try {
  this["Module"] = Module;
} catch (e) {
  this["Module"] = Module = {};
}

var ENVIRONMENT_IS_NODE = typeof process === "object";

var ENVIRONMENT_IS_WEB = typeof window === "object";

var ENVIRONMENT_IS_WORKER = typeof importScripts === "function";

var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;

if (ENVIRONMENT_IS_NODE) {
  Module["print"] = (function(x) {
    process["stdout"].write(x + "\n");
  });
  Module["printErr"] = (function(x) {
    process["stderr"].write(x + "\n");
  });
  var nodeFS = require("fs");
  var nodePath = require("path");
  Module["read"] = (function(filename) {
    filename = nodePath["normalize"](filename);
    var ret = nodeFS["readFileSync"](filename).toString();
    if (!ret && filename != nodePath["resolve"](filename)) {
      filename = path.join(__dirname, "..", "src", filename);
      ret = nodeFS["readFileSync"](filename).toString();
    }
    return ret;
  });
  Module["load"] = (function(f) {
    globalEval(read(f));
  });
  if (!Module["arguments"]) {
    Module["arguments"] = process["argv"].slice(2);
  }
} else if (ENVIRONMENT_IS_SHELL) {
  Module["print"] = print;
  Module["printErr"] = printErr;
  if (typeof read != "undefined") {
    Module["read"] = read;
  } else {
    Module["read"] = (function(f) {
      snarf(f);
    });
  }
  if (!Module["arguments"]) {
    if (typeof scriptArgs != "undefined") {
      Module["arguments"] = scriptArgs;
    } else if (typeof arguments != "undefined") {
      Module["arguments"] = arguments;
    }
  }
} else if (ENVIRONMENT_IS_WEB) {
  if (!Module["print"]) {
    Module["print"] = (function(x) {
      console.log(x);
    });
  }
  if (!Module["printErr"]) {
    Module["printErr"] = (function(x) {
      console.log(x);
    });
  }
  Module["read"] = (function(url) {
    var xhr = new XMLHttpRequest;
    xhr.open("GET", url, false);
    xhr.send(null);
    return xhr.responseText;
  });
  if (!Module["arguments"]) {
    if (typeof arguments != "undefined") {
      Module["arguments"] = arguments;
    }
  }
} else if (ENVIRONMENT_IS_WORKER) {
  Module["load"] = importScripts;
} else {
  throw "Unknown runtime environment. Where are we?";
}

function globalEval(x) {
  eval.call(null, x);
}

if (!Module["load"] == "undefined" && Module["read"]) {
  Module["load"] = (function(f) {
    globalEval(Module["read"](f));
  });
}

if (!Module["printErr"]) {
  Module["printErr"] = (function() {});
}

if (!Module["print"]) {
  Module["print"] = Module["printErr"];
}

if (!Module["arguments"]) {
  Module["arguments"] = [];
}

Module.print = Module["print"];

Module.printErr = Module["printErr"];

var Runtime = {
  stackSave: (function() {
    return STACKTOP;
  }),
  stackRestore: (function(stackTop) {
    STACKTOP = stackTop;
  }),
  forceAlign: (function(target, quantum) {
    quantum = quantum || 4;
    if (quantum == 1) return target;
    if (isNumber(target) && isNumber(quantum)) {
      return Math.ceil(target / quantum) * quantum;
    } else if (isNumber(quantum) && isPowerOfTwo(quantum)) {
      var logg = log2(quantum);
      return "((((" + target + ")+" + (quantum - 1) + ")>>" + logg + ")<<" + logg + ")";
    }
    return "Math.ceil((" + target + ")/" + quantum + ")*" + quantum;
  }),
  isNumberType: (function(type) {
    return type in Runtime.INT_TYPES || type in Runtime.FLOAT_TYPES;
  }),
  isPointerType: function isPointerType(type) {
    return type[type.length - 1] == "*";
  },
  isStructType: function isStructType(type) {
    if (isPointerType(type)) return false;
    if (/^\[\d+\ x\ (.*)\]/.test(type)) return true;
    if (/<?{ ?[^}]* ?}>?/.test(type)) return true;
    return type[0] == "%";
  },
  INT_TYPES: {
    "i1": 0,
    "i8": 0,
    "i16": 0,
    "i32": 0,
    "i64": 0
  },
  FLOAT_TYPES: {
    "float": 0,
    "double": 0
  },
  bitshift64: (function(low, high, op, bits) {
    var ander = Math.pow(2, bits) - 1;
    if (bits < 32) {
      switch (op) {
       case "shl":
        return [ low << bits, high << bits | (low & ander << 32 - bits) >>> 32 - bits ];
       case "ashr":
        return [ (low >>> bits | (high & ander) << 32 - bits) >> 0 >>> 0, high >> bits >>> 0 ];
       case "lshr":
        return [ (low >>> bits | (high & ander) << 32 - bits) >>> 0, high >>> bits ];
      }
    } else if (bits == 32) {
      switch (op) {
       case "shl":
        return [ 0, low ];
       case "ashr":
        return [ high, (high | 0) < 0 ? ander : 0 ];
       case "lshr":
        return [ high, 0 ];
      }
    } else {
      switch (op) {
       case "shl":
        return [ 0, low << bits - 32 ];
       case "ashr":
        return [ high >> bits - 32 >>> 0, (high | 0) < 0 ? ander : 0 ];
       case "lshr":
        return [ high >>> bits - 32, 0 ];
      }
    }
    abort("unknown bitshift64 op: " + [ value, op, bits ]);
  }),
  or64: (function(x, y) {
    var l = x | 0 | (y | 0);
    var h = (Math.round(x / 4294967296) | Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  }),
  and64: (function(x, y) {
    var l = (x | 0) & (y | 0);
    var h = (Math.round(x / 4294967296) & Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  }),
  xor64: (function(x, y) {
    var l = (x | 0) ^ (y | 0);
    var h = (Math.round(x / 4294967296) ^ Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  }),
  getNativeTypeSize: (function(type, quantumSize) {
    if (Runtime.QUANTUM_SIZE == 1) return 1;
    var size = {
      "%i1": 1,
      "%i8": 1,
      "%i16": 2,
      "%i32": 4,
      "%i64": 8,
      "%float": 4,
      "%double": 8
    }["%" + type];
    if (!size) {
      if (type[type.length - 1] == "*") {
        size = Runtime.QUANTUM_SIZE;
      } else if (type[0] == "i") {
        var bits = parseInt(type.substr(1));
        assert(bits % 8 == 0);
        size = bits / 8;
      }
    }
    return size;
  }),
  getNativeFieldSize: (function(type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  }),
  dedup: function dedup(items, ident) {
    var seen = {};
    if (ident) {
      return items.filter((function(item) {
        if (seen[item[ident]]) return false;
        seen[item[ident]] = true;
        return true;
      }));
    } else {
      return items.filter((function(item) {
        if (seen[item]) return false;
        seen[item] = true;
        return true;
      }));
    }
  },
  set: function set() {
    var args = typeof arguments[0] === "object" ? arguments[0] : arguments;
    var ret = {};
    for (var i = 0; i < args.length; i++) {
      ret[args[i]] = 0;
    }
    return ret;
  },
  calculateStructAlignment: function calculateStructAlignment(type) {
    type.flatSize = 0;
    type.alignSize = 0;
    var diffs = [];
    var prev = -1;
    type.flatIndexes = type.fields.map((function(field) {
      var size, alignSize;
      if (Runtime.isNumberType(field) || Runtime.isPointerType(field)) {
        size = Runtime.getNativeTypeSize(field);
        alignSize = size;
      } else if (Runtime.isStructType(field)) {
        size = Types.types[field].flatSize;
        alignSize = Types.types[field].alignSize;
      } else {
        throw "Unclear type in struct: " + field + ", in " + type.name_ + " :: " + dump(Types.types[type.name_]);
      }
      alignSize = type.packed ? 1 : Math.min(alignSize, Runtime.QUANTUM_SIZE);
      type.alignSize = Math.max(type.alignSize, alignSize);
      var curr = Runtime.alignMemory(type.flatSize, alignSize);
      type.flatSize = curr + size;
      if (prev >= 0) {
        diffs.push(curr - prev);
      }
      prev = curr;
      return curr;
    }));
    type.flatSize = Runtime.alignMemory(type.flatSize, type.alignSize);
    if (diffs.length == 0) {
      type.flatFactor = type.flatSize;
    } else if (Runtime.dedup(diffs).length == 1) {
      type.flatFactor = diffs[0];
    }
    type.needsFlattening = type.flatFactor != 1;
    return type.flatIndexes;
  },
  generateStructInfo: (function(struct, typeName, offset) {
    var type, alignment;
    if (typeName) {
      offset = offset || 0;
      type = (typeof Types === "undefined" ? Runtime.typeInfo : Types.types)[typeName];
      if (!type) return null;
      assert(type.fields.length === struct.length, "Number of named fields must match the type for " + typeName);
      alignment = type.flatIndexes;
    } else {
      var type = {
        fields: struct.map((function(item) {
          return item[0];
        }))
      };
      alignment = Runtime.calculateStructAlignment(type);
    }
    var ret = {
      __size__: type.flatSize
    };
    if (typeName) {
      struct.forEach((function(item, i) {
        if (typeof item === "string") {
          ret[item] = alignment[i] + offset;
        } else {
          var key;
          for (var k in item) key = k;
          ret[key] = Runtime.generateStructInfo(item[key], type.fields[i], alignment[i]);
        }
      }));
    } else {
      struct.forEach((function(item, i) {
        ret[item[1]] = alignment[i];
      }));
    }
    return ret;
  }),
  addFunction: (function(func) {
    var ret = FUNCTION_TABLE.length;
    FUNCTION_TABLE.push(func);
    FUNCTION_TABLE.push(0);
    return ret;
  }),
  stackAlloc: function stackAlloc(size) {
    var ret = STACKTOP;
    STACKTOP += size;
    STACKTOP = STACKTOP + 3 >> 2 << 2;
    return ret;
  },
  staticAlloc: function staticAlloc(size) {
    var ret = STATICTOP;
    STATICTOP += size;
    STATICTOP = STATICTOP + 3 >> 2 << 2;
    if (STATICTOP >= TOTAL_MEMORY) enlargeMemory();
    return ret;
  },
  alignMemory: function alignMemory(size, quantum) {
    var ret = size = Math.ceil(size / (quantum ? quantum : 4)) * (quantum ? quantum : 4);
    return ret;
  },
  makeBigInt: function makeBigInt(low, high, unsigned) {
    var ret = unsigned ? (low >>> 0) + (high >>> 0) * 4294967296 : (low >>> 0) + (high | 0) * 4294967296;
    return ret;
  },
  QUANTUM_SIZE: 4,
  __dummy__: 0
};

var CorrectionsMonitor = {
  MAX_ALLOWED: 0,
  corrections: 0,
  sigs: {},
  note: (function(type, succeed, sig) {
    if (!succeed) {
      this.corrections++;
      if (this.corrections >= this.MAX_ALLOWED) abort("\n\nToo many corrections!");
    }
  }),
  print: (function() {})
};

var __THREW__ = false;

var ABORT = false;

var undef = 0;

var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD;

var tempI64, tempI64b;

function abort(text) {
  Module.print(text + ":\n" + (new Error).stack);
  ABORT = true;
  throw "Assertion: " + text;
}

function assert(condition, text) {
  if (!condition) {
    abort("Assertion failed: " + text);
  }
}

var globalScope = this;

function ccall(ident, returnType, argTypes, args) {
  var stack = 0;
  function toC(value, type) {
    if (type == "string") {
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length + 1);
      writeStringToMemory(value, ret);
      return ret;
    } else if (type == "array") {
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length);
      writeArrayToMemory(value, ret);
      return ret;
    }
    return value;
  }
  function fromC(value, type) {
    if (type == "string") {
      return Pointer_stringify(value);
    }
    assert(type != "array");
    return value;
  }
  try {
    var func = eval("_" + ident);
  } catch (e) {
    try {
      func = globalScope["Module"]["_" + ident];
    } catch (e) {}
  }
  assert(func, "Cannot call unknown function " + ident + " (perhaps LLVM optimizations or closure removed it?)");
  var i = 0;
  var cArgs = args ? args.map((function(arg) {
    return toC(arg, argTypes[i++]);
  })) : [];
  var ret = fromC(func.apply(null, cArgs), returnType);
  if (stack) Runtime.stackRestore(stack);
  return ret;
}

Module["ccall"] = ccall;

function cwrap(ident, returnType, argTypes) {
  return (function() {
    return ccall(ident, returnType, argTypes, Array.prototype.slice.call(arguments));
  });
}

Module["cwrap"] = cwrap;

function setValue(ptr, value, type, noSafe) {
  type = type || "i8";
  if (type[type.length - 1] === "*") type = "i32";
  switch (type) {
   case "i1":
    HEAP8[ptr] = value;
    break;
   case "i8":
    HEAP8[ptr] = value;
    break;
   case "i16":
    HEAP16[ptr >> 1] = value;
    break;
   case "i32":
    HEAP32[ptr >> 2] = value;
    break;
   case "i64":
    HEAP32[ptr >> 2] = value;
    break;
   case "float":
    HEAPF32[ptr >> 2] = value;
    break;
   case "double":
    tempDoubleF64[0] = value, HEAP32[ptr >> 2] = tempDoubleI32[0], HEAP32[ptr + 4 >> 2] = tempDoubleI32[1];
    break;
   default:
    abort("invalid type for setValue: " + type);
  }
}

Module["setValue"] = setValue;

function getValue(ptr, type, noSafe) {
  type = type || "i8";
  if (type[type.length - 1] === "*") type = "i32";
  switch (type) {
   case "i1":
    return HEAP8[ptr];
   case "i8":
    return HEAP8[ptr];
   case "i16":
    return HEAP16[ptr >> 1];
   case "i32":
    return HEAP32[ptr >> 2];
   case "i64":
    return HEAP32[ptr >> 2];
   case "float":
    return HEAPF32[ptr >> 2];
   case "double":
    return tempDoubleI32[0] = HEAP32[ptr >> 2], tempDoubleI32[1] = HEAP32[ptr + 4 >> 2], tempDoubleF64[0];
   default:
    abort("invalid type for setValue: " + type);
  }
  return null;
}

Module["getValue"] = getValue;

var ALLOC_NORMAL = 0;

var ALLOC_STACK = 1;

var ALLOC_STATIC = 2;

Module["ALLOC_NORMAL"] = ALLOC_NORMAL;

Module["ALLOC_STACK"] = ALLOC_STACK;

Module["ALLOC_STATIC"] = ALLOC_STATIC;

function allocate(slab, types, allocator) {
  var zeroinit, size;
  if (typeof slab === "number") {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }
  var singleType = typeof types === "string" ? types : null;
  var ret = [ _malloc, Runtime.stackAlloc, Runtime.staticAlloc ][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  if (zeroinit) {
    _memset(ret, 0, size);
    return ret;
  }
  var i = 0, type;
  while (i < size) {
    var curr = slab[i];
    if (typeof curr === "function") {
      curr = Runtime.getFunctionIndex(curr);
    }
    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }
    if (type == "i64") type = "i32";
    setValue(ret + i, curr, type);
    i += Runtime.getNativeTypeSize(type);
  }
  return ret;
}

Module["allocate"] = allocate;

function Pointer_stringify(ptr, length) {
  var nullTerminated = typeof length == "undefined";
  var ret = "";
  var i = 0;
  var t;
  var nullByte = String.fromCharCode(0);
  while (1) {
    t = String.fromCharCode(HEAPU8[ptr + i]);
    if (nullTerminated && t == nullByte) {
      break;
    } else {}
    ret += t;
    i += 1;
    if (!nullTerminated && i == length) {
      break;
    }
  }
  return ret;
}

Module["Pointer_stringify"] = Pointer_stringify;

function Array_stringify(array) {
  var ret = "";
  for (var i = 0; i < array.length; i++) {
    ret += String.fromCharCode(array[i]);
  }
  return ret;
}

Module["Array_stringify"] = Array_stringify;

var FUNCTION_TABLE;

var PAGE_SIZE = 4096;

function alignMemoryPage(x) {
  return x + 4095 >> 12 << 12;
}

var HEAP;

var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;

var STACK_ROOT, STACKTOP, STACK_MAX;

var STATICTOP;

function enlargeMemory() {
  while (TOTAL_MEMORY <= STATICTOP) {
    TOTAL_MEMORY = alignMemoryPage(2 * TOTAL_MEMORY);
  }
  var oldHEAP8 = HEAP8;
  var buffer = new ArrayBuffer(TOTAL_MEMORY);
  HEAP8 = new Int8Array(buffer);
  HEAP16 = new Int16Array(buffer);
  HEAP32 = new Int32Array(buffer);
  HEAPU8 = new Uint8Array(buffer);
  HEAPU16 = new Uint16Array(buffer);
  HEAPU32 = new Uint32Array(buffer);
  HEAPF32 = new Float32Array(buffer);
  HEAPF64 = new Float64Array(buffer);
  HEAP8.set(oldHEAP8);
}

var TOTAL_STACK = Module["TOTAL_STACK"] || 5242880;

var TOTAL_MEMORY = Module["TOTAL_MEMORY"] || 10485760;

var FAST_MEMORY = Module["FAST_MEMORY"] || 2097152;

assert(!!Int32Array && !!Float64Array && !!(new Int32Array(1))["subarray"] && !!(new Int32Array(1))["set"], "Cannot fallback to non-typed array case: Code is too specialized");

var buffer = new ArrayBuffer(TOTAL_MEMORY);

HEAP8 = new Int8Array(buffer);

HEAP16 = new Int16Array(buffer);

HEAP32 = new Int32Array(buffer);

HEAPU8 = new Uint8Array(buffer);

HEAPU16 = new Uint16Array(buffer);

HEAPU32 = new Uint32Array(buffer);

HEAPF32 = new Float32Array(buffer);

HEAPF64 = new Float64Array(buffer);

HEAP32[0] = 255;

assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, "Typed arrays 2 must be run on a little-endian system");

var base = intArrayFromString("(null)");

STATICTOP = base.length;

for (var i = 0; i < base.length; i++) {
  HEAP8[i] = base[i];
}

Module["HEAP"] = HEAP;

Module["HEAP8"] = HEAP8;

Module["HEAP16"] = HEAP16;

Module["HEAP32"] = HEAP32;

Module["HEAPU8"] = HEAPU8;

Module["HEAPU16"] = HEAPU16;

Module["HEAPU32"] = HEAPU32;

Module["HEAPF32"] = HEAPF32;

Module["HEAPF64"] = HEAPF64;

STACK_ROOT = STACKTOP = Runtime.alignMemory(STATICTOP);

STACK_MAX = STACK_ROOT + TOTAL_STACK;

var tempDoublePtr = Runtime.alignMemory(STACK_MAX, 8);

var tempDoubleI8 = HEAP8.subarray(tempDoublePtr);

var tempDoubleI32 = HEAP32.subarray(tempDoublePtr >> 2);

var tempDoubleF32 = HEAPF32.subarray(tempDoublePtr >> 2);

var tempDoubleF64 = HEAPF64.subarray(tempDoublePtr >> 3);

function copyTempFloat(ptr) {
  tempDoubleI8[0] = HEAP8[ptr];
  tempDoubleI8[1] = HEAP8[ptr + 1];
  tempDoubleI8[2] = HEAP8[ptr + 2];
  tempDoubleI8[3] = HEAP8[ptr + 3];
}

function copyTempDouble(ptr) {
  tempDoubleI8[0] = HEAP8[ptr];
  tempDoubleI8[1] = HEAP8[ptr + 1];
  tempDoubleI8[2] = HEAP8[ptr + 2];
  tempDoubleI8[3] = HEAP8[ptr + 3];
  tempDoubleI8[4] = HEAP8[ptr + 4];
  tempDoubleI8[5] = HEAP8[ptr + 5];
  tempDoubleI8[6] = HEAP8[ptr + 6];
  tempDoubleI8[7] = HEAP8[ptr + 7];
}

STACK_MAX = tempDoublePtr + 8;

STATICTOP = alignMemoryPage(STACK_MAX);

function callRuntimeCallbacks(callbacks) {
  while (callbacks.length > 0) {
    var callback = callbacks.shift();
    var func = callback.func;
    if (typeof func === "number") {
      func = FUNCTION_TABLE[func];
    }
    func(callback.arg === undefined ? null : callback.arg);
  }
}

var __ATINIT__ = [];

var __ATMAIN__ = [];

var __ATEXIT__ = [];

function initRuntime() {
  callRuntimeCallbacks(__ATINIT__);
}

function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}

function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
  CorrectionsMonitor.print();
}

function Array_copy(ptr, num) {
  return Array.prototype.slice.call(HEAP8.subarray(ptr, ptr + num));
  return HEAP.slice(ptr, ptr + num);
}

Module["Array_copy"] = Array_copy;

function TypedArray_copy(ptr, num, offset) {
  if (offset === undefined) {
    offset = 0;
  }
  var arr = new Uint8Array(num - offset);
  for (var i = offset; i < num; ++i) {
    arr[i - offset] = HEAP8[ptr + i];
  }
  return arr.buffer;
}

Module["TypedArray_copy"] = TypedArray_copy;

function String_len(ptr) {
  var i = 0;
  while (HEAP8[ptr + i]) i++;
  return i;
}

Module["String_len"] = String_len;

function String_copy(ptr, addZero) {
  var len = String_len(ptr);
  if (addZero) len++;
  var ret = Array_copy(ptr, len);
  if (addZero) ret[len - 1] = 0;
  return ret;
}

Module["String_copy"] = String_copy;

function intArrayFromString(stringy, dontAddNull, length) {
  var ret = [];
  var t;
  var i = 0;
  if (length === undefined) {
    length = stringy.length;
  }
  while (i < length) {
    var chr = stringy.charCodeAt(i);
    if (chr > 255) {
      chr &= 255;
    }
    ret.push(chr);
    i = i + 1;
  }
  if (!dontAddNull) {
    ret.push(0);
  }
  return ret;
}

Module["intArrayFromString"] = intArrayFromString;

function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 255) {
      chr &= 255;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join("");
}

Module["intArrayToString"] = intArrayToString;

function writeStringToMemory(string, buffer, dontAddNull) {
  var i = 0;
  while (i < string.length) {
    var chr = string.charCodeAt(i);
    if (chr > 255) {
      chr &= 255;
    }
    HEAP8[buffer + i] = chr;
    i = i + 1;
  }
  if (!dontAddNull) {
    HEAP8[buffer + i] = 0;
  }
}

Module["writeStringToMemory"] = writeStringToMemory;

function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[buffer + i] = array[i];
  }
}

Module["writeArrayToMemory"] = writeArrayToMemory;

var STRING_TABLE = [];

function unSign(value, bits, ignore, sig) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2 * Math.abs(1 << bits - 1) + value : Math.pow(2, bits) + value;
}

function reSign(value, bits, ignore, sig) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << bits - 1) : Math.pow(2, bits - 1);
  if (value >= half && (bits <= 32 || value > half)) {
    value = -2 * half + value;
  }
  return value;
}

var runDependencies = 0;

function addRunDependency() {
  runDependencies++;
  if (Module["monitorRunDependencies"]) {
    Module["monitorRunDependencies"](runDependencies);
  }
}

function removeRunDependency() {
  runDependencies--;
  if (Module["monitorRunDependencies"]) {
    Module["monitorRunDependencies"](runDependencies);
  }
  if (runDependencies == 0) run();
}

function __ZN2js2gcL14GetGCKindSlotsENS0_9AllocKindE($thingKind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($thingKind | 0) == 2 || ($thingKind | 0) == 3) {
      __label__ = 2;
      break;
    } else if (($thingKind | 0) == 4 || ($thingKind | 0) == 5) {
      __label__ = 3;
      break;
    } else if (($thingKind | 0) == 6 || ($thingKind | 0) == 7) {
      __label__ = 4;
      break;
    } else if (($thingKind | 0) == 8 || ($thingKind | 0) == 9) {
      __label__ = 5;
      break;
    } else if (($thingKind | 0) == 11 || ($thingKind | 0) == 10) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $_0 = 2;
    __label__ = 7;
    break;
   case 3:
    var $_0 = 4;
    __label__ = 7;
    break;
   case 4:
    var $_0 = 8;
    __label__ = 7;
    break;
   case 5:
    var $_0 = 12;
    __label__ = 7;
    break;
   case 6:
    var $_0 = 16;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js8Bindings9lastShapeEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js8Bindings16countArgsAndVarsEv($this_0_1_val, $this_0_2_val) {
  return ($this_0_2_val & 65535) + ($this_0_1_val & 65535) | 0;
}

function __ZN9JSContext20typeInferenceEnabledEv($this_0_33_val) {
  return ($this_0_33_val & 1) << 24 >> 24 != 0;
}

function __ZNK8JSObject10fixedSlotsEv($this) {
  return $this + 40 | 0;
}

function __ZNK2js8Bindings17extensibleParentsEv($this_0_4_val) {
  return ($this_0_4_val & 1) << 24 >> 24 != 0;
}

function __ZN8JSObject6asCallEv($this) {
  return $this;
}

function __ZN2js2gcL15GetGCObjectKindEjb($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject10makeVarObjEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] | 4096;
  HEAP32[$1 >> 2] = $3;
  return;
}

function _BUILD_JSVAL($agg_result, $tag) {
  HEAP32[$agg_result + 4 >> 2] = $tag;
  HEAP32[$agg_result >> 2] = 0;
  return;
}

function _OBJECT_TO_JSVAL_IMPL($agg_result, $obj) {
  HEAP32[$agg_result + 4 >> 2] = -121;
  HEAP32[$agg_result >> 2] = $obj;
  return;
}

function __ZN8JSObject11setOwnShapeEj($this, $s) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] | 128;
  HEAP32[$1 >> 2] = $3;
  HEAP32[$this + 12 >> 2] = $s;
  return;
}

function __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($this, $newType) {
  HEAP32[$this + 36 >> 2] = $newType;
  return;
}

function __ZN8JSObject11setDelegateEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function _MAGIC_TO_JSVAL_IMPL($agg_result, $why) {
  HEAP32[$agg_result + 4 >> 2] = -124;
  HEAP32[$agg_result >> 2] = $why;
  return;
}

function __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($kind) {
  return HEAP32[__ZN2js2gc5Arena10ThingSizesE + ($kind << 2) >> 2];
}

function __ZN8JSObject9earlyInitEj($this, $capacity) {
  HEAP32[$this + 28 >> 2] = $capacity;
  HEAP32[$this >> 2] = 0;
  return;
}

function __ZN2js2gc8FreeSpan8allocateEj($this, $thingSize) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $4 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 < $4 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $2 + $thingSize | 0;
    __label__ = 5;
    break;
   case 3:
    if (($2 | 0) == ($4 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $11 = $2;
    var $12 = $this;
    var $13$0 = HEAP32[$11 >> 2];
    var $13$1 = HEAP32[$11 + 4 >> 2];
    HEAP32[$12 >> 2] = $13$0;
    HEAP32[$12 + 4 >> 2] = $13$1;
    __label__ = 5;
    break;
   case 5:
    var $_0 = $2;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14BreakpointSite3incEP9JSContext($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 24 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $12 = $2;
      __label__ = 4;
      break;
    }
   case 2:
    if ((HEAP32[$this + 28 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $12 = $2;
      __label__ = 4;
      break;
    }
   case 3:
    HEAP8[HEAP32[$this + 4 >> 2]] = 83;
    var $12 = HEAP32[$1 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $12;
    HEAP32[$1 >> 2] = $12 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14BreakpointSite3decEP9JSContext($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 24 | 0;
    var $3 = HEAP32[$1 >> 2] - 1 | 0;
    HEAP32[$1 >> 2] = $3;
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    if ((HEAP32[$this + 28 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP8[HEAP32[$this + 4 >> 2]] = HEAP32[$this + 8 >> 2] & 255;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14BreakpointSite7setTrapEP9JSContextPF12JSTrapStatusS2_P8JSScriptPhPN2JS5ValueES8_ERKS8_($this, $closure) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 24 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP8[HEAP32[$this + 4 >> 2]] = 83;
    __label__ = 3;
    break;
   case 3:
    HEAP32[$this + 28 >> 2] = 2;
    var $9 = $closure | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $this + 32 | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Breakpoint13fromSiteLinksEP10JSCListStr($links) {
  return $links - 24 + 4 | 0;
}

function __ZN2js10BreakpointC2EPNS_8DebuggerEPNS_14BreakpointSiteEP8JSObject($this, $debugger, $site, $handler) {
  HEAP32[$this >> 2] = $debugger;
  HEAP32[$this + 4 >> 2] = $site;
  HEAP32[$this + 8 >> 2] = $handler;
  var $5 = $this + 12 | 0;
  HEAP32[$5 >> 2] = $debugger + 44 | 0;
  var $7 = $debugger + 48 | 0;
  var $8 = HEAP32[$7 >> 2];
  HEAP32[$this + 16 >> 2] = $8;
  var $11 = HEAP32[$7 >> 2] | 0;
  HEAP32[$11 >> 2] = $5;
  HEAP32[$7 >> 2] = $5;
  var $13 = $this + 20 | 0;
  HEAP32[$13 >> 2] = $site + 16 | 0;
  var $15 = $site + 20 | 0;
  var $16 = HEAP32[$15 >> 2];
  HEAP32[$this + 24 >> 2] = $16;
  var $19 = HEAP32[$15 >> 2] | 0;
  HEAP32[$19 >> 2] = $13;
  HEAP32[$15 >> 2] = $13;
  return;
}

function __ZN2js10Breakpoint17fromDebuggerLinksEP10JSCListStr($links) {
  return $links - 16 + 4 | 0;
}

function __ZN2js10CallObject6createEP9JSContextP8JSScriptR8JSObjectPS5_($cx, $script, $scopeChain, $callee) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $script + 64 | 0;
    var $_idx_val = HEAP16[$script + 68 >> 1];
    var $_idx1_val = HEAP16[$script + 70 >> 1];
    var $2 = __ZNK2js8Bindings16countArgsAndVarsEv($_idx_val, $_idx1_val);
    var $3 = $2 + 2 | 0;
    var $4 = __ZN2js2gcL15GetGCObjectKindEjb($3);
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $5 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $kind_0 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $7 = __ZN2js2gcL14GetGCKindSlotsENS0_9AllocKindE($4);
    if ($7 >>> 0 < $3 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $kind_0 = $4;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = __ZN2js2gcL15GetGCObjectKindEjb(2);
    var $kind_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $kind_0;
    var $12 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind_0);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN8JSObject8initCallEP9JSContextRKN2js8BindingsEPS_($12, $cx, $1, $scopeChain);
    __ZN8JSObject10makeVarObjEv($12);
    var $15 = $12;
    var $16 = $cx;
    var $17 = __ZN8JSObject27ensureInstanceReservedSlotsEP9JSContextj($15, $16, $2);
    if ($17) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $19 = __ZN8JSObject6asCallEv($12);
    __ZN2js10CallObject9setCalleeEP8JSObject($19, $callee);
    var $_0 = $19;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($kind);
    var $2 = __Z10NewGCThingI8JSObjectEPT_P9JSContextN2js2gc9AllocKindEj($cx, $kind, $1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js2gcL14GetGCKindSlotsENS0_9AllocKindE($kind);
    __ZN8JSObject9earlyInitEj($2, $5);
    __label__ = 3;
    break;
   case 3:
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject8initCallEP9JSContextRKN2js8BindingsEPS_($this, $cx, $bindings, $parent) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($this, __ZN2js9CallClassE, __ZN2js5types15emptyTypeObjectE, $parent, 0, 0);
    var $bindings_idx_val = HEAP32[$bindings >> 2];
    var $1 = __ZNK2js8Bindings9lastShapeEv($bindings_idx_val);
    HEAP32[$this >> 2] = $1;
    var $bindings_idx1_val = HEAP8[$bindings + 10 | 0];
    var $3 = __ZNK2js8Bindings17extensibleParentsEv($bindings_idx1_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    var $5 = __Z16js_GenerateShapeP9JSContext($cx_idx_val);
    __ZN8JSObject11setOwnShapeEj($this, $5);
    __label__ = 4;
    break;
   case 3:
    var $8 = HEAP32[$1 >> 2];
    HEAP32[$this + 12 >> 2] = $8;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10CallObject9setCalleeEP8JSObject($this, $callee) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2JSL17ObjectOrNullValueEP8JSObject($1, $callee);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  __ZN8JSObject12setFixedSlotEjRKN2JS5ValueE($2, 0, $_idx_val$0, $_idx_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN8JSObject12setFixedSlotEjRKN2JS5ValueE($this, $slot, $value_0_0_0_val$0, $value_0_0_0_val$1) {
  var $1 = __ZNK8JSObject10fixedSlotsEv($this);
  var $2 = $1 + ($slot << 3) | 0;
  HEAP32[$2 >> 2] = $value_0_0_0_val$0;
  HEAP32[$2 + 4 >> 2] = $value_0_0_0_val$1;
  return;
}

function __ZN2JSL17ObjectOrNullValueEP8JSObject($agg_result, $obj) {
  __ZN2JS5Value15setObjectOrNullEP8JSObject($agg_result, $obj);
  return;
}

function __ZN2JS5Value15setObjectOrNullEP8JSObject($this, $arg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($arg | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($this, $arg);
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value7setNullEv($this);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JS5Value9setObjectER8JSObject($this, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _OBJECT_TO_JSVAL_IMPL($1, $obj);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2JS5Value7setNullEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BUILD_JSVAL($1, -122);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($this, $aclasp, $type, $parent, $priv, $denseArray) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this + 4 >> 2] = $aclasp;
    var $3 = HEAP32[$this + 28 >> 2];
    var $4 = $3 << 27;
    var $5 = $this + 8 | 0;
    HEAP32[$5 >> 2] = $4;
    HEAP32[$this + 24 >> 2] = $priv;
    var $7 = $this + 32 | 0;
    HEAP32[$7 >> 2] = 0;
    var $8 = __ZNK8JSObject10fixedSlotsEv($this);
    if ($denseArray) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$7 >> 2] = $8;
    var $10 = $4 | 16384;
    HEAP32[$5 >> 2] = $10;
    __label__ = 4;
    break;
   case 3:
    __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb($8, $3, 0);
    __label__ = 4;
    break;
   case 4:
    HEAP32[$this + 16 >> 2] = 0;
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($this, $type);
    __ZN8JSObject9setParentEPS_($this, $parent);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb($vec, $len, $useHoles) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($len | 0) == 0;
    if ($useHoles) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    if ($1) {
      __label__ = 6;
      break;
    } else {
      var $i_04 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    if ($1) {
      __label__ = 6;
      break;
    } else {
      var $i1_01 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $i_04;
    var $2 = $vec + ($i_04 << 3) | 0;
    __ZN2JS5Value8setMagicE10JSWhyMagic($2, 0);
    var $3 = $i_04 + 1 | 0;
    if (($3 | 0) == ($len | 0)) {
      __label__ = 6;
      break;
    } else {
      var $i_04 = $3;
      __label__ = 4;
      break;
    }
   case 5:
    var $i1_01;
    var $4 = $vec + ($i1_01 << 3) | 0;
    __ZN2JS5Value12setUndefinedEv($4);
    var $5 = $i1_01 + 1 | 0;
    if (($5 | 0) == ($len | 0)) {
      __label__ = 6;
      break;
    } else {
      var $i1_01 = $5;
      __label__ = 5;
      break;
    }
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject9setParentEPS_($this, $newParent) {
  __ZN8JSObject19setDelegateNullSafeEPS_($newParent);
  HEAP32[$this + 20 >> 2] = $newParent;
  return;
}

function __ZN8JSObject19setDelegateNullSafeEPS_($obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN8JSObject11setDelegateEv($obj);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JS5Value8setMagicE10JSWhyMagic($this, $why) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _MAGIC_TO_JSVAL_IMPL($1, $why);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2JS5Value12setUndefinedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BUILD_JSVAL($1, -126);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return;
}

function __Z10NewGCThingI8JSObjectEPT_P9JSContextN2js2gc9AllocKindEj($cx, $kind, $thingSize) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$cx + 56 >> 2] + 8 | 0;
    var $4 = __ZN2js2gc10ArenaLists20allocateFromFreeListENS0_9AllocKindEj($3, $kind, $thingSize);
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $9 = $4;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js2gc10ArenaLists14refillFreeListEP9JSContextNS0_9AllocKindE($cx, $kind);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc10ArenaLists20allocateFromFreeListENS0_9AllocKindEj($this, $thingKind, $thingSize) {
  var $1 = $this + ($thingKind << 3) | 0;
  var $2 = __ZN2js2gc8FreeSpan8allocateEj($1, $thingSize);
  return $2;
}

function __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, $name, $required) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $s = __stackBase__;
  var $3 = $s | 0;
  HEAP8[$3] = $required + 47 & 255;
  HEAP8[$s + 1 | 0] = 0;
  var $6 = ($required | 0) == 1 ? __str17668 | 0 : STRING_TABLE.__str226519 | 0;
  _JS_ReportErrorNumber($cx, 4, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $name, HEAP32[tempInt + 4 >> 2] = $3, HEAP32[tempInt + 8 >> 2] = $6, tempInt));
  STACKTOP = __stackBase__;
  return;
}

function __Z20ReportObjectRequiredP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  _JS_ReportErrorNumber($cx, 4, 231, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js14BreakpointSiteC2EP8JSScriptPh($this, $script, $pc) {
  HEAP32[$this >> 2] = $script;
  HEAP32[$this + 4 >> 2] = $pc;
  HEAP32[$this + 8 >> 2] = HEAPU8[$pc] & 255;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  HEAP32[$this + 28 >> 2] = 0;
  var $9 = $this + 32 | 0;
  __ZN2JSL14UndefinedValueEv($9);
  var $10 = $this + 16 | 0;
  HEAP32[$10 >> 2] = $10;
  HEAP32[$this + 20 >> 2] = $10;
  return;
}

function __ZN2JSL14UndefinedValueEv($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2js14BreakpointSite9clearTrapEP9JSContextPNS_6detail9HashTableINS_12HashMapEntryIPhPS0_EENS_7HashMapIS6_S7_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESC_E4EnumEPPF12JSTrapStatusS2_P8JSScriptS6_PN2JS5ValueESM_ESN_($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this + 28 >> 2] = 0;
    var $2 = $this + 32 | 0;
    __ZN2JS5Value12setUndefinedEv($2);
    if ((HEAP32[$this + 24 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP8[HEAP32[$this + 4 >> 2]] = HEAP32[$this + 8 >> 2] & 255;
    __ZN2js14BreakpointSite14destroyIfEmptyEP9JSRuntimePNS_6detail9HashTableINS_12HashMapEntryIPhPS0_EENS_7HashMapIS6_S7_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESC_E4EnumE($this, $e);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14BreakpointSite14destroyIfEmptyEP9JSRuntimePNS_6detail9HashTableINS_12HashMapEntryIPhPS0_EENS_7HashMapIS6_S7_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESC_E4EnumE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 16 | 0;
    if ((HEAP32[$1 >> 2] | 0) == ($1 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    if ((HEAP32[$this + 28 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    if (($e | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4Enum11removeFrontEv($e);
    __label__ = 6;
    break;
   case 5:
    var $15 = HEAP32[$this >> 2];
    var $16 = __ZNK2js2gc4Cell11compartmentEv($15);
    var $17 = $16 + 1956 | 0;
    var $18 = $this + 4 | 0;
    __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE6removeERKS1_($17, $18);
    __label__ = 6;
    break;
   case 6:
    __ZN9JSRuntime7delete_IN2js14BreakpointSiteEEEvPT_($this);
    __label__ = 7;
    break;
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6removeERNS0_14HashTableEntryIS6_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZNK2js2gc4Cell11compartmentEv($this) {
  var $1 = __ZNK2js2gc4Cell11arenaHeaderEv($this);
  return HEAP32[$1 >> 2];
}

function __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE6removeERKS1_($this, $l) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 4;
    __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE6lookupERKS1_($p, $this, $l);
    var $p_idx_val = HEAP32[$p >> 2];
    var $p_idx_val_idx_val = HEAP32[$p_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrcvMSE_FvvEEv($1, $p_idx_val_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS1_S3_EENS7_13MapHashPolicyES6_E3PtrE($this, $p_idx_val);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime7delete_IN2js14BreakpointSiteEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $p;
    __ZN9JSRuntime5free_EPv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js14BreakpointSite15firstBreakpointEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 16 | 0;
    var $3 = HEAP32[$1 >> 2];
    if (($3 | 0) == ($1 | 0)) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN2js10Breakpoint13fromSiteLinksEP10JSCListStr($3);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14BreakpointSite13hasBreakpointEPNS_10BreakpointE($this, $bp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js14BreakpointSite15firstBreakpointEv($this);
    var $p_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $p_0;
    if (($p_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($p_0 | 0) == ($bp | 0)) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $p_0_idx_val = HEAP32[$p_0 + 4 >> 2];
    var $p_0_idx1_val = HEAP32[$p_0 + 20 >> 2];
    var $7 = __ZN2js10Breakpoint10nextInSiteEv($p_0_idx_val, $p_0_idx1_val);
    var $p_0 = $7;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Breakpoint10nextInSiteEv($this_0_1_val, $this_0_4_0_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_1_val + 16 | 0) == ($this_0_4_0_val | 0)) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js10Breakpoint13fromSiteLinksEP10JSCListStr($this_0_4_0_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Breakpoint7destroyEP9JSContextPNS_6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS6_S8_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESD_E4EnumE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_pre = $this + 4 | 0;
    if ((HEAP8[HEAP32[$this >> 2] + 40 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$_pre >> 2];
    __ZN2js14BreakpointSite3decEP9JSContext($8);
    __label__ = 3;
    break;
   case 3:
    var $9 = $this + 12 | 0;
    var $10 = HEAP32[$9 >> 2];
    var $11 = $this + 16 | 0;
    var $13 = HEAP32[$11 >> 2] | 0;
    HEAP32[$13 >> 2] = $10;
    var $14 = HEAP32[$11 >> 2];
    var $16 = HEAP32[$9 >> 2] + 4 | 0;
    HEAP32[$16 >> 2] = $14;
    var $17 = $this + 20 | 0;
    var $18 = HEAP32[$17 >> 2];
    var $19 = $this + 24 | 0;
    var $21 = HEAP32[$19 >> 2] | 0;
    HEAP32[$21 >> 2] = $18;
    var $22 = HEAP32[$19 >> 2];
    var $24 = HEAP32[$17 >> 2] + 4 | 0;
    HEAP32[$24 >> 2] = $22;
    var $25 = HEAP32[$_pre >> 2];
    __ZN2js14BreakpointSite14destroyIfEmptyEP9JSRuntimePNS_6detail9HashTableINS_12HashMapEntryIPhPS0_EENS_7HashMapIS6_S7_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESC_E4EnumE($25, $e);
    __ZN9JSRuntime7delete_IN2js10BreakpointEEEvPT_($this);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime7delete_IN2js10BreakpointEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $p;
    __ZN9JSRuntime5free_EPv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Breakpoint14nextInDebuggerEv($this_0_0_val, $this_0_3_0_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_0_val + 44 | 0) == ($this_0_3_0_val | 0)) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js10Breakpoint17fromDebuggerLinksEP10JSCListStr($this_0_3_0_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8DebuggerC2EP9JSContextP8JSObject($this, $cx, $dbg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $lock = __stackBase__ + 8;
  HEAP32[$this + 8 >> 2] = $dbg;
  var $4 = $this + 12 | 0;
  __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES5_($4);
  HEAP32[$this + 36 >> 2] = 0;
  HEAP8[$this + 40 | 0] = 1;
  var $7 = $this + 52 | 0;
  var $cx_idx1 = $cx + 52 | 0;
  var $cx_idx1_val = HEAP32[$cx_idx1 >> 2];
  __ZN2js18RuntimeAllocPolicyC1EP9JSContext($1, $cx_idx1_val);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC1ES7_($7, $_0_val);
  var $8 = $this + 80 | 0;
  var $cx_idx3_val = HEAP32[$cx_idx1 >> 2];
  __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEEC1EP9JSContext($8, $cx_idx3_val);
  var $9 = $this + 116 | 0;
  var $cx_idx2_val = HEAP32[$cx_idx1 >> 2];
  __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEEC1EP9JSContext($9, $cx_idx2_val);
  var $10 = $this + 152 | 0;
  var $cx_idx_val = HEAP32[$cx_idx1 >> 2];
  __ZN2js18RuntimeAllocPolicyC1EP9JSContext($2, $cx_idx_val);
  var $_04_val = HEAP32[$2 >> 2];
  __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC1ES7_($10, $_04_val);
  var $11 = HEAP32[$cx_idx1 >> 2];
  __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $11);
  var $12 = $11 + 144228 | 0;
  var $13 = $this | 0;
  HEAP32[$this >> 2] = $12;
  var $15 = $11 + 144232 | 0;
  var $16 = HEAP32[$15 >> 2];
  HEAP32[$this + 4 >> 2] = $16;
  var $19 = HEAP32[$15 >> 2] | 0;
  HEAP32[$19 >> 2] = $13;
  HEAP32[$15 >> 2] = $13;
  var $20 = $this + 44 | 0;
  HEAP32[$20 >> 2] = $20;
  HEAP32[$this + 48 >> 2] = $20;
  STACKTOP = __stackBase__;
  return;
}

__ZN2js8DebuggerC2EP9JSContextP8JSObject["X"] = 1;

function __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES5_($this) {
  __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES5_($this);
  return;
}

function __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC1ES7_($this, $a_01) {
  __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES7_($this, $a_01);
  return;
}

function __ZN2js18RuntimeAllocPolicyC1EP9JSContext($this, $cx_0_11_val) {
  __ZN2js18RuntimeAllocPolicyC2EP9JSContext($this, $cx_0_11_val);
  return;
}

function __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEEC1EP9JSContext($this, $cx_0_11_val) {
  __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEEC2EP9JSContext($this, $cx_0_11_val);
  return;
}

function __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC1ES7_($this, $a_01) {
  __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES7_($this, $a_01);
  return;
}

function __ZN2js10AutoLockGCC1EP9JSRuntime($this, $rt) {
  __ZN2js10AutoLockGCC2EP9JSRuntime($this, $rt);
  return;
}

function __ZN2js8DebuggerD2Ev($this) {
  var $1 = $this | 0;
  var $2 = HEAP32[$1 >> 2];
  var $3 = $this + 4 | 0;
  var $5 = HEAP32[$3 >> 2] | 0;
  HEAP32[$5 >> 2] = $2;
  var $6 = HEAP32[$3 >> 2];
  var $8 = HEAP32[$1 >> 2] + 4 | 0;
  HEAP32[$8 >> 2] = $6;
  var $9 = $this + 152 | 0;
  __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED1Ev($9);
  var $10 = $this + 116 | 0;
  __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEED1Ev($10);
  var $11 = $this + 80 | 0;
  __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEED1Ev($11);
  var $12 = $this + 52 | 0;
  __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED1Ev($12);
  var $13 = $this + 12 | 0;
  __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev($13);
  return;
}

function __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEED1Ev($this) {
  __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEED2Ev($this);
  return;
}

function __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js8Debugger4initEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 52 | 0;
    var $2 = __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $4 = $this + 88 | 0;
    var $5 = __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj($4);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $7 = $this + 12 | 0;
    var $8 = __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE4initEj($7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $10 = $this + 124 | 0;
    var $11 = __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj($10);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $13 = $this + 152 | 0;
    var $14 = __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj($13);
    if ($14) {
      var $16 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $16 = 0;
    __label__ = 7;
    break;
   case 7:
    var $16;
    return $16;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4initEj($1);
  return $2;
}

function __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4initEj($1);
  return $2;
}

function __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj($1);
  return $2;
}

function __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4initEj($1);
  return $2;
}

function __ZNK2js14BreakpointSite15getScriptObjectEv($this_0_3_val) {
  return $this_0_3_val;
}

function __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5beginEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js8Debugger10toJSObjectEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK8JSObject8getClassEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK8JSObject10getPrivateEv($this_0_6_val) {
  return $this_0_6_val;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($this_0_0_val, $this_0_1_val) {
  return ($this_0_0_val | 0) == ($this_0_1_val | 0);
}

function __ZNK2js10StackFrame13isScriptFrameEv($this_0_0_val) {
  return ($this_0_0_val & 3 | 0) != 0;
}

function __ZNK2js10StackFrame11isEvalFrameEv($this_0_0_val) {
  return ($this_0_0_val & 8 | 0) != 0;
}

function __ZN9JSContext18isExceptionPendingEv($this_0_4_val) {
  return ($this_0_4_val | 0) != 0;
}

function __ZN8JSObject10setPrivateEPv($this, $data) {
  HEAP32[$this + 24 >> 2] = $data;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($this_0_0_val, $this_0_1_val) {
  return $this_0_0_val + ($this_0_1_val << 2) | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN2js8Debugger17fromChildJSObjectEP8JSObject($obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZNK8JSObject15getReservedSlotEj($1, $obj, 0);
  var $_idx1 = $1 | 0;
  var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
  var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
  var $2 = __ZNK2JS5Value8toObjectEv($_idx1_val$0, $_idx1_val$1);
  var $_idx_val = HEAP32[$2 + 24 >> 2];
  var $3 = __ZN2js8Debugger12fromJSObjectEP8JSObject($_idx_val);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZNK8JSObject15getReservedSlotEj($agg_result, $this, $index) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 28 >> 2];
    var $1 = __ZNK8JSObject8numSlotsEv($this_idx_val);
    if ($1 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject7getSlotEj($this, $index);
    var $5 = $4 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $agg_result | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv($agg_result);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value8toObjectEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_TO_OBJECT_IMPL($this_0_0_0_val$0, $this_0_0_0_val$1);
  return $1;
}

function __ZN2js8Debugger12fromJSObjectEP8JSObject($obj_0_6_val) {
  var $1 = __ZNK8JSObject10getPrivateEv($obj_0_6_val);
  return $1;
}

function __ZN2js8Debugger14getScriptFrameEP9JSContextPNS_10StackFrameEPN2JS5ValueE($this, $cx, $fp, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $3 = __stackBase__ + 20;
    var $frameobj = __stackBase__ + 28;
    var $4 = __stackBase__ + 32;
    HEAP32[$1 >> 2] = $fp;
    var $5 = $this + 52 | 0;
    __ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_($p, $5, $1);
    var $_idx2 = $p | 0;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $_idx2_val_idx_val = HEAP32[$_idx2_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($2, $_idx2_val_idx_val);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_idx3_val = $_idx2_val;
      __label__ = 7;
      break;
    }
   case 2:
    var $10 = $this + 8 | 0;
    var $11 = HEAP32[$10 >> 2];
    __ZNK8JSObject15getReservedSlotEj($3, $11, 0);
    var $_idx = $3 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $12 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $13 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, _DebuggerFrame_class, $12, 0);
    HEAP32[$frameobj >> 2] = $13;
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($13, $cx);
    if ($16) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $19 = HEAP32[$1 >> 2];
    __ZN8JSObject10setPrivateEPv($13, $19);
    var $20 = HEAP32[$10 >> 2];
    __ZN2JSL11ObjectValueER8JSObject($4, $20);
    var $_idx1 = $4 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($13, 0, $_idx1_val$0, $_idx1_val$1);
    var $21 = __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($5, $p, $1, $frameobj);
    if ($21) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $_idx3_val = HEAP32[$_idx2 >> 2];
    __label__ = 7;
    break;
   case 6:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 7:
    var $_idx3_val;
    var $24 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($_idx3_val);
    var $26 = HEAP32[$24 + 4 >> 2];
    __ZN2JS5Value9setObjectER8JSObject($vp, $26);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger14getScriptFrameEP9JSContextPNS_10StackFrameEPN2JS5ValueE["X"] = 1;

function __ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 6,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, $clasp, $proto, $parent) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb1($4);
  var $6 = __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE($cx, $clasp, $proto, $parent, $5);
  return $6;
}

function __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK8JSObject11nativeEmptyEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $5 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN8JSObject38ensureClassReservedSlotsForEmptyObjectEP9JSContext($this, $cx);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($this, $index, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, $index, $v_0_0_0_val$0, $v_0_0_0_val$1);
  return;
}

function __ZN2JSL11ObjectValueER8JSObject($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $7 = HEAP32[$v >> 2];
    var $8 = $5 + 4 | 0;
    HEAP32[$8 >> 2] = $7;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js8Debugger7getHookENS0_4HookE($this_0_1_val, $hook) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $hook + 3 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $this_0_1_val, $2);
    var $_idx1 = $1 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $3 = __ZNK2JS5Value11isUndefinedEv($_idx1_val$0, $_idx1_val$1);
    if ($3) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2JS5Value8toObjectEv($_idx1_val$0, $_idx1_val$1);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    STACKTOP = __stackBase__;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value11isUndefinedEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_IS_UNDEFINED_IMPL($this_0_0_0_val$0, $this_0_0_0_val$1);
  return ($1 | 0) != 0;
}

function __ZNK2js8Debugger15hasAnyLiveHooksEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = __stackBase__ + 8;
    if ((HEAP8[$this + 40 | 0] & 1) << 24 >> 24 == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx5 = $this + 8 | 0;
    var $this_idx5_val = HEAP32[$this_idx5 >> 2];
    var $7 = __ZNK2js8Debugger7getHookENS0_4HookE($this_idx5_val, 0);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 15;
      break;
    }
   case 3:
    var $this_idx4_val = HEAP32[$this_idx5 >> 2];
    var $10 = __ZNK2js8Debugger7getHookENS0_4HookE($this_idx4_val, 1);
    if (($10 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 15;
      break;
    }
   case 4:
    var $this_idx3_val = HEAP32[$this_idx5 >> 2];
    var $13 = __ZNK2js8Debugger7getHookENS0_4HookE($this_idx3_val, 2);
    if (($13 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 15;
      break;
    }
   case 5:
    var $this_idx_val = HEAP32[$this_idx5 >> 2];
    var $16 = __ZNK2js8Debugger7getHookENS0_4HookE($this_idx_val, 3);
    if (($16 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 15;
      break;
    }
   case 6:
    var $19 = __ZNK2js8Debugger15firstBreakpointEv($this);
    var $cx_idx = $cx + 52 | 0;
    var $bp_0 = $19;
    __label__ = 7;
    break;
   case 7:
    var $bp_0;
    if (($bp_0 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx6_val = HEAP32[HEAP32[$bp_0 + 4 >> 2] + 12 >> 2];
    var $25 = __ZNK2js14BreakpointSite15getScriptObjectEv($_idx6_val);
    if (($25 | 0) == 0) {
      var $_0 = 1;
      __label__ = 15;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $28 = $25;
    var $cx_idx_val_idx_val = HEAP32[HEAP32[$cx_idx >> 2] + 144080 >> 2];
    var $29 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx_idx_val_idx_val, $28);
    if ($29) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 15;
      break;
    }
   case 10:
    var $bp_0_idx_val = HEAP32[$bp_0 >> 2];
    var $bp_0_idx7_val = HEAP32[$bp_0 + 12 >> 2];
    var $31 = __ZN2js10Breakpoint14nextInDebuggerEv($bp_0_idx_val, $bp_0_idx7_val);
    var $bp_0 = $31;
    __label__ = 7;
    break;
   case 11:
    var $33 = $this + 52 | 0;
    __ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($r, $33);
    var $r_idx = $r | 0;
    var $r_idx1 = $r + 4 | 0;
    var $_idx = $1 | 0;
    __label__ = 12;
    break;
   case 12:
    var $r_idx_val = HEAP32[$r_idx >> 2];
    var $r_idx1_val = HEAP32[$r_idx1 >> 2];
    var $35 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($r_idx_val, $r_idx1_val);
    if ($35) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $37 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($r_idx_val);
    var $39 = HEAP32[$37 + 4 >> 2];
    __ZNK8JSObject15getReservedSlotEj($1, $39, 2);
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $40 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($40) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 1;
      __label__ = 15;
      break;
    }
   case 14:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($r);
    __label__ = 12;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js8Debugger15hasAnyLiveHooksEP9JSContext["X"] = 1;

function __ZNK2js8Debugger15firstBreakpointEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 44 | 0;
    var $3 = HEAP32[$1 >> 2];
    if (($3 | 0) == ($1 | 0)) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN2js10Breakpoint17fromDebuggerLinksEP10JSCListStr($3);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($agg_result, $this) {
  var $_idx_val = HEAP32[$this + 8 >> 2];
  var $_idx1_val = HEAP32[$this + 24 >> 2];
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3allEv($agg_result, $_idx_val, $_idx1_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$5 >> 2];
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isLiveEv($_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger20slowPathOnEnterFrameEP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 104;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $triggered = __stackBase__;
    var $global = __stackBase__ + 92;
    var $1 = __stackBase__ + 96;
    __ZN2js15AutoValueVectorC1EP9JSContext($triggered, $cx);
    var $2 = __ZNK9JSContext2fpEv($cx);
    var $3 = __ZNK2js10StackFrame10scopeChainEv($2);
    var $4 = $3;
    var $5 = __ZNK8JSObject9getGlobalEv($4);
    HEAP32[$global >> 2] = $5;
    var $7 = $5;
    var $8 = __ZN2js12GlobalObject12getDebuggersEv($7);
    if (($8 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_pre_phi = $triggered | 0;
    __label__ = 8;
    break;
   case 3:
    var $_idx1 = $8 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $11 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5beginEv($_idx1_val);
    var $12 = $triggered | 0;
    var $_idx3 = $8 + 4 | 0;
    var $_idx5 = $1 | 0;
    var $p_0 = $11;
    var $_idx2_val = $_idx1_val;
    __label__ = 4;
    break;
   case 4:
    var $_idx2_val;
    var $p_0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $14 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($_idx2_val, $_idx3_val);
    if (($p_0 | 0) == ($14 | 0)) {
      var $_pre_phi = $12;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = HEAP32[$p_0 >> 2];
    var $18 = __ZNK2js8Debugger18observesEnterFrameEv($17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $_idx4_val = HEAP32[$17 + 8 >> 2];
    var $20 = __ZNK2js8Debugger10toJSObjectEv($_idx4_val);
    __ZN2JSL11ObjectValueER8JSObject($1, $20);
    var $_idx5_val$0 = HEAP32[$_idx5 >> 2];
    var $_idx5_val$1 = HEAP32[$_idx5 + 4 >> 2];
    var $21 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($12, $_idx5_val$0, $_idx5_val$1);
    if ($21) {
      __label__ = 7;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 7:
    var $p_0 = $p_0 + 4 | 0;
    var $_idx2_val = HEAP32[$_idx1 >> 2];
    __label__ = 4;
    break;
   case 8:
    var $_pre_phi;
    var $24 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($_pre_phi);
    var $25 = __ZN2js16AutoVectorRooterIN2JS5ValueEE3endEv($_pre_phi);
    if (($24 | 0) == ($25 | 0)) {
      __label__ = 13;
      break;
    } else {
      var $p1_03 = $24;
      __label__ = 9;
      break;
    }
   case 9:
    var $p1_03;
    var $p1_03_idx = $p1_03 | 0;
    var $p1_03_idx_val$0 = HEAP32[$p1_03_idx >> 2];
    var $p1_03_idx_val$1 = HEAP32[$p1_03_idx + 4 >> 2];
    var $27 = __ZNK2JS5Value8toObjectEv($p1_03_idx_val$0, $p1_03_idx_val$1);
    var $_idx_val = HEAP32[$27 + 24 >> 2];
    var $28 = __ZN2js8Debugger12fromJSObjectEP8JSObject($_idx_val);
    var $29 = $28 + 12 | 0;
    var $30 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3hasERKS2_($29, $global);
    if ($30) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $32 = __ZNK2js8Debugger18observesEnterFrameEv($28);
    if ($32) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    __ZN2js8Debugger14fireEnterFrameEP9JSContext($28, $cx);
    __label__ = 12;
    break;
   case 12:
    var $35 = $p1_03 + 8 | 0;
    var $36 = __ZN2js16AutoVectorRooterIN2JS5ValueEE3endEv($_pre_phi);
    if (($35 | 0) == ($36 | 0)) {
      __label__ = 13;
      break;
    } else {
      var $p1_03 = $35;
      __label__ = 9;
      break;
    }
   case 13:
    __ZN2js15AutoValueVectorD1Ev($triggered);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger20slowPathOnEnterFrameEP9JSContext["X"] = 1;

function __ZN2js15AutoValueVectorC1EP9JSContext($this, $cx) {
  __ZN2js15AutoValueVectorC2EP9JSContext($this, $cx);
  return;
}

function __ZNK9JSContext2fpEv($this) {
  var $_idx_val_idx_val_idx_val = HEAP32[HEAP32[HEAP32[$this + 60 >> 2] + 8 >> 2] + 12 >> 2];
  var $1 = __ZNK2js12ContextStack2fpEv($_idx_val_idx_val_idx_val);
  return $1;
}

function __ZNK2js10StackFrame10scopeChainEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 & 524288 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = HEAP32[$this + 12 >> 2];
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZNK2js10StackFrame6calleeEv($this);
    var $_idx_val = HEAP32[$6 + 20 >> 2];
    var $7 = __ZNK8JSObject9getParentEv($_idx_val);
    HEAP32[$this + 12 >> 2] = $7;
    var $9 = $2 | 524288;
    HEAP32[$1 >> 2] = $9;
    var $11 = $7;
    __label__ = 4;
    break;
   case 4:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js8Debugger18observesEnterFrameEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 40 | 0] & 1) << 24 >> 24 == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 8 >> 2];
    var $6 = __ZNK2js8Debugger7getHookENS0_4HookE($this_idx_val, 3);
    var $9 = ($6 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($this, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  var $1 = $this + 12 | 0;
  var $2 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE6appendIS2_EEbT_($1, $v_0_0_0_val$0, $v_0_0_0_val$1);
  return $2;
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($this) {
  var $_idx_val = HEAP32[$this + 16 >> 2];
  var $1 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE5beginEv($_idx_val);
  return $1;
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEE3endEv($this) {
  var $_idx_val = HEAP32[$this + 16 >> 2];
  var $_idx1_val = HEAP32[$this + 20 >> 2];
  var $1 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE3endEv($_idx_val, $_idx1_val);
  return $1;
}

function __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3hasERKS2_($this, $l) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = $this | 0;
  __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_($1, $3, $l);
  var $_idx_val_idx_val = HEAP32[HEAP32[$1 >> 2] >> 2];
  __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($2, $_idx_val_idx_val);
  var $6 = (HEAP32[$2 >> 2] | 0) != 0;
  STACKTOP = __stackBase__;
  return $6;
}

function __ZN2js8Debugger14fireEnterFrameEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 84;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ac = __stackBase__;
    var $argv = __stackBase__ + 52;
    var $rv = __stackBase__ + 60;
    var $1 = __stackBase__ + 68;
    var $2 = __stackBase__ + 76;
    var $this_idx = $this + 8 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $3 = __ZNK2js8Debugger7getHookENS0_4HookE($this_idx_val, 3);
    var $4 = __ZNK9JSContext2fpEv($cx);
    var $5 = HEAP32[$this_idx >> 2];
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $5);
    var $6 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $8 = $argv | 0;
    var $9 = __ZN2js8Debugger14getScriptFrameEP9JSContextPNS_10StackFrameEPN2JS5ValueE($this, $cx, $4, $8);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb($this, $ac, 0, 0);
    __label__ = 6;
    break;
   case 4:
    var $13 = HEAP32[$this_idx >> 2];
    __ZN2JSL11ObjectValueER8JSObject($1, $13);
    __ZN2JSL11ObjectValueER8JSObject($2, $3);
    var $14 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $1, $2, 1, $8, $rv);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = __ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb($this, $ac, 0, 1);
    __label__ = 6;
    break;
   case 6:
    __ZN2js15AutoCompartmentD2Ev($ac);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15AutoValueVectorD1Ev($this) {
  __ZN2js15AutoValueVectorD2Ev($this);
  return;
}

function __ZN2js8Debugger20slowPathOnLeaveFrameEP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fp = __stackBase__;
    var $p1 = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __ZNK9JSContext2fpEv($cx);
    HEAP32[$fp >> 2] = $3;
    var $4 = __ZNK2js10StackFrame10scopeChainEv($3);
    var $5 = $4;
    var $6 = __ZNK8JSObject9getGlobalEv($5);
    var $7 = $6;
    var $8 = __ZN2js12GlobalObject12getDebuggersEv($7);
    if (($8 | 0) == 0) {
      var $39 = $3;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx3 = $8 | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $11 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5beginEv($_idx3_val);
    var $_idx7 = $8 + 4 | 0;
    var $_idx7_val = HEAP32[$_idx7 >> 2];
    var $12 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($_idx3_val, $_idx7_val);
    if (($11 | 0) == ($12 | 0)) {
      var $39 = $3;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = $1 | 0;
    var $15 = $p1 | 0;
    var $16 = $cx;
    var $_idx2 = $2 | 0;
    var $p_01 = $11;
    __label__ = 4;
    break;
   case 4:
    var $p_01;
    var $19 = HEAP32[$p_01 >> 2] + 52 | 0;
    __ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_($p1, $19, $fp);
    var $p1_idx_val = HEAP32[$15 >> 2];
    var $p1_idx_val_idx_val = HEAP32[$p1_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($1, $p1_idx_val_idx_val);
    if ((HEAP32[$14 >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($p1_idx_val);
    var $25 = HEAP32[$23 >> 2];
    var $27 = HEAP32[$23 + 4 >> 2];
    __ZN8JSObject10setPrivateEPv($27, 0);
    __ZNK8JSObject15getReservedSlotEj($2, $27, 2);
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    var $28 = __ZNK2JS5Value11isUndefinedEv($_idx2_val$0, $_idx2_val$1);
    if ($28) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx1_val = HEAP32[$25 >> 2];
    var $30 = __ZNK2js10StackFrame13isScriptFrameEv($_idx1_val);
    if ($30) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $32 = __ZNK2js10StackFrame6scriptEv($25);
    var $33 = $32;
    __ZN8JSScript19changeStepModeCountEP9JSContexti($33, $16, -1);
    __label__ = 8;
    break;
   case 8:
    __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE($19, $p1_idx_val);
    __label__ = 9;
    break;
   case 9:
    var $36 = $p_01 + 4 | 0;
    var $_idx4_val = HEAP32[$_idx3 >> 2];
    var $_idx5_val = HEAP32[$_idx7 >> 2];
    var $37 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($_idx4_val, $_idx5_val);
    if (($36 | 0) == ($37 | 0)) {
      __label__ = 10;
      break;
    } else {
      var $p_01 = $36;
      __label__ = 4;
      break;
    }
   case 10:
    var $39 = HEAP32[$fp >> 2];
    __label__ = 11;
    break;
   case 11:
    var $39;
    var $_idx_val = HEAP32[$39 >> 2];
    var $40 = __ZNK2js10StackFrame11isEvalFrameEv($_idx_val);
    if ($40) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $42 = __ZNK2js10StackFrame6scriptEv($39);
    var $43 = $42;
    var $44 = __ZNK2js2gc4Cell11compartmentEv($43);
    __ZN13JSCompartment18clearBreakpointsInEP9JSContextPN2js8DebuggerEP8JSScriptP8JSObject($44, 0, $42, 0);
    __label__ = 13;
    break;
   case 13:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger20slowPathOnLeaveFrameEP9JSContext["X"] = 1;

function __ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js10StackFrame6scriptEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK2js10StackFrame15isFunctionFrameEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = __ZNK2js10StackFrame11isEvalFrameEv($this_idx_val);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $15 = HEAP32[$this + 8 >> 2];
    __label__ = 6;
    break;
   case 4:
    var $9 = __ZNK2js10StackFrame3funEv($this);
    var $10 = __ZNK10JSFunction6scriptEv($9);
    var $15 = $10;
    __label__ = 6;
    break;
   case 5:
    var $15 = HEAP32[$this + 4 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $15;
    return $15;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE($this, $p_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE($1, $p_0);
  return;
}

function __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($this, $cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $p = __stackBase__ + 4;
    var $1 = __stackBase__ + 12;
    var $2 = __stackBase__ + 20;
    var $dobj = __stackBase__ + 28;
    var $3 = __stackBase__ + 32;
    var $4 = $this + 8 | 0;
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $5 = __ZNK2JS5Value8isObjectEv($vp_idx_val$0, $vp_idx_val$1);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    var $7 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
    HEAP32[$obj >> 2] = $7;
    var $8 = $this + 88 | 0;
    __ZNK2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_($p, $8, $obj);
    var $_idx2_val = HEAP32[$p >> 2];
    var $_idx2_val_idx_val = HEAP32[$_idx2_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($1, $_idx2_val_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($_idx2_val);
    var $15 = HEAP32[$13 + 4 >> 2];
    __ZN2JS5Value9setObjectER8JSObject($vp, $15);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 4:
    var $17 = HEAP32[$4 >> 2];
    __ZNK8JSObject15getReservedSlotEj($2, $17, 1);
    var $_idx = $2 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $18 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $19 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, _DebuggerObject_class, $18, 0);
    HEAP32[$dobj >> 2] = $19;
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $22 = __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($19, $cx);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 6:
    var $25 = HEAP32[$obj >> 2];
    __ZN8JSObject10setPrivateEPv($19, $25);
    var $26 = HEAP32[$4 >> 2];
    __ZN2JSL11ObjectValueER8JSObject($3, $26);
    var $_idx3 = $3 | 0;
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($19, 0, $_idx3_val$0, $_idx3_val$1);
    var $27 = __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13relookupOrAddERNS_6detail9HashTableINS_12HashMapEntryIS2_S2_EENS6_13MapHashPolicyES5_E6AddPtrERKS2_SG_($8, $p, $obj, $dobj);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 8:
    var $30 = HEAP32[$dobj >> 2];
    __ZN2JS5Value9setObjectER8JSObject($vp, $30);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 9:
    var $33 = HEAP32[$cx + 56 >> 2];
    var $34 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($33, $cx, $vp);
    if ($34) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE["X"] = 1;

function __ZNK2JS5Value8isObjectEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_IS_OBJECT_IMPL($this_0_0_0_val$0, $this_0_0_0_val$1);
  return ($1 | 0) != 0;
}

function __ZNK2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 8,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13relookupOrAddERNS_6detail9HashTableINS_12HashMapEntryIS2_S2_EENS6_13MapHashPolicyES5_E6AddPtrERKS2_SG_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $k_val = HEAP32[$k >> 2];
  __ZN2js12HashMapEntryIP8JSObjectS2_EC1ERKS2_S5_($1, $k_val, $v);
  var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E13relookupOrAddERNSC_6AddPtrERKS4_RKS5_($2, $p, $k, $1);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN2js8Debugger19unwrapDebuggeeValueEP9JSContextPN2JS5ValueE($this, $cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $owner = __stackBase__;
    var $1 = $this + 8 | 0;
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $2 = __ZNK2JS5Value8isObjectEv($vp_idx_val$0, $vp_idx_val$1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
    var $_idx2_val = HEAP32[$4 + 4 >> 2];
    var $5 = __ZNK8JSObject8getClassEv($_idx2_val);
    if (($5 | 0) == (_DebuggerObject_class | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAP32[$5 >> 2];
    _JS_ReportErrorNumber($cx, 4, 255, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str2 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str3 | 0, HEAP32[tempInt + 8 >> 2] = $9, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 4:
    __ZNK8JSObject15getReservedSlotEj($owner, $4, 0);
    var $owner_idx3 = $owner | 0;
    var $owner_idx3_val$0 = HEAP32[$owner_idx3 >> 2];
    var $owner_idx3_val$1 = HEAP32[$owner_idx3 + 4 >> 2];
    var $11 = __ZNK2JS5Value14toObjectOrNullEv($owner_idx3_val$0, $owner_idx3_val$1);
    if (($11 | 0) == (HEAP32[$1 >> 2] | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = __ZNK2JS5Value6isNullEv($owner_idx3_val$0, $owner_idx3_val$1);
    var $16 = $15 ? 279 : 278;
    _JS_ReportErrorNumber($cx, 4, $16, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $_idx_val = HEAP32[$4 + 24 >> 2];
    var $18 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $19 = $18;
    __ZN2JS5Value9setObjectER8JSObject($vp, $19);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value14toObjectOrNullEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_TO_OBJECT_IMPL($this_0_0_0_val$0, $this_0_0_0_val$1);
  return $1;
}

function __ZNK2JS5Value6isNullEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_IS_NULL_IMPL($this_0_0_0_val$0, $this_0_0_0_val$1);
  return ($1 | 0) != 0;
}

function __ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb($this, $ac, $vp, $callHook) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fval = __stackBase__;
    var $exc = __stackBase__ + 8;
    var $rv = __stackBase__ + 16;
    var $1 = __stackBase__ + 24;
    var $3 = HEAP32[$ac >> 2];
    var $_idx1 = $3 + 20 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $4 = __ZN9JSContext18isExceptionPendingEv($_idx1_val);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 2:
    if ($callHook) {
      __label__ = 3;
      break;
    } else {
      var $_idx_val = $_idx1_val;
      __label__ = 8;
      break;
    }
   case 3:
    var $8 = HEAP32[$this + 36 >> 2];
    if (($8 | 0) == 0) {
      var $_idx_val = $_idx1_val;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JSL11ObjectValueER8JSObject($fval, $8);
    var $_idx2 = $3 + 24 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN9JSContext19getPendingExceptionEv($exc, $_idx2_val$0, $_idx2_val$1);
    __ZN9JSContext21clearPendingExceptionEv($3);
    var $12 = HEAP32[$this + 8 >> 2];
    __ZN2JSL11ObjectValueER8JSObject($1, $12);
    var $13 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($3, $1, $fval, 1, $exc, $rv);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx_val = HEAP32[$_idx1 >> 2];
    __label__ = 8;
    break;
   case 6:
    if (($vp | 0) == 0) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $17 = __ZN2js8Debugger20parseResumptionValueERNS_15AutoCompartmentEbRKN2JS5ValueEPS4_b($this, $ac, 1, $rv, $vp, 0);
    var $_0 = $17;
    __label__ = 11;
    break;
   case 8:
    var $_idx_val;
    var $19 = __ZN9JSContext18isExceptionPendingEv($_idx_val);
    if ($19) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $21 = _JS_ReportPendingException($3);
    __ZN9JSContext21clearPendingExceptionEv($3);
    __label__ = 10;
    break;
   case 10:
    __ZN2js15AutoCompartment5leaveEv($ac);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject12lastPropertyEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js5Shape8previousEv($this_0_10_val) {
  return $this_0_10_val;
}

function __ZNK8JSObject8isObjectEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js11ObjectClassE | 0);
}

function __ZNK2js5Shape16isDataDescriptorEv($this_0_7_val) {
  return ($this_0_7_val & 48) << 24 >> 24 == 0;
}

function __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($this_0_0_val, $this_0_1_val) {
  return ($this_0_0_val | 0) == ($this_0_1_val | 0);
}

function __ZN9JSContext19getPendingExceptionEv($agg_result, $this_0_5_0_0_val$0, $this_0_5_0_0_val$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $this_0_5_0_0_val$0;
  HEAP32[$1 + 4 >> 2] = $this_0_5_0_0_val$1;
  return;
}

function __ZN9JSContext19setPendingExceptionEN2JS5ValueE($this, $_0_0_0_val$0, $_0_0_0_val$1) {
  HEAP32[$this + 20 >> 2] = 1;
  var $_04 = $this + 24 | 0;
  HEAP32[$_04 >> 2] = $_0_0_0_val$0;
  HEAP32[$_04 + 4 >> 2] = $_0_0_0_val$1;
  return;
}

function __ZN13JSCompartment12getDebuggeesEv($this) {
  return $this + 1932 | 0;
}

function __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN9JSContext21clearPendingExceptionEv($this) {
  HEAP32[$this + 20 >> 2] = 0;
  var $2 = $this + 24 | 0;
  __ZN2JS5Value12setUndefinedEv($2);
  return;
}

function __ZN2js8Debugger20parseResumptionValueERNS_15AutoCompartmentEbRKN2JS5ValueEPS4_b($this, $ac, $ok, $rv, $vp, $callHook) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($ok) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $2 = __ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb($this, $ac, $vp, $callHook);
    var $_0 = $2;
    __label__ = 21;
    break;
   case 3:
    var $rv_idx2 = $rv | 0;
    var $rv_idx2_val$0 = HEAPU32[$rv_idx2 >> 2];
    var $rv_idx2_val$1 = HEAPU32[$rv_idx2 + 4 >> 2];
    var $4 = __ZNK2JS5Value11isUndefinedEv($rv_idx2_val$0, $rv_idx2_val$1);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js15AutoCompartment5leaveEv($ac);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 5:
    var $7 = __ZNK2JS5Value6isNullEv($rv_idx2_val$0, $rv_idx2_val$1);
    if ($7) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js15AutoCompartment5leaveEv($ac);
    var $_0 = 0;
    __label__ = 21;
    break;
   case 7:
    var $11 = HEAPU32[$ac >> 2];
    var $13 = HEAP32[$11 + 52 >> 2];
    var $16 = HEAP32[$13 + 210488 >> 2] | 0;
    var $17 = __ZL12ATOM_TO_JSIDP6JSAtom($16);
    var $20 = HEAP32[$13 + 210492 >> 2] | 0;
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom($20);
    var $22 = __ZNK2JS5Value8isObjectEv($rv_idx2_val$0, $rv_idx2_val$1);
    var $23 = $22 & 1;
    if ($22) {
      __label__ = 8;
      break;
    } else {
      var $okResumption_0 = $23;
      var $obj_0 = undef;
      __label__ = 9;
      break;
    }
   case 8:
    var $25 = __ZNK2JS5Value8toObjectEv($rv_idx2_val$0, $rv_idx2_val$1);
    var $_idx6_val = HEAP32[$25 + 4 >> 2];
    var $26 = __ZNK8JSObject8isObjectEv($_idx6_val);
    var $okResumption_0 = $26 & 1;
    var $obj_0 = $25;
    __label__ = 9;
    break;
   case 9:
    var $obj_0;
    var $okResumption_0;
    if ($okResumption_0 << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $obj_0_idx_val = HEAP32[$obj_0 >> 2];
    var $31 = __ZNK8JSObject12lastPropertyEv($obj_0_idx_val);
    var $_idx3_val = HEAP32[$31 + 32 >> 2];
    var $32 = __ZNK2js5Shape8previousEv($_idx3_val);
    if (($32 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_idx_val = HEAP32[$32 + 32 >> 2];
    var $35 = __ZNK2js5Shape8previousEv($_idx_val);
    if (($35 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $38 = $31 + 12 | 0;
    var $39 = HEAP32[$38 >> 2];
    if (($39 | 0) == ($17 | 0) | ($39 | 0) == ($21 | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $_idx5_val = HEAP8[$31 + 28 | 0];
    var $43 = __ZNK2js5Shape16isDataDescriptorEv($_idx5_val);
    if ($43) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    _JS_ReportErrorNumber($11, 4, 275, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $44 = __ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb($this, $ac, $vp, $callHook);
    var $_0 = $44;
    __label__ = 21;
    break;
   case 15:
    var $46 = $11;
    var $47 = $obj_0;
    var $48 = $31;
    var $49 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($46, $47, $47, $48, 0, $vp);
    if (($49 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $52 = __ZN2js8Debugger19unwrapDebuggeeValueEP9JSContextPN2JS5ValueE($this, $11, $vp);
    if ($52) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $54 = __ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb($this, $ac, $vp, $callHook);
    var $_0 = $54;
    __label__ = 21;
    break;
   case 18:
    __ZN2js15AutoCompartment5leaveEv($ac);
    var $57 = HEAP32[$11 + 56 >> 2];
    var $58 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($57, $11, $vp);
    if ($58) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 0;
    __label__ = 21;
    break;
   case 20:
    var $63 = (HEAP32[$38 >> 2] | 0) == ($17 | 0) ? 2 : 3;
    var $_0 = $63;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger20parseResumptionValueERNS_15AutoCompartmentEbRKN2JS5ValueEPS4_b["X"] = 1;

function __ZN2js8Debugger18newCompletionValueERNS_15AutoCompartmentEbN2JS5ValueEPS4_($this, $ac, $ok, $_0_0_0_val$0, $_0_0_0_val$1, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $val = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = $val | 0;
    HEAP32[$2 >> 2] = $_0_0_0_val$0;
    HEAP32[$2 + 4 >> 2] = $_0_0_0_val$1;
    var $4 = HEAP32[$ac >> 2];
    if ($ok) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js15AutoCompartment5leaveEv($ac);
    var $10 = HEAP32[HEAP32[$4 + 52 >> 2] + 210488 >> 2] | 0;
    var $11 = __ZL12ATOM_TO_JSIDP6JSAtom($10);
    var $key_0 = $11;
    __label__ = 6;
    break;
   case 3:
    var $_idx_val = HEAP32[$4 + 20 >> 2];
    var $13 = __ZN9JSContext18isExceptionPendingEv($_idx_val);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $19 = HEAP32[HEAP32[$4 + 52 >> 2] + 210492 >> 2] | 0;
    var $20 = __ZL12ATOM_TO_JSIDP6JSAtom($19);
    var $_idx1 = $4 + 24 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN9JSContext19getPendingExceptionEv($1, $_idx1_val$0, $_idx1_val$1);
    var $21 = $1 | 0;
    var $22$0 = HEAP32[$21 >> 2];
    var $22$1 = HEAP32[$21 + 4 >> 2];
    HEAP32[$2 >> 2] = $22$0;
    HEAP32[$2 + 4 >> 2] = $22$1;
    __ZN9JSContext21clearPendingExceptionEv($4);
    __ZN2js15AutoCompartment5leaveEv($ac);
    var $key_0 = $20;
    __label__ = 6;
    break;
   case 5:
    __ZN2js15AutoCompartment5leaveEv($ac);
    __ZN2JS5Value7setNullEv($vp);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 6:
    var $key_0;
    var $25 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE($4);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $28 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($this, $4, $val);
    if ($28) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $30 = $4;
    var $31 = $25;
    var $32 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($30, $31, $key_0, $val, 10, 12, 1, 0, 0, 0);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2JS5Value9setObjectER8JSObject($vp, $25);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger18newCompletionValueERNS_15AutoCompartmentEbN2JS5ValueEPS4_["X"] = 1;

function __ZL12ATOM_TO_JSIDP6JSAtom($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj($1);
  return $2;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE($cx) {
  var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb1($3);
  var $5 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE($cx, $4);
  return $5;
}

function __Z19CallMethodIfPresentP9JSContextP8JSObjectPKciPN2JS5ValueES7_($cx, $obj, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fval = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZN2JS5Value12setUndefinedEv($rval);
    var $2 = _strlen(STRING_TABLE.__str4 | 0);
    var $3 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, STRING_TABLE.__str4 | 0, $2, 0);
    if (($3 | 0) == 0) {
      var $16 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZL12ATOM_TO_JSIDP6JSAtom($3);
    var $7 = $cx;
    var $8 = $obj;
    var $9 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($7, $8, $6, 2, $fval);
    if (($9 | 0) == 0) {
      var $16 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $fval_idx = $fval | 0;
    var $fval_idx_val$0 = HEAP32[$fval_idx >> 2];
    var $fval_idx_val$1 = HEAP32[$fval_idx + 4 >> 2];
    var $12 = __ZL13js_IsCallableRKN2JS5ValueE($fval_idx_val$0, $fval_idx_val$1);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $16 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JSL11ObjectValueER8JSObject($1, $obj);
    var $14 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $1, $fval, 1, $argv, $rval);
    var $16 = $14;
    __label__ = 5;
    break;
   case 5:
    var $16;
    STACKTOP = __stackBase__;
    return $16;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13js_IsCallableRKN2JS5ValueE($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZN8JSObject10isCallableEv($_idx_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger21fireDebuggerStatementEP9JSContextPN2JS5ValueE($this, $cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 84;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ac = __stackBase__;
    var $argv = __stackBase__ + 52;
    var $rv = __stackBase__ + 60;
    var $1 = __stackBase__ + 68;
    var $2 = __stackBase__ + 76;
    var $this_idx = $this + 8 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $3 = __ZNK2js8Debugger7getHookENS0_4HookE($this_idx_val, 0);
    var $4 = __ZNK9JSContext2fpEv($cx);
    var $5 = HEAP32[$this_idx >> 2];
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $5);
    var $6 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $8 = $argv | 0;
    var $9 = __ZN2js8Debugger14getScriptFrameEP9JSContextPNS_10StackFrameEPN2JS5ValueE($this, $cx, $4, $8);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb($this, $ac, $vp, 0);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 4:
    var $13 = HEAP32[$this_idx >> 2];
    __ZN2JSL11ObjectValueER8JSObject($1, $13);
    __ZN2JSL11ObjectValueER8JSObject($2, $3);
    var $14 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $1, $2, 1, $8, $rv);
    var $15 = __ZN2js8Debugger20parseResumptionValueERNS_15AutoCompartmentEbRKN2JS5ValueEPS4_b($this, $ac, $14, $rv, $vp, 1);
    var $_0 = $15;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($ac);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger19fireExceptionUnwindEP9JSContextPN2JS5ValueE($this, $cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 100;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $exc = __stackBase__;
    var $ac = __stackBase__ + 8;
    var $argv = __stackBase__ + 60;
    var $rv = __stackBase__ + 76;
    var $1 = __stackBase__ + 84;
    var $2 = __stackBase__ + 92;
    var $this_idx = $this + 8 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $3 = __ZNK2js8Debugger7getHookENS0_4HookE($this_idx_val, 1);
    var $4 = __ZNK9JSContext2fpEv($cx);
    var $cx_idx = $cx + 24 | 0;
    var $cx_idx_val$0 = HEAP32[$cx_idx >> 2];
    var $cx_idx_val$1 = HEAP32[$cx_idx + 4 >> 2];
    __ZN9JSContext19getPendingExceptionEv($exc, $cx_idx_val$0, $cx_idx_val$1);
    __ZN9JSContext21clearPendingExceptionEv($cx);
    var $5 = HEAP32[$this_idx >> 2];
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $5);
    var $6 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $8 = $argv + 8 | 0;
    var $9 = $exc | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $8 | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = $argv | 0;
    var $13 = __ZN2js8Debugger14getScriptFrameEP9JSContextPNS_10StackFrameEPN2JS5ValueE($this, $cx, $4, $12);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $15 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($this, $cx, $8);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = __ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb($this, $ac, $vp, 0);
    var $_0 = $17;
    __label__ = 7;
    break;
   case 5:
    var $19 = HEAP32[$this_idx >> 2];
    __ZN2JSL11ObjectValueER8JSObject($1, $19);
    __ZN2JSL11ObjectValueER8JSObject($2, $3);
    var $20 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $1, $2, 2, $12, $rv);
    var $21 = __ZN2js8Debugger20parseResumptionValueERNS_15AutoCompartmentEbRKN2JS5ValueEPS4_b($this, $ac, $20, $rv, $vp, 1);
    if (($21 | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $21;
      __label__ = 7;
      break;
    }
   case 6:
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($cx, $10$0, $10$1);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($ac);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger19fireExceptionUnwindEP9JSContextPN2JS5ValueE["X"] = 1;

function __ZN2js8Debugger13fireNewScriptEP9JSContextP8JSScriptP8JSObjectNS0_13NewScriptKindE($this, $cx, $script, $obj, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 84;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ac = __stackBase__;
    var $argv = __stackBase__ + 52;
    var $rv = __stackBase__ + 60;
    var $1 = __stackBase__ + 68;
    var $2 = __stackBase__ + 76;
    var $this_idx = $this + 8 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $3 = __ZNK2js8Debugger7getHookENS0_4HookE($this_idx_val, 2);
    var $4 = HEAP32[$this_idx >> 2];
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $4);
    var $5 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    if (($kind | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = __ZN2js8Debugger14wrapHeldScriptEP9JSContextP8JSScriptP8JSObject($this, $cx, $script, $obj);
    var $13 = $9;
    __label__ = 5;
    break;
   case 4:
    var $11 = __ZN2js8Debugger17wrapNonHeldScriptEP9JSContextP8JSScript($this, $cx, $script);
    var $13 = $11;
    __label__ = 5;
    break;
   case 5:
    var $13;
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $16 = __ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb($this, $ac, 0, 0);
    __label__ = 9;
    break;
   case 7:
    var $18 = $argv | 0;
    __ZN2JS5Value9setObjectER8JSObject($18, $13);
    var $19 = HEAP32[$this_idx >> 2];
    __ZN2JSL11ObjectValueER8JSObject($1, $19);
    __ZN2JSL11ObjectValueER8JSObject($2, $3);
    var $20 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $1, $2, 1, $18, $rv);
    if ($20) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = __ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb($this, $ac, 0, 1);
    __label__ = 9;
    break;
   case 9:
    __ZN2js15AutoCompartmentD2Ev($ac);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger14wrapHeldScriptEP9JSContextP8JSScriptP8JSObject($this, $cx, $script, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $scriptobj = __stackBase__ + 20;
    HEAP32[$1 >> 2] = $obj;
    var $3 = $this + 124 | 0;
    __ZNK2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_($p, $3, $1);
    var $_idx = $p | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $_idx_val_idx_val = HEAP32[$_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($2, $_idx_val_idx_val);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_idx1_val = $_idx_val;
      __label__ = 5;
      break;
    }
   case 2:
    var $8 = HEAP32[$1 >> 2];
    var $9 = __ZN2js8Debugger17newDebuggerScriptEP9JSContextP8JSScriptP8JSObject($this, $cx, $script, $8);
    HEAP32[$scriptobj >> 2] = $9;
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13relookupOrAddERNS_6detail9HashTableINS_12HashMapEntryIS2_S2_EENS6_13MapHashPolicyES5_E6AddPtrERKS2_SG_($3, $p, $1, $scriptobj);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $_idx1_val = HEAP32[$_idx >> 2];
    __label__ = 5;
    break;
   case 5:
    var $_idx1_val;
    var $14 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($_idx1_val);
    var $_0 = HEAP32[$14 + 4 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger17wrapNonHeldScriptEP9JSContextP8JSScript($this, $cx, $script) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $scriptobj = __stackBase__ + 20;
    HEAP32[$1 >> 2] = $script;
    var $3 = $this + 152 | 0;
    __ZNK2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_($p, $3, $1);
    var $_idx = $p | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $_idx_val_idx_val = HEAP32[$_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($2, $_idx_val_idx_val);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_idx1_val = $_idx_val;
      __label__ = 5;
      break;
    }
   case 2:
    var $8 = HEAP32[$1 >> 2];
    var $9 = __ZN2js8Debugger17newDebuggerScriptEP9JSContextP8JSScriptP8JSObject($this, $cx, $8, 0);
    HEAP32[$scriptobj >> 2] = $9;
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13relookupOrAddERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($3, $p, $1, $scriptobj);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $_idx1_val = HEAP32[$_idx >> 2];
    __label__ = 5;
    break;
   case 5:
    var $_idx1_val;
    var $14 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($_idx1_val);
    var $_0 = HEAP32[$14 + 4 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger12dispatchHookEP9JSContextPN2JS5ValueENS0_4HookE($cx, $vp, $which) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 104;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $triggered = __stackBase__;
    var $global = __stackBase__ + 92;
    var $1 = __stackBase__ + 96;
    __ZN2js15AutoValueVectorC1EP9JSContext($triggered, $cx);
    var $2 = __ZNK9JSContext2fpEv($cx);
    var $3 = __ZNK2js10StackFrame10scopeChainEv($2);
    var $4 = $3;
    var $5 = __ZNK8JSObject9getGlobalEv($4);
    HEAP32[$global >> 2] = $5;
    var $7 = $5;
    var $8 = __ZN2js12GlobalObject12getDebuggersEv($7);
    if (($8 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_pre_phi = $triggered | 0;
    __label__ = 9;
    break;
   case 3:
    var $_idx1 = $8 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $11 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5beginEv($_idx1_val);
    var $12 = $triggered | 0;
    var $_idx3 = $8 + 4 | 0;
    var $_idx7 = $1 | 0;
    var $p_0 = $11;
    var $_idx2_val = $_idx1_val;
    __label__ = 4;
    break;
   case 4:
    var $_idx2_val;
    var $p_0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $14 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($_idx2_val, $_idx3_val);
    if (($p_0 | 0) == ($14 | 0)) {
      var $_pre_phi = $12;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = HEAP32[$p_0 >> 2];
    if ((HEAP8[$17 + 40 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx6 = $17 + 8 | 0;
    var $_idx6_val = HEAP32[$_idx6 >> 2];
    var $23 = __ZNK2js8Debugger7getHookENS0_4HookE($_idx6_val, $which);
    if (($23 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx4_val = HEAP32[$_idx6 >> 2];
    var $26 = __ZNK2js8Debugger10toJSObjectEv($_idx4_val);
    __ZN2JSL11ObjectValueER8JSObject($1, $26);
    var $_idx7_val$0 = HEAP32[$_idx7 >> 2];
    var $_idx7_val$1 = HEAP32[$_idx7 + 4 >> 2];
    var $27 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($12, $_idx7_val$0, $_idx7_val$1);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 8:
    var $p_0 = $p_0 + 4 | 0;
    var $_idx2_val = HEAP32[$_idx1 >> 2];
    __label__ = 4;
    break;
   case 9:
    var $_pre_phi;
    var $29 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($_pre_phi);
    var $30 = ($which | 0) == 0;
    var $p1_0 = $29;
    __label__ = 10;
    break;
   case 10:
    var $p1_0;
    var $32 = __ZN2js16AutoVectorRooterIN2JS5ValueEE3endEv($_pre_phi);
    if (($p1_0 | 0) == ($32 | 0)) {
      var $_0 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $p1_0_idx = $p1_0 | 0;
    var $p1_0_idx_val$0 = HEAP32[$p1_0_idx >> 2];
    var $p1_0_idx_val$1 = HEAP32[$p1_0_idx + 4 >> 2];
    var $35 = __ZNK2JS5Value8toObjectEv($p1_0_idx_val$0, $p1_0_idx_val$1);
    var $_idx_val = HEAP32[$35 + 24 >> 2];
    var $36 = __ZN2js8Debugger12fromJSObjectEP8JSObject($_idx_val);
    var $37 = $36 + 12 | 0;
    var $38 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3hasERKS2_($37, $global);
    if ($38) {
      __label__ = 12;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 12:
    if ((HEAP8[$36 + 40 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $_idx5_val = HEAP32[$36 + 8 >> 2];
    var $45 = __ZNK2js8Debugger7getHookENS0_4HookE($_idx5_val, $which);
    if (($45 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    if ($30) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $49 = __ZN2js8Debugger21fireDebuggerStatementEP9JSContextPN2JS5ValueE($36, $cx, $vp);
    var $53 = $49;
    __label__ = 17;
    break;
   case 16:
    var $51 = __ZN2js8Debugger19fireExceptionUnwindEP9JSContextPN2JS5ValueE($36, $cx, $vp);
    var $53 = $51;
    __label__ = 17;
    break;
   case 17:
    var $53;
    if (($53 | 0) == 1) {
      __label__ = 18;
      break;
    } else {
      var $_0 = $53;
      __label__ = 19;
      break;
    }
   case 18:
    var $p1_0 = $p1_0 + 8 | 0;
    __label__ = 10;
    break;
   case 19:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($triggered);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger12dispatchHookEP9JSContextPN2JS5ValueENS0_4HookE["X"] = 1;

function __ZN2js8Debugger19slowPathOnNewScriptEP9JSContextP8JSScriptP8JSObjectNS0_13NewScriptKindE($cx, $script, $obj, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 104;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $triggered = __stackBase__;
    var $global = __stackBase__ + 92;
    var $r = __stackBase__ + 96;
    __ZN2js15AutoValueVectorC1EP9JSContext($triggered, $cx);
    if ((HEAP8[$script + 36 | 0] & 16) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $obj;
    var $7 = __ZNK8JSObject9getGlobalEv($6);
    var $8 = $7;
    HEAP32[$global >> 2] = $8;
    var $9 = $7;
    var $10 = __ZN2js12GlobalObject12getDebuggersEv($9);
    if (($10 | 0) == 0) {
      var $27 = $8;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = __ZL22AddNewScriptRecipientsPN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEEEPNS_15AutoValueVectorE($10, $triggered);
    if ($13) {
      var $27 = $8;
      __label__ = 8;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 4:
    HEAP32[$global >> 2] = 0;
    var $15 = $script;
    var $16 = __ZNK2js2gc4Cell11compartmentEv($15);
    var $17 = __ZN13JSCompartment12getDebuggeesEv($16);
    __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3allEv($r, $17);
    var $r_idx = $r | 0;
    var $r_idx1 = $r + 4 | 0;
    __label__ = 5;
    break;
   case 5:
    var $r_idx_val = HEAP32[$r_idx >> 2];
    var $r_idx1_val = HEAP32[$r_idx1 >> 2];
    var $19 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r_idx_val, $r_idx1_val);
    if ($19) {
      var $27 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($r_idx_val);
    var $23 = HEAP32[$21 >> 2];
    var $24 = __ZN2js12GlobalObject12getDebuggersEv($23);
    var $25 = __ZL22AddNewScriptRecipientsPN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEEEPNS_15AutoValueVectorE($24, $triggered);
    if ($25) {
      __label__ = 7;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 7:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($r);
    __label__ = 5;
    break;
   case 8:
    var $27;
    var $28 = $triggered | 0;
    var $29 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($28);
    var $30 = __ZN2js16AutoVectorRooterIN2JS5ValueEE3endEv($28);
    if (($29 | 0) == ($30 | 0)) {
      __label__ = 16;
      break;
    } else {
      var $p_01 = $29;
      var $32 = $27;
      __label__ = 9;
      break;
    }
   case 9:
    var $32;
    var $p_01;
    var $p_01_idx = $p_01 | 0;
    var $p_01_idx_val$0 = HEAP32[$p_01_idx >> 2];
    var $p_01_idx_val$1 = HEAP32[$p_01_idx + 4 >> 2];
    var $33 = __ZNK2JS5Value8toObjectEv($p_01_idx_val$0, $p_01_idx_val$1);
    var $_idx_val = HEAP32[$33 + 24 >> 2];
    var $34 = __ZN2js8Debugger12fromJSObjectEP8JSObject($_idx_val);
    if (($32 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $37 = $34 + 12 | 0;
    var $38 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3hasERKS2_($37, $global);
    if ($38) {
      __label__ = 11;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 11:
    if ((HEAP8[$34 + 40 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $_idx3_val = HEAP32[$34 + 8 >> 2];
    var $45 = __ZNK2js8Debugger7getHookENS0_4HookE($_idx3_val, 2);
    if (($45 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    __ZN2js8Debugger13fireNewScriptEP9JSContextP8JSScriptP8JSObjectNS0_13NewScriptKindE($34, $cx, $script, $obj, $kind);
    __label__ = 14;
    break;
   case 14:
    var $49 = $p_01 + 8 | 0;
    var $50 = __ZN2js16AutoVectorRooterIN2JS5ValueEE3endEv($28);
    if (($49 | 0) == ($50 | 0)) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $p_01 = $49;
    var $32 = HEAP32[$global >> 2];
    __label__ = 9;
    break;
   case 16:
    __ZN2js15AutoValueVectorD1Ev($triggered);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger19slowPathOnNewScriptEP9JSContextP8JSScriptP8JSObjectNS0_13NewScriptKindE["X"] = 1;

function __ZL22AddNewScriptRecipientsPN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEEEPNS_15AutoValueVectorE($src, $dest) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $dest | 0;
    var $2 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($1);
    var $3 = ($2 | 0) == 0;
    var $src_idx = $src | 0;
    var $src_idx_val = HEAP32[$src_idx >> 2];
    var $4 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5beginEv($src_idx_val);
    var $src_idx2 = $src + 4 | 0;
    var $v_idx3 = $v | 0;
    var $p_0 = $4;
    var $src_idx1_val = $src_idx_val;
    __label__ = 2;
    break;
   case 2:
    var $src_idx1_val;
    var $p_0;
    var $src_idx2_val = HEAP32[$src_idx2 >> 2];
    var $6 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($src_idx1_val, $src_idx2_val);
    if (($p_0 | 0) == ($6 | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAP32[$p_0 >> 2];
    var $_idx_val = HEAP32[$9 + 8 >> 2];
    var $10 = __ZNK2js8Debugger10toJSObjectEv($_idx_val);
    __ZN2JSL11ObjectValueER8JSObject($v, $10);
    var $11 = __ZNK2js8Debugger17observesNewScriptEv($9);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    if ($3) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $v_idx3_val$1 = HEAP32[$v_idx3 + 4 >> 2];
    var $v_idx3_val$0 = HEAP32[$v_idx3 >> 2];
    __label__ = 7;
    break;
   case 6:
    var $14 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($1);
    var $15 = __ZN2js16AutoVectorRooterIN2JS5ValueEE3endEv($1);
    var $v_idx_val$0 = HEAP32[$v_idx3 >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx3 + 4 >> 2];
    var $16 = __ZN2jsL4FindIN2JS5ValueEEEPT_S4_S4_RKS3_($14, $15, $v_idx_val$0, $v_idx_val$1);
    if (($16 | 0) == ($15 | 0)) {
      var $v_idx3_val$1 = $v_idx_val$1;
      var $v_idx3_val$0 = $v_idx_val$0;
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $v_idx3_val$0;
    var $v_idx3_val$1;
    var $19 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($1, $v_idx3_val$0, $v_idx3_val$1);
    if ($19) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $p_0 = $p_0 + 4 | 0;
    var $src_idx1_val = HEAP32[$src_idx >> 2];
    __label__ = 2;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3allEv($agg_result, $this) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $_idx1_val = HEAP32[$this + 20 >> 2];
  __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3allEv($agg_result, $_idx_val, $_idx1_val);
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 8 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$5 >> 2];
    var $8 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isLiveEv($_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js10Breakpoint10getHandlerEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($this_0_0_val, $this_0_1_val) {
  return ($this_0_0_val | 0) == ($this_0_1_val | 0);
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($this_0_0_val, $this_0_1_val) {
  return ($this_0_0_val | 0) == ($this_0_1_val | 0);
}

function __ZN2js8Debugger9fromLinksEP10JSCListStr($links) {
  return $links;
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($this_0_0_val, $this_0_1_val) {
  return $this_0_0_val + ($this_0_1_val << 2) | 0;
}

function __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($this_0_0_val, $this_0_1_val) {
  return $this_0_0_val + ($this_0_1_val << 2) | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN2js8Debugger6onTrapEP9JSContextPN2JS5ValueE($cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 120;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $scriptGlobal = __stackBase__;
    var $triggered = __stackBase__ + 4;
    var $1 = __stackBase__ + 28;
    var $2 = __stackBase__ + 32;
    var $3 = __stackBase__ + 36;
    var $ac = __stackBase__ + 44;
    var $argv = __stackBase__ + 96;
    var $rv = __stackBase__ + 104;
    var $4 = __stackBase__ + 112;
    var $5 = __ZNK9JSContext2fpEv($cx);
    var $6 = __ZNK2js10StackFrame10scopeChainEv($5);
    var $7 = $6;
    var $8 = __ZNK8JSObject9getGlobalEv($7);
    HEAP32[$scriptGlobal >> 2] = $8;
    var $10 = __ZNK9JSContext4regsEv($cx);
    var $12 = HEAP32[$10 + 4 >> 2];
    var $13 = $cx + 56 | 0;
    var $14 = HEAP32[$13 >> 2];
    var $15 = __ZN13JSCompartment17getBreakpointSiteEPh($14, $12);
    var $17 = HEAP32[$15 + 8 >> 2];
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
    var $_0_val = HEAP32[$1 >> 2];
    __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEEC1ES3_($triggered, $_0_val);
    var $18 = __ZNK2js14BreakpointSite15firstBreakpointEv($15);
    var $bp_0 = $18;
    __label__ = 2;
    break;
   case 2:
    var $bp_0;
    if (($bp_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $22 = __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($triggered, $bp_0);
    if ($22) {
      __label__ = 4;
      break;
    } else {
      var $_3 = 0;
      __label__ = 22;
      break;
    }
   case 4:
    var $bp_0_idx_val = HEAP32[$bp_0 + 4 >> 2];
    var $bp_0_idx1_val = HEAP32[$bp_0 + 20 >> 2];
    var $24 = __ZN2js10Breakpoint10nextInSiteEv($bp_0_idx_val, $bp_0_idx1_val);
    var $bp_0 = $24;
    __label__ = 2;
    break;
   case 5:
    var $triggered_idx = $triggered + 4 | 0;
    var $triggered_idx_val = HEAP32[$triggered_idx >> 2];
    var $26 = __ZNK2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE5beginEv($triggered_idx_val);
    var $27 = $3 | 0;
    var $28 = $argv | 0;
    var $triggered_idx3 = $triggered + 8 | 0;
    var $_idx = $2 | 0;
    var $p_0 = $26;
    var $site_0 = $15;
    var $triggered_idx2_val = $triggered_idx_val;
    __label__ = 6;
    break;
   case 6:
    var $triggered_idx2_val;
    var $site_0;
    var $p_0;
    var $triggered_idx3_val = HEAP32[$triggered_idx3 >> 2];
    var $30 = __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE3endEv($triggered_idx2_val, $triggered_idx3_val);
    if (($p_0 | 0) == ($30 | 0)) {
      __label__ = 18;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $33 = HEAP32[$p_0 >> 2];
    if (($site_0 | 0) == 0) {
      var $site_2 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $36 = __ZN2js14BreakpointSite13hasBreakpointEPNS_10BreakpointE($site_0, $33);
    if ($36) {
      __label__ = 9;
      break;
    } else {
      var $site_2 = $site_0;
      __label__ = 17;
      break;
    }
   case 9:
    var $39 = HEAP32[$33 >> 2];
    if ((HEAP8[$39 + 40 | 0] & 1) << 24 >> 24 == 0) {
      var $site_2 = $site_0;
      __label__ = 17;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $45 = $39 + 12 | 0;
    __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6lookupERKS2_($2, $45, $scriptGlobal);
    var $_idx_val_idx_val = HEAP32[HEAP32[$_idx >> 2] >> 2];
    __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($3, $_idx_val_idx_val);
    if ((HEAP32[$27 >> 2] | 0) == 0) {
      var $site_2 = $site_0;
      __label__ = 17;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $50 = HEAP32[$39 + 8 >> 2];
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $50);
    var $51 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($51) {
      __label__ = 12;
      break;
    } else {
      var $_1_ph = 0;
      __label__ = 15;
      break;
    }
   case 12:
    var $53 = __ZN2js8Debugger14getScriptFrameEP9JSContextPNS_10StackFrameEPN2JS5ValueE($39, $cx, $5, $28);
    if ($53) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $55 = __ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb($39, $ac, $vp, 0);
    var $_1_ph = $55;
    __label__ = 15;
    break;
   case 14:
    var $58 = HEAP32[$33 + 8 >> 2];
    var $59 = __Z19CallMethodIfPresentP9JSContextP8JSObjectPKciPN2JS5ValueES7_($cx, $58, $28, $rv);
    var $60 = __ZN2js8Debugger20parseResumptionValueERNS_15AutoCompartmentEbRKN2JS5ValueEPS4_b($39, $ac, $59, $rv, $vp, 1);
    if (($60 | 0) == 1) {
      __label__ = 16;
      break;
    } else {
      var $_1_ph = $60;
      __label__ = 15;
      break;
    }
   case 15:
    var $_1_ph;
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_3 = $_1_ph;
    __label__ = 22;
    break;
   case 16:
    var $63 = HEAP32[$13 >> 2];
    var $64 = __ZN13JSCompartment17getBreakpointSiteEPh($63, $12);
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $site_2 = $64;
    __label__ = 17;
    break;
   case 17:
    var $site_2;
    var $p_0 = $p_0 + 4 | 0;
    var $site_0 = $site_2;
    var $triggered_idx2_val = HEAP32[$triggered_idx >> 2];
    __label__ = 6;
    break;
   case 18:
    if (($site_0 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $70 = HEAP32[$site_0 + 28 >> 2];
    if (($70 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $73 = __ZNK2js10StackFrame6scriptEv($5);
    var $74 = $site_0 + 32 | 0;
    var $75$0 = HEAP32[$74 >> 2];
    var $75$1 = HEAP32[$74 + 4 >> 2];
    var $76 = $4 | 0;
    HEAP32[$76 >> 2] = $75$0;
    HEAP32[$76 + 4 >> 2] = $75$1;
    var $77 = FUNCTION_TABLE[$70]($cx, $73, $12, $vp, $4);
    if (($77 | 0) == 1) {
      __label__ = 21;
      break;
    } else {
      var $_3 = $77;
      __label__ = 22;
      break;
    }
   case 21:
    __ZN2JS5Value8setInt32Ei($vp, $17);
    var $_3 = 1;
    __label__ = 22;
    break;
   case 22:
    var $_3;
    __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEED1Ev($triggered);
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger6onTrapEP9JSContextPN2JS5ValueE["X"] = 1;

function __ZNK9JSContext4regsEv($this) {
  var $_idx_val_idx_val = HEAP32[HEAP32[$this + 60 >> 2] + 8 >> 2];
  var $1 = __ZNK2js12ContextStack4regsEv($_idx_val_idx_val);
  return $1;
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEEC1ES3_($this, $ap_01) {
  __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap_01);
  return;
}

function __ZN2js15TempAllocPolicyC1EP9JSContext($this, $cx) {
  __ZN2js15TempAllocPolicyC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE13growStorageByEj($this);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 14,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2JS5Value8setInt32Ei($this, $i) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _INT32_TO_JSVAL_IMPL($1, $i);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js8Debugger12onSingleStepEP9JSContextPN2JS5ValueE($cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 168;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fp = __stackBase__;
    var $exception = __stackBase__ + 4;
    var $frames = __stackBase__ + 12;
    var $p = __stackBase__ + 72;
    var $1 = __stackBase__ + 76;
    var $2 = __stackBase__ + 84;
    var $ac = __stackBase__ + 92;
    var $3 = __stackBase__ + 144;
    var $rval = __stackBase__ + 152;
    var $4 = __stackBase__ + 160;
    var $5 = __ZNK9JSContext2fpEv($cx);
    HEAP32[$fp >> 2] = $5;
    __ZN2JSL14UndefinedValueEv($exception);
    var $cx_idx_val = HEAP32[$cx + 20 >> 2];
    var $6 = __ZN9JSContext18isExceptionPendingEv($cx_idx_val);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $cx_idx4 = $cx + 24 | 0;
    var $st$1$0 = $cx_idx4 | 0;
    var $cx_idx4_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $cx_idx4 + 4 | 0;
    var $cx_idx4_val$1 = HEAP32[$st$1$1 >> 2];
    __ZN9JSContext19getPendingExceptionEv($exception, $cx_idx4_val$0, $cx_idx4_val$1);
    __ZN9JSContext21clearPendingExceptionEv($cx);
    __label__ = 3;
    break;
   case 3:
    __ZN2js16AutoObjectVectorC1EP9JSContext($frames, $cx);
    var $9 = __ZNK2js10StackFrame10scopeChainEv($5);
    var $10 = $9;
    var $11 = __ZNK8JSObject9getGlobalEv($10);
    var $12 = $11;
    var $13 = __ZN2js12GlobalObject12getDebuggersEv($12);
    if (($13 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_pre_phi = $frames | 0;
    __label__ = 11;
    break;
   case 5:
    var $_idx1 = $13 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $16 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5beginEv($_idx1_val);
    var $17 = $1 | 0;
    var $18 = $frames | 0;
    var $_idx3 = $13 + 4 | 0;
    var $p_idx = $p | 0;
    var $_idx = $2 | 0;
    var $d_0 = $16;
    var $_idx2_val = $_idx1_val;
    __label__ = 6;
    break;
   case 6:
    var $_idx2_val;
    var $d_0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $20 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($_idx2_val, $_idx3_val);
    if (($d_0 | 0) == ($20 | 0)) {
      var $_pre_phi = $18;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = HEAP32[$d_0 >> 2] + 52 | 0;
    __ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_($p, $24, $fp);
    var $p_idx_val = HEAP32[$p_idx >> 2];
    var $p_idx_val_idx_val = HEAP32[$p_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($1, $p_idx_val_idx_val);
    if ((HEAP32[$17 >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $28 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($p_idx_val);
    var $30 = HEAP32[$28 + 4 >> 2];
    __ZNK8JSObject15getReservedSlotEj($2, $30, 2);
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $31 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($31) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $33 = __ZN2js16AutoVectorRooterIP8JSObjectE6appendERKS2_($18, $30);
    if ($33) {
      __label__ = 10;
      break;
    } else {
      var $_2 = 0;
      __label__ = 19;
      break;
    }
   case 10:
    var $d_0 = $d_0 + 4 | 0;
    var $_idx2_val = HEAP32[$_idx1 >> 2];
    __label__ = 6;
    break;
   case 11:
    var $_pre_phi;
    var $36 = __ZN2js16AutoVectorRooterIP8JSObjectE5beginEv($_pre_phi);
    var $_0 = undef;
    var $p1_0 = $36;
    __label__ = 12;
    break;
   case 12:
    var $p1_0;
    var $_0;
    var $38 = __ZN2js16AutoVectorRooterIP8JSObjectE3endEv($_pre_phi);
    if (($p1_0 | 0) == ($38 | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $41 = HEAP32[$p1_0 >> 2];
    var $42 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($41);
    var $44 = HEAP32[$42 + 8 >> 2];
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $44);
    var $45 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($45) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_2 = 0;
    __label__ = 19;
    break;
   case 15:
    __ZNK8JSObject15getReservedSlotEj($3, $41, 2);
    __ZN2JSL11ObjectValueER8JSObject($4, $41);
    var $47 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $4, $3, 0, 0, $rval);
    var $48 = __ZN2js8Debugger20parseResumptionValueERNS_15AutoCompartmentEbRKN2JS5ValueEPS4_b($42, $ac, $47, $rval, $vp, 1);
    var $49 = ($48 | 0) == 1;
    var $_0_ = $49 ? $_0 : $48;
    __ZN2js15AutoCompartmentD2Ev($ac);
    if ($49) {
      __label__ = 16;
      break;
    } else {
      var $_2 = $_0_;
      __label__ = 19;
      break;
    }
   case 16:
    var $_0 = $_0_;
    var $p1_0 = $p1_0 + 4 | 0;
    __label__ = 12;
    break;
   case 17:
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($6) {
      __label__ = 18;
      break;
    } else {
      var $_2 = 1;
      __label__ = 19;
      break;
    }
   case 18:
    var $54 = $exception | 0;
    var $st$1$0 = $54 | 0;
    var $55$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $54 + 4 | 0;
    var $55$1 = HEAP32[$st$1$1 >> 2];
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($cx, $55$0, $55$1);
    var $_2 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_2;
    __ZN2js16AutoObjectVectorD1Ev($frames);
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger12onSingleStepEP9JSContextPN2JS5ValueE["X"] = 1;

function __ZN2js16AutoObjectVectorC1EP9JSContext($this, $cx) {
  __ZN2js16AutoObjectVectorC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js16AutoVectorRooterIP8JSObjectE6appendERKS2_($this, $v_val) {
  var $1 = $this + 12 | 0;
  var $2 = __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE6appendIS2_EEbT_($1, $v_val);
  return $2;
}

function __ZN2js16AutoVectorRooterIP8JSObjectE5beginEv($this) {
  var $_idx_val = HEAP32[$this + 16 >> 2];
  var $1 = __ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE5beginEv($_idx_val);
  return $1;
}

function __ZN2js16AutoVectorRooterIP8JSObjectE3endEv($this) {
  var $_idx_val = HEAP32[$this + 16 >> 2];
  var $_idx1_val = HEAP32[$this + 20 >> 2];
  var $1 = __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE3endEv($_idx_val, $_idx1_val);
  return $1;
}

function __ZN2js16AutoObjectVectorD1Ev($this) {
  __ZN2js16AutoObjectVectorD2Ev($this);
  return;
}

function __ZN2js8Debugger21markKeysInCompartmentEP8JSTracerRKNS_7WeakMapIP8JSObjectS5_NS_13DefaultHasherIS5_EENS_17DefaultMarkPolicyIS5_S5_EEEE($tracer, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $tracer | 0;
    var $6 = HEAP32[HEAP32[HEAP32[$1 >> 2] + 52 >> 2] + 144080 >> 2];
    var $7 = $map + 8 | 0;
    __ZNK2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($r, $7);
    var $r_idx2 = $r | 0;
    var $r_idx2_val = HEAP32[$r_idx2 >> 2];
    var $r_idx3 = $r + 4 | 0;
    var $r_idx3_val = HEAP32[$r_idx3 >> 2];
    var $8 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r_idx2_val, $r_idx3_val);
    if ($8) {
      __label__ = 6;
      break;
    } else {
      var $r_idx4_val = $r_idx2_val;
      __label__ = 2;
      break;
    }
   case 2:
    var $r_idx4_val;
    var $9 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($r_idx4_val);
    var $11 = HEAP32[$9 >> 2];
    var $12 = $11;
    var $13 = __ZNK2js2gc4Cell11compartmentEv($12);
    if (($13 | 0) == ($6 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $17 = $11;
    var $_idx_val_idx_val = HEAP32[HEAP32[HEAP32[$1 >> 2] + 52 >> 2] + 144080 >> 2];
    var $18 = __Z20IsAboutToBeFinalizedP9JSContextPKv($_idx_val_idx_val, $17);
    if ($18) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($tracer, $11);
    __label__ = 5;
    break;
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($r);
    var $r_idx_val = HEAP32[$r_idx2 >> 2];
    var $r_idx1_val = HEAP32[$r_idx3 >> 2];
    var $21 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r_idx_val, $r_idx1_val);
    if ($21) {
      __label__ = 6;
      break;
    } else {
      var $r_idx4_val = $r_idx_val;
      __label__ = 2;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($agg_result, $this) {
  var $_idx_val = HEAP32[$this + 8 >> 2];
  var $_idx1_val = HEAP32[$this + 24 >> 2];
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $_idx_val, $_idx1_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$5 >> 2];
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isLiveEv($_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger43markCrossCompartmentDebuggerObjectReferentsEP8JSTracer($tracer) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAP32[HEAP32[$tracer >> 2] + 52 >> 2];
    var $6 = HEAP32[$4 + 144080 >> 2];
    var $7 = $4 + 144228 | 0;
    var $9 = HEAP32[$7 >> 2];
    if (($9 | 0) == ($7 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $11 = $9;
      __label__ = 2;
      break;
    }
   case 2:
    var $11;
    var $12 = __ZN2js8Debugger9fromLinksEP10JSCListStr($11);
    var $15 = HEAP32[$12 + 8 >> 2];
    var $16 = __ZNK2js2gc4Cell11compartmentEv($15);
    if (($16 | 0) == ($6 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $19 = $12 + 80 | 0;
    __ZN2js8Debugger21markKeysInCompartmentEP8JSTracerRKNS_7WeakMapIP8JSObjectS5_NS_13DefaultHasherIS5_EENS_17DefaultMarkPolicyIS5_S5_EEEE($tracer, $19);
    var $20 = $12 + 116 | 0;
    __ZN2js8Debugger21markKeysInCompartmentEP8JSTracerRKNS_7WeakMapIP8JSObjectS5_NS_13DefaultHasherIS5_EENS_17DefaultMarkPolicyIS5_S5_EEEE($tracer, $20);
    __label__ = 4;
    break;
   case 4:
    var $22 = HEAP32[$11 >> 2];
    if (($22 | 0) == ($7 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $11 = $22;
      __label__ = 2;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger18markAllIterativelyEPNS_8GCMarkerE($trc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $trc | 0;
    var $3 = HEAPU32[$trc >> 2];
    var $4 = $3 + 52 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $7 = HEAPU32[$5 + 144080 >> 2];
    var $_idx5 = $5 + 4 | 0;
    var $_idx5_val = HEAP32[$_idx5 >> 2];
    var $8 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($_idx5_val);
    var $_idx9 = $5 + 8 | 0;
    var $_idx9_val = HEAP32[$_idx9 >> 2];
    var $9 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx5_val, $_idx9_val);
    if (($8 | 0) == ($9 | 0)) {
      var $markedAny_0_lcssa = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = ($7 | 0) != 0;
    var $_not = $11 ^ 1;
    var $r_idx2 = $r | 0;
    var $r_idx3 = $r + 4 | 0;
    var $c_015 = $8;
    var $markedAny_016 = 0;
    __label__ = 3;
    break;
   case 3:
    var $markedAny_016;
    var $c_015;
    var $13 = HEAPU32[$c_015 >> 2];
    var $14 = ($13 | 0) == ($7 | 0);
    if ($14 | $_not) {
      __label__ = 4;
      break;
    } else {
      var $markedAny_1 = $markedAny_016;
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = $markedAny_016 & 1;
    var $17 = __ZN13JSCompartment27markTrapClosuresIterativelyEP8JSTracer($13, $1);
    var $markedAny_1 = $17 & 1 | $16;
    __label__ = 5;
    break;
   case 5:
    var $markedAny_1;
    if ($11 & $14) {
      var $markedAny_8 = $markedAny_1;
      __label__ = 21;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = __ZN13JSCompartment12getDebuggeesEv($13);
    __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3allEv($r, $22);
    var $r_idx2_val = HEAP32[$r_idx2 >> 2];
    var $r_idx3_val = HEAP32[$r_idx3 >> 2];
    var $23 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r_idx2_val, $r_idx3_val);
    if ($23) {
      var $markedAny_8 = $markedAny_1;
      __label__ = 21;
      break;
    } else {
      var $markedAny_211 = $markedAny_1;
      var $r_idx4_val = $r_idx2_val;
      __label__ = 7;
      break;
    }
   case 7:
    var $r_idx4_val;
    var $markedAny_211;
    var $24 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($r_idx4_val);
    var $26 = HEAP32[$24 >> 2];
    var $27 = __ZN2js12GlobalObject12getDebuggersEv($26);
    var $_idx = $27 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $28 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5beginEv($_idx_val);
    var $_idx16 = $27 + 4 | 0;
    var $_idx16_val = HEAP32[$_idx16 >> 2];
    var $29 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($_idx_val, $_idx16_val);
    if (($28 | 0) == ($29 | 0)) {
      var $markedAny_3_lcssa = $markedAny_211;
      __label__ = 20;
      break;
    } else {
      var $p_06 = $28;
      var $markedAny_37 = $markedAny_211;
      __label__ = 8;
      break;
    }
   case 8:
    var $markedAny_37;
    var $p_06;
    var $31 = HEAP32[$p_06 >> 2];
    var $_idx17_val = HEAP32[$31 + 8 >> 2];
    var $32 = __ZNK2js8Debugger10toJSObjectEv($_idx17_val);
    if ($11) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = $32;
    var $35 = __ZNK2js2gc4Cell11compartmentEv($34);
    if (($7 | 0) == ($35 | 0)) {
      __label__ = 10;
      break;
    } else {
      var $markedAny_7 = $markedAny_37;
      __label__ = 19;
      break;
    }
   case 10:
    var $38 = $32;
    var $_idx12_val_idx_val = HEAP32[HEAP32[$4 >> 2] + 144080 >> 2];
    var $39 = __Z20IsAboutToBeFinalizedP9JSContextPKv($_idx12_val_idx_val, $38);
    if ($39) {
      __label__ = 11;
      break;
    } else {
      var $markedAny_42 = $markedAny_37;
      __label__ = 13;
      break;
    }
   case 11:
    var $41 = __ZNK2js8Debugger15hasAnyLiveHooksEP9JSContext($31, $3);
    if ($41) {
      __label__ = 12;
      break;
    } else {
      var $markedAny_7 = $markedAny_37;
      __label__ = 19;
      break;
    }
   case 12:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($1, $32);
    var $markedAny_42 = 1;
    __label__ = 13;
    break;
   case 13:
    var $markedAny_42;
    var $42 = __ZNK2js8Debugger15firstBreakpointEv($31);
    if (($42 | 0) == 0) {
      var $markedAny_7 = $markedAny_42;
      __label__ = 19;
      break;
    } else {
      var $markedAny_53 = $markedAny_42;
      var $bp_04 = $42;
      __label__ = 14;
      break;
    }
   case 14:
    var $bp_04;
    var $markedAny_53;
    var $_idx18_val = HEAP32[HEAP32[$bp_04 + 4 >> 2] + 12 >> 2];
    var $46 = __ZNK2js14BreakpointSite15getScriptObjectEv($_idx18_val);
    if (($46 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $49 = $46;
    var $_idx11_val_idx_val = HEAP32[HEAP32[$4 >> 2] + 144080 >> 2];
    var $50 = __Z20IsAboutToBeFinalizedP9JSContextPKv($_idx11_val_idx_val, $49);
    if ($50) {
      var $markedAny_6 = $markedAny_53;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $bp_04_idx21 = $bp_04 + 8 | 0;
    var $bp_04_idx21_val = HEAP32[$bp_04_idx21 >> 2];
    var $52 = __ZNK2js10Breakpoint10getHandlerEv($bp_04_idx21_val);
    var $53 = $52;
    var $_idx10_val_idx_val = HEAP32[HEAP32[$4 >> 2] + 144080 >> 2];
    var $54 = __Z20IsAboutToBeFinalizedP9JSContextPKv($_idx10_val_idx_val, $53);
    if ($54) {
      __label__ = 17;
      break;
    } else {
      var $markedAny_6 = $markedAny_53;
      __label__ = 18;
      break;
    }
   case 17:
    var $bp_04_idx20_val = HEAP32[$bp_04_idx21 >> 2];
    var $56 = __ZNK2js10Breakpoint10getHandlerEv($bp_04_idx20_val);
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($1, $56);
    var $markedAny_6 = 1;
    __label__ = 18;
    break;
   case 18:
    var $markedAny_6;
    var $bp_04_idx_val = HEAP32[$bp_04 >> 2];
    var $bp_04_idx19_val = HEAP32[$bp_04 + 12 >> 2];
    var $58 = __ZN2js10Breakpoint14nextInDebuggerEv($bp_04_idx_val, $bp_04_idx19_val);
    if (($58 | 0) == 0) {
      var $markedAny_7 = $markedAny_6;
      __label__ = 19;
      break;
    } else {
      var $markedAny_53 = $markedAny_6;
      var $bp_04 = $58;
      __label__ = 14;
      break;
    }
   case 19:
    var $markedAny_7;
    var $60 = $p_06 + 4 | 0;
    var $_idx13_val = HEAP32[$_idx >> 2];
    var $_idx14_val = HEAP32[$_idx16 >> 2];
    var $61 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($_idx13_val, $_idx14_val);
    if (($60 | 0) == ($61 | 0)) {
      var $markedAny_3_lcssa = $markedAny_7;
      __label__ = 20;
      break;
    } else {
      var $p_06 = $60;
      var $markedAny_37 = $markedAny_7;
      __label__ = 8;
      break;
    }
   case 20:
    var $markedAny_3_lcssa;
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($r);
    var $r_idx_val = HEAP32[$r_idx2 >> 2];
    var $r_idx1_val = HEAP32[$r_idx3 >> 2];
    var $63 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r_idx_val, $r_idx1_val);
    if ($63) {
      var $markedAny_8 = $markedAny_3_lcssa;
      __label__ = 21;
      break;
    } else {
      var $markedAny_211 = $markedAny_3_lcssa;
      var $r_idx4_val = $r_idx_val;
      __label__ = 7;
      break;
    }
   case 21:
    var $markedAny_8;
    var $64 = $c_015 + 4 | 0;
    var $_idx6_val = HEAP32[$_idx5 >> 2];
    var $_idx7_val = HEAP32[$_idx9 >> 2];
    var $65 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx6_val, $_idx7_val);
    if (($64 | 0) == ($65 | 0)) {
      var $markedAny_0_lcssa = $markedAny_8;
      __label__ = 22;
      break;
    } else {
      var $c_015 = $64;
      var $markedAny_016 = $markedAny_8;
      __label__ = 3;
      break;
    }
   case 22:
    var $markedAny_0_lcssa;
    STACKTOP = __stackBase__;
    return ($markedAny_0_lcssa & 1) << 24 >> 24 != 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger18markAllIterativelyEPNS_8GCMarkerE["X"] = 1;

function __ZN2js8Debugger11traceObjectEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj_idx_val = HEAP32[$obj + 24 >> 2];
    var $1 = __ZN2js8Debugger12fromJSObjectEP8JSObject($obj_idx_val);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js8Debugger5traceEP8JSTracer($1, $trc);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger5traceEP8JSTracer($this, $trc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $r1 = __stackBase__ + 8;
    var $2 = HEAP32[$this + 36 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $2);
    __label__ = 3;
    break;
   case 3:
    var $6 = $this + 52 | 0;
    __ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($r, $6);
    var $r_idx2 = $r | 0;
    var $r_idx2_val = HEAP32[$r_idx2 >> 2];
    var $r_idx3 = $r + 4 | 0;
    var $r_idx3_val = HEAP32[$r_idx3 >> 2];
    var $7 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($r_idx2_val, $r_idx3_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      var $r_idx4_val = $r_idx2_val;
      __label__ = 4;
      break;
    }
   case 4:
    var $r_idx4_val;
    var $8 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($r_idx4_val);
    var $10 = HEAP32[$8 + 4 >> 2];
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $10);
    __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($r);
    var $r_idx_val = HEAP32[$r_idx2 >> 2];
    var $r_idx1_val = HEAP32[$r_idx3 >> 2];
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($r_idx_val, $r_idx1_val);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      var $r_idx4_val = $r_idx_val;
      __label__ = 4;
      break;
    }
   case 5:
    var $12 = $this + 80 | 0;
    __ZN2js11WeakMapBase5traceEP8JSTracer($12, $trc);
    var $13 = $this + 116 | 0;
    __ZN2js11WeakMapBase5traceEP8JSTracer($13, $trc);
    var $14 = $this + 152 | 0;
    __ZNK2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($r1, $14);
    var $r1_idx6 = $r1 | 0;
    var $r1_idx6_val = HEAP32[$r1_idx6 >> 2];
    var $r1_idx7 = $r1 + 4 | 0;
    var $r1_idx7_val = HEAP32[$r1_idx7 >> 2];
    var $15 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($r1_idx6_val, $r1_idx7_val);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      var $r1_idx8_val = $r1_idx6_val;
      __label__ = 6;
      break;
    }
   case 6:
    var $r1_idx8_val;
    var $16 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($r1_idx8_val);
    var $18 = HEAP32[$16 + 4 >> 2];
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $18);
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($r1);
    var $r1_idx_val = HEAP32[$r1_idx6 >> 2];
    var $r1_idx5_val = HEAP32[$r1_idx7 >> 2];
    var $19 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($r1_idx_val, $r1_idx5_val);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      var $r1_idx8_val = $r1_idx_val;
      __label__ = 6;
      break;
    }
   case 7:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11WeakMapBase5traceEP8JSTracer($this, $tracer) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$tracer + 4 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = HEAP32[HEAP32[$tracer >> 2] + 52 >> 2] + 200 | 0;
    var $10 = HEAP32[$9 >> 2];
    HEAP32[$this + 4 >> 2] = $10;
    HEAP32[$9 >> 2] = $this;
    __label__ = 5;
    break;
   case 3:
    if ((HEAP32[$tracer + 20 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = HEAP32[HEAP32[$this >> 2] >> 2];
    FUNCTION_TABLE[$19]($this, $tracer);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($agg_result, $this) {
  var $_idx_val = HEAP32[$this + 8 >> 2];
  var $_idx1_val = HEAP32[$this + 24 >> 2];
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3allEv($agg_result, $_idx_val, $_idx1_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$5 >> 2];
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isLiveEv($_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5emptyEv($this_0_1_val) {
  return ($this_0_1_val | 0) == 0;
}

function __ZNK2js12CallReceiver5thisvEv($this_0_0_val) {
  return $this_0_0_val - 8 | 0;
}

function __ZNK2js12CallReceiver4rvalEv($this_0_0_val) {
  return $this_0_0_val - 16 | 0;
}

function __ZNK2js8CallArgsixEj($this_0_0_0_val, $i) {
  return $this_0_0_0_val + ($i << 3) | 0;
}

function __ZN2js8Debugger8sweepAllEP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e = __stackBase__;
    var $e1 = __stackBase__ + 16;
    var $1 = $cx + 52 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $2 + 144228 | 0;
    var $5 = HEAP32[$3 >> 2];
    if (($5 | 0) == ($3 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $e | 0;
    var $_idx6 = $e | 0;
    var $_idx7 = $e + 4 | 0;
    var $9 = $5;
    var $cx_idx15_val = $2;
    __label__ = 3;
    break;
   case 3:
    var $cx_idx15_val;
    var $9;
    var $10 = __ZN2js8Debugger9fromLinksEP10JSCListStr($9);
    var $13 = HEAP32[$10 + 8 >> 2];
    var $cx_idx15_val_idx_val = HEAP32[$cx_idx15_val + 144080 >> 2];
    var $14 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx_idx15_val_idx_val, $13);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $16 = $10 + 12 | 0;
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC1IS9_EERT_($e, $16);
    var $_idx6_val = HEAP32[$_idx6 >> 2];
    var $_idx7_val = HEAP32[$_idx7 >> 2];
    var $17 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($_idx6_val, $_idx7_val);
    if ($17) {
      __label__ = 5;
      break;
    } else {
      var $_idx9_val = $_idx6_val;
      __label__ = 8;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD1Ev($e);
    __label__ = 6;
    break;
   case 6:
    var $19 = HEAP32[$9 >> 2];
    if (($19 | 0) == ($3 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $9 = $19;
    var $cx_idx15_val = HEAP32[$1 >> 2];
    __label__ = 3;
    break;
   case 8:
    var $_idx9_val;
    var $21 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($_idx9_val);
    var $22 = HEAP32[$21 >> 2];
    __ZN2js8Debugger20removeDebuggeeGlobalEP9JSContextPNS_12GlobalObjectEPNS_6detail9HashTableIKS4_NS_7HashSetIS4_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE6SetOpsESB_E4EnumESG_($10, $cx, $22, 0, $e);
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($7);
    var $_idx4_val = HEAP32[$_idx6 >> 2];
    var $_idx5_val = HEAP32[$_idx7 >> 2];
    var $23 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($_idx4_val, $_idx5_val);
    if ($23) {
      __label__ = 5;
      break;
    } else {
      var $_idx9_val = $_idx4_val;
      __label__ = 8;
      break;
    }
   case 9:
    var $_idx10 = $2 + 4 | 0;
    var $_idx10_val = HEAP32[$_idx10 >> 2];
    var $24 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($_idx10_val);
    var $_idx14 = $2 + 8 | 0;
    var $_idx14_val = HEAP32[$_idx14 >> 2];
    var $25 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx10_val, $_idx14_val);
    if (($24 | 0) == ($25 | 0)) {
      __label__ = 16;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $27 = $e1 | 0;
    var $_idx2 = $e1 | 0;
    var $_idx3 = $e1 + 4 | 0;
    var $c_01 = $24;
    __label__ = 11;
    break;
   case 11:
    var $c_01;
    var $29 = HEAP32[$c_01 >> 2];
    var $30 = __ZN13JSCompartment12getDebuggeesEv($29);
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC1IS9_EERT_($e1, $30);
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $31 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($_idx2_val, $_idx3_val);
    if ($31) {
      __label__ = 12;
      break;
    } else {
      var $_idx8_val = $_idx2_val;
      __label__ = 13;
      break;
    }
   case 12:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD1Ev($e1);
    var $32 = $c_01 + 4 | 0;
    var $_idx11_val = HEAP32[$_idx10 >> 2];
    var $_idx12_val = HEAP32[$_idx14 >> 2];
    var $33 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx11_val, $_idx12_val);
    if (($32 | 0) == ($33 | 0)) {
      __label__ = 16;
      break;
    } else {
      var $c_01 = $32;
      __label__ = 11;
      break;
    }
   case 13:
    var $_idx8_val;
    var $35 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($_idx8_val);
    var $36 = HEAP32[$35 >> 2];
    var $37 = $36;
    var $cx_idx_val_idx_val = HEAP32[HEAP32[$1 >> 2] + 144080 >> 2];
    var $38 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx_idx_val_idx_val, $37);
    if ($38) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    __ZN2js8Debugger28detachAllDebuggersFromGlobalEP9JSContextPNS_12GlobalObjectEPNS_6detail9HashTableIKS4_NS_7HashSetIS4_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE6SetOpsESB_E4EnumE($cx, $36, $e1);
    __label__ = 15;
    break;
   case 15:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($27);
    var $_idx_val = HEAP32[$_idx2 >> 2];
    var $_idx1_val = HEAP32[$_idx3 >> 2];
    var $41 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($_idx_val, $_idx1_val);
    if ($41) {
      __label__ = 12;
      break;
    } else {
      var $_idx8_val = $_idx_val;
      __label__ = 13;
      break;
    }
   case 16:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger8sweepAllEP9JSContext["X"] = 1;

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC1IS9_EERT_($this, $map) {
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC2IS9_EERT_($this, $map);
  return;
}

function __ZN2js8Debugger20removeDebuggeeGlobalEP9JSContextPNS_12GlobalObjectEPNS_6detail9HashTableIKS4_NS_7HashSetIS4_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE6SetOpsESB_E4EnumESG_($this, $cx, $global, $compartmentEnum, $debugEnum) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $e = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $global;
    var $2 = $this + 52 | 0;
    __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC1ISC_EERT_($e, $2);
    var $3 = $e | 0;
    var $_idx2 = $e | 0;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $_idx3 = $e + 4 | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $4 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($_idx2_val, $_idx3_val);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_idx4_val = $_idx2_val;
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD1Ev($e);
    var $5 = $global;
    var $6 = __ZN2js12GlobalObject12getDebuggersEv($5);
    var $_idx6_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5beginEv($_idx6_val);
    var $_idx8 = $6 + 4 | 0;
    var $_idx8_val = HEAP32[$_idx8 >> 2];
    var $8 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($_idx6_val, $_idx8_val);
    var $p_0 = $7;
    __label__ = 6;
    break;
   case 3:
    var $_idx4_val;
    var $9 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($_idx4_val);
    var $11 = HEAP32[$9 >> 2];
    var $12 = __ZNK2js10StackFrame10scopeChainEv($11);
    var $13 = $12;
    var $14 = __ZNK8JSObject9getGlobalEv($13);
    if (($14 | 0) == ($global | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $19 = HEAP32[$9 + 4 >> 2];
    __ZN8JSObject10setPrivateEPv($19, 0);
    __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4Enum11removeFrontEv($e);
    __label__ = 5;
    break;
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($3);
    var $_idx_val = HEAP32[$_idx2 >> 2];
    var $_idx1_val = HEAP32[$_idx3 >> 2];
    var $21 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($_idx_val, $_idx1_val);
    if ($21) {
      __label__ = 2;
      break;
    } else {
      var $_idx4_val = $_idx_val;
      __label__ = 3;
      break;
    }
   case 6:
    var $p_0;
    if (($p_0 | 0) == ($8 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ((HEAP32[$p_0 >> 2] | 0) == ($this | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $p_0 = $p_0 + 4 | 0;
    __label__ = 6;
    break;
   case 9:
    __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5eraseEPS2_($6, $p_0);
    var $_idx9_val = HEAP32[$_idx8 >> 2];
    var $30 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5emptyEv($_idx9_val);
    if ($30) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $32 = $global;
    var $33 = __ZNK2js2gc4Cell11compartmentEv($32);
    __ZN13JSCompartment14removeDebuggeeEP9JSContextPN2js12GlobalObjectEPNS2_6detail9HashTableIKS4_NS2_7HashSetIS4_NS2_13DefaultHasherIS4_EENS2_17SystemAllocPolicyEE6SetOpsESB_E4EnumE($33, $cx, $global, $compartmentEnum);
    __label__ = 11;
    break;
   case 11:
    if (($debugEnum | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4Enum11removeFrontEv($debugEnum);
    __label__ = 14;
    break;
   case 13:
    var $38 = $this + 12 | 0;
    __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeERKS2_($38, $1);
    __label__ = 14;
    break;
   case 14:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger20removeDebuggeeGlobalEP9JSContextPNS_12GlobalObjectEPNS_6detail9HashTableIKS4_NS_7HashSetIS4_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE6SetOpsESB_E4EnumESG_["X"] = 1;

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD2Ev($this);
  return;
}

function __ZN2js8Debugger28detachAllDebuggersFromGlobalEP9JSContextPNS_12GlobalObjectEPNS_6detail9HashTableIKS4_NS_7HashSetIS4_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE6SetOpsESB_E4EnumE($cx, $global, $compartmentEnum) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $global;
    var $2 = __ZN2js12GlobalObject12getDebuggersEv($1);
    var $_idx1 = $2 + 4 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $3 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5emptyEv($_idx1_val);
    if ($3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx2 = $2 | 0;
    var $_idx3_val = $_idx1_val;
    __label__ = 3;
    break;
   case 3:
    var $_idx3_val;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $4 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE4backEv($_idx2_val, $_idx3_val);
    var $5 = HEAP32[$4 >> 2];
    __ZN2js8Debugger20removeDebuggeeGlobalEP9JSContextPNS_12GlobalObjectEPNS_6detail9HashTableIKS4_NS_7HashSetIS4_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE6SetOpsESB_E4EnumESG_($5, $cx, $global, $compartmentEnum, 0);
    var $_idx_val = HEAP32[$_idx1 >> 2];
    var $6 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5emptyEv($_idx_val);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      var $_idx3_val = $_idx_val;
      __label__ = 3;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE4backEv($this_0_0_val, $this_0_1_val) {
  var $1 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($this_0_0_val, $this_0_1_val);
  return $1 - 4 | 0;
}

function __ZN2js8Debugger8finalizeEP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e = __stackBase__;
    var $obj_idx_val = HEAP32[$obj + 24 >> 2];
    var $1 = __ZN2js8Debugger12fromJSObjectEP8JSObject($obj_idx_val);
    if (($1 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1 + 12 | 0;
    var $5 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5emptyEv($4);
    if ($5) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC1IS9_EERT_($e, $4);
    var $7 = $e | 0;
    var $_idx2 = $e | 0;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $_idx3 = $e + 4 | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $8 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($_idx2_val, $_idx3_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_idx4_val = $_idx2_val;
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD1Ev($e);
    __label__ = 6;
    break;
   case 5:
    var $_idx4_val;
    var $9 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($_idx4_val);
    var $10 = HEAP32[$9 >> 2];
    __ZN2js8Debugger20removeDebuggeeGlobalEP9JSContextPNS_12GlobalObjectEPNS_6detail9HashTableIKS4_NS_7HashSetIS4_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE6SetOpsESB_E4EnumESG_($1, $cx, $10, 0, $e);
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($7);
    var $_idx_val = HEAP32[$_idx2 >> 2];
    var $_idx1_val = HEAP32[$_idx3 >> 2];
    var $11 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($_idx_val, $_idx1_val);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_idx4_val = $_idx_val;
      __label__ = 5;
      break;
    }
   case 6:
    __ZN9JSContext7delete_IN2js8DebuggerEEEvPT_($1);
    __label__ = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5emptyEv($this) {
  var $_idx_val = HEAP32[$this + 8 >> 2];
  var $1 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5emptyEv($_idx_val);
  return $1;
}

function __ZN9JSContext7delete_IN2js8DebuggerEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js8DebuggerD2Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, $fnname) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx3_val = HEAP32[$args >> 2];
    var $1 = __ZNK2js12CallReceiver5thisvEv($_idx3_val);
    var $_idx1 = $1 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $2 = __ZNK2JS5Value8isObjectEv($_idx1_val$0, $_idx1_val$1);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z20ReportObjectRequiredP9JSContext($cx);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $5 = __ZNK2JS5Value8toObjectEv($_idx1_val$0, $_idx1_val$1);
    var $_idx4_val = HEAP32[$5 + 4 >> 2];
    var $6 = __ZNK8JSObject8getClassEv($_idx4_val);
    if (($6 | 0) == (__ZN2js8Debugger7jsclassE | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = HEAP32[$6 >> 2];
    _JS_ReportErrorNumber($cx, 4, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str2 | 0, HEAP32[tempInt + 4 >> 2] = $fnname, HEAP32[tempInt + 8 >> 2] = $10, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 5:
    var $_idx_val = HEAP32[$5 + 24 >> 2];
    var $12 = __ZN2js8Debugger12fromJSObjectEP8JSObject($_idx_val);
    if (($12 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $12;
      __label__ = 7;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 4, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str2 | 0, HEAP32[tempInt + 4 >> 2] = $fnname, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str11 | 0, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger10getEnabledEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str12 | 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$args >> 2];
    var $4 = __ZNK2js12CallReceiver4rvalEv($_idx_val);
    var $8 = (HEAP8[$1 + 40 | 0] & 1) << 24 >> 24 != 0;
    __ZN2JS5Value10setBooleanEb($4, $8);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14CallArgsFromVpEjPN2JS5ValueE($agg_result, $argc, $vp) {
  var $1 = $vp + 16 | 0;
  __ZN2js16CallArgsFromArgvEjPN2JS5ValueE($agg_result, $argc, $1);
  return;
}

function __ZN2JS5Value10setBooleanEb($this, $b) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $b & 1;
  _BOOLEAN_TO_JSVAL_IMPL($1, $2);
  var $3 = $1 | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  var $5 = $this | 0;
  HEAP32[$5 >> 2] = $4$0;
  HEAP32[$5 + 4 >> 2] = $4$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js8Debugger10setEnabledEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str13 | 0, 1);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 3:
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $4 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str14 | 0);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $args_idx_val = HEAPU32[$args >> 2];
    var $7 = __ZNK2js8CallArgsixEj($args_idx_val, 0);
    var $8 = __Z17js_ValueToBooleanRKN2JS5ValueE($7);
    var $9 = ($8 | 0) != 0;
    var $11 = $4 + 40 | 0;
    if (($9 & 1 | 0) == (HEAP8[$11] & 1 & 255 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = __ZNK2js8Debugger15firstBreakpointEv($4);
    if (($17 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $bp_01 = $17;
      __label__ = 6;
      break;
    }
   case 6:
    var $bp_01;
    var $20 = HEAP32[$bp_01 + 4 >> 2];
    if ($9) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2js14BreakpointSite3incEP9JSContext($20);
    __label__ = 9;
    break;
   case 8:
    __ZN2js14BreakpointSite3decEP9JSContext($20);
    __label__ = 9;
    break;
   case 9:
    var $bp_01_idx_val = HEAP32[$bp_01 >> 2];
    var $bp_01_idx1_val = HEAP32[$bp_01 + 12 >> 2];
    var $24 = __ZN2js10Breakpoint14nextInDebuggerEv($bp_01_idx_val, $bp_01_idx1_val);
    if (($24 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $bp_01 = $24;
      __label__ = 6;
      break;
    }
   case 10:
    HEAP8[$11] = $9 & 1;
    var $27 = __ZNK2js12CallReceiver4rvalEv($args_idx_val);
    __ZN2JS5Value12setUndefinedEv($27);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger11getHookImplEP9JSContextjPN2JS5ValueENS0_4HookE($cx, $argc, $vp, $which) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $2 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str15 | 0);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$args >> 2];
    var $5 = __ZNK2js12CallReceiver4rvalEv($_idx_val);
    var $7 = HEAP32[$2 + 8 >> 2];
    var $8 = $which + 3 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $7, $8);
    var $9 = $1 | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $5 | 0;
    var $st$13$0 = $11 | 0;
    HEAP32[$st$13$0 >> 2] = $10$0;
    var $st$13$1 = $11 + 4 | 0;
    HEAP32[$st$13$1 >> 2] = $10$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger11setHookImplEP9JSContextjPN2JS5ValueENS0_4HookE($cx, $argc, $vp, $which) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str16 | 0, 1);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 3:
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $4 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str17 | 0);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $args_idx_val = HEAP32[$args >> 2];
    var $7 = __ZNK2js8CallArgsixEj($args_idx_val, 0);
    var $_idx = $7 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $8 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $10 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $_idx3_val = HEAP32[$10 + 4 >> 2];
    var $11 = __ZN8JSObject10isCallableEv($_idx3_val);
    if ($11) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj($cx, $vp, 65536);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 7:
    var $14 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($14) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    _JS_ReportErrorNumber($cx, 4, 230, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 10;
    break;
   case 9:
    var $18 = HEAP32[$4 + 8 >> 2];
    var $19 = $which + 3 | 0;
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($18, $19, $_idx_val$0, $_idx_val$1);
    var $20 = __ZNK2js12CallReceiver4rvalEv($args_idx_val);
    __ZN2JS5Value12setUndefinedEv($20);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject10isCallableEv($this_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject10isFunctionEv($this_0_1_val);
    if ($1) {
      var $8 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject8getClassEv($this_0_1_val);
    var $8 = (HEAP32[$3 + 48 >> 2] | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger22getOnDebuggerStatementEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZN2js8Debugger11getHookImplEP9JSContextjPN2JS5ValueENS0_4HookE($cx, $argc, $vp, 0);
  return $1;
}

function __ZN2js8Debugger22setOnDebuggerStatementEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZN2js8Debugger11setHookImplEP9JSContextjPN2JS5ValueENS0_4HookE($cx, $argc, $vp, 0);
  return $1;
}

function __ZN2js8Debugger20getOnExceptionUnwindEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZN2js8Debugger11getHookImplEP9JSContextjPN2JS5ValueENS0_4HookE($cx, $argc, $vp, 1);
  return $1;
}

function __ZN2js8Debugger20setOnExceptionUnwindEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZN2js8Debugger11setHookImplEP9JSContextjPN2JS5ValueENS0_4HookE($cx, $argc, $vp, 1);
  return $1;
}

function __ZN2js8Debugger14getOnNewScriptEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZN2js8Debugger11getHookImplEP9JSContextjPN2JS5ValueENS0_4HookE($cx, $argc, $vp, 2);
  return $1;
}

function __ZN2js8Debugger14setOnNewScriptEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZN2js8Debugger11setHookImplEP9JSContextjPN2JS5ValueENS0_4HookE($cx, $argc, $vp, 2);
  return $1;
}

function __ZN2js8Debugger15getOnEnterFrameEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZN2js8Debugger11getHookImplEP9JSContextjPN2JS5ValueENS0_4HookE($cx, $argc, $vp, 3);
  return $1;
}

function __ZN2js8Debugger15setOnEnterFrameEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZN2js8Debugger11setHookImplEP9JSContextjPN2JS5ValueENS0_4HookE($cx, $argc, $vp, 3);
  return $1;
}

function __ZN2js8Debugger24getUncaughtExceptionHookEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str18 | 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$args >> 2];
    var $4 = __ZNK2js12CallReceiver4rvalEv($_idx_val);
    var $6 = HEAP32[$1 + 36 >> 2];
    __ZN2JS5Value15setObjectOrNullEP8JSObject($4, $6);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger24setUncaughtExceptionHookEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str19 | 0, 1);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 3:
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $4 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str20 | 0);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $args_idx4_val = HEAP32[$args >> 2];
    var $7 = __ZNK2js8CallArgsixEj($args_idx4_val, 0);
    var $_idx2 = $7 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    var $8 = __ZNK2JS5Value6isNullEv($_idx2_val$0, $_idx2_val$1);
    if ($8) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = __ZNK2JS5Value8isObjectEv($_idx2_val$0, $_idx2_val$1);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $12 = __ZNK2JS5Value8toObjectEv($_idx2_val$0, $_idx2_val$1);
    var $_idx3_val = HEAP32[$12 + 4 >> 2];
    var $13 = __ZN8JSObject10isCallableEv($_idx3_val);
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 4, 276, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str21 | 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 8:
    var $16 = __ZNK2JS5Value14toObjectOrNullEv($_idx2_val$0, $_idx2_val$1);
    HEAP32[$4 + 36 >> 2] = $16;
    var $18 = __ZNK2js12CallReceiver4rvalEv($args_idx4_val);
    __ZN2JS5Value12setUndefinedEv($18);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger22unwrapDebuggeeArgumentEP9JSContextRKN2JS5ValueE($this, $cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $rv = __stackBase__;
    var $1 = $cx;
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $2 = __ZN2js13NonNullObjectEP9JSContextRKN2JS5ValueE($1, $v_idx_val$0, $v_idx_val$1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = $3;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$2 + 4 >> 2];
    var $7 = __ZNK8JSObject8getClassEv($_idx1_val);
    if (($7 | 0) == (_DebuggerObject_class | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $st$0$0 = $v_idx | 0;
    var $10$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $v_idx + 4 | 0;
    var $10$1 = HEAP32[$st$0$1 >> 2];
    var $11 = $rv | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZN2js8Debugger19unwrapDebuggeeValueEP9JSContextPN2JS5ValueE($this, $cx, $rv);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 4:
    var $st$0$0 = $11 | 0;
    var $rv_idx_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $11 + 4 | 0;
    var $rv_idx_val$1 = HEAP32[$st$0$1 >> 2];
    var $14 = __ZNK2JS5Value8toObjectEv($rv_idx_val$0, $rv_idx_val$1);
    var $_0 = $14;
    __label__ = 7;
    break;
   case 5:
    var $16 = __ZNK8JSObject25isCrossCompartmentWrapperEv($3);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $3;
      __label__ = 7;
      break;
    }
   case 6:
    var $18 = __ZNK8JSObject15getProxyPrivateEv($3);
    var $_idx = $18 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $19 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $_0 = $19;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject15getProxyPrivateEv($this) {
  var $1 = __ZNK8JSObject7getSlotEj($this, 1);
  return $1;
}

function __ZN2js8Debugger11addDebuggeeEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $v = __stackBase__ + 8;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str22 | 0, 1);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 3:
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $4 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str23 | 0);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $args_idx_val = HEAP32[$args >> 2];
    var $7 = __ZNK2js8CallArgsixEj($args_idx_val, 0);
    var $8 = __ZN2js8Debugger22unwrapDebuggeeArgumentEP9JSContextRKN2JS5ValueE($4, $cx, $7);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = $8;
    var $12 = __ZNK8JSObject9getGlobalEv($11);
    var $13 = $12;
    var $14 = __ZN2js8Debugger17addDebuggeeGlobalEP9JSContextPNS_12GlobalObjectE($4, $cx, $13);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    __ZN2JSL11ObjectValueER8JSObject($v, $8);
    var $16 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($4, $cx, $v);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $18 = __ZNK2js12CallReceiver4rvalEv($args_idx_val);
    var $19 = $v | 0;
    var $20$0 = HEAP32[$19 >> 2];
    var $20$1 = HEAP32[$19 + 4 >> 2];
    var $21 = $18 | 0;
    var $st$7$0 = $21 | 0;
    HEAP32[$st$7$0 >> 2] = $20$0;
    var $st$7$1 = $21 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $20$1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger17addDebuggeeGlobalEP9JSContextPNS_12GlobalObjectE($this, $cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 96;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $visited = __stackBase__ + 4;
    var $2 = __stackBase__ + 28;
    var $r = __stackBase__ + 32;
    var $next = __stackBase__ + 40;
    var $ac = __stackBase__ + 44;
    HEAP32[$1 >> 2] = $global;
    var $3 = $this + 12 | 0;
    var $4 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3hasERKS2_($3, $1);
    if ($4) {
      var $_2 = 1;
      __label__ = 32;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAPU32[$1 >> 2];
    var $7 = $6;
    var $8 = __ZNK2js2gc4Cell11compartmentEv($7);
    __ZN2js15TempAllocPolicyC1EP9JSContext($2, $cx);
    var $_06_val = HEAP32[$2 >> 2];
    __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEC1ES3_($visited, $_06_val);
    var $11 = HEAP32[$this + 8 >> 2];
    var $12 = __ZNK2js2gc4Cell11compartmentEv($11);
    var $13 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($visited, $12);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 0;
      __label__ = 31;
      break;
    }
   case 3:
    var $visited_idx = $visited + 8 | 0;
    var $visited_idx7 = $visited + 4 | 0;
    var $r_idx = $r | 0;
    var $r_idx1 = $r + 4 | 0;
    var $i_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_0;
    var $visited_idx_val = HEAP32[$visited_idx >> 2];
    var $14 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE6lengthEv($visited_idx_val);
    if ($i_0 >>> 0 < $14 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 5:
    var $visited_idx7_val = HEAP32[$visited_idx7 >> 2];
    var $17 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEixEj($visited_idx7_val, $i_0);
    var $18 = HEAPU32[$17 >> 2];
    if (($18 | 0) == ($8 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 4, 280, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 31;
    break;
   case 7:
    var $22 = __ZN13JSCompartment12getDebuggeesEv($18);
    __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3allEv($r, $22);
    __label__ = 8;
    break;
   case 8:
    var $r_idx_val = HEAP32[$r_idx >> 2];
    var $r_idx1_val = HEAP32[$r_idx1 >> 2];
    var $24 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r_idx_val, $r_idx1_val);
    if ($24) {
      __label__ = 16;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $26 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($r_idx_val);
    var $28 = HEAP32[$26 >> 2];
    var $29 = __ZN2js12GlobalObject12getDebuggersEv($28);
    var $_idx = $29 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $30 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5beginEv($_idx_val);
    var $_idx4 = $29 + 4 | 0;
    var $p_0 = $30;
    var $_idx3_val = $_idx_val;
    __label__ = 10;
    break;
   case 10:
    var $_idx3_val;
    var $p_0;
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $32 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($_idx3_val, $_idx4_val);
    if (($p_0 | 0) == ($32 | 0)) {
      __label__ = 15;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $38 = HEAP32[HEAP32[$p_0 >> 2] + 8 >> 2];
    var $39 = __ZNK2js2gc4Cell11compartmentEv($38);
    HEAP32[$next >> 2] = $39;
    var $visited_idx10_val = HEAP32[$visited_idx7 >> 2];
    var $visited_idx11_val = HEAP32[$visited_idx >> 2];
    var $40 = __ZN2jsL4FindINS_6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEEEEPNT_11ElementTypeERS6_RKS7_($visited_idx10_val, $visited_idx11_val, $next);
    var $41 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE3endEv($visited_idx10_val, $visited_idx11_val);
    if (($40 | 0) == ($41 | 0)) {
      __label__ = 12;
      break;
    } else {
      var $_idx3_val_pre = $_idx3_val;
      __label__ = 14;
      break;
    }
   case 12:
    var $44 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($visited, $39);
    if ($44) {
      __label__ = 13;
      break;
    } else {
      var $_1 = 0;
      __label__ = 31;
      break;
    }
   case 13:
    var $_idx3_val_pre = HEAP32[$_idx >> 2];
    __label__ = 14;
    break;
   case 14:
    var $_idx3_val_pre;
    var $p_0 = $p_0 + 4 | 0;
    var $_idx3_val = $_idx3_val_pre;
    __label__ = 10;
    break;
   case 15:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($r);
    __label__ = 8;
    break;
   case 16:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 4;
    break;
   case 17:
    var $_idx5_val = HEAP32[$8 + 804 >> 2];
    var $51 = __ZNK13JSCompartment9debugModeEv($_idx5_val);
    if ($51) {
      __label__ = 20;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $53 = __ZN13JSCompartment17hasScriptsOnStackEP9JSContext($8, $cx);
    if ($53) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    _JS_ReportErrorNumber($cx, 4, 281, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 31;
    break;
   case 20:
    var $56 = $6 | 0;
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $56);
    var $57 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($57) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 0;
      __label__ = 30;
      break;
    }
   case 21:
    var $59 = $6;
    var $60 = $cx;
    var $61 = __ZN2js12GlobalObject20getOrCreateDebuggersEP9JSContext($59, $60);
    if (($61 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $64 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE6appendIS2_EEbT_($61, $this);
    if ($64) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 30;
    break;
   case 24:
    var $67 = __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3putERKS2_($3, $1);
    if (($67 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    __label__ = 29;
    break;
   case 26:
    var $71 = HEAPU32[$1 >> 2];
    var $72 = $71;
    var $73 = __ZN2js12GlobalObject12getDebuggersEv($72);
    var $_idx12_val = HEAP32[$73 + 4 >> 2];
    var $74 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE6lengthEv($_idx12_val);
    if ($74 >>> 0 > 1) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $77 = __ZN13JSCompartment11addDebuggeeEP9JSContextPN2js12GlobalObjectE($8, $cx, $71);
    if ($77) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeERKS2_($3, $1);
    __label__ = 29;
    break;
   case 29:
    __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE7popBackEv($61);
    var $_0 = 0;
    __label__ = 30;
    break;
   case 30:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_1 = $_0;
    __label__ = 31;
    break;
   case 31:
    var $_1;
    __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEED1Ev($visited);
    var $_2 = $_1;
    __label__ = 32;
    break;
   case 32:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger17addDebuggeeGlobalEP9JSContextPNS_12GlobalObjectE["X"] = 1;

function __ZNK2js12ContextStack5spaceEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js13AllFramesIter2fpEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE6lengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE6lengthEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js13AllFramesIter4doneEv($this_0_1_val) {
  return ($this_0_1_val | 0) == 0;
}

function __ZNK13JSCompartment9debugModeEv($this_0_28_val) {
  return ($this_0_28_val | 0) != 0;
}

function __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($this_0_8_val, $idx, $val_0_0_0_val$0, $val_0_0_0_val$1) {
  var $1 = $this_0_8_val + ($idx << 3) | 0;
  HEAP32[$1 >> 2] = $val_0_0_0_val$0;
  HEAP32[$1 + 4 >> 2] = $val_0_0_0_val$1;
  return;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE7popBackEv($this) {
  var $1 = $this + 4 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK10JSFunction6scriptEv($this) {
  return HEAP32[$this + 60 >> 2];
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN2js8Debugger14removeDebuggeeEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $global = __stackBase__ + 8;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str24 | 0, 1);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 3:
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $4 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str25 | 0);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $args_idx_val = HEAP32[$args >> 2];
    var $7 = __ZNK2js8CallArgsixEj($args_idx_val, 0);
    var $8 = __ZN2js8Debugger22unwrapDebuggeeArgumentEP9JSContextRKN2JS5ValueE($4, $cx, $7);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = $8;
    var $12 = __ZNK8JSObject9getGlobalEv($11);
    var $13 = $12;
    HEAP32[$global >> 2] = $13;
    var $14 = $4 + 12 | 0;
    var $15 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3hasERKS2_($14, $global);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $17 = HEAP32[$global >> 2];
    __ZN2js8Debugger20removeDebuggeeGlobalEP9JSContextPNS_12GlobalObjectEPNS_6detail9HashTableIKS4_NS_7HashSetIS4_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE6SetOpsESB_E4EnumESG_($4, $cx, $17, 0, 0);
    __label__ = 7;
    break;
   case 7:
    var $19 = __ZNK2js12CallReceiver4rvalEv($args_idx_val);
    __ZN2JS5Value12setUndefinedEv($19);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger11hasDebuggeeEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 12;
    var $3 = __stackBase__ + 16;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str26 | 0, 1);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 3:
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $7 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str27 | 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $args_idx_val = HEAP32[$args >> 2];
    var $10 = __ZNK2js8CallArgsixEj($args_idx_val, 0);
    var $11 = __ZN2js8Debugger22unwrapDebuggeeArgumentEP9JSContextRKN2JS5ValueE($7, $cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = __ZNK2js12CallReceiver4rvalEv($args_idx_val);
    var $15 = $7 + 12 | 0;
    var $16 = $11;
    var $17 = __ZNK8JSObject9getGlobalEv($16);
    var $18 = $17;
    HEAP32[$1 >> 2] = $18;
    __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6lookupERKS2_($2, $15, $1);
    var $_idx_val_idx_val = HEAP32[HEAP32[$2 >> 2] >> 2];
    __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($3, $_idx_val_idx_val);
    var $21 = (HEAP32[$3 >> 2] | 0) != 0;
    __ZN2JS5Value10setBooleanEb($14, $21);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger12getDebuggeesEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $e = __stackBase__ + 8;
    var $v = __stackBase__ + 24;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str28 | 0);
    if (($1 | 0) == 0) {
      var $_1 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1 + 12 | 0;
    var $5 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5countEv($4);
    var $6 = __ZN2js22NewDenseAllocatedArrayEP9JSContextjP8JSObject($cx, $5);
    if (($6 | 0) == 0) {
      var $_1 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5countEv($4);
    __ZN8JSObject33ensureDenseArrayInitializedLengthEP9JSContextjj($6, $cx, 0, $9);
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC1IS9_EERT_($e, $4);
    var $10 = $e | 0;
    var $_idx = $e | 0;
    var $_idx1 = $e + 4 | 0;
    var $_idx4 = $6 + 32 | 0;
    var $v_idx = $v | 0;
    var $i_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $12 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($_idx_val, $_idx1_val);
    if ($12) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($_idx_val);
    var $16 = HEAP32[$14 >> 2] | 0;
    __ZN2JSL11ObjectValueER8JSObject($v, $16);
    var $17 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($1, $cx, $v);
    if ($17) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $19 = $i_0 + 1 | 0;
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($_idx4_val, $i_0, $v_idx_val$0, $v_idx_val$1);
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($10);
    var $i_0 = $19;
    __label__ = 4;
    break;
   case 7:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD1Ev($e);
    var $_1 = 0;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD1Ev($e);
    var $_idx3_val = HEAP32[$args >> 2];
    var $21 = __ZNK2js12CallReceiver4rvalEv($_idx3_val);
    __ZN2JS5Value9setObjectER8JSObject($21, $6);
    var $_1 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger12getDebuggeesEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5countEv($this) {
  var $_idx_val = HEAP32[$this + 8 >> 2];
  var $1 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5countEv($_idx_val);
  return $1;
}

function __ZN8JSObject33ensureDenseArrayInitializedLengthEP9JSContextjj($this, $cx, $index, $extra) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 16 | 0;
    var $2 = $1;
    var $3 = HEAPU32[$2 >> 2];
    if ($3 >>> 0 < $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $12 = $3;
      __label__ = 3;
      break;
    }
   case 2:
    __ZN8JSObject23markDenseArrayNotPackedEP9JSContext($this, $cx);
    var $8 = HEAP32[$2 >> 2];
    var $9 = HEAP32[$this + 32 >> 2] + ($8 << 3) | 0;
    var $10 = $index - $8 | 0;
    __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2($9, $10);
    var $12 = HEAP32[$2 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $12;
    var $13 = $extra + $index | 0;
    if ($12 >>> 0 < $13 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$1 >> 2] = $13;
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger14getNewestFrameEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $i = __stackBase__ + 8;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str29 | 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$cx + 64 >> 2];
    var $4 = __ZNK2js12ContextStack5spaceEv($_idx_val);
    var $5 = $i;
    var $_idx2_val = HEAP32[$4 >> 2];
    __ZN2js13AllFramesIterC2ERNS_10StackSpaceE($5, $_idx2_val);
    var $i_idx = $i + 4 | 0;
    __label__ = 3;
    break;
   case 3:
    var $i_idx_val = HEAP32[$i_idx >> 2];
    var $7 = __ZNK2js13AllFramesIter4doneEv($i_idx_val);
    if ($7) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZNK2js13AllFramesIter2fpEv($i_idx_val);
    var $10 = __ZNK2js8Debugger13observesFrameEPNS_10StackFrameE($1, $9);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $12 = __ZN2js8Debugger14getScriptFrameEP9JSContextPNS_10StackFrameEPN2JS5ValueE($1, $cx, $9, $vp);
    var $_0 = $12 & 1;
    __label__ = 8;
    break;
   case 6:
    __ZN2js13AllFramesIterppEv($5);
    __label__ = 3;
    break;
   case 7:
    var $_idx1_val = HEAP32[$args >> 2];
    var $16 = __ZNK2js12CallReceiver4rvalEv($_idx1_val);
    __ZN2JS5Value7setNullEv($16);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js8Debugger13observesFrameEPNS_10StackFrameE($this, $fp) {
  var $1 = __ZNK2js10StackFrame10scopeChainEv($fp);
  var $2 = __ZNK2js8Debugger13observesScopeEP8JSObject($this, $1);
  return $2;
}

function __ZN2js8Debugger19clearAllBreakpointsEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $r = __stackBase__ + 8;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str30 | 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1 + 12 | 0;
    __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3allEv($r, $4);
    var $r_idx2 = $r | 0;
    var $r_idx2_val = HEAP32[$r_idx2 >> 2];
    var $r_idx3 = $r + 4 | 0;
    var $r_idx3_val = HEAP32[$r_idx3 >> 2];
    var $5 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r_idx2_val, $r_idx3_val);
    if ($5) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      var $r_idx4_val = $r_idx2_val;
      __label__ = 3;
      break;
    }
   case 3:
    var $r_idx4_val;
    var $6 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($r_idx4_val);
    var $8 = HEAP32[$6 >> 2];
    var $9 = __ZNK2js2gc4Cell11compartmentEv($8);
    __ZN13JSCompartment18clearBreakpointsInEP9JSContextPN2js8DebuggerEP8JSScriptP8JSObject($9, $1, 0, 0);
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($r);
    var $r_idx_val = HEAP32[$r_idx2 >> 2];
    var $r_idx1_val = HEAP32[$r_idx3 >> 2];
    var $10 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r_idx_val, $r_idx1_val);
    if ($10) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      var $r_idx4_val = $r_idx_val;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger9constructEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $v = __stackBase__ + 8;
    var $1 = __stackBase__ + 16;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $args_idx5_val = HEAPU32[$args >> 2];
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if ($i_0 >>> 0 < $argc >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    var $5 = __ZNK2js8CallArgsixEj($args_idx5_val, $i_0);
    var $_idx = $5 | 0;
    var $st$2$0 = $_idx | 0;
    var $_idx_val$0 = HEAPU32[$st$2$0 >> 2];
    var $st$2$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAP32[$st$2$1 >> 2];
    var $6 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __Z20ReportObjectRequiredP9JSContext($cx);
    var $_0 = 0;
    __label__ = 18;
    break;
   case 5:
    var $9 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $10 = __ZNK8JSObject25isCrossCompartmentWrapperEv($9);
    if ($10) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 4, 274, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str2 | 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 8:
    var $15 = __ZNK2js12CallReceiver6calleeEv($args_idx5_val);
    var $19 = HEAP32[HEAP32[$cx + 52 >> 2] + 210200 >> 2];
    var $20 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($15, $cx, $19, $v);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $23 = __ZNK2JS5Value8toObjectEv($v_idx_val$0, $v_idx_val$1);
    var $24 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, __ZN2js8Debugger7jsclassE, $23, 0);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $27 = __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($24, $cx);
    if ($27) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 11:
    __ZNK8JSObject15getReservedSlotEj($1, $23, 0);
    var $_idx8 = $1 | 0;
    var $st$2$0 = $_idx8 | 0;
    var $_idx8_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx8 + 4 | 0;
    var $_idx8_val$1 = HEAP32[$st$2$1 >> 2];
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($24, 0, $_idx8_val$0, $_idx8_val$1);
    __ZNK8JSObject15getReservedSlotEj($1, $23, 1);
    var $_idx7_val$0 = HEAP32[$_idx8 >> 2];
    var $_idx7_val$1 = HEAP32[$_idx8 + 4 >> 2];
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($24, 1, $_idx7_val$0, $_idx7_val$1);
    __ZNK8JSObject15getReservedSlotEj($1, $23, 2);
    var $_idx6_val$0 = HEAP32[$_idx8 >> 2];
    var $_idx6_val$1 = HEAP32[$_idx8 + 4 >> 2];
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($24, 2, $_idx6_val$0, $_idx6_val$1);
    var $28 = __ZN9JSContext4new_IN2js8DebuggerEPS_P8JSObjectEEPT_T0_T1_($cx, $cx, $24);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $31 = $28;
    __ZN8JSObject10setPrivateEPv($24, $31);
    var $32 = __ZN2js8Debugger4initEP9JSContext($28, $cx);
    if ($32) {
      var $i1_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    __ZN9JSContext7delete_IN2js8DebuggerEEEvPT_($28);
    var $_0 = 0;
    __label__ = 18;
    break;
   case 14:
    var $i1_0;
    if ($i1_0 >>> 0 < $argc >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $36 = __ZNK2js8CallArgsixEj($args_idx5_val, $i1_0);
    var $_idx2 = $36 | 0;
    var $st$2$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$2$1 >> 2];
    var $37 = __ZNK2JS5Value8toObjectEv($_idx2_val$0, $_idx2_val$1);
    var $38 = __ZNK8JSObject15getProxyPrivateEv($37);
    var $_idx1 = $38 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $39 = __ZNK2JS5Value8toObjectEv($_idx1_val$0, $_idx1_val$1);
    var $40 = $39;
    var $41 = __ZNK8JSObject9getGlobalEv($40);
    var $42 = $41;
    var $43 = __ZN2js8Debugger17addDebuggeeGlobalEP9JSContextPNS_12GlobalObjectE($28, $cx, $42);
    if ($43) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 16:
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 14;
    break;
   case 17:
    var $47 = __ZNK2js12CallReceiver4rvalEv($args_idx5_val);
    __ZN2JS5Value9setObjectER8JSObject($47, $24);
    var $_0 = 1;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger9constructEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZNK2js12CallReceiver6calleeEv($this_0_0_val) {
  var $_idx = $this_0_0_val - 16 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $1 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
  return $1;
}

function __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($this, $cx, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom($1);
  var $3 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($this, $cx, $2, $vp);
  return $3;
}

function __ZN9JSContext4new_IN2js8DebuggerEPS_P8JSObjectEEPT_T0_T1_($this, $p1, $p2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 180);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js8DebuggerC2EP9JSContextP8JSObject($4, $p1, $p2);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEC1ES3_($this, $ap_01) {
  __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap_01);
  return;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE13growStorageByEj($this);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEixEj($this_0_1_val, $i) {
  var $1 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE5beginEv($this_0_1_val);
  return $1 + ($i << 2) | 0;
}

function __ZN2jsL4FindINS_6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEEEEPNT_11ElementTypeERS6_RKS7_($c_0_1_val, $c_0_2_val, $v) {
  var $1 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE5beginEv($c_0_1_val);
  var $2 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE3endEv($c_0_1_val, $c_0_2_val);
  var $3 = __ZN2jsL4FindIP13JSCompartmentEEPT_S4_S4_RKS3_($1, $2, $v);
  return $3;
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 4 >> 2] | 0) == (HEAP32[$this + 8 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE13growStorageByEj($this);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3putERKS2_($this, $t) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE12lookupForAddERKS2_($p, $this, $t);
    var $_idx = $p | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $_idx_val_idx_val = HEAP32[$_idx_val >> 2];
    __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($1, $_idx_val_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrdeEv($_idx_val);
    var $12 = $6;
    __label__ = 5;
    break;
   case 3:
    var $8 = __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS6_6SetOpsES5_E6AddPtrERS9_($this, $p, $t);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $12 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx1_val = HEAP32[$_idx >> 2];
    var $10 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrdeEv($_idx1_val);
    var $12 = $10;
    __label__ = 5;
    break;
   case 5:
    var $12;
    STACKTOP = __stackBase__;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeERKS2_($this, $l) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 4;
    __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6lookupERKS2_($p, $this, $l);
    var $p_idx_val = HEAP32[$p >> 2];
    var $p_idx_val_idx_val = HEAP32[$p_idx_val >> 2];
    __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($1, $p_idx_val_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS6_6SetOpsES5_E3PtrE($this, $p_idx_val);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC1ISC_EERT_($this, $map) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC2ISC_EERT_($this, $map);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD2Ev($this);
  return;
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5eraseEPS2_($this, $it) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $it + 4 | 0;
    var $this_idx2 = $this | 0;
    var $this_idx2_val = HEAP32[$this_idx2 >> 2];
    var $this_idx3 = $this + 4 | 0;
    var $this_idx3_val = HEAP32[$this_idx3 >> 2];
    var $2 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($this_idx2_val, $this_idx3_val);
    if (($1 | 0) == ($2 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $_01 = $it;
      var $4 = $1;
      __label__ = 2;
      break;
    }
   case 2:
    var $4;
    var $_01;
    var $5 = HEAP32[$4 >> 2];
    HEAP32[$_01 >> 2] = $5;
    var $6 = $4 + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx2 >> 2];
    var $this_idx1_val = HEAP32[$this_idx3 >> 2];
    var $7 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($this_idx_val, $this_idx1_val);
    if (($6 | 0) == ($7 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $_01 = $4;
      var $4 = $6;
      __label__ = 2;
      break;
    }
   case 3:
    __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE7popBackEv($this);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS4_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZL20DebuggerScript_traceP8JSTracerP8JSObject($trc, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    if ((HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    __ZNK8JSObject15getReservedSlotEj($v, $obj, 1);
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $9 = __ZNK2JS5Value11isUndefinedEv($v_idx_val$0, $v_idx_val$1);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2JS5Value9toPrivateEv($v_idx_val$0, $v_idx_val$1);
    if (($11 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $11;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $14);
    __label__ = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger17newDebuggerScriptEP9JSContextP8JSScriptP8JSObject($this, $cx, $script, $holder) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = $this + 8 | 0;
    var $5 = HEAP32[$4 >> 2];
    __ZNK8JSObject15getReservedSlotEj($1, $5, 2);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $6 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $7 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, _DebuggerScript_class, $6, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($7, $cx);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = $script;
    __ZN8JSObject10setPrivateEPv($7, $12);
    var $13 = HEAP32[$4 >> 2];
    __ZN2JSL11ObjectValueER8JSObject($2, $13);
    var $_idx2 = $2 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($7, 0, $_idx2_val$0, $_idx2_val$1);
    var $14 = $holder;
    __ZN2JSL12PrivateValueEPv($3, $14);
    var $_idx1 = $3 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($7, 1, $_idx1_val$0, $_idx1_val$1);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL12PrivateValueEPv($agg_result, $ptr) {
  __ZN2JS5Value10setPrivateEPv($agg_result, $ptr);
  return;
}

function __ZN2js8Debugger18wrapFunctionScriptEP9JSContextP10JSFunction($this, $cx, $fun) {
  var $1 = __ZNK10JSFunction6scriptEv($fun);
  var $2 = $fun | 0;
  var $3 = __ZN2js8Debugger14wrapHeldScriptEP9JSContextP8JSScriptP8JSObject($this, $cx, $1, $2);
  return $3;
}

function __ZN2js8Debugger15wrapJSAPIScriptEP9JSContextP8JSObject($this, $cx, $obj) {
  var $obj_idx_val = HEAP32[$obj + 24 >> 2];
  var $1 = __ZNK8JSObject9getScriptEv($obj_idx_val);
  var $2 = __ZN2js8Debugger14wrapHeldScriptEP9JSContextP8JSScriptP8JSObject($this, $cx, $1, $obj);
  return $2;
}

function __ZNK8JSObject9getScriptEv($this_0_6_val) {
  var $1 = __ZNK8JSObject10getPrivateEv($this_0_6_val);
  return $1;
}

function __ZNK2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 16,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13relookupOrAddERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $k_val = HEAP32[$k >> 2];
  __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC1ERKS2_RKS4_($1, $k_val, $v);
  var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13relookupOrAddERNSE_6AddPtrERKS4_RKS7_($2, $p, $k, $1);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN2js8Debugger23slowPathOnDestroyScriptEP8JSScript($script) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $script;
    var $2 = __ZNK2js2gc4Cell11compartmentEv($1);
    var $3 = __ZN13JSCompartment12getDebuggeesEv($2);
    __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3allEv($r, $3);
    var $r_idx2 = $r | 0;
    var $r_idx2_val = HEAP32[$r_idx2 >> 2];
    var $r_idx3 = $r + 4 | 0;
    var $r_idx3_val = HEAP32[$r_idx3 >> 2];
    var $4 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r_idx2_val, $r_idx3_val);
    if ($4) {
      __label__ = 5;
      break;
    } else {
      var $r_idx4_val = $r_idx2_val;
      __label__ = 2;
      break;
    }
   case 2:
    var $r_idx4_val;
    var $5 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($r_idx4_val);
    var $7 = HEAP32[$5 >> 2];
    var $8 = __ZN2js12GlobalObject12getDebuggersEv($7);
    var $_idx = $8 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $9 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5beginEv($_idx_val);
    var $_idx8 = $8 + 4 | 0;
    var $_idx8_val = HEAP32[$_idx8 >> 2];
    var $10 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($_idx_val, $_idx8_val);
    if (($9 | 0) == ($10 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $p_01 = $9;
      __label__ = 3;
      break;
    }
   case 3:
    var $p_01;
    var $12 = HEAP32[$p_01 >> 2];
    __ZN2js8Debugger20destroyNonHeldScriptEP8JSScript($12, $script);
    var $13 = $p_01 + 4 | 0;
    var $_idx5_val = HEAP32[$_idx >> 2];
    var $_idx6_val = HEAP32[$_idx8 >> 2];
    var $14 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($_idx5_val, $_idx6_val);
    if (($13 | 0) == ($14 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $p_01 = $13;
      __label__ = 3;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($r);
    var $r_idx_val = HEAP32[$r_idx2 >> 2];
    var $r_idx1_val = HEAP32[$r_idx3 >> 2];
    var $16 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r_idx_val, $r_idx1_val);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      var $r_idx4_val = $r_idx_val;
      __label__ = 2;
      break;
    }
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger20destroyNonHeldScriptEP8JSScript($this, $script) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 8;
    HEAP32[$1 >> 2] = $script;
    var $3 = $this + 152 | 0;
    __ZNK2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_($p, $3, $1);
    var $p_idx_val = HEAP32[$p >> 2];
    var $p_idx_val_idx_val = HEAP32[$p_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($2, $p_idx_val_idx_val);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($p_idx_val);
    var $10 = HEAP32[$8 + 4 >> 2];
    __ZL19ClearScriptReferentP8JSObject($10);
    __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE($3, $p_idx_val);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $1, $l);
  return;
}

function __ZL19ClearScriptReferentP8JSObject($obj) {
  __ZN8JSObject10setPrivateEPv($obj, 0);
  return;
}

function __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE($this, $p_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE($1, $p_0);
  return;
}

function __ZL21DebuggerScript_getUrlP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str120 | 0, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    var $4 = __ZL17GetScriptReferentP8JSObject($_idx1_val);
    var $6 = HEAP32[$4 + 52 >> 2];
    var $7 = $cx;
    var $8 = __Z17js_NewStringCopyZP9JSContextPKc($7, $6);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = $8 | 0;
    var $_idx_val = HEAP32[$args >> 2];
    var $12 = __ZNK2js12CallReceiver4rvalEv($_idx_val);
    __ZN2JS5Value9setStringEP8JSString($12, $11);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL27DebuggerScript_getStartLineP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str119 | 0, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    var $4 = __ZL17GetScriptReferentP8JSObject($_idx1_val);
    var $_idx_val = HEAP32[$args >> 2];
    var $5 = __ZNK2js12CallReceiver4rvalEv($_idx_val);
    var $7 = HEAP32[$4 + 28 >> 2];
    var $8 = __ZN2JS5Value9setNumberEj($5, $7);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL27DebuggerScript_getLineCountP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str118 | 0, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    var $4 = __ZL17GetScriptReferentP8JSObject($_idx1_val);
    var $5 = $4;
    var $6 = __Z22js_GetScriptLineExtentP8JSScript($5);
    var $_idx_val = HEAP32[$args >> 2];
    var $7 = __ZNK2js12CallReceiver4rvalEv($_idx_val);
    var $8 = $6 >>> 0;
    var $9 = __ZN2JS5Value9setNumberEd($7, $8);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL22DebuggerScript_getLiveP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str107 | 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    var $4 = __ZL17GetScriptReferentP8JSObject($_idx1_val);
    var $_idx_val = HEAP32[$args >> 2];
    var $5 = __ZNK2js12CallReceiver4rvalEv($_idx_val);
    var $6 = ($4 | 0) != 0;
    __ZN2JS5Value10setBooleanEb($5, $6);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL30DebuggerScript_getChildScriptsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $2 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str107 | 0, 1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx4_val = HEAP32[$2 + 24 >> 2];
    var $5 = __ZL17GetScriptReferentP8JSObject($_idx4_val);
    var $6 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($2);
    var $7 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($cx);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = HEAP8[$5 + 16 | 0];
    var $12 = __ZN8JSScript13isValidOffsetEh($11);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 4:
    var $_idx1_val = HEAP32[$5 + 4 >> 2];
    var $14 = __ZN8JSScript7objectsEv($_idx1_val, $11);
    var $20 = $14 + 4 | 0;
    var $21 = $14 | 0;
    var $i_0 = (HEAPU8[$5 + 36 | 0] & 255) >>> 1 & 1 & 255;
    __label__ = 5;
    break;
   case 5:
    var $i_0;
    if ($i_0 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $28 = HEAPU32[HEAP32[$21 >> 2] + ($i_0 << 2) >> 2];
    var $_idx_val = HEAP32[$28 + 4 >> 2];
    var $29 = __ZNK8JSObject10isFunctionEv($_idx_val);
    if ($29) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $31 = $28;
    var $32 = __ZN2js8Debugger18wrapFunctionScriptEP9JSContextP10JSFunction($6, $cx, $31);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2JSL11ObjectValueER8JSObject($1, $32);
    var $35 = __Z19js_NewbornArrayPushP9JSContextP8JSObjectRKN2JS5ValueE($cx, $7, $1);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 5;
    break;
   case 10:
    var $_idx3_val = HEAP32[$args >> 2];
    var $39 = __ZNK2js12CallReceiver4rvalEv($_idx3_val);
    __ZN2JS5Value9setObjectER8JSObject($39, $7);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL30DebuggerScript_getChildScriptsP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL28DebuggerScript_getAllOffsetsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 96;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $flowData = __stackBase__ + 8;
    var $r = __stackBase__ + 32;
    var $offsetsv = __stackBase__ + 60;
    var $id = __stackBase__ + 68;
    var $1 = __stackBase__ + 72;
    var $2 = __stackBase__ + 80;
    var $3 = __stackBase__ + 88;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $4 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str42 | 0, 1);
    if (($4 | 0) == 0) {
      var $_1 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx3_val = HEAP32[$4 + 24 >> 2];
    var $7 = __ZL17GetScriptReferentP8JSObject($_idx3_val);
    __ZN16FlowGraphSummaryC1EP9JSContext($flowData, $cx);
    var $8 = __ZN16FlowGraphSummary8populateEP9JSContextP8JSScript($flowData, $cx, $7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 3:
    var $10 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($cx);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN28BytecodeRangeWithLineNumbersC1EP9JSContextP8JSScript($r, $cx, $7);
    var $_idx4 = $r + 8 | 0;
    var $_idx5 = $r + 12 | 0;
    var $_idx6 = $r + 4 | 0;
    var $r_idx = $r + 16 | 0;
    var $_idx = $flowData + 4 | 0;
    var $offsetsv_idx = $offsetsv | 0;
    __label__ = 5;
    break;
   case 5:
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $_idx5_val = HEAP32[$_idx5 >> 2];
    var $14 = __ZNK2js13BytecodeRange5emptyEv($_idx4_val, $_idx5_val);
    if ($14) {
      __label__ = 15;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx6_val_idx_val = HEAP32[HEAP32[$_idx6 >> 2] >> 2];
    var $16 = __ZNK2js13BytecodeRange11frontOffsetEv($_idx6_val_idx_val, $_idx4_val);
    var $r_idx_val = HEAP32[$r_idx >> 2];
    var $17 = __ZNK28BytecodeRangeWithLineNumbers15frontLineNumberEv($r_idx_val);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $18 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEixEj($_idx_val, $16);
    var $19 = HEAP32[$18 >> 2];
    if (($19 | 0) == -1 | ($19 | 0) == ($17 | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = __ZN8JSObject22arrayGetOwnDataElementEP9JSContextjPN2JS5ValueE($10, $cx, $17, $offsetsv);
    if ($23) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 8:
    var $offsetsv_idx_val$0 = HEAP32[$offsetsv_idx >> 2];
    var $offsetsv_idx_val$1 = HEAP32[$offsetsv_idx + 4 >> 2];
    var $25 = __ZNK2JS5Value8isObjectEv($offsetsv_idx_val$0, $offsetsv_idx_val$1);
    if ($25) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = __ZNK2JS5Value8toObjectEv($offsetsv_idx_val$0, $offsetsv_idx_val$1);
    var $offsets_0 = $27;
    __label__ = 13;
    break;
   case 10:
    var $29 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($cx);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $32 = $17 >>> 0;
    __ZN2JSL11NumberValueEd($1, $32);
    var $33 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($cx, $1, $id);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 12:
    var $35 = HEAP32[$id >> 2];
    __ZN2JSL11ObjectValueER8JSObject($2, $29);
    var $36 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($10, $cx, $35, $2, 10, 12, 1);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      var $offsets_0 = $29;
      __label__ = 13;
      break;
    }
   case 13:
    var $offsets_0;
    var $39 = $16 >>> 0;
    __ZN2JSL11NumberValueEd($3, $39);
    var $40 = __Z19js_NewbornArrayPushP9JSContextP8JSObjectRKN2JS5ValueE($cx, $offsets_0, $3);
    if (($40 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZN28BytecodeRangeWithLineNumbers8popFrontEv($r);
    __label__ = 5;
    break;
   case 15:
    var $_idx2_val = HEAP32[$args >> 2];
    var $44 = __ZNK2js12CallReceiver4rvalEv($_idx2_val);
    __ZN2JS5Value9setObjectER8JSObject($44, $10);
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    __ZN16FlowGraphSummaryD1Ev($flowData);
    var $_1 = $_0;
    __label__ = 17;
    break;
   case 17:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL28DebuggerScript_getAllOffsetsP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL29DebuggerScript_getLineOffsetsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 68;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $flowData = __stackBase__ + 8;
    var $r = __stackBase__ + 32;
    var $1 = __stackBase__ + 60;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $2 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str42 | 0, 1);
    if (($2 | 0) == 0) {
      var $_1 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx3_val = HEAP32[$2 + 24 >> 2];
    var $5 = __ZL17GetScriptReferentP8JSObject($_idx3_val);
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str117 | 0, 1);
    var $_1 = 0;
    __label__ = 17;
    break;
   case 4:
    var $args_idx_val = HEAPU32[$args >> 2];
    var $9 = __ZNK2js8CallArgsixEj($args_idx_val, 0);
    var $_idx = $9 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $10 = __ZNK2JS5Value8isNumberEv($_idx_val$0, $_idx_val$1);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $12 = __ZNK2JS5Value8toNumberEv($9);
    var $13 = $12 >= 0 ? Math.floor($12) : Math.ceil($12);
    if ($13 >>> 0 == $12) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 4, 283, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 17;
    break;
   case 7:
    __ZN16FlowGraphSummaryC1EP9JSContext($flowData, $cx);
    var $17 = __ZN16FlowGraphSummary8populateEP9JSContextP8JSScript($flowData, $cx, $5);
    if ($17) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 8:
    var $19 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($cx);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN28BytecodeRangeWithLineNumbersC1EP9JSContextP8JSScript($r, $cx, $5);
    var $_idx4 = $r + 8 | 0;
    var $_idx5 = $r + 12 | 0;
    var $_idx6 = $r + 4 | 0;
    var $r_idx = $r + 16 | 0;
    var $_idx1 = $flowData + 4 | 0;
    __label__ = 10;
    break;
   case 10:
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $_idx5_val = HEAP32[$_idx5 >> 2];
    var $23 = __ZNK2js13BytecodeRange5emptyEv($_idx4_val, $_idx5_val);
    if ($23) {
      __label__ = 15;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_idx6_val_idx_val = HEAP32[HEAP32[$_idx6 >> 2] >> 2];
    var $25 = __ZNK2js13BytecodeRange11frontOffsetEv($_idx6_val_idx_val, $_idx4_val);
    var $r_idx_val = HEAP32[$r_idx >> 2];
    var $26 = __ZNK28BytecodeRangeWithLineNumbers15frontLineNumberEv($r_idx_val);
    if (($26 | 0) == ($13 | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $29 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEixEj($_idx1_val, $25);
    var $30 = HEAP32[$29 >> 2];
    if (($30 | 0) == -1 | ($30 | 0) == ($13 | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $34 = $25 >>> 0;
    __ZN2JSL11NumberValueEd($1, $34);
    var $35 = __Z19js_NewbornArrayPushP9JSContextP8JSObjectRKN2JS5ValueE($cx, $19, $1);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZN28BytecodeRangeWithLineNumbers8popFrontEv($r);
    __label__ = 10;
    break;
   case 15:
    var $39 = __ZNK2js12CallReceiver4rvalEv($args_idx_val);
    __ZN2JS5Value9setObjectER8JSObject($39, $19);
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    __ZN16FlowGraphSummaryD1Ev($flowData);
    var $_1 = $_0;
    __label__ = 17;
    break;
   case 17:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL29DebuggerScript_getLineOffsetsP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL28DebuggerScript_getOffsetLineP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $offset = __stackBase__ + 8;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str116 | 0, 1);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 3:
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $4 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str44 | 0, 1);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx1_val = HEAP32[$4 + 24 >> 2];
    var $7 = __ZL17GetScriptReferentP8JSObject($_idx1_val);
    var $args_idx_val = HEAP32[$args >> 2];
    var $8 = __ZNK2js8CallArgsixEj($args_idx_val, 0);
    var $9 = __ZL12ScriptOffsetP9JSContextP8JSScriptRKN2JS5ValueEPj($cx, $7, $8, $offset);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $14 = HEAP32[$7 >> 2] + HEAP32[$offset >> 2] | 0;
    var $15 = $cx;
    var $16 = $7;
    var $17 = _JS_PCToLineNumber($15, $16, $14);
    var $18 = __ZNK2js12CallReceiver4rvalEv($args_idx_val);
    var $19 = __ZN2JS5Value9setNumberEj($18, $17);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL28DebuggerScript_setBreakpointP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $offset = __stackBase__ + 8;
    if ($argc >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str115 | 0, 2);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 3:
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $4 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str45 | 0, 1);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx3_val = HEAP32[$4 + 24 >> 2];
    var $7 = __ZL17GetScriptReferentP8JSObject($_idx3_val);
    var $8 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($4);
    var $9 = __ZL15GetScriptHolderP8JSObject($4);
    var $10 = __ZL11ScriptScopeP9JSContextP8JSScriptP8JSObject($cx, $7, $9);
    var $11 = __ZNK2js8Debugger13observesScopeEP8JSObject($8, $10);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 4, 284, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 12;
    break;
   case 6:
    var $args_idx1_val = HEAPU32[$args >> 2];
    var $14 = __ZNK2js8CallArgsixEj($args_idx1_val, 0);
    var $15 = __ZL12ScriptOffsetP9JSContextP8JSScriptRKN2JS5ValueEPj($cx, $7, $14, $offset);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 7:
    var $17 = __ZNK2js8CallArgsixEj($args_idx1_val, 1);
    var $18 = $cx;
    var $_idx2 = $17 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    var $19 = __ZN2js13NonNullObjectEP9JSContextRKN2JS5ValueE($18, $_idx2_val$0, $_idx2_val$1);
    var $20 = $19;
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $23 = $7;
    var $24 = __ZNK2js2gc4Cell11compartmentEv($23);
    var $28 = HEAP32[$7 >> 2] + HEAP32[$offset >> 2] | 0;
    var $29 = __ZN13JSCompartment25getOrCreateBreakpointSiteEP9JSContextP8JSScriptPhP8JSObject($24, $cx, $7, $28, $9);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2js14BreakpointSite3incEP9JSContext($29);
    var $33 = HEAP32[$cx + 52 >> 2];
    var $34 = __ZN9JSRuntime4new_IN2js10BreakpointEPNS1_8DebuggerEPNS1_14BreakpointSiteEP8JSObjectEEPT_T0_T1_T2_($33, $8, $29, $20);
    if (($34 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $37 = __ZNK2js12CallReceiver4rvalEv($args_idx1_val);
    __ZN2JS5Value12setUndefinedEv($37);
    var $_0 = 1;
    __label__ = 12;
    break;
   case 11:
    __ZN2js14BreakpointSite3decEP9JSContext($29);
    __ZN2js14BreakpointSite14destroyIfEmptyEP9JSRuntimePNS_6detail9HashTableINS_12HashMapEntryIPhPS0_EENS_7HashMapIS6_S7_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESC_E4EnumE($29, 0);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL28DebuggerScript_setBreakpointP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL29DebuggerScript_getBreakpointsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $offset = __stackBase__ + 8;
    var $r = __stackBase__ + 12;
    var $1 = __stackBase__ + 20;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $2 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str46 | 0, 1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx5_val = HEAP32[$2 + 24 >> 2];
    var $5 = __ZL17GetScriptReferentP8JSObject($_idx5_val);
    var $6 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($2);
    if (($argc | 0) == 0) {
      var $pc_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $args_idx_val = HEAP32[$args >> 2];
    var $9 = __ZNK2js8CallArgsixEj($args_idx_val, 0);
    var $10 = __ZL12ScriptOffsetP9JSContextP8JSScriptRKN2JS5ValueEPj($cx, $5, $9, $offset);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 4:
    var $pc_0 = HEAP32[$5 >> 2] + HEAP32[$offset >> 2] | 0;
    __label__ = 5;
    break;
   case 5:
    var $pc_0;
    var $17 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($cx);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = $5;
    var $21 = __ZNK2js2gc4Cell11compartmentEv($20);
    var $22 = $21 + 1956 | 0;
    __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE3allEv($r, $22);
    var $23 = ($pc_0 | 0) == 0;
    var $r_idx = $r | 0;
    var $r_idx1 = $r + 4 | 0;
    __label__ = 7;
    break;
   case 7:
    var $r_idx_val = HEAP32[$r_idx >> 2];
    var $r_idx1_val = HEAP32[$r_idx1 >> 2];
    var $25 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($r_idx_val, $r_idx1_val);
    if ($25) {
      __label__ = 17;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5frontEv($r_idx_val);
    var $29 = HEAP32[$27 + 4 >> 2];
    if ((HEAP32[$29 >> 2] | 0) == ($5 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 9:
    if ($23) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ((HEAP32[$29 + 4 >> 2] | 0) == ($pc_0 | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 11:
    var $39 = __ZNK2js14BreakpointSite15firstBreakpointEv($29);
    var $bp_0 = $39;
    __label__ = 12;
    break;
   case 12:
    var $bp_0;
    if (($bp_0 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if ((HEAP32[$bp_0 >> 2] | 0) == ($6 | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $bp_0_idx_val = HEAP32[$bp_0 + 8 >> 2];
    var $47 = __ZNK2js10Breakpoint10getHandlerEv($bp_0_idx_val);
    __ZN2JSL11ObjectValueER8JSObject($1, $47);
    var $48 = __Z19js_NewbornArrayPushP9JSContextP8JSObjectRKN2JS5ValueE($cx, $17, $1);
    if (($48 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $bp_0_idx3_val = HEAP32[$bp_0 + 4 >> 2];
    var $bp_0_idx4_val = HEAP32[$bp_0 + 20 >> 2];
    var $51 = __ZN2js10Breakpoint10nextInSiteEv($bp_0_idx3_val, $bp_0_idx4_val);
    var $bp_0 = $51;
    __label__ = 12;
    break;
   case 16:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range8popFrontEv($r);
    __label__ = 7;
    break;
   case 17:
    var $_idx_val = HEAP32[$args >> 2];
    var $53 = __ZNK2js12CallReceiver4rvalEv($_idx_val);
    __ZN2JS5Value9setObjectER8JSObject($53, $17);
    var $_0 = 1;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL29DebuggerScript_getBreakpointsP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL30DebuggerScript_clearBreakpointP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str114 | 0, 1);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 3:
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $4 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str47 | 0, 1);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx2_val = HEAP32[$4 + 24 >> 2];
    var $7 = __ZL17GetScriptReferentP8JSObject($_idx2_val);
    var $8 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($4);
    var $args_idx_val = HEAP32[$args >> 2];
    var $9 = __ZNK2js8CallArgsixEj($args_idx_val, 0);
    var $10 = $cx;
    var $_idx1 = $9 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $11 = __ZN2js13NonNullObjectEP9JSContextRKN2JS5ValueE($10, $_idx1_val$0, $_idx1_val$1);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = $11;
    var $15 = $7;
    var $16 = __ZNK2js2gc4Cell11compartmentEv($15);
    __ZN13JSCompartment18clearBreakpointsInEP9JSContextPN2js8DebuggerEP8JSScriptP8JSObject($16, $8, $7, $14);
    var $17 = __ZNK2js12CallReceiver4rvalEv($args_idx_val);
    __ZN2JS5Value12setUndefinedEv($17);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL34DebuggerScript_clearAllBreakpointsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str47 | 0, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    var $4 = __ZL17GetScriptReferentP8JSObject($_idx1_val);
    var $5 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $6 = $4;
    var $7 = __ZNK2js2gc4Cell11compartmentEv($6);
    __ZN13JSCompartment18clearBreakpointsInEP9JSContextPN2js8DebuggerEP8JSScriptP8JSObject($7, $5, $4, 0);
    var $_idx_val = HEAP32[$args >> 2];
    var $8 = __ZNK2js12CallReceiver4rvalEv($_idx_val);
    __ZN2JS5Value12setUndefinedEv($8);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15EvaluateInScopeEP9JSContextP8JSObjectPNS_10StackFrameEPKtjPKcjPN2JS5ValueE($cx, $scobj, $fp, $chars, $length, $filename, $lineno, $rval) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11ComputeThisEP9JSContextPNS_10StackFrameE($cx, $fp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZNK2js10StackFrame10scopeChainEv($fp);
    var $4 = __ZN8JSObject10principalsEP9JSContext($3, $cx);
    var $5 = __ZNK9JSContext11findVersionEv($cx);
    var $6 = __ZN2js8Compiler13compileScriptEP9JSContextP8JSObjectPNS_10StackFrameEP12JSPrincipalsjPKtjPKcj9JSVersionP8JSStringj($cx, $scobj, $fp, $4, 1073750016, $chars, $length, $filename, $lineno, $5, 0, 16);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZNK2js10StackFrame9thisValueEv($fp);
    var $10 = __ZN2js13ExecuteKernelEP9JSContextP8JSScriptR8JSObjectRKN2JS5ValueENS_11ExecuteTypeEPNS_10StackFrameEPS7_($cx, $6, $scobj, $9, 24, $fp, $rval);
    var $_0 = $10 & 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ComputeThisEP9JSContextPNS_10StackFrameE($cx, $fp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2js10StackFrame9thisValueEv($fp);
    var $_idx = $2 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $3 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($3) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $fp_idx_val = HEAP32[$fp >> 2];
    var $5 = __ZNK2js10StackFrame15isFunctionFrameEv($fp_idx_val);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZNK2js10StackFrame3funEv($fp);
    var $8 = __ZNK10JSFunction12inStrictModeEv($7);
    if ($8) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZNK2js10StackFrame12callReceiverEv($1, $fp);
    var $10 = __ZN2js16BoxNonStrictThisEP9JSContextRKNS_12CallReceiverE($cx, $1);
    var $_0 = $10;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject10principalsEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JS_GetSecurityCallbacks($cx);
    if (($1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$1 + 8 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = FUNCTION_TABLE[$5]($cx, $this);
    var $_0 = $8;
    __label__ = 6;
    break;
   case 4:
    var $10 = HEAP32[$cx + 56 >> 2];
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_0 = HEAP32[$10 + 4 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK9JSContext11findVersionEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 16 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[$this + 12 >> 2];
    __label__ = 10;
    break;
   case 3:
    var $_idx_val = HEAP32[$this + 60 >> 2];
    var $9 = __ZNK2js12ContextStack5hasfpEv($_idx_val);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    var $11 = __ZNK9JSContext2fpEv($this);
    var $f_0 = $11;
    __label__ = 5;
    break;
   case 5:
    var $f_0;
    if (($f_0 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $f_0_idx1_val = HEAP32[$f_0 >> 2];
    var $15 = __ZNK2js10StackFrame13isScriptFrameEv($f_0_idx1_val);
    if ($15) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $f_0_idx_val = HEAP32[$f_0 + 16 >> 2];
    var $17 = __ZNK2js10StackFrame4prevEv($f_0_idx_val);
    var $f_0 = $17;
    __label__ = 5;
    break;
   case 8:
    var $18 = __ZNK2js10StackFrame6scriptEv($f_0);
    var $_idx2_val = HEAP16[$18 + 12 >> 1];
    var $19 = __ZNK8JSScript10getVersionEv($_idx2_val);
    var $_0 = $19;
    __label__ = 10;
    break;
   case 9:
    var $_0 = HEAP32[$this + 8 >> 2];
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame9thisValueEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this >> 2] & 9 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_pn = $this;
    __label__ = 4;
    break;
   case 3:
    var $8 = __ZNK2js10StackFrame10formalArgsEv($this);
    var $_pn = $8;
    __label__ = 4;
    break;
   case 4:
    var $_pn;
    return $_pn - 8 | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26DebuggerFrame_getArgumentsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $argumentsv = __stackBase__ + 8;
    var $proto = __stackBase__ + 16;
    var $1 = __stackBase__ + 20;
    var $2 = __stackBase__ + 28;
    var $3 = __stackBase__ + 36;
    var $4 = __stackBase__ + 44;
    var $5 = __stackBase__ + 52;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $6 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str111 | 0, 1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$6 + 24 >> 2];
    var $9 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $10 = $9;
    __ZNK8JSObject15getReservedSlotEj($argumentsv, $6, 1);
    var $argumentsv_idx = $argumentsv | 0;
    var $argumentsv_idx_val$0 = HEAP32[$argumentsv_idx >> 2];
    var $argumentsv_idx_val$1 = HEAP32[$argumentsv_idx + 4 >> 2];
    var $11 = __ZNK2JS5Value11isUndefinedEv($argumentsv_idx_val$0, $argumentsv_idx_val$1);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx5_val = HEAP32[$args >> 2];
    var $13 = __ZNK2js12CallReceiver4rvalEv($_idx5_val);
    var $14 = $13 | 0;
    var $st$4$0 = $14 | 0;
    HEAP32[$st$4$0 >> 2] = $argumentsv_idx_val$0;
    var $st$4$1 = $14 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $argumentsv_idx_val$1;
    var $_0 = 1;
    __label__ = 15;
    break;
   case 4:
    var $_idx6_val = HEAP32[$9 >> 2];
    var $16 = __ZNK2js10StackFrame7hasArgsEv($_idx6_val);
    var $_idx1_val = HEAP32[$args >> 2];
    if ($16) {
      __label__ = 5;
      break;
    } else {
      var $argsobj_0 = 0;
      var $_idx4_val = $_idx1_val;
      __label__ = 14;
      break;
    }
   case 5:
    var $18 = __ZNK2js12CallReceiver6calleeEv($_idx1_val);
    var $19 = $18;
    var $20 = __ZNK8JSObject9getGlobalEv($19);
    var $21 = $20;
    var $22 = $cx;
    var $23 = $20 | 0;
    var $24 = $proto;
    var $25 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($22, $23, 3, $24, 0);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $28 = HEAP32[$proto >> 2];
    var $29 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, _DebuggerArguments_class, $28, $21);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JSL11ObjectValueER8JSObject($1, $6);
    var $32 = $29;
    var $33 = __Z18js_SetReservedSlotP9JSContextP8JSObjectjRKN2JS5ValueE($22, $32, 0, $1);
    if ($33) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 8:
    var $35 = __ZNK2js10StackFrame13numActualArgsEv($10);
    var $40 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $41 = __ZL12ATOM_TO_JSIDP6JSAtom($40);
    __ZN2JSL10Int32ValueEi($2, $35);
    var $42 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($22, $32, $41, $2, 0, 0, 6, 0, 0, 0);
    if (($42 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      var $i_0 = 0;
      __label__ = 9;
      break;
    }
   case 9:
    var $i_0;
    if (($i_0 | 0) < ($35 | 0)) {
      __label__ = 10;
      break;
    } else {
      var $argsobj_0 = $29;
      var $_idx4_val = $_idx1_val;
      __label__ = 14;
      break;
    }
   case 10:
    var $46 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($cx, 0, 18, 0, 0, $21, 0);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2JSL10Int32ValueEi($3, $i_0);
    var $49 = $46;
    var $50 = __Z18js_SetReservedSlotP9JSContextP8JSObjectjRKN2JS5ValueE($22, $49, 0, $3);
    if ($50) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 12:
    var $52 = _INT_TO_JSID($i_0);
    __ZN2JSL14UndefinedValueEv($4);
    var $53 = $46;
    var $54 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($22, $32, $52, $4, $53, 0, 81, 0, 0, 0);
    if (($54 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 9;
    break;
   case 14:
    var $_idx4_val;
    var $argsobj_0;
    var $58 = __ZNK2js12CallReceiver4rvalEv($_idx4_val);
    __ZN2JSL17ObjectOrNullValueEP8JSObject5($5, $argsobj_0);
    var $59 = $5 | 0;
    var $60$0 = HEAP32[$59 >> 2];
    var $60$1 = HEAP32[$59 + 4 >> 2];
    var $61 = $58 | 0;
    HEAP32[$61 >> 2] = $60$0;
    HEAP32[$61 + 4 >> 2] = $60$1;
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($6, 1, $60$0, $60$1);
    var $_0 = 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL26DebuggerFrame_getArgumentsP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL23DebuggerFrame_getCalleeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $calleev = __stackBase__ + 8;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str110 | 0, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $4 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $5 = $4;
    var $_idx1_val = HEAP32[$4 >> 2];
    var $6 = __ZNK2js10StackFrame15isFunctionFrameEv($_idx1_val);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $8 = __ZNK2js10StackFrame11isEvalFrameEv($_idx1_val);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZNK2js10StackFrame7calleevEv($5);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $calleev | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    __label__ = 6;
    break;
   case 5:
    __ZN2JSL9NullValueEv($calleev);
    __label__ = 6;
    break;
   case 6:
    var $16 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $17 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($16, $cx, $calleev);
    if ($17) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $_idx3_val = HEAP32[$args >> 2];
    var $19 = __ZNK2js12CallReceiver4rvalEv($_idx3_val);
    var $20 = $calleev | 0;
    var $21$0 = HEAP32[$20 >> 2];
    var $21$1 = HEAP32[$20 + 4 >> 2];
    var $22 = $19 | 0;
    var $st$9$0 = $22 | 0;
    HEAP32[$st$9$0 >> 2] = $21$0;
    var $st$9$1 = $22 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $21$1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL29DebuggerFrame_getConstructingP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str109 | 0, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $4 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $_idx3_val = HEAP32[$args >> 2];
    var $5 = __ZNK2js12CallReceiver4rvalEv($_idx3_val);
    var $_idx1_val = HEAP32[$4 >> 2];
    var $6 = __ZNK2js10StackFrame15isFunctionFrameEv($_idx1_val);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $10 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZNK2js10StackFrame14isConstructingEv($_idx1_val);
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    __ZN2JS5Value10setBooleanEb($5, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26DebuggerFrame_getGeneratorP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str108 | 0, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $4 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $_idx2_val = HEAP32[$args >> 2];
    var $5 = __ZNK2js12CallReceiver4rvalEv($_idx2_val);
    var $_idx1_val = HEAP32[$4 >> 2];
    var $6 = __ZNK2js10StackFrame16isGeneratorFrameEv($_idx1_val);
    __ZN2JS5Value10setBooleanEb($5, $6);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21DebuggerFrame_getLiveP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str107 | 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $4 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $_idx1_val = HEAP32[$args >> 2];
    var $5 = __ZNK2js12CallReceiver4rvalEv($_idx1_val);
    var $6 = ($4 | 0) != 0;
    __ZN2JS5Value10setBooleanEb($5, $6);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23DebuggerFrame_getOffsetP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $2 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str106 | 0, 1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$2 + 24 >> 2];
    var $5 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $_idx1_val = HEAP32[$5 >> 2];
    var $6 = __ZNK2js10StackFrame13isScriptFrameEv($_idx1_val);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = $5;
    var $9 = __ZNK2js10StackFrame6scriptEv($8);
    var $10 = $cx;
    __ZN2js12ContextStackC2EP9JSContext($1, $10);
    var $11 = $5;
    var $12 = __ZN2js10StackFrame11pcQuadraticERKNS_12ContextStackEPS0_PPNS_13JSInlinedSiteE($11, $1, 0);
    var $17 = $12 - HEAP32[$9 >> 2] | 0;
    var $_idx3_val = HEAP32[$args >> 2];
    var $18 = __ZNK2js12CallReceiver4rvalEv($_idx3_val);
    var $19 = $17 >>> 0;
    var $20 = __ZN2JS5Value9setNumberEd($18, $19);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 4:
    var $_idx2_val = HEAP32[$args >> 2];
    var $22 = __ZNK2js12CallReceiver4rvalEv($_idx2_val);
    __ZN2JS5Value12setUndefinedEv($22);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL22DebuggerFrame_getOlderP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str105 | 0, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $4 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $5 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $_idx1_val = HEAP32[$4 + 16 >> 2];
    var $7 = __ZNK2js10StackFrame4prevEv($_idx1_val);
    var $fp_0 = $7;
    __label__ = 3;
    break;
   case 3:
    var $fp_0;
    if (($fp_0 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $fp_0_idx2_val = HEAP32[$fp_0 >> 2];
    var $11 = __ZNK2js10StackFrame12isDummyFrameEv($fp_0_idx2_val);
    if ($11) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = __ZNK2js8Debugger13observesFrameEPNS_10StackFrameE($5, $fp_0);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $15 = __ZN2js8Debugger14getScriptFrameEP9JSContextPNS_10StackFrameEPN2JS5ValueE($5, $cx, $fp_0, $vp);
    var $_0 = $15 & 1;
    __label__ = 9;
    break;
   case 7:
    var $fp_0_idx_val = HEAP32[$fp_0 + 16 >> 2];
    var $18 = __ZNK2js10StackFrame4prevEv($fp_0_idx_val);
    var $fp_0 = $18;
    __label__ = 3;
    break;
   case 8:
    var $_idx3_val = HEAP32[$args >> 2];
    var $20 = __ZNK2js12CallReceiver4rvalEv($_idx3_val);
    __ZN2JS5Value7setNullEv($20);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23DebuggerFrame_getScriptP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str89 | 0, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $4 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $5 = $4;
    var $6 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $_idx1_val = HEAP32[$4 >> 2];
    var $7 = __ZNK2js10StackFrame15isFunctionFrameEv($_idx1_val);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $9 = __ZNK2js10StackFrame11isEvalFrameEv($_idx1_val);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = __ZNK2js10StackFrame6calleeEv($5);
    var $_idx3_val = HEAP32[$11 + 24 >> 2];
    var $12 = __ZNK8JSObject18getFunctionPrivateEv($_idx3_val);
    var $_idx4_val = HEAP16[$12 + 58 >> 1];
    var $13 = __ZNK10JSFunction13isInterpretedEv($_idx4_val);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      var $scriptObject_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $15 = __ZN2js8Debugger18wrapFunctionScriptEP9JSContextP10JSFunction($6, $cx, $12);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      var $scriptObject_0 = $15;
      __label__ = 11;
      break;
    }
   case 6:
    var $18 = __ZNK2js10StackFrame13isScriptFrameEv($_idx1_val);
    if ($18) {
      __label__ = 7;
      break;
    } else {
      var $scriptObject_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $20 = __ZNK2js10StackFrame6scriptEv($5);
    var $22 = HEAP32[$20 + 84 >> 2];
    if (($22 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $25 = __ZN2js8Debugger15wrapJSAPIScriptEP9JSContextP8JSObject($6, $cx, $22);
    var $29 = $25;
    __label__ = 10;
    break;
   case 9:
    var $27 = __ZN2js8Debugger17wrapNonHeldScriptEP9JSContextP8JSScript($6, $cx, $20);
    var $29 = $27;
    __label__ = 10;
    break;
   case 10:
    var $29;
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      var $scriptObject_0 = $29;
      __label__ = 11;
      break;
    }
   case 11:
    var $scriptObject_0;
    var $_idx6_val = HEAP32[$args >> 2];
    var $32 = __ZNK2js12CallReceiver4rvalEv($_idx6_val);
    __ZN2JS5Value15setObjectOrNullEP8JSObject($32, $scriptObject_0);
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21DebuggerFrame_getThisP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 68;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $thisv = __stackBase__ + 8;
    var $ac = __stackBase__ + 16;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str105 | 0, 1);
    if (($1 | 0) == 0) {
      var $_1 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $4 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $5 = $4;
    var $6 = __ZNK2js10StackFrame10scopeChainEv($5);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $6);
    var $7 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = __ZN2js11ComputeThisEP9JSContextPNS_10StackFrameE($cx, $5);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = __ZNK2js10StackFrame9thisValueEv($5);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $thisv | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $14 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $15 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($14, $cx, $thisv);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      var $_1 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_1 = 0;
    __label__ = 7;
    break;
   case 6:
    var $_idx1_val = HEAP32[$args >> 2];
    var $18 = __ZNK2js12CallReceiver4rvalEv($_idx1_val);
    var $19$0 = HEAP32[$13 >> 2];
    var $19$1 = HEAP32[$13 + 4 >> 2];
    var $20 = $18 | 0;
    var $st$8$0 = $20 | 0;
    HEAP32[$st$8$0 >> 2] = $19$0;
    var $st$8$1 = $20 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $19$1;
    var $_1 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21DebuggerFrame_getTypeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str104 | 0, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $4 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $_idx2_val = HEAP32[$args >> 2];
    var $5 = __ZNK2js12CallReceiver4rvalEv($_idx2_val);
    var $_idx1_val = HEAP32[$4 >> 2];
    var $6 = __ZNK2js10StackFrame11isEvalFrameEv($_idx1_val);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $_in = HEAP32[$cx + 52 >> 2] + 210212 | 0;
    __label__ = 7;
    break;
   case 4:
    var $12 = __ZNK2js10StackFrame13isGlobalFrameEv($_idx1_val);
    var $14 = HEAP32[$cx + 52 >> 2];
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $_in = $14 + 210224 | 0;
    __label__ = 7;
    break;
   case 6:
    var $_in = $14 + 210188 | 0;
    __label__ = 7;
    break;
   case 7:
    var $_in;
    var $21 = HEAP32[$_in >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($5, $21);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23DebuggerFrame_getOnStepP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $handler = __stackBase__ + 8;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str103 | 0, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZNK8JSObject15getReservedSlotEj($handler, $1, 2);
    var $_idx_val = HEAP32[$args >> 2];
    var $4 = __ZNK2js12CallReceiver4rvalEv($_idx_val);
    var $5 = $handler | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $4 | 0;
    var $st$10$0 = $7 | 0;
    HEAP32[$st$10$0 >> 2] = $6$0;
    var $st$10$1 = $7 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $6$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23DebuggerFrame_setOnStepP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 68;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $prior = __stackBase__ + 8;
    var $ac = __stackBase__ + 16;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str101 | 0, 1);
    var $_1 = 0;
    __label__ = 13;
    break;
   case 3:
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $4 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str102 | 0, 1);
    if (($4 | 0) == 0) {
      var $_1 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$4 + 24 >> 2];
    var $7 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $8 = $7;
    var $_idx1_val = HEAP32[$7 >> 2];
    var $9 = __ZNK2js10StackFrame13isScriptFrameEv($_idx1_val);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 4, 286, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 13;
    break;
   case 6:
    var $args_idx4_val = HEAPU32[$args >> 2];
    var $12 = __ZNK2js8CallArgsixEj($args_idx4_val, 0);
    var $_idx7 = $12 | 0;
    var $_idx7_val$0 = HEAP32[$_idx7 >> 2];
    var $_idx7_val$1 = HEAP32[$_idx7 + 4 >> 2];
    var $13 = __ZL11IsValidHookRKN2JS5ValueE($_idx7_val$0, $_idx7_val$1);
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 4, 230, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 13;
    break;
   case 8:
    __ZNK8JSObject15getReservedSlotEj($prior, $4, 2);
    var $_idx2_val$0 = HEAPU32[$_idx7 >> 2];
    var $_idx2_val$1 = HEAPU32[$_idx7 + 4 >> 2];
    var $16 = __ZNK2JS5Value11isUndefinedEv($_idx2_val$0, $_idx2_val$1);
    var $18 = $16 & 1 ^ 1;
    var $prior_idx = $prior | 0;
    var $prior_idx_val$0 = HEAP32[$prior_idx >> 2];
    var $prior_idx_val$1 = HEAP32[$prior_idx + 4 >> 2];
    var $19 = __ZNK2JS5Value11isUndefinedEv($prior_idx_val$0, $prior_idx_val$1);
    var $22 = $18 - ($19 & 1 ^ 1) | 0;
    if ($16 ^ $19) {
      __label__ = 9;
      break;
    } else {
      var $_idx5_val$1 = $_idx2_val$1;
      var $_idx5_val$0 = $_idx2_val$0;
      __label__ = 11;
      break;
    }
   case 9:
    var $25 = __ZNK2js10StackFrame10scopeChainEv($8);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $25);
    var $26 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($26) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $28 = __ZNK2js10StackFrame6scriptEv($8);
    var $29 = $28;
    var $30 = $cx;
    __ZN8JSScript19changeStepModeCountEP9JSContexti($29, $30, $22);
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_idx5_val$1 = HEAP32[$_idx7 + 4 >> 2];
    var $_idx5_val$0 = HEAP32[$_idx7 >> 2];
    __label__ = 11;
    break;
   case 11:
    var $_idx5_val$0;
    var $_idx5_val$1;
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($4, 2, $_idx5_val$0, $_idx5_val$1);
    var $32 = __ZNK2js12CallReceiver4rvalEv($args_idx4_val);
    __ZN2JS5Value12setUndefinedEv($32);
    var $_1 = 1;
    __label__ = 13;
    break;
   case 12:
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_1 = 0;
    __label__ = 13;
    break;
   case 13:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL23DebuggerFrame_setOnStepP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL18DebuggerFrame_evalP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL17DebuggerFrameEvalP9JSContextjPN2JS5ValueE16EvalBindingsMode($cx, $argc, $vp, 0);
  return $1;
}

function __ZL30DebuggerFrame_evalWithBindingsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL17DebuggerFrameEvalP9JSContextjPN2JS5ValueE16EvalBindingsMode($cx, $argc, $vp, 1);
  return $1;
}

function __ZL20DebuggerObject_traceP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $obj_idx_val = HEAP32[$obj + 24 >> 2];
    var $9 = __ZNK8JSObject10getPrivateEv($obj_idx_val);
    if (($9 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $9;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $12);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23DebuggerObject_getProtoP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $protov = __stackBase__ + 8;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE.__str94 | 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $5 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $_idx1_val_idx_val = HEAP32[HEAP32[$5 + 36 >> 2] >> 2];
    var $7 = __ZNK8JSObject8getProtoEv($_idx1_val_idx_val);
    __ZN2JSL17ObjectOrNullValueEP8JSObject5($protov, $7);
    var $8 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($4, $cx, $protov);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_idx2_val = HEAP32[$args >> 2];
    var $10 = __ZNK2js12CallReceiver4rvalEv($_idx2_val);
    var $11 = $protov | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $10 | 0;
    var $st$9$0 = $13 | 0;
    HEAP32[$st$9$0 >> 2] = $12$0;
    var $st$9$1 = $13 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23DebuggerObject_getClassP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE.__str93 | 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $4 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $_idx1_val = HEAP32[$4 + 4 >> 2];
    var $6 = __ZNK8JSObject8getClassEv($_idx1_val);
    var $8 = HEAP32[$6 >> 2];
    var $9 = _strlen($8);
    var $10 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $8, $9, 0);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx2_val = HEAP32[$args >> 2];
    var $13 = __ZNK2js12CallReceiver4rvalEv($_idx2_val);
    var $14 = $10 | 0;
    __ZN2JS5Value9setStringEP8JSString($13, $14);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26DebuggerObject_getCallableP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE.__str92 | 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $4 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $_idx2_val = HEAP32[$args >> 2];
    var $5 = __ZNK2js12CallReceiver4rvalEv($_idx2_val);
    var $_idx1_val = HEAP32[$4 + 4 >> 2];
    var $7 = __ZN8JSObject10isCallableEv($_idx1_val);
    __ZN2JS5Value10setBooleanEb($5, $7);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL22DebuggerObject_getNameP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $namev = __stackBase__ + 8;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE.__str91 | 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $5 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $_idx1_val = HEAP32[$5 + 4 >> 2];
    var $7 = __ZNK8JSObject10isFunctionEv($_idx1_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx5_val = HEAP32[$args >> 2];
    var $9 = __ZNK2js12CallReceiver4rvalEv($_idx5_val);
    __ZN2JS5Value12setUndefinedEv($9);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 4:
    var $_idx2_val = HEAP32[$5 + 24 >> 2];
    var $12 = __ZNK8JSObject18getFunctionPrivateEv($_idx2_val);
    var $14 = HEAP32[$12 + 72 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $_idx4_val = HEAP32[$args >> 2];
    var $17 = __ZNK2js12CallReceiver4rvalEv($_idx4_val);
    __ZN2JS5Value12setUndefinedEv($17);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 6:
    var $19 = $14 | 0;
    __ZN2JSL11StringValueEP8JSString($namev, $19);
    var $20 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($4, $cx, $namev);
    if ($20) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $_idx3_val = HEAP32[$args >> 2];
    var $22 = __ZNK2js12CallReceiver4rvalEv($_idx3_val);
    var $23 = $namev | 0;
    var $24$0 = HEAP32[$23 >> 2];
    var $24$1 = HEAP32[$23 + 4 >> 2];
    var $25 = $22 | 0;
    var $st$9$0 = $25 | 0;
    HEAP32[$st$9$0 >> 2] = $24$0;
    var $st$9$1 = $25 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $24$1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL22DebuggerObject_getNameP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL32DebuggerObject_getParameterNamesP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $names = __stackBase__ + 8;
    var $1 = __stackBase__ + 32;
    var $2 = __stackBase__ + 36;
    var $3 = __stackBase__ + 44;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $4 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE.__str90 | 0);
    if (($4 | 0) == 0) {
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$4 + 24 >> 2];
    var $7 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $_idx1_val = HEAP32[$7 + 4 >> 2];
    var $9 = __ZNK8JSObject10isFunctionEv($_idx1_val);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx5_val = HEAP32[$args >> 2];
    var $11 = __ZNK2js12CallReceiver4rvalEv($_idx5_val);
    __ZN2JS5Value12setUndefinedEv($11);
    var $_1 = 1;
    __label__ = 20;
    break;
   case 4:
    var $_idx2_val = HEAP32[$7 + 24 >> 2];
    var $14 = __ZNK8JSObject18getFunctionPrivateEv($_idx2_val);
    var $15 = $14 + 56 | 0;
    var $17 = HEAPU16[$15 >> 1] & 65535;
    var $18 = __ZN2js22NewDenseAllocatedArrayEP9JSContextjP8JSObject($cx, $17);
    if (($18 | 0) == 0) {
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $22 = HEAPU16[$15 >> 1] & 65535;
    __ZN8JSObject33ensureDenseArrayInitializedLengthEP9JSContextjj($18, $cx, 0, $22);
    var $_idx3_val = HEAP16[$14 + 58 >> 1];
    var $23 = __ZNK10JSFunction13isInterpretedEv($_idx3_val);
    var $25 = HEAP16[$15 >> 1] << 16 >> 16 == 0;
    if ($23) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ($25) {
      __label__ = 18;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx6 = $18 + 32 | 0;
    var $_idx7 = $3 | 0;
    var $i1_02 = 0;
    __label__ = 17;
    break;
   case 8:
    if ($25) {
      __label__ = 18;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
    var $_0_val = HEAP32[$1 >> 2];
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEC1ES3_($names, $_0_val);
    var $28 = __ZNK10JSFunction6scriptEv($14);
    var $30 = $28 + 64 | 0;
    var $31 = $names;
    var $32 = __ZN2js8Bindings17getLocalNameArrayEP9JSContextPNS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEE($30, $31);
    if ($32) {
      __label__ = 10;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 10:
    if (HEAP16[$15 >> 1] << 16 >> 16 == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $names_idx = $names + 4 | 0;
    var $_idx8 = $18 + 32 | 0;
    var $_idx9 = $2 | 0;
    var $i_04 = 0;
    __label__ = 12;
    break;
   case 12:
    var $i_04;
    var $names_idx_val = HEAP32[$names_idx >> 2];
    var $35 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEixEj($names_idx_val, $i_04);
    var $36 = HEAP32[$35 >> 2];
    if (($36 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $39 = $36 | 0;
    __ZN2JSL11StringValueEP8JSString($2, $39);
    __label__ = 15;
    break;
   case 14:
    __ZN2JSL14UndefinedValueEv($2);
    __label__ = 15;
    break;
   case 15:
    var $_idx8_val = HEAP32[$_idx8 >> 2];
    var $_idx9_val$0 = HEAP32[$_idx9 >> 2];
    var $_idx9_val$1 = HEAP32[$_idx9 + 4 >> 2];
    __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($_idx8_val, $i_04, $_idx9_val$0, $_idx9_val$1);
    var $42 = $i_04 + 1 | 0;
    if ($42 >>> 0 < (HEAPU16[$15 >> 1] & 65535) >>> 0) {
      var $i_04 = $42;
      __label__ = 12;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev($names);
    __label__ = 18;
    break;
   case 17:
    var $i1_02;
    __ZN2JSL14UndefinedValueEv($3);
    var $_idx6_val = HEAP32[$_idx6 >> 2];
    var $_idx7_val$0 = HEAP32[$_idx7 >> 2];
    var $_idx7_val$1 = HEAP32[$_idx7 + 4 >> 2];
    __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($_idx6_val, $i1_02, $_idx7_val$0, $_idx7_val$1);
    var $46 = $i1_02 + 1 | 0;
    if ($46 >>> 0 < (HEAPU16[$15 >> 1] & 65535) >>> 0) {
      var $i1_02 = $46;
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $_idx4_val = HEAP32[$args >> 2];
    var $50 = __ZNK2js12CallReceiver4rvalEv($_idx4_val);
    __ZN2JS5Value9setObjectER8JSObject($50, $18);
    var $_1 = 1;
    __label__ = 20;
    break;
   case 19:
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev($names);
    var $_1 = 0;
    __label__ = 20;
    break;
   case 20:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL32DebuggerObject_getParameterNamesP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL24DebuggerObject_getScriptP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE.__str89 | 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $5 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $_idx5_val = HEAP32[$args >> 2];
    var $6 = __ZNK2js12CallReceiver4rvalEv($_idx5_val);
    __ZN2JS5Value12setUndefinedEv($6);
    var $_idx1_val = HEAP32[$5 + 4 >> 2];
    var $8 = __ZNK8JSObject10isFunctionEv($_idx1_val);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 3:
    var $_idx2_val = HEAP32[$5 + 24 >> 2];
    var $11 = __ZNK8JSObject18getFunctionPrivateEv($_idx2_val);
    var $_idx3_val = HEAP16[$11 + 58 >> 1];
    var $12 = __ZNK10JSFunction13isInterpretedEv($_idx3_val);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 4:
    var $14 = __ZN2js8Debugger18wrapFunctionScriptEP9JSContextP10JSFunction($4, $cx, $11);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JS5Value9setObjectER8JSObject($6, $14);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL39DebuggerObject_getOwnPropertyDescriptorP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 144;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $id = __stackBase__ + 8;
    var $1 = __stackBase__ + 12;
    var $desc = __stackBase__ + 20;
    var $ac = __stackBase__ + 68;
    var $ec = __stackBase__ + 120;
    var $get = __stackBase__ + 128;
    var $set = __stackBase__ + 136;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $2 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE.__str102207 | 0);
    if (($2 | 0) == 0) {
      var $_3 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($2);
    var $_idx_val = HEAP32[$2 + 24 >> 2];
    var $6 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $7 = $6;
    if (($argc | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $args_idx_val = HEAP32[$args >> 2];
    var $10 = __ZNK2js8CallArgsixEj($args_idx_val, 0);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $1 | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    __label__ = 5;
    break;
   case 4:
    __ZN2JSL14UndefinedValueEv($1);
    __label__ = 5;
    break;
   case 5:
    var $16 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($cx, $1, $id);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_3 = 0;
      __label__ = 20;
      break;
    }
   case 6:
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($desc, $cx);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $7);
    var $18 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($18) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $21 = HEAP32[$cx + 56 >> 2];
    var $22 = __ZN13JSCompartment6wrapIdEP9JSContextPi($21, $cx, $id);
    if ($22) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_2 = 0;
    __label__ = 19;
    break;
   case 9:
    var $_idx1_val = HEAP32[$5 + 8 >> 2];
    var $24 = __ZNK2js8Debugger10toJSObjectEv($_idx1_val);
    __ZN2js11ErrorCopierC1ERNS_15AutoCompartmentEP8JSObject($ec, $ac, $24);
    var $25 = HEAP32[$id >> 2];
    var $26 = $desc + 16 | 0;
    var $phitmp3 = $26;
    var $27 = $cx;
    var $28 = $6;
    var $29 = __ZN2js24GetOwnPropertyDescriptorEP9JSContextP8JSObjectiP20JSPropertyDescriptor($27, $28, $25, $phitmp3);
    var $30 = $ec;
    __ZN2js11ErrorCopierD2Ev($30);
    __ZN2js15AutoCompartmentD2Ev($ac);
    if ($29) {
      __label__ = 10;
      break;
    } else {
      var $_2 = 0;
      __label__ = 19;
      break;
    }
   case 10:
    if ((HEAP32[$26 >> 2] | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $36 = $desc + 32 | 0;
    var $37 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($5, $cx, $36);
    if ($37) {
      __label__ = 12;
      break;
    } else {
      var $_2 = 0;
      __label__ = 19;
      break;
    }
   case 12:
    var $39 = $desc + 20 | 0;
    var $40 = HEAP32[$39 >> 2];
    if (($40 & 16 | 0) == 0) {
      var $52 = $40;
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $44 = $desc + 24 | 0;
    var $45 = HEAP32[$44 >> 2];
    var $46 = __ZN2js12CastAsObjectEPFiP9JSContextP8JSObjectiPN2JS5ValueEE($45);
    __ZN2JSL17ObjectOrNullValueEP8JSObject5($get, $46);
    var $47 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($5, $cx, $get);
    if ($47) {
      __label__ = 14;
      break;
    } else {
      var $_2 = 0;
      __label__ = 19;
      break;
    }
   case 14:
    var $get_idx = $get | 0;
    var $st$1$0 = $get_idx | 0;
    var $get_idx_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $get_idx + 4 | 0;
    var $get_idx_val$1 = HEAP32[$st$1$1 >> 2];
    var $49 = __ZNK2JS5Value14toObjectOrNullEv($get_idx_val$0, $get_idx_val$1);
    var $50 = __ZN2jsL16CastAsPropertyOpEP8JSObject($49);
    HEAP32[$44 >> 2] = $50;
    var $52 = HEAP32[$39 >> 2];
    __label__ = 15;
    break;
   case 15:
    var $52;
    if (($52 & 32 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $56 = $desc + 28 | 0;
    var $57 = HEAP32[$56 >> 2];
    var $58 = __ZN2js12CastAsObjectEPFiP9JSContextP8JSObjectiiPN2JS5ValueEE($57);
    __ZN2JSL17ObjectOrNullValueEP8JSObject5($set, $58);
    var $59 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($5, $cx, $set);
    if ($59) {
      __label__ = 17;
      break;
    } else {
      var $_2 = 0;
      __label__ = 19;
      break;
    }
   case 17:
    var $set_idx = $set | 0;
    var $st$1$0 = $set_idx | 0;
    var $set_idx_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $set_idx + 4 | 0;
    var $set_idx_val$1 = HEAP32[$st$1$1 >> 2];
    var $61 = __ZNK2JS5Value14toObjectOrNullEv($set_idx_val$0, $set_idx_val$1);
    var $62 = __ZN2jsL22CastAsStrictPropertyOpEP8JSObject($61);
    HEAP32[$56 >> 2] = $62;
    __label__ = 18;
    break;
   case 18:
    var $_idx2_val = HEAP32[$args >> 2];
    var $63 = __ZNK2js12CallReceiver4rvalEv($_idx2_val);
    var $64 = __ZN2js27NewPropertyDescriptorObjectEP9JSContextPK20JSPropertyDescriptorPN2JS5ValueE($27, $phitmp3, $63);
    var $_2 = $64 & 1;
    __label__ = 19;
    break;
   case 19:
    var $_2;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
    var $_3 = $_2;
    __label__ = 20;
    break;
   case 20:
    var $_3;
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL39DebuggerObject_getOwnPropertyDescriptorP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIP8JSScriptP8JSObjectEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefIP8JSScriptEcvRS2_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefIP8JSObjectEcvRS2_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE12hasCollisionEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 8 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 12 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEC2ERS9_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefIP8JSObjectEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefIP8JSScriptEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEaSERKS5_($this, $rhs) {
  var $2 = HEAP32[$rhs >> 2];
  HEAP32[$this >> 2] = $2;
  var $5 = HEAP32[$rhs + 4 >> 2];
  HEAP32[$this + 4 >> 2] = $5;
  return;
}

function __ZL34DebuggerObject_getOwnPropertyNamesP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 228;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $keys = __stackBase__ + 8;
    var $ac = __stackBase__ + 68;
    var $ec = __stackBase__ + 120;
    var $vals = __stackBase__ + 128;
    var $1 = __stackBase__ + 220;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $2 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE.__str152212 | 0);
    if (($2 | 0) == 0) {
      var $_4 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($2);
    var $_idx_val = HEAP32[$2 + 24 >> 2];
    var $6 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $7 = $6;
    __ZN2js12AutoIdVectorC1EP9JSContext($keys, $cx);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $7);
    var $8 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_3 = 0;
    __label__ = 18;
    break;
   case 4:
    var $_idx1_val = HEAP32[$5 + 8 >> 2];
    var $10 = __ZNK2js8Debugger10toJSObjectEv($_idx1_val);
    __ZN2js11ErrorCopierC1ERNS_15AutoCompartmentEP8JSObject($ec, $ac, $10);
    var $11 = $cx;
    var $12 = $6;
    var $13 = $keys;
    var $14 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($11, $12, 24, $13);
    var $15 = $ec;
    __ZN2js11ErrorCopierD2Ev($15);
    __ZN2js15AutoCompartmentD2Ev($ac);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      var $_3 = 0;
      __label__ = 18;
      break;
    }
   case 5:
    __ZN2js15AutoValueVectorC1EP9JSContext($vals, $cx);
    var $17 = $vals | 0;
    var $18 = $keys | 0;
    var $19 = __ZNK2js16AutoVectorRooterIiE6lengthEv($18);
    var $20 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6resizeEj($17, $19);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_2 = 0;
      __label__ = 17;
      break;
    }
   case 6:
    var $22 = __ZNK2js16AutoVectorRooterIiE6lengthEv($18);
    var $23 = $cx + 56 | 0;
    var $24 = $cx;
    var $_idx3 = $1 | 0;
    var $i_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $i_0;
    if ($i_0 >>> 0 < $22 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 8:
    var $28 = __ZN2js16AutoVectorRooterIiEixEj($18, $i_0);
    var $29 = HEAPU32[$28 >> 2];
    var $30 = _JSID_IS_INT($29);
    if (($30 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $33 = _JSID_TO_INT($29);
    __ZN2JSL10Int32ValueEi($1, $33);
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    var $34 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($24, $_idx3_val$0, $_idx3_val$1);
    if (($34 | 0) == 0) {
      var $_2 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $37 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($17, $i_0);
    __ZN2JS5Value9setStringEP8JSString($37, $34);
    __label__ = 14;
    break;
   case 11:
    var $39 = __ZL12JSID_IS_ATOMi($29);
    var $40 = ($39 | 0) == 0;
    var $41 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($17, $i_0);
    if ($40) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $43 = _JSID_TO_STRING($29);
    __ZN2JS5Value9setStringEP8JSString($41, $43);
    var $44 = HEAP32[$23 >> 2];
    var $45 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($17, $i_0);
    var $46 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($44, $cx, $45);
    if ($46) {
      __label__ = 14;
      break;
    } else {
      var $_2 = 0;
      __label__ = 17;
      break;
    }
   case 13:
    var $48 = _JSID_TO_OBJECT($29);
    __ZN2JS5Value9setObjectER8JSObject($41, $48);
    var $49 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($17, $i_0);
    var $50 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($5, $cx, $49);
    if ($50) {
      __label__ = 14;
      break;
    } else {
      var $_2 = 0;
      __label__ = 17;
      break;
    }
   case 14:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 7;
    break;
   case 15:
    var $54 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($17);
    var $55 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($17);
    var $56 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($cx, $54, $55);
    if (($56 | 0) == 0) {
      var $_2 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $_idx2_val = HEAP32[$args >> 2];
    var $59 = __ZNK2js12CallReceiver4rvalEv($_idx2_val);
    __ZN2JS5Value9setObjectER8JSObject($59, $56);
    var $_2 = 1;
    __label__ = 17;
    break;
   case 17:
    var $_2;
    __ZN2js15AutoValueVectorD1Ev($vals);
    var $_3 = $_2;
    __label__ = 18;
    break;
   case 18:
    var $_3;
    __ZN2js12AutoIdVectorD1Ev($keys);
    var $_4 = $_3;
    __label__ = 19;
    break;
   case 19:
    var $_4;
    STACKTOP = __stackBase__;
    return $_4;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL34DebuggerObject_getOwnPropertyNamesP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL29DebuggerObject_definePropertyP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 144;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $id = __stackBase__ + 8;
    var $descs = __stackBase__ + 12;
    var $ac = __stackBase__ + 80;
    var $ec = __stackBase__ + 132;
    var $dummy = __stackBase__ + 140;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE.__str122209 | 0);
    if (($1 | 0) == 0) {
      var $_3 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $5 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $6 = $5;
    if ($argc >>> 0 < 2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str88 | 0, 2);
    var $_3 = 0;
    __label__ = 14;
    break;
   case 4:
    var $args_idx2_val = HEAPU32[$args >> 2];
    var $10 = __ZNK2js8CallArgsixEj($args_idx2_val, 0);
    var $11 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($cx, $10, $id);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      var $_3 = 0;
      __label__ = 14;
      break;
    }
   case 5:
    __ZN2js23AutoPropDescArrayRooterC1EP9JSContext($descs, $cx);
    var $13 = __ZN2js23AutoPropDescArrayRooter6appendEv($descs);
    if (($13 | 0) == 0) {
      var $_2 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = __ZNK2js8CallArgsixEj($args_idx2_val, 1);
    var $17 = $cx;
    var $_idx4 = $16 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    var $18 = __ZN2js8PropDesc10initializeEP9JSContextRKN2JS5ValueEb($13, $17, $_idx4_val$0, $_idx4_val$1, 0);
    if ($18) {
      __label__ = 7;
      break;
    } else {
      var $_2 = 0;
      __label__ = 13;
      break;
    }
   case 7:
    var $20 = $13 | 0;
    __ZN2JS5Value12setUndefinedEv($20);
    var $21 = __ZL14UnwrapPropDescP9JSContextPN2js8DebuggerEP8JSObjectPNS1_8PropDescE($cx, $4, $6, $13);
    if ($21) {
      __label__ = 8;
      break;
    } else {
      var $_2 = 0;
      __label__ = 13;
      break;
    }
   case 8:
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $6);
    var $23 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($23) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $25 = __ZL17WrapIdAndPropDescP9JSContextP8JSObjectPiPN2js8PropDescE($cx, $6, $id, $13);
    if ($25) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_2 = 0;
    __label__ = 13;
    break;
   case 11:
    var $_idx1_val = HEAP32[$4 + 8 >> 2];
    var $27 = __ZNK2js8Debugger10toJSObjectEv($_idx1_val);
    __ZN2js11ErrorCopierC1ERNS_15AutoCompartmentEP8JSObject($ec, $ac, $27);
    var $28 = $5;
    var $29 = __ZN2js14DefinePropertyEP9JSContextP8JSObjectRKiRKNS_8PropDescEbPb($17, $28, $id, $13, $dummy);
    var $30 = $ec;
    __ZN2js11ErrorCopierD2Ev($30);
    __ZN2js15AutoCompartmentD2Ev($ac);
    if ($29) {
      __label__ = 12;
      break;
    } else {
      var $_2 = 0;
      __label__ = 13;
      break;
    }
   case 12:
    var $32 = __ZNK2js12CallReceiver4rvalEv($args_idx2_val);
    __ZN2JS5Value12setUndefinedEv($32);
    var $_2 = 1;
    __label__ = 13;
    break;
   case 13:
    var $_2;
    __ZN2js23AutoPropDescArrayRooterD1Ev($descs);
    var $_3 = $_2;
    __label__ = 14;
    break;
   case 14:
    var $_3;
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL29DebuggerObject_definePropertyP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL31DebuggerObject_definePropertiesP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 200;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $ids = __stackBase__ + 8;
    var $descs = __stackBase__ + 68;
    var $ac = __stackBase__ + 136;
    var $ec = __stackBase__ + 188;
    var $dummy = __stackBase__ + 196;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE.__str132210 | 0);
    if (($1 | 0) == 0) {
      var $_3 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $5 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $6 = $5;
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str84 | 0, 1);
    var $_3 = 0;
    __label__ = 22;
    break;
   case 4:
    var $args_idx_val = HEAPU32[$args >> 2];
    var $10 = __ZNK2js8CallArgsixEj($args_idx_val, 0);
    var $11 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $10);
    if (($11 | 0) == 0) {
      var $_3 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js12AutoIdVectorC1EP9JSContext($ids, $cx);
    __ZN2js23AutoPropDescArrayRooterC1EP9JSContext($descs, $cx);
    var $14 = $cx;
    var $15 = $11;
    var $16 = $ids;
    var $17 = $descs;
    var $18 = __ZN2js23ReadPropertyDescriptorsEP9JSContextP8JSObjectbPNS_12AutoIdVectorEPNS_23AutoPropDescArrayRooterE($14, $15, 0, $16, $17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      var $_2 = 0;
      __label__ = 21;
      break;
    }
   case 6:
    var $20 = $ids | 0;
    var $21 = __ZNK2js16AutoVectorRooterIiE6lengthEv($20);
    var $i_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $i_0;
    if ($i_0 >>> 0 < $21 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $25 = __ZN2js23AutoPropDescArrayRooterixEj($descs, $i_0);
    var $26 = __ZL14UnwrapPropDescP9JSContextPN2js8DebuggerEP8JSObjectPNS1_8PropDescE($cx, $4, $6, $25);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      var $_2 = 0;
      __label__ = 21;
      break;
    }
   case 9:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 7;
    break;
   case 10:
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $6);
    var $30 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($30) {
      var $i1_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 11:
    var $i1_0;
    if ($i1_0 >>> 0 < $21 >>> 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $33 = __ZN2js16AutoVectorRooterIiEixEj($20, $i1_0);
    var $34 = __ZN2js23AutoPropDescArrayRooterixEj($descs, $i1_0);
    var $35 = __ZL17WrapIdAndPropDescP9JSContextP8JSObjectPiPN2js8PropDescE($cx, $6, $33, $34);
    if ($35) {
      __label__ = 13;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 13:
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 11;
    break;
   case 14:
    var $_idx1_val = HEAP32[$4 + 8 >> 2];
    var $39 = __ZNK2js8Debugger10toJSObjectEv($_idx1_val);
    __ZN2js11ErrorCopierC1ERNS_15AutoCompartmentEP8JSObject($ec, $ac, $39);
    var $40 = $5;
    var $i2_0 = 0;
    __label__ = 15;
    break;
   case 15:
    var $i2_0;
    if ($i2_0 >>> 0 < $21 >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 16:
    var $44 = __ZN2js16AutoVectorRooterIiEixEj($20, $i2_0);
    var $45 = __ZN2js23AutoPropDescArrayRooterixEj($descs, $i2_0);
    var $46 = __ZN2js14DefinePropertyEP9JSContextP8JSObjectRKiRKNS_8PropDescEbPb($14, $40, $44, $45, $dummy);
    if ($46) {
      __label__ = 17;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 17:
    var $i2_0 = $i2_0 + 1 | 0;
    __label__ = 15;
    break;
   case 18:
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_2 = 0;
    __label__ = 21;
    break;
   case 19:
    var $50 = $ec;
    __ZN2js11ErrorCopierD2Ev($50);
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $51 = __ZNK2js12CallReceiver4rvalEv($args_idx_val);
    __ZN2JS5Value12setUndefinedEv($51);
    var $_2 = 1;
    __label__ = 21;
    break;
   case 20:
    var $52 = $ec;
    __ZN2js11ErrorCopierD2Ev($52);
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_2 = 0;
    __label__ = 21;
    break;
   case 21:
    var $_2;
    __ZN2js23AutoPropDescArrayRooterD1Ev($descs);
    __ZN2js12AutoIdVectorD1Ev($ids);
    var $_3 = $_2;
    __label__ = 22;
    break;
   case 22:
    var $_3;
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL31DebuggerObject_definePropertiesP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL29DebuggerObject_deletePropertyP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $arg = __stackBase__ + 8;
    var $id = __stackBase__ + 16;
    var $ac = __stackBase__ + 20;
    var $ec = __stackBase__ + 72;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE.__str72 | 0);
    if (($1 | 0) == 0) {
      var $_1 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $5 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $6 = $5;
    if (($argc | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $args_idx_val = HEAP32[$args >> 2];
    var $9 = __ZNK2js8CallArgsixEj($args_idx_val, 0);
    var $10 = $9 | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = $arg | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    __label__ = 5;
    break;
   case 4:
    __ZN2JSL14UndefinedValueEv($arg);
    __label__ = 5;
    break;
   case 5:
    var $15 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($cx, $arg, $id);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      var $_1 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $6);
    var $17 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($17) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $20 = HEAP32[$cx + 56 >> 2];
    var $21 = __ZN13JSCompartment6wrapIdEP9JSContextPi($20, $cx, $id);
    if ($21) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $_idx1_val = HEAP32[$4 + 8 >> 2];
    var $23 = __ZNK2js8Debugger10toJSObjectEv($_idx1_val);
    __ZN2js11ErrorCopierC1ERNS_15AutoCompartmentEP8JSObject($ec, $ac, $23);
    var $24 = HEAP32[$id >> 2];
    var $_idx2_val = HEAP32[$args >> 2];
    var $25 = __ZNK2js12CallReceiver4rvalEv($_idx2_val);
    var $26 = __ZN8JSObject14deletePropertyEP9JSContextiPN2JS5ValueEi($6, $cx, $24, $25, 0);
    var $27 = $ec;
    __ZN2js11ErrorCopierD2Ev($27);
    var $_0 = $26;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_1 = $_0;
    __label__ = 10;
    break;
   case 10:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL29DebuggerObject_deletePropertyP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL19DebuggerObject_sealP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL25DebuggerObject_sealHelperP9JSContextjPN2JS5ValueE12SealHelperOpPKc($cx, $argc, $vp, 0, STRING_TABLE.__str202217 | 0);
  return $1;
}

function __ZL21DebuggerObject_freezeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL25DebuggerObject_sealHelperP9JSContextjPN2JS5ValueE12SealHelperOpPKc($cx, $argc, $vp, 1, STRING_TABLE.__str182215 | 0);
  return $1;
}

function __ZL32DebuggerObject_preventExtensionsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL25DebuggerObject_sealHelperP9JSContextjPN2JS5ValueE12SealHelperOpPKc($cx, $argc, $vp, 2, STRING_TABLE.__str172214 | 0);
  return $1;
}

function __ZL23DebuggerObject_isSealedP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL29DebuggerObject_isSealedHelperP9JSContextjPN2JS5ValueE12SealHelperOpPKc($cx, $argc, $vp, 0, STRING_TABLE.__str212218 | 0);
  return $1;
}

function __ZL23DebuggerObject_isFrozenP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL29DebuggerObject_isSealedHelperP9JSContextjPN2JS5ValueE12SealHelperOpPKc($cx, $argc, $vp, 1, STRING_TABLE.__str192216 | 0);
  return $1;
}

function __ZL27DebuggerObject_isExtensibleP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL29DebuggerObject_isSealedHelperP9JSContextjPN2JS5ValueE12SealHelperOpPKc($cx, $argc, $vp, 2, STRING_TABLE.__str162213 | 0);
  return $1;
}

function __ZL20DebuggerObject_applyP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL11ApplyOrCallP9JSContextjPN2JS5ValueE15ApplyOrCallMode($cx, $argc, $vp, 0);
  return $1;
}

function __ZL19DebuggerObject_callP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL11ApplyOrCallP9JSContextjPN2JS5ValueE15ApplyOrCallMode($cx, $argc, $vp, 1);
  return $1;
}

function _JS_DefineDebuggerObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $objProto = __stackBase__;
    var $debugCtor = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 24;
    var $4 = $cx;
    var $5 = $obj;
    var $6 = $objProto;
    var $7 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($4, $5, 1, $6, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = HEAP32[$objProto >> 2];
    var $12 = $debugCtor;
    var $13 = __Z12js_InitClassP9JSContextP8JSObjectS2_PN2js5ClassEPFiS0_jPN2JS5ValueEEjP14JSPropertySpecP14JSFunctionSpecSC_SE_PS2_($4, $5, $11, __ZN2js8Debugger7jsclassE, 20, 1, __ZN2js8Debugger10propertiesE, __ZN2js8Debugger7methodsE, $12);
    var $14 = $13;
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($14, $cx);
    if ($17) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $20 = HEAP32[$debugCtor >> 2];
    var $21 = __Z12js_InitClassP9JSContextP8JSObjectS2_PN2js5ClassEPFiS0_jPN2JS5ValueEEjP14JSPropertySpecP14JSFunctionSpecSC_SE_PS2_($4, $20, $11, _DebuggerFrame_class, 22, 0, __ZL24DebuggerFrame_properties, __ZL21DebuggerFrame_methods, 0);
    var $22 = $21;
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $26 = HEAP32[$debugCtor >> 2];
    var $27 = __Z12js_InitClassP9JSContextP8JSObjectS2_PN2js5ClassEPFiS0_jPN2JS5ValueEEjP14JSPropertySpecP14JSFunctionSpecSC_SE_PS2_($4, $26, $11, _DebuggerScript_class, 24, 0, __ZL25DebuggerScript_properties, __ZL22DebuggerScript_methods, 0);
    var $28 = $27;
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $32 = HEAP32[$debugCtor >> 2];
    var $33 = __Z12js_InitClassP9JSContextP8JSObjectS2_PN2js5ClassEPFiS0_jPN2JS5ValueEEjP14JSPropertySpecP14JSFunctionSpecSC_SE_PS2_($4, $32, $11, _DebuggerObject_class, 26, 0, __ZL25DebuggerObject_properties, __ZL22DebuggerObject_methods, 0);
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $36 = $33;
    __ZN2JSL11ObjectValueER8JSObject($1, $22);
    var $_idx2 = $1 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($14, 0, $_idx2_val$0, $_idx2_val$1);
    __ZN2JSL11ObjectValueER8JSObject($2, $36);
    var $_idx1 = $2 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($14, 1, $_idx1_val$0, $_idx1_val$1);
    __ZN2JSL11ObjectValueER8JSObject($3, $28);
    var $_idx = $3 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($14, 2, $_idx_val$0, $_idx_val$1);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_DefineDebuggerObject["X"] = 1;

function __ZL23DebuggerFrame_constructP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  _JS_ReportErrorNumber($cx, 4, 9, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str83 | 0, tempInt));
  STACKTOP = __stackBase__;
  return 0;
}

function __ZL24DebuggerScript_constructP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  _JS_ReportErrorNumber($cx, 4, 9, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str82 | 0, tempInt));
  STACKTOP = __stackBase__;
  return 0;
}

function __ZL24DebuggerObject_constructP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  _JS_ReportErrorNumber($cx, 4, 9, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str3 | 0, tempInt));
  STACKTOP = __stackBase__;
  return 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE($this, $p_0) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE($this, $p_0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e_idx_val = HEAP32[$e >> 2];
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE12hasCollisionEv($e_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE10setRemovedEv($e);
    var $3 = $this + 20 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 12 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this >> 2];
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($_idx_val, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $17 = $this + 16 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 5;
    break;
   case 5:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $22 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isLiveEv($src_01_idx_val);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE10getKeyHashEv($src_01_idx1_val);
    var $25 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEENS_7MoveRefIT_EERSB_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEaSENS_7MoveRefIS8_EE($25, $_02_val);
    __label__ = 7;
    break;
   case 7:
    var $27 = $src_01 + 12 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($3);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($alloc_0_0_val, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js18RuntimeAllocPolicy7malloc_Ej($alloc_0_0_val, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEaSENS_7MoveRefIS8_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = $2 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIP8JSScriptP8JSObjectEEEENS_7MoveRefIT_EERS8_($1, $7);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEaSENS_7MoveRefIS5_EE($6, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEENS_7MoveRefIT_EERSB_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEC1ERS9_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js18RuntimeAllocPolicy5free_EPv($0);
  return;
}

function __ZN2js18RuntimeAllocPolicy5free_EPv($p) {
  __ZN9JSRuntime5free_EPv($p);
  return;
}

function __ZN9JSRuntime5free_EPv($p) {
  __ZN2js10Foreground5free_EPv($p);
  return;
}

function __ZN2js10Foreground5free_EPv($p) {
  _js_free($p);
  return;
}

function _js_free($p) {
  _free($p);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEC1ERS9_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEC2ERS9_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEaSENS_7MoveRefIS5_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIP8JSScriptP8JSObjectEEEptEv($rhs_0);
  var $4 = $3 | 0;
  __ZN2js4MoveIP8JSScriptEENS_7MoveRefIT_EERKS4_($1, $4);
  var $_idx2_val = HEAP32[$1 >> 2];
  var $5 = __ZNK2js7MoveRefIP8JSScriptEcvRS2_Ev($_idx2_val);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = $3 + 4 | 0;
  __ZN2js4MoveIP8JSObjectEENS_7MoveRefIT_EERS4_($2, $8);
  var $_idx_val = HEAP32[$2 >> 2];
  var $9 = __ZNK2js7MoveRefIP8JSObjectEcvRS2_Ev($_idx_val);
  var $10 = HEAP32[$9 >> 2];
  HEAP32[$this + 4 >> 2] = $10;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIP8JSScriptP8JSObjectEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js4MoveIP8JSScriptEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefIP8JSScriptEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js4MoveIP8JSObjectEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefIP8JSObjectEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIP8JSObjectEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIP8JSObjectEC2ERS2_($this, $t);
  return;
}

function __ZN2js7MoveRefIP8JSScriptEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIP8JSScriptEC2ERS2_($this, $t);
  return;
}

function __ZN2js18RuntimeAllocPolicy7malloc_Ej($this_0_0_val, $bytes) {
  var $1 = __ZN9JSRuntime7malloc_EjP9JSContext($this_0_0_val, $bytes, 0);
  return $1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC1Ev($this) {
  __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC2Ev($this);
  return;
}

function __ZN9JSRuntime7malloc_EjP9JSContext($this, $bytes, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __ZN9JSRuntime19updateMallocCounterEj($this, $bytes);
    var $1 = _js_malloc($bytes);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $5 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    __ZN9JSRuntime13onOutOfMemoryEPvjP9JSContext($cx);
    var $5 = 0;
    __label__ = 3;
    break;
   case 3:
    var $5;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime19updateMallocCounterEj($this, $nbytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 144096 | 0;
    var $3 = HEAP32[$1 >> 2] - $nbytes | 0;
    HEAP32[$1 >> 2] = $3;
    if (($3 | 0) < 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN9JSRuntime15onTooMuchMallocEv($this);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_malloc($bytes) {
  var $1 = _malloc($bytes);
  return $1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC1Ev($1);
  __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC1Ev($1);
  __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv($this) {
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefIPNS_10StackFrameEEcvRS2_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefIPNS_12GlobalObjectEEcvRS2_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js13PointerHasherIP8JSScriptLj2EE5matchERKS2_S5_($k_val, $l_val) {
  return ($k_val | 0) == ($l_val | 0);
}

function __ZN2js13PointerHasherIP8JSScriptLj2EE4hashERKS2_($l_val) {
  return $l_val >>> 2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this_0_2_val, $this_0_3_val, $this_0_5_val) {
  return ($this_0_5_val + $this_0_3_val | 0) >>> 0 >= ($this_0_2_val * 192 | 0) >>> 8 >>> 0;
}

function __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE12hasCollisionEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE12hasCollisionEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($e) {
  return $e | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC2ERKS2_RKS4_($this, $k_val, $v) {
  HEAP32[$this >> 2] = $k_val;
  var $3 = HEAP32[$v >> 2];
  HEAP32[$this + 4 >> 2] = $3;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE10setRemovedEv($this) {
  HEAP32[$this >> 2] = 1;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE7setFreeEv($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEaSERKS5_($this, $rhs) {
  var $2 = HEAP32[$rhs >> 2];
  HEAP32[$this >> 2] = $2;
  var $5 = HEAP32[$rhs + 4 >> 2];
  HEAP32[$this + 4 >> 2] = $5;
  return;
}

function __ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 8 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 12 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEC2ERS9_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefIPNS_10StackFrameEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE10endNoCheckEv($this_0_0_val, $this_0_1_val) {
  return $this_0_0_val + ($this_0_1_val << 2) | 0;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l_val1) {
  var $1 = __ZN2js13PointerHasherIP8JSScriptLj2EE4hashERKS2_($l_val1);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $l_val4 = HEAP32[$l >> 2];
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($6, $l_val4);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $l_val = HEAP32[$l >> 2];
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($27, $l_val);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($e, $l_val1) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($1);
  var $_val = HEAP32[$2 >> 2];
  var $3 = __ZN2js13PointerHasherIP8JSScriptLj2EE5matchERKS2_S5_($_val, $l_val1);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13relookupOrAddERNSE_6AddPtrERKS4_RKS7_($this, $p, $l, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$p + 4 >> 2];
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $2, 1);
    HEAP32[$p >> 2] = $3;
    var $_idx_val_idx_val = HEAP32[$3 >> 2];
    var $5 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($_idx_val_idx_val);
    if ($5) {
      var $9 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrERKS7_($this, $p, $t);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC1ERKS2_RKS4_($this, $k_val1, $v) {
  __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC2ERKS2_RKS4_($this, $k_val1, $v);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrERKS7_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEaSERKS5_($5, $t);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 12 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 8 >> 2];
    var $this_idx1 = $this + 12 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 20 >> 2];
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS4_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e_idx_val = HEAP32[$e >> 2];
    var $1 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE12hasCollisionEv($e_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e_idx_val = HEAP32[$e >> 2];
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE12hasCollisionEv($e_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE10setRemovedEv($e);
    var $3 = $this + 20 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 12 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEC1Ev($1);
  __ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEC1Ev($1);
  __ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEC1Ev($this) {
  __ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEC2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this >> 2];
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($_idx_val, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $17 = $this + 16 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 5;
    break;
   case 5:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $22 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isLiveEv($src_01_idx_val);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE10getKeyHashEv($src_01_idx1_val);
    var $25 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEENS_7MoveRefIT_EERSB_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEaSENS_7MoveRefIS8_EE($25, $_02_val);
    __label__ = 7;
    break;
   case 7:
    var $27 = $src_01 + 12 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($3);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($alloc_0_0_val, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js18RuntimeAllocPolicy7malloc_Ej($alloc_0_0_val, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEaSENS_7MoveRefIS8_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = $2 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEENS_7MoveRefIT_EERS8_($1, $7);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEaSENS_7MoveRefIS5_EE($6, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEENS_7MoveRefIT_EERSB_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEC1ERS9_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js18RuntimeAllocPolicy5free_EPv($0);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEC1ERS9_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEC2ERS9_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEaSENS_7MoveRefIS5_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEptEv($rhs_0);
  var $4 = $3 | 0;
  __ZN2js4MoveIPNS_10StackFrameEEENS_7MoveRefIT_EERKS4_($1, $4);
  var $_idx_val = HEAP32[$1 >> 2];
  var $5 = __ZNK2js7MoveRefIPNS_10StackFrameEEcvRS2_Ev($_idx_val);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = $3 + 4 | 0;
  __ZN2js4MoveIP8JSObjectEENS_7MoveRefIT_EERS4_($2, $8);
  var $_idx2_val = HEAP32[$2 >> 2];
  var $9 = __ZNK2js7MoveRefIP8JSObjectEcvRS2_Ev($_idx2_val);
  var $10 = HEAP32[$9 >> 2];
  HEAP32[$this + 4 >> 2] = $10;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js4MoveIPNS_10StackFrameEEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefIPNS_10StackFrameEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIPNS_10StackFrameEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIPNS_10StackFrameEEC2ERS2_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEC1Ev($2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC2ISC_EERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($1, $map);
  var $2 = $1;
  var $3 = $this;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  HEAP32[$this + 8 >> 2] = $map | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS6_6SetOpsES5_E3PtrE($this, $p_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE($1, $p_0);
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE($this, $p_0) {
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS4_EE($this, $p_0);
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv($this);
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j($10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + ($5 << 3) | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 5;
    break;
   case 5:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $22 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isLiveEv($src_01_idx_val);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE10getKeyHashEv($src_01_idx1_val);
    var $25 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEENS_7MoveRefIT_EERS8_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEEaSENS_7MoveRefIS5_EE($25, $_02_val);
    __label__ = 7;
    break;
   case 7:
    var $27 = $src_01 + 8 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($3);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j($capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 3;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej($1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + ($capacity << 3) | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 8 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 3) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + ($15 << 3) | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEEaSENS_7MoveRefIS5_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $2 + 4 | 0;
  __ZN2js4MoveIPNS_12GlobalObjectEEENS_7MoveRefIT_EERS4_($1, $6);
  var $_idx_val = HEAP32[$1 >> 2];
  var $7 = __ZNK2js7MoveRefIPNS_12GlobalObjectEEcvRS2_Ev($_idx_val);
  var $8 = HEAP32[$7 >> 2];
  HEAP32[$this + 4 >> 2] = $8;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv($0);
  return;
}

function __ZN2js17SystemAllocPolicy5free_EPv($p) {
  _js_free($p);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js4MoveIPNS_12GlobalObjectEEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefIPNS_12GlobalObjectEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIPNS_12GlobalObjectEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIPNS_12GlobalObjectEEC2ERS2_($this, $t);
  return;
}

function __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_($t) {
  return $t;
}

function __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5countEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv($this_0_1_val, $this_0_2_val, $this_0_4_val) {
  return ($this_0_4_val + $this_0_2_val | 0) >>> 0 >= ($this_0_1_val * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZN2js13PointerHasherIPNS_12GlobalObjectELj2EE5matchERKS2_S5_($k_val, $l_val) {
  return ($k_val | 0) == ($l_val | 0);
}

function __ZN2js13PointerHasherIPNS_12GlobalObjectELj2EE4hashERKS2_($l_val) {
  return $l_val >>> 2;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZNK7mozilla14AlignedStorageILj1EE4addrEv($this) {
  return $this;
}

function __ZN7mozilla14AlignedStorageILj1EE4addrEv($this) {
  return $this;
}

function __ZN2js7MoveRefIPNS_12GlobalObjectEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrdeEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js10VectorImplIPNS_8DebuggerELj0ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL4FindIP13JSCompartmentEEPT_S4_S4_RKS3_($beg, $end, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p_0 = $beg;
    __label__ = 2;
    break;
   case 2:
    var $p_0;
    if (($p_0 | 0) == ($end | 0)) {
      var $_0 = $end;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$p_0 >> 2] | 0) == (HEAP32[$v >> 2] | 0)) {
      var $_0 = $p_0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $p_0 = $p_0 + 4 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZN2js10VectorImplIP13JSCompartmentLj0ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZN2js17SystemAllocPolicy7malloc_Ej($bytes) {
  var $1 = _js_malloc($bytes);
  return $1;
}

function __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEEC2Ev($this);
  return;
}

function __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERS4_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS6_6SetOpsES5_E6AddPtrERS9_($this, $p, $t) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS4_($1, $p, $t);
  return $2;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS4_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$t >> 2];
    var $6 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$6 >> 2] = $3;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 8 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 16 >> 2];
    var $12 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERS4_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS4_($l_val);
  var $2 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS4_($l_val1) {
  var $1 = __ZN2js13PointerHasherIPNS_12GlobalObjectELj2EE4hashERKS2_($l_val1);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 3) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $l_val4 = HEAP32[$l >> 2];
    var $11 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_($6, $l_val4);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + ($26 << 3) | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $l_val = HEAP32[$l >> 2];
    var $35 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_($27, $l_val);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_jj["X"] = 1;

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_($e, $l_val1) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_($1);
  var $_val = HEAP32[$2 >> 2];
  var $3 = __ZN2js13PointerHasherIPNS_12GlobalObjectELj2EE5matchERKS2_S5_($_val, $l_val1);
  return $3;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE13growStorageByEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this >> 2];
    var $this_idx1 = $this + 4 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $5 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    var $5 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    HEAP32[$this_idx1 >> 2] = $5 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = $this + 12 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 2;
    var $7 = __ZN2js17SystemAllocPolicy7malloc_Ej($6);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $11 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $12 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplIPNS_8DebuggerELj0ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($8, $11, $12);
    HEAP32[$this_idx >> 2] = $8;
    HEAP32[$this + 8 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIPNS_8DebuggerELj0ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($curLength, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, 1);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $5;
    if ($5 >>> 0 > 536870911) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPNS_8DebuggerELj0ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = __ZN2js17SystemAllocPolicy8realloc_EPvjj($4, $1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5;
    var $9 = $v + 8 | 0;
    HEAP32[$2 >> 2] = $8;
    HEAP32[$9 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17SystemAllocPolicy8realloc_EPvjj($p, $bytes) {
  var $1 = _js_realloc($p, $bytes);
  return $1;
}

function _js_realloc($p, $bytes) {
  var $1 = _realloc($p, $bytes);
  return $1;
}

function __ZN2js11RoundUpPow2Ej($x) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($x >>> 0 < 2) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $x - 1 | 0;
    var $4 = _llvm_ctlz_i32($3);
    var $7 = 32 - $4 | 0;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return 1 << $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPNS_8DebuggerELj0ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIPNS_8DebuggerELj0ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE13growStorageByEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $5 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    var $5 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    HEAP32[$this_idx1 >> 2] = $5 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 2;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplIP13JSCompartmentLj0ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIP13JSCompartmentLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, 1);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP13JSCompartmentLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $3 = $v + 4 | 0;
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($2, $5, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    var $10 = $v + 12 | 0;
    HEAP32[$3 >> 2] = $9;
    HEAP32[$10 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15TempAllocPolicy8realloc_EPvjj($this, $p, $bytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_realloc($p, $bytes);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $p2_0 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this >> 2];
    __ZN2js15TempAllocPolicy13onOutOfMemoryEPvj($this_idx_val);
    var $p2_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $p2_0;
    return $p2_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15TempAllocPolicy7malloc_Ej($this, $bytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_malloc($bytes);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $p_0 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this >> 2];
    __ZN2js15TempAllocPolicy13onOutOfMemoryEPvj($this_idx_val);
    var $p_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $p_0;
    return $p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP13JSCompartmentLj0ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIP13JSCompartmentLj0ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15TempAllocPolicy5free_EPv($p) {
  _js_free($p);
  return;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZN9JSContext7malloc_Ej($this, $bytes) {
  var $2 = HEAP32[$this + 52 >> 2];
  var $3 = __ZN9JSRuntime7malloc_EjP9JSContext($2, $bytes, $this);
  return $3;
}

function __ZN9JSContext5free_EPv($p) {
  __ZN9JSRuntime5free_EPv($p);
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC2IS9_EERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3allEv($1, $map);
  var $2 = $1;
  var $3 = $this;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  HEAP32[$this + 8 >> 2] = $map | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3allEv($agg_result, $this_0_2_val, $this_0_6_val) {
  var $1 = $this_0_6_val + $this_0_2_val * 12 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_($agg_result, $this_0_6_val, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$4 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isLiveEv($_idx_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $this_0_2_val, $this_0_6_val) {
  var $1 = $this_0_6_val + $this_0_2_val * 12 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_($agg_result, $this_0_6_val, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$4 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isLiveEv($_idx_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE13growStorageByEj($this);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE13growStorageByEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $5 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    var $5 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    HEAP32[$this_idx1 >> 2] = $5 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj32EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 2;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplIP8JSObjectLj8ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIP8JSObjectLj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj8ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv($this) {
  return;
}

function __ZNK2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIP8JSObjectS3_EEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv($this) {
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this_0_2_val, $this_0_3_val, $this_0_5_val) {
  return ($this_0_5_val + $this_0_3_val | 0) >>> 0 >= ($this_0_2_val * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZN2js13PointerHasherIP8JSObjectLj2EE5matchERKS2_S5_($k_val, $l_val) {
  return ($k_val | 0) == ($l_val | 0);
}

function __ZN2js13PointerHasherIP8JSObjectLj2EE4hashERKS2_($l_val) {
  return $l_val >>> 2;
}

function __ZNK7mozilla14AlignedStorageILj32EE4addrEv($this) {
  return $this;
}

function __ZN2js10VectorImplIP8JSObjectLj8ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZN2js10VectorImplIPNS_10BreakpointELj0ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12HashMapEntryIP8JSObjectS2_EC2ERKS2_S5_($this, $k_val, $v) {
  HEAP32[$this >> 2] = $k_val;
  var $3 = HEAP32[$v >> 2];
  HEAP32[$this + 4 >> 2] = $3;
  return;
}

function __ZN2js12HashMapEntryIP8JSObjectS2_EaSERKS3_($this, $rhs) {
  var $2 = HEAP32[$rhs >> 2];
  HEAP32[$this >> 2] = $2;
  var $5 = HEAP32[$rhs + 4 >> 2];
  HEAP32[$this + 4 >> 2] = $5;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEC2ERS7_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectS3_EEEC2ERS4_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js12HashMapEntryIP8JSObjectS2_EC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE12setCollisionEj($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S2_EE($e) {
  return $e | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, 1);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP8JSObjectLj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj8ES3_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $3 = $v + 4 | 0;
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($2, $5, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    var $10 = $v + 12 | 0;
    HEAP32[$3 >> 2] = $9;
    HEAP32[$10 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP8JSObjectLj8ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIP8JSObjectLj8ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend);
  return;
}

function __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS4_($l_val);
  var $2 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry);
  return;
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE13growStorageByEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $5 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    var $5 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    HEAP32[$this_idx1 >> 2] = $5 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 2;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplIPNS_10BreakpointELj0ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIPNS_10BreakpointELj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, 1);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPNS_10BreakpointELj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $3 = $v + 4 | 0;
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($2, $5, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    var $10 = $v + 12 | 0;
    HEAP32[$3 >> 2] = $9;
    HEAP32[$10 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPNS_10BreakpointELj0ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIPNS_10BreakpointELj0ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3allEv($agg_result, $this_0_1_val, $this_0_5_val) {
  var $1 = $this_0_5_val + ($this_0_1_val << 3) | 0;
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC1EPNS0_14HashTableEntryIS4_EESF_($agg_result, $this_0_5_val, $1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC1EPNS0_14HashTableEntryIS4_EESF_($this, $c, $e) {
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC2EPNS0_14HashTableEntryIS4_EESF_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC2EPNS0_14HashTableEntryIS4_EESF_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$4 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isLiveEv($_idx_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 8 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E13relookupOrAddERNSC_6AddPtrERKS4_RKS5_($this, $p, $l, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$p + 4 >> 2];
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $2);
    HEAP32[$p >> 2] = $3;
    var $_idx_val_idx_val = HEAP32[$3 >> 2];
    var $5 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($_idx_val_idx_val);
    if ($5) {
      var $9 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrERKS5_($this, $p, $t);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12HashMapEntryIP8JSObjectS2_EC1ERKS2_S5_($this, $k_val1, $v) {
  __ZN2js12HashMapEntryIP8JSObjectS2_EC2ERKS2_S5_($this, $k_val1, $v);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $l_val4 = HEAP32[$l >> 2];
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($6, $l_val4);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE12setCollisionEj($entry_0);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $l_val = HEAP32[$l >> 2];
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($27, $l_val);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj["X"] = 1;

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrERKS5_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    __ZN2js12HashMapEntryIP8JSObjectS2_EaSERKS3_($5, $t);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 12 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 8 >> 2];
    var $this_idx1 = $this + 12 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 20 >> 2];
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this >> 2];
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($_idx_val, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $17 = $this + 16 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 5;
    break;
   case 5:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $22 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isLiveEv($src_01_idx_val);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE10getKeyHashEv($src_01_idx1_val);
    var $25 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEENS_7MoveRefIT_EERS9_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEEaSENS_7MoveRefIS6_EE($25, $_02_val);
    __label__ = 7;
    break;
   case 7:
    var $27 = $src_01 + 12 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($3);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($alloc_0_0_val, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js18RuntimeAllocPolicy7malloc_Ej($alloc_0_0_val, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEEaSENS_7MoveRefIS6_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = $2 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIP8JSObjectS3_EEEENS_7MoveRefIT_EERS6_($1, $7);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js12HashMapEntryIP8JSObjectS2_EaSENS_7MoveRefIS3_EE($6, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEENS_7MoveRefIT_EERS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js18RuntimeAllocPolicy5free_EPv($0);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEC1ERS7_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEC2ERS7_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIP8JSObjectS2_EaSENS_7MoveRefIS3_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIP8JSObjectS3_EEEptEv($rhs_0);
  var $4 = $3 | 0;
  __ZN2js4MoveIP8JSObjectEENS_7MoveRefIT_EERKS4_($1, $4);
  var $_idx1_val = HEAP32[$1 >> 2];
  var $5 = __ZNK2js7MoveRefIP8JSObjectEcvRS2_Ev($_idx1_val);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = $3 + 4 | 0;
  __ZN2js4MoveIP8JSObjectEENS_7MoveRefIT_EERS4_($2, $8);
  var $_idx_val = HEAP32[$2 >> 2];
  var $9 = __ZNK2js7MoveRefIP8JSObjectEcvRS2_Ev($_idx_val);
  var $10 = HEAP32[$9 >> 2];
  HEAP32[$this + 4 >> 2] = $10;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIP8JSObjectS3_EEEENS_7MoveRefIT_EERS6_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectS3_EEEC1ERS4_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectS3_EEEC1ERS4_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectS3_EEEC2ERS4_($this, $t);
  return;
}

function __ZN2js4MoveIP8JSObjectEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefIP8JSObjectEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP8JSObjectS2_EC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIP8JSObjectS2_EC1Ev($this) {
  __ZN2js12HashMapEntryIP8JSObjectS2_EC2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($e, $l_val1) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S2_EE($1);
  var $_val = HEAP32[$2 >> 2];
  var $3 = __ZN2js13PointerHasherIP8JSObjectLj2EE5matchERKS2_S5_($_val, $l_val1);
  return $3;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l_val1) {
  var $1 = __ZN2js13PointerHasherIP8JSObjectLj2EE4hashERKS2_($l_val1);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE($this, $p_0) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE($this, $p_0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv($this);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l_val1) {
  var $1 = __ZN2js13PointerHasherIPNS_10StackFrameELj2EE4hashERKS2_($l_val1);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry);
  return;
}

function __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js7MoveRefIN2JS5ValueEEcvRS2_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK8JSObject9getParentEv($this_0_5_val) {
  return $this_0_5_val;
}

function __ZNK8JSObject8numSlotsEv($this_0_7_val) {
  return $this_0_7_val;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js13PointerHasherIPNS_10StackFrameELj2EE5matchERKS2_S5_($k_val, $l_val) {
  return ($k_val | 0) == ($l_val | 0);
}

function __ZN2js13PointerHasherIPNS_10StackFrameELj2EE4hashERKS2_($l_val) {
  return $l_val >>> 2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this_0_2_val, $this_0_3_val, $this_0_5_val) {
  return ($this_0_5_val + $this_0_3_val | 0) >>> 0 >= ($this_0_2_val * 192 | 0) >>> 8 >>> 0;
}

function __ZNK2js5Class8isNativeEv($this_0_1_val) {
  return ($this_0_1_val & 524288 | 0) == 0;
}

function __ZNK8JSObject12isDenseArrayEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js10ArrayClassE | 0);
}

function __ZN2js5types10TypeObject17unknownPropertiesEv($this_0_3_val) {
  return ($this_0_3_val & 16777216 | 0) != 0;
}

function __ZNK7mozilla14AlignedStorageILj64EE4addrEv($this) {
  return $this;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($e) {
  return $e | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 3) | 0;
}

function __ZN2js7MoveRefIN2JS5ValueEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js2gcL15GetGCObjectKindEjb1($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject6setMapEPN2js5ShapeE($this, $amap) {
  HEAP32[$this >> 2] = $amap;
  var $3 = HEAP32[$amap >> 2];
  HEAP32[$this + 12 >> 2] = $3;
  return;
}

function __ZN2js11KidsPointer7setNullEv($this) {
  HEAP32[$this >> 2] = 0;
  return;
}

function __ZNK2js10EmptyShape8getClassEv($this) {
  return HEAP32[$this + 16 >> 2];
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $l_val4 = HEAP32[$l >> 2];
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($6, $l_val4);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $l_val = HEAP32[$l >> 2];
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($27, $l_val);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($e, $l_val1) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($1);
  var $_val = HEAP32[$2 >> 2];
  var $3 = __ZN2js13PointerHasherIPNS_10StackFrameELj2EE5matchERKS2_S5_($_val, $l_val1);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE6appendIS2_EEbT_($this, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $_0_0_0_val$0, $_0_0_0_val$1);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $5 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_03 = $1 | 0;
    var $st$1$0 = $_03 | 0;
    HEAP32[$st$1$0 >> 2] = $_0_0_0_val$0;
    var $st$1$1 = $_03 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $_0_0_0_val$1;
    var $5 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    HEAP32[$this_idx1 >> 2] = $5 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj64EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 3;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplIN2JS5ValueELj8ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIN2JS5ValueELj8ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj8ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 268435455) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 268435455) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIN2JS5ValueELj8ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj8ES3_EEj($v, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $v | 0;
    var $3 = $newcap << 3;
    var $4 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $v_idx = $v + 4 | 0;
    var $v_idx_val = HEAP32[$v_idx >> 2];
    var $8 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($v_idx_val);
    var $v_idx4 = $v + 8 | 0;
    var $v_idx4_val = HEAP32[$v_idx4 >> 2];
    var $9 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE10endNoCheckEv($v_idx_val, $v_idx4_val);
    if (($8 | 0) == ($9 | 0)) {
      var $22 = $v_idx_val;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx = $1 | 0;
    var $dst_01 = $5;
    var $src_02 = $8;
    var $v_idx1_val5 = $v_idx_val;
    var $v_idx2_val7 = $v_idx4_val;
    __label__ = 4;
    break;
   case 4:
    var $v_idx2_val7;
    var $v_idx1_val5;
    var $src_02;
    var $dst_01;
    if (($dst_01 | 0) == 0) {
      var $v_idx1_val = $v_idx1_val5;
      var $v_idx2_val = $v_idx2_val7;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = $dst_01 | 0;
    HEAP32[$13 >> 2] = 0;
    HEAP32[$13 + 4 >> 2] = 0;
    __ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERS4_($1, $src_02);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $14 = __ZNK2js7MoveRefIN2JS5ValueEEcvRS2_Ev($_idx_val);
    var $15 = $14 | 0;
    var $16$0 = HEAP32[$15 >> 2];
    var $16$1 = HEAP32[$15 + 4 >> 2];
    HEAP32[$13 >> 2] = $16$0;
    HEAP32[$13 + 4 >> 2] = $16$1;
    var $v_idx1_val = HEAP32[$v_idx >> 2];
    var $v_idx2_val = HEAP32[$v_idx4 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $v_idx2_val;
    var $v_idx1_val;
    var $18 = $dst_01 + 8 | 0;
    var $19 = $src_02 + 8 | 0;
    var $20 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE10endNoCheckEv($v_idx1_val, $v_idx2_val);
    if (($19 | 0) == ($20 | 0)) {
      var $22 = $v_idx1_val;
      __label__ = 7;
      break;
    } else {
      var $dst_01 = $18;
      var $src_02 = $19;
      var $v_idx1_val5 = $v_idx1_val;
      var $v_idx2_val7 = $v_idx2_val;
      __label__ = 4;
      break;
    }
   case 7:
    var $22;
    __ZN2js15TempAllocPolicy5free_EPv($22);
    HEAP32[$v_idx >> 2] = $5;
    HEAP32[$v + 12 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js10VectorImplIN2JS5ValueELj8ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj8ES3_EEj["X"] = 1;

function __ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefIN2JS5ValueEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIN2JS5ValueEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIN2JS5ValueEEC2ERS2_($this, $t);
  return;
}

function __ZN2js10VectorImplIN2JS5ValueELj8ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx = $1 | 0;
    var $p_01 = $srcbeg;
    var $_02 = $dst;
    __label__ = 3;
    break;
   case 3:
    var $_02;
    var $p_01;
    if (($_02 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $5 = $_02 | 0;
    HEAP32[$5 >> 2] = 0;
    HEAP32[$5 + 4 >> 2] = 0;
    __ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERKS4_($1, $p_01);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $6 = __ZNK2js7MoveRefIN2JS5ValueEEcvRS2_Ev($_idx_val);
    var $7 = $6 | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    HEAP32[$5 >> 2] = $8$0;
    HEAP32[$5 + 4 >> 2] = $8$1;
    __label__ = 5;
    break;
   case 5:
    var $10 = $p_01 + 8 | 0;
    if (($10 | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      var $p_01 = $10;
      var $_02 = $_02 + 8 | 0;
      __label__ = 3;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefIN2JS5ValueEEC1ERS2_($agg_result, $t);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3allEv($agg_result, $this_0_2_val, $this_0_6_val) {
  var $1 = $this_0_6_val + $this_0_2_val * 12 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_($agg_result, $this_0_6_val, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$4 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isLiveEv($_idx_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 12 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 8 >> 2];
    var $this_idx1 = $this + 12 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 20 >> 2];
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($proto | 0) != 0;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $5 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      var $5 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $5;
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($parent | 0) != 0 | $1 ^ 1) {
      var $12 = $parent;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $proto_idx_val = HEAP32[$proto + 20 >> 2];
    var $10 = __ZNK8JSObject9getParentEv($proto_idx_val);
    var $12 = $10;
    __label__ = 6;
    break;
   case 6:
    var $12;
    var $13 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, $clasp, $5, $12, 0, $13);
    var $clasp_idx_val = HEAP32[$clasp + 4 >> 2];
    var $14 = __ZNK2js5Class8isNativeEv($clasp_idx_val);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $16 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE($cx, $6, $clasp, $5, $kind);
    if ($16) {
      var $_0 = $6;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = 0;
    __label__ = 10;
    break;
   case 9:
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    var $_0 = $6;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($this, $cx, $fun, $markUnknown) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $1 = __ZNK8JSObject12isDenseArrayEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($this, $cx);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = $this + 16 | 0;
    var $7 = HEAP32[$6 >> 2];
    if (($7 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = HEAP32[$7 + 16 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$11 >> 2] | 0) == ($fun | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js5types10TypeObject14clearNewScriptEP9JSContext($7, $cx);
    __label__ = 7;
    break;
   case 7:
    if ($markUnknown) {
      __label__ = 8;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 8:
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $20 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($20) {
      __label__ = 9;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 9:
    var $22 = HEAP32[$6 >> 2];
    var $_idx_val = HEAP32[$22 + 12 >> 2];
    var $23 = __ZN2js5types10TypeObject17unknownPropertiesEv($_idx_val);
    if ($23) {
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2js5types10TypeObject11markUnknownEP9JSContext($22, $cx);
    __label__ = 12;
    break;
   case 11:
    __ZN8JSObject11makeNewTypeEP9JSContextP10JSFunctionb($this, $cx, $fun, $markUnknown);
    __label__ = 12;
    break;
   case 12:
    var $_0 = HEAP32[$6 >> 2];
    __label__ = 13;
    break;
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE($cx, $obj, $clasp, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
    var $obj_idx_val = HEAP32[$obj + 28 >> 2];
    var $5 = __ZNK8JSObject8numSlotsEv($obj_idx_val);
    if ($4 >>> 0 > $5 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $obj;
    var $9 = $cx;
    var $10 = __ZN8JSObject10allocSlotsEP9JSContextj($8, $9, $4);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $12 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($type, $clasp);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($type, $cx, $clasp, $kind);
    var $empty_0 = $14;
    __label__ = 6;
    break;
   case 5:
    var $16 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, $clasp);
    var $empty_0 = $16;
    __label__ = 6;
    break;
   case 6:
    var $empty_0;
    if (($empty_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($obj, $empty_0 | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject21setSharedNonNativeMapEv($this) {
  __ZN8JSObject6setMapEPN2js5ShapeE($this, __ZN2js5Shape15sharedNonNativeE);
  return;
}

function __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($this, $aclasp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this >> 2] | 0) == 0) {
      var $17 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$this + 4 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $17 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = HEAP32[$this + 8 >> 2];
    if (($10 | 0) == 0) {
      var $17 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = HEAP32[$10 >> 2];
    var $14 = __ZNK2js10EmptyShape8getClassEv($13);
    var $17 = ($14 | 0) == ($aclasp | 0);
    __label__ = 5;
    break;
   case 5:
    var $17;
    return $17;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($this, $cx, $aclasp, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $17 = $2;
      __label__ = 5;
      break;
    }
   case 2:
    var $5 = __ZN9JSContext7calloc_Ej($cx, 48);
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, $aclasp);
    var $10 = HEAP32[$1 >> 2];
    HEAP32[$10 >> 2] = $9;
    var $11 = HEAP32[$1 >> 2];
    if ((HEAP32[$11 >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $17 = $11;
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = $11;
    __ZN9JSContext5free_EPv($15);
    HEAP32[$1 >> 2] = 0;
    var $_0 = 0;
    __label__ = 8;
    break;
   case 5:
    var $17;
    var $19 = HEAP32[$17 + ($kind << 2) >> 2];
    if (($19 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $30 = $19;
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, $aclasp);
    var $24 = HEAP32[$1 >> 2] + ($kind << 2) | 0;
    HEAP32[$24 >> 2] = $22;
    var $27 = HEAP32[HEAP32[$1 >> 2] + ($kind << 2) >> 2];
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      var $30 = $27;
      __label__ = 7;
      break;
    }
   case 7:
    var $30;
    var $_0 = $30;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, $clasp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __ZN2js12PropertyTree8newShapeEP9JSContext($1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $2;
    var $_idx_val = HEAP32[HEAP32[$cx + 56 >> 2] >> 2];
    __ZN2js10EmptyShapeC1EP13JSCompartmentPNS_5ClassE($6, $_idx_val, $clasp);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10EmptyShapeC1EP13JSCompartmentPNS_5ClassE($this, $comp_0_0_val, $aclasp) {
  __ZN2js10EmptyShapeC2EP13JSCompartmentPNS_5ClassE($this, $comp_0_0_val, $aclasp);
  return;
}

function __ZN2js10EmptyShapeC2EP13JSCompartmentPNS_5ClassE($this, $comp_0_0_val, $aclasp) {
  var $1 = $this | 0;
  __ZN2js5ShapeC2EP13JSCompartmentPNS_5ClassE($1, $comp_0_0_val, $aclasp);
  return;
}

function __ZN2js5ShapeC2EP13JSCompartmentPNS_5ClassE($this, $comp_0_0_val, $aclasp) {
  var $1 = $this | 0;
  var $2 = __Z16js_GenerateShapeP9JSRuntime($comp_0_0_val);
  HEAP32[$1 >> 2] = $2;
  HEAP32[$this + 4 >> 2] = HEAPU32[$aclasp + 4 >> 2] >>> 8 & 255;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 4;
  HEAP32[$this + 16 >> 2] = $aclasp;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = -1;
  HEAP8[$this + 28 | 0] = 0;
  HEAP8[$this + 29 | 0] = 1;
  HEAP16[$this + 30 >> 1] = 0;
  HEAP32[$this + 32 >> 2] = 0;
  var $17 = $this + 36 | 0;
  __ZN2js11KidsPointer7setNullEv($17);
  return;
}

function __ZN9JSContext7calloc_Ej($this, $bytes) {
  var $2 = HEAP32[$this + 52 >> 2];
  var $3 = __ZN9JSRuntime7calloc_EjP9JSContext($2, $bytes, $this);
  return $3;
}

function __ZN9JSRuntime7calloc_EjP9JSContext($this, $bytes, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __ZN9JSRuntime19updateMallocCounterEj($this, $bytes);
    var $1 = _js_calloc($bytes);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $5 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    __ZN9JSRuntime13onOutOfMemoryEPvjP9JSContext($cx);
    var $5 = 0;
    __label__ = 3;
    break;
   case 3:
    var $5;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_calloc($bytes) {
  var $1 = _calloc($bytes);
  return $1;
}

function __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2($vec, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($len | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $i_01;
    var $2 = $vec + ($i_01 << 3) | 0;
    __ZN2JS5Value8setMagicE10JSWhyMagic($2, 0);
    var $3 = $i_01 + 1 | 0;
    if (($3 | 0) == ($len | 0)) {
      __label__ = 3;
      break;
    } else {
      var $i_01 = $3;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this >> 2];
    var $0 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($_idx_val, 16);
    HEAP32[$this + 24 >> 2] = $0;
    if (($0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, 4);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $0 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j(16);
    HEAP32[$this + 20 >> 2] = $0;
    if (($0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, 4);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this >> 2];
    var $0 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($_idx_val, 16);
    HEAP32[$this + 24 >> 2] = $0;
    if (($0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, 4);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefIPhEcvRS1_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefIPNS_14BreakpointSiteEEcvRS2_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3Ptr7nonNullEv($this) {
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE12hasCollisionEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE12hasCollisionEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js13PointerHasherIPhLj2EE5matchERKS1_S4_($k_val, $l_val) {
  return ($k_val | 0) == ($l_val | 0);
}

function __ZN2js13PointerHasherIPhLj2EE4hashERKS1_($l_val) {
  return $l_val >>> 2;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_($this) {
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC2ESB_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  return;
}

function __ZN2js11WeakMapBaseC2Ev($this) {
  HEAP32[$this >> 2] = __ZTVN2js11WeakMapBaseE + 8 | 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 8 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 12 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectS2_EC2EP8JSTracer($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC2ESB_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 8 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 12 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEC2ERS8_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC2ERS5_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefIPNS_14BreakpointSiteEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefIPhEC2ERS1_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEaSERKS4_($this, $rhs) {
  var $2 = HEAP32[$rhs >> 2];
  HEAP32[$this >> 2] = $2;
  var $5 = HEAP32[$rhs + 4 >> 2];
  HEAP32[$this + 4 >> 2] = $5;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S3_EE($e) {
  return $e | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrC2ERNS0_14HashTableEntryIS6_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this >> 2];
    var $0 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($_idx_val, 16);
    HEAP32[$this + 24 >> 2] = $0;
    if (($0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, 4);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES5_($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_($1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_($this) {
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_($this);
  return;
}

function __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES7_($this, $a_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC1ESB_($1, $a_0);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC1ESB_($this, $ap_01) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC2ESB_($this, $ap_01);
  return;
}

function __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEEC2EP9JSContext($this, $cx_0_11_val) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this + 8 | 0;
  __ZN2js18RuntimeAllocPolicyC1EP9JSContext($1, $cx_0_11_val);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES5_($2, $_0_val);
  var $3 = $this | 0;
  __ZN2js11WeakMapBaseC2Ev($3);
  HEAP32[$this >> 2] = __ZTVN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEEE + 8 | 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES5_($this, $a_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_EC1ES9_($1, $a_0);
  return;
}

function __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEE15nonMarkingTraceEP8JSTracer($this, $tracer) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $t = __stackBase__;
    var $r = __stackBase__ + 4;
    __ZN2js17DefaultMarkPolicyIP8JSObjectS2_EC1EP8JSTracer($t, $tracer);
    var $1 = $this + 8 | 0;
    __ZNK2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($r, $1);
    var $r_idx2 = $r | 0;
    var $r_idx2_val = HEAP32[$r_idx2 >> 2];
    var $r_idx3 = $r + 4 | 0;
    var $r_idx3_val = HEAP32[$r_idx3 >> 2];
    var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r_idx2_val, $r_idx3_val);
    if ($2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $t_idx_val = HEAP32[$t >> 2];
    var $r_idx4_val = $r_idx2_val;
    __label__ = 3;
    break;
   case 3:
    var $r_idx4_val;
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($r_idx4_val);
    var $5 = HEAP32[$3 + 4 >> 2];
    __ZN2js17DefaultMarkPolicyIP8JSObjectS2_E9markEntryES2_($t_idx_val, $5);
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($r);
    var $r_idx_val = HEAP32[$r_idx2 >> 2];
    var $r_idx1_val = HEAP32[$r_idx3 >> 2];
    var $6 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r_idx_val, $r_idx1_val);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      var $r_idx4_val = $r_idx_val;
      __label__ = 3;
      break;
    }
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEE15markIterativelyEP8JSTracer($this, $tracer) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $t = __stackBase__;
    var $r = __stackBase__ + 4;
    __ZN2js17DefaultMarkPolicyIP8JSObjectS2_EC1EP8JSTracer($t, $tracer);
    var $1 = $this + 8 | 0;
    __ZNK2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($r, $1);
    var $r_idx2 = $r | 0;
    var $r_idx2_val = HEAP32[$r_idx2 >> 2];
    var $r_idx3 = $r + 4 | 0;
    var $r_idx3_val = HEAP32[$r_idx3 >> 2];
    var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r_idx2_val, $r_idx3_val);
    if ($2) {
      var $markedAny_0_lcssa = 0;
      __label__ = 4;
      break;
    } else {
      var $markedAny_01 = 0;
      var $r_idx4_val = $r_idx2_val;
      __label__ = 2;
      break;
    }
   case 2:
    var $r_idx4_val;
    var $markedAny_01;
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($r_idx4_val);
    var $5 = HEAP32[$3 >> 2];
    var $7 = HEAP32[$3 + 4 >> 2];
    var $8 = __ZN2js17DefaultMarkPolicyIP8JSObjectS2_E15markEntryIfLiveES2_S2_($t, $5, $7);
    var $markedAny_1 = $8 ? 1 : $markedAny_01;
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($r);
    var $r_idx_val = HEAP32[$r_idx2 >> 2];
    var $r_idx1_val = HEAP32[$r_idx3 >> 2];
    var $9 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r_idx_val, $r_idx1_val);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $markedAny_01 = $markedAny_1;
      var $r_idx4_val = $r_idx_val;
      __label__ = 2;
      break;
    }
   case 3:
    var $markedAny_0_lcssa = ($markedAny_1 & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 4:
    var $markedAny_0_lcssa;
    STACKTOP = __stackBase__;
    return $markedAny_0_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEE5sweepEP8JSTracer($this, $tracer) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $t = __stackBase__;
    var $e = __stackBase__ + 4;
    __ZN2js17DefaultMarkPolicyIP8JSObjectS2_EC1EP8JSTracer($t, $tracer);
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumC1INS_7WeakMapIS4_S4_S8_NS_17DefaultMarkPolicyIS4_S4_EEEEEERT_($e, $this);
    var $1 = $e | 0;
    var $_idx2 = $e | 0;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $_idx3 = $e + 4 | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($_idx2_val, $_idx3_val);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $t_idx_val_idx = HEAP32[$t >> 2] | 0;
    var $_idx4_val = $_idx2_val;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev($e);
    STACKTOP = __stackBase__;
    return;
   case 4:
    var $_idx4_val;
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($_idx4_val);
    var $5 = HEAP32[$3 >> 2];
    var $t_idx_val_idx_val_idx_val_idx_val = HEAP32[HEAP32[HEAP32[$t_idx_val_idx >> 2] + 52 >> 2] + 144080 >> 2];
    var $6 = __ZN2js17DefaultMarkPolicyIP8JSObjectS2_E9keyMarkedES2_($t_idx_val_idx_val_idx_val_idx_val, $5);
    if ($6) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv($e);
    __label__ = 6;
    break;
   case 6:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($1);
    var $_idx_val = HEAP32[$_idx2 >> 2];
    var $_idx1_val = HEAP32[$_idx3 >> 2];
    var $9 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($_idx_val, $_idx1_val);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_idx4_val = $_idx_val;
      __label__ = 4;
      break;
    }
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectS2_EC1EP8JSTracer($this, $t) {
  __ZN2js17DefaultMarkPolicyIP8JSObjectS2_EC2EP8JSTracer($this, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumC1INS_7WeakMapIS4_S4_S8_NS_17DefaultMarkPolicyIS4_S4_EEEEEERT_($this, $map) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumC2INS_7WeakMapIS4_S4_S8_NS_17DefaultMarkPolicyIS4_S4_EEEEEERT_($this, $map);
  return;
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectS2_E9keyMarkedES2_($this_0_0_val_0_0_val_0_11_val_0_36_val, $k) {
  var $1 = $k;
  var $2 = __Z20IsAboutToBeFinalizedP9JSContextPKv($this_0_0_val_0_0_val_0_11_val_0_36_val, $1);
  return $2 ^ 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS5_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS5_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e_idx_val = HEAP32[$e >> 2];
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE12hasCollisionEv($e_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE10setRemovedEv($e);
    var $3 = $this + 20 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 12 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP8JSObjectS2_EC1Ev($1);
  __ZN2js12HashMapEntryIP8JSObjectS2_EaSERKS3_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP8JSObjectS2_EC1Ev($1);
  __ZN2js12HashMapEntryIP8JSObjectS2_EaSERKS3_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumC2INS_7WeakMapIS4_S4_S8_NS_17DefaultMarkPolicyIS4_S4_EEEEEERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $map + 8 | 0;
  __ZNK2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($1, $2);
  var $3 = $1;
  var $4 = $this;
  var $5$0 = HEAP32[$3 >> 2];
  var $5$1 = HEAP32[$3 + 4 >> 2];
  HEAP32[$4 >> 2] = $5$0;
  HEAP32[$4 + 4 >> 2] = $5$1;
  HEAP32[$this + 8 >> 2] = $2 | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectS2_E15markEntryIfLiveES2_S2_($this, $k, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx = $this | 0;
    var $this_idx_val_idx_val_idx_val_idx_val = HEAP32[HEAP32[HEAP32[HEAP32[$this_idx >> 2] >> 2] + 52 >> 2] + 144080 >> 2];
    var $1 = __ZN2js17DefaultMarkPolicyIP8JSObjectS2_E9keyMarkedES2_($this_idx_val_idx_val_idx_val_idx_val, $k);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $this_idx1_val_idx_val_idx_val_idx_val = HEAP32[HEAP32[HEAP32[HEAP32[$this_idx >> 2] >> 2] + 52 >> 2] + 144080 >> 2];
    var $3 = __ZN2js17DefaultMarkPolicyIP8JSObjectS2_E11valueMarkedES2_($this_idx1_val_idx_val_idx_val_idx_val, $v);
    if ($3) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = HEAP32[$this_idx >> 2];
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($5, $v);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectS2_E11valueMarkedES2_($this_0_0_val_0_0_val_0_11_val_0_36_val, $v) {
  var $1 = $v;
  var $2 = __Z20IsAboutToBeFinalizedP9JSContextPKv($this_0_0_val_0_0_val_0_11_val_0_36_val, $1);
  return $2 ^ 1;
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectS2_E9markEntryES2_($this_0_0_val, $v) {
  __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($this_0_0_val, $v);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_EC1ES9_($this, $ap_01) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap_01);
  return;
}

function __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES7_($this, $a_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC1ESB_($1, $a_0);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC1ESB_($this, $ap_01) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC2ESB_($this, $ap_01);
  return;
}

function __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE6lookupERKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6lookupERKS3_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrcvMSE_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 28,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS1_S3_EENS7_13MapHashPolicyES6_E3PtrE($this, $p_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6removeENSD_3PtrE($1, $p_0);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6removeENSD_3PtrE($this, $p_0) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6removeERNS0_14HashTableEntryIS6_EE($this, $p_0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E16checkUnderloadedEv($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6removeERNS0_14HashTableEntryIS6_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e_idx_val = HEAP32[$e >> 2];
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE12hasCollisionEv($e_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE10setRemovedEv($e);
    var $3 = $this + 20 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 12 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this >> 2];
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E11createTableERSA_j($_idx_val, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $17 = $this + 16 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 5;
    break;
   case 5:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $22 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isLiveEv($src_01_idx_val);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE10getKeyHashEv($src_01_idx1_val);
    var $25 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEENS_7MoveRefIT_EERSA_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEaSENS_7MoveRefIS7_EE($25, $_02_val);
    __label__ = 7;
    break;
   case 7:
    var $27 = $src_01 + 12 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E12destroyTableERSA_PNS0_14HashTableEntryIS6_EEj($3);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E15changeTableSizeEi["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E11createTableERSA_j($alloc_0_0_val, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js18RuntimeAllocPolicy7malloc_Ej($alloc_0_0_val, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEaSENS_7MoveRefIS7_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = $2 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEENS_7MoveRefIT_EERS7_($1, $7);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEaSENS_7MoveRefIS4_EE($6, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEENS_7MoveRefIT_EERSA_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEC1ERS8_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E12destroyTableERSA_PNS0_14HashTableEntryIS6_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js18RuntimeAllocPolicy5free_EPv($0);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEC1ERS8_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEC2ERS8_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEaSENS_7MoveRefIS4_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEptEv($rhs_0);
  var $4 = $3 | 0;
  __ZN2js4MoveIPhEENS_7MoveRefIT_EERKS3_($1, $4);
  var $_idx_val = HEAP32[$1 >> 2];
  var $5 = __ZNK2js7MoveRefIPhEcvRS1_Ev($_idx_val);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = $3 + 4 | 0;
  __ZN2js4MoveIPNS_14BreakpointSiteEEENS_7MoveRefIT_EERS4_($2, $8);
  var $_idx2_val = HEAP32[$2 >> 2];
  var $9 = __ZNK2js7MoveRefIPNS_14BreakpointSiteEEcvRS2_Ev($_idx2_val);
  var $10 = HEAP32[$9 >> 2];
  HEAP32[$this + 4 >> 2] = $10;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEENS_7MoveRefIT_EERS7_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC1ERS5_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC1ERS5_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC2ERS5_($this, $t);
  return;
}

function __ZN2js4MoveIPhEENS_7MoveRefIT_EERKS3_($agg_result, $t) {
  __ZN2js7MoveRefIPhEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js4MoveIPNS_14BreakpointSiteEEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefIPNS_14BreakpointSiteEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIPNS_14BreakpointSiteEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIPNS_14BreakpointSiteEEC2ERS2_($this, $t);
  return;
}

function __ZN2js7MoveRefIPhEC1ERS1_($this, $t) {
  __ZN2js7MoveRefIPhEC2ERS1_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEC1Ev($this) {
  __ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEC1Ev($1);
  __ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEaSERKS4_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEC1Ev($1);
  __ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEaSERKS4_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6lookupERKS3_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E11prepareHashERKS3_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6lookupERKS3_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrC1ERNS0_14HashTableEntryIS6_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E11prepareHashERKS3_($l_val1) {
  var $1 = __ZN2js13PointerHasherIPhLj2EE4hashERKS1_($l_val1);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrC1ERNS0_14HashTableEntryIS6_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrC2ERNS0_14HashTableEntryIS6_EE($this, $entry);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6lookupERKS3_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $l_val4 = HEAP32[$l >> 2];
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5matchERNS0_14HashTableEntryIS6_EERKS3_($6, $l_val4);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $l_val = HEAP32[$l >> 2];
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5matchERNS0_14HashTableEntryIS6_EERKS3_($27, $l_val);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6lookupERKS3_jj["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5matchERNS0_14HashTableEntryIS6_EERKS3_($e, $l_val1) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S3_EE($1);
  var $_val = HEAP32[$2 >> 2];
  var $3 = __ZN2js13PointerHasherIPhLj2EE5matchERKS1_S4_($_val, $l_val1);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE10isLiveHashEj($hash);
  return $1;
}

function __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js8CallArgs4argvEv($this_0_0_0_val) {
  return $this_0_0_0_val;
}

function __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE6lengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK8JSObject4typeEv($this_0_9_val) {
  return $this_0_9_val;
}

function __ZN2js5types8Property6getKeyEPS1_($p_0_0_val) {
  return $p_0_0_val;
}

function __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5emptyEv($this_0_2_val) {
  return ($this_0_2_val | 0) == 0;
}

function __ZNK8JSObject12isExtensibleEv($this_0_2_val) {
  return ($this_0_2_val & 4 | 0) == 0;
}

function __ZNK2js5Shape8isNativeEv($this) {
  return ($this | 0) != (__ZN2js5Shape15sharedNonNativeE | 0);
}

function __ZNK8JSObject11hasLazyTypeEv($this_0_2_val) {
  return ($this_0_2_val & 131072 | 0) != 0;
}

function __ZNK8JSObject16hasSingletonTypeEv($this_0_2_val) {
  return ($this_0_2_val & 65536 | 0) != 0;
}

function __ZNK2js5types10TypeObject17basePropertyCountEv($this_0_3_val) {
  return $this_0_3_val >>> 4 & 4095;
}

function __ZN7mozilla14AlignedStorageILj32EE4addrEv($this) {
  return $this;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 3) | 0;
}

function __ZN2js11ErrorCopierC2ERNS_15AutoCompartmentEP8JSObject($this, $ac, $scope) {
  HEAP32[$this >> 2] = $ac;
  HEAP32[$this + 4 >> 2] = $scope;
  return;
}

function __ZN2js12AutoGCRooterD2Ev($this_0_0_val, $this_0_2_val) {
  HEAP32[$this_0_2_val + 196 >> 2] = $this_0_0_val;
  return;
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZN2js12AutoGCRooterC2EP9JSContexti($this, $cx, $tag) {
  var $2 = $cx + 196 | 0;
  var $3 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $3;
  HEAP32[$this + 4 >> 2] = $tag;
  HEAP32[$this + 8 >> 2] = $cx;
  HEAP32[$2 >> 2] = $this;
  return;
}

function __ZL11ApplyOrCallP9JSContextjPN2JS5ValueE15ApplyOrCallMode($cx, $argc, $vp, $mode) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 180;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $calleev = __stackBase__ + 8;
    var $thisv = __stackBase__ + 16;
    var $callArgc = __stackBase__ + 24;
    var $argv = __stackBase__ + 28;
    var $ac = __stackBase__ + 120;
    var $1 = __stackBase__ + 172;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $2 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE.__str79 | 0);
    if (($2 | 0) == 0) {
      var $_2 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($2);
    var $_idx_val = HEAP32[$2 + 24 >> 2];
    var $6 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $7 = $6;
    __ZN2JSL11ObjectValueER8JSObject($calleev, $7);
    var $_idx4_val = HEAP32[$6 + 4 >> 2];
    var $9 = __ZN8JSObject10isCallableEv($_idx4_val);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK8JSObject8getClassEv($_idx4_val);
    var $13 = HEAP32[$11 >> 2];
    _JS_ReportErrorNumber($cx, 4, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str3 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str79 | 0, HEAP32[tempInt + 8 >> 2] = $13, tempInt));
    var $_2 = 0;
    __label__ = 34;
    break;
   case 4:
    var $15 = ($argc | 0) != 0;
    if ($15) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $args_idx6_val = HEAP32[$args >> 2];
    var $17 = __ZNK2js8CallArgsixEj($args_idx6_val, 0);
    var $18 = $17 | 0;
    var $st$4$0 = $18 | 0;
    var $19$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $18 + 4 | 0;
    var $19$1 = HEAP32[$st$4$1 >> 2];
    var $20 = $thisv | 0;
    HEAP32[$20 >> 2] = $19$0;
    HEAP32[$20 + 4 >> 2] = $19$1;
    __label__ = 7;
    break;
   case 6:
    __ZN2JSL14UndefinedValueEv($thisv);
    __label__ = 7;
    break;
   case 7:
    var $23 = __ZN2js8Debugger19unwrapDebuggeeValueEP9JSContextPN2JS5ValueE($5, $cx, $thisv);
    if ($23) {
      __label__ = 8;
      break;
    } else {
      var $_2 = 0;
      __label__ = 34;
      break;
    }
   case 8:
    HEAP32[$callArgc >> 2] = 0;
    __ZN2js15AutoValueVectorC1EP9JSContext($argv, $cx);
    if (($mode | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 9:
    if ($argc >>> 0 > 1) {
      __label__ = 10;
      break;
    } else {
      var $callArgv_0 = 0;
      var $58 = 0;
      __label__ = 21;
      break;
    }
   case 10:
    var $args_idx5_val = HEAP32[$args >> 2];
    var $29 = __ZNK2js8CallArgsixEj($args_idx5_val, 1);
    var $_idx8 = $29 | 0;
    var $st$4$0 = $_idx8 | 0;
    var $_idx8_val$0 = HEAPU32[$st$4$0 >> 2];
    var $st$4$1 = $_idx8 + 4 | 0;
    var $_idx8_val$1 = HEAPU32[$st$4$1 >> 2];
    var $30 = __ZNK2JS5Value17isNullOrUndefinedEv($_idx8_val$0, $_idx8_val$1);
    if ($30) {
      var $callArgv_0 = 0;
      var $58 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $32 = __ZNK2JS5Value8isObjectEv($_idx8_val$0, $_idx8_val$1);
    if ($32) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    _JS_ReportErrorNumber($cx, 4, 154, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str79 | 0, tempInt));
    var $_1 = 0;
    __label__ = 33;
    break;
   case 13:
    var $35 = __ZNK2JS5Value8toObjectEv($_idx8_val$0, $_idx8_val$1);
    var $36 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $35, $callArgc);
    if (($36 | 0) == 0) {
      var $_1 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $39 = HEAPU32[$callArgc >> 2];
    var $41 = $39 >>> 0 < 491520 ? $39 : 491520;
    HEAP32[$callArgc >> 2] = $41;
    var $42 = $argv | 0;
    var $43 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6growByEj($42, $41);
    if ($43) {
      __label__ = 15;
      break;
    } else {
      var $_1 = 0;
      __label__ = 33;
      break;
    }
   case 15:
    var $45 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($42);
    var $46 = __ZN2js11GetElementsEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $35, $41, $45);
    if ($46) {
      __label__ = 16;
      break;
    } else {
      var $_1 = 0;
      __label__ = 33;
      break;
    }
   case 16:
    var $48 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($42);
    var $callArgv_0 = $48;
    var $58 = $41;
    __label__ = 21;
    break;
   case 17:
    if ($15) {
      __label__ = 18;
      break;
    } else {
      var $54 = 0;
      __label__ = 20;
      break;
    }
   case 18:
    var $51 = $argc - 1 | 0;
    if ($51 >>> 0 < 491520) {
      __label__ = 19;
      break;
    } else {
      var $54 = 491520;
      __label__ = 20;
      break;
    }
   case 19:
    var $54 = $51;
    __label__ = 20;
    break;
   case 20:
    var $54;
    HEAP32[$callArgc >> 2] = $54;
    var $args_idx_val = HEAP32[$args >> 2];
    var $55 = __ZNK2js8CallArgs4argvEv($args_idx_val);
    var $callArgv_0 = $55 + 8 | 0;
    var $58 = $54;
    __label__ = 21;
    break;
   case 21:
    var $58;
    var $callArgv_0;
    var $i_0 = 0;
    var $60 = $58;
    __label__ = 22;
    break;
   case 22:
    var $60;
    var $i_0;
    if ($i_0 >>> 0 < $60 >>> 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 23:
    var $64 = __ZN2js8Debugger19unwrapDebuggeeValueEP9JSContextPN2JS5ValueE($5, $cx, $callArgv_0 + ($i_0 << 3) | 0);
    if ($64) {
      __label__ = 24;
      break;
    } else {
      var $_1 = 0;
      __label__ = 33;
      break;
    }
   case 24:
    var $i_0 = $i_0 + 1 | 0;
    var $60 = HEAP32[$callArgc >> 2];
    __label__ = 22;
    break;
   case 25:
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $7);
    var $68 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($68) {
      __label__ = 26;
      break;
    } else {
      var $_0 = 0;
      __label__ = 32;
      break;
    }
   case 26:
    var $70 = $cx + 56 | 0;
    var $71 = HEAP32[$70 >> 2];
    var $72 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($71, $cx, $calleev);
    if ($72) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 0;
      __label__ = 32;
      break;
    }
   case 27:
    var $74 = HEAP32[$70 >> 2];
    var $75 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($74, $cx, $thisv);
    if ($75) {
      var $i1_0 = 0;
      __label__ = 28;
      break;
    } else {
      var $_0 = 0;
      __label__ = 32;
      break;
    }
   case 28:
    var $i1_0;
    if ($i1_0 >>> 0 < $60 >>> 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 29:
    var $78 = HEAP32[$70 >> 2];
    var $80 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($78, $cx, $callArgv_0 + ($i1_0 << 3) | 0);
    if ($80) {
      __label__ = 30;
      break;
    } else {
      var $_0 = 0;
      __label__ = 32;
      break;
    }
   case 30:
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 28;
    break;
   case 31:
    var $84 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $thisv, $calleev, $60, $callArgv_0, $1);
    var $_idx7_val = HEAP32[$args >> 2];
    var $85 = __ZNK2js12CallReceiver4rvalEv($_idx7_val);
    var $_idx9 = $1 | 0;
    var $_idx9_val$0 = HEAP32[$_idx9 >> 2];
    var $_idx9_val$1 = HEAP32[$_idx9 + 4 >> 2];
    var $86 = __ZN2js8Debugger18newCompletionValueERNS_15AutoCompartmentEbN2JS5ValueEPS4_($5, $ac, $84, $_idx9_val$0, $_idx9_val$1, $85);
    var $_0 = $86 & 1;
    __label__ = 32;
    break;
   case 32:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_1 = $_0;
    __label__ = 33;
    break;
   case 33:
    var $_1;
    __ZN2js15AutoValueVectorD1Ev($argv);
    var $_2 = $_1;
    __label__ = 34;
    break;
   case 34:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11ApplyOrCallP9JSContextjPN2JS5ValueE15ApplyOrCallMode["X"] = 1;

function __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, $fnname) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx3_val = HEAP32[$args >> 2];
    var $1 = __ZNK2js12CallReceiver5thisvEv($_idx3_val);
    var $_idx1 = $1 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $2 = __ZNK2JS5Value8isObjectEv($_idx1_val$0, $_idx1_val$1);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z20ReportObjectRequiredP9JSContext($cx);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $5 = __ZNK2JS5Value8toObjectEv($_idx1_val$0, $_idx1_val$1);
    var $_idx4_val = HEAP32[$5 + 4 >> 2];
    var $6 = __ZNK8JSObject8getClassEv($_idx4_val);
    if (($6 | 0) == (_DebuggerObject_class | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = HEAP32[$6 >> 2];
    _JS_ReportErrorNumber($cx, 4, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str3 | 0, HEAP32[tempInt + 4 >> 2] = $fnname, HEAP32[tempInt + 8 >> 2] = $10, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 5:
    var $_idx_val = HEAP32[$5 + 24 >> 2];
    var $12 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($12 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $5;
      __label__ = 7;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 4, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str3 | 0, HEAP32[tempInt + 4 >> 2] = $fnname, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str11 | 0, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value17isNullOrUndefinedEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value6isNullEv($this_0_0_0_val$0, $this_0_0_0_val$1);
    if ($1) {
      var $5 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value11isUndefinedEv($this_0_0_0_val$0, $this_0_0_0_val$1);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEE6growByEj($this, $inc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    var $_idx = $this + 20 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $2 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE19growByUninitializedEj($1, $inc);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE6lengthEv($_idx_val);
    var $_idx1_val = HEAP32[$this + 16 >> 2];
    var $5 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE5beginEv($_idx1_val);
    var $6 = $5 + ($4 << 3) | 0;
    var $_idx3_val = HEAP32[$_idx >> 2];
    var $7 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE3endEv($_idx1_val, $_idx3_val);
    __ZN2jsL15MakeRangeGCSafeEPN2JS5ValueES2_($6, $7);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE19growByUninitializedEj($this, $incr) {
  var $1 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr);
  return $1;
}

function __ZN2jsL15MakeRangeGCSafeEPN2JS5ValueES2_($beg, $end) {
  var $4 = $end - $beg >> 3;
  __ZN2jsL7PodZeroIN2JS5ValueEEEvPT_j($beg, $4);
  return;
}

function __ZN2jsL7PodZeroIN2JS5ValueEEEvPT_j($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem << 3;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 8 | 0;
    var $4 = HEAPU32[$3 >> 2];
    if ((HEAP32[$this + 12 >> 2] - $4 | 0) >>> 0 < $incr >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $10 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = HEAP32[$3 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $10;
    HEAP32[$3 >> 2] = $10 + $incr | 0;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL29DebuggerObject_isSealedHelperP9JSContextjPN2JS5ValueE12SealHelperOpPKc($cx, $argc, $vp, $op, $name) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $ac = __stackBase__ + 8;
    var $ec = __stackBase__ + 60;
    var $r = __stackBase__ + 68;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, $name);
    if (($1 | 0) == 0) {
      var $_2 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $5 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $6 = $5;
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $6);
    var $7 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 0;
      __label__ = 9;
      break;
    }
   case 3:
    var $_idx1_val = HEAP32[$4 + 8 >> 2];
    var $9 = __ZNK2js8Debugger10toJSObjectEv($_idx1_val);
    __ZN2js11ErrorCopierC1ERNS_15AutoCompartmentEP8JSObject($ec, $ac, $9);
    if (($op | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($op | 0) == 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $11 = __ZN8JSObject8isSealedEP9JSContextPb($6, $cx, $r);
    if ($11) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $13 = __ZN8JSObject8isFrozenEP9JSContextPb($6, $cx, $r);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $_idx2_val = HEAP32[$5 + 8 >> 2];
    var $16 = __ZNK8JSObject12isExtensibleEv($_idx2_val);
    HEAP8[$r] = $16 & 1;
    __label__ = 7;
    break;
   case 7:
    var $_idx3_val = HEAP32[$args >> 2];
    var $18 = __ZNK2js12CallReceiver4rvalEv($_idx3_val);
    var $21 = (HEAP8[$r] & 1) << 24 >> 24 != 0;
    __ZN2JS5Value10setBooleanEb($18, $21);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    var $23 = $ec;
    __ZN2js11ErrorCopierD2Ev($23);
    var $_1 = $_0;
    __label__ = 9;
    break;
   case 9:
    var $_1;
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_2 = $_1;
    __label__ = 10;
    break;
   case 10:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ErrorCopierC1ERNS_15AutoCompartmentEP8JSObject($this, $ac, $scope) {
  __ZN2js11ErrorCopierC2ERNS_15AutoCompartmentEP8JSObject($this, $ac, $scope);
  return;
}

function __ZN8JSObject8isSealedEP9JSContextPb($this, $cx, $resultp) {
  var $1 = $this;
  var $2 = $cx;
  var $3 = __ZN8JSObject16isSealedOrFrozenEP9JSContextNS_16ImmutabilityTypeEPb($1, $2, 0, $resultp);
  return $3;
}

function __ZN8JSObject8isFrozenEP9JSContextPb($this, $cx, $resultp) {
  var $1 = $this;
  var $2 = $cx;
  var $3 = __ZN8JSObject16isSealedOrFrozenEP9JSContextNS_16ImmutabilityTypeEPb($1, $2, 1, $resultp);
  return $3;
}

function __ZL25DebuggerObject_sealHelperP9JSContextjPN2JS5ValueE12SealHelperOpPKc($cx, $argc, $vp, $op, $name) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 128;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $ac = __stackBase__ + 8;
    var $ec = __stackBase__ + 60;
    var $props = __stackBase__ + 68;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, $name);
    if (($1 | 0) == 0) {
      var $_2 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $5 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $6 = $5;
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $6);
    var $7 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 0;
      __label__ = 12;
      break;
    }
   case 3:
    var $_idx1_val = HEAP32[$4 + 8 >> 2];
    var $9 = __ZNK2js8Debugger10toJSObjectEv($_idx1_val);
    __ZN2js11ErrorCopierC1ERNS_15AutoCompartmentEP8JSObject($ec, $ac, $9);
    if (($op | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($op | 0) == 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $11 = __ZN8JSObject4sealEP9JSContext($6, $cx);
    var $ok_0 = $11 & 1;
    __label__ = 9;
    break;
   case 5:
    var $14 = __ZN8JSObject6freezeEP9JSContext($6, $cx);
    var $ok_0 = $14 & 1;
    __label__ = 9;
    break;
   case 6:
    var $_idx2_val = HEAP32[$5 + 8 >> 2];
    var $18 = __ZNK8JSObject12isExtensibleEv($_idx2_val);
    if ($18) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx4_val = HEAP32[$args >> 2];
    var $20 = __ZNK2js12CallReceiver4rvalEv($_idx4_val);
    __ZN2JS5Value12setUndefinedEv($20);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 8:
    __ZN2js12AutoIdVectorC1EP9JSContext($props, $cx);
    var $22 = __ZN8JSObject17preventExtensionsEP9JSContextPN2js12AutoIdVectorE($6, $cx, $props);
    var $23 = $22 & 1;
    __ZN2js12AutoIdVectorD1Ev($props);
    var $ok_0 = $23;
    __label__ = 9;
    break;
   case 9:
    var $ok_0;
    if ($ok_0 << 24 >> 24 == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_idx3_val = HEAP32[$args >> 2];
    var $27 = __ZNK2js12CallReceiver4rvalEv($_idx3_val);
    __ZN2JS5Value12setUndefinedEv($27);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    var $29 = $ec;
    __ZN2js11ErrorCopierD2Ev($29);
    var $_1 = $_0;
    __label__ = 12;
    break;
   case 12:
    var $_1;
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_2 = $_1;
    __label__ = 13;
    break;
   case 13:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL25DebuggerObject_sealHelperP9JSContextjPN2JS5ValueE12SealHelperOpPKc["X"] = 1;

function __ZN8JSObject4sealEP9JSContext($this, $cx) {
  var $1 = $this;
  var $2 = $cx;
  var $3 = __ZN8JSObject12sealOrFreezeEP9JSContextNS_16ImmutabilityTypeE($1, $2, 0);
  return $3;
}

function __ZN8JSObject6freezeEP9JSContext($this, $cx) {
  var $1 = $this;
  var $2 = $cx;
  var $3 = __ZN8JSObject12sealOrFreezeEP9JSContextNS_16ImmutabilityTypeE($1, $2, 1);
  return $3;
}

function __ZN2js12AutoIdVectorC1EP9JSContext($this, $cx) {
  __ZN2js12AutoIdVectorC2EP9JSContext($this, $cx);
  return;
}

function __ZN8JSObject17preventExtensionsEP9JSContextPN2js12AutoIdVectorE($this, $cx, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $success = __stackBase__;
    var $this_idx1_val = HEAP32[$this + 4 >> 2];
    var $1 = __ZNK8JSObject6getOpsEv($this_idx1_val);
    var $3 = HEAP32[$1 + 120 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = FUNCTION_TABLE[$3]($cx, $this, $success, $props);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP8[$success] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    _JS_ReportErrorNumber($cx, 4, 259, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 5:
    var $14 = $cx;
    var $15 = $this;
    var $16 = $props;
    var $17 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($14, $15, 24, $16);
    if ($17) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $this_idx_val = HEAP32[$this >> 2];
    var $19 = __ZNK8JSObject8isNativeEv($this_idx_val);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN8JSObject21extensibleShapeChangeEP9JSContext($this, $cx_idx_val);
    __label__ = 8;
    break;
   case 8:
    var $22 = $this + 8 | 0;
    var $24 = HEAP32[$22 >> 2] | 4;
    HEAP32[$22 >> 2] = $24;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12AutoIdVectorD1Ev($this) {
  __ZN2js12AutoIdVectorD2Ev($this);
  return;
}

function __ZN2js12AutoIdVectorD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js16AutoVectorRooterIiED2Ev($1);
  return;
}

function __ZN2js16AutoVectorRooterIiED2Ev($this) {
  var $1 = $this + 12 | 0;
  __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEED1Ev($1);
  var $_idx_val = HEAP32[$this >> 2];
  var $_idx1_val = HEAP32[$this + 8 >> 2];
  __ZN2js12AutoGCRooterD2Ev($_idx_val, $_idx1_val);
  return;
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj32EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZNK8JSObject6getOpsEv($this_0_1_val) {
  var $1 = __ZNK8JSObject8getClassEv($this_0_1_val);
  return $1 + 92 | 0;
}

function __ZNK8JSObject8isNativeEv($this_0_0_val) {
  var $1 = __ZNK2js5Shape8isNativeEv($this_0_0_val);
  return $1;
}

function __ZN8JSObject21extensibleShapeChangeEP9JSContext($this, $cx_0_11_val) {
  __ZN8JSObject16generateOwnShapeEP9JSContext($this, $cx_0_11_val);
  return;
}

function __ZN2js12AutoIdVectorC2EP9JSContext($this, $cx) {
  var $1 = $this | 0;
  __ZN2js16AutoVectorRooterIiEC2EP9JSContexti($1, $cx);
  return;
}

function __ZN2js16AutoVectorRooterIiEC2EP9JSContexti($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($2, $cx, -15);
  var $3 = $this + 12 | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEEC1ES1_($3, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEEC1ES1_($this, $ap_01) {
  __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEEC2ES1_($this, $ap_01);
  return;
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEEC2ES1_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj32EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 8;
  return;
}

function __ZN8JSObject14deletePropertyEP9JSContextiPN2JS5ValueEi($this, $cx, $id, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  __ZN2js5types4Type13UndefinedTypeEv($1);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiNS0_4TypeE($cx, $this, $id, $_0_val);
  __ZN2js5types26MarkTypePropertyConfiguredEP9JSContextP8JSObjecti($cx, $this, $id);
  var $this_idx_val = HEAP32[$this + 4 >> 2];
  var $2 = __ZNK8JSObject6getOpsEv($this_idx_val);
  var $4 = HEAP32[$2 + 100 >> 2];
  var $6 = ($4 | 0) != 0 ? $4 : 30;
  var $7 = FUNCTION_TABLE[$6]($cx, $this, $id, $rval, $strict);
  STACKTOP = __stackBase__;
  return $7;
}

function __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiNS0_4TypeE($cx, $obj, $id, $type_0) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cx_idx = $cx + 232 | 0;
    var $cx_idx_val = HEAP8[$cx_idx];
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $id;
      var $cx_idx1_val = $cx_idx_val;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js5types10MakeTypeIdEP9JSContexti($cx, $id);
    var $_0 = $3;
    var $cx_idx1_val = HEAP8[$cx_idx];
    __label__ = 3;
    break;
   case 3:
    var $cx_idx1_val;
    var $_0;
    var $5 = __ZN2js5types18TrackPropertyTypesEP9JSContextP8JSObjecti($cx_idx1_val, $obj, $_0);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $obj_idx_val = HEAP32[$obj + 36 >> 2];
    var $7 = __ZNK8JSObject4typeEv($obj_idx_val);
    __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextiNS0_4TypeE($7, $cx, $_0, $type_0);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types4Type13UndefinedTypeEv($agg_result) {
  __ZN2js5types4TypeC1Ej($agg_result, 2);
  return;
}

function __ZN2js5types26MarkTypePropertyConfiguredEP9JSContextP8JSObjecti($cx, $obj, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cx_idx = $cx + 232 | 0;
    var $cx_idx_val = HEAP8[$cx_idx];
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $id;
      var $cx_idx1_val = $cx_idx_val;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js5types10MakeTypeIdEP9JSContexti($cx, $id);
    var $_0 = $3;
    var $cx_idx1_val = HEAP8[$cx_idx];
    __label__ = 3;
    break;
   case 3:
    var $cx_idx1_val;
    var $_0;
    var $5 = __ZN2js5types18TrackPropertyTypesEP9JSContextP8JSObjecti($cx_idx1_val, $obj, $_0);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $obj_idx_val = HEAP32[$obj + 36 >> 2];
    var $7 = __ZNK8JSObject4typeEv($obj_idx_val);
    __ZN2js5types10TypeObject22markPropertyConfiguredEP9JSContexti($7, $cx, $_0);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10MakeTypeIdEP9JSContexti($cx, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_INT($id);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 2;
      __label__ = 7;
      break;
    }
   case 2:
    var $4 = _JSID_IS_STRING($id);
    if (($4 | 0) == 0) {
      var $_0 = 2;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = _JSID_TO_FLAT_STRING($id);
    var $8 = $7 | 0;
    var $9 = __ZN8JSString9getCharsZEP9JSContext($8, $cx);
    var $10 = HEAPU16[$9 >> 1];
    if ((($10 & 65535) - 48 | 0) >>> 0 < 10 | $10 << 16 >> 16 == 45) {
      var $_pn = $9;
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $_pn;
    var $cp_0 = $_pn + 2 | 0;
    var $15 = HEAPU16[$cp_0 >> 1];
    if ((($15 & 65535) - 48 | 0) >>> 0 < 10) {
      var $_pn = $cp_0;
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ($15 << 16 >> 16 == 0) {
      var $_0 = 2;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_0 = $id;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types18TrackPropertyTypesEP9JSContextP8JSObjecti($cx_0_33_val, $obj, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx_0_33_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $obj_idx1_val = HEAP32[$obj + 8 >> 2];
    var $3 = __ZNK8JSObject11hasLazyTypeEv($obj_idx1_val);
    if ($3) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $obj_idx2_val = HEAP32[$obj + 36 >> 2];
    var $5 = __ZNK8JSObject4typeEv($obj_idx2_val);
    var $_idx_val = HEAP32[$5 + 12 >> 2];
    var $6 = __ZN2js5types10TypeObject17unknownPropertiesEv($_idx_val);
    if ($6) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZNK8JSObject16hasSingletonTypeEv($obj_idx1_val);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $_idx4_val = HEAP32[$5 + 24 >> 2];
    var $10 = __ZN2js5types10TypeObject16maybeGetPropertyEP9JSContexti($_idx_val, $_idx4_val, $id);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObject16maybeGetPropertyEP9JSContexti($this_0_3_val, $this_0_6_val, $id) {
  var $1 = __ZNK2js5types10TypeObject17basePropertyCountEv($this_0_3_val);
  var $2 = __ZN2js5typesL13HashSetLookupIiNS0_8PropertyES2_EEPT0_PS4_jT_($this_0_6_val, $1, $id);
  var $5 = ($2 | 0) == 0 ? 0 : $2 + 4 | 0;
  return $5;
}

function __ZN2js5typesL13HashSetLookupIiNS0_8PropertyES2_EEPT0_PS4_jT_($values, $count, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($count | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($count | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $2 = $values;
    var $_idx2_val = HEAP32[$values >> 2];
    var $3 = __ZN2js5types8Property6getKeyEPS1_($_idx2_val);
    var $5 = ($3 | 0) == ($key | 0) ? $2 : 0;
    var $_0 = $5;
    __label__ = 11;
    break;
   case 3:
    if ($count >>> 0 < 9) {
      var $i_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $i_0;
    if ($i_0 >>> 0 < $count >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $11 = HEAPU32[$values + ($i_0 << 2) >> 2];
    var $_idx1_val = HEAP32[$11 >> 2];
    var $12 = __ZN2js5types8Property6getKeyEPS1_($_idx1_val);
    if (($12 | 0) == ($key | 0)) {
      var $_0 = $11;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 4;
    break;
   case 7:
    var $17 = __ZN2js5typesL15HashSetCapacityEj($count);
    var $18 = __ZN2js5typesL7HashKeyIiNS0_8PropertyEEEjT_($key);
    var $19 = $17 - 1 | 0;
    var $_pn = $18;
    __label__ = 8;
    break;
   case 8:
    var $_pn;
    var $pos_0 = $_pn & $19;
    var $22 = HEAP32[$values + ($pos_0 << 2) >> 2];
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_idx_val = HEAP32[$22 >> 2];
    var $25 = __ZN2js5types8Property6getKeyEPS1_($_idx_val);
    if (($25 | 0) == ($key | 0)) {
      var $_0 = $22;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_pn = $pos_0 + 1 | 0;
    __label__ = 8;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5typesL15HashSetCapacityEj($count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 < 9) {
      var $_0 = 8;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $count | 1;
    var $4 = _llvm_ctlz_i32($3);
    var $_0 = 1 << 33 - $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types8Property7keyBitsEi($id) {
  return $id;
}

function __ZNK14JSLinearString5charsEv($this_0_0_0_1_0_val) {
  return $this_0_0_0_1_0_val;
}

function __ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE6lengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZNK2js7MoveRefINS_8PropDescEEcvRS1_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function _JSID_IS_INT($iden) {
  return $iden & 1;
}

function _JSID_IS_STRING($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_TO_FLAT_STRING($id) {
  return $id;
}

function __ZNK8JSString6isFlatEv($this_0_0_0_val) {
  return ($this_0_0_0_val & 3 | 0) == 0;
}

function __ZNK8JSString11isDependentEv($this_0_0_0_val) {
  return ($this_0_0_0_val & 2 | 0) != 0;
}

function __ZNK8JSObject13isObjectProxyEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js16ObjectProxyClassE | 0) | ($this_0_1_val | 0) == (__ZN2js21OuterWindowProxyClassE | 0);
}

function __ZNK8JSObject15isFunctionProxyEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js18FunctionProxyClassE | 0);
}

function _JSID_TO_INT($iden) {
  return $iden >> 1;
}

function _JSID_TO_STRING($iden) {
  return $iden;
}

function _JSID_TO_OBJECT($iden) {
  return $iden & -8;
}

function __ZNK8JSObject10isFunctionEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js13FunctionClassE | 0);
}

function __ZN8JSString6asFlatEv($this) {
  return $this;
}

function __ZN8JSString11asDependentEv($this) {
  return $this;
}

function __ZN8JSString6asRopeEv($this) {
  return $this;
}

function __ZNK7mozilla14AlignedStorageILj40EE4addrEv($this) {
  return $this;
}

function __ZN7mozilla14AlignedStorageILj40EE4addrEv($this) {
  return $this;
}

function __ZN2js12CastAsObjectEPFiP9JSContextP8JSObjectiPN2JS5ValueEE($op) {
  return $op;
}

function __ZN2jsL16CastAsPropertyOpEP8JSObject($object) {
  return $object;
}

function __ZN2js12CastAsObjectEPFiP9JSContextP8JSObjectiiPN2JS5ValueEE($op) {
  return $op;
}

function __ZN2jsL22CastAsStrictPropertyOpEP8JSObject($object) {
  return $object;
}

function __ZN2js5types4TypeC2Ej($this, $data) {
  HEAP32[$this >> 2] = $data;
  return;
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + $this_0_2_val * 40 | 0;
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + $this_0_2_val * 40 | 0;
}

function __ZN2js7MoveRefINS_8PropDescEEC2ERS1_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function _STRING_TO_JSVAL_IMPL($agg_result, $str) {
  HEAP32[$agg_result + 4 >> 2] = -123;
  HEAP32[$agg_result >> 2] = $str;
  return;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE8shrinkByEj($this, $incr) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] - $incr | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js5typesL7HashKeyIiNS0_8PropertyEEEjT_($v) {
  var $1 = __ZN2js5types8Property7keyBitsEi($v);
  return ((($1 & 255 ^ 84696351) * 16777619 ^ $1 >>> 8 & 255) * 16777619 ^ $1 >>> 16 & 255) * 16777619 ^ $1 >>> 24;
}

function __ZN8JSString9getCharsZEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSString10ensureFlatEP9JSContext($this, $cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$1 + 4 >> 2];
    var $4 = __ZNK14JSLinearString5charsEv($_idx_val);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSString10ensureFlatEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx1_val = HEAP32[$this >> 2];
    var $1 = __ZNK8JSString6isFlatEv($this_idx1_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN8JSString6asFlatEv($this);
    var $14 = $3;
    __label__ = 6;
    break;
   case 3:
    var $5 = __ZNK8JSString11isDependentEv($this_idx1_val);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZN8JSString11asDependentEv($this);
    var $8 = __ZN17JSDependentString8undependEP9JSContext($7, $cx);
    var $14 = $8 | 0;
    __label__ = 6;
    break;
   case 5:
    var $11 = __ZN8JSString6asRopeEv($this);
    var $12 = __ZN6JSRope7flattenEP9JSContext($11, $cx);
    var $14 = $12;
    __label__ = 6;
    break;
   case 6:
    var $14;
    return $14;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types4TypeC1Ej($this, $data) {
  __ZN2js5types4TypeC2Ej($this, $data);
  return;
}

function __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $1 = __ZNK2JS5Value8isObjectEv($vp_idx_val$0, $vp_idx_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
    var $_0 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = $cx;
    var $6 = __ZN2js12ToObjectSlowEP9JSContextPN2JS5ValueE($5, $vp);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js23AutoPropDescArrayRooterC1EP9JSContext($this, $cx) {
  __ZN2js23AutoPropDescArrayRooterC2EP9JSContext($this, $cx);
  return;
}

function __ZNK2js16AutoVectorRooterIiE6lengthEv($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  var $1 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE6lengthEv($_idx_val);
  return $1;
}

function __ZL14UnwrapPropDescP9JSContextPN2js8DebuggerEP8JSObjectPNS1_8PropDescE($cx, $dbg, $obj, $desc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $desc + 33 | 0;
    var $2 = HEAP8[$1];
    if (($2 & 4) << 24 >> 24 == 0) {
      var $11 = $2;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $desc + 8 | 0;
    var $7 = __ZN2js8Debugger19unwrapDebuggeeValueEP9JSContextPN2JS5ValueE($dbg, $cx, $6);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $33 = 0;
      __label__ = 14;
      break;
    }
   case 3:
    var $_idx2 = $6 | 0;
    var $st$1$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$1$1 >> 2];
    var $$emscripten$temp$0 = STRING_TABLE.__str247540 | 0;
    var $9 = __ZL19CheckArgCompartmentP9JSContextP8JSObjectRKN2JS5ValueEPKcS8_($cx, $obj, $_idx2_val$0, $_idx2_val$1, $$emscripten$temp$0);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $33 = 0;
      __label__ = 14;
      break;
    }
   case 4:
    var $11 = HEAP8[$1];
    __label__ = 5;
    break;
   case 5:
    var $11;
    if (($11 & 1) << 24 >> 24 == 0) {
      var $22 = $11;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $desc + 16 | 0;
    var $16 = __ZN2js8Debugger19unwrapDebuggeeValueEP9JSContextPN2JS5ValueE($dbg, $cx, $15);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $33 = 0;
      __label__ = 14;
      break;
    }
   case 7:
    var $_idx1 = $15 | 0;
    var $st$1$0 = $_idx1 | 0;
    var $_idx1_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx1 + 4 | 0;
    var $_idx1_val$1 = HEAP32[$st$1$1 >> 2];
    var $$emscripten$temp$1 = STRING_TABLE.__str24079 | 0;
    var $18 = __ZL19CheckArgCompartmentP9JSContextP8JSObjectRKN2JS5ValueEPKcS8_($cx, $obj, $_idx1_val$0, $_idx1_val$1, $$emscripten$temp$1);
    if ($18) {
      __label__ = 8;
      break;
    } else {
      var $33 = 0;
      __label__ = 14;
      break;
    }
   case 8:
    var $20 = __ZN2js8PropDesc11checkGetterEP9JSContext($desc, $cx);
    if ($20) {
      __label__ = 9;
      break;
    } else {
      var $33 = 0;
      __label__ = 14;
      break;
    }
   case 9:
    var $22 = HEAP8[$1];
    __label__ = 10;
    break;
   case 10:
    var $22;
    if (($22 & 2) << 24 >> 24 == 0) {
      var $33 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = $desc + 24 | 0;
    var $27 = __ZN2js8Debugger19unwrapDebuggeeValueEP9JSContextPN2JS5ValueE($dbg, $cx, $26);
    if ($27) {
      __label__ = 12;
      break;
    } else {
      var $33 = 0;
      __label__ = 14;
      break;
    }
   case 12:
    var $_idx = $26 | 0;
    var $st$1$0 = $_idx | 0;
    var $_idx_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAP32[$st$1$1 >> 2];
    var $$emscripten$temp$2 = STRING_TABLE.__str44081 | 0;
    var $29 = __ZL19CheckArgCompartmentP9JSContextP8JSObjectRKN2JS5ValueEPKcS8_($cx, $obj, $_idx_val$0, $_idx_val$1, $$emscripten$temp$2);
    if ($29) {
      __label__ = 13;
      break;
    } else {
      var $33 = 0;
      __label__ = 14;
      break;
    }
   case 13:
    var $31 = __ZN2js8PropDesc11checkSetterEP9JSContext($desc, $cx);
    var $33 = $31;
    __label__ = 14;
    break;
   case 14:
    var $33;
    return $33;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14UnwrapPropDescP9JSContextPN2js8DebuggerEP8JSObjectPNS1_8PropDescE["X"] = 1;

function __ZN2js23AutoPropDescArrayRooterixEj($this, $i) {
  var $_idx_val = HEAP32[$this + 16 >> 2];
  var $1 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEEixEj($_idx_val, $i);
  return $1;
}

function __ZL17WrapIdAndPropDescP9JSContextP8JSObjectPiPN2js8PropDescE($cx, $obj, $idp, $desc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 56 >> 2];
    var $3 = __ZN13JSCompartment6wrapIdEP9JSContextPi($2, $cx, $idp);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $19 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $5 = $desc + 8 | 0;
    var $6 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($2, $cx, $5);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $19 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    var $8 = $desc + 16 | 0;
    var $9 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($2, $cx, $8);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $19 = 0;
      __label__ = 7;
      break;
    }
   case 4:
    var $11 = $desc + 24 | 0;
    var $12 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($2, $cx, $11);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      var $19 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $14 = __ZNK8JSObject7isProxyEv($obj_idx_val);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      var $19 = 1;
      __label__ = 7;
      break;
    }
   case 6:
    var $16 = $cx;
    var $17 = __ZN2js8PropDesc10makeObjectEP9JSContext($desc, $16);
    var $19 = $17;
    __label__ = 7;
    break;
   case 7:
    var $19;
    return $19;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16AutoVectorRooterIiEixEj($this, $i) {
  var $_idx_val = HEAP32[$this + 16 >> 2];
  var $1 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEEixEj($_idx_val, $i);
  return $1;
}

function __ZN2js23AutoPropDescArrayRooterD1Ev($this) {
  __ZN2js23AutoPropDescArrayRooterD2Ev($this);
  return;
}

function __ZN2js23AutoPropDescArrayRooterD2Ev($this) {
  var $1 = $this + 12 | 0;
  __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEED1Ev($1);
  var $_idx_val = HEAP32[$this >> 2];
  var $_idx1_val = HEAP32[$this + 8 >> 2];
  __ZN2js12AutoGCRooterD2Ev($_idx_val, $_idx1_val);
  return;
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj40EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEEixEj($this_0_1_val, $i) {
  var $1 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE5beginEv($this_0_1_val);
  return $1 + ($i << 2) | 0;
}

function __ZNK8JSObject7isProxyEv($this_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject13isObjectProxyEv($this_0_1_val);
    if ($1) {
      var $5 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject15isFunctionProxyEv($this_0_1_val);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEEixEj($this_0_1_val, $i) {
  var $1 = __ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE5beginEv($this_0_1_val);
  return $1 + $i * 40 | 0;
}

function __ZL19CheckArgCompartmentP9JSContextP8JSObjectRKN2JS5ValueEPKcS8_($cx, $obj, $v_0_0_0_val$0, $v_0_0_0_val$1, $propname) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $4 = $3;
    var $5 = __ZNK2js2gc4Cell11compartmentEv($4);
    var $6 = $obj;
    var $7 = __ZNK2js2gc4Cell11compartmentEv($6);
    if (($5 | 0) == ($7 | 0)) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 4, 285, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = STRING_TABLE.__str122209 | 0, HEAP32[tempInt + 4 >> 2] = $propname, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8PropDesc11checkGetterEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 33 | 0] & 1) << 24 >> 24 == 0) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1 = $this + 16 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $6 = __ZL13js_IsCallableRKN2JS5ValueE($_idx1_val$0, $_idx1_val$1);
    if ($6) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2JS5Value11isUndefinedEv($_idx1_val$0, $_idx1_val$1);
    if ($8) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _JS_ReportErrorNumber($cx, 4, 248, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str12882 | 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8PropDesc11checkSetterEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 33 | 0] & 2) << 24 >> 24 == 0) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1 = $this + 24 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $6 = __ZL13js_IsCallableRKN2JS5ValueE($_idx1_val$0, $_idx1_val$1);
    if ($6) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2JS5Value11isUndefinedEv($_idx1_val$0, $_idx1_val$1);
    if ($8) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _JS_ReportErrorNumber($cx, 4, 248, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str42885 | 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js23AutoPropDescArrayRooterC2EP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($2, $cx, -7);
  var $3 = $this + 12 | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEEC1ES2_($3, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEEC1ES2_($this, $ap_01) {
  __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEEC2ES2_($this, $ap_01);
  return;
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEEC2ES2_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj40EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 1;
  return;
}

function __ZN2js23AutoPropDescArrayRooter6appendEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 12 | 0;
    __ZN2js8PropDescC2Ev($1);
    var $3 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE6appendIS1_EEbT_($2, $1);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this + 16 >> 2];
    var $_idx1_val = HEAP32[$this + 20 >> 2];
    var $5 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE4backEv($_idx_val, $_idx1_val);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE6appendIS1_EEbT_($this, $0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 40;
  for (var $$src = tempParam >> 2, $$dest = $0 >> 2, $$stop = $$src + 10; $$src < $$stop; $$src++, $$dest++) {
    HEAP32[$$dest] = HEAP32[$$src];
  }
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __stackBase__;
    var $_040 = $0 | 0;
    var $tmp41$0 = HEAP32[$_040 >> 2];
    var $tmp41$1 = HEAP32[$_040 + 4 >> 2];
    var $_1434_0 = $0 + 8 | 0;
    var $tmp35$0 = HEAP32[$_1434_0 >> 2];
    var $tmp35$1 = HEAP32[$_1434_0 + 4 >> 2];
    var $_2530_0 = $0 + 16 | 0;
    var $tmp31$0 = HEAP32[$_2530_0 >> 2];
    var $tmp31$1 = HEAP32[$_2530_0 + 4 >> 2];
    var $_3626_0 = $0 + 24 | 0;
    var $tmp27$0 = HEAP32[$_3626_0 >> 2];
    var $tmp27$1 = HEAP32[$_3626_0 + 4 >> 2];
    var $4 = HEAPU32[$0 + 32 >> 2];
    var $6 = $4 & 255;
    var $8 = ($4 & 65535 & 65535) >>> 8 & 255;
    var $10 = $4 >>> 16 & 255;
    var $12 = $4 >>> 24 & 255;
    var $tmp14 = HEAPU16[$0 + 36 >> 1];
    var $14 = $tmp14 & 255;
    var $16 = ($tmp14 & 65535) >>> 8 & 255;
    var $tmp16 = HEAPU16[$0 + 38 >> 1];
    var $18 = $tmp16 & 255;
    var $20 = ($tmp16 & 65535) >>> 8 & 255;
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $27 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE13growStorageByEj($this);
    if ($27) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_038 = $2 | 0;
    HEAP32[$_038 >> 2] = $tmp41$0;
    HEAP32[$_038 + 4 >> 2] = $tmp41$1;
    var $_132_0 = $2 + 8 | 0;
    HEAP32[$_132_0 >> 2] = $tmp35$0;
    HEAP32[$_132_0 + 4 >> 2] = $tmp35$1;
    var $_228_0 = $2 + 16 | 0;
    HEAP32[$_228_0 >> 2] = $tmp31$0;
    HEAP32[$_228_0 + 4 >> 2] = $tmp31$1;
    var $_324_0 = $2 + 24 | 0;
    HEAP32[$_324_0 >> 2] = $tmp27$0;
    HEAP32[$_324_0 + 4 >> 2] = $tmp27$1;
    HEAP8[$2 + 32 | 0] = $6;
    HEAP8[$2 + 33 | 0] = $8;
    HEAP8[$2 + 34 | 0] = $10;
    HEAP8[$2 + 35 | 0] = $12;
    HEAP8[$2 + 36 | 0] = $14;
    HEAP8[$2 + 37 | 0] = $16;
    HEAP8[$2 + 38 | 0] = $18;
    HEAP8[$2 + 39 | 0] = $20;
    __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE14internalAppendIS1_EEvT_($this, $2);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE6appendIS1_EEbT_["X"] = 1;

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE4backEv($this_0_1_val, $this_0_2_val) {
  var $1 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val);
  return $1 - 40 | 0;
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE13growStorageByEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE17growHeapStorageByEj($this);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE14internalAppendIS1_EEvT_($this, $0) {
  var __stackBase__ = STACKTOP;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 40;
  for (var $$src = tempParam >> 2, $$dest = $0 >> 2, $$stop = $$src + 10; $$src < $$stop; $$src++, $$dest++) {
    HEAP32[$$dest] = HEAP32[$$src];
  }
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $2 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_3525_0 = $0 + 24 | 0;
    var $_2429_0 = $0 + 16 | 0;
    var $_1333_0 = $0 + 8 | 0;
    var $_038 = $0 | 0;
    var $tmp16 = HEAP8[$0 + 39 | 0];
    var $tmp15 = HEAP8[$0 + 38 | 0];
    var $tmp14 = HEAP8[$0 + 37 | 0];
    var $tmp13 = HEAP8[$0 + 36 | 0];
    var $tmp12 = HEAP8[$0 + 35 | 0];
    var $tmp11 = HEAP8[$0 + 34 | 0];
    var $tmp9 = HEAP8[$0 + 33 | 0];
    var $tmp7 = HEAP8[$0 + 32 | 0];
    var $tmp26$0 = HEAP32[$_3525_0 >> 2];
    var $tmp26$1 = HEAP32[$_3525_0 + 4 >> 2];
    var $tmp30$0 = HEAP32[$_2429_0 >> 2];
    var $tmp30$1 = HEAP32[$_2429_0 + 4 >> 2];
    var $tmp34$0 = HEAP32[$_1333_0 >> 2];
    var $tmp34$1 = HEAP32[$_1333_0 + 4 >> 2];
    var $tmp39$0 = HEAP32[$_038 >> 2];
    var $tmp39$1 = HEAP32[$_038 + 4 >> 2];
    var $_0 = $2 | 0;
    var $st$37$0 = $_0 | 0;
    HEAP32[$st$37$0 >> 2] = $tmp39$0;
    var $st$37$1 = $_0 + 4 | 0;
    HEAP32[$st$37$1 >> 2] = $tmp39$1;
    var $_131_0 = $2 + 8 | 0;
    var $st$42$0 = $_131_0 | 0;
    HEAP32[$st$42$0 >> 2] = $tmp34$0;
    var $st$42$1 = $_131_0 + 4 | 0;
    HEAP32[$st$42$1 >> 2] = $tmp34$1;
    var $_227_0 = $2 + 16 | 0;
    var $st$47$0 = $_227_0 | 0;
    HEAP32[$st$47$0 >> 2] = $tmp30$0;
    var $st$47$1 = $_227_0 + 4 | 0;
    HEAP32[$st$47$1 >> 2] = $tmp30$1;
    var $_323_0 = $2 + 24 | 0;
    var $st$52$0 = $_323_0 | 0;
    HEAP32[$st$52$0 >> 2] = $tmp26$0;
    var $st$52$1 = $_323_0 + 4 | 0;
    HEAP32[$st$52$1 >> 2] = $tmp26$1;
    HEAP8[$2 + 32 | 0] = $tmp7;
    HEAP8[$2 + 33 | 0] = $tmp9;
    HEAP8[$2 + 34 | 0] = $tmp11;
    HEAP8[$2 + 35 | 0] = $tmp12;
    HEAP8[$2 + 36 | 0] = $tmp13;
    HEAP8[$2 + 37 | 0] = $tmp14;
    HEAP8[$2 + 38 | 0] = $tmp15;
    HEAP8[$2 + 39 | 0] = $tmp16;
    var $6 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $6;
    HEAP32[$this_idx1 >> 2] = $6 + 1 | 0;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE14internalAppendIS1_EEvT_["X"] = 1;

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 * 40 | 0;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplINS_8PropDescELj1ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE17growHeapStorageByEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplINS_8PropDescELj1ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj1ES2_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, 1);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 33554431) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 33554431) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplINS_8PropDescELj1ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj1ES2_EEj($v, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $v | 0;
    var $3 = $newcap * 40 | 0;
    var $4 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $v_idx = $v + 4 | 0;
    var $v_idx_val = HEAP32[$v_idx >> 2];
    var $8 = __ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE12beginNoCheckEv($v_idx_val);
    var $v_idx4 = $v + 8 | 0;
    var $v_idx4_val = HEAP32[$v_idx4 >> 2];
    var $9 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE10endNoCheckEv($v_idx_val, $v_idx4_val);
    if (($8 | 0) == ($9 | 0)) {
      var $21 = $v_idx_val;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx = $1 | 0;
    var $dst_01 = $5;
    var $src_02 = $8;
    var $v_idx1_val5 = $v_idx_val;
    var $v_idx2_val7 = $v_idx4_val;
    __label__ = 4;
    break;
   case 4:
    var $v_idx2_val7;
    var $v_idx1_val5;
    var $src_02;
    var $dst_01;
    if (($dst_01 | 0) == 0) {
      var $v_idx1_val = $v_idx1_val5;
      var $v_idx2_val = $v_idx2_val7;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js4MoveINS_8PropDescEEENS_7MoveRefIT_EERS3_($1, $src_02);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $13 = __ZNK2js7MoveRefINS_8PropDescEEcvRS1_Ev($_idx_val);
    var $14 = $dst_01;
    var $15 = $13;
    for (var $$src = $15 >> 2, $$dest = $14 >> 2, $$stop = $$src + 10; $$src < $$stop; $$src++, $$dest++) {
      HEAP32[$$dest] = HEAP32[$$src];
    }
    var $v_idx1_val = HEAP32[$v_idx >> 2];
    var $v_idx2_val = HEAP32[$v_idx4 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $v_idx2_val;
    var $v_idx1_val;
    var $17 = $dst_01 + 40 | 0;
    var $18 = $src_02 + 40 | 0;
    var $19 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE10endNoCheckEv($v_idx1_val, $v_idx2_val);
    if (($18 | 0) == ($19 | 0)) {
      var $21 = $v_idx1_val;
      __label__ = 7;
      break;
    } else {
      var $dst_01 = $17;
      var $src_02 = $18;
      var $v_idx1_val5 = $v_idx1_val;
      var $v_idx2_val7 = $v_idx2_val;
      __label__ = 4;
      break;
    }
   case 7:
    var $21;
    __ZN2js15TempAllocPolicy5free_EPv($21);
    HEAP32[$v_idx >> 2] = $5;
    HEAP32[$v + 12 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_8PropDescEEENS_7MoveRefIT_EERS3_($agg_result, $t) {
  __ZN2js7MoveRefINS_8PropDescEEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_8PropDescEEC1ERS1_($this, $t) {
  __ZN2js7MoveRefINS_8PropDescEEC2ERS1_($this, $t);
  return;
}

function __ZN2js10VectorImplINS_8PropDescELj1ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_($dst, $srcbeg, $srcend) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx = $1 | 0;
    var $p_01 = $srcbeg;
    var $_02 = $dst;
    __label__ = 3;
    break;
   case 3:
    var $_02;
    var $p_01;
    if (($_02 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js4MoveINS_8PropDescEEENS_7MoveRefIT_EERKS3_($1, $p_01);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $5 = __ZNK2js7MoveRefINS_8PropDescEEcvRS1_Ev($_idx_val);
    var $6 = $_02;
    var $7 = $5;
    for (var $$src = $7 >> 2, $$dest = $6 >> 2, $$stop = $$src + 10; $$src < $$stop; $$src++, $$dest++) {
      HEAP32[$$dest] = HEAP32[$$src];
    }
    __label__ = 5;
    break;
   case 5:
    var $9 = $p_01 + 40 | 0;
    if (($9 | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      var $p_01 = $9;
      var $_02 = $_02 + 40 | 0;
      __label__ = 3;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_8PropDescEEENS_7MoveRefIT_EERKS3_($agg_result, $t) {
  __ZN2js7MoveRefINS_8PropDescEEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEE6resizeEj($this, $newLength) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    var $_idx = $this + 20 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $2 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE6lengthEv($_idx_val);
    if ($2 >>> 0 < $newLength >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 - $newLength | 0;
    __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE8shrinkByEj($1, $5);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $7 = $newLength - $2 | 0;
    var $8 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE19growByUninitializedEj($1, $7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx1_val = HEAP32[$this + 16 >> 2];
    var $10 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE5beginEv($_idx1_val);
    var $11 = $10 + ($2 << 3) | 0;
    var $_idx3_val = HEAP32[$_idx >> 2];
    var $12 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE3endEv($_idx1_val, $_idx3_val);
    __ZN2jsL15MakeRangeGCSafeEPN2JS5ValueES2_($11, $12);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL10Int32ValueEi($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($this, $i) {
  var $_idx_val = HEAP32[$this + 16 >> 2];
  var $1 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEEixEj($_idx_val, $i);
  return $1;
}

function __ZN2JS5Value9setStringEP8JSString($this, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _STRING_TO_JSVAL_IMPL($1, $str);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZL12JSID_IS_ATOMi($id) {
  var $1 = _JSID_IS_STRING($id);
  return $1;
}

function __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  var $1 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE6lengthEv($_idx_val);
  return $1;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEEixEj($this_0_1_val, $i) {
  var $1 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE5beginEv($this_0_1_val);
  return $1 + ($i << 3) | 0;
}

function __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($this, $cx) {
  __ZN2js28AutoPropertyDescriptorRooterC2EP9JSContext($this, $cx);
  return;
}

function __ZN2JSL17ObjectOrNullValueEP8JSObject5($agg_result, $obj) {
  __ZN2JS5Value15setObjectOrNullEP8JSObject($agg_result, $obj);
  return;
}

function __ZN2js28AutoPropertyDescriptorRooterD1Ev($this) {
  __ZN2js28AutoPropertyDescriptorRooterD2Ev($this);
  return;
}

function __ZN2js28AutoPropertyDescriptorRooterD2Ev($this) {
  var $_idx_val = HEAP32[$this >> 2];
  var $_idx1_val = HEAP32[$this + 8 >> 2];
  __ZN2js12AutoGCRooterD2Ev($_idx_val, $_idx1_val);
  return;
}

function __ZN2js28AutoPropertyDescriptorRooterC2EP9JSContext($this, $cx) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($1, $cx, -13);
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  HEAP32[$this + 28 >> 2] = 0;
  var $6 = $this + 32 | 0;
  __ZN2JS5Value12setUndefinedEv($6);
  return;
}

function __ZNK8JSObject18getFunctionPrivateEv($this_0_6_val) {
  var $1 = __ZNK8JSObject10getPrivateEv($this_0_6_val);
  return $1;
}

function __ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK8JSObject8getProtoEv($this_0_9_val_0_0_val) {
  return $this_0_9_val_0_0_val;
}

function __ZNK2js10StackFrame4prevEv($this_0_4_val) {
  return $this_0_4_val;
}

function _JSVAL_TO_INT32_IMPL($l_0$0, $l_0$1) {
  return $l_0$0;
}

function __ZNK2js12StackSegment9maybeRegsEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZNK10JSFunction4kindEv($this_0_2_val) {
  return $this_0_2_val & -16384;
}

function __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($this_0_0_val) {
  return ($this_0_0_val & 10 | 0) == 2;
}

function __ZNK2js10StackFrame10hasCallObjEv($this_0_0_val) {
  return ($this_0_0_val & 16384 | 0) != 0;
}

function __ZNK8JSString6lengthEv($this_0_0_0_val) {
  return $this_0_0_0_val >>> 4;
}

function __ZNK8JSString8isLinearEv($this_0_0_0_val) {
  return ($this_0_0_0_val & 1 | 0) == 0;
}

function _JSVAL_TO_STRING_IMPL($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_IS_STRING_IMPL($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -123) & 1;
}

function __ZNK2js10StackFrame13isGlobalFrameEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function __ZNK2js10StackFrame15isFunctionFrameEv($this_0_0_val) {
  return ($this_0_0_val & 2 | 0) != 0;
}

function __ZNK2js10StackFrame12isDummyFrameEv($this_0_0_val) {
  return ($this_0_0_val & 4 | 0) != 0;
}

function __ZNK2js10StackFrame16isGeneratorFrameEv($this_0_0_val) {
  return ($this_0_0_val & 32 | 0) != 0;
}

function __ZNK2js10StackFrame14isConstructingEv($this_0_0_val) {
  return ($this_0_0_val & 128 | 0) != 0;
}

function _INT_TO_JSID($i) {
  return $i << 1 | 1;
}

function __ZNK2js10StackFrame10hasArgsObjEv($this_0_0_val) {
  return ($this_0_0_val & 32768 | 0) != 0;
}

function __ZNK8JSObject13numFixedSlotsEv($this_0_2_val) {
  return $this_0_2_val >>> 27;
}

function __ZNK8JSScript10getVersionEv($this_0_3_val) {
  return $this_0_3_val & 65535;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($this_0_0_val, $this_0_1_val) {
  return ($this_0_0_val | 0) == ($this_0_1_val | 0);
}

function __ZN8JSString8asLinearEv($this) {
  return $this;
}

function _DOUBLE_TO_JSVAL_IMPL($agg_result, $d) {
  var $1 = $agg_result;
  tempDoubleF64[0] = $d, HEAP32[$1 >> 2] = tempDoubleI32[0], HEAP32[$1 + 4 >> 2] = tempDoubleI32[1];
  return;
}

function _JSDOUBLE_IS_NEGZERO($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d != 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $_0 = tempDoubleI32[1] >>> 31 | 0 << 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZN2JS6AnchorIP8JSStringEC2ES2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js10StackFrame3funEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js10StackFrame7argsObjEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN2js20CallReceiverFromArgvEPN2JS5ValueE($agg_result, $argv) {
  HEAP32[$agg_result >> 2] = $argv;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5frontEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZNK10JSFunction13isInterpretedEv($this_0_2_val) {
  var $1 = __ZNK10JSFunction4kindEv($this_0_2_val);
  return ($1 & 65535) > 16383;
}

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEC1ES3_($this, $ap_01) {
  __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap_01);
  return;
}

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEixEj($this_0_1_val, $i) {
  var $1 = __ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE5beginEv($this_0_1_val);
  return $1 + ($i << 2) | 0;
}

function __ZN2JSL11StringValueEP8JSString($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZL17DebuggerFrameEvalP9JSContextjPN2JS5ValueE16EvalBindingsMode($cx, $argc, $vp, $mode) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 224;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $keys = __stackBase__ + 8;
    var $values = __stackBase__ + 68;
    var $ac = __stackBase__ + 160;
    var $anchor = __stackBase__ + 212;
    var $1 = __stackBase__ + 216;
    var $2 = ($mode | 0) == 1;
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    if ($argc >>> 0 < 2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str96 | 0, 2);
    var $_2 = 0;
    __label__ = 33;
    break;
   case 4:
    if (($argc | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str97 | 0, 1);
    var $_2 = 0;
    __label__ = 33;
    break;
   case 6:
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $10 = $2 ? STRING_TABLE.__str61 | 0 : STRING_TABLE.__str60 | 0;
    var $11 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, $10, 1);
    if (($11 | 0) == 0) {
      var $_2 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx_val = HEAP32[$11 + 24 >> 2];
    var $14 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $15 = $14;
    var $16 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($11);
    var $args_idx6_val = HEAPU32[$args >> 2];
    var $17 = __ZNK2js8CallArgsixEj($args_idx6_val, 0);
    var $_idx5 = $17 | 0;
    var $_idx5_val$0 = HEAP32[$_idx5 >> 2];
    var $_idx5_val$1 = HEAP32[$_idx5 + 4 >> 2];
    var $18 = __ZNK2JS5Value8isStringEv($_idx5_val$0, $_idx5_val$1);
    if ($18) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = __ZN2js21InformalValueTypeNameERKN2JS5ValueE($_idx5_val$0, $_idx5_val$1);
    _JS_ReportErrorNumber($cx, 4, 255, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str97 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str268561 | 0, HEAP32[tempInt + 8 >> 2] = $20, tempInt));
    var $_2 = 0;
    __label__ = 33;
    break;
   case 9:
    var $22 = __ZNK2JS5Value8toStringEv($_idx5_val$0, $_idx5_val$1);
    var $23 = __ZN8JSString12ensureLinearEP9JSContext($22, $cx);
    if (($23 | 0) == 0) {
      var $_2 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2js12AutoIdVectorC1EP9JSContext($keys, $cx);
    __ZN2js15AutoValueVectorC1EP9JSContext($values, $cx);
    if ($2) {
      __label__ = 11;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 11:
    var $27 = __ZNK2js8CallArgsixEj($args_idx6_val, 1);
    var $28 = $cx;
    var $_idx9 = $27 | 0;
    var $_idx9_val$0 = HEAP32[$_idx9 >> 2];
    var $_idx9_val$1 = HEAP32[$_idx9 + 4 >> 2];
    var $29 = __ZN2js13NonNullObjectEP9JSContextRKN2JS5ValueE($28, $_idx9_val$0, $_idx9_val$1);
    var $30 = $29;
    if (($29 | 0) == 0) {
      var $_1 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $33 = $cx;
    var $34 = $29;
    var $35 = $keys;
    var $36 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($33, $34, 8, $35);
    if ($36) {
      __label__ = 13;
      break;
    } else {
      var $_1 = 0;
      __label__ = 32;
      break;
    }
   case 13:
    var $38 = $values | 0;
    var $39 = $keys | 0;
    var $40 = __ZNK2js16AutoVectorRooterIiE6lengthEv($39);
    var $41 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6growByEj($38, $40);
    if ($41) {
      var $i_0 = 0;
      __label__ = 14;
      break;
    } else {
      var $_1 = 0;
      __label__ = 32;
      break;
    }
   case 14:
    var $i_0;
    var $42 = __ZNK2js16AutoVectorRooterIiE6lengthEv($39);
    if ($i_0 >>> 0 < $42 >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 15:
    var $45 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($38, $i_0);
    var $46 = __ZN2js16AutoVectorRooterIiEixEj($39, $i_0);
    var $47 = HEAP32[$46 >> 2];
    var $48 = __ZN8JSObject10getGenericEP9JSContextPS_iPN2JS5ValueE($30, $cx, $30, $47, $45);
    if (($48 | 0) == 0) {
      var $_1 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $51 = __ZN2js8Debugger19unwrapDebuggeeValueEP9JSContextPN2JS5ValueE($16, $cx, $45);
    if ($51) {
      __label__ = 17;
      break;
    } else {
      var $_1 = 0;
      __label__ = 32;
      break;
    }
   case 17:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 14;
    break;
   case 18:
    var $54 = __ZNK2js10StackFrame10scopeChainEv($15);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $54);
    var $55 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($55) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 31;
      break;
    }
   case 19:
    var $_idx1_val = HEAP32[$14 >> 2];
    var $57 = __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($_idx1_val);
    if ($57) {
      __label__ = 20;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 20:
    var $59 = __ZNK2js10StackFrame10hasCallObjEv($_idx1_val);
    if ($59) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $61 = __ZN2js19CreateFunCallObjectEP9JSContextPNS_10StackFrameE($cx, $15);
    if (($61 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $64 = __ZN2js13GetScopeChainEP9JSContextPNS_10StackFrameE($cx, $15);
    if (($64 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    if ($2) {
      __label__ = 24;
      break;
    } else {
      var $scobj_0 = $64;
      __label__ = 30;
      break;
    }
   case 24:
    var $68 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, __ZN2js11ObjectClassE, 0, $64);
    if (($68 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $70 = $keys | 0;
    var $71 = $cx + 56 | 0;
    var $72 = $values | 0;
    var $73 = $cx;
    var $74 = $68;
    var $i1_0 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i1_0;
    var $76 = __ZNK2js16AutoVectorRooterIiE6lengthEv($70);
    if ($i1_0 >>> 0 < $76 >>> 0) {
      __label__ = 27;
      break;
    } else {
      var $scobj_0 = $68;
      __label__ = 30;
      break;
    }
   case 27:
    var $79 = HEAP32[$71 >> 2];
    var $80 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($72, $i1_0);
    var $81 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($79, $cx, $80);
    if ($81) {
      __label__ = 28;
      break;
    } else {
      var $_0 = 0;
      __label__ = 31;
      break;
    }
   case 28:
    var $83 = __ZN2js16AutoVectorRooterIiEixEj($70, $i1_0);
    var $84 = HEAP32[$83 >> 2];
    var $85 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($72, $i1_0);
    var $86 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($73, $74, $84, $85, 0, 0, 0, 0, 0, 0);
    if (($86 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 26;
    break;
   case 30:
    var $scobj_0;
    var $90 = $23 | 0;
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $90);
    var $_idx3_val = HEAP32[$23 + 4 >> 2];
    var $91 = __ZNK14JSLinearString5charsEv($_idx3_val);
    var $_idx2_val = HEAP32[$23 >> 2];
    var $92 = __ZNK8JSString6lengthEv($_idx2_val);
    var $93 = __ZN2js15EvaluateInScopeEP9JSContextP8JSObjectPNS_10StackFrameEPKtjPKcjPN2JS5ValueE($cx, $scobj_0, $15, $91, $92, STRING_TABLE.__str99 | 0, 1, $1);
    var $94 = ($93 | 0) != 0;
    var $_idx10 = $1 | 0;
    var $_idx10_val$0 = HEAP32[$_idx10 >> 2];
    var $_idx10_val$1 = HEAP32[$_idx10 + 4 >> 2];
    var $95 = __ZN2js8Debugger18newCompletionValueERNS_15AutoCompartmentEbN2JS5ValueEPS4_($16, $ac, $94, $_idx10_val$0, $_idx10_val$1, $vp);
    var $_0 = $95 & 1;
    __label__ = 31;
    break;
   case 31:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_1 = $_0;
    __label__ = 32;
    break;
   case 32:
    var $_1;
    __ZN2js15AutoValueVectorD1Ev($values);
    __ZN2js12AutoIdVectorD1Ev($keys);
    var $_2 = $_1;
    __label__ = 33;
    break;
   case 33:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17DebuggerFrameEvalP9JSContextjPN2JS5ValueE16EvalBindingsMode["X"] = 1;

function __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, $fnname, $checkLive) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $_idx4_val = HEAP32[$args >> 2];
    var $2 = __ZNK2js12CallReceiver5thisvEv($_idx4_val);
    var $_idx1 = $2 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $3 = __ZNK2JS5Value8isObjectEv($_idx1_val$0, $_idx1_val$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z20ReportObjectRequiredP9JSContext($cx);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8toObjectEv($_idx1_val$0, $_idx1_val$1);
    var $_idx5_val = HEAP32[$6 + 4 >> 2];
    var $7 = __ZNK8JSObject8getClassEv($_idx5_val);
    if (($7 | 0) == (_DebuggerFrame_class | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = HEAP32[$7 >> 2];
    _JS_ReportErrorNumber($cx, 4, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str83 | 0, HEAP32[tempInt + 4 >> 2] = $fnname, HEAP32[tempInt + 8 >> 2] = $11, tempInt));
    var $_0 = 0;
    __label__ = 10;
    break;
   case 5:
    var $_idx_val = HEAP32[$6 + 24 >> 2];
    var $13 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $6;
      __label__ = 10;
      break;
    }
   case 6:
    __ZNK8JSObject15getReservedSlotEj($1, $6, 0);
    var $_idx3 = $1 | 0;
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    var $16 = __ZNK2JS5Value11isUndefinedEv($_idx3_val$0, $_idx3_val$1);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 4, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str83 | 0, HEAP32[tempInt + 4 >> 2] = $fnname, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str11 | 0, tempInt));
    var $_0 = 0;
    __label__ = 10;
    break;
   case 8:
    if ($checkLive) {
      __label__ = 9;
      break;
    } else {
      var $_0 = $6;
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 4, 277, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str83 | 0, HEAP32[tempInt + 4 >> 2] = $fnname, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str100 | 0, tempInt));
    var $_0 = 0;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value8isStringEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_IS_STRING_IMPL($this_0_0_0_val$0, $this_0_0_0_val$1);
  return ($1 | 0) != 0;
}

function __ZNK2JS5Value8toStringEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_TO_STRING_IMPL($this_0_0_0_val$0, $this_0_0_0_val$1);
  return $1;
}

function __ZN8JSString12ensureLinearEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK8JSString8isLinearEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN8JSString8asLinearEv($this);
    var $9 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN8JSString6asRopeEv($this);
    var $6 = __ZN6JSRope7flattenEP9JSContext($5, $cx);
    var $9 = $6 | 0;
    __label__ = 4;
    break;
   case 4:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject10getGenericEP9JSContextPS_iPN2JS5ValueE($this, $cx, $receiver, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $1 = __ZNK8JSObject6getOpsEv($this_idx_val);
    var $3 = HEAP32[$1 + 32 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = FUNCTION_TABLE[$3]($cx, $this, $receiver, $id, $vp);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = $cx;
    var $10 = $this;
    var $11 = $receiver;
    var $12 = __Z14js_GetPropertyP9JSContextP8JSObjectS2_iPN2JS5ValueE($9, $10, $11, $id, $vp);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JS6AnchorIP8JSStringEC1ES2_($this, $t) {
  __ZN2JS6AnchorIP8JSStringEC2ES2_($this, $t);
  return;
}

function __ZL11IsValidHookRKN2JS5ValueE($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value11isUndefinedEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      var $8 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $8 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_idx_val = HEAP32[$5 + 4 >> 2];
    var $6 = __ZN8JSObject10isCallableEv($_idx_val);
    var $8 = $6;
    __label__ = 4;
    break;
   case 4:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame6calleeEv($this) {
  var $1 = __ZNK2js10StackFrame7calleevEv($this);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $2 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
  return $2;
}

function __ZNK2js10StackFrame7calleevEv($this) {
  var $1 = __ZNK2js10StackFrame14mutableCalleevEv($this);
  return $1;
}

function __ZNK2js10StackFrame14mutableCalleevEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK2js10StackFrame11isEvalFrameEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_pn = $this;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZNK2js10StackFrame10formalArgsEv($this);
    var $_pn = $5;
    __label__ = 4;
    break;
   case 4:
    var $_pn;
    return $_pn - 16 | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame10formalArgsEv($this) {
  var $1 = $this;
  var $2 = __ZNK2js10StackFrame13numFormalArgsEv($this);
  return $1 + (-$2 << 3) | 0;
}

function __ZNK2js10StackFrame13numFormalArgsEv($this) {
  var $1 = __ZNK2js10StackFrame3funEv($this);
  return HEAPU16[$1 + 56 >> 1] & 65535;
}

function __ZN2JS5Value9setNumberEd($this, $d) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $1 = _JSDOUBLE_IS_INT32($d, $i);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$i >> 2];
    __ZN2JS5Value8setInt32Ei($this, $4);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value9setDoubleEd($this, $d);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSDOUBLE_IS_INT32($d, $pi) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSDOUBLE_IS_NEGZERO($d);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $d & -1;
    HEAP32[$pi >> 2] = $4;
    var $_0 = ($4 | 0) == $d & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JS5Value9setDoubleEd($this, $d) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _DOUBLE_TO_JSVAL_IMPL($1, $d);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2JSL9NullValueEv($agg_result) {
  __ZN2JS5Value7setNullEv($agg_result);
  return;
}

function __ZNK2js10StackFrame7hasArgsEv($this_0_0_val) {
  var $1 = __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($this_0_0_val);
  return $1;
}

function __ZNK2js10StackFrame13numActualArgsEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    if (($2 & 6144 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK2js10StackFrame10hasArgsObjEv($2);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZNK2js10StackFrame7argsObjEv($this);
    var $9 = __ZNK2js15ArgumentsObject13initialLengthEv($8);
    var $_0 = $9;
    __label__ = 6;
    break;
   case 4:
    var $_0 = HEAP32[$this + 8 >> 2];
    __label__ = 6;
    break;
   case 5:
    var $14 = __ZNK2js10StackFrame13numFormalArgsEv($this);
    var $_0 = $14;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24DebuggerArguments_getArgP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $ca2 = __stackBase__ + 24;
    var $arg = __stackBase__ + 32;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $_idx6_val = HEAPU32[$args >> 2];
    var $3 = __ZNK2js12CallReceiver6calleeEv($_idx6_val);
    __ZNK8JSObject15getReservedSlotEj($1, $3, 0);
    var $_idx1 = $1 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $4 = __ZNK2JS5Value7toInt32Ev($_idx1_val$0, $_idx1_val$1);
    var $5 = __ZNK2js12CallReceiver5thisvEv($_idx6_val);
    var $_idx2 = $5 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    var $6 = __ZNK2JS5Value8isObjectEv($_idx2_val$0, $_idx2_val$1);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z20ReportObjectRequiredP9JSContext($cx);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 3:
    var $9 = __ZNK2JS5Value8toObjectEv($_idx2_val$0, $_idx2_val$1);
    var $_idx5_val = HEAP32[$9 + 4 >> 2];
    var $10 = __ZNK8JSObject8getClassEv($_idx5_val);
    if (($10 | 0) == (_DebuggerArguments_class | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = HEAP32[$10 >> 2];
    _JS_ReportErrorNumber($cx, 4, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str1263 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str112 | 0, HEAP32[tempInt + 8 >> 2] = $14, tempInt));
    var $_0 = 0;
    __label__ = 11;
    break;
   case 5:
    __ZNK8JSObject15getReservedSlotEj($2, $9, 0);
    var $16 = $2 | 0;
    var $st$2$0 = $16 | 0;
    var $17$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $16 + 4 | 0;
    var $17$1 = HEAP32[$st$2$1 >> 2];
    HEAP32[$_idx2 >> 2] = $17$0;
    HEAP32[$_idx2 + 4 >> 2] = $17$1;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($ca2, $argc, $vp);
    var $18 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $ca2, STRING_TABLE.__str113 | 0, 1);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx_val = HEAP32[$18 + 24 >> 2];
    var $21 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $22 = $21;
    var $23 = __ZNK2js10StackFrame13numActualArgsEv($22);
    if ($4 >>> 0 < $23 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $26 = __ZNK2js10StackFrame18canonicalActualArgEj($22, $4);
    var $27 = $26 | 0;
    var $st$2$0 = $27 | 0;
    var $28$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $27 + 4 | 0;
    var $28$1 = HEAP32[$st$2$1 >> 2];
    var $29 = $arg | 0;
    var $st$7$0 = $29 | 0;
    HEAP32[$st$7$0 >> 2] = $28$0;
    var $st$7$1 = $29 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $28$1;
    __label__ = 9;
    break;
   case 8:
    __ZN2JS5Value12setUndefinedEv($arg);
    __label__ = 9;
    break;
   case 9:
    var $32 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($18);
    var $33 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($32, $cx, $arg);
    if ($33) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $35 = __ZNK2js12CallReceiver4rvalEv($_idx6_val);
    var $36 = $arg | 0;
    var $st$2$0 = $36 | 0;
    var $37$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $36 + 4 | 0;
    var $37$1 = HEAP32[$st$2$1 >> 2];
    var $38 = $35 | 0;
    var $st$7$0 = $38 | 0;
    HEAP32[$st$7$0 >> 2] = $37$0;
    var $st$7$1 = $38 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $37$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL24DebuggerArguments_getArgP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZNK2JS5Value7toInt32Ev($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_TO_INT32_IMPL($this_0_0_0_val$0, $this_0_0_0_val$1);
  return $1;
}

function __ZNK2js10StackFrame18canonicalActualArgEj($this, $i) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame13numFormalArgsEv($this);
    if ($1 >>> 0 > $i >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2js10StackFrame9formalArgEj($this, $i);
    var $_0 = $4;
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZNK2js10StackFrame10actualArgsEv($this);
    var $_0 = $6 + ($i << 3) | 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame9formalArgEj($this, $i) {
  var $1 = __ZNK2js10StackFrame10formalArgsEv($this);
  return $1 + ($i << 3) | 0;
}

function __ZNK2js10StackFrame10actualArgsEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame10formalArgsEv($this);
    var $3 = HEAP32[$this >> 2];
    if (($3 & 2048 | 0) == 0) {
      var $_0 = $1;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK2js10StackFrame10hasArgsObjEv($3);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = __ZNK2js10StackFrame7argsObjEv($this);
    var $10 = __ZNK2js15ArgumentsObject13initialLengthEv($9);
    var $15 = $10;
    __label__ = 5;
    break;
   case 4:
    var $15 = HEAP32[$this + 8 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $15;
    var $_0 = $1 + (-2 - $15 << 3) | 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js15ArgumentsObject13initialLengthEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK8JSObject7getSlotEj($1, 0);
  var $_idx = $2 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $3 = __ZNK2JS5Value7toInt32Ev($_idx_val$0, $_idx_val$1);
  return $3 >>> 1;
}

function __ZNK8JSObject7getSlotEj($this, $slot) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 8 >> 2];
    var $1 = __ZNK8JSObject13numFixedSlotsEv($this_idx_val);
    if ($1 >>> 0 > $slot >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject10fixedSlotsEv($this);
    var $_0 = $4 + ($slot << 3) | 0;
    __label__ = 4;
    break;
   case 3:
    var $_0 = HEAP32[$this + 32 >> 2] + ($slot - $1 << 3) | 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12ContextStack5hasfpEv($this_0_0_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_0_val | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this_0_0_val + 8 >> 2];
    var $3 = __ZNK2js12StackSegment9maybeRegsEv($_idx_val);
    var $6 = ($3 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK10JSFunction12inStrictModeEv($this) {
  var $1 = __ZNK10JSFunction6scriptEv($this);
  return (HEAP8[$1 + 36 | 0] & 8) << 24 >> 24 != 0;
}

function __ZNK2js10StackFrame12callReceiverEv($agg_result, $this) {
  var $1 = __ZNK2js10StackFrame10formalArgsEv($this);
  __ZN2js20CallReceiverFromArgvEPN2JS5ValueE($agg_result, $1);
  return;
}

function __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, $fnname, $checkLive) {
  var $_idx_val = HEAP32[$args >> 2];
  var $1 = __ZNK2js12CallReceiver5thisvEv($_idx_val);
  var $_idx1 = $1 | 0;
  var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
  var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
  var $2 = __ZL20DebuggerScript_checkP9JSContextRKN2JS5ValueEPKcS6_b($cx, $_idx1_val$0, $_idx1_val$1, $fnname, $checkLive);
  return $2;
}

function __ZL17GetScriptReferentP8JSObject($obj_0_6_val) {
  var $1 = __ZNK8JSObject10getPrivateEv($obj_0_6_val);
  return $1;
}

function __ZL20DebuggerScript_checkP9JSContextRKN2JS5ValueEPKcS6_b($cx, $v_0_0_0_val$0, $v_0_0_0_val$1, $fnname, $checkLive) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z20ReportObjectRequiredP9JSContext($cx);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 3:
    var $5 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_idx2_val = HEAP32[$5 + 4 >> 2];
    var $6 = __ZNK8JSObject8getClassEv($_idx2_val);
    if (($6 | 0) == (_DebuggerScript_class | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = HEAP32[$6 >> 2];
    _JS_ReportErrorNumber($cx, 4, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str82 | 0, HEAP32[tempInt + 4 >> 2] = $fnname, HEAP32[tempInt + 8 >> 2] = $10, tempInt));
    var $_0 = 0;
    __label__ = 10;
    break;
   case 5:
    __ZNK8JSObject15getReservedSlotEj($1, $5, 1);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $12 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 4, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str82 | 0, HEAP32[tempInt + 4 >> 2] = $fnname, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str11 | 0, tempInt));
    var $_0 = 0;
    __label__ = 10;
    break;
   case 7:
    if ($checkLive) {
      __label__ = 8;
      break;
    } else {
      var $_0 = $5;
      __label__ = 10;
      break;
    }
   case 8:
    var $_idx3_val = HEAP32[$5 + 24 >> 2];
    var $16 = __ZL17GetScriptReferentP8JSObject($_idx3_val);
    if (($16 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $_0 = $5;
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 4, 277, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str82 | 0, HEAP32[tempInt + 4 >> 2] = $fnname, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str120413 | 0, tempInt));
    var $_0 = 0;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12ScriptOffsetP9JSContextP8JSScriptRKN2JS5ValueEPj($cx, $script, $v, $offsetp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $1 = __ZNK2JS5Value8isNumberEv($v_idx_val$0, $v_idx_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toNumberEv($v);
    var $4 = $3 >= 0 ? Math.floor($3) : Math.ceil($3);
    if ($4 >>> 0 != $3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZN2js21IsValidBytecodeOffsetEP9JSContextP8JSScriptj($cx, $script, $4);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _JS_ReportErrorNumber($cx, 4, 282, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 5:
    HEAP32[$offsetp >> 2] = $4;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE3allEv($agg_result, $this) {
  var $_idx_val = HEAP32[$this + 8 >> 2];
  var $_idx1_val = HEAP32[$this + 24 >> 2];
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3allEv($agg_result, $_idx_val, $_idx1_val);
  return;
}

function __ZNK28BytecodeRangeWithLineNumbers15frontLineNumberEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js13BytecodeRange7frontPCEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZN2js13FlowsIntoNextE4JSOp($op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($op | 0) == 197 || ($op | 0) == 155 || ($op | 0) == 141 || ($op | 0) == 112 || ($op | 0) == 6 || ($op | 0) == 5 || ($op | 0) == 117) {
      var $2 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $2 = 1;
    __label__ = 3;
    break;
   case 3:
    var $2;
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSVAL_IS_DOUBLE_IMPL($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 < 4294967169 & 1;
}

function _JSVAL_IS_NUMBER_IMPL($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 < 4294967170 & 1;
}

function _JSVAL_TO_PRIVATE_PTR_IMPL($l_0$0, $l_0$1) {
  return $l_0$0;
}

function __ZNK2js13BytecodeRange5emptyEv($this_0_2_val, $this_0_3_val) {
  return ($this_0_2_val | 0) == ($this_0_3_val | 0);
}

function __ZNK2js13BytecodeRange11frontOffsetEv($this_0_1_val_0_0_val, $this_0_2_val) {
  return $this_0_2_val - $this_0_1_val_0_0_val | 0;
}

function __ZNK10JSCodeSpec4typeEv($this_0_4_val) {
  return $this_0_4_val & 31;
}

function __ZNK2JS5Value8toDoubleEv($this) {
  var $1 = $this;
  var $2 = (tempDoubleI32[0] = HEAP32[$1 >> 2], tempDoubleI32[1] = HEAP32[$1 + 4 >> 2], tempDoubleF64[0]);
  return $2;
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZN2js13BytecodeRangeC2EP9JSContextP8JSScript($this, $cx, $script) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $script;
  var $5 = HEAP32[$script >> 2];
  HEAP32[$this + 8 >> 2] = $5;
  var $9 = $5 + HEAP32[$script + 8 >> 2] | 0;
  HEAP32[$this + 12 >> 2] = $9;
  return;
}

function __ZN8JSScript5notesEv($this_0_0_val, $this_0_2_val) {
  return $this_0_0_val + $this_0_2_val | 0;
}

function __ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE10initializeEPjS3_($begin, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($begin | 0) == ($end | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $begin;
      __label__ = 2;
      break;
    }
   case 2:
    var $p_01;
    if (($p_01 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$p_01 >> 2] = 0;
    __label__ = 4;
    break;
   case 4:
    var $5 = $p_01 + 4 | 0;
    if (($5 | 0) == ($end | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $5;
      __label__ = 2;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE13copyConstructIjEEvPjPKT_S7_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$5 >> 2];
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isLiveEv($_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3allEv($agg_result, $this_0_2_val, $this_0_6_val) {
  var $1 = $this_0_6_val + $this_0_2_val * 12 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5RangeC1EPNS0_14HashTableEntryIS6_EESH_($agg_result, $this_0_6_val, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5RangeC1EPNS0_14HashTableEntryIS6_EESH_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5RangeC2EPNS0_14HashTableEntryIS6_EESH_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5RangeC2EPNS0_14HashTableEntryIS6_EESH_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$4 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isLiveEv($_idx_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value8isNumberEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_IS_NUMBER_IMPL($this_0_0_0_val$0, $this_0_0_0_val$1);
  return ($1 | 0) != 0;
}

function __ZNK2JS5Value8toNumberEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx1 = $this | 0;
    var $this_idx1_val$0 = HEAP32[$this_idx1 >> 2];
    var $this_idx1_val$1 = HEAP32[$this_idx1 + 4 >> 2];
    var $1 = __ZNK2JS5Value8isDoubleEv($this_idx1_val$0, $this_idx1_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toDoubleEv($this);
    var $8 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZNK2JS5Value7toInt32Ev($this_idx1_val$0, $this_idx1_val$1);
    var $8 = $5 | 0;
    __label__ = 4;
    break;
   case 4:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value8isDoubleEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_IS_DOUBLE_IMPL($this_0_0_0_val$0, $this_0_0_0_val$1);
  return ($1 | 0) != 0;
}

function __ZL15GetScriptHolderP8JSObject($obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $v = __stackBase__;
  __ZNK8JSObject15getReservedSlotEj($v, $obj, 1);
  var $v_idx = $v | 0;
  var $v_idx_val$0 = HEAP32[$v_idx >> 2];
  var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
  var $1 = __ZNK2JS5Value9toPrivateEv($v_idx_val$0, $v_idx_val$1);
  var $2 = $1;
  STACKTOP = __stackBase__;
  return $2;
}

function __ZNK2js8Debugger13observesScopeEP8JSObject($this, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this + 12 | 0;
  var $3 = $obj;
  var $4 = __ZNK8JSObject9getGlobalEv($3);
  HEAP32[$1 >> 2] = $4;
  var $6 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3hasERKS2_($2, $1);
  STACKTOP = __stackBase__;
  return $6;
}

function __ZL11ScriptScopeP9JSContextP8JSScriptP8JSObject($cx, $script, $holder) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    if (($holder | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $holder;
      __label__ = 5;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$cx + 64 >> 2];
    var $3 = __ZNK2js12ContextStack5spaceEv($_idx_val);
    var $4 = $i;
    var $_idx1_val = HEAP32[$3 >> 2];
    __ZN2js13AllFramesIterC2ERNS_10StackSpaceE($4, $_idx1_val);
    var $i_idx2 = $i + 4 | 0;
    var $i_idx2_val = HEAP32[$i_idx2 >> 2];
    var $5 = __ZNK2js13AllFramesIter2fpEv($i_idx2_val);
    var $6 = __ZNK2js10StackFrame11maybeScriptEv($5);
    if (($6 | 0) == ($script | 0)) {
      var $_lcssa = $5;
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $_lcssa;
    var $8 = __ZNK2js10StackFrame10scopeChainEv($_lcssa);
    var $_0 = $8;
    __label__ = 5;
    break;
   case 4:
    __ZN2js13AllFramesIterppEv($4);
    var $i_idx_val = HEAP32[$i_idx2 >> 2];
    var $9 = __ZNK2js13AllFramesIter2fpEv($i_idx_val);
    var $10 = __ZNK2js10StackFrame11maybeScriptEv($9);
    if (($10 | 0) == ($script | 0)) {
      var $_lcssa = $9;
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime4new_IN2js10BreakpointEPNS1_8DebuggerEPNS1_14BreakpointSiteEP8JSObjectEEPT_T0_T1_T2_($this, $p1, $p2, $p3) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSRuntime7malloc_EjP9JSContext($this, 28, 0);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js10BreakpointC2EPNS_8DebuggerEPNS_14BreakpointSiteEP8JSObject($4, $p1, $p2, $p3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame11maybeScriptEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK2js10StackFrame13isScriptFrameEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $5 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2js10StackFrame6scriptEv($this);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value9toPrivateEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_TO_PRIVATE_PTR_IMPL($this_0_0_0_val$0, $this_0_0_0_val$1);
  return $1;
}

function __ZN2JS5Value9setNumberEj($this, $ui) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($ui | 0) < 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $ui >>> 0;
    __ZN2JS5Value9setDoubleEd($this, $3);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value8setInt32Ei($this, $ui);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN16FlowGraphSummaryC1EP9JSContext($this, $cx) {
  __ZN16FlowGraphSummaryC2EP9JSContext($this, $cx);
  return;
}

function __ZN16FlowGraphSummary8populateEP9JSContextP8JSScript($this, $cx, $script) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $this | 0;
    var $2 = $script + 8 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $4 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE6growByEj($1, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 2:
    var $_idx1 = $this + 4 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $6 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEixEj($_idx1_val, 0);
    HEAP32[$6 >> 2] = -2;
    if (HEAPU32[$2 >> 2] >>> 0 > 1) {
      var $i_017 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $i_017;
    var $_idx_val = HEAP32[$_idx1 >> 2];
    var $9 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEixEj($_idx_val, $i_017);
    HEAP32[$9 >> 2] = -1;
    var $10 = $i_017 + 1 | 0;
    if ($10 >>> 0 < HEAPU32[$2 >> 2] >>> 0) {
      var $i_017 = $10;
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = HEAP32[$script + 28 >> 2];
    __ZN28BytecodeRangeWithLineNumbersC1EP9JSContextP8JSScript($r, $cx, $script);
    var $_idx7 = $r + 8 | 0;
    var $_idx7_val = HEAPU32[$_idx7 >> 2];
    var $_idx8 = $r + 12 | 0;
    var $_idx8_val = HEAP32[$_idx8 >> 2];
    var $15 = __ZNK2js13BytecodeRange5emptyEv($_idx7_val, $_idx8_val);
    if ($15) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $r_idx = $r + 16 | 0;
    var $_idx10 = $r + 4 | 0;
    var $prevLine_014 = $14;
    var $prevOp_015 = 0;
    var $_idx15_val = $_idx7_val;
    __label__ = 6;
    break;
   case 6:
    var $_idx15_val;
    var $prevOp_015;
    var $prevLine_014;
    var $r_idx_val = HEAP32[$r_idx >> 2];
    var $16 = __ZNK28BytecodeRangeWithLineNumbers15frontLineNumberEv($r_idx_val);
    var $_idx10_val = HEAPU32[$_idx10 >> 2];
    var $17 = __ZNK2js13BytecodeRange11frontOpcodeEv($_idx10_val, $_idx15_val);
    var $18 = __ZN2js13FlowsIntoNextE4JSOp($prevOp_015);
    if ($18) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $_idx18_val_idx_val = HEAP32[$_idx10_val >> 2];
    var $20 = __ZNK2js13BytecodeRange11frontOffsetEv($_idx18_val_idx_val, $_idx15_val);
    __ZN16FlowGraphSummary7addEdgeEjj($this, $prevLine_014, $20);
    __label__ = 8;
    break;
   case 8:
    var $_idx20_val = HEAP32[_js_CodeSpec + ($17 << 3) + 4 >> 2];
    var $22 = __ZNK10JSCodeSpec4typeEv($_idx20_val);
    if (($22 | 0) == 1) {
      __label__ = 9;
      break;
    } else if (($22 | 0) == 9) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $_idx16_val_idx_val = HEAP32[$_idx10_val >> 2];
    var $24 = __ZNK2js13BytecodeRange11frontOffsetEv($_idx16_val_idx_val, $_idx15_val);
    var $25 = __ZNK2js13BytecodeRange7frontPCEv($_idx15_val);
    var $35 = (((HEAPU8[$25 + 1 | 0] & 255) << 8 | HEAPU8[$25 + 2 | 0] & 255) << 16 >> 16) + $24 | 0;
    __ZN16FlowGraphSummary7addEdgeEjj($this, $16, $35);
    __label__ = 23;
    break;
   case 10:
    var $_idx14_val_idx_val = HEAP32[$_idx10_val >> 2];
    var $37 = __ZNK2js13BytecodeRange11frontOffsetEv($_idx14_val_idx_val, $_idx15_val);
    var $38 = __ZNK2js13BytecodeRange7frontPCEv($_idx15_val);
    var $57 = ((HEAPU8[$38 + 2 | 0] & 255) << 16 | (HEAPU8[$38 + 1 | 0] & 255) << 24 | HEAPU8[$38 + 4 | 0] & 255 | (HEAPU8[$38 + 3 | 0] & 255) << 8) + $37 | 0;
    __ZN16FlowGraphSummary7addEdgeEjj($this, $16, $57);
    __label__ = 23;
    break;
   case 11:
    var $59 = ($17 | 0) == 149;
    if (($17 | 0) == 71 || ($17 | 0) == 149 || ($17 | 0) == 150) {
      __label__ = 12;
      break;
    } else if (($17 | 0) == 70) {
      var $62 = 1;
      __label__ = 13;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 12:
    var $62 = $59;
    __label__ = 13;
    break;
   case 13:
    var $62;
    var $63 = ($17 - 149 | 0) >>> 0 < 2;
    var $64 = __ZNK2js13BytecodeRange7frontPCEv($_idx15_val);
    var $_idx12_val_idx_val = HEAP32[$_idx10_val >> 2];
    var $65 = __ZNK2js13BytecodeRange11frontOffsetEv($_idx12_val_idx_val, $_idx15_val);
    var $66 = $63 ? 4 : 2;
    var $69 = HEAPU8[$64 + 1 | 0] & 255;
    if ($63) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $94 = (HEAPU8[$64 + 2 | 0] & 255) << 16 | $69 << 24 | HEAPU8[$64 + 4 | 0] & 255 | (HEAPU8[$64 + 3 | 0] & 255) << 8;
    __label__ = 16;
    break;
   case 15:
    var $94 = (HEAPU8[$64 + 2 | 0] & 255 | $69 << 8) << 16 >> 16;
    __label__ = 16;
    break;
   case 16:
    var $94;
    var $95 = $94 + $65 | 0;
    __ZN16FlowGraphSummary7addEdgeEjj($this, $16, $95);
    var $100 = $66 + ($64 + 2) | 0;
    var $103 = (HEAPU8[$64 + ($66 | 1) | 0] & 255) << 8 | HEAPU8[$100] & 255;
    if ($62) {
      __label__ = 17;
      break;
    } else {
      var $ncases_0 = $103;
      var $pc_0 = $100;
      __label__ = 18;
      break;
    }
   case 17:
    var $110 = $66 + ($64 + 4) | 0;
    var $ncases_0 = 1 - ($103 << 16 >> 16) + (((HEAPU8[$66 + ($64 + 3) | 0] & 255) << 8 | HEAPU8[$110] & 255) << 16 >> 16) | 0;
    var $pc_0 = $110;
    __label__ = 18;
    break;
   case 18:
    var $pc_0;
    var $ncases_0;
    if (($ncases_0 | 0) > 0) {
      var $pc_111 = $pc_0;
      var $i1_012 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 19:
    var $i1_012;
    var $pc_111;
    var $pc_2 = $62 ? $pc_111 : $pc_111 + 2 | 0;
    var $122 = HEAPU8[$pc_2 + 1 | 0] & 255;
    if ($63) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $147 = (HEAPU8[$pc_2 + 2 | 0] & 255) << 16 | $122 << 24 | HEAPU8[$pc_2 + 4 | 0] & 255 | (HEAPU8[$pc_2 + 3 | 0] & 255) << 8;
    __label__ = 22;
    break;
   case 21:
    var $147 = (HEAPU8[$pc_2 + 2 | 0] & 255 | $122 << 8) << 16 >> 16;
    __label__ = 22;
    break;
   case 22:
    var $147;
    var $148 = $147 + $65 | 0;
    __ZN16FlowGraphSummary7addEdgeEjj($this, $16, $148);
    var $149 = $pc_2 + $66 | 0;
    var $150 = $i1_012 + 1 | 0;
    if (($150 | 0) == ($ncases_0 | 0)) {
      __label__ = 23;
      break;
    } else {
      var $pc_111 = $149;
      var $i1_012 = $150;
      __label__ = 19;
      break;
    }
   case 23:
    __ZN28BytecodeRangeWithLineNumbers8popFrontEv($r);
    var $_idx5_val = HEAPU32[$_idx7 >> 2];
    var $_idx6_val = HEAP32[$_idx8 >> 2];
    var $151 = __ZNK2js13BytecodeRange5emptyEv($_idx5_val, $_idx6_val);
    if ($151) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      var $prevLine_014 = $16;
      var $prevOp_015 = $17;
      var $_idx15_val = $_idx5_val;
      __label__ = 6;
      break;
    }
   case 24:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN16FlowGraphSummary8populateEP9JSContextP8JSScript["X"] = 1;

function __ZN28BytecodeRangeWithLineNumbersC1EP9JSContextP8JSScript($this, $cx, $script) {
  __ZN28BytecodeRangeWithLineNumbersC2EP9JSContextP8JSScript($this, $cx, $script);
  return;
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEixEj($this_0_1_val, $i) {
  var $1 = __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE5beginEv($this_0_1_val);
  return $1 + ($i << 2) | 0;
}

function __ZN2JSL11NumberValueEd($agg_result, $dbl) {
  var $1 = __ZN2JS5Value9setNumberEd($agg_result, $dbl);
  return;
}

function __ZN28BytecodeRangeWithLineNumbers8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    __ZN2js13BytecodeRange8popFrontEv($1);
    var $_idx_val = HEAP32[$this + 8 >> 2];
    var $_idx1_val = HEAP32[$this + 12 >> 2];
    var $2 = __ZNK2js13BytecodeRange5emptyEv($_idx_val, $_idx1_val);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN28BytecodeRangeWithLineNumbers10updateLineEv($this);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN16FlowGraphSummaryD1Ev($this) {
  __ZN16FlowGraphSummaryD2Ev($this);
  return;
}

function __ZN16FlowGraphSummaryD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEED2Ev($1);
  return;
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js13BytecodeRange8popFrontEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 8 | 0;
  var $4 = HEAP32[$3 >> 2];
  var $5 = __ZN2js17GetBytecodeLengthEP9JSContextP8JSScriptPh($2, $4);
  var $7 = HEAP32[$3 >> 2] + $5 | 0;
  HEAP32[$3 >> 2] = $7;
  return;
}

function __ZN28BytecodeRangeWithLineNumbers10updateLineEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 24 | 0;
    var $2 = $this + 20 | 0;
    var $3 = $this + 16 | 0;
    var $_idx = $this + 8 | 0;
    var $5 = HEAP32[$2 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $5;
    var $6 = HEAPU8[$5];
    if ($6 << 24 >> 24 == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$_idx >> 2];
    var $10 = __ZNK2js13BytecodeRange7frontPCEv($_idx_val);
    if ($9 >>> 0 > $10 >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($6 & 255) > 191) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = ($6 & 255) >>> 3;
    if (($16 | 0) == 23) {
      __label__ = 6;
      break;
    } else if (($16 | 0) == 22) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = _js_GetSrcNoteOffset($5, 0);
    HEAP32[$3 >> 2] = $18;
    __label__ = 8;
    break;
   case 7:
    var $21 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $21;
    __label__ = 8;
    break;
   case 8:
    var $22 = HEAPU8[$5];
    if (($22 & 255) > 191) {
      var $28 = 24;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $28 = ($22 & 255) >>> 3;
    __label__ = 10;
    break;
   case 10:
    var $28;
    if (HEAP8[_js_SrcNoteSpec + ($28 << 3) + 4 | 0] << 24 >> 24 == 0) {
      var $35 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $33 = _js_SrcNoteLength($5);
    var $35 = $33;
    __label__ = 12;
    break;
   case 12:
    var $35;
    var $36 = $5 + $35 | 0;
    HEAP32[$2 >> 2] = $36;
    var $37 = HEAPU8[$36];
    var $_v = ($37 & 255) > 191 ? 63 : 7;
    HEAP32[$1 >> 2] = $9 + ($_v & ($37 & 255)) | 0;
    var $5 = $36;
    __label__ = 2;
    break;
   case 13:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN28BytecodeRangeWithLineNumbers10updateLineEv["X"] = 1;

function __ZN28BytecodeRangeWithLineNumbersC2EP9JSContextP8JSScript($this, $cx, $script) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    __ZN2js13BytecodeRangeC2EP9JSContextP8JSScript($1, $cx, $script);
    var $4 = HEAP32[$script + 28 >> 2];
    HEAP32[$this + 16 >> 2] = $4;
    var $5 = $this + 20 | 0;
    var $script_idx = $script | 0;
    var $script_idx_val = HEAP32[$script_idx >> 2];
    var $script_idx1_val = HEAP32[$script + 8 >> 2];
    var $6 = __ZN8JSScript5notesEv($script_idx_val, $script_idx1_val);
    HEAP32[$5 >> 2] = $6;
    var $7 = $this + 24 | 0;
    var $8 = HEAPU32[$script_idx >> 2];
    HEAP32[$7 >> 2] = $8;
    var $9 = HEAPU8[$6];
    if ($9 << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_v = ($9 & 255) > 191 ? 63 : 7;
    var $15 = $8 + ($_v & ($9 & 255)) | 0;
    HEAP32[$7 >> 2] = $15;
    __label__ = 3;
    break;
   case 3:
    __ZN28BytecodeRangeWithLineNumbers10updateLineEv($this);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE6growByEj($this, $incr) {
  var $1 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE10growByImplILb1EEEbj($this, $incr);
  return $1;
}

function __ZNK2js13BytecodeRange11frontOpcodeEv($this_0_1_val, $this_0_2_val) {
  var $1 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh($this_0_1_val, $this_0_2_val);
  return $1;
}

function __ZN16FlowGraphSummary7addEdgeEjj($this, $sourceLine, $targetOffset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this + 4 >> 2];
    var $1 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEixEj($_idx_val, $targetOffset);
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $sourceLine;
    __label__ = 5;
    break;
   case 3:
    if (($2 | 0) == ($sourceLine | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$1 >> 2] = -2;
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12js_GetOpcodeP9JSContextP8JSScriptPh($script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU8[$pc];
    var $2 = $1 & 255;
    if ($1 << 24 >> 24 == 83) {
      __label__ = 2;
      break;
    } else {
      var $op_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $script;
    var $6 = _JS_GetTrapOpcode($5, $pc);
    var $op_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $op_0;
    return $op_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE10growByImplILb1EEEbj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 8 | 0;
    var $4 = HEAPU32[$3 >> 2];
    if ((HEAP32[$this + 12 >> 2] - $4 | 0) >>> 0 < $incr >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $this_idx1_val = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $this_idx1_val = HEAP32[$3 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $this_idx1_val;
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $10 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    var $11 = $10 + ($incr << 2) | 0;
    __ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE10initializeEPjS3_($10, $11);
    var $13 = HEAP32[$3 >> 2] + $incr | 0;
    HEAP32[$3 >> 2] = $13;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 2;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE13moveConstructIjEEvPjPKT_S7_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIjLj0ES1_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIjLj0ES1_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $3 = $v + 4 | 0;
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($2, $5, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    var $10 = $v + 12 | 0;
    HEAP32[$3 >> 2] = $9;
    HEAP32[$10 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE13moveConstructIjEEvPjPKT_S7_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE13copyConstructIjEEvPjPKT_S7_($dst, $srcbeg, $srcend);
  return;
}

function __ZN16FlowGraphSummaryC2EP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEC2ES1_($2, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js12StackSegment4regsEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZL14JSID_FROM_BITSj($bits) {
  return $bits;
}

function __ZNK2js9FrameRegs2fpEv($this_0_3_val) {
  return $this_0_3_val;
}

function __ZN8JSScript13isValidOffsetEh($offset) {
  return $offset << 24 >> 24 != -1;
}

function __ZN2js5types10TypeObject11hasAllFlagsEj($this_0_3_val, $flags) {
  return ($this_0_3_val & $flags | 0) == ($flags | 0);
}

function __ZNK2JS5ValueeqERKS0_($this_0_0_0_val$0, $this_0_0_0_val$1, $rhs_0_0_0_val$0, $rhs_0_0_0_val$1) {
  return $this_0_0_0_val$0 == $rhs_0_0_0_val$0 && $this_0_0_0_val$1 == $rhs_0_0_0_val$1;
}

function _JSVAL_IS_NULL_IMPL($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -122) & 1;
}

function _JSVAL_TO_OBJECT_IMPL($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_IS_OBJECT_IMPL($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -121) & 1;
}

function _JSVAL_IS_UNDEFINED_IMPL($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -126) & 1;
}

function __ZNK2js5Shape12isEmptyShapeEv($this_0_10_val) {
  return ($this_0_10_val | 0) == 0;
}

function __ZNK2js2gc4Cell7addressEv($this) {
  return $this;
}

function __ZN7mozilla14AlignedStorageILj64EE4addrEv($this) {
  return $this;
}

function __ZN8JSObject8asGlobalEv($this) {
  return $this;
}

function __ZN8JSScript7objectsEv($this_0_1_val, $this_0_5_val) {
  return $this_0_1_val + ($this_0_5_val & 255) | 0;
}

function _PRIVATE_PTR_TO_JSVAL_IMPL($agg_result, $ptr) {
  HEAP32[$agg_result + 4 >> 2] = 0;
  HEAP32[$agg_result >> 2] = $ptr;
  return;
}

function _BOOLEAN_TO_JSVAL_IMPL($agg_result, $b) {
  HEAP32[$agg_result + 4 >> 2] = -125;
  HEAP32[$agg_result >> 2] = $b;
  return;
}

function __ZN2js16CallArgsFromArgvEjPN2JS5ValueE($agg_result, $argc, $argv) {
  HEAP32[$agg_result >> 2] = $argv;
  HEAP32[$agg_result + 4 >> 2] = $argc;
  return;
}

function _INT32_TO_JSVAL_IMPL($agg_result, $i) {
  HEAP32[$agg_result + 4 >> 2] = -127;
  HEAP32[$agg_result >> 2] = $i;
  return;
}

function __ZN2js15TempAllocPolicyC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  return;
}

function __ZN2js10AutoLockGCC2EP9JSRuntime($this, $rt) {
  HEAP32[$this >> 2] = $rt;
  return;
}

function __ZN2js18RuntimeAllocPolicyC2EP9JSContext($this, $cx_0_11_val) {
  HEAP32[$this >> 2] = $cx_0_11_val;
  return;
}

function __ZN10JSFunction19setConstructorClassEPN2js5ClassE($this, $clasp) {
  HEAP32[$this + 64 >> 2] = $clasp;
  return;
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEC2ES1_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($this, $cx, $id, $value, $getter, $setter, $attrs) {
  var $this_idx_val = HEAP32[$this + 4 >> 2];
  var $1 = __ZNK8JSObject6getOpsEv($this_idx_val);
  var $3 = HEAP32[$1 + 20 >> 2];
  var $5 = ($3 | 0) != 0 ? $3 : 32;
  var $6 = FUNCTION_TABLE[$5]($cx, $this, $id, $value, $getter, $setter, $attrs);
  return $6;
}

function __ZN2JS5Value10setPrivateEPv($this, $ptr) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _PRIVATE_PTR_TO_JSVAL_IMPL($1, $ptr);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($this, $cx, $id, $vp) {
  var $1 = __ZN8JSObject10getGenericEP9JSContextPS_iPN2JS5ValueE($this, $cx, $this, $id, $vp);
  return $1;
}

function __ZN8JSObject23markDenseArrayNotPackedEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 & 16384 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $2 ^ 16384;
    HEAP32[$1 >> 2] = $6;
    __ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj($cx, $this, 131072);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj($cx, $obj, $flags) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $obj_idx_val = HEAP32[$obj + 8 >> 2];
    var $3 = __ZNK8JSObject11hasLazyTypeEv($obj_idx_val);
    if ($3) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $obj_idx1_val = HEAP32[$obj + 36 >> 2];
    var $5 = __ZNK8JSObject4typeEv($obj_idx1_val);
    var $_idx_val = HEAP32[$5 + 12 >> 2];
    var $6 = __ZN2js5types10TypeObject11hasAllFlagsEj($_idx_val, $flags);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js5types10TypeObject8setFlagsEP9JSContextj($5, $cx, $flags);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16AutoObjectVectorD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js16AutoVectorRooterIP8JSObjectED2Ev($1);
  return;
}

function __ZN2js16AutoVectorRooterIP8JSObjectED2Ev($this) {
  var $1 = $this + 12 | 0;
  __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEED1Ev($1);
  var $_idx_val = HEAP32[$this >> 2];
  var $_idx1_val = HEAP32[$this + 8 >> 2];
  __ZN2js12AutoGCRooterD2Ev($_idx_val, $_idx1_val);
  return;
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16AutoObjectVectorC2EP9JSContext($this, $cx) {
  var $1 = $this | 0;
  __ZN2js16AutoVectorRooterIP8JSObjectEC2EP9JSContexti($1, $cx);
  return;
}

function __ZN2js16AutoVectorRooterIP8JSObjectEC2EP9JSContexti($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($2, $cx, -16);
  var $3 = $this + 12 | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEEC1ES3_($3, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEEC1ES3_($this, $ap_01) {
  __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEEC2ES3_($this, $ap_01);
  return;
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEEC2ES3_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj32EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 8;
  return;
}

function __ZNK2js12ContextStack4regsEv($this_0_0_val_0_2_val) {
  var $1 = __ZNK2js12StackSegment4regsEv($this_0_0_val_0_2_val);
  return $1;
}

function __ZNK2js8Debugger17observesNewScriptEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 40 | 0] & 1) << 24 >> 24 == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 8 >> 2];
    var $6 = __ZNK2js8Debugger7getHookENS0_4HookE($this_idx_val, 2);
    var $9 = ($6 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL4FindIN2JS5ValueEEEPT_S4_S4_RKS3_($beg, $end, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p_0 = $beg;
    __label__ = 2;
    break;
   case 2:
    var $p_0;
    if (($p_0 | 0) == ($end | 0)) {
      var $_0 = $end;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $p_0_idx = $p_0 | 0;
    var $p_0_idx_val$0 = HEAP32[$p_0_idx >> 2];
    var $p_0_idx_val$1 = HEAP32[$p_0_idx + 4 >> 2];
    var $4 = __ZNK2JS5ValueeqERKS0_($p_0_idx_val$0, $p_0_idx_val$1, $v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($4) {
      var $_0 = $p_0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $p_0 = $p_0 + 8 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 24;
    var $4 = __ZNK9JSContext5hasfpEv($cx);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $7;
    var $8 = $cx;
    var $9 = $global;
    var $10 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($8, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $18 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZNK9JSContext2fpEv($cx);
    var $13 = __ZNK2js10StackFrame10scopeChainEv($12);
    var $14 = $13;
    var $15 = __ZNK8JSObject9getGlobalEv($14);
    var $16 = $15;
    HEAP32[$global >> 2] = $16;
    var $18 = $16;
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $18, $19);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $20 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    HEAP32[$proto >> 2] = $22;
    var $29 = $22;
    __label__ = 9;
    break;
   case 7:
    var $24 = $cx;
    var $26 = $proto;
    var $27 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($24, $18, $3, $26, __ZN2js11ObjectClassE);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $29 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $29;
    var $30 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE($cx, $29, $18, $kind);
    var $_0 = $30;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK9JSContext5hasfpEv($this) {
  var $_idx_val = HEAP32[$this + 60 >> 2];
  var $1 = __ZNK2js12ContextStack5hasfpEv($_idx_val);
  return $1;
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, __ZN2js11ObjectClassE, $1, $parent, 0, (__ZN2js11ObjectClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $7 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, __ZN2js11ObjectClassE, $kind);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $10);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15AutoValueVectorD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js16AutoVectorRooterIN2JS5ValueEED2Ev($1);
  return;
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEED2Ev($this) {
  var $1 = $this + 12 | 0;
  __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEED1Ev($1);
  var $_idx_val = HEAP32[$this >> 2];
  var $_idx1_val = HEAP32[$this + 8 >> 2];
  __ZN2js12AutoGCRooterD2Ev($_idx_val, $_idx1_val);
  return;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12ContextStack2fpEv($this_0_0_val_0_2_val_0_3_val) {
  var $1 = __ZNK2js12StackSegment2fpEv($this_0_0_val_0_2_val_0_3_val);
  return $1;
}

function __ZNK2js12StackSegment2fpEv($this_0_2_val_0_3_val) {
  var $1 = __ZNK2js9FrameRegs2fpEv($this_0_2_val_0_3_val);
  return $1;
}

function __ZN2js15AutoValueVectorC2EP9JSContext($this, $cx) {
  var $1 = $this | 0;
  __ZN2js16AutoVectorRooterIN2JS5ValueEEC2EP9JSContexti($1, $cx);
  return;
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEEC2EP9JSContexti($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($2, $cx, -12);
  var $3 = $this + 12 | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEEC1ES3_($3, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEEC1ES3_($this, $ap_01) {
  __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEEC2ES3_($this, $ap_01);
  return;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEEC2ES3_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj64EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 8;
  return;
}

function __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, $slot, $value_0_0_0_val$0, $value_0_0_0_val$1) {
  var $1 = __ZN8JSObject10getSlotRefEj($this, $slot);
  var $2 = $1 | 0;
  HEAP32[$2 >> 2] = $value_0_0_0_val$0;
  HEAP32[$2 + 4 >> 2] = $value_0_0_0_val$1;
  return;
}

function __ZN8JSObject10getSlotRefEj($this, $slot) {
  var $1 = __ZN8JSObject14getSlotAddressEj($this, $slot);
  return $1;
}

function __ZN8JSObject14getSlotAddressEj($this, $slot) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 8 >> 2];
    var $1 = __ZNK8JSObject13numFixedSlotsEv($this_idx_val);
    if ($1 >>> 0 > $slot >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject10fixedSlotsEv($this);
    var $_0 = $4 + ($slot << 3) | 0;
    __label__ = 4;
    break;
   case 3:
    var $_0 = HEAP32[$this + 32 >> 2] + ($slot - $1 << 3) | 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject11nativeEmptyEv($this_0_0_val) {
  var $1 = __ZNK8JSObject12lastPropertyEv($this_0_0_val);
  var $_idx_val = HEAP32[$1 + 32 >> 2];
  var $2 = __ZNK2js5Shape12isEmptyShapeEv($_idx_val);
  return $2;
}

function __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev($this_0_5_val) {
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev($this_0_5_val);
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev($this_0_5_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_5_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($this_0_5_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 24 >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED1Ev($this_0_6_val) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED2Ev($this_0_6_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED2Ev($this_0_6_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_6_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($this_0_6_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEED2Ev($this) {
  var $1 = $this + 8 | 0;
  __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev($1);
  return;
}

function __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 24 >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_ED1Ev($this_0_6_val) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_ED2Ev($this_0_6_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_ED2Ev($this_0_6_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_6_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($this_0_6_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 24 >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED1Ev($this_0_6_val) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED2Ev($this_0_6_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED2Ev($this_0_6_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_6_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($this_0_6_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js2gc4Cell11arenaHeaderEv($this) {
  var $1 = __ZNK2js2gc4Cell7addressEv($this);
  return $1 & -4096;
}

function __Z18js_InitObjectClassP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject8asGlobalEv($obj);
    var $2 = __ZNK2js12GlobalObject32functionObjectClassesInitializedEv($1);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js12GlobalObject28initFunctionAndObjectClassesEP9JSContext($1, $cx);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js12GlobalObject18getObjectPrototypeEv($1);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12GlobalObject32functionObjectClassesInitializedEv($this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject7getSlotEj($1, 2);
  var $_idx = $2 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $3 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
  return $3 ^ 1;
}

function __ZN2js12GlobalObject28initFunctionAndObjectClassesEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ids = __stackBase__;
    if ((HEAP32[$cx + 132 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $cx;
    var $6 = $this;
    _JS_SetGlobalObject($5, $6);
    __label__ = 3;
    break;
   case 3:
    var $8 = $this | 0;
    var $9 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_123($cx, __ZN2js11ObjectClassE, 0, $8);
    if (($9 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN8JSObject16setSingletonTypeEP9JSContext($9, $cx);
    var $12 = $9;
    var $13 = $cx;
    var $14 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($12, $13, 0, 1);
    if (($14 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($14, $13, __ZN2js11ObjectClassE, 0);
    if (($17 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = __ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, __ZN2js13FunctionClassE, $9, $8);
    if (($20 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject16setSingletonTypeEP9JSContext($20, $cx);
    var $23 = $20;
    var $24 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($23, $13, 0, 1);
    if (($24 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($24, $13, __ZN2js13FunctionClassE, 0);
    if (($27 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $30 = $this;
    var $31 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($13, $23, 0, 0, 16384, $30, 0);
    var $32 = $31;
    if (($31 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $35 = $31 + 58 | 0;
    var $37 = HEAP16[$35 >> 1] | 2048;
    HEAP16[$35 >> 1] = $37;
    var $38 = $cx;
    var $39 = __ZN8JSScript9NewScriptEP9JSContextjjjjjjjjjttj9JSVersion($38, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0);
    if (($39 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $42 = $39 + 36 | 0;
    var $44 = HEAP8[$42] | 1;
    HEAP8[$42] = $44;
    var $45 = $39 | 0;
    HEAP8[HEAP32[$45 >> 2]] = -59;
    HEAP8[HEAP32[$45 >> 2] + 1 | 0] = 0;
    HEAP32[$31 + 60 >> 2] = $39;
    var $50 = $31;
    var $51 = __ZN8JSObject7getTypeEP9JSContext($50, $cx);
    HEAP32[$51 + 28 >> 2] = $32;
    var $53 = $39 + 37 | 0;
    var $55 = HEAP8[$53] | 4;
    HEAP8[$53] = $55;
    var $56 = $cx + 52 | 0;
    var $60 = HEAP32[HEAP32[$56 >> 2] + 210024 >> 2] | 0;
    var $61 = __ZL12ATOM_TO_JSIDP6JSAtom124($60);
    var $62 = __ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, __ZN2js13FunctionClassE, $50, $8);
    if (($62 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $65 = __ZL12JSID_TO_ATOMi($61);
    var $66 = $62;
    var $67 = $65;
    var $68 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($13, $66, 34, 1, 512, $30, $67);
    var $69 = $68;
    if (($68 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    __ZN10JSFunction19setConstructorClassEPN2js5ClassE($69, __ZN2js11ObjectClassE);
    __ZN2js12GlobalObject21setObjectClassDetailsEP10JSFunctionP8JSObject($this, $69, $9);
    var $75 = HEAP32[HEAP32[$56 >> 2] + 210028 >> 2] | 0;
    var $76 = __ZL12ATOM_TO_JSIDP6JSAtom124($75);
    var $77 = __ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, __ZN2js13FunctionClassE, $50, $8);
    if (($77 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $80 = __ZL12JSID_TO_ATOMi($76);
    var $81 = $77;
    var $82 = $80;
    var $83 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($13, $81, 36, 1, 512, $30, $82);
    var $84 = $83;
    if (($83 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    __ZN10JSFunction19setConstructorClassEPN2js5ClassE($84, __ZN2js13FunctionClassE);
    __ZN2js12GlobalObject23setFunctionClassDetailsEP10JSFunctionP8JSObject($this, $84, $50);
    var $87 = $68;
    var $88 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($cx, $87, $9);
    if ($88) {
      __label__ = 16;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 16:
    var $90 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($cx, $9, _object_props, _object_methods);
    if ($90) {
      __label__ = 17;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 17:
    var $92 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($cx, $87, 0, _object_static_methods);
    if ($92) {
      __label__ = 18;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 18:
    var $94 = $83;
    var $95 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($cx, $94, $50);
    if ($95) {
      __label__ = 19;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 19:
    var $97 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($cx, $50, 0, __ZN2js16function_methodsE);
    if ($97) {
      __label__ = 20;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 20:
    var $99 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($cx, $94, 0, 0);
    if ($99) {
      __label__ = 21;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 21:
    var $101 = __ZN8JSObject15addDataPropertyEP9JSContextijj($8, $cx, $61, 75, 0);
    if (($101 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $104 = __ZN8JSObject15addDataPropertyEP9JSContextijj($8, $cx, $76, 76, 0);
    if (($104 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $110 = HEAP32[HEAP32[$56 >> 2] + 210212 >> 2] | 0;
    var $111 = __ZL12ATOM_TO_JSIDP6JSAtom124($110);
    var $112 = __Z17js_DefineFunctionP9JSContextP8JSObjectiPFiS0_jPN2JS5ValueEEjj($13, $30, $111, 38, 1, 4096);
    if (($112 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $115 = $112;
    __ZN2js12GlobalObject15setOriginalEvalEP8JSObject($this, $115);
    var $116 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($13, 0, 40, 0, 0, $30, 0);
    var $117 = $116;
    if (($116 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    __ZN2js12AutoIdVectorC1EP9JSContext($ids, $13);
    var $120 = $116 | 0;
    var $121 = __ZN8JSObject17preventExtensionsEP9JSContextPN2js12AutoIdVectorE($120, $13, $ids);
    if ($121) {
      __label__ = 26;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 26:
    __ZN2js12GlobalObject17setThrowTypeErrorEP10JSFunction($this, $117);
    var $123 = __ZN8JSObject21shouldSplicePrototypeEP9JSContext($30, $13);
    if ($123) {
      __label__ = 27;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 27:
    var $125 = __ZN8JSObject15splicePrototypeEP9JSContextPS_($30, $13, $12);
    if ($125) {
      __label__ = 28;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 28:
    var $127 = __ZNK10JSFunction6scriptEv($31);
    var $128 = $127;
    var $129 = $31;
    __Z20js_CallNewScriptHookP9JSContextP8JSScriptP10JSFunction($38, $128, $129);
    var $_0 = $50;
    __label__ = 29;
    break;
   case 29:
    var $_0;
    __ZN2js12AutoIdVectorD1Ev($ids);
    var $_1 = $_0;
    __label__ = 30;
    break;
   case 30:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js12GlobalObject28initFunctionAndObjectClassesEP9JSContext["X"] = 1;

function __ZNK2js12GlobalObject18getObjectPrototypeEv($this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject7getSlotEj($1, 38);
  var $_idx = $2 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $3 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
  return $3;
}

function __Z20js_InitFunctionClassP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject8asGlobalEv($obj);
    var $2 = __ZNK2js12GlobalObject32functionObjectClassesInitializedEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2js12GlobalObject20getFunctionPrototypeEv($1);
    var $8 = $4;
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN2js12GlobalObject28initFunctionAndObjectClassesEP9JSContext($1, $cx);
    var $8 = $6;
    __label__ = 4;
    break;
   case 4:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12GlobalObject20getFunctionPrototypeEv($this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject7getSlotEj($1, 39);
  var $_idx = $2 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $3 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
  return $3;
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_123($cx, $clasp, $proto, $parent) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb135($4);
  var $6 = __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE136($cx, $clasp, $proto, $parent, $5);
  return $6;
}

function __ZN8JSObject16setSingletonTypeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP8[$cx + 232 | 0];
    var $2 = __ZN9JSContext20typeInferenceEnabledEv($_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this + 8 | 0;
    var $6 = HEAP32[$4 >> 2] | 196608;
    HEAP32[$4 >> 2] = $6;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, $clasp, $proto, $parent) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb135($4);
  var $6 = __ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE($cx, $clasp, $proto, $parent, $5);
  return $6;
}

function __ZN8JSObject7getTypeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this + 8 >> 2];
    var $2 = __ZNK8JSObject11hasLazyTypeEv($_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this;
    var $5 = $cx;
    __ZN8JSObject12makeLazyTypeEP9JSContext($4, $5);
    __label__ = 3;
    break;
   case 3:
    return HEAP32[$this + 36 >> 2];
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12ATOM_TO_JSIDP6JSAtom124($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj151($1);
  return $2;
}

function __ZL12JSID_TO_ATOMi($id) {
  var $1 = _JSID_TO_STRING150($id);
  return $1;
}

function __ZN2js12GlobalObject21setObjectClassDetailsEP10JSFunctionP8JSObject($this, $ctor, $proto) {
  var $1 = $ctor | 0;
  __ZN2js12GlobalObject16setDetailsForKeyE10JSProtoKeyP8JSObjectS3_($this, 1, $1, $proto);
  return;
}

function __ZN2js12GlobalObject23setFunctionClassDetailsEP10JSFunctionP8JSObject($this, $ctor, $proto) {
  var $1 = $ctor | 0;
  __ZN2js12GlobalObject16setDetailsForKeyE10JSProtoKeyP8JSObjectS3_($this, 2, $1, $proto);
  return;
}

function __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_0_0_val) {
  return $this_0_0_val;
}

function _JSVAL_IS_SPECIFIC_BOOLEAN($l_0$0, $l_0$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -125) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = ($l_0$0 | 0) == 0;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL15GetGCObjectKindEjb135($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26js_IsPropertyCacheDisabledP9JSContext($cx_0_11_val) {
  return HEAPU32[$cx_0_11_val + 209944 >> 2] >>> 0 > 16777215 & 1;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE5clearEv($this) {
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE10endNoCheckEv($this_0_0_val, $this_0_1_val) {
  return $this_0_0_val + ($this_0_1_val << 2) | 0;
}

function __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($cx, $ctor, $proto) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $cx + 52 | 0;
    var $7 = HEAP32[HEAP32[$3 >> 2] + 210200 >> 2] | 0;
    var $8 = __ZL12ATOM_TO_JSIDP6JSAtom124($7);
    __ZN2JSL11ObjectValueER8JSObject125($1, $proto);
    var $9 = $ctor;
    var $10 = $cx;
    var $11 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($9, $10, $8, $1, 10, 12, 6);
    if (($11 | 0) == 0) {
      var $23 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $17 = HEAP32[HEAP32[$3 >> 2] + 210204 >> 2] | 0;
    var $18 = __ZL12ATOM_TO_JSIDP6JSAtom124($17);
    __ZN2JSL11ObjectValueER8JSObject125($2, $ctor);
    var $19 = $proto;
    var $20 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($19, $10, $18, $2, 10, 12, 0);
    var $23 = ($20 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $23;
    STACKTOP = __stackBase__;
    return $23;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($cx, $obj, $ps, $fs) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($ps | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $cx;
    var $4 = $obj;
    var $5 = $ps;
    var $6 = _JS_DefineProperties($3, $4, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($fs | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $cx;
    var $12 = $obj;
    var $13 = $fs;
    var $14 = _JS_DefineFunctions($11, $12, $13);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx_val = HEAP8[$cx + 232 | 0];
    var $18 = __ZN9JSContext20typeInferenceEnabledEv($_idx_val);
    if ($18) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = __ZN8JSObject5brandEP9JSContext($obj, $cx);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject15addDataPropertyEP9JSContextijj($this, $cx, $id, $slot, $attrs) {
  var $1 = $this;
  var $2 = $cx;
  var $3 = __ZN8JSObject11addPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji($1, $2, $id, 0, 0, $slot, $attrs, 0, 0);
  return $3;
}

function __ZN2js12GlobalObject15setOriginalEvalEP8JSObject($this, $evalobj) {
  var $1 = $this;
  var $2 = __ZN8JSObject10getSlotRefEj($1, 116);
  var $3 = $evalobj;
  __ZN2JS5Value9setObjectER8JSObject($2, $3);
  return;
}

function __ZL14ThrowTypeErrorP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  var $1 = $cx;
  var $2 = _JS_ReportErrorFlagsAndNumber($1, 0, 252, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
  STACKTOP = __stackBase__;
  return 0;
}

function __ZN2js12GlobalObject17setThrowTypeErrorEP10JSFunction($this, $fun) {
  var $1 = $this;
  var $2 = __ZN8JSObject10getSlotRefEj($1, 111);
  var $3 = $fun;
  __ZN2JS5Value9setObjectER8JSObject($2, $3);
  return;
}

function __ZN2js12GlobalObject6createEP9JSContextPNS_5ClassE($cx, $clasp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_123($cx, $clasp, 0, 0);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN8JSObject16setSingletonTypeEP9JSContext($2, $cx);
    var $5 = __ZN8JSObject8asGlobalEv($2);
    var $6 = $5 | 0;
    var $7 = $5;
    __ZN8JSObject10makeVarObjEv($7);
    __ZN8JSObject19syncSpecialEqualityEv($6);
    var $8 = __ZN2jsL24regexp_statics_constructEP9JSContextPNS_12GlobalObjectE($cx, $5);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JSL11ObjectValueER8JSObject125($1, $8);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($7, 113, $_idx_val$0, $_idx_val$1);
    __ZN2js12GlobalObject8setFlagsEi($5);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject19syncSpecialEqualityEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this + 4 >> 2];
    var $2 = __ZNK8JSObject8getClassEv($_idx_val);
    if ((HEAP32[$2 + 68 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] | 2048;
    HEAP32[$8 >> 2] = $10;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL24regexp_statics_constructEP9JSContextPNS_12GlobalObjectE($cx, $parent) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $parent | 0;
    var $2 = __ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, __ZN2js20regexp_statics_classE, 0, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN9JSContext4new_IN2js13RegExpStaticsEEEPT_v($cx);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $5;
    var $9 = $2;
    __ZN8JSObject10setPrivateEPv($9, $8);
    var $_0 = $2;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11ObjectValueER8JSObject125($agg_result, $obj) {
  var $1 = $obj;
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $1);
  return;
}

function __ZN2js12GlobalObject8setFlagsEi($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL10Int32ValueEi127($1, 0);
  var $2 = $this;
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, 117, $_idx_val$0, $_idx_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12GlobalObject19initStandardClassesEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 209984 >> 2] | 0;
    var $7 = __ZL12ATOM_TO_JSIDP6JSAtom124($6);
    __ZN2JSL14UndefinedValueEv126($1);
    var $8 = $this;
    var $9 = $cx;
    var $10 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($8, $9, $7, $1, 10, 12, 6);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js12GlobalObject28initFunctionAndObjectClassesEP9JSContext($this, $cx);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = __Z17js_InitArrayClassP9JSContextP8JSObject($9, $8);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = $cx;
    var $20 = $this;
    var $21 = __Z19js_InitBooleanClassP9JSContextP8JSObject($19, $20);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = $cx;
    var $25 = $this;
    var $26 = __Z23js_InitExceptionClassesP9JSContextP8JSObject($24, $25);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $29 = $cx;
    var $30 = $this;
    var $31 = __Z16js_InitMathClassP9JSContextP8JSObject($29, $30);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $34 = __Z18js_InitNumberClassP9JSContextP8JSObject($9, $8);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $37 = __Z16js_InitJSONClassP9JSContextP8JSObject($29, $30);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $40 = $cx;
    var $41 = $this;
    var $42 = __Z18js_InitRegExpClassP9JSContextP8JSObject($40, $41);
    if (($42 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $45 = $cx;
    var $46 = $this;
    var $47 = __Z18js_InitStringClassP9JSContextP8JSObject($45, $46);
    if (($47 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $50 = __Z24js_InitTypedArrayClassesP9JSContextP8JSObject($9, $8);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $53 = __Z17js_InitXMLClassesP9JSContextP8JSObject($40, $41);
    if (($53 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $56 = __Z22js_InitIteratorClassesP9JSContextP8JSObject($29, $30);
    if (($56 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $59 = $cx;
    var $60 = $this;
    var $61 = __Z16js_InitDateClassP9JSContextP8JSObject($59, $60);
    if (($61 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $64 = _js_InitProxyClass($9, $8);
    var $_0 = ($64 | 0) != 0;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js12GlobalObject19initStandardClassesEP9JSContext["X"] = 1;

function __ZN2JSL14UndefinedValueEv126($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2js12GlobalObject5clearEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = $this | 0;
    __ZN8JSObject7unbrandEP9JSContext($6, $cx);
    var $7 = $this;
    var $_idx5 = $1 | 0;
    var $key_01 = 0;
    __label__ = 2;
    break;
   case 2:
    var $key_01;
    __ZN2JSL14UndefinedValueEv126($1);
    var $_idx5_val$0 = HEAP32[$_idx5 >> 2];
    var $_idx5_val$1 = HEAP32[$_idx5 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($7, $key_01, $_idx5_val$0, $_idx5_val$1);
    var $9 = $key_01 + 1 | 0;
    if (($9 | 0) == 111) {
      __label__ = 3;
      break;
    } else {
      var $key_01 = $9;
      __label__ = 2;
      break;
    }
   case 3:
    var $11 = __ZN2js13RegExpStatics11extractFromEPNS_12GlobalObjectE($this);
    __ZN2js13RegExpStatics5clearEv($11);
    __ZN2JSL14UndefinedValueEv126($2);
    var $_idx4 = $2 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($7, 115, $_idx4_val$0, $_idx4_val$1);
    __ZN2JSL14UndefinedValueEv126($3);
    var $_idx3 = $3 | 0;
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($7, 116, $_idx3_val$0, $_idx3_val$1);
    __ZN2JSL14UndefinedValueEv126($4);
    var $_idx2 = $4 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($7, 111, $_idx2_val$0, $_idx2_val$1);
    var $12 = __ZNK8JSObject7getSlotEj($7, 117);
    var $_idx = $12 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $13 = __ZNK2JS5Value7toInt32Ev($_idx_val$0, $_idx_val$1);
    var $14 = $13 | 1;
    __ZN2JSL10Int32ValueEi127($5, $14);
    var $_idx1 = $5 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($7, 117, $_idx1_val$0, $_idx1_val$1);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js12GlobalObject5clearEP9JSContext["X"] = 1;

function __ZN8JSObject7unbrandEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx = $this + 8 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $1 = __ZN8JSObject7brandedEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $this;
    var $_idx = $cx + 52 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    __ZN8JSObject16generateOwnShapeEP9JSContext($3, $_idx_val);
    var $cx_idx_val = HEAP32[$_idx >> 2];
    var $5 = __ZL26js_IsPropertyCacheDisabledP9JSContext($cx_idx_val);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = HEAP32[$this_idx >> 2] & -9;
    HEAP32[$this_idx >> 2] = $9;
    __label__ = 4;
    break;
   case 4:
    __ZN8JSObject10setGenericEv($this);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13RegExpStatics11extractFromEPNS_12GlobalObjectE($globalObj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $resVal = __stackBase__;
  __ZNK2js12GlobalObject16getRegExpStaticsEv($resVal, $globalObj);
  var $resVal_idx = $resVal | 0;
  var $resVal_idx_val$0 = HEAP32[$resVal_idx >> 2];
  var $resVal_idx_val$1 = HEAP32[$resVal_idx + 4 >> 2];
  var $1 = __ZNK2JS5Value8toObjectEv($resVal_idx_val$0, $resVal_idx_val$1);
  var $_idx_val = HEAP32[$1 + 24 >> 2];
  var $2 = __ZNK8JSObject10getPrivateEv($_idx_val);
  var $3 = $2;
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN2js13RegExpStatics5clearEv($this) {
  __ZN2js13RegExpStatics12aboutToWriteEv($this);
  HEAP32[$this + 100 >> 2] = 0;
  HEAP32[$this + 96 >> 2] = 0;
  HEAP32[$this + 92 >> 2] = 0;
  var $4 = $this | 0;
  __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE5clearEv($4);
  return;
}

function __ZN2JSL10Int32ValueEi127($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZN2js12GlobalObject23isRuntimeCodeGenEnabledEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this;
    var $3 = __ZN8JSObject10getSlotRefEj($2, 115);
    var $_idx = $3 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $4 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_idx1_val$1 = $_idx_val$1;
      var $_idx1_val$0 = $_idx_val$0;
      __label__ = 6;
      break;
    }
   case 2:
    var $6 = $cx;
    var $7 = _JS_GetSecurityCallbacks($6);
    if (($7 | 0) == 0) {
      var $18 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = HEAP32[$7 + 12 >> 2];
    if (($11 | 0) == 0) {
      var $18 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $11;
    var $15 = FUNCTION_TABLE[$14]($cx);
    var $18 = ($15 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $18;
    __ZN2JSL12BooleanValueEb($1, $18);
    var $19 = $1 | 0;
    var $20$0 = HEAP32[$19 >> 2];
    var $20$1 = HEAP32[$19 + 4 >> 2];
    HEAP32[$_idx >> 2] = $20$0;
    HEAP32[$_idx + 4 >> 2] = $20$1;
    var $_idx1_val$1 = $20$1;
    var $_idx1_val$0 = $20$0;
    __label__ = 6;
    break;
   case 6:
    var $_idx1_val$0;
    var $_idx1_val$1;
    var $22 = __ZNK2JS5Value7isFalseEv($_idx1_val$0, $_idx1_val$1);
    var $23 = $22 ^ 1;
    STACKTOP = __stackBase__;
    return $23;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL12BooleanValueEb($agg_result, $boo) {
  __ZN2JS5Value10setBooleanEb($agg_result, $boo);
  return;
}

function __ZNK2JS5Value7isFalseEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_IS_SPECIFIC_BOOLEAN($this_0_0_0_val$0, $this_0_0_0_val$1);
  return ($1 | 0) != 0;
}

function __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($this, $cx, $ctor, $clasp, $name, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = $ctor;
    var $3 = $this;
    var $4 = $name;
    var $5 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($1, 0, $2, $length, 512, $3, $4);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN10JSFunction19setConstructorClassEPN2js5ClassE($6, $clasp);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($this, $cx, $clasp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $objectProto = __stackBase__;
    var $1 = $cx;
    var $2 = $this;
    var $3 = $objectProto;
    var $4 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($1, $2, 1, $3, 0);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$objectProto >> 2];
    var $8 = __ZN2jsL16CreateBlankProtoEP9JSContextPNS_5ClassER8JSObjectRNS_12GlobalObjectE($cx, $clasp, $7, $this);
    var $_0 = $8;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16CreateBlankProtoEP9JSContextPNS_5ClassER8JSObjectRNS_12GlobalObjectE($cx, $clasp, $proto, $global) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $global | 0;
    var $2 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_123($cx, $clasp, $proto, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN8JSObject16setSingletonTypeEP9JSContext($2, $cx);
    var $5 = $2;
    var $6 = $cx;
    var $7 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($5, $6, 0, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $clasp;
    var $11 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($7, $6, $10, 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = $2;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12GlobalObject30createBlankPrototypeInheritingEP9JSContextPNS_5ClassER8JSObject($this, $cx, $proto) {
  var $1 = __ZN2jsL16CreateBlankProtoEP9JSContextPNS_5ClassER8JSObjectRNS_12GlobalObjectE($cx, __ZN2js10ErrorClassE, $proto, $this);
  return $1;
}

function __ZN8JSObject5brandEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $_idx = $cx + 52 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    __ZN8JSObject16generateOwnShapeEP9JSContext($1, $_idx_val);
    var $cx_idx_val = HEAP32[$_idx >> 2];
    var $3 = __ZL26js_IsPropertyCacheDisabledP9JSContext($cx_idx_val);
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = $this + 8 | 0;
    var $8 = HEAP32[$6 >> 2] | 8;
    HEAP32[$6 >> 2] = $8;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js24GlobalDebuggees_finalizeEP9JSContextP8JSObject($cx, $obj) {
  var $_idx_val = HEAP32[$obj + 24 >> 2];
  var $2 = __ZNK8JSObject10getPrivateEv($_idx_val);
  var $3 = $2;
  __ZN9JSContext7delete_IN2js6VectorIPNS1_8DebuggerELj0ENS1_17SystemAllocPolicyEEEEEvPT_($3);
  return;
}

function __ZN9JSContext7delete_IN2js6VectorIPNS1_8DebuggerELj0ENS1_17SystemAllocPolicyEEEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEED1Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12GlobalObject12getDebuggersEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $debuggers = __stackBase__;
    var $1 = $this;
    __ZNK8JSObject15getReservedSlotEj($debuggers, $1, 118);
    var $debuggers_idx1 = $debuggers | 0;
    var $debuggers_idx1_val$0 = HEAP32[$debuggers_idx1 >> 2];
    var $debuggers_idx1_val$1 = HEAP32[$debuggers_idx1 + 4 >> 2];
    var $2 = __ZNK2JS5Value11isUndefinedEv($debuggers_idx1_val$0, $debuggers_idx1_val$1);
    if ($2) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value8toObjectEv($debuggers_idx1_val$0, $debuggers_idx1_val$1);
    var $_idx_val = HEAP32[$4 + 24 >> 2];
    var $5 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12GlobalObject20getOrCreateDebuggersEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN2js12GlobalObject12getDebuggersEv($this);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $2;
      __label__ = 5;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_123($cx, __ZN2jsL21GlobalDebuggees_classE, 0, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZN9JSContext4new_IN2js6VectorIPNS1_8DebuggerELj0ENS1_17SystemAllocPolicyEEEEEPT_v($cx);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $9;
    var $13 = $6;
    __ZN8JSObject10setPrivateEPv($13, $12);
    __ZN2JSL11ObjectValueER8JSObject125($1, $6);
    var $14 = $this;
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($14, 118, $_idx_val$0, $_idx_val$1);
    var $_0 = $9;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext4new_IN2js6VectorIPNS1_8DebuggerELj0ENS1_17SystemAllocPolicyEEEEEPT_v($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZN9JSContext7malloc_Ej($1, 20);
    if (($2 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEEC1ES3_($5);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEEC1ES3_($this) {
  __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEEC2ES3_($this);
  return;
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEEC2ES3_($this) {
  var $1 = $this | 0;
  var $2 = $this + 12 | 0;
  var $3 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($2);
  HEAP32[$1 >> 2] = $3;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this >> 2];
    var $3 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js17SystemAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE136($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($proto | 0) != 0;
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZN2js5types15emptyTypeObjectE;
    var $_pre_phi = $cx;
    __label__ = 4;
    break;
   case 3:
    var $3 = $proto;
    var $4 = $cx;
    var $5 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($3, $4, 0, 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      var $8 = $6;
      var $_pre_phi = $4;
      __label__ = 4;
      break;
    }
   case 4:
    var $_pre_phi;
    var $8;
    var $9 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($_pre_phi, $kind);
    var $10 = $9;
    if (($9 | 0) == 0) {
      var $_0 = $10;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($parent | 0) != 0 | $1 ^ 1) {
      var $18 = $parent;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx_val = HEAP32[$proto + 20 >> 2];
    var $15 = __ZNK8JSObject9getParentEv($_idx_val);
    var $18 = $15;
    __label__ = 7;
    break;
   case 7:
    var $18;
    var $19 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    var $20 = $clasp;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($9, $20, $8, $18, 0, $19);
    var $_idx1_val = HEAP32[$clasp + 4 >> 2];
    var $24 = __ZNK2js5Class8isNativeEv($_idx1_val);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $26 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE139($cx, $10, $clasp, $8, $kind);
    if ($26) {
      var $_0 = $10;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_0 = 0;
    __label__ = 11;
    break;
   case 10:
    __ZN8JSObject21setSharedNonNativeMapEv($9);
    var $_0 = $10;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE139($cx, $obj, $clasp, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
    var $5 = $obj;
    var $_idx_val = HEAP32[$obj + 28 >> 2];
    var $7 = __ZNK8JSObject8numSlotsEv($_idx_val);
    if ($4 >>> 0 > $7 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = $obj;
    var $11 = $cx;
    var $12 = __ZN8JSObject10allocSlotsEP9JSContextj($10, $11, $4);
    if ($12) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $14 = $type;
    var $15 = $clasp;
    var $16 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($14, $15);
    var $17 = $cx;
    if ($16) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $19 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($14, $17, $15, $kind);
    var $empty_0_in = $19;
    __label__ = 6;
    break;
   case 5:
    var $21 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($17, $15);
    var $empty_0_in = $21;
    __label__ = 6;
    break;
   case 6:
    var $empty_0_in;
    if (($empty_0_in | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($5, $empty_0_in | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($clasp | 0) == (__ZN2js13FunctionClassE | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detailL9NewObjectILb1ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE($cx, __ZN2js13FunctionClassE, $proto, $parent, $kind);
    var $_0 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE136($cx, $clasp, $proto, $parent, $kind);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb1ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($proto | 0) != 0;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $8 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $proto;
    var $4 = $cx;
    var $5 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($3, $4, 0, 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      var $8 = $6;
      __label__ = 3;
      break;
    }
   case 3:
    var $8;
    var $9 = __Z16js_NewGCFunctionP9JSContext($cx);
    var $10 = $9 | 0;
    if (($9 | 0) == 0) {
      var $_0 = $10;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($parent | 0) != 0 | $1 ^ 1) {
      var $18 = $parent;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx_val = HEAP32[$proto + 20 >> 2];
    var $15 = __ZNK8JSObject9getParentEv($_idx_val);
    var $18 = $15;
    __label__ = 6;
    break;
   case 6:
    var $18;
    var $19 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    var $20 = $9;
    var $21 = $clasp;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($20, $21, $8, $18, 0, $19);
    var $_idx1_val = HEAP32[$clasp + 4 >> 2];
    var $25 = __ZNK2js5Class8isNativeEv($_idx1_val);
    if ($25) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $27 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE139($cx, $10, $clasp, $8, $kind);
    if ($27) {
      var $_0 = $10;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = 0;
    __label__ = 10;
    break;
   case 9:
    __ZN8JSObject21setSharedNonNativeMapEv($20);
    var $_0 = $10;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_NewGCFunctionP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z10NewGCThingI10JSFunctionEPT_P9JSContextN2js2gc9AllocKindEj($cx);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 + 28 >> 2] = 2;
    HEAP32[$1 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z10NewGCThingI10JSFunctionEPT_P9JSContextN2js2gc9AllocKindEj($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAP32[$cx + 56 >> 2] + 8 | 0;
    var $5 = __ZN2js2gc10ArenaLists20allocateFromFreeListENS0_9AllocKindEj($4, 12, 80);
    if (($5 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $11 = $5;
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $cx;
    var $9 = __ZN2js2gc10ArenaLists14refillFreeListEP9JSContextNS0_9AllocKindE($8, 12);
    var $11 = $9;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13RegExpStatics12aboutToWriteEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 104 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP8[$2 + 108 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js13RegExpStatics6copyToERS0_($this, $2);
    HEAP8[HEAP32[$1 >> 2] + 108 | 0] = 1;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13RegExpStatics6copyToERS0_($this, $dst) {
  var $1 = $dst | 0;
  __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE5clearEv($1);
  var $_idx_val = HEAP32[$this >> 2];
  var $_idx1_val = HEAP32[$this + 4 >> 2];
  __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE16infallibleAppendIiLj20ES1_EEvRKNS0_IT_XT0_ET1_EE($1, $_idx_val, $_idx1_val);
  var $3 = HEAP32[$this + 92 >> 2];
  HEAP32[$dst + 92 >> 2] = $3;
  var $6 = HEAP32[$this + 96 >> 2];
  HEAP32[$dst + 96 >> 2] = $6;
  var $9 = HEAP32[$this + 100 >> 2];
  HEAP32[$dst + 100 >> 2] = $9;
  return;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE16infallibleAppendIiLj20ES1_EEvRKNS0_IT_XT0_ET1_EE($this, $other_0_0_val, $other_0_1_val) {
  __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE14internalAppendIiLj20ES1_EEvRKNS0_IT_XT0_ET1_EE($this, $other_0_0_val, $other_0_1_val);
  return;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE14internalAppendIiLj20ES1_EEvRKNS0_IT_XT0_ET1_EE($this, $other_0_0_val, $other_0_1_val) {
  var $1 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE5beginEv($other_0_0_val);
  var $2 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE6lengthEv($other_0_1_val);
  __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE14internalAppendIiEEvPKT_j($this, $1, $2);
  return;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE14internalAppendIiEEvPKT_j($this, $insBegin, $length) {
  var $this_idx_val = HEAP32[$this >> 2];
  var $this_idx1 = $this + 4 | 0;
  var $this_idx1_val = HEAP32[$this_idx1 >> 2];
  var $1 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
  var $2 = $insBegin + ($length << 2) | 0;
  __ZN2js10VectorImplIiLj20ENS_17SystemAllocPolicyELb1EE13copyConstructIiEEvPiPKT_S7_($1, $insBegin, $2);
  var $4 = HEAP32[$this_idx1 >> 2] + $length | 0;
  HEAP32[$this_idx1 >> 2] = $4;
  return;
}

function __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE5beginEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE6lengthEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZL14JSID_FROM_BITSj151($bits) {
  return $bits;
}

function __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE5beginEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE6lengthEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js12DefnOrHeader4defnEv($this_0_0_0_val) {
  return $this_0_0_0_val;
}

function __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN8JSObject7brandedEv($this_0_2_val) {
  return ($this_0_2_val & 8 | 0) != 0;
}

function _JSID_TO_STRING150($iden) {
  return $iden;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E10overloadedEv($this_0_2_val, $this_0_3_val, $this_0_5_val) {
  return ($this_0_5_val + $this_0_3_val | 0) >>> 0 >= ($this_0_2_val * 192 | 0) >>> 8 >>> 0;
}

function __ZN7mozilla14AlignedStorageILj80EE4addrEv($this) {
  return $this;
}

function __ZN2js12ParseMapPool9asAtomMapEPv($ptr) {
  return $ptr;
}

function __ZNK2js12DefnOrHeader8isHeaderEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZNK2js12DefnOrHeader6headerEv($this) {
  return HEAP32[$this >> 2] & -2;
}

function __ZNK7mozilla14AlignedStorageILj128EE4addrEv($this) {
  return $this;
}

function __ZN7mozilla14AlignedStorageILj128EE4addrEv($this) {
  return $this;
}

function __ZN2js10VectorImplIiLj20ENS_17SystemAllocPolicyELb1EE13copyConstructIiEEvPiPKT_S7_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject10setGenericEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] | 16;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE3endEv($this_0_0_val, $this_0_1_val) {
  return $this_0_0_val + ($this_0_1_val << 2) | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  return;
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE10endNoCheckEv($this_0_0_val, $this_0_1_val) {
  return $this_0_0_val + ($this_0_1_val << 2) | 0;
}

function __ZN2js10VectorImplIPvLj32ENS_17SystemAllocPolicyELb1EE13copyConstructIS1_EEvPS1_PKT_S8_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE5clearEv($this) {
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZNK2js12GlobalObject16getRegExpStaticsEv($agg_result, $this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject7getSlotEj($1, 113);
  var $3 = $2 | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  var $5 = $agg_result | 0;
  HEAP32[$5 >> 2] = $4$0;
  HEAP32[$5 + 4 >> 2] = $4$1;
  return;
}

function __ZN9JSContext4new_IN2js13RegExpStaticsEEEPT_v($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZN9JSContext7malloc_Ej($1, 112);
    if (($2 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN2js13RegExpStaticsC1Ev($5);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13RegExpStaticsC1Ev($this) {
  __ZN2js13RegExpStaticsC2Ev($this);
  return;
}

function __ZN2js13RegExpStaticsC2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEEC1ES1_($1);
  HEAP32[$this + 104 >> 2] = 0;
  HEAP8[$this + 108 | 0] = 0;
  __ZN2js13RegExpStatics5clearEv($this);
  return;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEEC1ES1_($this) {
  __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEEC2ES1_($this);
  return;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEEC2ES1_($this) {
  var $1 = $this | 0;
  var $2 = $this + 12 | 0;
  var $3 = __ZN7mozilla14AlignedStorageILj80EE4addrEv($2);
  HEAP32[$1 >> 2] = $3;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 20;
  return;
}

function __ZN2js12GlobalObject16setDetailsForKeyE10JSProtoKeyP8JSObjectS3_($this, $key, $ctor, $proto) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 8;
  var $3 = $this;
  var $4 = __ZN8JSObject10getSlotRefEj($3, $key);
  var $5 = $key + 37 | 0;
  var $6 = __ZN8JSObject10getSlotRefEj($3, $5);
  var $7 = $key + 74 | 0;
  var $8 = __ZN8JSObject10getSlotRefEj($3, $7);
  __ZN2JSL11ObjectValueER8JSObject125($1, $ctor);
  var $9 = $1 | 0;
  var $10$0 = HEAP32[$9 >> 2];
  var $10$1 = HEAP32[$9 + 4 >> 2];
  var $11 = $4 | 0;
  HEAP32[$11 >> 2] = $10$0;
  HEAP32[$11 + 4 >> 2] = $10$1;
  __ZN2JSL11ObjectValueER8JSObject125($2, $proto);
  var $12 = $2 | 0;
  var $13$0 = HEAP32[$12 >> 2];
  var $13$1 = HEAP32[$12 + 4 >> 2];
  var $14 = $6 | 0;
  HEAP32[$14 >> 2] = $13$0;
  HEAP32[$14 + 4 >> 2] = $13$1;
  var $15$0 = HEAP32[$11 >> 2];
  var $15$1 = HEAP32[$11 + 4 >> 2];
  var $16 = $8 | 0;
  HEAP32[$16 >> 2] = $15$0;
  HEAP32[$16 + 4 >> 2] = $15$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12ParseMapPool8purgeAllEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_idx_val = HEAP32[$this >> 2];
    var $2 = __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE5beginEv($_idx_val);
    var $_idx2_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE3endEv($_idx_val, $_idx2_val);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $it_01 = $2;
      __label__ = 2;
      break;
    }
   case 2:
    var $it_01;
    var $5 = HEAP32[$it_01 >> 2];
    var $6 = __ZN2js12ParseMapPool9asAtomMapEPv($5);
    __ZN9JSContext7delete_IN2js9InlineMapIP6JSAtomjLj24EEEEEvPT_($6);
    var $7 = $it_01 + 4 | 0;
    if (($7 | 0) == ($3 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $it_01 = $7;
      __label__ = 2;
      break;
    }
   case 3:
    __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE12clearAndFreeEv($1);
    var $9 = $this + 140 | 0;
    __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE12clearAndFreeEv($9);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext7delete_IN2js9InlineMapIP6JSAtomjLj24EEEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js9InlineMapIP6JSAtomjLj24EED1Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE12clearAndFreeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE5clearEv($this);
    var $1 = __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx = $this | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $3 = __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js17SystemAllocPolicy5free_EPv($4);
    var $5 = $this + 12 | 0;
    var $6 = __ZN7mozilla14AlignedStorageILj128EE4addrEv($5);
    HEAP32[$this_idx >> 2] = $6;
    HEAP32[$this + 8 >> 2] = 32;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ParseMapPool13allocateFreshEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_idx_val = HEAP32[$this + 4 >> 2];
    var $2 = __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE6lengthEv($_idx_val);
    var $3 = $2 + 1 | 0;
    var $4 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE7reserveEj($1, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $6 = $this + 140 | 0;
    var $7 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE7reserveEj($6, $3);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = HEAP32[$this + 280 >> 2];
    var $11 = __ZN9JSContext4new_IN2js9InlineMapIP6JSAtomjLj24EEEPS_EEPT_T0_($10, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $11;
    __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE16infallibleAppendERKS1_($1, $14);
    var $_0 = $14;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE7reserveEj($this, $request) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$this + 8 >> 2] >>> 0 < $request >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $request - HEAP32[$this + 4 >> 2] | 0;
    var $8 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE13growStorageByEj($this, $7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext4new_IN2js9InlineMapIP6JSAtomjLj24EEEPS_EEPT_T0_($this, $p1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 228);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js9InlineMapIP6JSAtomjLj24EEC1EP9JSContext($4, $p1);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE16infallibleAppendERKS1_($this, $t_val) {
  __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE14internalAppendIS1_EEvT_($this, $t_val);
  return;
}

function __ZN2js9AtomDecls9allocNodeEP12JSDefinition($this, $defn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $4 = HEAP32[$2 + 88 >> 2];
    var $6 = HEAP32[$2 + 96 >> 2];
    var $9 = $6 + 8 & ($6 ^ -1);
    var $10 = $4 + 12 | 0;
    var $11 = HEAPU32[$10 >> 2];
    if ($11 >>> 0 > (HEAP32[$4 + 8 >> 2] - $9 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = $2 + 72 | 0;
    var $18 = _JS_ArenaAllocate($17, $9);
    var $_p_0 = $18;
    __label__ = 4;
    break;
   case 3:
    var $21 = $9 + $11 | 0;
    HEAP32[$10 >> 2] = $21;
    var $_p_0 = $11;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $25 = HEAP32[$1 >> 2];
    __Z20js_ReportOutOfMemoryP9JSContext($25);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $27 = $_p_0;
    __ZN2js12AtomDeclNodeC1EP12JSDefinition($27, $defn);
    var $_0 = $27;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12AtomDeclNodeC1EP12JSDefinition($this, $defn) {
  __ZN2js12AtomDeclNodeC2EP12JSDefinition($this, $defn);
  return;
}

function __ZN2js9AtomDecls9addShadowEP6JSAtomP12JSDefinition($this, $atom, $defn) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 20;
    var $3 = __stackBase__ + 24;
    HEAP32[$1 >> 2] = $atom;
    var $4 = __ZN2js9AtomDecls9allocNodeEP12JSDefinition($this, $defn);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this + 4 | 0;
    var $8 = HEAP32[$7 >> 2];
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE12lookupForAddERKS2_($p, $8, $1);
    var $9 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrcvPPPPPPPS5_Ev($p);
    if (($9 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = HEAP32[$7 >> 2];
    __ZN2js12DefnOrHeaderC1EPNS_12AtomDeclNodeE($2, $4);
    var $13 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3addERNS4_6AddPtrERKS2_RKS3_($12, $p, $1, $2);
    var $_0 = $13;
    __label__ = 8;
    break;
   case 4:
    var $15 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtr5valueEv($p);
    var $16 = __ZNK2js12DefnOrHeader8isHeaderEv($15);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $18 = __ZNK2js12DefnOrHeader6headerEv($15);
    var $toShadow_0 = $18;
    __label__ = 7;
    break;
   case 6:
    var $_idx_val = HEAP32[$15 >> 2];
    var $20 = __ZNK2js12DefnOrHeader4defnEv($_idx_val);
    var $21 = __ZN2js9AtomDecls9allocNodeEP12JSDefinition($this, $20);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      var $toShadow_0 = $21;
      __label__ = 7;
      break;
    }
   case 7:
    var $toShadow_0;
    HEAP32[$4 + 4 >> 2] = $toShadow_0;
    var $25 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtr5valueEv($p);
    __ZN2js12DefnOrHeaderC1EPNS_12AtomDeclNodeE($3, $4);
    var $27 = HEAP32[$3 >> 2];
    HEAP32[$25 >> 2] = $27;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE12lookupForAddERKS2_($agg_result, $this, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $this_idx_val = HEAP32[$this >> 2];
    var $2 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE8usingMapEv($this_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this + 200 | 0;
    __ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($1, $4, $key);
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC1ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E6AddPtrE($agg_result, $1);
    __label__ = 9;
    break;
   case 3:
    var $7 = $this + 8 + ($this_idx_val << 3) | 0;
    var $it_0 = $this + 8 | 0;
    __label__ = 4;
    break;
   case 4:
    var $it_0;
    if (($it_0 | 0) == ($7 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$it_0 >> 2] | 0) == (HEAP32[$key >> 2] | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC1EPNS4_10InlineElemEb($agg_result, $it_0, 1);
    __label__ = 9;
    break;
   case 7:
    var $it_0 = $it_0 + 8 | 0;
    __label__ = 4;
    break;
   case 8:
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC1EPNS4_10InlineElemEb($agg_result, $7, 0);
    __label__ = 9;
    break;
   case 9:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrcvPPPPPPPS5_Ev($this) {
  var $1 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtr5foundEv($this);
  var $2 = $1 ? 1 : 0;
  return $2;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3addERNS4_6AddPtrERKS2_RKS3_($this, $p, $key, $value) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$p + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $p + 8 | 0;
    var $7 = HEAP32[$6 >> 2];
    if (($7 | 0) == ($this + 200 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE12switchAndAddERKS2_RKS3_($this, $key, $value);
    var $_0 = $11;
    __label__ = 6;
    break;
   case 4:
    var $13 = HEAP32[$key >> 2];
    var $14 = $7 | 0;
    HEAP32[$14 >> 2] = $13;
    var $17 = HEAP32[$value >> 2];
    var $18 = HEAP32[$6 >> 2] + 4 | 0;
    HEAP32[$18 >> 2] = $17;
    var $19 = $this + 4 | 0;
    var $21 = HEAP32[$19 >> 2] + 1 | 0;
    HEAP32[$19 >> 2] = $21;
    var $22 = $this | 0;
    var $24 = HEAP32[$22 >> 2] + 1 | 0;
    HEAP32[$22 >> 2] = $24;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $26 = $this + 200 | 0;
    var $27 = $p | 0;
    var $28 = __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E6AddPtrERKS2_RKS3_($26, $27, $key, $value);
    var $_0 = $28;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12DefnOrHeaderC1EPNS_12AtomDeclNodeE($this, $node) {
  __ZN2js12DefnOrHeaderC2EPNS_12AtomDeclNodeE($this, $node);
  return;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtr5valueEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[$this + 8 >> 2] + 4 | 0;
    __label__ = 4;
    break;
   case 3:
    var $_idx_val = HEAP32[$this >> 2];
    var $10 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3PtrptEv($_idx_val);
    var $_0 = $10 + 4 | 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9AtomDecls10lastAsNodeEPNS_12DefnOrHeaderE($this, $doh) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2js12DefnOrHeader8isHeaderEv($doh);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZNK2js12DefnOrHeader6headerEv($doh);
    var $last_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $last_0;
    var $7 = HEAP32[$last_0 + 4 >> 2];
    if (($7 | 0) == 0) {
      var $_0 = $last_0;
      __label__ = 6;
      break;
    } else {
      var $last_0 = $7;
      __label__ = 3;
      break;
    }
   case 4:
    var $doh_idx = $doh | 0;
    var $doh_idx_val = HEAP32[$doh_idx >> 2];
    var $10 = __ZNK2js12DefnOrHeader4defnEv($doh_idx_val);
    var $11 = __ZN2js9AtomDecls9allocNodeEP12JSDefinition($this, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js12DefnOrHeaderC1EPNS_12AtomDeclNodeE($1, $11);
    var $15 = HEAP32[$1 >> 2];
    HEAP32[$doh_idx >> 2] = $15;
    var $_0 = $11;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9AtomDecls8addHoistEP6JSAtomP12JSDefinition($this, $atom, $defn) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 20;
    HEAP32[$1 >> 2] = $atom;
    var $3 = __ZN2js9AtomDecls9allocNodeEP12JSDefinition($this, $defn);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $this + 4 | 0;
    var $7 = HEAP32[$6 >> 2];
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE12lookupForAddERKS2_($p, $7, $1);
    var $8 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrcvPPPPPPPS5_Ev($p);
    if (($8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtr5valueEv($p);
    var $12 = __ZN2js9AtomDecls10lastAsNodeEPNS_12DefnOrHeaderE($this, $11);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$12 + 4 >> 2] = $3;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $17 = HEAP32[$6 >> 2];
    __ZN2js12DefnOrHeaderC1EPNS_12AtomDeclNodeE($2, $3);
    var $18 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3addERNS4_6AddPtrERKS2_RKS3_($17, $p, $1, $2);
    var $_0 = $18;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomjLj24EEC1EP9JSContext($this, $cx) {
  __ZN2js9InlineMapIP6JSAtomjLj24EEC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EEC2EP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  var $4 = $this + 200 | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_($4, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_($this, $a_01) {
  __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_($this, $a_01);
  return;
}

function __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_($this, $a_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC1ES9_($1, $a_0);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC1ES9_($this, $ap_01) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap_01);
  return;
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = $this + 12 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj128EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 2;
    var $7 = __ZN2js17SystemAllocPolicy7malloc_Ej($6);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $11 = __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $12 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplIPvLj32ENS_17SystemAllocPolicyELb1EE13moveConstructIS1_EEvPS1_PKT_S8_($8, $11, $12);
    HEAP32[$this_idx >> 2] = $8;
    HEAP32[$this + 8 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIPvLj32ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS1_Lj32ES2_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $5;
    if ($5 >>> 0 > 536870911) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPvLj32ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS1_Lj32ES2_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = __ZN2js17SystemAllocPolicy8realloc_EPvjj($4, $1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5;
    var $9 = $v + 8 | 0;
    HEAP32[$2 >> 2] = $8;
    HEAP32[$9 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPvLj32ENS_17SystemAllocPolicyELb1EE13moveConstructIS1_EEvPS1_PKT_S8_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIPvLj32ENS_17SystemAllocPolicyELb1EE13copyConstructIS1_EEvPS1_PKT_S8_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EED1Ev($this) {
  __ZN2js9InlineMapIP6JSAtomjLj24EED2Ev($this);
  return;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EED2Ev($this) {
  var $1 = $this + 200 | 0;
  __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev($1);
  return;
}

function __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 24 >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED1Ev($this_0_6_val) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED2Ev($this_0_6_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED2Ev($this_0_6_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_6_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($this_0_6_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js15TempAllocPolicy5free_EPv($0);
  return;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE12switchAndAddERKS2_RKS3_($this, $key, $value) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE11switchToMapEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this + 200 | 0;
    var $4 = __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKS3_($3, $key, $value);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E6AddPtrERKS2_RKS3_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrEPPS6_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $8 = HEAP32[$v >> 2];
    var $9 = $5 + 4 | 0;
    HEAP32[$9 >> 2] = $8;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrEPPS6_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 12 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 8 >> 2];
    var $this_idx1 = $this + 12 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 20 >> 2];
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefIP6JSAtomEcvRS2_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_12DefnOrHeaderEEcvRS1_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5countEv($this_0_3_val) {
  return $this_0_3_val;
}

function __ZNK2js9FrameRegs7inlinedEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZN2js13PointerHasherIP6JSAtomLj2EE5matchERKS2_S5_($k_val, $l_val) {
  return ($k_val | 0) == ($l_val | 0);
}

function __ZN2js13PointerHasherIP6JSAtomLj2EE4hashERKS2_($l_val) {
  return $l_val >>> 2;
}

function __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE8usingMapEv($this_0_0_val) {
  return $this_0_0_val >>> 0 > 24;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11initializedEv($this_0_6_val) {
  return ($this_0_6_val | 0) != 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEC2ERS8_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC2ERS5_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_12DefnOrHeaderEEC2ERS1_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefIP6JSAtomEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js12DefnOrHeaderC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3PtrC2ERNS0_14HashTableEntryIS6_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S3_EE($e) {
  return $e | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3PtrptEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC2EPNS4_10InlineElemEb($this, $ptr, $found) {
  HEAP32[$this + 8 >> 2] = $ptr;
  HEAP8[$this + 12 | 0] = 1;
  HEAP8[$this + 13 | 0] = $found & 1;
  return;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC2ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E6AddPtrE($this, $p) {
  var $1 = $p;
  var $2 = $this;
  var $3$0 = HEAP32[$1 >> 2];
  var $3$1 = HEAP32[$1 + 4 >> 2];
  HEAP32[$2 >> 2] = $3$0;
  HEAP32[$2 + 4 >> 2] = $3$1;
  HEAP8[$this + 12 | 0] = 0;
  return;
}

function __ZN2js12DefnOrHeaderC2EPNS_12AtomDeclNodeE($this, $node) {
  HEAP32[$this >> 2] = $node | 1;
  return;
}

function __ZN2js12AtomDeclNodeC2EP12JSDefinition($this, $defn) {
  HEAP32[$this >> 2] = $defn;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZNK2js10StackFrame10annotationEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this >> 2] & 131072 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$this + 48 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame13setAnnotationEPv($this, $annot) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 131072;
  HEAP32[$1 >> 2] = $3;
  HEAP32[$this + 48 >> 2] = $annot;
  return;
}

function __ZN2js10StackFrame22setScopeChainNoCallObjER8JSObject($this, $obj) {
  HEAP32[$this + 12 >> 2] = $obj;
  var $2 = $this | 0;
  var $4 = HEAP32[$2 >> 2] | 524288;
  HEAP32[$2 >> 2] = $4;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 3:
    var $14 = $this | 0;
    var $15 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11createTableERSA_j($14, $10);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $19 = $this + 16 | 0;
    var $21 = HEAP32[$19 >> 2] + 1 | 0;
    HEAP32[$19 >> 2] = $21;
    HEAP32[$2 >> 2] = $15;
    var $22 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 6;
    break;
   case 6:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isLiveEv($src_01_idx_val);
    if ($24) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $26 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE10getKeyHashEv($src_01_idx1_val);
    var $27 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E13findFreeEntryEj($this, $26);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEENS_7MoveRefIT_EERSA_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEaSENS_7MoveRefIS7_EE($27, $_02_val);
    __label__ = 8;
    break;
   case 8:
    var $29 = $src_01 + 12 | 0;
    if (($29 | 0) == ($22 | 0)) {
      __label__ = 9;
      break;
    } else {
      var $src_01 = $29;
      __label__ = 6;
      break;
    }
   case 9:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E12destroyTableERSA_PNS0_14HashTableEntryIS6_EEj($3);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E15changeTableSizeEi["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11createTableERSA_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js15TempAllocPolicy7malloc_Ej($alloc, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEaSENS_7MoveRefIS7_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = $2 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEENS_7MoveRefIT_EERS7_($1, $7);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEaSENS_7MoveRefIS4_EE($6, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEENS_7MoveRefIT_EERSA_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEC1ERS8_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E12destroyTableERSA_PNS0_14HashTableEntryIS6_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js15TempAllocPolicy5free_EPv($0);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEC1ERS8_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEC2ERS8_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEaSENS_7MoveRefIS4_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEptEv($rhs_0);
  var $4 = $3 | 0;
  __ZN2js4MoveIP6JSAtomEENS_7MoveRefIT_EERKS4_($1, $4);
  var $_idx_val = HEAP32[$1 >> 2];
  var $5 = __ZNK2js7MoveRefIP6JSAtomEcvRS2_Ev($_idx_val);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = $3 + 4 | 0;
  __ZN2js4MoveINS_12DefnOrHeaderEEENS_7MoveRefIT_EERS3_($2, $8);
  var $_idx2_val = HEAP32[$2 >> 2];
  var $9 = __ZNK2js7MoveRefINS_12DefnOrHeaderEEcvRS1_Ev($_idx2_val);
  var $11 = HEAP32[$9 >> 2];
  HEAP32[$this + 4 >> 2] = $11;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEENS_7MoveRefIT_EERS7_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC1ERS5_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC1ERS5_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC2ERS5_($this, $t);
  return;
}

function __ZN2js4MoveIP6JSAtomEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefIP6JSAtomEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js4MoveINS_12DefnOrHeaderEEENS_7MoveRefIT_EERS3_($agg_result, $t) {
  __ZN2js7MoveRefINS_12DefnOrHeaderEEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12DefnOrHeaderEEC1ERS1_($this, $t) {
  __ZN2js7MoveRefINS_12DefnOrHeaderEEC2ERS1_($this, $t);
  return;
}

function __ZN2js7MoveRefIP6JSAtomEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIP6JSAtomEC2ERS2_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEC1Ev($this) {
  __ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEC2Ev($this);
  return;
}

function __ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12DefnOrHeaderC1Ev($2);
  return;
}

function __ZN2js12DefnOrHeaderC1Ev($this) {
  __ZN2js12DefnOrHeaderC2Ev($this);
  return;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE11switchToMapEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 200 | 0;
    var $2 = __ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE11initializedEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv($1);
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5countEv($this);
    var $6 = __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($1, $5);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 4:
    var $9 = $this | 0;
    var $11 = $this + 8 + (HEAP32[$9 >> 2] << 3) | 0;
    var $it_0 = $this + 8 | 0;
    __label__ = 5;
    break;
   case 5:
    var $it_0;
    if (($it_0 | 0) == ($11 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $it_0 | 0;
    if ((HEAP32[$15 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKS3_($1, $15, $it_0 + 4 | 0);
    if ($20) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $it_0 = $it_0 + 8 | 0;
    __label__ = 5;
    break;
   case 9:
    HEAP32[$9 >> 2] = 25;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKS3_($this, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $p = __stackBase__;
  __ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($p, $this, $k);
  var $1 = __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E6AddPtrERKS2_RKS3_($this, $p, $k, $v);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11prepareHashERKS4_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6AddPtrC1ERNS0_14HashTableEntryIS6_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11prepareHashERKS4_($l_val1) {
  var $1 = __ZN2js13PointerHasherIP6JSAtomLj2EE4hashERKS2_($l_val1);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $l_val4 = HEAP32[$l >> 2];
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5matchERNS0_14HashTableEntryIS6_EERKS4_($6, $l_val4);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $l_val = HEAP32[$l >> 2];
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5matchERNS0_14HashTableEntryIS6_EERKS4_($27, $l_val);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6lookupERKS4_jj["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6AddPtrC1ERNS0_14HashTableEntryIS6_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6AddPtrC2ERNS0_14HashTableEntryIS6_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6AddPtrC2ERNS0_14HashTableEntryIS6_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3PtrC2ERNS0_14HashTableEntryIS6_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5matchERNS0_14HashTableEntryIS6_EERKS4_($e, $l_val1) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S3_EE($1);
  var $_val = HEAP32[$2 >> 2];
  var $3 = __ZN2js13PointerHasherIP6JSAtomLj2EE5matchERKS2_S5_($_val, $l_val1);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE10isLiveHashEj($hash);
  return $1;
}

function __ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE11initializedEv($this) {
  var $_idx_val = HEAP32[$this + 24 >> 2];
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11initializedEv($_idx_val);
  return $1;
}

function __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5clearEv($1);
  return;
}

function __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E4initEj($1, $len);
  return $2;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5countEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE8usingMapEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this + 200 | 0;
    var $4 = __ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv($3);
    var $9 = $4;
    __label__ = 4;
    break;
   case 3:
    var $9 = HEAP32[$this + 4 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv($this) {
  var $_idx_val = HEAP32[$this + 12 >> 2];
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5countEv($_idx_val);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $4 = $length * 171 | 0;
    var $capacity_0 = $4 >>> 0 < 2048 ? 16 : $4 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 5;
      break;
    }
   case 4:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $8 = $roundUp_01 << 1;
    var $9 = $roundUpLog2_02 + 1 | 0;
    if ($8 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $8;
      var $roundUpLog2_02 = $9;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = $8;
      var $roundUpLog2_0_lcssa = $9;
      __label__ = 5;
      break;
    }
   case 5:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $11 = $this | 0;
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11createTableERSA_j($11, $roundUp_0_lcssa);
    HEAP32[$this + 24 >> 2] = $12;
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5clearEv($this) {
  var $3 = HEAP32[$this + 24 >> 2];
  var $6 = HEAP32[$this + 8 >> 2] * 12 | 0;
  _memset($3, 0, $6, 1);
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtr5foundEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = (HEAP8[$this + 13 | 0] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $_idx_val_idx_val = HEAP32[HEAP32[$this >> 2] >> 2];
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3Ptr5foundEv($_idx_val_idx_val);
    var $13 = $11;
    __label__ = 4;
    break;
   case 4:
    var $13;
    return $13;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC1ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E6AddPtrE($this, $p) {
  __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC2ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E6AddPtrE($this, $p);
  return;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC1EPNS4_10InlineElemEb($this, $ptr, $found) {
  __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC2EPNS4_10InlineElemEb($this, $ptr, $found);
  return;
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE14internalAppendIS1_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this >> 2];
    var $this_idx1 = $this + 4 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $5 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    var $5 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    HEAP32[$this_idx1 >> 2] = $5 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame16initExecuteFrameEP8JSScriptPS0_PNS_9FrameRegsERKN2JS5ValueER8JSObjectNS_11ExecuteTypeE($this, $script, $prev, $regs, $thisv, $scopeChain, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $type | 1572864;
    var $3 = $this | 0;
    HEAP32[$3 >> 2] = $2;
    if (($type & 1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_idx_val = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = HEAP32[$prev >> 2] & 3 | $2;
    HEAP32[$3 >> 2] = $10;
    var $_idx_val = $10;
    __label__ = 3;
    break;
   case 3:
    var $_idx_val;
    var $12 = $this - 56 + 40 | 0;
    var $14 = $thisv | 0;
    var $15 = $12 + 8 | 0;
    var $16$0 = HEAP32[$14 >> 2];
    var $16$1 = HEAP32[$14 + 4 >> 2];
    HEAP32[$15 >> 2] = $16$0;
    HEAP32[$15 + 4 >> 2] = $16$1;
    var $17 = __ZNK2js10StackFrame15isFunctionFrameEv($_idx_val);
    if ($17) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $19 = $prev;
    var $20 = __ZNK2js10StackFrame7calleevEv($19);
    var $21 = $20 | 0;
    var $22 = $12;
    var $23$0 = HEAP32[$21 >> 2];
    var $23$1 = HEAP32[$21 + 4 >> 2];
    HEAP32[$22 >> 2] = $23$0;
    HEAP32[$22 + 4 >> 2] = $23$1;
    var $25 = HEAP32[$prev + 4 >> 2];
    HEAP32[$this + 4 >> 2] = $25;
    HEAP32[$this + 8 >> 2] = $script;
    __label__ = 6;
    break;
   case 5:
    __ZN2JSL9NullValueEv158($1);
    var $29 = $1 | 0;
    var $30 = $12;
    var $31$0 = HEAP32[$29 >> 2];
    var $31$1 = HEAP32[$29 + 4 >> 2];
    HEAP32[$30 >> 2] = $31$0;
    HEAP32[$30 + 4 >> 2] = $31$1;
    HEAP32[$this + 4 >> 2] = $script;
    __label__ = 6;
    break;
   case 6:
    HEAP32[$this + 12 >> 2] = $scopeChain;
    HEAP32[$this + 16 >> 2] = $prev;
    if (($regs | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $39 = HEAP32[$regs + 4 >> 2];
    HEAP32[$this + 32 >> 2] = $39;
    var $regs_idx_val = HEAP32[$regs + 8 >> 2];
    var $41 = __ZNK2js9FrameRegs7inlinedEv($regs_idx_val);
    var $44 = $41;
    __label__ = 9;
    break;
   case 8:
    HEAP32[$this + 32 >> 2] = 2989;
    var $44 = 0;
    __label__ = 9;
    break;
   case 9:
    var $44;
    HEAP32[$this + 36 >> 2] = $44;
    if (($prev | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $48 = __ZNK2js10StackFrame10annotationEv($prev);
    if (($48 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2js10StackFrame13setAnnotationEPv($this, $48);
    __label__ = 12;
    break;
   case 12:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js10StackFrame16initExecuteFrameEP8JSScriptPS0_PNS_9FrameRegsERKN2JS5ValueER8JSObjectNS_11ExecuteTypeE["X"] = 1;

function __ZN2JSL9NullValueEv158($agg_result) {
  __ZN2JS5Value7setNullEv($agg_result);
  return;
}

function __ZN2js10StackFrame14initDummyFrameEP9JSContextR8JSObject($this, $cx, $chain) {
  __ZN2jsL7PodZeroINS_10StackFrameEEEvPT_($this);
  HEAP32[$this >> 2] = 1572868;
  __ZN2js10StackFrame8initPrevEP9JSContext($this, $cx);
  __ZN2js10StackFrame22setScopeChainNoCallObjER8JSObject($this, $chain);
  return;
}

function __ZN2jsL7PodZeroINS_10StackFrameEEEvPT_($t) {
  var $1 = $t;
  _memset($1, 0, 56, 1);
  return;
}

function __ZN2js10StackFrame8initPrevEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK9JSContext9maybeRegsEv($cx);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$1 + 12 >> 2];
    var $5 = __ZNK2js9FrameRegs2fpEv($_idx_val);
    var $6 = $5;
    HEAP32[$this + 16 >> 2] = $6;
    var $9 = HEAP32[$1 + 4 >> 2];
    HEAP32[$this + 32 >> 2] = $9;
    var $_idx1_val = HEAP32[$1 + 8 >> 2];
    var $11 = __ZNK2js9FrameRegs7inlinedEv($_idx1_val);
    HEAP32[$this + 36 >> 2] = $11;
    __label__ = 4;
    break;
   case 3:
    HEAP32[$this + 16 >> 2] = 0;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame18stealFrameAndSlotsEPN2JS5ValueEPS0_S3_S3_($this, $vp, $otherfp, $othervp, $othersp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = $othersp - $othervp >> 3;
    __ZN2jsL7PodCopyIN2JS5ValueEEEvPT_PKS3_j($vp, $othervp, $4);
    var $5 = $this;
    var $_idx2 = $this | 0;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $6 = __ZNK2js10StackFrame10hasCallObjEv($_idx2_val);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = __ZNK2js10StackFrame7callObjEv($this);
    var $9 = $this;
    var $10 = $8;
    __ZN8JSObject10setPrivateEPv($10, $9);
    var $11 = $otherfp | 0;
    var $13 = HEAP32[$11 >> 2] & -16385;
    HEAP32[$11 >> 2] = $13;
    var $14 = __ZNK2js10StackFrame3funEv($5);
    var $15 = $14;
    var $16 = __Z16js_IsNamedLambdaP10JSFunction($15);
    if ($16) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $_idx1_val = HEAP32[$8 + 20 >> 2];
    var $19 = __ZNK8JSObject9getParentEv($_idx1_val);
    __ZN8JSObject10setPrivateEPv($19, $9);
    __label__ = 4;
    break;
   case 4:
    var $_idx_val = HEAP32[$_idx2 >> 2];
    var $20 = __ZNK2js10StackFrame10hasArgsObjEv($_idx_val);
    if ($20) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $22 = __ZNK2js10StackFrame7argsObjEv($5);
    var $_idx3_val = HEAP32[$22 + 4 >> 2];
    var $24 = __ZNK8JSObject17isNormalArgumentsEv($_idx3_val);
    if ($24) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $26 = $22;
    __ZN2js15ArgumentsObject13setStackFrameEPNS_10StackFrameE($26, $this);
    __label__ = 7;
    break;
   case 7:
    var $27 = $otherfp | 0;
    var $29 = HEAP32[$27 >> 2] & -32769;
    HEAP32[$27 >> 2] = $29;
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12StackSegment12prevInMemoryEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK9JSRuntime17trustedPrincipalsEv($this_0_68_val) {
  return $this_0_68_val;
}

function __ZNK2js12StackSegment13prevInContextEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js12StackSegment10maybeCallsEv($this_0_3_val) {
  return $this_0_3_val;
}

function __ZN2jsL12ToFrameFlagsENS_17InitialFrameFlagsE($initial) {
  return $initial;
}

function __ZNK2js8CallArgs4argcEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK8JSObject17isNormalArgumentsEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js26NormalArgumentsObjectClassE | 0);
}

function __ZN2jsL3MaxIPN2JS5ValueEEET_S4_S4_($t1, $t2) {
  var $2 = $t1 >>> 0 > $t2 >>> 0 ? $t1 : $t2;
  return $2;
}

function __Z16js_IsNamedLambdaP10JSFunction($fun) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP16[$fun + 58 >> 1] & 8) << 16 >> 16 == 0) {
      var $10 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = (HEAP32[$fun + 72 >> 2] | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame6prevpcEPPNS_13JSInlinedSiteE($this, $pinlined) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this >> 2] & 1048576 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($pinlined | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAP32[$this + 36 >> 2];
    HEAP32[$pinlined >> 2] = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0 = HEAP32[$this + 32 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12StackSegment10slotsBeginEv($this) {
  return $this + 16 | 0;
}

function __ZNK2js8CallArgs3endEv($this_0_0_0_val, $this_0_1_val) {
  return $this_0_0_0_val + ($this_0_1_val << 3) | 0;
}

function __ZN2js12StackSegment8pushRegsERNS_9FrameRegsE($this, $regs) {
  var $1 = $this + 8 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$1 >> 2] = $regs;
  return $2;
}

function __ZN2js12StackSegment7popRegsEPNS_9FrameRegsE($this, $regs) {
  HEAP32[$this + 8 >> 2] = $regs;
  return;
}

function __ZN2js12StackSegment8pushCallERNS_12CallArgsListE($this, $callList) {
  var $1 = $this + 12 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$callList + 8 >> 2] = $2;
  HEAP32[$1 >> 2] = $callList;
  return;
}

function __ZN2js12StackSegment11pointAtCallERNS_12CallArgsListE($this, $callList) {
  HEAP32[$this + 12 >> 2] = $callList;
  return;
}

function __ZN2js12StackSegment7popCallEv($this) {
  var $1 = $this + 12 | 0;
  var $4 = HEAP32[HEAP32[$1 >> 2] + 8 >> 2];
  HEAP32[$1 >> 2] = $4;
  return;
}

function __ZN2js10StackSpaceC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  return;
}

function __ZNK2js10StackFrame5slotsEv($this) {
  return $this + 56 | 0;
}

function __ZN2js12ContextStack11threadResetEv($this) {
  var $5 = HEAP32[HEAP32[$this + 8 >> 2] + 52 >> 2] + 144284 | 0;
  HEAP32[$this + 4 >> 2] = $5;
  return;
}

function __ZN2js12ImplicitCastINS_8CallArgsENS_15InvokeArgsGuardEEERT_RT0_($u) {
  return $u | 0;
}

function __ZN2js15InvokeArgsGuard9setPushedERNS_12ContextStackE($this, $stack) {
  HEAP32[$this + 16 >> 2] = $stack;
  return;
}

function __ZN2js10FrameGuard9setPushedERNS_12ContextStackE($this, $stack) {
  HEAP32[$this >> 2] = $stack;
  return;
}

function __ZN2jsL7PodCopyIN2JS5ValueEEEvPT_PKS3_j($dst, $src, $nelem) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($nelem >>> 0 < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $src + ($nelem << 3) | 0;
    if (($nelem | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $src;
      var $_03 = $dst;
      __label__ = 3;
      break;
    }
   case 3:
    var $_03;
    var $_012;
    var $5 = $_012 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $_03 | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $8 = $_012 + 8 | 0;
    if (($8 | 0) == ($3 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $8;
      var $_03 = $_03 + 8 | 0;
      __label__ = 3;
      break;
    }
   case 4:
    var $12 = $dst;
    var $13 = $src;
    var $14 = $nelem << 3;
    _memcpy($12, $13, $14, 1);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame7callObjEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js10StackFrame10scopeChainEv($1);
    var $pobj_01_idx_val = HEAP32[$2 + 4 >> 2];
    var $4 = __ZNK8JSObject6isCallEv($pobj_01_idx_val);
    if ($4) {
      var $pobj_0_in_lcssa = $2;
      __label__ = 3;
      break;
    } else {
      var $pobj_0_in2 = $2;
      __label__ = 2;
      break;
    }
   case 2:
    var $pobj_0_in2;
    var $pobj_0_in2_idx_val = HEAP32[$pobj_0_in2 + 20 >> 2];
    var $5 = __ZNK8JSObject9getParentEv($pobj_0_in2_idx_val);
    var $pobj_0_idx_val = HEAP32[$5 + 4 >> 2];
    var $7 = __ZNK8JSObject6isCallEv($pobj_0_idx_val);
    if ($7) {
      var $pobj_0_in_lcssa = $5;
      __label__ = 3;
      break;
    } else {
      var $pobj_0_in2 = $5;
      __label__ = 2;
      break;
    }
   case 3:
    var $pobj_0_in_lcssa;
    var $8 = __ZN8JSObject6asCallEv($pobj_0_in_lcssa);
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15ArgumentsObject13setStackFrameEPNS_10StackFrameE($this, $frame) {
  var $1 = $frame;
  var $2 = $this;
  __ZN8JSObject10setPrivateEPv($2, $1);
  return;
}

function __ZN2js10StackFrame11pcQuadraticERKNS_12ContextStackEPS0_PPNS_13JSInlinedSiteE($this, $stack, $next) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx1_val = HEAP32[$stack + 4 >> 2];
    var $2 = __ZNK2js12ContextStack5spaceEv($_idx1_val);
    var $_idx2_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js10StackSpace17containingSegmentEPKNS_10StackFrameE($_idx2_val, $this);
    var $_idx3_val = HEAP32[$3 + 8 >> 2];
    var $5 = __ZNK2js12StackSegment4regsEv($_idx3_val);
    var $_idx_val = HEAP32[$5 + 12 >> 2];
    var $6 = __ZNK2js9FrameRegs2fpEv($_idx_val);
    if (($6 | 0) == ($this | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = HEAP32[$5 + 4 >> 2];
    __label__ = 6;
    break;
   case 3:
    if (($next | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_01 = $next;
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = __ZNK2js12StackSegment16computeNextFrameEPKNS_10StackFrameE($3, $this);
    var $_01 = $15;
    __label__ = 5;
    break;
   case 5:
    var $_01;
    var $17 = __ZN2js10StackFrame6prevpcEPPNS_13JSInlinedSiteE($_01, 0);
    var $_0 = $17;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackSpace17containingSegmentEPKNS_10StackFrameE($this_0_0_val, $target) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $s_0 = $this_0_0_val;
    __label__ = 2;
    break;
   case 2:
    var $s_0;
    if (($s_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $4 = __ZNK2js12StackSegment8containsEPKNS_10StackFrameE($s_0, $target);
    if ($4) {
      var $_0 = $s_0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $s_0_idx_val = HEAP32[$s_0 + 4 >> 2];
    var $6 = __ZNK2js12StackSegment12prevInMemoryEv($s_0_idx_val);
    var $s_0 = $6;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12StackSegment16computeNextFrameEPKNS_10StackFrameE($this, $f) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val_idx_val = HEAP32[HEAP32[$this + 8 >> 2] + 12 >> 2];
    var $3 = __ZNK2js12StackSegment2fpEv($_idx_val_idx_val);
    var $next_0 = $3;
    __label__ = 2;
    break;
   case 2:
    var $next_0;
    var $_idx1_val = HEAP32[$next_0 + 16 >> 2];
    var $7 = __ZNK2js10StackFrame4prevEv($_idx1_val);
    var $8 = $7;
    if (($8 | 0) == ($f | 0)) {
      __label__ = 3;
      break;
    } else {
      var $next_0 = $8;
      __label__ = 2;
      break;
    }
   case 3:
    return $next_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12StackSegment8containsEPKNS_10StackFrameE($this, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $fp;
    var $2 = __ZNK2js12StackSegment10slotsBeginEv($this);
    if ($1 >>> 0 < $2 >>> 0) {
      var $8 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 8 >> 2];
    var $5 = __ZNK2js12StackSegment7maybefpEv($this_idx_val);
    var $8 = $5 >>> 0 >= $fp >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12StackSegment7maybefpEv($this_0_2_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_2_val | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this_0_2_val + 12 >> 2];
    var $4 = __ZNK2js9FrameRegs2fpEv($_idx_val);
    var $7 = $4;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12StackSegment8containsEPKNS_12CallArgsListE($this, $call) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($call | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAPU32[$this + 12 >> 2];
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx1_val = HEAP32[$call >> 2];
    var $7 = __ZNK2js8CallArgs4argvEv($_idx1_val);
    var $8 = __ZNK2js12StackSegment10slotsBeginEv($this);
    if ($7 >>> 0 > $8 >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$4 >> 2];
    var $11 = __ZNK2js8CallArgs4argvEv($_idx_val);
    var $_0 = $7 >>> 0 <= $11 >>> 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12StackSegment3endEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 12 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $6 = ($5 | 0) != 0;
    if (($2 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = HEAP32[$5 >> 2];
    var $_idx2_val = HEAP32[$2 >> 2];
    var $_idx3_val = HEAP32[$2 + 4 >> 2];
    var $11 = __ZNK2js8CallArgs3endEv($_idx2_val, $_idx3_val);
    var $12 = __ZN2jsL3MaxIPN2JS5ValueEEET_S4_S4_($10, $11);
    var $22 = $12;
    __label__ = 8;
    break;
   case 4:
    var $_idx_val = HEAP32[$2 >> 2];
    var $_idx1_val = HEAP32[$2 + 4 >> 2];
    var $14 = __ZNK2js8CallArgs3endEv($_idx_val, $_idx1_val);
    var $22 = $14;
    __label__ = 8;
    break;
   case 5:
    if ($6) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = HEAP32[$5 >> 2];
    __label__ = 8;
    break;
   case 7:
    var $20 = __ZNK2js12StackSegment10slotsBeginEv($this);
    var $22 = $20;
    __label__ = 8;
    break;
   case 8:
    var $22;
    return $22;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackSpace4initEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _mmap(0, 4194304, 3, 4098, -1, 0);
    if (($1 | 0) == -1) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$this + 4 >> 2] = $1;
    HEAP32[$this + 16 >> 2] = $1 + 4194304 | 0;
    var $10 = $1 + 4063232 | 0;
    HEAP32[$this + 12 >> 2] = $10;
    HEAP32[$this + 8 >> 2] = $10;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackSpaceD2Ev($this_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_1_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $this_0_1_val;
    var $4 = _munmap($3, 4194304);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackSpace4markEP8JSTracer($this, $trc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    if (($2 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2js10StackSpace11firstUnusedEv($this);
    var $5 = $trc;
    var $seg_03 = $2;
    var $nextSegEnd_04 = $4;
    __label__ = 3;
    break;
   case 3:
    var $nextSegEnd_04;
    var $seg_03;
    var $seg_03_idx_val = HEAP32[$seg_03 + 8 >> 2];
    var $7 = __ZNK2js12StackSegment7maybefpEv($seg_03_idx_val);
    if ($7 >>> 0 > $seg_03 >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $slotsEnd_0_lcssa = $nextSegEnd_04;
      __label__ = 6;
      break;
    }
   case 4:
    var $10 = $seg_03;
    var $slotsEnd_01 = $nextSegEnd_04;
    var $fp_02 = $7;
    __label__ = 5;
    break;
   case 5:
    var $fp_02;
    var $slotsEnd_01;
    var $11 = $fp_02;
    var $12 = __ZNK2js10StackFrame5slotsEv($fp_02);
    __ZN2js28MarkStackRangeConservativelyEP8JSTracerPN2JS5ValueES4_($5, $12, $slotsEnd_01);
    __Z18js_TraceStackFrameP8JSTracerPN2js10StackFrameE($5, $fp_02);
    var $_idx_val = HEAP32[$fp_02 + 16 >> 2];
    var $15 = __ZNK2js10StackFrame4prevEv($_idx_val);
    if ($15 >>> 0 > $10 >>> 0) {
      var $slotsEnd_01 = $11;
      var $fp_02 = $15;
      __label__ = 5;
      break;
    } else {
      var $slotsEnd_0_lcssa = $11;
      __label__ = 6;
      break;
    }
   case 6:
    var $slotsEnd_0_lcssa;
    var $18 = $seg_03;
    var $19 = __ZNK2js12StackSegment10slotsBeginEv($seg_03);
    __ZN2js28MarkStackRangeConservativelyEP8JSTracerPN2JS5ValueES4_($5, $19, $slotsEnd_0_lcssa);
    var $seg_03_idx1_val = HEAP32[$seg_03 + 4 >> 2];
    var $20 = __ZNK2js12StackSegment12prevInMemoryEv($seg_03_idx1_val);
    if (($20 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $seg_03 = $20;
      var $nextSegEnd_04 = $18;
      __label__ = 3;
      break;
    }
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackSpace11firstUnusedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2js12StackSegment3endEv($2);
    var $10 = $5;
    __label__ = 4;
    break;
   case 3:
    var $10 = HEAP32[$this + 4 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackSpace15ensureSpaceSlowEP9JSContextNS_16MaybeReportErrorEPN2JS5ValueEiP13JSCompartment($this, $cx, $from, $nvals, $dest) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($dest | 0) == 12) {
      __label__ = 2;
      break;
    } else {
      var $_01 = $dest;
      __label__ = 3;
      break;
    }
   case 2:
    var $_01 = HEAP32[$cx + 56 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_01;
    if (($_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = HEAP32[$_01 + 4 >> 2];
    var $_idx_val = HEAP32[HEAP32[$cx + 52 >> 2] + 209940 >> 2];
    var $12 = __ZNK9JSRuntime17trustedPrincipalsEv($_idx_val);
    if (($9 | 0) == ($12 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $_in = $this + 16 | 0;
    __label__ = 7;
    break;
   case 6:
    var $_in = $this + 12 | 0;
    __label__ = 7;
    break;
   case 7:
    var $_in;
    if ((HEAP32[$_in >> 2] - $from >> 3 | 0) < ($nvals | 0)) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 8:
    var $25 = $cx;
    __Z21js_ReportOverRecursedP9JSContext($25);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackSpace11ensureSpaceEP9JSContextNS_16MaybeReportErrorEPN2JS5ValueEiP13JSCompartment($this, $cx, $from, $nvals, $dest) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] - $from >> 3 | 0) < ($nvals | 0)) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = __ZNK2js10StackSpace15ensureSpaceSlowEP9JSContextNS_16MaybeReportErrorEPN2JS5ValueEiP13JSCompartment($this, $cx, $from, $nvals, $dest);
    var $_0 = $9;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ContextStackC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = 0;
  var $5 = HEAP32[$cx + 52 >> 2] + 144284 | 0;
  HEAP32[$this + 4 >> 2] = $5;
  HEAP32[$this + 8 >> 2] = $cx;
  __ZN2js12ContextStack11threadResetEv($this);
  return;
}

function __ZNK2js12ContextStack5onTopEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    if (($2 | 0) == 0) {
      var $11 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this + 4 >> 2];
    var $6 = __ZNK2js12ContextStack5spaceEv($_idx_val);
    var $11 = ($2 | 0) == (HEAP32[$6 >> 2] | 0);
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ContextStack11ensureOnTopEP9JSContextNS_16MaybeReportErrorEjNS0_11MaybeExtendEPbP13JSCompartment($this, $cx, $nvars, $extend, $pushedSeg, $dest) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx4 = $this + 4 | 0;
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $2 = __ZNK2js12ContextStack5spaceEv($_idx4_val);
    var $3 = $2;
    var $4 = __ZNK2js10StackSpace11firstUnusedEv($3);
    var $5 = __ZNK2js12ContextStack5onTopEv($this);
    var $6 = ($extend | 0) == 0;
    if ($6 | $5 ^ 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK2js10StackSpace11ensureSpaceEP9JSContextNS_16MaybeReportErrorEPN2JS5ValueEiP13JSCompartment($3, $cx, $4, $nvars, $dest);
    var $_ = $8 ? $4 : 0;
    var $_0 = $_;
    __label__ = 9;
    break;
   case 3:
    var $10 = $nvars + 2 | 0;
    var $11 = __ZNK2js10StackSpace11ensureSpaceEP9JSContextNS_16MaybeReportErrorEPN2JS5ValueEiP13JSCompartment($3, $cx, $4, $10, $dest);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 4:
    var $13 = $this | 0;
    var $14 = HEAP32[$13 >> 2];
    if (($14 | 0) == 0 | $6) {
      var $calls_0 = 0;
      var $regs_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx1_val = HEAP32[$14 + 8 >> 2];
    var $18 = __ZNK2js12StackSegment9maybeRegsEv($_idx1_val);
    var $19 = $18;
    var $_idx_val = HEAP32[$14 + 12 >> 2];
    var $20 = __ZNK2js12StackSegment10maybeCallsEv($_idx_val);
    var $calls_0 = $20;
    var $regs_0 = $19;
    __label__ = 6;
    break;
   case 6:
    var $regs_0;
    var $calls_0;
    if (($4 | 0) == 0) {
      var $30 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = $4;
    var $_idx3_val = HEAP32[$_idx4 >> 2];
    var $26 = __ZNK2js12ContextStack5spaceEv($_idx3_val);
    var $28 = HEAP32[$26 >> 2];
    __ZN2js12StackSegmentC1EPS0_S1_PNS_9FrameRegsEPNS_12CallArgsListE($24, $14, $28, $regs_0, $calls_0);
    var $30 = $24;
    __label__ = 8;
    break;
   case 8:
    var $30;
    HEAP32[$13 >> 2] = $30;
    var $_idx2_val = HEAP32[$_idx4 >> 2];
    var $32 = __ZNK2js12ContextStack5spaceEv($_idx2_val);
    var $33 = $32 | 0;
    HEAP32[$33 >> 2] = $30;
    HEAP8[$pushedSeg] = 1;
    var $34 = HEAP32[$13 >> 2];
    var $35 = __ZNK2js12StackSegment10slotsBeginEv($34);
    var $_0 = $35;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js12ContextStack11ensureOnTopEP9JSContextNS_16MaybeReportErrorEjNS0_11MaybeExtendEPbP13JSCompartment["X"] = 1;

function __ZN2js12StackSegmentC1EPS0_S1_PNS_9FrameRegsEPNS_12CallArgsListE($this, $prevInContext, $prevInMemory, $regs, $calls) {
  __ZN2js12StackSegmentC2EPS0_S1_PNS_9FrameRegsEPNS_12CallArgsListE($this, $prevInContext, $prevInMemory, $regs, $calls);
  return;
}

function __ZN2js12ContextStack10popSegmentEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_idx2_val = HEAP32[HEAP32[$1 >> 2] + 4 >> 2];
    var $3 = __ZNK2js12StackSegment12prevInMemoryEv($_idx2_val);
    var $_idx1_val = HEAP32[$this + 4 >> 2];
    var $5 = __ZNK2js12ContextStack5spaceEv($_idx1_val);
    var $6 = $5 | 0;
    var $_c = $3;
    HEAP32[$6 >> 2] = $_c;
    var $_idx_val = HEAP32[HEAP32[$1 >> 2] >> 2];
    var $8 = __ZNK2js12StackSegment13prevInContextEv($_idx_val);
    HEAP32[$1 >> 2] = $8;
    if (($8 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $12 = HEAP32[$this + 8 >> 2];
    __ZN9JSContext27maybeMigrateVersionOverrideEv($12);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext27maybeMigrateVersionOverrideEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP8[$this + 16 | 0];
    var $1 = __ZNK9JSContext19isVersionOverriddenEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$this + 12 >> 2];
    HEAP32[$this + 8 >> 2] = $4;
    __ZN9JSContext20clearVersionOverrideEv($this);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($this, $cx, $argc, $iag) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $argc + 2 | 0;
    var $3 = $iag + 20 | 0;
    var $4 = __ZN2js12ContextStack11ensureOnTopEP9JSContextNS_16MaybeReportErrorEjNS0_11MaybeExtendEPbP13JSCompartment($this, $cx, $2, 1, $3, 12);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZN2js12ImplicitCastINS_8CallArgsENS_15InvokeArgsGuardEEERT_RT0_($iag);
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($1, $argc, $4);
    var $8 = $1;
    var $9 = $7;
    var $10$0 = HEAP32[$8 >> 2];
    var $10$1 = HEAP32[$8 + 4 >> 2];
    HEAP32[$9 >> 2] = $10$0;
    HEAP32[$9 + 4 >> 2] = $10$1;
    var $12 = HEAP32[$this >> 2];
    var $13 = $iag | 0;
    __ZN2js12StackSegment8pushCallERNS_12CallArgsListE($12, $13);
    __ZN2js15InvokeArgsGuard9setPushedERNS_12ContextStackE($iag, $this);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ContextStack13popInvokeArgsERKNS_15InvokeArgsGuardE($this, $iag) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    __ZN2js12StackSegment7popCallEv($2);
    if ((HEAP8[$iag + 20 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js12ContextStack10popSegmentEv($this);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ContextStack15pushInvokeFrameEP9JSContextRKNS_8CallArgsENS_17InitialFrameFlagsEPNS_16InvokeFrameGuardE($this, $cx, $args, $initial, $ifg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $flags = __stackBase__;
    var $_idx1_val = HEAP32[$args >> 2];
    var $1 = __ZNK2js12CallReceiver6calleeEv($_idx1_val);
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $2 = __ZNK8JSObject18getFunctionPrivateEv($_idx_val);
    var $3 = __ZNK10JSFunction6scriptEv($2);
    var $4 = $3;
    var $5 = __ZN2jsL12ToFrameFlagsENS_17InitialFrameFlagsE($initial);
    HEAP32[$flags >> 2] = $5;
    var $_idx2_val = HEAP16[$2 + 56 >> 1];
    var $_idx3_val = HEAP16[$3 + 44 >> 1];
    var $8 = __ZNK2js12ContextStack12getCallFrameEP9JSContextNS_16MaybeReportErrorERKNS_8CallArgsEP10JSFunctionP8JSScriptPNS_10StackFrame5FlagsE($this, $cx, $args, $_idx2_val, $_idx3_val, $flags);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = $2;
    var $12 = $1;
    var $args_idx_val = HEAP32[$args + 4 >> 2];
    var $13 = __ZNK2js8CallArgs4argcEv($args_idx_val);
    var $14 = HEAP32[$flags >> 2];
    __ZN2js10StackFrame13initCallFrameEP9JSContextR8JSObjectP10JSFunctionP8JSScriptjNS0_5FlagsE($8, $cx, $12, $11, $4, $13, $14);
    var $15 = $ifg | 0;
    var $16 = $ifg + 8 | 0;
    __ZN2js9FrameRegs12prepareToRunERNS_10StackFrameEP8JSScript($16, $8, $4);
    var $18 = HEAP32[$this >> 2];
    var $19 = __ZN2js12StackSegment8pushRegsERNS_9FrameRegsE($18, $16);
    HEAP32[$ifg + 24 >> 2] = $19;
    __ZN2js10FrameGuard9setPushedERNS_12ContextStackE($15, $this);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12ContextStack12getCallFrameEP9JSContextNS_16MaybeReportErrorERKNS_8CallArgsEP10JSFunctionP8JSScriptPNS_10StackFrame5FlagsE($this, $cx, $args, $fun_0_1_val, $script_0_19_val, $flags) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $fun_0_1_val & 65535;
    var $args_idx = $args | 0;
    var $args_idx_val = HEAP32[$args_idx >> 2];
    var $args_idx4 = $args + 4 | 0;
    var $args_idx4_val = HEAPU32[$args_idx4 >> 2];
    var $2 = __ZNK2js8CallArgs3endEv($args_idx_val, $args_idx4_val);
    var $4 = ($script_0_19_val & 65535) + 257 | 0;
    var $5 = __ZNK2js8CallArgs4argcEv($args_idx4_val);
    if (($5 | 0) == ($1 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $_idx3_val = HEAP32[$this + 4 >> 2];
    var $9 = __ZNK2js12ContextStack5spaceEv($_idx3_val);
    var $10 = $9;
    var $11 = __ZNK2js10StackSpace11ensureSpaceEP9JSContextNS_16MaybeReportErrorEPN2JS5ValueEiP13JSCompartment($10, $cx, $2, $4, 12);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 3:
    var $_0 = $2;
    __label__ = 9;
    break;
   case 4:
    var $16 = HEAPU32[$flags >> 2];
    if ($5 >>> 0 < $1 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    HEAP32[$flags >> 2] = $16 | 4096;
    var $args_idx5_val = HEAP32[$args_idx4 >> 2];
    var $19 = __ZNK2js8CallArgs4argcEv($args_idx5_val);
    var $20 = $1 - $19 | 0;
    var $_idx2_val = HEAP32[$this + 4 >> 2];
    var $22 = __ZNK2js12ContextStack5spaceEv($_idx2_val);
    var $23 = $22;
    var $24 = $20 + $4 | 0;
    var $25 = __ZNK2js10StackSpace11ensureSpaceEP9JSContextNS_16MaybeReportErrorEPN2JS5ValueEiP13JSCompartment($23, $cx, $2, $24, 12);
    if ($25) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueEj($2, $20);
    var $_0 = $2 + ($20 << 3) | 0;
    __label__ = 9;
    break;
   case 7:
    HEAP32[$flags >> 2] = $16 | 2048;
    var $31 = $1 + 2 | 0;
    var $_idx1_val = HEAP32[$this + 4 >> 2];
    var $33 = __ZNK2js12ContextStack5spaceEv($_idx1_val);
    var $34 = $33;
    var $35 = $4 + $31 | 0;
    var $36 = __ZNK2js10StackSpace11ensureSpaceEP9JSContextNS_16MaybeReportErrorEPN2JS5ValueEiP13JSCompartment($34, $cx, $2, $35, 12);
    if ($36) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $_idx_val = HEAP32[$args_idx >> 2];
    var $38 = __ZNK2js12CallReceiver4baseEv($_idx_val);
    __ZN2jsL7PodCopyIN2JS5ValueEEEvPT_PKS3_j($2, $38, $31);
    var $_0 = $2 + ($31 << 3) | 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js12ContextStack12getCallFrameEP9JSContextNS_16MaybeReportErrorERKNS_8CallArgsEP10JSFunctionP8JSScriptPNS_10StackFrame5FlagsE["X"] = 1;

function __ZN2js10StackFrame13initCallFrameEP9JSContextR8JSObjectP10JSFunctionP8JSScriptjNS0_5FlagsE($this, $cx, $callee, $fun, $script, $nactual, $flagsArg) {
  HEAP32[$this >> 2] = $flagsArg | 1572866;
  HEAP32[$this + 4 >> 2] = $fun;
  HEAP32[$this + 8 >> 2] = $nactual;
  var $_idx_val = HEAP32[$callee + 20 >> 2];
  var $6 = __ZNK8JSObject9getParentEv($_idx_val);
  var $7 = $6;
  HEAP32[$this + 12 >> 2] = $7;
  HEAP32[$this + 20 >> 2] = 0;
  __ZN2js10StackFrame8initPrevEP9JSContext($this, $cx);
  var $10 = __ZNK2js10StackFrame5slotsEv($this);
  var $13 = HEAPU16[$script + 14 >> 1] & 65535;
  __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueEj($10, $13);
  return;
}

function __ZN2js9FrameRegs12prepareToRunERNS_10StackFrameEP8JSScript($this, $fp, $script) {
  var $2 = HEAP32[$script >> 2];
  HEAP32[$this + 4 >> 2] = $2;
  var $4 = __ZNK2js10StackFrame5slotsEv($fp);
  HEAP32[$this >> 2] = $4 + ((HEAPU16[$script + 14 >> 1] & 65535) << 3) | 0;
  HEAP32[$this + 12 >> 2] = $fp;
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZNK2js9StackIter2fpEv($this_0_3_val) {
  return $this_0_3_val;
}

function __ZN11JSGenerator13floatingFrameEv($this_0_4_val) {
  return $this_0_4_val;
}

function __ZNK2js12CallArgsList4prevEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js9StackIter8isScriptEv($this_0_2_val) {
  return ($this_0_2_val | 0) == 1;
}

function __ZNK2js10StackFrame22isFramePushedByExecuteEv($this_0_0_val) {
  return ($this_0_0_val & 9 | 0) != 0;
}

function __ZNK2js12CallArgsList6activeEv($this_0_2_val) {
  return ($this_0_2_val & 1) << 24 >> 24 != 0;
}

function __ZNK2js9StackIter4doneEv($this_0_2_val) {
  return ($this_0_2_val | 0) == 0;
}

function __ZN9JSContext14setCompartmentEP13JSCompartment($this, $compartment) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this + 56 >> 2] = $compartment;
    if (($compartment | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP8[$compartment + 376 | 0] & 1;
    __label__ = 3;
    break;
   case 3:
    var $7;
    HEAP8[$this + 232 | 0] = $7;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame22unsetFloatingGeneratorEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -65;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js10StackFrame20setFloatingGeneratorEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 64;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js9StackIter10poisonRegsEv($this) {
  HEAP32[$this + 24 >> 2] = 2989;
  HEAP32[$this + 28 >> 2] = 2989;
  return;
}

function __ZNK2js12CallReceiver4baseEv($this_0_0_val) {
  return $this_0_0_val - 16 | 0;
}

function __ZNK2js12CallReceiver7calleevEv($this_0_0_val) {
  return $this_0_0_val - 16 | 0;
}

function __ZN2js12ContextStack16pushExecuteFrameEP9JSContextP8JSScriptRKN2JS5ValueER8JSObjectNS_11ExecuteTypeEPNS_10StackFrameEPNS_17ExecuteFrameGuardE($this, $cx, $script, $thisv, $scopeChain, $type, $evalInFrame, $efg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $iter = __stackBase__;
    var $1 = ($evalInFrame | 0) != 0;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    __ZN2js9StackIterC2EP9JSContextNS0_11SavedOptionE($iter, $cx, 1);
    var $iter_idx1 = $iter + 12 | 0;
    var $iter_idx = $iter + 8 | 0;
    __label__ = 3;
    break;
   case 3:
    var $iter_idx_val = HEAP32[$iter_idx >> 2];
    var $4 = __ZNK2js9StackIter8isScriptEv($iter_idx_val);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $iter_idx1_val = HEAP32[$iter_idx1 >> 2];
    var $6 = __ZNK2js9StackIter2fpEv($iter_idx1_val);
    if (($6 | 0) == ($evalInFrame | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js9StackIterppEv($iter);
    __label__ = 3;
    break;
   case 6:
    var $extend_0 = 0;
    var $prev_0 = $evalInFrame;
    var $evalInFrameCalls_0 = HEAP32[$iter + 16 >> 2];
    __label__ = 8;
    break;
   case 7:
    var $this_idx_val = HEAP32[$this >> 2];
    var $12 = __ZNK2js12ContextStack7maybefpEv($this_idx_val);
    var $extend_0 = 1;
    var $prev_0 = $12;
    var $evalInFrameCalls_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $evalInFrameCalls_0;
    var $prev_0;
    var $extend_0;
    var $17 = (HEAPU16[$script + 44 >> 1] & 65535) + 9 | 0;
    var $18 = $efg | 0;
    var $19 = $efg + 4 | 0;
    var $20 = __ZN2js12ContextStack11ensureOnTopEP9JSContextNS_16MaybeReportErrorEjNS0_11MaybeExtendEPbP13JSCompartment($this, $cx, $17, $extend_0, $19, 12);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $24 = $20 + 16 | 0;
    var $25 = $this | 0;
    var $_idx_val = HEAP32[HEAP32[$25 >> 2] + 8 >> 2];
    var $28 = __ZNK2js12StackSegment9maybeRegsEv($_idx_val);
    var $29 = $28;
    __ZN2js10StackFrame16initExecuteFrameEP8JSScriptPS0_PNS_9FrameRegsERKN2JS5ValueER8JSObjectNS_11ExecuteTypeE($24, $script, $prev_0, $29, $thisv, $scopeChain, $type);
    var $30 = __ZNK2js10StackFrame5slotsEv($24);
    var $33 = HEAPU16[$script + 14 >> 1] & 65535;
    __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueEj($30, $33);
    var $34 = $efg + 8 | 0;
    __ZN2js9FrameRegs12prepareToRunERNS_10StackFrameEP8JSScript($34, $24, $script);
    if (($evalInFrameCalls_0 | 0) == 0 | $1 ^ 1) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $37 = HEAP32[$25 >> 2];
    __ZN2js12StackSegment11pointAtCallERNS_12CallArgsListE($37, $evalInFrameCalls_0);
    __label__ = 11;
    break;
   case 11:
    var $39 = HEAP32[$25 >> 2];
    var $40 = __ZN2js12StackSegment8pushRegsERNS_9FrameRegsE($39, $34);
    HEAP32[$efg + 24 >> 2] = $40;
    __ZN2js10FrameGuard9setPushedERNS_12ContextStackE($18, $this);
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js12ContextStack16pushExecuteFrameEP9JSContextP8JSScriptRKN2JS5ValueER8JSObjectNS_11ExecuteTypeEPNS_10StackFrameEPNS_17ExecuteFrameGuardE["X"] = 1;

function __ZN2js9StackIterppEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0 || ($2 | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 2) {
      __label__ = 3;
      break;
    } else if (($2 | 0) == 3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    __ZN2js9StackIter8popFrameEv($this);
    __ZN2js9StackIter16settleOnNewStateEv($this);
    __label__ = 5;
    break;
   case 3:
    __ZN2js9StackIter7popCallEv($this);
    __ZN2js9StackIter16settleOnNewStateEv($this);
    __label__ = 5;
    break;
   case 4:
    HEAP32[$1 >> 2] = 1;
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12ContextStack7maybefpEv($this_0_0_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_0_val | 0) == 0) {
      var $5 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this_0_0_val + 8 >> 2];
    var $3 = __ZNK2js12StackSegment7maybefpEv($_idx_val);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueEj($vec, $len) {
  var $1 = $vec + ($len << 3) | 0;
  __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueES2_($vec, $1);
  return;
}

function __ZN2js12ContextStack14pushDummyFrameEP9JSContextP13JSCompartmentR8JSObjectPNS_15DummyFrameGuardE($this, $cx, $dest, $scopeChain, $dfg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $dfg + 4 | 0;
    var $2 = __ZN2js12ContextStack11ensureOnTopEP9JSContextNS_16MaybeReportErrorEjNS0_11MaybeExtendEPbP13JSCompartment($this, $cx, 7, 1, $1, $dest);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $dfg | 0;
    var $6 = $2;
    __ZN2js10StackFrame14initDummyFrameEP9JSContextR8JSObject($6, $cx, $scopeChain);
    var $7 = $dfg + 8 | 0;
    __ZN2js9FrameRegs14initDummyFrameERNS_10StackFrameE($7, $6);
    __ZN9JSContext14setCompartmentEP13JSCompartment($cx, $dest);
    var $9 = HEAP32[$this >> 2];
    var $10 = __ZN2js12StackSegment8pushRegsERNS_9FrameRegsE($9, $7);
    HEAP32[$dfg + 24 >> 2] = $10;
    __ZN2js10FrameGuard9setPushedERNS_12ContextStackE($5, $this);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9FrameRegs14initDummyFrameERNS_10StackFrameE($this, $fp) {
  HEAP32[$this + 4 >> 2] = 0;
  var $2 = __ZNK2js10StackFrame5slotsEv($fp);
  HEAP32[$this >> 2] = $2;
  HEAP32[$this + 12 >> 2] = $fp;
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN2js12ContextStack8popFrameERKNS_10FrameGuardE($this, $fg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$fg + 20 >> 2];
    var $2 = __ZNK2js9FrameRegs2fpEv($_idx_val);
    var $_idx1_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($_idx1_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN2js10StackFrame16functionEpilogueEv($5);
    __label__ = 3;
    break;
   case 3:
    var $8 = HEAP32[$this >> 2];
    var $10 = HEAP32[$fg + 24 >> 2];
    __ZN2js12StackSegment7popRegsEPNS_9FrameRegsE($8, $10);
    if ((HEAP8[$fg + 4 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js12ContextStack10popSegmentEv($this);
    __label__ = 5;
    break;
   case 5:
    var $_idx2_val = HEAP32[$this >> 2];
    var $17 = __ZNK2js12ContextStack5hasfpEv($_idx2_val);
    if ($17) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = HEAP32[$this + 8 >> 2];
    __ZN9JSContext16resetCompartmentEv($21);
    __label__ = 7;
    break;
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame16functionEpilogueEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    if (($2 & 49152 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $this;
    var $7 = __ZNK2js10StackFrame10hasCallObjEv($2);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __Z16js_PutCallObjectPN2js10StackFrameE($6);
    __label__ = 6;
    break;
   case 4:
    var $10 = __ZNK2js10StackFrame10hasArgsObjEv($2);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __Z16js_PutArgsObjectPN2js10StackFrameE($6);
    __label__ = 6;
    break;
   case 6:
    var $13 = __ZNK2js10StackFrame20maintainNestingStateEv($this);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $15 = $this;
    __ZN2js5types15NestingEpilogueEPNS_10StackFrameE($15);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ContextStack18pushGeneratorFrameEP9JSContextP11JSGeneratorPNS_19GeneratorFrameGuardE($this, $cx, $gen, $gfg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $gen_idx_val = HEAP32[$gen + 28 >> 2];
    var $1 = __ZN11JSGenerator13floatingFrameEv($gen_idx_val);
    var $2 = $gen + 32 | 0;
    var $6 = $1 - $2 >> 3;
    var $7 = __ZNK2js10StackFrame8numSlotsEv($1);
    var $9 = $6 + ($7 + 7) | 0;
    var $10 = $gfg + 4 | 0;
    var $11 = __ZN2js12ContextStack11ensureOnTopEP9JSContextNS_16MaybeReportErrorEjNS0_11MaybeExtendEPbP13JSCompartment($this, $cx, $9, 1, $10, 12);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = $gfg | 0;
    var $16 = $11 + ($6 << 3) | 0;
    HEAP32[$gfg + 28 >> 2] = $gen;
    HEAP32[$gfg + 32 >> 2] = $11;
    var $19 = $gen + 8 | 0;
    var $21 = HEAP32[$19 >> 2];
    __ZN2js10StackFrame18stealFrameAndSlotsEPN2JS5ValueEPS0_S3_S3_($16, $11, $1, $2, $21);
    __ZN2js10StackFrame18resetGeneratorPrevEP9JSContext($16, $cx);
    __ZN2js10StackFrame22unsetFloatingGeneratorEv($16);
    var $22 = $gfg + 8 | 0;
    __ZN2js9FrameRegs12rebaseFromToERKS0_RNS_10StackFrameE($22, $19, $16);
    var $24 = HEAP32[$this >> 2];
    var $25 = __ZN2js12StackSegment8pushRegsERNS_9FrameRegsE($24, $22);
    HEAP32[$gfg + 24 >> 2] = $25;
    __ZN2js10FrameGuard9setPushedERNS_12ContextStackE($14, $this);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame8numSlotsEv($this) {
  var $1 = $this;
  var $2 = __ZNK2js10StackFrame6scriptEv($1);
  return HEAPU16[$2 + 44 >> 1] & 65535;
}

function __ZN2js10StackFrame18resetGeneratorPrevEP9JSContext($this, $cx) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1048576;
  HEAP32[$1 >> 2] = $3;
  __ZN2js10StackFrame8initPrevEP9JSContext($this, $cx);
  return;
}

function __ZN2js9FrameRegs12rebaseFromToERKS0_RNS_10StackFrameE($this, $from, $to) {
  HEAP32[$this + 12 >> 2] = $to;
  var $2 = __ZNK2js10StackFrame5slotsEv($to);
  var $4 = HEAP32[$from >> 2];
  var $6 = HEAP32[$from + 12 >> 2];
  var $7 = __ZNK2js10StackFrame5slotsEv($6);
  var $12 = $2 + ($4 - $7 >> 3 << 3) | 0;
  HEAP32[$this >> 2] = $12;
  var $15 = HEAP32[$from + 4 >> 2];
  HEAP32[$this + 4 >> 2] = $15;
  var $18 = HEAP32[$from + 8 >> 2];
  HEAP32[$this + 8 >> 2] = $18;
  return;
}

function __ZN2js12ContextStack17popGeneratorFrameERKNS_19GeneratorFrameGuardE($gfg) {
  var $2 = HEAP32[$gfg + 28 >> 2];
  var $_idx1_val = HEAP32[$2 + 28 >> 2];
  var $3 = __ZN11JSGenerator13floatingFrameEv($_idx1_val);
  var $4 = $2 + 32 | 0;
  var $5 = $gfg + 8 | 0;
  var $_idx_val = HEAP32[$gfg + 20 >> 2];
  var $7 = __ZNK2js9FrameRegs2fpEv($_idx_val);
  var $8 = $7;
  var $10 = HEAP32[$gfg + 32 >> 2];
  var $11 = $2 + 8 | 0;
  __ZN2js9FrameRegs12rebaseFromToERKS0_RNS_10StackFrameE($11, $5, $3);
  var $13 = HEAP32[$5 >> 2];
  __ZN2js10StackFrame18stealFrameAndSlotsEPN2JS5ValueEPS0_S3_S3_($3, $4, $8, $10, $13);
  __ZN2js10StackFrame20setFloatingGeneratorEv($3);
  return;
}

function __ZN2js12ContextStack14saveFrameChainEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pushedSeg = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js12ContextStack11ensureOnTopEP9JSContextNS_16MaybeReportErrorEjNS0_11MaybeExtendEPbP13JSCompartment($this, $2, 0, 0, $pushedSeg, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$1 >> 2];
    __ZN9JSContext16resetCompartmentEv($7);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ContextStack17restoreFrameChainEv($this) {
  __ZN2js12ContextStack10popSegmentEv($this);
  var $3 = HEAP32[$this + 8 >> 2];
  __ZN9JSContext16resetCompartmentEv($3);
  return;
}

function __ZN2js9StackIter8popFrameEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $inline_ = __stackBase__;
    var $1 = $this + 12 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $2;
    var $_idx_val = HEAP32[$2 + 16 >> 2];
    var $5 = __ZNK2js10StackFrame4prevEv($_idx_val);
    var $6 = $5;
    HEAP32[$1 >> 2] = $6;
    var $8 = HEAP32[$this + 20 >> 2];
    var $9 = __ZNK2js12StackSegment8containsEPKNS_10StackFrameE($8, $6);
    if ($9) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    var $11 = __ZN2js10StackFrame6prevpcEPPNS_13JSInlinedSiteE($2, $inline_);
    HEAP32[$this + 28 >> 2] = $11;
    var $_idx1_val = HEAP32[$2 >> 2];
    var $13 = __ZNK2js10StackFrame16isGeneratorFrameEv($_idx1_val);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $15 = __ZNK2js10StackFrame10actualArgsEv($3);
    var $16 = $15 - 16 | 0;
    HEAP32[$this + 24 >> 2] = $16;
    __label__ = 10;
    break;
   case 4:
    var $19 = __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($_idx1_val);
    if ($19) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $21 = __ZNK2js10StackFrame13actualArgsEndEv($2);
    HEAP32[$this + 24 >> 2] = $21;
    __label__ = 10;
    break;
   case 6:
    var $24 = __ZNK2js10StackFrame22isFramePushedByExecuteEv($_idx1_val);
    if ($24) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $27 = $2 - 56 + 40 | 0;
    HEAP32[$this + 24 >> 2] = $27;
    __label__ = 10;
    break;
   case 8:
    var $30 = $2;
    HEAP32[$this + 24 >> 2] = $30;
    __label__ = 10;
    break;
   case 9:
    __ZN2js9StackIter10poisonRegsEv($this);
    __label__ = 10;
    break;
   case 10:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame13actualArgsEndEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = (HEAP32[$this >> 2] & 2048 | 0) == 0;
    var $5 = $this;
    var $6 = __ZNK2js10StackFrame10formalArgsEv($5);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = $6 - 16 | 0;
    __label__ = 4;
    break;
   case 3:
    var $10 = __ZNK2js10StackFrame13numActualArgsEv($5);
    var $_0 = $6 + ($10 << 3) | 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9StackIter7popCallEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 16 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $_idx_val = HEAP32[$2 + 8 >> 2];
    var $3 = __ZNK2js12CallArgsList4prevEv($_idx_val);
    HEAP32[$1 >> 2] = $3;
    var $5 = HEAP32[$this + 20 >> 2];
    var $7 = HEAP32[$this + 12 >> 2];
    var $8 = __ZNK2js12StackSegment8containsEPKNS_10StackFrameE($5, $7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$2 >> 2];
    var $10 = __ZNK2js12CallReceiver4baseEv($_idx1_val);
    HEAP32[$this + 24 >> 2] = $10;
    __label__ = 4;
    break;
   case 3:
    __ZN2js9StackIter10poisonRegsEv($this);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9StackIter18settleOnNewSegmentEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[HEAP32[$this + 20 >> 2] + 8 >> 2];
    var $4 = __ZNK2js12StackSegment9maybeRegsEv($_idx_val);
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$4 >> 2];
    HEAP32[$this + 24 >> 2] = $8;
    var $11 = HEAP32[$4 + 4 >> 2];
    HEAP32[$this + 28 >> 2] = $11;
    __label__ = 4;
    break;
   case 3:
    __ZN2js9StackIter10poisonRegsEv($this);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9StackIter14startOnSegmentEPNS_12StackSegmentE($this, $seg) {
  HEAP32[$this + 20 >> 2] = $seg;
  var $seg_idx_val = HEAP32[$seg + 8 >> 2];
  var $2 = __ZNK2js12StackSegment7maybefpEv($seg_idx_val);
  HEAP32[$this + 12 >> 2] = $2;
  var $_idx_val = HEAP32[$seg + 12 >> 2];
  var $4 = __ZNK2js12StackSegment10maybeCallsEv($_idx_val);
  HEAP32[$this + 16 >> 2] = $4;
  __ZN2js9StackIter18settleOnNewSegmentEv($this);
  return;
}

function __ZN2js9StackIter16settleOnNewStateEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $1 = __stackBase__ + 40;
    var $2 = __stackBase__ + 48;
    var $3 = $this + 12 | 0;
    var $4 = $this + 16 | 0;
    var $5 = $this + 4 | 0;
    var $6 = $this + 20 | 0;
    __label__ = 2;
    break;
   case 2:
    var $7 = HEAP32[$3 >> 2];
    var $9 = HEAPU32[$4 >> 2];
    if (($7 | 0) == 0 & ($9 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    if ((HEAP32[$5 >> 2] | 0) == 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $_idx1_val = HEAP32[HEAP32[$6 >> 2] >> 2];
    var $16 = __ZNK2js12StackSegment13prevInContextEv($_idx1_val);
    if (($16 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js9StackIter14startOnSegmentEPNS_12StackSegmentE($this, $16);
    __label__ = 2;
    break;
   case 6:
    HEAP32[$this + 8 >> 2] = 0;
    __label__ = 35;
    break;
   case 7:
    var $21 = HEAPU32[$6 >> 2];
    var $22 = __ZNK2js12StackSegment8containsEPKNS_10StackFrameE($21, $7);
    var $23 = $22 & 1;
    var $24 = __ZNK2js12StackSegment8containsEPKNS_12CallArgsListE($21, $9);
    var $containsFrame_0 = $23;
    var $containsCall_0 = $24 & 1;
    __label__ = 8;
    break;
   case 8:
    var $containsCall_0;
    var $containsFrame_0;
    var $27 = $containsFrame_0 << 24 >> 24 != 0;
    var $28 = $containsCall_0 << 24 >> 24 == 0;
    if ($28 & ($27 ^ 1)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 9:
    var $_idx_val = HEAP32[HEAP32[$6 >> 2] >> 2];
    var $31 = __ZNK2js12StackSegment13prevInContextEv($_idx_val);
    HEAP32[$6 >> 2] = $31;
    var $32 = HEAPU32[$3 >> 2];
    var $33 = __ZNK2js12StackSegment8containsEPKNS_10StackFrameE($31, $32);
    var $34 = $33 & 1;
    var $35 = HEAP32[$4 >> 2];
    var $36 = __ZNK2js12StackSegment8containsEPKNS_12CallArgsListE($31, $35);
    var $37 = $36 & 1;
    if ($33) {
      __label__ = 10;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 10:
    var $_idx3_val_idx_val = HEAP32[HEAP32[$31 + 8 >> 2] + 12 >> 2];
    var $41 = __ZNK2js12StackSegment2fpEv($_idx3_val_idx_val);
    if (($41 | 0) == ($32 | 0)) {
      __label__ = 16;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $45 = $tmp;
    var $46 = $this;
    for (var $$src = $46 >> 2, $$dest = $45 >> 2, $$stop = $$src + 10; $$src < $$stop; $$src++, $$dest++) {
      HEAP32[$$dest] = HEAP32[$$src];
    }
    __ZN2js9StackIter14startOnSegmentEPNS_12StackSegmentE($tmp, $31);
    var $tmp_idx4 = $tmp + 12 | 0;
    var $tmp_idx = $tmp + 8 | 0;
    __label__ = 12;
    break;
   case 12:
    var $tmp_idx_val = HEAP32[$tmp_idx >> 2];
    var $48 = __ZNK2js9StackIter8isScriptEv($tmp_idx_val);
    if ($48) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $tmp_idx4_val = HEAP32[$tmp_idx4 >> 2];
    var $50 = __ZNK2js9StackIter2fpEv($tmp_idx4_val);
    if (($50 | 0) == (HEAP32[$3 >> 2] | 0)) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZN2js9StackIterppEv($tmp);
    __label__ = 12;
    break;
   case 15:
    for (var $$src = $45 >> 2, $$dest = $46 >> 2, $$stop = $$src + 10; $$src < $$stop; $$src++, $$dest++) {
      HEAP32[$$dest] = HEAP32[$$src];
    }
    __label__ = 35;
    break;
   case 16:
    __ZN2js9StackIter18settleOnNewSegmentEv($this);
    var $containsFrame_0 = $34;
    var $containsCall_0 = $37;
    __label__ = 8;
    break;
   case 17:
    if ($27) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $134 = HEAP32[$4 >> 2];
    __label__ = 31;
    break;
   case 19:
    var $_pre11 = HEAPU32[$3 >> 2];
    if ($28) {
      var $61 = $_pre11;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $57 = $_pre11;
    var $58 = HEAPU32[$4 >> 2];
    var $_idx2_val = HEAP32[$58 >> 2];
    var $59 = __ZNK2js8CallArgs4argvEv($_idx2_val);
    if ($57 >>> 0 < $59 >>> 0) {
      var $134 = $58;
      __label__ = 31;
      break;
    } else {
      var $61 = $_pre11;
      __label__ = 21;
      break;
    }
   case 21:
    var $61;
    var $_idx5_val = HEAP32[$61 >> 2];
    var $62 = __ZNK2js10StackFrame12isDummyFrameEv($_idx5_val);
    if ($62) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    __ZN2js9StackIter8popFrameEv($this);
    __label__ = 2;
    break;
   case 23:
    var $66 = __ZNK2js10StackFrame6scriptEv($61);
    var $67 = $66;
    var $68 = $this + 28 | 0;
    var $69 = HEAP32[$68 >> 2];
    var $70 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh161($67, $69);
    if (($70 | 0) == 108 || ($70 | 0) == 58) {
      __label__ = 24;
      break;
    } else if (($70 | 0) == 79) {
      __label__ = 26;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 24:
    var $72 = HEAPU32[$68 >> 2];
    var $80 = (HEAPU8[$72 + 1 | 0] & 255) << 8 | HEAPU8[$72 + 2 | 0] & 255;
    var $84 = HEAP32[$this + 24 >> 2] + (-2 - $80 << 3) | 0;
    var $85 = HEAP32[$3 >> 2];
    __ZL18CrashIfInvalidSlotPN2js10StackFrameEPN2JS5ValueE($85, $84);
    var $_idx8 = $84 | 0;
    var $_idx8_val$0 = HEAP32[$_idx8 >> 2];
    var $_idx8_val$1 = HEAP32[$_idx8 + 4 >> 2];
    var $86 = __ZN2jsL16IsNativeFunctionERKN2JS5ValueE($_idx8_val$0, $_idx8_val$1);
    if ($86) {
      __label__ = 25;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 25:
    HEAP32[$this + 8 >> 2] = 3;
    var $88 = $this + 32 | 0;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($1, $80, $84);
    var $89 = $1;
    var $90 = $88;
    var $st$6$0 = $89 | 0;
    var $91$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $89 + 4 | 0;
    var $91$1 = HEAP32[$st$6$1 >> 2];
    var $st$10$0 = $90 | 0;
    HEAP32[$st$10$0 >> 2] = $91$0;
    var $st$10$1 = $90 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $91$1;
    __label__ = 35;
    break;
   case 26:
    var $94 = HEAPU32[$68 >> 2];
    var $102 = (HEAPU8[$94 + 1 | 0] & 255) << 8 | HEAPU8[$94 + 2 | 0] & 255;
    var $103 = HEAP32[$this >> 2];
    var $105 = HEAP32[$3 >> 2];
    var $106 = __ZNK2js10StackFrame6scriptEv($105);
    var $107 = $103;
    var $108 = _js_ReconstructStackDepth($107, $106, $94);
    var $109 = HEAP32[$3 >> 2];
    var $110 = __ZNK2js10StackFrame4baseEv($109);
    var $_sum = $108 + (-2 - $102) | 0;
    var $112 = $110 + ($_sum << 3) | 0;
    __ZL18CrashIfInvalidSlotPN2js10StackFrameEPN2JS5ValueE($109, $112);
    var $_idx7 = $112 | 0;
    var $_idx7_val$0 = HEAP32[$_idx7 >> 2];
    var $_idx7_val$1 = HEAP32[$_idx7 + 4 >> 2];
    var $113 = __ZN2jsL16IsNativeFunctionERKN2JS5ValueE($_idx7_val$0, $_idx7_val$1);
    if ($113) {
      __label__ = 27;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 27:
    var $117 = HEAP32[$this + 24 >> 2];
    if (($117 | 0) == ($110 + ($108 << 3) | 0)) {
      var $argc1_0 = $102;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $argc1_0 = $117 - ($110 + ($_sum + 2 << 3)) >> 3;
    __label__ = 29;
    break;
   case 29:
    var $argc1_0;
    HEAP32[$this + 8 >> 2] = 3;
    var $127 = $this + 32 | 0;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($2, $argc1_0, $112);
    var $128 = $2;
    var $129 = $127;
    var $130$0 = HEAP32[$128 >> 2];
    var $130$1 = HEAP32[$128 + 4 >> 2];
    HEAP32[$129 >> 2] = $130$0;
    HEAP32[$129 + 4 >> 2] = $130$1;
    __label__ = 35;
    break;
   case 30:
    HEAP32[$this + 8 >> 2] = 1;
    __label__ = 35;
    break;
   case 31:
    var $134;
    var $_idx9_val = HEAP8[$134 + 12 | 0];
    var $135 = __ZNK2js12CallArgsList6activeEv($_idx9_val);
    if ($135) {
      __label__ = 32;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 32:
    var $_idx10_val = HEAP32[$134 >> 2];
    var $137 = __ZNK2js12CallReceiver7calleevEv($_idx10_val);
    var $_idx6 = $137 | 0;
    var $_idx6_val$0 = HEAP32[$_idx6 >> 2];
    var $_idx6_val$1 = HEAP32[$_idx6 + 4 >> 2];
    var $138 = __ZN2jsL16IsNativeFunctionERKN2JS5ValueE($_idx6_val$0, $_idx6_val$1);
    if ($138) {
      __label__ = 33;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 33:
    HEAP32[$this + 8 >> 2] = 2;
    var $143 = HEAP32[$4 >> 2];
    var $144 = $this + 32 | 0;
    var $st$6$0 = $143 | 0;
    var $145$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $143 + 4 | 0;
    var $145$1 = HEAP32[$st$6$1 >> 2];
    var $st$10$0 = $144 | 0;
    HEAP32[$st$10$0 >> 2] = $145$0;
    var $st$10$1 = $144 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $145$1;
    __label__ = 35;
    break;
   case 34:
    __ZN2js9StackIter7popCallEv($this);
    __label__ = 2;
    break;
   case 35:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js9StackIter16settleOnNewStateEv["X"] = 1;

function __ZL12js_GetOpcodeP9JSContextP8JSScriptPh161($script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU8[$pc];
    var $2 = $1 & 255;
    if ($1 << 24 >> 24 == 83) {
      __label__ = 2;
      break;
    } else {
      var $op_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $script;
    var $6 = _JS_GetTrapOpcode($5, $pc);
    var $op_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $op_0;
    return $op_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame4baseEv($this) {
  var $1 = __ZNK2js10StackFrame5slotsEv($this);
  var $2 = $this;
  var $3 = __ZNK2js10StackFrame6scriptEv($2);
  return $1 + ((HEAPU16[$3 + 14 >> 1] & 65535) << 3) | 0;
}

function __ZL18CrashIfInvalidSlotPN2js10StackFrameEPN2JS5ValueE($fp, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame5slotsEv($fp);
    if ($1 >>> 0 > $vp >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $fp;
    var $5 = __ZNK2js10StackFrame6scriptEv($4);
    if (($1 + ((HEAPU16[$5 + 44 >> 1] & 65535) << 3) | 0) >>> 0 > $vp >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[2989 >> 2] = 0;
    _JS_Assert(STRING_TABLE.__str156 | 0, STRING_TABLE.__str1157 | 0, 967);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16IsNativeFunctionERKN2JS5ValueE($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fun = __stackBase__;
    var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP10JSFunction($v_0_0_0_val$0, $v_0_0_0_val$1, $fun);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$fun >> 2];
    var $4 = __ZNK10JSFunction8isNativeEv($3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    STACKTOP = __stackBase__;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9StackIterC2EP9JSContextNS0_11SavedOptionE($this, $cx, $savedOption) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this >> 2] = $cx;
    HEAP32[$this + 4 >> 2] = $savedOption;
    var $4 = HEAP32[$cx + 60 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js9StackIter14startOnSegmentEPNS_12StackSegmentE($this, $4);
    __ZN2js9StackIter16settleOnNewStateEv($this);
    __label__ = 4;
    break;
   case 3:
    HEAP32[$this + 8 >> 2] = 0;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSScript7nestingEv($this_0_32_val_0_3_val) {
  return $this_0_32_val_0_3_val;
}

function __ZNK17JSDependentString4baseEv($this_0_0_0_0_2_0_0_0_val) {
  return $this_0_0_0_0_2_0_0_0_val;
}

function __ZNK7mozilla9RangedPtrIKtEdeEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK9JSContext19isVersionOverriddenEv($this_0_3_val) {
  return ($this_0_3_val & 1) << 24 >> 24 != 0;
}

function __ZNK8JSObject6isCallEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js9CallClassE | 0);
}

function __ZNK8JSString12isExtensibleEv($this_0_0_0_val) {
  return ($this_0_0_0_val & 15 | 0) == 12;
}

function __ZNK8JSString6isRopeEv($this_0_0_0_val) {
  return ($this_0_0_0_val & 1 | 0) != 0;
}

function __ZN8JSString19buildLengthAndFlagsEjj($length, $flags) {
  return $length << 4 | $flags;
}

function __ZN13JSShortString10lengthFitsEj($length) {
  return $length >>> 0 < 12;
}

function __ZNK7mozilla9RangedPtrIKtEeqIS1_EEbRKNS0_IT_EE($this_0_0_val, $other_0_0_val) {
  return ($this_0_0_val | 0) == ($other_0_0_val | 0);
}

function __ZNK8JSString12asExtensibleEv($this) {
  return $this;
}

function __ZN8JSString7asFixedEv($this) {
  return $this;
}

function __ZNK8JSString6asAtomEv($this) {
  return $this;
}

function __ZNK2js9StackIter10nativeArgsEv($agg_result, $this) {
  var $2 = $this + 32 | 0;
  var $3 = $agg_result;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  return;
}

function __ZN9JSContext20clearVersionOverrideEv($this) {
  HEAP8[$this + 16 | 0] = 0;
  return;
}

function __ZN2js12StackSegmentC2EPS0_S1_PNS_9FrameRegsEPNS_12CallArgsListE($this, $prevInContext, $prevInMemory, $regs, $calls) {
  HEAP32[$this >> 2] = $prevInContext;
  HEAP32[$this + 4 >> 2] = $prevInMemory;
  HEAP32[$this + 8 >> 2] = $regs;
  HEAP32[$this + 12 >> 2] = $calls;
  return;
}

function __ZNK18JSExtensibleString8capacityEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZNK6JSRope9leftChildEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js13StaticStrings15fitsInSmallCharEt($c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($c & 65535) < 128) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = STRING_TABLE.__ZN2js13StaticStrings11toSmallCharE + ($c & 65535) | 0;
    var $8 = HEAP8[$4] << 24 >> 24 != -1;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla9RangedPtrIKtEaSIS1_EERS2_RKNS0_IT_EE($this, $p_0_0_val) {
  HEAP32[$this >> 2] = $p_0_0_val;
  return;
}

function __ZN7mozilla9RangedPtrIKtEC2EPS1_S3_j($this, $p) {
  HEAP32[$this >> 2] = $p;
  return;
}

function __ZN7mozilla9RangedPtrIKtEC2EPS1_j($this, $p) {
  HEAP32[$this >> 2] = $p;
  return;
}

function __ZN2js19PreserveCompartmentD2Ev($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this | 0;
  var $5 = HEAP32[$3 >> 2] + 56 | 0;
  HEAP32[$5 >> 2] = $2;
  var $8 = HEAP8[$this + 8 | 0] & 1;
  HEAP8[HEAP32[$3 >> 2] + 232 | 0] = $8;
  return;
}

function __ZN2js13AllFramesIterC2ERNS_10StackSpaceE($this, $space_0_0_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this >> 2] = $space_0_0_val;
    var $2 = $this + 4 | 0;
    if (($space_0_0_val | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$space_0_0_val + 8 >> 2];
    var $5 = __ZNK2js12StackSegment7maybefpEv($_idx_val);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    HEAP32[$2 >> 2] = $7;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13AllFramesIterppEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $_idx_val = HEAP32[HEAP32[$1 >> 2] + 16 >> 2];
    var $4 = __ZNK2js10StackFrame4prevEv($_idx_val);
    var $5 = $4;
    HEAP32[$1 >> 2] = $5;
    var $6 = $this | 0;
    var $7 = HEAP32[$6 >> 2];
    var $8 = __ZNK2js12StackSegment8containsEPKNS_10StackFrameE($7, $5);
    if ($8) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx2_val = HEAP32[$7 + 4 >> 2];
    var $10 = __ZNK2js12StackSegment12prevInMemoryEv($_idx2_val);
    var $12 = $10;
    __label__ = 3;
    break;
   case 3:
    var $12;
    HEAP32[$6 >> 2] = $12;
    if (($12 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $storemerge_idx_val = HEAP32[$12 + 8 >> 2];
    var $15 = __ZNK2js12StackSegment7maybefpEv($storemerge_idx_val);
    HEAP32[$1 >> 2] = $15;
    if (($15 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $_idx1_val = HEAP32[$12 + 4 >> 2];
    var $18 = __ZNK2js12StackSegment12prevInMemoryEv($_idx1_val);
    var $12 = $18;
    __label__ = 3;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP10JSFunction($v_0_0_0_val$0, $v_0_0_0_val$1, $fun) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $funobj = __stackBase__;
  var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction($v_0_0_0_val$0, $v_0_0_0_val$1, $funobj, $fun);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZNK10JSFunction8isNativeEv($this) {
  var $_idx_val = HEAP16[$this + 58 >> 1];
  var $2 = __ZNK10JSFunction13isInterpretedEv($_idx_val);
  return $2 ^ 1;
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction($v_0_0_0_val$0, $v_0_0_0_val$1, $funobj, $fun) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject($v_0_0_0_val$0, $v_0_0_0_val$1, $funobj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[HEAP32[$funobj >> 2] + 24 >> 2];
    var $5 = __ZNK8JSObject18getFunctionPrivateEv($_idx_val);
    var $6 = $5;
    HEAP32[$fun >> 2] = $6;
    __label__ = 3;
    break;
   case 3:
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject($v_0_0_0_val$0, $v_0_0_0_val$1, $funobj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    HEAP32[$funobj >> 2] = $3;
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $5 = __ZNK8JSObject10isFunctionEv($_idx_val);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame20maintainNestingStateEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $_idx1_val = HEAP32[$this >> 2];
    var $2 = __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($_idx1_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $12 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZNK2js10StackFrame16isGeneratorFrameEv($_idx1_val);
    if ($4) {
      var $12 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZNK2js10StackFrame6scriptEv($1);
    var $_idx2_val_idx_val = HEAP32[HEAP32[$6 + 100 >> 2] + 12 >> 2];
    var $9 = __ZNK8JSScript7nestingEv($_idx2_val_idx_val);
    var $12 = ($9 | 0) != 0;
    __label__ = 4;
    break;
   case 4:
    var $12;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueES2_($beg, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($beg | 0) == ($end | 0)) {
      __label__ = 3;
      break;
    } else {
      var $v_01 = $beg;
      __label__ = 2;
      break;
    }
   case 2:
    var $v_01;
    __ZN2JS5Value12setUndefinedEv($v_01);
    var $2 = $v_01 + 8 | 0;
    if (($2 | 0) == ($end | 0)) {
      __label__ = 3;
      break;
    } else {
      var $v_01 = $2;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK9JSContext9maybeRegsEv($this) {
  var $_idx_val = HEAP32[$this + 60 >> 2];
  var $1 = __ZNK2js12ContextStack9maybeRegsEv($_idx_val);
  return $1;
}

function __ZNK2js12ContextStack9maybeRegsEv($this_0_0_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_0_val | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this_0_0_val + 8 >> 2];
    var $4 = __ZNK2js12StackSegment9maybeRegsEv($_idx_val);
    var $7 = $4;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js2gc4Cell12getAllocKindEv($this) {
  var $1 = __ZNK2js2gc4Cell11arenaHeaderEv($this);
  var $2 = __ZNK2js2gc11ArenaHeader12getAllocKindEv($1);
  return $2;
}

function __ZN14JSLinearString4markEP8JSTracer($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str_0 = $this;
    __label__ = 2;
    break;
   case 2:
    var $str_0;
    var $3 = __ZNK2js2gc4Cell14markIfUnmarkedEj($str_0, 0);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$str_0 >> 2];
    var $5 = __ZNK8JSString11isDependentEv($_idx_val);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZN8JSString11asDependentEv($str_0 | 0);
    var $_idx1_val = HEAP32[$8 + 8 >> 2];
    var $9 = __ZNK17JSDependentString4baseEv($_idx1_val);
    var $str_0 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js2gc4Cell14markIfUnmarkedEj($this, $color) {
  var $1 = __ZNK2js2gc4Cell5chunkEv($this);
  var $2 = $1 + 1032192 | 0;
  var $3 = __ZN2js2gc11ChunkBitmap14markIfUnmarkedEPKNS0_4CellEj($2, $this, $color);
  return $3;
}

function __ZN6JSRope7flattenEP9JSContext($this, $maybecx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $wholeCapacity = __stackBase__;
    var $wholeChars = __stackBase__ + 4;
    var $1 = $this | 0;
    var $_idx1_val = HEAP32[$this >> 2];
    var $2 = __ZNK8JSString6lengthEv($_idx1_val);
    var $3 = __ZNK6JSRope9leftChildEv($this);
    var $_idx6_val = HEAP32[$3 >> 2];
    var $4 = __ZNK8JSString12isExtensibleEv($_idx6_val);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = __ZNK8JSString12asExtensibleEv($3);
    var $7 = __ZNK18JSExtensibleString8capacityEv($6);
    if ($7 >>> 0 < $2 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$wholeCapacity >> 2] = $7;
    var $_idx2_val = HEAP32[$6 + 4 >> 2];
    var $10 = __ZNK14JSLinearString5charsEv($_idx2_val);
    HEAP32[$wholeChars >> 2] = $10;
    var $11 = $6 | 0;
    var $12 = HEAPU32[$11 >> 2];
    var $14 = $10 + ($12 >>> 4 << 1) | 0;
    HEAP32[$11 >> 2] = $12 ^ 14;
    var $16 = $this;
    HEAP32[$6 + 8 >> 2] = $16;
    var $pos_1_ph = $14;
    var $str_1_ph = $1;
    var $_pre_phi = $16;
    __label__ = 9;
    break;
   case 4:
    var $19 = __ZL10AllocCharsP9JSContextjPPtPj($maybecx, $2, $wholeChars, $wholeCapacity);
    if ($19) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 5:
    var $pos_0_ph = HEAP32[$wholeChars >> 2];
    var $str_0_ph = $1;
    __label__ = 6;
    break;
   case 6:
    var $str_0_ph;
    var $pos_0_ph;
    var $22 = $str_0_ph + 4 | 0;
    var $24 = HEAPU32[$22 >> 2];
    HEAP32[$22 >> 2] = $pos_0_ph;
    var $_idx5_val = HEAP32[$24 >> 2];
    var $26 = __ZNK8JSString6isRopeEv($_idx5_val);
    if ($26) {
      var $str_09 = $str_0_ph;
      var $27 = $24;
      __label__ = 7;
      break;
    } else {
      var $str_0_lcssa = $str_0_ph;
      var $_lcssa8 = $24;
      var $_lcssa8_idx_val = $_idx5_val;
      __label__ = 8;
      break;
    }
   case 7:
    var $27;
    var $str_09;
    HEAP32[$27 + 12 >> 2] = $str_09;
    HEAP32[$27 >> 2] = 512;
    var $30 = $27 + 4 | 0;
    var $32 = HEAP32[$30 >> 2];
    HEAP32[$30 >> 2] = $pos_0_ph;
    var $_idx4_val = HEAP32[$32 >> 2];
    var $34 = __ZNK8JSString6isRopeEv($_idx4_val);
    if ($34) {
      var $str_09 = $27;
      var $27 = $32;
      __label__ = 7;
      break;
    } else {
      var $str_0_lcssa = $27;
      var $_lcssa8 = $32;
      var $_lcssa8_idx_val = $_idx4_val;
      __label__ = 8;
      break;
    }
   case 8:
    var $_lcssa8_idx_val;
    var $_lcssa8;
    var $str_0_lcssa;
    var $35 = __ZNK8JSString6lengthEv($_lcssa8_idx_val);
    var $37 = HEAP32[$_lcssa8 + 4 >> 2];
    __ZN2jsL7PodCopyItEEvPT_PKS1_j($pos_0_ph, $37, $35);
    var $pos_1_ph = $pos_0_ph + ($35 << 1) | 0;
    var $str_1_ph = $str_0_lcssa;
    var $_pre_phi = $this;
    __label__ = 9;
    break;
   case 9:
    var $_pre_phi;
    var $str_1_ph;
    var $pos_1_ph;
    var $pos_1 = $pos_1_ph;
    var $str_1 = $str_1_ph;
    __label__ = 10;
    break;
   case 10:
    var $str_1;
    var $pos_1;
    var $41 = HEAP32[$str_1 + 8 >> 2];
    var $_idx3 = $41 | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $42 = __ZNK8JSString6isRopeEv($_idx3_val);
    if ($42) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $44 = $41 + 12 | 0;
    HEAP32[$44 >> 2] = $str_1;
    HEAP32[$_idx3 >> 2] = 768;
    var $pos_0_ph = $pos_1;
    var $str_0_ph = $41;
    __label__ = 6;
    break;
   case 12:
    var $46 = __ZNK8JSString6lengthEv($_idx3_val);
    var $48 = HEAP32[$41 + 4 >> 2];
    __ZN2jsL7PodCopyItEEvPT_PKS1_j($pos_1, $48, $46);
    var $49 = $pos_1 + ($46 << 1) | 0;
    var $50 = $49;
    var $str_2 = $str_1;
    __label__ = 13;
    break;
   case 13:
    var $str_2;
    if (($str_2 | 0) == ($1 | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    HEAP16[$49 >> 1] = 0;
    var $54 = __ZN8JSString19buildLengthAndFlagsEjj($2, 12);
    HEAP32[$str_2 >> 2] = $54;
    var $56 = HEAP32[$wholeChars >> 2];
    HEAP32[$str_2 + 4 >> 2] = $56;
    var $_c = HEAP32[$wholeCapacity >> 2];
    HEAP32[$str_2 + 8 >> 2] = $_c;
    var $60 = __ZN8JSString6asFlatEv($1);
    var $_0 = $60;
    __label__ = 16;
    break;
   case 15:
    var $62 = $str_2 | 0;
    var $63 = HEAP32[$62 >> 2];
    var $68 = $50 - HEAP32[$str_2 + 4 >> 2] >> 1;
    var $69 = __ZN8JSString19buildLengthAndFlagsEjj($68, 2);
    HEAP32[$62 >> 2] = $69;
    HEAP32[$str_2 + 8 >> 2] = $_pre_phi;
    var $72 = HEAP32[$str_2 + 12 >> 2];
    if (($63 | 0) == 512) {
      var $pos_1 = $49;
      var $str_1 = $72;
      __label__ = 10;
      break;
    } else {
      var $str_2 = $72;
      __label__ = 13;
      break;
    }
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN6JSRope7flattenEP9JSContext["X"] = 1;

function __ZL10AllocCharsP9JSContextjPPtPj($maybecx, $length, $chars, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $length + 1 | 0;
    if ($1 >>> 0 > 1048576) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = ($1 >>> 3) + $1 | 0;
    __label__ = 4;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    var $9 = $7;
    __label__ = 4;
    break;
   case 4:
    var $9;
    HEAP32[$capacity >> 2] = $9 - 1 | 0;
    var $11 = $9 << 1;
    if (($maybecx | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = __ZN9JSContext7malloc_Ej($maybecx, $11);
    var $18 = $14;
    __label__ = 7;
    break;
   case 6:
    var $16 = __ZN2js11OffTheBooks7malloc_Ej($11);
    var $18 = $16;
    __label__ = 7;
    break;
   case 7:
    var $18;
    HEAP32[$chars >> 2] = $18;
    return ($18 | 0) != 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodCopyItEEvPT_PKS1_j($dst, $src, $nelem) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($nelem >>> 0 < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $src + ($nelem << 1) | 0;
    if (($nelem | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $src;
      var $_03 = $dst;
      __label__ = 3;
      break;
    }
   case 3:
    var $_03;
    var $_012;
    var $5 = HEAP16[$_012 >> 1];
    HEAP16[$_03 >> 1] = $5;
    var $6 = $_012 + 2 | 0;
    if (($6 | 0) == ($3 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $6;
      var $_03 = $_03 + 2 | 0;
      __label__ = 3;
      break;
    }
   case 4:
    var $10 = $dst;
    var $11 = $src;
    var $12 = $nelem << 1;
    _memcpy($10, $11, $12, 1);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_ConcatStringsP9JSContextP8JSStringS2_($cx, $left, $right) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $left_idx_val = HEAP32[$left >> 2];
    var $1 = __ZNK8JSString6lengthEv($left_idx_val);
    if (($1 | 0) == 0) {
      var $_0 = $right;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $right_idx_val = HEAP32[$right >> 2];
    var $4 = __ZNK8JSString6lengthEv($right_idx_val);
    if (($4 | 0) == 0) {
      var $_0 = $left;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $4 + $1 | 0;
    var $8 = __ZN13JSShortString10lengthFitsEj($7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $10 = __Z19js_NewGCShortStringP9JSContext($cx);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = __ZN8JSString8getCharsEP9JSContext($left, $cx);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = __ZN8JSString8getCharsEP9JSContext($right, $cx);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = $10 | 0;
    var $20 = __ZN14JSInlineString4initEj($19, $7);
    __ZN2jsL7PodCopyItEEvPT_PKS1_j($20, $13, $1);
    var $21 = $20 + ($1 << 1) | 0;
    __ZN2jsL7PodCopyItEEvPT_PKS1_j($21, $16, $4);
    HEAP16[$20 + ($7 << 1) >> 1] = 0;
    var $_0 = $10 | 0;
    __label__ = 11;
    break;
   case 8:
    if ($7 >>> 0 > 268435455) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    __Z27js_ReportAllocationOverflowP9JSContext($cx);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 10:
    var $28 = __ZN6JSRope4new_EP9JSContextP8JSStringS3_j($cx, $left, $right, $7);
    var $_0 = $28 | 0;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19js_NewGCShortStringP9JSContext($cx) {
  var $1 = __Z10NewGCThingI13JSShortStringEPT_P9JSContextN2js2gc9AllocKindEj($cx);
  return $1;
}

function __ZN8JSString8getCharsEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSString12ensureLinearEP9JSContext($this, $cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$1 + 4 >> 2];
    var $4 = __ZNK14JSLinearString5charsEv($_idx_val);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN14JSInlineString4initEj($this, $length) {
  var $1 = __ZN8JSString19buildLengthAndFlagsEjj($length, 4);
  HEAP32[$this >> 2] = $1;
  var $4 = $this + 8 | 0;
  HEAP32[$this + 4 >> 2] = $4;
  return $4;
}

function __ZN6JSRope4new_EP9JSContextP8JSStringS3_j($cx, $left, $right, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z14js_NewGCStringP9JSContext($cx);
    var $2 = $1;
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN6JSRope4initEP8JSStringS1_j($2, $left, $right, $length);
    var $_0 = $2;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN17JSDependentString8undependEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx = $this | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $1 = __ZNK8JSString6lengthEv($_idx_val);
    var $3 = ($1 << 1) + 2 | 0;
    var $4 = __ZN9JSContext7malloc_Ej($cx, $3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $this | 0;
    var $_idx1 = $this + 4 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $9 = __ZNK14JSLinearString5charsEv($_idx1_val);
    __ZN2jsL7PodCopyItEEvPT_PKS1_j($5, $9, $1);
    HEAP16[$5 + ($1 << 1) >> 1] = 0;
    var $11 = __ZN8JSString19buildLengthAndFlagsEjj($1, 4);
    HEAP32[$_idx >> 2] = $11;
    HEAP32[$_idx1 >> 2] = $5;
    var $12 = __ZN8JSString7asFixedEv($8);
    var $_0 = $12;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK12JSFlatString6charsZEv($this) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $1 = __ZNK14JSLinearString5charsEv($_idx_val);
  return $1;
}

function __ZN7mozilla9RangedPtrIKtEC1EPS1_j($this, $p) {
  __ZN7mozilla9RangedPtrIKtEC2EPS1_j($this, $p);
  return;
}

function __ZN7mozilla9RangedPtrIKtEC1EPS1_S3_j($this, $p) {
  __ZN7mozilla9RangedPtrIKtEC2EPS1_S3_j($this, $p);
  return;
}

function __ZN7mozilla9RangedPtrIKtEppEi($agg_result, $this) {
  var $2 = HEAP32[$this >> 2];
  HEAP32[$agg_result >> 2] = $2;
  var $4 = __ZN7mozilla9RangedPtrIKtEppEv($this);
  return;
}

function __ZN2js13StaticStrings4initEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sc = __stackBase__;
    var $buffer = __stackBase__ + 12;
    var $buffer2 = __stackBase__ + 16;
    var $buffer5 = __stackBase__ + 24;
    var $4 = HEAP32[HEAP32[$cx + 52 >> 2] >> 2];
    __ZN2js19SwitchToCompartmentC1EP9JSContextP13JSCompartment($sc, $cx, $4);
    var $5 = $buffer | 0;
    var $6 = $buffer + 2 | 0;
    var $7 = $cx;
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if ($i_0 >>> 0 < 256) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $buffer2 | 0;
    var $11 = $buffer2 + 2 | 0;
    var $12 = $buffer2 + 4 | 0;
    var $i1_0 = 0;
    __label__ = 6;
    break;
   case 4:
    HEAP16[$5 >> 1] = $i_0 & 65535;
    HEAP16[$6 >> 1] = 0;
    var $15 = __Z17js_NewStringCopyNP9JSContextPKtj($7, $5, 1);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = __ZN13JSFixedString27morphAtomizedStringIntoAtomEv($15);
    HEAP32[$this + 17412 + ($i_0 << 2) >> 2] = $18;
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 6:
    var $i1_0;
    if ($i1_0 >>> 0 < 4096) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = $buffer5 | 0;
    var $24 = $buffer5 + 2 | 0;
    var $25 = $buffer5 + 4 | 0;
    var $26 = $buffer5 + 6 | 0;
    var $i4_0 = 0;
    __label__ = 14;
    break;
   case 8:
    var $28 = $i1_0 >>> 6;
    if ($i1_0 >>> 0 < 640) {
      var $34 = 48;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = $i1_0 >>> 0 < 2304 ? 87 : 29;
    var $34 = $32;
    __label__ = 10;
    break;
   case 10:
    var $34;
    HEAP16[$10 >> 1] = $34 + $28 & 65535;
    var $37 = $i1_0 & 63;
    if ($37 >>> 0 < 10) {
      var $43 = 48;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $41 = $37 >>> 0 < 36 ? 87 : 29;
    var $43 = $41;
    __label__ = 12;
    break;
   case 12:
    var $43;
    HEAP16[$11 >> 1] = $43 + $37 & 65535;
    HEAP16[$12 >> 1] = 0;
    var $46 = __Z17js_NewStringCopyNP9JSContextPKtj($7, $10, 2);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $49 = __ZN13JSFixedString27morphAtomizedStringIntoAtomEv($46);
    HEAP32[$this + 4 + ($i1_0 << 2) >> 2] = $49;
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 6;
    break;
   case 14:
    var $i4_0;
    if ($i4_0 >>> 0 < 256) {
      __label__ = 15;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    if ($i4_0 >>> 0 < 10) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $59 = HEAP32[$this + 17412 + ($i4_0 + 48 << 2) >> 2];
    HEAP32[$this + 16388 + ($i4_0 << 2) >> 2] = $59;
    __label__ = 26;
    break;
   case 17:
    if ($i4_0 >>> 0 < 100) {
      __label__ = 18;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 18:
    var $64 = Math.floor(($i4_0 >>> 0) / 10);
    var $65 = $64 + 48 | 0;
    if ($65 >>> 0 < 58) {
      var $77 = $64;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    if (($64 - 49 | 0) >>> 0 < 26) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $77 = $64 - 39 | 0;
    __label__ = 23;
    break;
   case 21:
    if ($65 >>> 0 > 64) {
      __label__ = 22;
      break;
    } else {
      var $77 = 255;
      __label__ = 23;
      break;
    }
   case 22:
    var $_ = $65 >>> 0 < 91 ? $64 + 19 | 0 : 255;
    var $77 = $_;
    __label__ = 23;
    break;
   case 23:
    var $77;
    var $79 = ($i4_0 >>> 0) % 10;
    var $82 = ($79 | 48) >>> 0 < 58 ? $79 : 255;
    var $85 = HEAP32[$this + 4 + ($82 + ($77 << 6) << 2) >> 2];
    HEAP32[$this + 16388 + ($i4_0 << 2) >> 2] = $85;
    __label__ = 26;
    break;
   case 24:
    var $88 = Math.floor(($i4_0 >>> 0) / 100);
    HEAP16[$23 >> 1] = $88 + 48 & 65535;
    var $91 = Math.floor(($i4_0 >>> 0) / 10);
    HEAP16[$24 >> 1] = (($91 >>> 0) % 10 | 48) & 65535;
    HEAP16[$25 >> 1] = (($i4_0 >>> 0) % 10 | 48) & 65535;
    HEAP16[$26 >> 1] = 0;
    var $98 = __Z17js_NewStringCopyNP9JSContextPKtj($7, $23, 3);
    if (($98 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $101 = __ZN13JSFixedString27morphAtomizedStringIntoAtomEv($98);
    HEAP32[$this + 16388 + ($i4_0 << 2) >> 2] = $101;
    __label__ = 26;
    break;
   case 26:
    var $i4_0 = $i4_0 + 1 | 0;
    __label__ = 14;
    break;
   case 27:
    HEAP8[$this | 0] = 1;
    var $_0 = 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    __ZN2js19SwitchToCompartmentD1Ev($sc);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13StaticStrings4initEP9JSContext["X"] = 1;

function __ZN2js19SwitchToCompartmentC1EP9JSContextP13JSCompartment($this, $cx, $newCompartment) {
  __ZN2js19SwitchToCompartmentC2EP9JSContextP13JSCompartment($this, $cx, $newCompartment);
  return;
}

function __ZN13JSFixedString27morphAtomizedStringIntoAtomEv($this) {
  var $1 = $this | 0;
  var $2 = $this | 0;
  var $4 = HEAP32[$2 >> 2] ^ 12;
  HEAP32[$2 >> 2] = $4;
  var $5 = __ZNK8JSString6asAtomEv($1);
  return $5;
}

function __ZN2js19SwitchToCompartmentD1Ev($this) {
  __ZN2js19SwitchToCompartmentD2Ev($this);
  return;
}

function __ZN2js13StaticStrings5traceEP8JSTracer($this, $trc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      var $i_05 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $i_05;
    var $7 = HEAP32[$this + 17412 + ($i_05 << 2) >> 2] | 0;
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($trc, $7);
    var $8 = $i_05 + 1 | 0;
    if (($8 | 0) == 256) {
      var $i1_03 = 0;
      __label__ = 3;
      break;
    } else {
      var $i_05 = $8;
      __label__ = 2;
      break;
    }
   case 3:
    var $i1_03;
    var $11 = HEAP32[$this + 4 + ($i1_03 << 2) >> 2] | 0;
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($trc, $11);
    var $12 = $i1_03 + 1 | 0;
    if (($12 | 0) == 4096) {
      var $i2_01 = 0;
      __label__ = 4;
      break;
    } else {
      var $i1_03 = $12;
      __label__ = 3;
      break;
    }
   case 4:
    var $i2_01;
    var $15 = HEAP32[$this + 16388 + ($i2_01 << 2) >> 2] | 0;
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($trc, $15);
    var $16 = $i2_01 + 1 | 0;
    if (($16 | 0) == 256) {
      __label__ = 5;
      break;
    } else {
      var $i2_01 = $16;
      __label__ = 4;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla9RangedPtrIKtEppEv($this) {
  var $1 = __ZN7mozilla9RangedPtrIKtEpLEj($this, 1);
  return $1;
}

function __ZN7mozilla9RangedPtrIKtEpLEj($this, $inc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $this_idx_val = HEAP32[$this >> 2];
  __ZN7mozilla9RangedPtrIKtEplEj($1, $this_idx_val, $inc);
  var $_idx_val = HEAP32[$1 >> 2];
  __ZN7mozilla9RangedPtrIKtEaSIS1_EERS2_RKNS0_IT_EE($this, $_idx_val);
  STACKTOP = __stackBase__;
  return $this;
}

function __ZN7mozilla9RangedPtrIKtEplEj($agg_result, $this_0_0_val, $inc) {
  var $1 = $this_0_0_val + ($inc << 1) | 0;
  __ZNK7mozilla9RangedPtrIKtE6createEPS1_($agg_result, $1);
  return;
}

function __ZNK7mozilla9RangedPtrIKtE6createEPS1_($agg_result, $ptr) {
  __ZN7mozilla9RangedPtrIKtEC1EPS1_S3_j($agg_result, $ptr);
  return;
}

function __ZN2js19SwitchToCompartmentD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js19PreserveCompartmentD2Ev($1);
  return;
}

function __ZNK2v88internal5DiyFp1fEv($this_0_0_val$0, $this_0_0_val$1) {
  return [ $this_0_0_val$0, $this_0_0_val$1 ];
}

function __ZNK2v88internal5DiyFp1eEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js2gc4Cell5chunkEv($this) {
  return $this & -1048576;
}

function __ZNK2v88internal13StringBuilder12is_finalizedEv($this_0_1_val) {
  return ($this_0_1_val | 0) < 0;
}

function __ZN2v88internalL15BiggestPowerTenEjiPjPi($number, $number_bits, $power, $exponent) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($number_bits | 0) == 32 || ($number_bits | 0) == 31 || ($number_bits | 0) == 30) {
      __label__ = 2;
      break;
    } else if (($number_bits | 0) == 29 || ($number_bits | 0) == 28 || ($number_bits | 0) == 27) {
      __label__ = 4;
      break;
    } else if (($number_bits | 0) == 26 || ($number_bits | 0) == 25 || ($number_bits | 0) == 24) {
      __label__ = 6;
      break;
    } else if (($number_bits | 0) == 23 || ($number_bits | 0) == 22 || ($number_bits | 0) == 21 || ($number_bits | 0) == 20) {
      __label__ = 8;
      break;
    } else if (($number_bits | 0) == 19 || ($number_bits | 0) == 18 || ($number_bits | 0) == 17) {
      __label__ = 10;
      break;
    } else if (($number_bits | 0) == 16 || ($number_bits | 0) == 15 || ($number_bits | 0) == 14) {
      __label__ = 12;
      break;
    } else if (($number_bits | 0) == 13 || ($number_bits | 0) == 12 || ($number_bits | 0) == 11 || ($number_bits | 0) == 10) {
      __label__ = 14;
      break;
    } else if (($number_bits | 0) == 9 || ($number_bits | 0) == 8 || ($number_bits | 0) == 7) {
      __label__ = 16;
      break;
    } else if (($number_bits | 0) == 6 || ($number_bits | 0) == 5 || ($number_bits | 0) == 4) {
      __label__ = 18;
      break;
    } else if (($number_bits | 0) == 3 || ($number_bits | 0) == 2 || ($number_bits | 0) == 1) {
      __label__ = 20;
      break;
    } else if (($number_bits | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 2:
    if ($number >>> 0 > 999999999) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[$power >> 2] = 1e9;
    HEAP32[$exponent >> 2] = 9;
    __label__ = 24;
    break;
   case 4:
    if ($number >>> 0 > 99999999) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    HEAP32[$power >> 2] = 1e8;
    HEAP32[$exponent >> 2] = 8;
    __label__ = 24;
    break;
   case 6:
    if ($number >>> 0 > 9999999) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    HEAP32[$power >> 2] = 1e7;
    HEAP32[$exponent >> 2] = 7;
    __label__ = 24;
    break;
   case 8:
    if ($number >>> 0 > 999999) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    HEAP32[$power >> 2] = 1e6;
    HEAP32[$exponent >> 2] = 6;
    __label__ = 24;
    break;
   case 10:
    if ($number >>> 0 > 99999) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$power >> 2] = 1e5;
    HEAP32[$exponent >> 2] = 5;
    __label__ = 24;
    break;
   case 12:
    if ($number >>> 0 > 9999) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    HEAP32[$power >> 2] = 1e4;
    HEAP32[$exponent >> 2] = 4;
    __label__ = 24;
    break;
   case 14:
    if ($number >>> 0 > 999) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    HEAP32[$power >> 2] = 1e3;
    HEAP32[$exponent >> 2] = 3;
    __label__ = 24;
    break;
   case 16:
    if ($number >>> 0 > 99) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    HEAP32[$power >> 2] = 100;
    HEAP32[$exponent >> 2] = 2;
    __label__ = 24;
    break;
   case 18:
    if ($number >>> 0 > 9) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    HEAP32[$power >> 2] = 10;
    HEAP32[$exponent >> 2] = 1;
    __label__ = 24;
    break;
   case 20:
    if (($number | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    HEAP32[$power >> 2] = 1;
    HEAP32[$exponent >> 2] = 0;
    __label__ = 24;
    break;
   case 22:
    HEAP32[$power >> 2] = 0;
    HEAP32[$exponent >> 2] = -1;
    __label__ = 24;
    break;
   case 23:
    HEAP32[$power >> 2] = 0;
    HEAP32[$exponent >> 2] = 0;
    __label__ = 24;
    break;
   case 24:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2v88internalL15BiggestPowerTenEjiPjPi["X"] = 1;

function __ZN2js19PreserveCompartmentC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  var $3 = HEAP32[$cx + 56 >> 2];
  HEAP32[$this + 4 >> 2] = $3;
  var $7 = HEAP8[$cx + 232 | 0] & 1;
  HEAP8[$this + 8 | 0] = $7;
  return;
}

function __ZNK2js2gc11ArenaHeader12getAllocKindEv($this) {
  return HEAP32[$this + 12 >> 2] & 255;
}

function __ZN2v88internal6VectorIcEC2EPci($this, $data, $length) {
  HEAP32[$this >> 2] = $data;
  HEAP32[$this + 4 >> 2] = $length;
  return;
}

function __ZNK2v88internal6VectorIcEixEi($this_0_0_val, $index) {
  return $this_0_0_val + $index | 0;
}

function __ZN2v88internal5DiyFp8MultiplyERKS1_($this, $other_0_0_val$0, $other_0_0_val$1, $other_0_1_val) {
  var $1 = $this | 0;
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3$0 = $2$1;
  var $3$1 = 0;
  var $4$0 = HEAP32[$1 >> 2] & -1;
  var $4$1 = $2$1 & 0;
  var $5$0 = $other_0_0_val$1;
  var $5$1 = 0;
  var $6$0 = $other_0_0_val$0 & -1;
  var $6$1 = $other_0_0_val$1 & 0;
  var $7$0 = (i64Math.multiply($5$0, $5$1, $3$0, $3$1), i64Math.result[0]);
  var $7$1 = i64Math.result[1];
  var $8$0 = (i64Math.multiply($5$0, $5$1, $4$0, $4$1), i64Math.result[0]);
  var $8$1 = i64Math.result[1];
  var $9$0 = (i64Math.multiply($6$0, $6$1, $3$0, $3$1), i64Math.result[0]);
  var $9$1 = i64Math.result[1];
  var $10$0 = (i64Math.multiply($6$0, $6$1, $4$0, $4$1), i64Math.result[0]);
  var $10$1 = i64Math.result[1];
  var $11$0 = $10$1;
  var $11$1 = 0;
  var $12$0 = $9$0 & -1;
  var $12$1 = $9$1 & 0;
  var $13$0 = $8$0 & -1;
  var $13$1 = $8$1 & 0;
  var $14$0 = (i64Math.add($13$0, $13$1, -2147483648, 0), i64Math.result[0]);
  var $14$1 = i64Math.result[1];
  var $15$0 = (i64Math.add($14$0, $14$1, $12$0, $12$1), i64Math.result[0]);
  var $15$1 = i64Math.result[1];
  var $16$0 = (i64Math.add($15$0, $15$1, $11$0, $11$1), i64Math.result[0]);
  var $16$1 = i64Math.result[1];
  var $17$0 = $9$1;
  var $17$1 = 0;
  var $18$0 = $8$1;
  var $19$0 = $16$1;
  var $19$1 = 0;
  var $20$0 = (i64Math.add($18$0, 0, $7$0, $7$1), i64Math.result[0]);
  var $20$1 = i64Math.result[1];
  var $21$0 = (i64Math.add($20$0, $20$1, $17$0, $17$1), i64Math.result[0]);
  var $21$1 = i64Math.result[1];
  var $22$0 = (i64Math.add($21$0, $21$1, $19$0, $19$1), i64Math.result[0]);
  var $22$1 = i64Math.result[1];
  var $23 = $this + 8 | 0;
  var $26 = $other_0_1_val + 64 + HEAP32[$23 >> 2] | 0;
  HEAP32[$23 >> 2] = $26;
  HEAP32[$1 >> 2] = $22$0;
  HEAP32[$1 + 4 >> 2] = $22$1;
  return;
}

__ZN2v88internal5DiyFp8MultiplyERKS1_["X"] = 1;

function __ZN2v88internal5DiyFp5set_fEy($this, $new_value$0, $new_value$1) {
  var $1 = $this | 0;
  HEAP32[$1 >> 2] = $new_value$0;
  HEAP32[$1 + 4 >> 2] = $new_value$1;
  return;
}

function __ZN2v88internal5DiyFp5set_eEi($this, $new_value) {
  HEAP32[$this + 8 >> 2] = $new_value;
  return;
}

function __ZN2v88internal5DiyFp9NormalizeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = $this + 8 | 0;
    var $4 = HEAP32[$3 >> 2];
    var $$emscripten$temp$0$1 = 4194304;
    if ($2$1 >>> 0 < $$emscripten$temp$0$1 >>> 0 || $2$1 >>> 0 == $$emscripten$temp$0$1 >>> 0 && $2$0 >>> 0 < 0 >>> 0) {
      var $f_04$1 = $2$1;
      var $f_04$0 = $2$0;
      var $e_05 = $4;
      __label__ = 3;
      break;
    } else {
      var $f_0_lcssa$1 = $2$1;
      var $f_0_lcssa$0 = $2$0;
      var $e_0_lcssa = $4;
      __label__ = 2;
      break;
    }
   case 2:
    var $e_0_lcssa;
    var $f_0_lcssa$0;
    var $f_0_lcssa$1;
    var $$emscripten$temp$1$1 = -1;
    if (($f_0_lcssa$1 | 0) > ($$emscripten$temp$1$1 | 0) || ($f_0_lcssa$1 | 0) == ($$emscripten$temp$1$1 | 0) && $f_0_lcssa$0 >>> 0 > -1 >>> 0) {
      var $f_11$1 = $f_0_lcssa$1;
      var $f_11$0 = $f_0_lcssa$0;
      var $e_12 = $e_0_lcssa;
      __label__ = 4;
      break;
    } else {
      var $f_1_lcssa$1 = $f_0_lcssa$1;
      var $f_1_lcssa$0 = $f_0_lcssa$0;
      var $e_1_lcssa = $e_0_lcssa;
      __label__ = 5;
      break;
    }
   case 3:
    var $e_05;
    var $f_04$0;
    var $f_04$1;
    var $7$0 = $f_04$0 << 10 | 0 >>> 22;
    var $7$1 = $f_04$1 << 10 | $f_04$0 >>> 22;
    var $8 = $e_05 - 10 | 0;
    var $$emscripten$temp$2$1 = 4194304;
    if ($7$1 >>> 0 < $$emscripten$temp$2$1 >>> 0 || $7$1 >>> 0 == $$emscripten$temp$2$1 >>> 0 && $7$0 >>> 0 < 0 >>> 0) {
      var $f_04$1 = $7$1;
      var $f_04$0 = $7$0;
      var $e_05 = $8;
      __label__ = 3;
      break;
    } else {
      var $f_0_lcssa$1 = $7$1;
      var $f_0_lcssa$0 = $7$0;
      var $e_0_lcssa = $8;
      __label__ = 2;
      break;
    }
   case 4:
    var $e_12;
    var $f_11$0;
    var $f_11$1;
    var $10$0 = $f_11$0 << 1 | 0 >>> 31;
    var $10$1 = $f_11$1 << 1 | $f_11$0 >>> 31;
    var $11 = $e_12 - 1 | 0;
    var $$emscripten$temp$3$1 = -1;
    if (($10$1 | 0) > ($$emscripten$temp$3$1 | 0) || ($10$1 | 0) == ($$emscripten$temp$3$1 | 0) && $10$0 >>> 0 > -1 >>> 0) {
      var $f_11$1 = $10$1;
      var $f_11$0 = $10$0;
      var $e_12 = $11;
      __label__ = 4;
      break;
    } else {
      var $f_1_lcssa$1 = $10$1;
      var $f_1_lcssa$0 = $10$0;
      var $e_1_lcssa = $11;
      __label__ = 5;
      break;
    }
   case 5:
    var $e_1_lcssa;
    var $f_1_lcssa$0;
    var $f_1_lcssa$1;
    HEAP32[$1 >> 2] = $f_1_lcssa$0;
    HEAP32[$1 + 4 >> 2] = $f_1_lcssa$1;
    HEAP32[$3 >> 2] = $e_1_lcssa;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js19SwitchToCompartmentC2EP9JSContextP13JSCompartment($this, $cx, $newCompartment) {
  var $1 = $this | 0;
  __ZN2js19PreserveCompartmentC2EP9JSContext($1, $cx);
  var $2 = $cx;
  var $3 = $newCompartment;
  __ZN9JSContext14setCompartmentEP13JSCompartment($2, $3);
  return;
}

function _js_malloc181($bytes) {
  var $1 = _malloc($bytes);
  return $1;
}

function __Z14js_NewGCStringP9JSContext($cx) {
  var $1 = __Z10NewGCThingI8JSStringEPT_P9JSContextN2js2gc9AllocKindEj($cx);
  return $1;
}

function __ZN6JSRope4initEP8JSStringS1_j($this, $left, $right, $length) {
  var $1 = __ZN8JSString19buildLengthAndFlagsEjj($length, 1);
  HEAP32[$this >> 2] = $1;
  HEAP32[$this + 4 >> 2] = $left;
  HEAP32[$this + 8 >> 2] = $right;
  return;
}

function __Z10NewGCThingI8JSStringEPT_P9JSContextN2js2gc9AllocKindEj($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$cx + 56 >> 2] + 8 | 0;
    var $4 = __ZN2js2gc10ArenaLists20allocateFromFreeListENS0_9AllocKindEj($3, 18, 16);
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $9 = $4;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js2gc10ArenaLists14refillFreeListEP9JSContextNS0_9AllocKindE($cx, 18);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z10NewGCThingI13JSShortStringEPT_P9JSContextN2js2gc9AllocKindEj($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$cx + 56 >> 2] + 8 | 0;
    var $4 = __ZN2js2gc10ArenaLists20allocateFromFreeListENS0_9AllocKindEj($3, 17, 32);
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $9 = $4;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js2gc10ArenaLists14refillFreeListEP9JSContextNS0_9AllocKindE($cx, 17);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11OffTheBooks7malloc_Ej($bytes) {
  var $1 = _js_malloc181($bytes);
  return $1;
}

function __ZN2js2gc11ChunkBitmap14markIfUnmarkedEPKNS0_4CellEj($this, $cell, $color) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $word = __stackBase__;
    var $mask = __stackBase__ + 4;
    __ZN2js2gc11ChunkBitmap18getMarkWordAndMaskEPKNS0_4CellEjPPjS5_($this, $cell, 0, $word, $mask);
    var $1 = HEAP32[$word >> 2];
    var $2 = HEAP32[$1 >> 2];
    var $3 = HEAP32[$mask >> 2];
    if (($3 & $2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $7 = $3 | $2;
    HEAP32[$1 >> 2] = $7;
    if (($color | 0) == 0) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js2gc11ChunkBitmap18getMarkWordAndMaskEPKNS0_4CellEjPPjS5_($this, $cell, $color, $word, $mask);
    var $10 = HEAP32[$word >> 2];
    var $11 = HEAP32[$10 >> 2];
    var $12 = HEAP32[$mask >> 2];
    if (($12 & $11 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = $12 | $11;
    HEAP32[$10 >> 2] = $16;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc11ChunkBitmap18getMarkWordAndMaskEPKNS0_4CellEjPPjS5_($this, $cell, $color, $wordp, $maskp) {
  var $1 = __ZNK2js2gc4Cell7addressEv($cell);
  var $2 = $1 >>> 3;
  var $4 = ($2 & 131071) + $color | 0;
  HEAP32[$maskp >> 2] = 1 << ($2 + $color & 31);
  HEAP32[$wordp >> 2] = $this + ($4 >>> 5 << 2) | 0;
  return;
}

function __ZN2v88internal15DoubleToCStringEdPci($v, $buffer) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $builder = __stackBase__;
    var $decimal_point = __stackBase__ + 12;
    var $sign = __stackBase__ + 16;
    var $v8_dtoa_buffer = __stackBase__ + 20;
    var $length = __stackBase__ + 40;
    var $1 = __stackBase__ + 44;
    __ZN2v88internal13StringBuilderC1EPci($builder, $buffer);
    var $2 = ___fpclassifyd($v);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 1) {
      __label__ = 3;
      break;
    } else if (($2 | 0) == 2) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    __ZN2v88internal13StringBuilder9AddStringEPKc($builder, STRING_TABLE.__str21098 | 0);
    __label__ = 19;
    break;
   case 3:
    if ($v < 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2v88internal13StringBuilder9AddStringEPKc($builder, STRING_TABLE.__str1185 | 0);
    __label__ = 19;
    break;
   case 5:
    __ZN2v88internal13StringBuilder9AddStringEPKc($builder, STRING_TABLE.__str11097 | 0);
    __label__ = 19;
    break;
   case 6:
    __ZN2v88internal13StringBuilder12AddCharacterEc($builder, 48);
    __label__ = 19;
    break;
   case 7:
    var $10 = $v8_dtoa_buffer | 0;
    __ZN2v88internal6VectorIcEC1EPci($1, $10, 18);
    var $_01_val = HEAP32[$1 >> 2];
    var $_1_val = HEAP32[$1 + 4 >> 2];
    var $11 = __ZN2v88internal13DoubleToAsciiEdNS0_8DtoaModeEiNS0_6VectorIcEEPiS4_S4_($v, $_01_val, $_1_val, $sign, $length, $decimal_point);
    if ($11) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 20;
      break;
    }
   case 8:
    if ((HEAP32[$sign >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2v88internal13StringBuilder12AddCharacterEc($builder, 45);
    __label__ = 10;
    break;
   case 10:
    var $17 = HEAPU32[$length >> 2];
    var $18 = HEAPU32[$decimal_point >> 2];
    if (($17 | 0) <= ($18 | 0) & ($18 | 0) < 22) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    __ZN2v88internal13StringBuilder9AddStringEPKc($builder, $10);
    var $22 = $18 - $17 | 0;
    __ZN2v88internal13StringBuilder10AddPaddingEci($builder, $22);
    __label__ = 19;
    break;
   case 12:
    var $_off = $18 - 1 | 0;
    if ($_off >>> 0 < 21) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    __ZN2v88internal13StringBuilder12AddSubstringEPKci($builder, $10, $18);
    __ZN2v88internal13StringBuilder12AddCharacterEc($builder, 46);
    var $26 = $v8_dtoa_buffer + $18 | 0;
    __ZN2v88internal13StringBuilder9AddStringEPKc($builder, $26);
    __label__ = 19;
    break;
   case 14:
    if (($18 + 5 | 0) >>> 0 < 6) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    __ZN2v88internal13StringBuilder9AddStringEPKc($builder, STRING_TABLE.__str3187 | 0);
    var $30 = -$18 | 0;
    __ZN2v88internal13StringBuilder10AddPaddingEci($builder, $30);
    __ZN2v88internal13StringBuilder9AddStringEPKc($builder, $10);
    __label__ = 19;
    break;
   case 16:
    var $32 = HEAP8[$10];
    __ZN2v88internal13StringBuilder12AddCharacterEc($builder, $32);
    if (($17 | 0) == 1) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    __ZN2v88internal13StringBuilder12AddCharacterEc($builder, 46);
    var $35 = $v8_dtoa_buffer + 1 | 0;
    __ZN2v88internal13StringBuilder9AddStringEPKc($builder, $35);
    __label__ = 18;
    break;
   case 18:
    __ZN2v88internal13StringBuilder12AddCharacterEc($builder, 101);
    var $38 = ($18 | 0) > -1 ? 43 : 45;
    __ZN2v88internal13StringBuilder12AddCharacterEc($builder, $38);
    var $_ = ($_off | 0) < 0 ? 1 - $18 | 0 : $_off;
    __ZN2v88internal13StringBuilder10AddIntegerEi($builder, $_);
    __label__ = 19;
    break;
   case 19:
    var $42 = __ZN2v88internal13StringBuilder8FinalizeEv($builder);
    var $_0 = $42;
    __label__ = 20;
    break;
   case 20:
    var $_0;
    __ZN2v88internal13StringBuilderD1Ev($builder);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2v88internal15DoubleToCStringEdPci["X"] = 1;

function __ZN2v88internal13StringBuilderC1EPci($this, $buffer) {
  __ZN2v88internal13StringBuilderC2EPci($this, $buffer);
  return;
}

function __ZN2v88internal13StringBuilder12AddCharacterEc($this, $c) {
  var $1 = $this + 8 | 0;
  var $2 = HEAP32[$1 >> 2];
  var $3 = $2 + 1 | 0;
  HEAP32[$1 >> 2] = $3;
  var $_idx_val = HEAP32[$this >> 2];
  var $4 = __ZNK2v88internal6VectorIcEixEi($_idx_val, $2);
  HEAP8[$4] = $c;
  return;
}

function __ZN2v88internal6VectorIcEC1EPci($this, $data, $length) {
  __ZN2v88internal6VectorIcEC2EPci($this, $data, $length);
  return;
}

function __ZN2v88internal13StringBuilderD1Ev($this) {
  __ZN2v88internal13StringBuilderD2Ev($this);
  return;
}

function __ZN2v88internal13StringBuilderD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 8 >> 2];
    var $1 = __ZNK2v88internal13StringBuilder12is_finalizedEv($this_idx_val);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2v88internal13StringBuilder8FinalizeEv($this);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2v88internal13StringBuilderC2EPci($this, $buffer) {
  var $1 = $this | 0;
  __ZN2v88internal6VectorIcEC1EPci($1, $buffer, 34);
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN2v88internal9RoundWeedENS0_6VectorIcEEiyyyyy($buffer_0, $buffer_1, $length, $distance_too_high_w$0, $distance_too_high_w$1, $unsafe_interval$0, $unsafe_interval$1, $rest$0, $rest$1, $ten_kappa$0, $ten_kappa$1, $unit$0, $unit$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1$0 = (i64Math.subtract($distance_too_high_w$0, $distance_too_high_w$1, $unit$0, $unit$1), i64Math.result[0]);
    var $1$1 = i64Math.result[1];
    var $2$0 = (i64Math.add($unit$0, $unit$1, $distance_too_high_w$0, $distance_too_high_w$1), i64Math.result[0]);
    var $2$1 = i64Math.result[1];
    var $3 = $length - 1 | 0;
    var $_03$1 = $rest$1;
    var $_03$0 = $rest$0;
    __label__ = 2;
    break;
   case 2:
    var $_03$0;
    var $_03$1;
    if ($_03$1 >>> 0 < $1$1 >>> 0 || $_03$1 >>> 0 == $1$1 >>> 0 && $_03$0 >>> 0 < $1$0 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    var $7$0 = (i64Math.subtract($unsafe_interval$0, $unsafe_interval$1, $_03$0, $_03$1), i64Math.result[0]);
    var $7$1 = i64Math.result[1];
    if ($7$1 >>> 0 < $ten_kappa$1 >>> 0 || $7$1 >>> 0 == $ten_kappa$1 >>> 0 && $7$0 >>> 0 < $ten_kappa$0 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10$0 = (i64Math.add($_03$0, $_03$1, $ten_kappa$0, $ten_kappa$1), i64Math.result[0]);
    var $10$1 = i64Math.result[1];
    if ($10$1 >>> 0 < $1$1 >>> 0 || $10$1 >>> 0 == $1$1 >>> 0 && $10$0 >>> 0 < $1$0 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13$0 = (i64Math.subtract($1$0, $1$1, $_03$0, $_03$1), i64Math.result[0]);
    var $13$1 = i64Math.result[1];
    var $14$0 = (i64Math.subtract($10$0, $10$1, $1$0, $1$1), i64Math.result[0]);
    var $14$1 = i64Math.result[1];
    if ($13$1 >>> 0 < $14$1 >>> 0 || $13$1 >>> 0 == $14$1 >>> 0 && $13$0 >>> 0 < $14$0 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = __ZNK2v88internal6VectorIcEixEi($buffer_0, $3);
    var $18 = HEAP8[$16] - 1 & 255;
    HEAP8[$16] = $18;
    var $_03$1 = $10$1;
    var $_03$0 = $10$0;
    __label__ = 2;
    break;
   case 7:
    if ($_03$1 >>> 0 < $2$1 >>> 0 || $_03$1 >>> 0 == $2$1 >>> 0 && $_03$0 >>> 0 < $2$0 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $21$0 = (i64Math.subtract($unsafe_interval$0, $unsafe_interval$1, $_03$0, $_03$1), i64Math.result[0]);
    var $21$1 = i64Math.result[1];
    if ($21$1 >>> 0 < $ten_kappa$1 >>> 0 || $21$1 >>> 0 == $ten_kappa$1 >>> 0 && $21$0 >>> 0 < $ten_kappa$0 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $24$0 = (i64Math.add($_03$0, $_03$1, $ten_kappa$0, $ten_kappa$1), i64Math.result[0]);
    var $24$1 = i64Math.result[1];
    if ($24$1 >>> 0 < $2$1 >>> 0 || $24$1 >>> 0 == $2$1 >>> 0 && $24$0 >>> 0 < $2$0 >>> 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $27$0 = (i64Math.subtract($2$0, $2$1, $_03$0, $_03$1), i64Math.result[0]);
    var $27$1 = i64Math.result[1];
    var $28$0 = (i64Math.subtract($24$0, $24$1, $2$0, $2$1), i64Math.result[0]);
    var $28$1 = i64Math.result[1];
    var $30$1 = $unit$1 << 1 | $unit$0 >>> 31;
    if (($27$1 >>> 0 > $28$1 >>> 0 || $27$1 >>> 0 == $28$1 >>> 0 && $27$0 >>> 0 > $28$0 >>> 0) | ($30$1 >>> 0 > $_03$1 >>> 0 || $30$1 >>> 0 == $_03$1 >>> 0 && ($unit$0 << 1 | 0 >>> 31) >>> 0 > $_03$0 >>> 0)) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $_old$1 = $unit$1 << 1 | $unit$0 >>> 31;
    if ($_old$1 >>> 0 > $_03$1 >>> 0 || $_old$1 >>> 0 == $_03$1 >>> 0 && ($unit$0 << 1 | 0 >>> 31) >>> 0 > $_03$0 >>> 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $34$0 = $unit$0 << 2 | 0 >>> 30;
    var $34$1 = $unit$1 << 2 | $unit$0 >>> 30;
    var $35$0 = (i64Math.subtract($unsafe_interval$0, $unsafe_interval$1, $34$0, $34$1), i64Math.result[0]);
    var $35$1 = i64Math.result[1];
    var $_0 = $_03$1 >>> 0 <= $35$1 >>> 0 && ($_03$1 >>> 0 < $35$1 >>> 0 || $_03$0 >>> 0 <= $35$0 >>> 0);
    __label__ = 13;
    break;
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2v88internal9RoundWeedENS0_6VectorIcEEiyyyyy["X"] = 1;

function __ZN2v88internal8DigitGenENS0_5DiyFpES1_S1_NS0_6VectorIcEEPiS4_($low_0$0, $low_0$1, $low_1, $w_0$0, $w_0$1, $w_1, $high_0$0, $high_0$1, $high_1, $buffer_0, $buffer_1, $length, $kappa) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $too_low = __stackBase__;
    var $too_high = __stackBase__ + 12;
    var $unsafe_interval = __stackBase__ + 24;
    var $one = __stackBase__ + 36;
    var $divider = __stackBase__ + 48;
    var $divider_exponent = __stackBase__ + 52;
    var $1 = __stackBase__ + 56;
    var $2 = __stackBase__ + 68;
    var $3 = __ZNK2v88internal5DiyFp1fEv($low_0$0, $low_0$1);
    var $3$0 = $3[0];
    var $3$1 = $3[1];
    var $4$0 = (i64Math.add($3$0, $3$1, -1, -1), i64Math.result[0]);
    var $4$1 = i64Math.result[1];
    var $5 = __ZNK2v88internal5DiyFp1eEv($low_1);
    __ZN2v88internal5DiyFpC1Eyi($too_low, $4$0, $4$1, $5);
    var $6 = __ZNK2v88internal5DiyFp1fEv($high_0$0, $high_0$1);
    var $6$0 = $6[0];
    var $6$1 = $6[1];
    var $7$0 = (i64Math.add($6$0, $6$1, 1, 0), i64Math.result[0]);
    var $7$1 = i64Math.result[1];
    var $8 = __ZNK2v88internal5DiyFp1eEv($high_1);
    __ZN2v88internal5DiyFpC1Eyi($too_high, $7$0, $7$1, $8);
    var $too_low_idx = $too_low | 0;
    var $too_low_idx_val$0 = HEAP32[$too_low_idx >> 2];
    var $too_low_idx_val$1 = HEAP32[$too_low_idx + 4 >> 2];
    __ZN2v88internal5DiyFp5MinusERKS1_S3_($unsafe_interval, $too_high, $too_low_idx_val$0, $too_low_idx_val$1);
    var $9 = __ZNK2v88internal5DiyFp1eEv($w_1);
    var $11$0 = -$9 | 0;
    var $12 = Runtime.bitshift64(1, 0, "shl", $11$0);
    var $12$0 = $12[0], $12$1 = $12[1];
    __ZN2v88internal5DiyFpC1Eyi($one, $12$0, $12$1, $9);
    var $too_high_idx = $too_high | 0;
    var $too_high_idx_val$0 = HEAP32[$too_high_idx >> 2];
    var $too_high_idx_val$1 = HEAP32[$too_high_idx + 4 >> 2];
    var $13 = __ZNK2v88internal5DiyFp1fEv($too_high_idx_val$0, $too_high_idx_val$1);
    var $13$0 = $13[0];
    var $13$1 = $13[1];
    var $one_idx15 = $one + 8 | 0;
    var $one_idx15_val = HEAP32[$one_idx15 >> 2];
    var $14 = __ZNK2v88internal5DiyFp1eEv($one_idx15_val);
    var $16$0 = -$14 | 0;
    var $17 = Runtime.bitshift64($13$0, $13$1, "lshr", $16$0);
    var $18 = $17[0];
    var $one_idx9 = $one | 0;
    var $one_idx9_val$0 = HEAPU32[$one_idx9 >> 2];
    var $one_idx9_val$1 = HEAPU32[$one_idx9 + 4 >> 2];
    var $19 = __ZNK2v88internal5DiyFp1fEv($one_idx9_val$0, $one_idx9_val$1);
    var $19$0 = $19[0];
    var $19$1 = $19[1];
    var $20$0 = (i64Math.add($19$0, $19$1, -1, -1), i64Math.result[0]);
    var $20$1 = i64Math.result[1];
    var $21$0 = $20$0 & $13$0;
    var $21$1 = $20$1 & $13$1;
    var $22 = $14 + 64 | 0;
    __ZN2v88internalL15BiggestPowerTenEjiPjPi($18, $22, $divider, $divider_exponent);
    var $24 = HEAP32[$divider_exponent >> 2] + 1 | 0;
    HEAP32[$kappa >> 2] = $24;
    HEAP32[$length >> 2] = 0;
    var $unsafe_interval_idx8 = $unsafe_interval | 0;
    var $unsafe_interval_idx8_val$0 = HEAPU32[$unsafe_interval_idx8 >> 2];
    var $unsafe_interval_idx8_val$1 = HEAPU32[$unsafe_interval_idx8 + 4 >> 2];
    var $integrals_0 = $18;
    var $26 = HEAP32[$kappa >> 2];
    __label__ = 2;
    break;
   case 2:
    var $26;
    var $integrals_0;
    if (($26 | 0) > 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $unsafe_interval_idx12 = $unsafe_interval + 8 | 0;
    var $fractionals_0$1 = $21$1;
    var $fractionals_0$0 = $21$0;
    var $unit_0$1 = 0;
    var $unit_0$0 = 1;
    var $unsafe_interval_idx5_val$1 = $unsafe_interval_idx8_val$1;
    var $unsafe_interval_idx5_val$0 = $unsafe_interval_idx8_val$0;
    var $one_idx4_val$1 = $one_idx9_val$1;
    var $one_idx4_val$0 = $one_idx9_val$0;
    __label__ = 7;
    break;
   case 4:
    var $29 = HEAPU32[$divider >> 2];
    var $30 = Math.floor(($integrals_0 >>> 0) / ($29 >>> 0));
    var $32 = $30 + 48 & 255;
    var $33 = HEAP32[$length >> 2];
    var $34 = __ZNK2v88internal6VectorIcEixEi($buffer_0, $33);
    HEAP8[$34] = $32;
    var $36 = HEAP32[$length >> 2] + 1 | 0;
    HEAP32[$length >> 2] = $36;
    var $37 = ($integrals_0 >>> 0) % ($29 >>> 0);
    var $39 = HEAP32[$kappa >> 2] - 1 | 0;
    HEAP32[$kappa >> 2] = $39;
    var $40$0 = $37;
    var $41 = Runtime.bitshift64($40$0, 0, "shl", $16$0);
    var $41$0 = $41[0], $41$1 = $41[1];
    var $42$0 = (i64Math.add($41$0, $41$1, $21$0, $21$1), i64Math.result[0]);
    var $42$1 = i64Math.result[1];
    var $43 = __ZNK2v88internal5DiyFp1fEv($unsafe_interval_idx8_val$0, $unsafe_interval_idx8_val$1);
    var $43$0 = $43[0];
    var $43$1 = $43[1];
    if ($42$1 >>> 0 < $43$1 >>> 0 || $42$1 >>> 0 == $43$1 >>> 0 && $42$0 >>> 0 < $43$0 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $46 = HEAP32[$length >> 2];
    __ZN2v88internal5DiyFp5MinusERKS1_S3_($1, $too_high, $w_0$0, $w_0$1);
    var $_idx7 = $1 | 0;
    var $st$3$0 = $_idx7 | 0;
    var $_idx7_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx7 + 4 | 0;
    var $_idx7_val$1 = HEAP32[$st$3$1 >> 2];
    var $47 = __ZNK2v88internal5DiyFp1fEv($_idx7_val$0, $_idx7_val$1);
    var $47$0 = $47[0];
    var $47$1 = $47[1];
    var $48$0 = $29;
    var $49 = Runtime.bitshift64($48$0, 0, "shl", $16$0);
    var $49$0 = $49[0], $49$1 = $49[1];
    var $50 = __ZN2v88internal9RoundWeedENS0_6VectorIcEEiyyyyy($buffer_0, $buffer_1, $46, $47$0, $47$1, $43$0, $43$1, $42$0, $42$1, $49$0, $49$1, 1, 0);
    var $_0 = $50;
    __label__ = 9;
    break;
   case 6:
    var $52 = Math.floor(($29 >>> 0) / 10);
    HEAP32[$divider >> 2] = $52;
    var $integrals_0 = $37;
    var $26 = $39;
    __label__ = 2;
    break;
   case 7:
    var $one_idx4_val$0;
    var $one_idx4_val$1;
    var $unsafe_interval_idx5_val$0;
    var $unsafe_interval_idx5_val$1;
    var $unit_0$0;
    var $unit_0$1;
    var $fractionals_0$0;
    var $fractionals_0$1;
    var $53$0 = (i64Math.multiply($fractionals_0$0, $fractionals_0$1, 5, 0), i64Math.result[0]);
    var $53$1 = i64Math.result[1];
    var $54$0 = (i64Math.multiply($unit_0$0, $unit_0$1, 5, 0), i64Math.result[0]);
    var $54$1 = i64Math.result[1];
    var $55 = __ZNK2v88internal5DiyFp1fEv($unsafe_interval_idx5_val$0, $unsafe_interval_idx5_val$1);
    var $55$0 = $55[0];
    var $55$1 = $55[1];
    var $56$0 = (i64Math.multiply($55$0, $55$1, 5, 0), i64Math.result[0]);
    var $56$1 = i64Math.result[1];
    __ZN2v88internal5DiyFp5set_fEy($unsafe_interval, $56$0, $56$1);
    var $unsafe_interval_idx12_val = HEAP32[$unsafe_interval_idx12 >> 2];
    var $57 = __ZNK2v88internal5DiyFp1eEv($unsafe_interval_idx12_val);
    var $58 = $57 + 1 | 0;
    __ZN2v88internal5DiyFp5set_eEi($unsafe_interval, $58);
    var $59 = __ZNK2v88internal5DiyFp1fEv($one_idx4_val$0, $one_idx4_val$1);
    var $59$1 = $59[1];
    var $60$0 = $59[0] >>> 1 | $59$1 << 31;
    var $60$1 = $59$1 >>> 1 | 0 << 31;
    __ZN2v88internal5DiyFp5set_fEy($one, $60$0, $60$1);
    var $one_idx11_val = HEAP32[$one_idx15 >> 2];
    var $61 = __ZNK2v88internal5DiyFp1eEv($one_idx11_val);
    var $62 = $61 + 1 | 0;
    __ZN2v88internal5DiyFp5set_eEi($one, $62);
    var $one_idx10_val = HEAP32[$one_idx15 >> 2];
    var $63 = __ZNK2v88internal5DiyFp1eEv($one_idx10_val);
    var $65$0 = -$63 | 0;
    var $66 = Runtime.bitshift64($53$0, $53$1, "lshr", $65$0);
    var $68 = ($66[0] & 255) + 48 & 255;
    var $69 = HEAP32[$length >> 2];
    var $70 = __ZNK2v88internal6VectorIcEixEi($buffer_0, $69);
    HEAP8[$70] = $68;
    var $72 = HEAP32[$length >> 2] + 1 | 0;
    HEAP32[$length >> 2] = $72;
    var $one_idx3_val$0 = HEAPU32[$one_idx9 >> 2];
    var $one_idx3_val$1 = HEAPU32[$one_idx9 + 4 >> 2];
    var $73 = __ZNK2v88internal5DiyFp1fEv($one_idx3_val$0, $one_idx3_val$1);
    var $73$0 = $73[0];
    var $73$1 = $73[1];
    var $74$0 = (i64Math.add($73$0, $73$1, -1, -1), i64Math.result[0]);
    var $74$1 = i64Math.result[1];
    var $75$0 = $74$0 & $53$0;
    var $75$1 = $74$1 & $53$1;
    var $77 = HEAP32[$kappa >> 2] - 1 | 0;
    HEAP32[$kappa >> 2] = $77;
    var $unsafe_interval_idx2_val$0 = HEAPU32[$unsafe_interval_idx8 >> 2];
    var $unsafe_interval_idx2_val$1 = HEAPU32[$unsafe_interval_idx8 + 4 >> 2];
    var $78 = __ZNK2v88internal5DiyFp1fEv($unsafe_interval_idx2_val$0, $unsafe_interval_idx2_val$1);
    var $78$0 = $78[0];
    var $78$1 = $78[1];
    if ($75$1 >>> 0 < $78$1 >>> 0 || $75$1 >>> 0 == $78$1 >>> 0 && $75$0 >>> 0 < $78$0 >>> 0) {
      __label__ = 8;
      break;
    } else {
      var $fractionals_0$1 = $75$1;
      var $fractionals_0$0 = $75$0;
      var $unit_0$1 = $54$1;
      var $unit_0$0 = $54$0;
      var $unsafe_interval_idx5_val$1 = $unsafe_interval_idx2_val$1;
      var $unsafe_interval_idx5_val$0 = $unsafe_interval_idx2_val$0;
      var $one_idx4_val$1 = $one_idx3_val$1;
      var $one_idx4_val$0 = $one_idx3_val$0;
      __label__ = 7;
      break;
    }
   case 8:
    var $81 = HEAP32[$length >> 2];
    __ZN2v88internal5DiyFp5MinusERKS1_S3_($2, $too_high, $w_0$0, $w_0$1);
    var $_idx = $2 | 0;
    var $st$3$0 = $_idx | 0;
    var $_idx_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAP32[$st$3$1 >> 2];
    var $82 = __ZNK2v88internal5DiyFp1fEv($_idx_val$0, $_idx_val$1);
    var $82$0 = $82[0];
    var $82$1 = $82[1];
    var $83$0 = (i64Math.multiply($82$0, $82$1, $54$0, $54$1), i64Math.result[0]);
    var $83$1 = i64Math.result[1];
    var $84 = __ZN2v88internal9RoundWeedENS0_6VectorIcEEiyyyyy($buffer_0, $buffer_1, $81, $83$0, $83$1, $78$0, $78$1, $75$0, $75$1, $73$0, $73$1, $54$0, $54$1);
    var $_0 = $84;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2v88internal8DigitGenENS0_5DiyFpES1_S1_NS0_6VectorIcEEPiS4_["X"] = 1;

function __ZN2v88internal5DiyFpC1Eyi($this, $f$0, $f$1, $e) {
  __ZN2v88internal5DiyFpC2Eyi($this, $f$0, $f$1, $e);
  return;
}

function __ZN2v88internal5DiyFp5MinusERKS1_S3_($agg_result, $a, $b_0_0_val$0, $b_0_0_val$1) {
  var $1 = $agg_result;
  var $2 = $a;
  HEAP32[$1 >> 2] = HEAP32[$2 >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[$2 + 4 >> 2];
  HEAP32[$1 + 8 >> 2] = HEAP32[$2 + 8 >> 2];
  __ZN2v88internal5DiyFp8SubtractERKS1_($agg_result, $b_0_0_val$0, $b_0_0_val$1);
  return;
}

function __ZN2v88internal6grisu3EdNS0_6VectorIcEEPiS3_($v, $buffer_0, $buffer_1, $length, $decimal_exponent) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 108;
  var $w = __stackBase__;
  var $1 = __stackBase__ + 12;
  var $boundary_minus = __stackBase__ + 20;
  var $boundary_plus = __stackBase__ + 32;
  var $2 = __stackBase__ + 44;
  var $ten_mk = __stackBase__ + 52;
  var $mk = __stackBase__ + 64;
  var $kappa = __stackBase__ + 68;
  var $3 = __stackBase__ + 72;
  var $4 = __stackBase__ + 84;
  var $5 = __stackBase__ + 96;
  __ZN2v88internal6DoubleC1Ed($1, $v);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  __ZNK2v88internal6Double17AsNormalizedDiyFpEv($w, $_idx_val$0, $_idx_val$1);
  __ZN2v88internal5DiyFpC1Ev($boundary_minus);
  __ZN2v88internal5DiyFpC1Ev($boundary_plus);
  __ZN2v88internal6DoubleC1Ed($2, $v);
  var $_idx1 = $2 | 0;
  var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
  var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
  __ZNK2v88internal6Double20NormalizedBoundariesEPNS0_5DiyFpES3_($_idx1_val$0, $_idx1_val$1, $boundary_minus, $boundary_plus);
  __ZN2v88internal5DiyFpC1Ev($ten_mk);
  var $w_idx_val = HEAP32[$w + 8 >> 2];
  var $6 = __ZNK2v88internal5DiyFp1eEv($w_idx_val);
  var $7 = $6 + 64 | 0;
  __ZN2v88internalL14GetCachedPowerEiiiPiPNS0_5DiyFpE($7, $mk, $ten_mk);
  var $ten_mk_idx5 = $ten_mk | 0;
  var $ten_mk_idx5_val$0 = HEAP32[$ten_mk_idx5 >> 2];
  var $ten_mk_idx5_val$1 = HEAP32[$ten_mk_idx5 + 4 >> 2];
  var $ten_mk_idx6_val = HEAP32[$ten_mk + 8 >> 2];
  __ZN2v88internal5DiyFp5TimesERKS1_S3_($4, $w, $ten_mk_idx5_val$0, $ten_mk_idx5_val$1, $ten_mk_idx6_val);
  __ZN2v88internal5DiyFp5TimesERKS1_S3_($3, $boundary_minus, $ten_mk_idx5_val$0, $ten_mk_idx5_val$1, $ten_mk_idx6_val);
  __ZN2v88internal5DiyFp5TimesERKS1_S3_($5, $boundary_plus, $ten_mk_idx5_val$0, $ten_mk_idx5_val$1, $ten_mk_idx6_val);
  var $_0 = $3 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $_1_val = HEAP32[$3 + 8 >> 2];
  var $_07 = $4 | 0;
  var $_07_val$0 = HEAP32[$_07 >> 2];
  var $_07_val$1 = HEAP32[$_07 + 4 >> 2];
  var $_18_val = HEAP32[$4 + 8 >> 2];
  var $_09 = $5 | 0;
  var $_09_val$0 = HEAP32[$_09 >> 2];
  var $_09_val$1 = HEAP32[$_09 + 4 >> 2];
  var $_110_val = HEAP32[$5 + 8 >> 2];
  var $8 = __ZN2v88internal8DigitGenENS0_5DiyFpES1_S1_NS0_6VectorIcEEPiS4_($_0_val$0, $_0_val$1, $_1_val, $_07_val$0, $_07_val$1, $_18_val, $_09_val$0, $_09_val$1, $_110_val, $buffer_0, $buffer_1, $length, $kappa);
  var $11 = HEAP32[$kappa >> 2] - HEAP32[$mk >> 2] | 0;
  HEAP32[$decimal_exponent >> 2] = $11;
  STACKTOP = __stackBase__;
  return $8;
}

__ZN2v88internal6grisu3EdNS0_6VectorIcEEPiS3_["X"] = 1;

function __ZN2v88internal6DoubleC1Ed($this, $d) {
  __ZN2v88internal6DoubleC2Ed($this, $d);
  return;
}

function __ZNK2v88internal6Double17AsNormalizedDiyFpEv($agg_result, $this_0_0_val$0, $this_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2v88internal6Double11SignificandEv($this_0_0_val$0, $this_0_0_val$1);
    var $1$0 = $1[0];
    var $1$1 = $1[1];
    var $2 = __ZNK2v88internal6Double8ExponentEv($this_0_0_val$0, $this_0_0_val$1);
    if (($1$0 & 0) == 0 && ($1$1 & 1048576) == 0) {
      var $f_01$1 = $1$1;
      var $f_01$0 = $1$0;
      var $e_02 = $2;
      __label__ = 2;
      break;
    } else {
      var $f_0_lcssa$1 = $1$1;
      var $f_0_lcssa$0 = $1$0;
      var $e_0_lcssa = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $e_02;
    var $f_01$0;
    var $f_01$1;
    var $5$0 = $f_01$0 << 1 | 0 >>> 31;
    var $5$1 = $f_01$1 << 1 | $f_01$0 >>> 31;
    var $6 = $e_02 - 1 | 0;
    if (($5$0 & 0) == 0 && ($5$1 & 1048576) == 0) {
      var $f_01$1 = $5$1;
      var $f_01$0 = $5$0;
      var $e_02 = $6;
      __label__ = 2;
      break;
    } else {
      var $f_0_lcssa$1 = $5$1;
      var $f_0_lcssa$0 = $5$0;
      var $e_0_lcssa = $6;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_0_lcssa;
    var $f_0_lcssa$0;
    var $f_0_lcssa$1;
    __ZN2v88internal5DiyFpC1Eyi($agg_result, $f_0_lcssa$0 << 11 | 0 >>> 21, $f_0_lcssa$1 << 11 | $f_0_lcssa$0 >>> 21, $e_0_lcssa - 11 | 0);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2v88internal5DiyFpC1Ev($this) {
  __ZN2v88internal5DiyFpC2Ev($this);
  return;
}

function __ZNK2v88internal6Double20NormalizedBoundariesEPNS0_5DiyFpES3_($this_0_0_val$0, $this_0_0_val$1, $out_m_minus, $out_m_plus) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $m_plus = __stackBase__ + 12;
    var $1 = __stackBase__ + 24;
    var $m_minus = __stackBase__ + 36;
    __ZNK2v88internal6Double7AsDiyFpEv($v, $this_0_0_val$0, $this_0_0_val$1);
    var $v_idx2 = $v | 0;
    var $v_idx2_val$0 = HEAP32[$v_idx2 >> 2];
    var $v_idx2_val$1 = HEAP32[$v_idx2 + 4 >> 2];
    var $2 = __ZNK2v88internal5DiyFp1fEv($v_idx2_val$0, $v_idx2_val$1);
    var $2$0 = $2[0];
    var $2$1 = $2[1];
    var $3 = $2$0 != 0 || $2$1 != 1048576;
    var $4$0 = $2$0 << 1 | 0 >>> 31;
    var $4$1 = $2$1 << 1 | $2$0 >>> 31;
    var $5$0 = $4$0 | 1;
    var $5$1 = $4$1 | 0;
    var $v_idx7_val = HEAP32[$v + 8 >> 2];
    var $6 = __ZNK2v88internal5DiyFp1eEv($v_idx7_val);
    var $7 = $6 - 1 | 0;
    __ZN2v88internal5DiyFpC1Eyi($1, $5$0, $5$1, $7);
    __ZN2v88internal5DiyFp9NormalizeERKS1_($m_plus, $1);
    __ZN2v88internal5DiyFpC1Ev($m_minus);
    if ($3 | ($6 | 0) == -1074) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $6 - 2 | 0;
    __ZN2v88internal5DiyFpC1Eyi($m_minus, -1, 4194303, $10);
    __label__ = 4;
    break;
   case 3:
    var $12$0 = (i64Math.add($4$0, $4$1, -1, -1), i64Math.result[0]);
    var $12$1 = i64Math.result[1];
    __ZN2v88internal5DiyFpC1Eyi($m_minus, $12$0, $12$1, $7);
    __label__ = 4;
    break;
   case 4:
    var $m_minus_idx = $m_minus | 0;
    var $m_minus_idx_val$0 = HEAP32[$m_minus_idx >> 2];
    var $m_minus_idx_val$1 = HEAP32[$m_minus_idx + 4 >> 2];
    var $14 = __ZNK2v88internal5DiyFp1fEv($m_minus_idx_val$0, $m_minus_idx_val$1);
    var $14$0 = $14[0];
    var $14$1 = $14[1];
    var $m_minus_idx4_val = HEAP32[$m_minus + 8 >> 2];
    var $15 = __ZNK2v88internal5DiyFp1eEv($m_minus_idx4_val);
    var $m_plus_idx3_val = HEAP32[$m_plus + 8 >> 2];
    var $16 = __ZNK2v88internal5DiyFp1eEv($m_plus_idx3_val);
    var $18$0 = $15 - $16 | 0;
    var $19 = Runtime.bitshift64($14$0, $14$1, "shl", $18$0);
    var $19$0 = $19[0], $19$1 = $19[1];
    __ZN2v88internal5DiyFp5set_fEy($m_minus, $19$0, $19$1);
    __ZN2v88internal5DiyFp5set_eEi($m_minus, $16);
    var $20 = $out_m_plus;
    var $21 = $m_plus;
    HEAP32[$20 >> 2] = HEAP32[$21 >> 2];
    HEAP32[$20 + 4 >> 2] = HEAP32[$21 + 4 >> 2];
    HEAP32[$20 + 8 >> 2] = HEAP32[$21 + 8 >> 2];
    var $22 = $out_m_minus;
    var $23 = $m_minus;
    HEAP32[$22 >> 2] = HEAP32[$23 >> 2];
    HEAP32[$22 + 4 >> 2] = HEAP32[$23 + 4 >> 2];
    HEAP32[$22 + 8 >> 2] = HEAP32[$23 + 8 >> 2];
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2v88internal6Double20NormalizedBoundariesEPNS0_5DiyFpES3_["X"] = 1;

function __ZN2v88internalL14GetCachedPowerEiiiPiPNS0_5DiyFpE($e, $mk, $c_mk) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $1 = __stackBase__;
  var $4 = (3 - $e | 0) * .30102999566398114;
  var $5 = __ZN2v88internal7ceilingEd($4);
  var $9 = ((($5 & -1) + 307 | 0) / 8 & -1) + 1 | 0;
  var $_039 = __ZN2v88internalL14kCachedPowers8E + $9 * 12 | 0;
  var $tmp40$0 = HEAP32[$_039 >> 2];
  var $tmp40$1 = HEAP32[$_039 + 4 >> 2];
  var $phitmp = HEAP16[__ZN2v88internalL14kCachedPowers8E + $9 * 12 + 8 >> 1] << 16 >> 16;
  var $phitmp1 = HEAP16[__ZN2v88internalL14kCachedPowers8E + $9 * 12 + 10 >> 1] << 16 >> 16;
  __ZN2v88internal5DiyFpC1Eyi($1, $tmp40$0, $tmp40$1, $phitmp);
  var $10 = $c_mk;
  var $11 = $1;
  HEAP32[$10 >> 2] = HEAP32[$11 >> 2];
  HEAP32[$10 + 4 >> 2] = HEAP32[$11 + 4 >> 2];
  HEAP32[$10 + 8 >> 2] = HEAP32[$11 + 8 >> 2];
  HEAP32[$mk >> 2] = $phitmp1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2v88internal5DiyFp5TimesERKS1_S3_($agg_result, $a, $b_0_0_val$0, $b_0_0_val$1, $b_0_1_val) {
  var $1 = $agg_result;
  var $2 = $a;
  HEAP32[$1 >> 2] = HEAP32[$2 >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[$2 + 4 >> 2];
  HEAP32[$1 + 8 >> 2] = HEAP32[$2 + 8 >> 2];
  __ZN2v88internal5DiyFp8MultiplyERKS1_($agg_result, $b_0_0_val$0, $b_0_0_val$1, $b_0_1_val);
  return;
}

function __ZN2v88internal8FastDtoaEdNS0_6VectorIcEEPiS3_($v, $buffer_0, $buffer_1, $length, $point) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $decimal_exponent = __stackBase__;
  var $1 = __ZN2v88internal6grisu3EdNS0_6VectorIcEEPiS3_($v, $buffer_0, $buffer_1, $length, $decimal_exponent);
  var $4 = HEAP32[$decimal_exponent >> 2] + HEAP32[$length >> 2] | 0;
  HEAP32[$point >> 2] = $4;
  var $5 = HEAP32[$length >> 2];
  var $6 = __ZNK2v88internal6VectorIcEixEi($buffer_0, $5);
  HEAP8[$6] = 0;
  STACKTOP = __stackBase__;
  return $1;
}

function __ZNK2v88internal6Double7AsDiyFpEv($agg_result, $this_0_0_val$0, $this_0_0_val$1) {
  var $1 = __ZNK2v88internal6Double11SignificandEv($this_0_0_val$0, $this_0_0_val$1);
  var $1$0 = $1[0];
  var $1$1 = $1[1];
  var $2 = __ZNK2v88internal6Double8ExponentEv($this_0_0_val$0, $this_0_0_val$1);
  __ZN2v88internal5DiyFpC1Eyi($agg_result, $1$0, $1$1, $2);
  return;
}

function __ZN2v88internal5DiyFp9NormalizeERKS1_($agg_result, $a) {
  var $1 = $agg_result;
  var $2 = $a;
  HEAP32[$1 >> 2] = HEAP32[$2 >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[$2 + 4 >> 2];
  HEAP32[$1 + 8 >> 2] = HEAP32[$2 + 8 >> 2];
  __ZN2v88internal5DiyFp9NormalizeEv($agg_result);
  return;
}

function __ZNK2v88internal6Double11SignificandEv($this_0_0_val$0, $this_0_0_val$1) {
  var $1 = __ZNK2v88internal6Double8AsUint64Ev($this_0_0_val$0, $this_0_0_val$1);
  var $2$0 = $1[0] & -1;
  var $2$1 = $1[1] & 1048575;
  var $3 = __ZNK2v88internal6Double10IsDenormalEv($this_0_0_val$0, $this_0_0_val$1);
  var $_0$0 = $3 ? $2$0 : $2$0 | 0;
  var $_0$1 = $3 ? $2$1 : $2$1 | 1048576;
  return [ $_0$0, $_0$1 ];
}

function __ZNK2v88internal6Double8AsUint64Ev($this_0_0_val$0, $this_0_0_val$1) {
  return [ $this_0_0_val$0, $this_0_0_val$1 ];
}

function __ZN2js7analyzeL7ArgSlotEj($arg) {
  return $arg + 2 | 0;
}

function __ZN2v88internal5DiyFpC2Ev($this) {
  var $1 = $this | 0;
  HEAP32[$1 >> 2] = 0;
  HEAP32[$1 + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN2v88internal7BitCastIydEET_RKT0_($source) {
  var $1 = $source;
  var $st$1$0 = $1 | 0;
  var $st$1$1 = $1 + 4 | 0;
  return [ HEAPU8[$st$1$0] | HEAPU8[$st$1$0 + 1] << 8 | HEAPU8[$st$1$0 + 2] << 16 | HEAPU8[$st$1$0 + 3] << 24 | 0, HEAPU8[$st$1$1] | HEAPU8[$st$1$1 + 1] << 8 | HEAPU8[$st$1$1 + 2] << 16 | HEAPU8[$st$1$1 + 3] << 24 | 0 ];
}

function __ZN2v88internal5DiyFp8SubtractERKS1_($this, $other_0_0_val$0, $other_0_0_val$1) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3$0 = (i64Math.subtract($2$0, $2$1, $other_0_0_val$0, $other_0_0_val$1), i64Math.result[0]);
  var $3$1 = i64Math.result[1];
  HEAP32[$1 >> 2] = $3$0;
  HEAP32[$1 + 4 >> 2] = $3$1;
  return;
}

function __ZN2v88internal5DiyFpC2Eyi($this, $f$0, $f$1, $e) {
  var $1 = $this | 0;
  HEAP32[$1 >> 2] = $f$0;
  HEAP32[$1 + 4 >> 2] = $f$1;
  HEAP32[$this + 8 >> 2] = $e;
  return;
}

function __ZN8JSScript7getAtomEj($this_0_24_val, $index) {
  return HEAP32[$this_0_24_val + ($index << 2) >> 2];
}

function __ZNK2v88internal6Double8ExponentEv($this_0_0_val$0, $this_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2v88internal6Double10IsDenormalEv($this_0_0_val$0, $this_0_0_val$1);
    if ($1) {
      var $_0 = -1074;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2v88internal6Double8AsUint64Ev($this_0_0_val$0, $this_0_0_val$1);
    var $_0 = (($3[1] >>> 20 | 0 << 12) & 2047) - 1075 | 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2v88internal6Double10IsDenormalEv($this_0_0_val$0, $this_0_0_val$1) {
  var $1 = __ZNK2v88internal6Double8AsUint64Ev($this_0_0_val$0, $this_0_0_val$1);
  return ($1[0] & 0) == 0 && ($1[1] & 2146435072) == 0;
}

function __ZN2v88internal6DoubleC2Ed($this, $d) {
  var $1 = $this | 0;
  var $2 = __ZN2v88internalL16double_to_uint64Ed($d);
  var $2$1 = $2[1];
  HEAP32[$1 >> 2] = $2[0];
  HEAP32[$1 + 4 >> 2] = $2$1;
  return;
}

function __ZN2v88internalL16double_to_uint64Ed($d) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  tempDoubleF64[0] = $d, HEAP32[$1 >> 2] = tempDoubleI32[0], HEAP32[$1 + 4 >> 2] = tempDoubleI32[1];
  var $2 = __ZN2v88internal7BitCastIydEET_RKT0_($1);
  var $2$0 = $2[0];
  var $2$1 = $2[1];
  STACKTOP = __stackBase__;
  return [ $2$0, $2$1 ];
}

function __ZN2js15TempAllocPolicy13onOutOfMemoryEPvj($this_0_0_val) {
  __ZN9JSRuntime13onOutOfMemoryEPvjP9JSContext($this_0_0_val);
  return;
}

function __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($this_0_0_val) {
  __Z27js_ReportAllocationOverflowP9JSContext($this_0_0_val);
  return;
}

function __ZN2js7analyze8Bytecode12mergeDefinesEP9JSContextPNS0_14ScriptAnalysisEbjPjj($this, $cx, $script, $initial, $newDepth, $newArray, $newCount) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($initial) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$this + 4 >> 2] = $newDepth;
    HEAP32[$this + 12 >> 2] = $newArray;
    HEAP32[$this + 8 >> 2] = $newCount;
    var $_0 = 1;
    __label__ = 17;
    break;
   case 3:
    if ((HEAP8[$this | 0] & 64) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 17;
      break;
    }
   case 4:
    var $10 = $this + 8 | 0;
    var $11 = ($newCount | 0) == 0;
    var $12 = $cx + 56 | 0;
    var $13 = $this + 12 | 0;
    var $i_0 = 0;
    var $owned_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $owned_0;
    var $i_0;
    var $15 = HEAPU32[$10 >> 2];
    if ($i_0 >>> 0 < $15 >>> 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 17;
      break;
    }
   case 6:
    if ($11) {
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = HEAP32[HEAP32[$13 >> 2] + ($i_0 << 2) >> 2];
    var $found_01 = 0;
    var $j_02 = 0;
    __label__ = 8;
    break;
   case 8:
    var $j_02;
    var $found_01;
    var $found_1 = (HEAP32[$newArray + ($j_02 << 2) >> 2] | 0) == ($19 | 0) ? 1 : $found_01;
    var $24 = $j_02 + 1 | 0;
    if (($24 | 0) == ($newCount | 0)) {
      __label__ = 9;
      break;
    } else {
      var $found_01 = $found_1;
      var $j_02 = $24;
      __label__ = 8;
      break;
    }
   case 9:
    if (($found_1 & 1) << 24 >> 24 == 0) {
      __label__ = 10;
      break;
    } else {
      var $i_1 = $i_0;
      var $owned_2 = $owned_0;
      __label__ = 16;
      break;
    }
   case 10:
    if (($owned_0 & 1) << 24 >> 24 == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $owned_1 = $owned_0;
    var $42 = $15;
    var $41 = HEAP32[$13 >> 2];
    __label__ = 15;
    break;
   case 12:
    var $30 = HEAP32[$12 >> 2] + 344 | 0;
    var $31 = __ZN2js10ArenaArrayIjEEPT_R11JSArenaPoolj($30, $15);
    if (($31 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($script, $cx);
    var $_0 = 0;
    __label__ = 17;
    break;
   case 14:
    var $35 = $31;
    var $37 = HEAP32[$13 >> 2];
    var $39 = HEAP32[$10 >> 2] << 2;
    _memcpy($35, $37, $39, 1);
    HEAP32[$13 >> 2] = $31;
    var $owned_1 = 1;
    var $42 = HEAP32[$10 >> 2];
    var $41 = $31;
    __label__ = 15;
    break;
   case 15:
    var $41;
    var $42;
    var $owned_1;
    var $43 = $42 - 1 | 0;
    HEAP32[$10 >> 2] = $43;
    var $45 = HEAP32[$41 + ($43 << 2) >> 2];
    HEAP32[$41 + ($i_0 << 2) >> 2] = $45;
    var $i_1 = $i_0 - 1 | 0;
    var $owned_2 = $owned_1;
    __label__ = 16;
    break;
   case 16:
    var $owned_2;
    var $i_1;
    var $i_0 = $i_1 + 1 | 0;
    var $owned_0 = $owned_2;
    __label__ = 5;
    break;
   case 17:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze8Bytecode12mergeDefinesEP9JSContextPNS0_14ScriptAnalysisEbjPjj["X"] = 1;

function __ZN2js10ArenaArrayIjEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + ($count << 2) & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    if ((HEAP8[$1] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    __label__ = 3;
    break;
   case 3:
    HEAP8[$1] = 1;
    HEAP8[$this + 13 | 0] = 1;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis16checkAliasedNameEP9JSContextPh($this, $cx, $pc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $2 = HEAP8[$pc] << 24 >> 24 == 127;
    var $3 = $this | 0;
    var $4 = HEAP32[$3 >> 2];
    var $5 = _js_GetIndexFromBytecode($4, $pc, 0);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$4 + 4 >> 2];
    var $_idx1_val = HEAP8[$4 + 16 | 0];
    var $7 = __ZN8JSScript11getFunctionEj($_idx_val, $_idx1_val, $5);
    var $atom_0 = HEAP32[$7 + 72 >> 2];
    __label__ = 4;
    break;
   case 3:
    var $_idx2_val = HEAP32[$4 + 56 >> 2];
    var $11 = __ZN8JSScript7getAtomEj($_idx2_val, $5);
    var $atom_0 = $11;
    __label__ = 4;
    break;
   case 4:
    var $atom_0;
    var $15 = HEAP32[$3 >> 2] + 64 | 0;
    var $16 = $cx;
    var $17 = __ZNK2js8Bindings6lookupEP9JSContextP6JSAtomPj($15, $16, $atom_0, $index);
    if (($17 | 0) == 1) {
      __label__ = 5;
      break;
    } else if (($17 | 0) == 2) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $19 = HEAP32[$index >> 2];
    var $20 = __ZN2js7analyzeL7ArgSlotEj($19);
    HEAP8[HEAP32[$this + 16 >> 2] + $20 | 0] = 1;
    __label__ = 7;
    break;
   case 6:
    var $25 = HEAP32[$3 >> 2];
    var $26 = HEAP32[$index >> 2];
    var $27 = __ZN2js7analyzeL9LocalSlotEP8JSScriptj($25, $26);
    HEAP8[HEAP32[$this + 16 >> 2] + $27 | 0] = 1;
    __label__ = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSScript11getFunctionEj($this_0_1_val, $this_0_5_val, $index) {
  var $1 = __ZN8JSScript9getObjectEj($this_0_1_val, $this_0_5_val, $index);
  return $1;
}

function __ZN2js7analyzeL9LocalSlotEP8JSScriptj($script, $local) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$script + 37 | 0] & 4) << 24 >> 24 == 0) {
      var $11 = 2;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $script_idx_val_idx_val = HEAP32[HEAP32[$script + 100 >> 2] + 4 >> 2];
    var $6 = __ZNK8JSScript8functionEv($script_idx_val_idx_val);
    var $11 = (HEAPU16[$6 + 56 >> 1] & 65535) + 2 | 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11 + $local | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis15analyzeBytecodeEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $forwardJump = __stackBase__;
    var $nextOffset = __stackBase__ + 4;
    var $untrap = __stackBase__ + 8;
    var $1 = $cx + 56 | 0;
    var $3 = HEAP32[$1 >> 2] + 344 | 0;
    var $4 = $this | 0;
    var $5 = HEAPU32[$4 >> 2];
    var $7 = HEAPU32[$5 + 8 >> 2];
    if ((HEAP8[$5 + 37 | 0] & 4) << 24 >> 24 == 0) {
      var $18 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx6_val_idx_val = HEAP32[HEAP32[$5 + 100 >> 2] + 4 >> 2];
    var $13 = __ZNK8JSScript8functionEv($_idx6_val_idx_val);
    var $18 = HEAPU16[$13 + 56 >> 1] & 65535;
    __label__ = 3;
    break;
   case 3:
    var $18;
    var $19 = __ZN2js7analyzeL10TotalSlotsEP8JSScript($5);
    var $20 = $this + 8 | 0;
    HEAP32[$20 >> 2] = $19;
    var $21 = __ZN2js10ArenaArrayIPNS_7analyze8BytecodeEEEPT_R11JSArenaPoolj($3, $7);
    var $22 = $this + 4 | 0;
    HEAP32[$22 >> 2] = $21;
    var $26 = HEAPU16[HEAP32[$4 >> 2] + 14 >> 1] & 65535;
    var $27 = __ZN2js10ArenaArrayIjEEPT_R11JSArenaPoolj($3, $26);
    var $28 = $this + 32 | 0;
    HEAP32[$28 >> 2] = $27;
    var $29 = HEAP32[$20 >> 2];
    var $30 = __ZN2js10ArenaArrayIhEEPT_R11JSArenaPoolj($3, $29);
    var $31 = $this + 16 | 0;
    HEAP32[$31 >> 2] = $30;
    var $32 = HEAPU32[$22 >> 2];
    if (($32 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $35 = HEAPU32[$28 >> 2];
    if (($35 | 0) == 0 | ($30 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 135;
    break;
   case 6:
    __ZN2jsL7PodZeroIPNS_7analyze8BytecodeEEEvPT_j($32, $7);
    var $40 = HEAPU32[$4 >> 2];
    if (HEAP16[$40 + 14 >> 1] << 16 >> 16 == 0) {
      var $53 = $30;
      var $52 = $40;
      __label__ = 10;
      break;
    } else {
      var $i_053 = 0;
      var $44 = $35;
      __label__ = 7;
      break;
    }
   case 7:
    var $44;
    var $i_053;
    HEAP32[$44 + ($i_053 << 2) >> 2] = -2;
    var $46 = $i_053 + 1 | 0;
    var $47 = HEAPU32[$4 >> 2];
    if ($46 >>> 0 < (HEAPU16[$47 + 14 >> 1] & 65535) >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $i_053 = $46;
    var $44 = HEAP32[$28 >> 2];
    __label__ = 7;
    break;
   case 9:
    var $53 = HEAP32[$31 >> 2];
    var $52 = $47;
    __label__ = 10;
    break;
   case 10:
    var $52;
    var $53;
    var $54 = HEAP32[$20 >> 2];
    __ZN2jsL7PodZeroIhEEvPT_j($53, $54);
    if ((HEAP8[$52 + 36 | 0] & 96) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $61 = __ZNK2js2gc4Cell11compartmentEv($52);
    var $_idx3_val = HEAP32[$61 + 804 >> 2];
    var $62 = __ZNK13JSCompartment9debugModeEv($_idx3_val);
    if ($62) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    if (($18 | 0) == 0) {
      var $82 = $52;
      __label__ = 19;
      break;
    } else {
      var $i1_051 = 0;
      var $67 = $53;
      __label__ = 14;
      break;
    }
   case 13:
    if (HEAP16[$52 + 48 >> 1] << 16 >> 16 == 0) {
      var $82 = $52;
      __label__ = 19;
      break;
    } else {
      var $i2_028 = 0;
      var $72 = $52;
      var $71 = $53;
      __label__ = 16;
      break;
    }
   case 14:
    var $67;
    var $i1_051;
    var $68 = __ZN2js7analyzeL7ArgSlotEj($i1_051);
    HEAP8[$67 + $68 | 0] = 1;
    var $70 = $i1_051 + 1 | 0;
    if (($70 | 0) == ($18 | 0)) {
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $i1_051 = $70;
    var $67 = HEAP32[$31 >> 2];
    __label__ = 14;
    break;
   case 16:
    var $71;
    var $72;
    var $i2_028;
    var $_idx21_val = HEAP32[$72 + 88 >> 2];
    var $73 = __ZN8JSScript12getClosedArgEj($_idx21_val, $i2_028);
    var $74 = __ZN2js7analyzeL7ArgSlotEj($73);
    HEAP8[$71 + $74 | 0] = 1;
    var $76 = $i2_028 + 1 | 0;
    var $77 = HEAPU32[$4 >> 2];
    if ($76 >>> 0 < (HEAPU16[$77 + 48 >> 1] & 65535) >>> 0) {
      __label__ = 17;
      break;
    } else {
      var $82 = $77;
      __label__ = 19;
      break;
    }
   case 17:
    var $i2_028 = $76;
    var $72 = $77;
    var $71 = HEAP32[$31 >> 2];
    __label__ = 16;
    break;
   case 18:
    var $82 = HEAP32[$4 >> 2];
    __label__ = 19;
    break;
   case 19:
    var $82;
    if ((HEAP8[$82 + 36 | 0] & 32) << 24 >> 24 == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $89 = __ZNK2js2gc4Cell11compartmentEv($82);
    var $_idx2_val = HEAP32[$89 + 804 >> 2];
    var $90 = __ZNK13JSCompartment9debugModeEv($_idx2_val);
    if ($90) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    if (HEAP16[$82 + 14 >> 1] << 16 >> 16 == 0) {
      var $118 = $82;
      __label__ = 25;
      break;
    } else {
      var $i3_047 = 0;
      var $97 = $82;
      __label__ = 23;
      break;
    }
   case 22:
    if (HEAP16[$82 + 50 >> 1] << 16 >> 16 == 0) {
      var $118 = $82;
      __label__ = 25;
      break;
    } else {
      var $i4_031 = 0;
      var $107 = $82;
      __label__ = 24;
      break;
    }
   case 23:
    var $97;
    var $i3_047;
    var $98 = __ZN2js7analyzeL9LocalSlotEP8JSScriptj($97, $i3_047);
    HEAP8[HEAP32[$31 >> 2] + $98 | 0] = 1;
    var $this_idx30_val = HEAP32[$28 >> 2];
    __ZN2js7analyze14ScriptAnalysis8setLocalEjj($this_idx30_val, $i3_047, -1);
    var $101 = $i3_047 + 1 | 0;
    var $102 = HEAPU32[$4 >> 2];
    if ($101 >>> 0 < (HEAPU16[$102 + 14 >> 1] & 65535) >>> 0) {
      var $i3_047 = $101;
      var $97 = $102;
      __label__ = 23;
      break;
    } else {
      var $118 = $102;
      __label__ = 25;
      break;
    }
   case 24:
    var $107;
    var $i4_031;
    var $_idx22_val = HEAP16[$107 + 48 >> 1];
    var $_idx23_val = HEAP32[$107 + 88 >> 2];
    var $108 = __ZN8JSScript12getClosedVarEj($_idx22_val, $_idx23_val, $i4_031);
    var $109 = __ZN2js7analyzeL9LocalSlotEP8JSScriptj($107, $108);
    HEAP8[HEAP32[$31 >> 2] + $109 | 0] = 1;
    var $this_idx29_val = HEAP32[$28 >> 2];
    __ZN2js7analyze14ScriptAnalysis8setLocalEjj($this_idx29_val, $108, -1);
    var $112 = $i4_031 + 1 | 0;
    var $113 = HEAPU32[$4 >> 2];
    if ($112 >>> 0 < (HEAPU16[$113 + 50 >> 1] & 65535) >>> 0) {
      var $i4_031 = $112;
      var $107 = $113;
      __label__ = 24;
      break;
    } else {
      var $118 = $113;
      __label__ = 25;
      break;
    }
   case 25:
    var $118;
    if ((HEAPU16[$118 + 14 >> 1] & 65535) > 50) {
      var $i5_043 = 50;
      __label__ = 26;
      break;
    } else {
      var $128 = $118;
      __label__ = 27;
      break;
    }
   case 26:
    var $i5_043;
    var $this_idx28_val = HEAP32[$28 >> 2];
    __ZN2js7analyze14ScriptAnalysis8setLocalEjj($this_idx28_val, $i5_043, -1);
    var $122 = $i5_043 + 1 | 0;
    var $123 = HEAPU32[$4 >> 2];
    if ($122 >>> 0 < (HEAPU16[$123 + 14 >> 1] & 65535) >>> 0) {
      var $i5_043 = $122;
      __label__ = 26;
      break;
    } else {
      var $128 = $123;
      __label__ = 27;
      break;
    }
   case 27:
    var $128;
    var $_idx1_val = HEAP32[HEAP32[$1 >> 2] + 804 >> 2];
    var $130 = __ZNK13JSCompartment9debugModeEv($_idx1_val);
    if ($130) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $_phi_trans_insert = $this + 25 | 0;
    var $140 = HEAP8[$_phi_trans_insert];
    var $_pre_phi = $_phi_trans_insert;
    __label__ = 30;
    break;
   case 29:
    var $132 = $this + 24 | 0;
    var $134 = HEAPU16[$132 >> 1];
    HEAP8[$132] = $134 & 255 | 1;
    var $140 = ($134 & 65535) >>> 8 & 255;
    var $_pre_phi = $this + 25 | 0;
    __label__ = 30;
    break;
   case 30:
    var $_pre_phi;
    var $140;
    HEAP8[$_pre_phi] = $140 | 1;
    var $142 = $128 + 48 | 0;
    if (HEAP16[$142 >> 1] << 16 >> 16 == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 31:
    if (HEAP16[$128 + 50 >> 1] << 16 >> 16 == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 32:
    if ((HEAPU16[$128 + 14 >> 1] & 65535) > 49) {
      __label__ = 37;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    if ((HEAP8[$128 + 37 | 0] & 4) << 24 >> 24 == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $_idx5_val_idx_val = HEAP32[HEAP32[$128 + 100 >> 2] + 4 >> 2];
    var $159 = __ZNK8JSScript8functionEv($_idx5_val_idx_val);
    var $_idx10_val = HEAP16[$159 + 58 >> 1];
    var $160 = __ZNK10JSFunction13isHeavyweightEv($_idx10_val);
    if ($160) {
      __label__ = 37;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    if ((HEAP8[$128 + 36 | 0] & 96) << 24 >> 24 == 0) {
      __label__ = 36;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 36:
    var $_idx_val = HEAP32[HEAP32[$1 >> 2] + 804 >> 2];
    var $168 = __ZNK13JSCompartment9debugModeEv($_idx_val);
    if ($168) {
      __label__ = 37;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 37:
    HEAP8[$_pre_phi] = $140 & -2;
    __label__ = 38;
    break;
   case 38:
    var $171 = $this + 24 | 0;
    var $172 = $171;
    var $173 = HEAPU16[$172 >> 1];
    HEAP8[$171] = $173 & 255 & -17;
    var $179 = ($173 & 65535) >>> 8 & 255;
    if (HEAP16[$142 >> 1] << 16 >> 16 == 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 39:
    if ((HEAP8[$128 + 37 | 0] & 4) << 24 >> 24 == 0) {
      var $195 = $179;
      __label__ = 42;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $_idx4_val_idx_val = HEAP32[HEAP32[$128 + 100 >> 2] + 4 >> 2];
    var $186 = __ZNK8JSScript8functionEv($_idx4_val_idx_val);
    var $_idx9_val = HEAP16[$186 + 58 >> 1];
    var $187 = __ZNK10JSFunction13isHeavyweightEv($_idx9_val);
    if ($187) {
      __label__ = 41;
      break;
    } else {
      var $195 = $179;
      __label__ = 42;
      break;
    }
   case 41:
    var $189 = HEAPU16[$172 >> 1];
    HEAP8[$171] = $189 & 255 | 16;
    var $195 = ($189 & 65535) >>> 8 & 255;
    __label__ = 42;
    break;
   case 42:
    var $195;
    HEAP8[$_pre_phi] = $195 | 2;
    HEAP32[$forwardJump >> 2] = 0;
    var $197 = __ZN2js8ArenaNewINS_7analyze8BytecodeEEEPT_R11JSArenaPool($3);
    if (($197 | 0) == 0) {
      __label__ = 43;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 43:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 135;
    break;
   case 44:
    var $201 = $197 + 4 | 0;
    HEAP32[$201 >> 2] = 0;
    var $202 = HEAP32[$22 >> 2];
    HEAP32[$202 >> 2] = $197;
    var $205 = HEAP32[HEAP32[$4 >> 2] + 100 >> 2];
    var $206 = __ZN2js5types10TypeScript9typeArrayEv($205);
    HEAP32[$nextOffset >> 2] = 0;
    var $207 = $untrap + 4 | 0;
    var $208 = $this + 28 | 0;
    var $cx_idx = $cx + 232 | 0;
    var $forwardCatch_0 = 0;
    var $nTypeSets_0 = 0;
    var $210 = 0;
    __label__ = 45;
    break;
   case 45:
    var $210;
    var $nTypeSets_0;
    var $forwardCatch_0;
    if ($210 >>> 0 < $7 >>> 0) {
      __label__ = 46;
      break;
    } else {
      __label__ = 134;
      break;
    }
   case 46:
    var $213 = HEAPU32[$forwardJump >> 2];
    if (($213 | 0) != 0 & ($213 | 0) == ($210 | 0)) {
      __label__ = 47;
      break;
    } else {
      var $217 = $213;
      __label__ = 48;
      break;
    }
   case 47:
    HEAP32[$forwardJump >> 2] = 0;
    var $217 = 0;
    __label__ = 48;
    break;
   case 48:
    var $217;
    var $forwardCatch_1 = ($forwardCatch_0 | 0) != 0 & ($forwardCatch_0 | 0) == ($210 | 0) ? 0 : $forwardCatch_0;
    var $this_idx_val = HEAP32[$22 >> 2];
    var $220 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEj($this_idx_val, $210);
    var $221 = HEAP32[$4 >> 2];
    var $223 = HEAPU32[$221 >> 2];
    var $224 = $223 + $210 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $221, $224);
    var $225 = HEAPU8[$224];
    var $226 = $225 & 255;
    var $227 = __ZN2js7analyzeL17GetBytecodeLengthEPh($224);
    var $228 = $227 + $210 | 0;
    HEAP32[$nextOffset >> 2] = $228;
    if (($220 | 0) == 0) {
      var $forwardCatch_6 = $forwardCatch_1;
      var $nTypeSets_2 = $nTypeSets_0;
      __label__ = 133;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $231 = $220 | 0;
    var $233 = HEAPU16[$220 >> 1];
    var $234 = $233 & 255;
    var $238 = ($233 & 65535) >>> 8 & 255;
    if (($234 & 64) << 24 >> 24 == 0) {
      __label__ = 50;
      break;
    } else {
      var $forwardCatch_6 = $forwardCatch_1;
      var $nTypeSets_2 = $nTypeSets_0;
      __label__ = 133;
      break;
    }
   case 50:
    HEAP8[$231] = $234 | 64;
    if (($forwardCatch_1 | 0) == 0) {
      var $246 = $238;
      __label__ = 52;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $244 = $238 | 1;
    HEAP8[$231 + 1 | 0] = $244;
    var $246 = $244;
    __label__ = 52;
    break;
   case 52:
    var $246;
    if ((HEAP8[$207] & 1) << 24 >> 24 == 0) {
      __label__ = 54;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    HEAP8[$231 + 1 | 0] = $246 | 2;
    var $254 = HEAP8[$_pre_phi] & -4;
    HEAP8[$_pre_phi] = $254;
    __label__ = 54;
    break;
   case 54:
    var $257 = HEAP32[$220 + 4 >> 2];
    var $258 = $220 + 12 | 0;
    var $259 = HEAPU32[$258 >> 2];
    var $260 = $220 + 8 | 0;
    var $261 = HEAP32[$260 >> 2];
    var $262 = ($217 | 0) == 0;
    if ($262) {
      __label__ = 55;
      break;
    } else {
      var $defineCount_0 = $261;
      var $defineArray_0 = $259;
      __label__ = 60;
      break;
    }
   case 55:
    var $265 = HEAP8[$231] | 32;
    HEAP8[$231] = $265;
    if (($261 | 0) == 0) {
      __label__ = 59;
      break;
    } else {
      var $i6_039 = 0;
      __label__ = 56;
      break;
    }
   case 56:
    var $i6_039;
    var $268 = HEAP32[$259 + ($i6_039 << 2) >> 2];
    var $269 = HEAP32[$28 >> 2];
    if ((HEAP32[$269 + ($268 << 2) >> 2] | 0) == -2) {
      __label__ = 57;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 57:
    __ZN2js7analyze14ScriptAnalysis8setLocalEjj($269, $268, $210);
    __label__ = 58;
    break;
   case 58:
    var $275 = $i6_039 + 1 | 0;
    if (($275 | 0) == ($261 | 0)) {
      __label__ = 59;
      break;
    } else {
      var $i6_039 = $275;
      __label__ = 56;
      break;
    }
   case 59:
    HEAP32[$258 >> 2] = 0;
    HEAP32[$260 >> 2] = 0;
    var $defineCount_0 = 0;
    var $defineArray_0 = 0;
    __label__ = 60;
    break;
   case 60:
    var $defineArray_0;
    var $defineCount_0;
    var $278 = HEAPU32[_js_CodeSpec + ($226 << 3) + 4 >> 2];
    if (($278 & 134217728 | 0) == 0) {
      __label__ = 61;
      break;
    } else {
      var $stackDepth_0 = $257;
      __label__ = 62;
      break;
    }
   case 61:
    var $282 = HEAP32[$4 >> 2];
    var $_idx31_val = HEAP32[$282 >> 2];
    var $283 = __ZN2js7analyzeL11GetUseCountEP8JSScriptj($_idx31_val, $210);
    var $284 = __ZN2js7analyzeL11GetDefCountEP8JSScriptj($282, $210);
    var $stackDepth_0 = $257 - $283 + $284 | 0;
    __label__ = 62;
    break;
   case 62:
    var $stackDepth_0;
    if (($278 & 67108864 | 0) == 0) {
      var $nTypeSets_1 = $nTypeSets_0;
      __label__ = 67;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $cx_idx_val = HEAP8[$cx_idx];
    var $291 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($291) {
      __label__ = 64;
      break;
    } else {
      var $nTypeSets_1 = $nTypeSets_0;
      __label__ = 67;
      break;
    }
   case 64:
    if ($nTypeSets_0 >>> 0 < (HEAPU16[HEAP32[$4 >> 2] + 22 >> 1] & 65535) >>> 0) {
      __label__ = 65;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 65:
    var $300 = $206 + $nTypeSets_0 * 12 | 0;
    var $301 = $220 + 16 | 0;
    HEAP32[$301 >> 2] = $300;
    var $nTypeSets_1 = $nTypeSets_0 + 1 | 0;
    __label__ = 67;
    break;
   case 66:
    var $304 = $206 + ($nTypeSets_0 - 1) * 12 | 0;
    var $305 = $220 + 16 | 0;
    HEAP32[$305 >> 2] = $304;
    var $nTypeSets_1 = $nTypeSets_0;
    __label__ = 67;
    break;
   case 67:
    var $nTypeSets_1;
    if (($226 | 0) == 5 || ($226 | 0) == 197) {
      __label__ = 68;
      break;
    } else if (($226 | 0) == 154 || ($226 | 0) == 2) {
      __label__ = 69;
      break;
    } else if (($226 | 0) == 59 || ($226 | 0) == 57 || ($226 | 0) == 110 || ($226 | 0) == 111 || ($226 | 0) == 36 || ($226 | 0) == 165 || ($226 | 0) == 166) {
      __label__ = 70;
      break;
    } else if (($226 | 0) == 127 || ($226 | 0) == 129 || ($226 | 0) == 128 || ($226 | 0) == 14) {
      __label__ = 71;
      break;
    } else if (($226 | 0) == 123) {
      __label__ = 72;
      break;
    } else if (($226 | 0) == 3) {
      __label__ = 73;
      break;
    } else if (($226 | 0) == 201 || ($226 | 0) == 202) {
      __label__ = 74;
      break;
    } else if (($226 | 0) == 65) {
      __label__ = 75;
      break;
    } else if (($226 | 0) == 58 || ($226 | 0) == 82) {
      __label__ = 76;
      break;
    } else if (($226 | 0) == 70 || ($226 | 0) == 149) {
      __label__ = 77;
      break;
    } else if (($226 | 0) == 71 || ($226 | 0) == 150) {
      __label__ = 83;
      break;
    } else if (($226 | 0) == 134) {
      __label__ = 88;
      break;
    } else if (($226 | 0) == 86) {
      __label__ = 95;
      break;
    } else if (($226 | 0) == 215 || ($226 | 0) == 101 || ($226 | 0) == 102 || ($226 | 0) == 103 || ($226 | 0) == 104) {
      __label__ = 101;
      break;
    } else if (($226 | 0) == 87) {
      __label__ = 105;
      break;
    } else if (($226 | 0) == 85 || ($226 | 0) == 97 || ($226 | 0) == 98 || ($226 | 0) == 99 || ($226 | 0) == 100) {
      __label__ = 115;
      break;
    } else if (($226 | 0) == 9 || ($226 | 0) == 112 || ($226 | 0) == 118 || ($226 | 0) == 140 || ($226 | 0) == 223 || ($226 | 0) == 130 || ($226 | 0) == 224 || ($226 | 0) == 136 || ($226 | 0) == 137 || ($226 | 0) == 138 || ($226 | 0) == 139 || ($226 | 0) == 115 || ($226 | 0) == 108 || ($226 | 0) == 79) {
      __label__ = 116;
      break;
    } else {
      var $forwardCatch_5 = $forwardCatch_1;
      var $defineCount_1 = $defineCount_0;
      var $defineArray_1 = $defineArray_0;
      __label__ = 117;
      break;
    }
   case 68:
    var $309 = HEAP32[$208 >> 2] + 1 | 0;
    HEAP32[$208 >> 2] = $309;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 69:
    var $311 = HEAPU16[$172 >> 1];
    HEAP8[$171] = $311 & 255 | 1;
    HEAP8[$_pre_phi] = ($311 & 65535) >>> 8 & 255 & -2;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 70:
    __ZN2js7analyze14ScriptAnalysis16checkAliasedNameEP9JSContextPh($this, $cx, $224);
    var $318 = HEAPU16[$172 >> 1];
    HEAP8[$171] = $318 & 255 | 2;
    HEAP8[$_pre_phi] = ($318 & 65535) >>> 8 & 255 & -2;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 71:
    __ZN2js7analyze14ScriptAnalysis16checkAliasedNameEP9JSContextPh($this, $cx, $224);
    var $325 = HEAPU16[$172 >> 1];
    HEAP8[$171] = $325 & 255 | 32;
    HEAP8[$_pre_phi] = ($325 & 65535) >>> 8 & 255 & -4;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 72:
    var $332 = HEAPU16[$172 >> 1];
    HEAP8[$171] = $332 & 255 | 32;
    HEAP8[$_pre_phi] = ($332 & 65535) >>> 8 & 255 & -4;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 73:
    var $339 = HEAPU16[$172 >> 1];
    HEAP8[$171] = $339 & 255 | 64;
    HEAP8[$_pre_phi] = ($339 & 65535) >>> 8 & 255 & -4;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 74:
    var $346 = HEAPU16[$172 >> 1];
    HEAP8[$171] = $346 & 255 | 64;
    HEAP8[$_pre_phi] = ($346 & 65535) >>> 8 & 255 & -2;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 75:
    var $354 = HEAP8[$171] | 4;
    HEAP8[$171] = $354;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 76:
    var $357 = HEAP8[$171] | 8;
    HEAP8[$171] = $357;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 77:
    var $359 = HEAP8[$_pre_phi] & -4;
    HEAP8[$_pre_phi] = $359;
    var $361 = $225 << 24 >> 24 == 70 ? 2 : 4;
    var $_val35 = HEAP8[$224];
    var $362 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($_val35, $224);
    var $363 = $362 + $210 | 0;
    var $_sum16 = $361 + $210 | 0;
    var $365 = HEAPU8[$_sum16 + ($223 + 1) | 0];
    var $367 = HEAPU8[$_sum16 + ($223 + 2) | 0];
    var $372 = $_sum16 + ($223 + 4) | 0;
    var $376 = ((HEAPU8[$_sum16 + ($223 + 3) | 0] & 255) << 8 | HEAPU8[$372] & 255) << 16 >> 16;
    var $377 = __ZN2js7analyze14ScriptAnalysis7addJumpEP9JSContextjPjS4_jS4_j($this, $cx, $363, $nextOffset, $forwardJump, $stackDepth_0, $defineArray_0, $defineCount_0);
    if ($377) {
      __label__ = 78;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 78:
    var $383 = (($365 & 255) << 8 | $367 & 255) << 16 >> 16;
    var $this_idx20_val = HEAP32[$22 >> 2];
    var $384 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_idx20_val, $363);
    var $385 = $384 | 0;
    var $387 = HEAP8[$385] | 16;
    HEAP8[$385] = $387;
    var $this_idx19_val = HEAP32[$22 >> 2];
    var $388 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_idx19_val, $363);
    var $390 = $388 + 1 | 0;
    var $392 = HEAP8[$390] | 2;
    HEAP8[$390] = $392;
    var $i8_0 = $383;
    var $pc2_0 = $372;
    __label__ = 79;
    break;
   case 79:
    var $pc2_0;
    var $i8_0;
    if (($i8_0 | 0) > ($376 | 0)) {
      var $forwardCatch_5 = $forwardCatch_1;
      var $defineCount_1 = $defineCount_0;
      var $defineArray_1 = $defineArray_0;
      __label__ = 117;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 80:
    var $_val34 = HEAP8[$224];
    var $396 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($_val34, $pc2_0);
    var $397 = $396 + $210 | 0;
    if (($396 | 0) == 0) {
      __label__ = 82;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 81:
    var $400 = __ZN2js7analyze14ScriptAnalysis7addJumpEP9JSContextjPjS4_jS4_j($this, $cx, $397, $nextOffset, $forwardJump, $stackDepth_0, $defineArray_0, $defineCount_0);
    if ($400) {
      __label__ = 82;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 82:
    var $this_idx18_val = HEAP32[$22 >> 2];
    var $402 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_idx18_val, $397);
    var $403 = $402 | 0;
    var $405 = HEAP8[$403] | 16;
    HEAP8[$403] = $405;
    var $this_idx17_val = HEAP32[$22 >> 2];
    var $406 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_idx17_val, $397);
    var $408 = $406 + 1 | 0;
    var $410 = HEAP8[$408] | 2;
    HEAP8[$408] = $410;
    var $i8_0 = $i8_0 + 1 | 0;
    var $pc2_0 = $pc2_0 + $361 | 0;
    __label__ = 79;
    break;
   case 83:
    var $414 = HEAP8[$_pre_phi] & -4;
    HEAP8[$_pre_phi] = $414;
    var $416 = $225 << 24 >> 24 == 71 ? 2 : 4;
    var $_val33 = HEAP8[$224];
    var $417 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($_val33, $224);
    var $418 = $417 + $210 | 0;
    var $_sum12 = $416 + $210 | 0;
    var $420 = HEAPU8[$_sum12 + ($223 + 1) | 0];
    var $421 = $_sum12 + ($223 + 2) | 0;
    var $422 = HEAPU8[$421];
    var $423 = __ZN2js7analyze14ScriptAnalysis7addJumpEP9JSContextjPjS4_jS4_j($this, $cx, $418, $nextOffset, $forwardJump, $stackDepth_0, $defineArray_0, $defineCount_0);
    if ($423) {
      __label__ = 84;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 84:
    var $428 = ($420 & 255) << 8 | $422 & 255;
    var $this_idx16_val = HEAP32[$22 >> 2];
    var $429 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_idx16_val, $418);
    var $430 = $429 | 0;
    var $432 = HEAP8[$430] | 16;
    HEAP8[$430] = $432;
    var $this_idx15_val = HEAP32[$22 >> 2];
    var $433 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_idx15_val, $418);
    var $435 = $433 + 1 | 0;
    var $437 = HEAP8[$435] | 2;
    HEAP8[$435] = $437;
    var $_sum15 = $416 + 2 | 0;
    var $npairs_0 = $428;
    var $pc29_0 = $421;
    __label__ = 85;
    break;
   case 85:
    var $pc29_0;
    var $npairs_0;
    if (($npairs_0 | 0) == 0) {
      var $forwardCatch_5 = $forwardCatch_1;
      var $defineCount_1 = $defineCount_0;
      var $defineArray_1 = $defineArray_0;
      __label__ = 117;
      break;
    } else {
      __label__ = 86;
      break;
    }
   case 86:
    var $_val32 = HEAP8[$224];
    var $442 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($_val32, $pc29_0 + 2 | 0);
    var $443 = $442 + $210 | 0;
    var $444 = __ZN2js7analyze14ScriptAnalysis7addJumpEP9JSContextjPjS4_jS4_j($this, $cx, $443, $nextOffset, $forwardJump, $stackDepth_0, $defineArray_0, $defineCount_0);
    if ($444) {
      __label__ = 87;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 87:
    var $this_idx14_val = HEAP32[$22 >> 2];
    var $446 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_idx14_val, $443);
    var $447 = $446 | 0;
    var $449 = HEAP8[$447] | 16;
    HEAP8[$447] = $449;
    var $this_idx13_val = HEAP32[$22 >> 2];
    var $450 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_idx13_val, $443);
    var $452 = $450 + 1 | 0;
    var $454 = HEAP8[$452] | 2;
    HEAP8[$452] = $454;
    var $npairs_0 = $npairs_0 - 1 | 0;
    var $pc29_0 = $pc29_0 + $_sum15 | 0;
    __label__ = 85;
    break;
   case 88:
    var $459 = HEAP8[$_pre_phi] & -4;
    HEAP8[$_pre_phi] = $459;
    var $460 = HEAP32[$4 >> 2];
    var $_idx7_val = HEAP32[$460 + 4 >> 2];
    var $_idx8_val = HEAP8[$460 + 19 | 0];
    var $461 = __ZN8JSScript8trynotesEv($_idx7_val, $_idx8_val);
    var $463 = HEAP32[$461 >> 2];
    var $466 = $463 + HEAP32[$461 + 4 >> 2] * 12 | 0;
    var $467 = $210 + 1 | 0;
    var $tn_0 = $463;
    var $forwardCatch_2 = $forwardCatch_1;
    __label__ = 89;
    break;
   case 89:
    var $forwardCatch_2;
    var $tn_0;
    if ($tn_0 >>> 0 < $466 >>> 0) {
      __label__ = 90;
      break;
    } else {
      var $forwardCatch_5 = $forwardCatch_2;
      var $defineCount_1 = $defineCount_0;
      var $defineArray_1 = $defineArray_0;
      __label__ = 117;
      break;
    }
   case 90:
    var $476 = HEAP32[$tn_0 + 4 >> 2] + HEAP32[HEAP32[$4 >> 2] + 32 >> 2] | 0;
    if (($476 | 0) == ($467 | 0)) {
      __label__ = 91;
      break;
    } else {
      var $forwardCatch_4 = $forwardCatch_2;
      __label__ = 94;
      break;
    }
   case 91:
    var $481 = HEAP32[$tn_0 + 8 >> 2] + $476 | 0;
    var $forwardCatch_3 = $481 >>> 0 > $forwardCatch_2 >>> 0 ? $481 : $forwardCatch_2;
    if (HEAP8[$tn_0 | 0] << 24 >> 24 == 2) {
      var $forwardCatch_4 = $forwardCatch_3;
      __label__ = 94;
      break;
    } else {
      __label__ = 92;
      break;
    }
   case 92:
    var $487 = __ZN2js7analyze14ScriptAnalysis7addJumpEP9JSContextjPjS4_jS4_j($this, $cx, $481, $nextOffset, $forwardJump, $stackDepth_0, $defineArray_0, $defineCount_0);
    if ($487) {
      __label__ = 93;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 93:
    var $this_idx12_val = HEAP32[$22 >> 2];
    var $489 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_idx12_val, $481);
    var $490 = $489 | 0;
    var $492 = HEAP8[$490] | -128;
    HEAP8[$490] = $492;
    var $this_idx11_val = HEAP32[$22 >> 2];
    var $493 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_idx11_val, $481);
    var $495 = $493 + 1 | 0;
    var $497 = HEAP8[$495] | 2;
    HEAP8[$495] = $497;
    var $forwardCatch_4 = $forwardCatch_3;
    __label__ = 94;
    break;
   case 94:
    var $forwardCatch_4;
    var $tn_0 = $tn_0 + 12 | 0;
    var $forwardCatch_2 = $forwardCatch_4;
    __label__ = 89;
    break;
   case 95:
    var $501 = $210 + ($223 + 3) | 0;
    var $this_idx36_val = HEAP32[$4 >> 2];
    if (HEAP8[$501] << 24 >> 24 == 81) {
      __label__ = 96;
      break;
    } else {
      var $506 = $this_idx36_val;
      __label__ = 97;
      break;
    }
   case 96:
    var $this_idx37_val = HEAP32[$22 >> 2];
    var $this_idx36_val_idx_val = HEAP32[$this_idx36_val >> 2];
    var $505 = __ZN2js7analyze14ScriptAnalysis10jumpTargetEPKh($this_idx36_val_idx_val, $this_idx37_val, $501);
    if ($505) {
      var $506 = $this_idx36_val;
      __label__ = 97;
      break;
    } else {
      var $forwardCatch_5 = $forwardCatch_1;
      var $defineCount_1 = $defineCount_0;
      var $defineArray_1 = $defineArray_0;
      __label__ = 117;
      break;
    }
   case 97:
    var $506;
    var $514 = (HEAPU8[$210 + ($223 + 1) | 0] & 255) << 8 | HEAPU8[$210 + ($223 + 2) | 0] & 255;
    if ($514 >>> 0 < (HEAPU16[$506 + 14 >> 1] & 65535) >>> 0) {
      __label__ = 99;
      break;
    } else {
      __label__ = 98;
      break;
    }
   case 98:
    var $521 = HEAP8[$171] | -128;
    HEAP8[$171] = $521;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 99:
    var $523 = __ZN2js7analyze14ScriptAnalysis12localDefinedEjj($this, $514, $210);
    if ($523) {
      var $forwardCatch_5 = $forwardCatch_1;
      var $defineCount_1 = $defineCount_0;
      var $defineArray_1 = $defineArray_0;
      __label__ = 117;
      break;
    } else {
      __label__ = 100;
      break;
    }
   case 100:
    var $this_idx26_val = HEAP32[$28 >> 2];
    __ZN2js7analyze14ScriptAnalysis8setLocalEjj($this_idx26_val, $514, -1);
    var $526 = HEAP8[$_pre_phi] & -2;
    HEAP8[$_pre_phi] = $526;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 101:
    var $535 = (HEAPU8[$210 + ($223 + 1) | 0] & 255) << 8 | HEAPU8[$210 + ($223 + 2) | 0] & 255;
    if ($535 >>> 0 < (HEAPU16[HEAP32[$4 >> 2] + 14 >> 1] & 65535) >>> 0) {
      __label__ = 103;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 102:
    var $543 = HEAP8[$171] | -128;
    HEAP8[$171] = $543;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 103:
    var $545 = __ZN2js7analyze14ScriptAnalysis12localDefinedEjj($this, $535, $210);
    if ($545) {
      var $forwardCatch_5 = $forwardCatch_1;
      var $defineCount_1 = $defineCount_0;
      var $defineArray_1 = $defineArray_0;
      __label__ = 117;
      break;
    } else {
      __label__ = 104;
      break;
    }
   case 104:
    var $this_idx25_val = HEAP32[$28 >> 2];
    __ZN2js7analyze14ScriptAnalysis8setLocalEjj($this_idx25_val, $535, -1);
    var $548 = HEAP8[$_pre_phi] & -2;
    HEAP8[$_pre_phi] = $548;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 105:
    var $557 = (HEAPU8[$210 + ($223 + 1) | 0] & 255) << 8 | HEAPU8[$210 + ($223 + 2) | 0] & 255;
    if ($557 >>> 0 < (HEAPU16[HEAP32[$4 >> 2] + 14 >> 1] & 65535) >>> 0) {
      __label__ = 107;
      break;
    } else {
      __label__ = 106;
      break;
    }
   case 106:
    var $565 = HEAP8[$171] | -128;
    HEAP8[$171] = $565;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 107:
    var $567 = HEAPU32[$28 >> 2];
    if ((HEAP32[$567 + ($557 << 2) >> 2] | 0) == -2) {
      __label__ = 108;
      break;
    } else {
      var $forwardCatch_5 = $forwardCatch_1;
      var $defineCount_1 = $defineCount_0;
      var $defineArray_1 = $defineArray_0;
      __label__ = 117;
      break;
    }
   case 108:
    if ($262) {
      __label__ = 114;
      break;
    } else {
      __label__ = 109;
      break;
    }
   case 109:
    var $573 = $defineCount_0 + 1 | 0;
    var $574 = __ZN2js10ArenaArrayIjEEPT_R11JSArenaPoolj($3, $573);
    if (($574 | 0) == 0) {
      __label__ = 110;
      break;
    } else {
      __label__ = 111;
      break;
    }
   case 110:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 132;
    break;
   case 111:
    if (($defineCount_0 | 0) == 0) {
      __label__ = 113;
      break;
    } else {
      __label__ = 112;
      break;
    }
   case 112:
    var $580 = $574;
    _memcpy($580, $defineArray_0, $defineCount_0 << 2, 1);
    __label__ = 113;
    break;
   case 113:
    var $584 = $574 + ($defineCount_0 << 2) | 0;
    HEAP32[$584 >> 2] = $557;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $573;
    var $defineArray_1 = $574;
    __label__ = 117;
    break;
   case 114:
    __ZN2js7analyze14ScriptAnalysis8setLocalEjj($567, $557, $210);
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 115:
    var $587 = HEAPU16[$172 >> 1];
    HEAP8[$171] = $587 & 255 | 16;
    HEAP8[$_pre_phi] = ($587 & 65535) >>> 8 & 255 & -2;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 116:
    var $594 = HEAP8[$_pre_phi] & -2;
    HEAP8[$_pre_phi] = $594;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 117:
    var $defineArray_1;
    var $defineCount_1;
    var $forwardCatch_5;
    var $595 = $278 & 31;
    if (($595 | 0) == 9 || ($595 | 0) == 1) {
      __label__ = 118;
      break;
    } else {
      var $stackDepth_2 = $stackDepth_0;
      __label__ = 122;
      break;
    }
   case 118:
    if (($226 | 0) == 68 || ($226 | 0) == 69 || ($226 | 0) == 144 || ($226 | 0) == 145) {
      __label__ = 119;
      break;
    } else if (($226 | 0) == 121 || ($226 | 0) == 147) {
      __label__ = 120;
      break;
    } else {
      var $newStackDepth_0 = $stackDepth_0;
      var $stackDepth_1 = $stackDepth_0;
      __label__ = 121;
      break;
    }
   case 119:
    var $newStackDepth_0 = $stackDepth_0;
    var $stackDepth_1 = $stackDepth_0 - 1 | 0;
    __label__ = 121;
    break;
   case 120:
    var $newStackDepth_0 = $stackDepth_0 - 1 | 0;
    var $stackDepth_1 = $stackDepth_0;
    __label__ = 121;
    break;
   case 121:
    var $stackDepth_1;
    var $newStackDepth_0;
    var $_val = HEAP8[$224];
    var $602 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($_val, $224);
    var $603 = $602 + $210 | 0;
    var $604 = __ZN2js7analyze14ScriptAnalysis7addJumpEP9JSContextjPjS4_jS4_j($this, $cx, $603, $nextOffset, $forwardJump, $newStackDepth_0, $defineArray_1, $defineCount_1);
    if ($604) {
      var $stackDepth_2 = $stackDepth_1;
      __label__ = 122;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 122:
    var $stackDepth_2;
    var $606 = __ZN2js7analyzeL21BytecodeNoFallThroughE4JSOp($226);
    if ($606) {
      var $forwardCatch_6 = $forwardCatch_5;
      var $nTypeSets_2 = $nTypeSets_1;
      __label__ = 133;
      break;
    } else {
      __label__ = 123;
      break;
    }
   case 123:
    var $609 = HEAP32[$22 >> 2] + ($228 << 2) | 0;
    var $610 = HEAP32[$609 >> 2];
    var $611 = ($610 | 0) == 0;
    if ($611) {
      __label__ = 124;
      break;
    } else {
      var $617 = $610;
      __label__ = 126;
      break;
    }
   case 124:
    var $613 = __ZN2js8ArenaNewINS_7analyze8BytecodeEEEPT_R11JSArenaPool($3);
    HEAP32[$609 >> 2] = $613;
    if (($613 | 0) == 0) {
      __label__ = 125;
      break;
    } else {
      var $617 = $613;
      __label__ = 126;
      break;
    }
   case 125:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 132;
    break;
   case 126:
    var $617;
    if (($595 | 0) == 9 || ($595 | 0) == 1) {
      __label__ = 127;
      break;
    } else {
      var $623 = $617;
      __label__ = 128;
      break;
    }
   case 127:
    var $619 = $617 | 0;
    var $621 = HEAP8[$619] | 8;
    HEAP8[$619] = $621;
    var $623 = HEAP32[$609 >> 2];
    __label__ = 128;
    break;
   case 128:
    var $623;
    var $624 = __ZN2js7analyze8Bytecode12mergeDefinesEP9JSContextPNS0_14ScriptAnalysisEbjPjj($623, $cx, $this, $611, $stackDepth_2, $defineArray_1, $defineCount_1);
    if ($624) {
      __label__ = 129;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 129:
    var $627 = HEAP32[$609 >> 2] | 0;
    var $628 = HEAP8[$627];
    if (($595 | 0) == 9 || ($595 | 0) == 1) {
      __label__ = 130;
      break;
    } else {
      __label__ = 131;
      break;
    }
   case 130:
    var $630 = $628 | 1;
    HEAP8[$627] = $630;
    var $forwardCatch_6 = $forwardCatch_5;
    var $nTypeSets_2 = $nTypeSets_1;
    __label__ = 133;
    break;
   case 131:
    var $632 = $628 | 4;
    HEAP8[$627] = $632;
    var $forwardCatch_6 = $forwardCatch_5;
    var $nTypeSets_2 = $nTypeSets_1;
    __label__ = 133;
    break;
   case 132:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    __label__ = 135;
    break;
   case 133:
    var $nTypeSets_2;
    var $forwardCatch_6;
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $forwardCatch_0 = $forwardCatch_6;
    var $nTypeSets_0 = $nTypeSets_2;
    var $210 = HEAP32[$nextOffset >> 2];
    __label__ = 45;
    break;
   case 134:
    HEAP8[$this + 20 | 0] = 1;
    __label__ = 135;
    break;
   case 135:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis15analyzeBytecodeEP9JSContext["X"] = 1;

function __ZNK8JSScript8functionEv($this_0_32_val_0_1_val) {
  return $this_0_32_val_0_1_val;
}

function __ZN2js7analyzeL21BytecodeNoFallThroughE4JSOp($op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($op | 0) == 116 || ($op | 0) == 146) {
      __label__ = 2;
      break;
    } else if (($op | 0) == 6 || ($op | 0) == 141 || ($op | 0) == 122 || ($op | 0) == 148 || ($op | 0) == 5 || ($op | 0) == 197 || ($op | 0) == 155 || ($op | 0) == 112 || ($op | 0) == 70 || ($op | 0) == 149 || ($op | 0) == 71 || ($op | 0) == 150 || ($op | 0) == 176) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK10JSFunction13isHeavyweightEv($this_0_2_val) {
  return ($this_0_2_val & 128) << 16 >> 16 != 0;
}

function __ZN2js5types10TypeScript9typeArrayEv($this) {
  return $this + 20 | 0;
}

function __ZN8JSScript12getClosedArgEj($this_0_30_val, $index) {
  return HEAP32[$this_0_30_val + ($index << 2) >> 2];
}

function __ZN2js7analyze14ScriptAnalysis8setLocalEjj($this_0_13_val, $local, $offset) {
  HEAP32[$this_0_13_val + ($local << 2) >> 2] = $offset;
  return;
}

function __ZN8JSScript12getClosedVarEj($this_0_21_val, $this_0_30_val, $index) {
  return HEAP32[$this_0_30_val + (($this_0_21_val & 65535) + $index << 2) >> 2];
}

function __ZN2js7analyze14ScriptAnalysis9maybeCodeEj($this_0_1_val, $offset) {
  return HEAP32[$this_0_1_val + ($offset << 2) >> 2];
}

function __ZN2js7analyzeL13GetJumpOffsetEPhS1_($pc_val, $pc2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $9 = HEAPU8[$pc2 + 1 | 0] & 255;
    if (((HEAP32[_js_CodeSpec + (($pc_val & 255) << 3) + 4 >> 2] & 31) - 9 | 0) >>> 0 < 3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = (HEAPU8[$pc2 + 2 | 0] & 255) << 16 | $9 << 24 | HEAPU8[$pc2 + 4 | 0] & 255 | (HEAPU8[$pc2 + 3 | 0] & 255) << 8;
    __label__ = 4;
    break;
   case 3:
    var $_0 = (HEAPU8[$pc2 + 2 | 0] & 255 | $9 << 8) << 16 >> 16;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_0_1_val, $offset) {
  return HEAP32[$this_0_1_val + ($offset << 2) >> 2];
}

function __ZN8JSScript8trynotesEv($this_0_1_val, $this_0_8_val) {
  return $this_0_1_val + ($this_0_8_val & 255) | 0;
}

function __ZN2js7analyzeL10TotalSlotsEP8JSScript($script) {
  var $1 = __ZN2js7analyzeL9LocalSlotEP8JSScriptj($script, 0);
  return (HEAPU16[$script + 14 >> 1] & 65535) + $1 | 0;
}

function __ZN2js10ArenaArrayIPNS_7analyze8BytecodeEEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + ($count << 2) & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10ArenaArrayIhEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + $count & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodZeroIPNS_7analyze8BytecodeEEEvPT_j($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem << 2;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2jsL7PodZeroIhEEvPT_j($t, $nelem) {
  _memset($t, 0, $nelem, 1);
  return;
}

function __ZN2js8ArenaNewINS_7analyze8BytecodeEEEPT_R11JSArenaPool($pool) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 44 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $25 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    __ZN2js7analyze8BytecodeC1Ev($23);
    var $25 = $23;
    __label__ = 6;
    break;
   case 6:
    var $25;
    return $25;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($this, $script, $pc) {
  __ZN2js7analyze12UntrapOpcodeC2EP9JSContextP8JSScriptPh($this, $script, $pc);
  return;
}

function __ZN2js7analyzeL17GetBytecodeLengthEPh($pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAPU8[_js_CodeSpec + ((HEAPU8[$pc] & 255) << 3) | 0];
    if ($4 << 24 >> 24 == -1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = $4 << 24 >> 24;
    __label__ = 4;
    break;
   case 3:
    var $9 = __Z28js_GetVariableBytecodeLengthPh($pc);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyzeL11GetUseCountEP8JSScriptj($script_0_0_val, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $script_0_0_val + $offset | 0;
    var $2 = HEAPU8[$1];
    var $3 = $2 & 255;
    if ($2 << 24 >> 24 == -123) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = (HEAPU8[$offset + ($script_0_0_val + 1) | 0] & 255) + 1 | 0;
    __label__ = 6;
    break;
   case 3:
    var $12 = HEAPU8[_js_CodeSpec + ($3 << 3) + 1 | 0];
    if ($12 << 24 >> 24 == -1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = _js_GetVariableStackUses($3, $1);
    var $_0 = $15;
    __label__ = 6;
    break;
   case 5:
    var $_0 = $12 << 24 >> 24;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyzeL11GetDefCountEP8JSScriptj($script, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$script >> 2];
    var $3 = $2 + $offset | 0;
    var $5 = HEAPU8[$3] & 255;
    var $7 = HEAPU8[_js_CodeSpec + ($5 << 3) + 2 | 0];
    var $8 = $7 << 24 >> 24;
    if ($7 << 24 >> 24 == -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = _js_GetEnterBlockStackDefs($script, $3);
    var $_0 = $11;
    __label__ = 7;
    break;
   case 3:
    if (($5 | 0) == 176) {
      __label__ = 4;
      break;
    } else if (($5 | 0) == 133) {
      __label__ = 5;
      break;
    } else if (($5 | 0) == 68 || ($5 | 0) == 144 || ($5 | 0) == 69 || ($5 | 0) == 145) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $_0 = 2;
    __label__ = 7;
    break;
   case 5:
    var $_0 = (HEAPU8[$offset + ($2 + 1) | 0] & 255) + 1 | 0;
    __label__ = 7;
    break;
   case 6:
    var $_0 = $8;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis7addJumpEP9JSContextjPjS4_jS4_j($this, $cx, $offset, $currentOffset, $forwardJump, $stackDepth, $defineArray, $defineCount) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $untrap = __stackBase__;
    var $3 = HEAP32[$this + 4 >> 2] + ($offset << 2) | 0;
    var $4 = HEAP32[$3 >> 2];
    var $5 = ($4 | 0) == 0;
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $14 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $9 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    var $10 = __ZN2js8ArenaNewINS_7analyze8BytecodeEEEPT_R11JSArenaPool($9);
    HEAP32[$3 >> 2] = $10;
    if (($10 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $14 = $10;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    var $_0 = 0;
    __label__ = 15;
    break;
   case 4:
    var $14;
    var $15 = __ZN2js7analyze8Bytecode12mergeDefinesEP9JSContextPNS0_14ScriptAnalysisEbjPjj($14, $cx, $this, $5, $stackDepth, $defineArray, $defineCount);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 5:
    var $18 = HEAP32[$3 >> 2] | 0;
    var $20 = HEAP8[$18] | 1;
    HEAP8[$18] = $20;
    if (HEAPU32[$currentOffset >> 2] >>> 0 > $offset >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 6:
    var $25 = HEAPU32[$this >> 2];
    var $28 = HEAP32[$25 >> 2] + $offset | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $25, $28);
    var $29 = HEAP8[$28];
    if ($29 << 24 >> 24 == 109 || $29 << 24 >> 24 == -74) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $32 = HEAP32[$3 >> 2] | 0;
    var $34 = HEAP8[$32] | 2;
    HEAP8[$32] = $34;
    __label__ = 8;
    break;
   case 8:
    var $36 = $this + 25 | 0;
    var $38 = HEAP8[$36] & -2;
    HEAP8[$36] = $38;
    if ((HEAP8[HEAP32[$3 >> 2] | 0] & 64) << 24 >> 24 == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 9:
    if ((HEAP32[$forwardJump >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $48 = HEAP32[$currentOffset >> 2];
    HEAP32[$forwardJump >> 2] = $48;
    __label__ = 11;
    break;
   case 11:
    HEAP32[$currentOffset >> 2] = $offset;
    __label__ = 12;
    break;
   case 12:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_0 = 1;
    __label__ = 15;
    break;
   case 13:
    if (HEAPU32[$forwardJump >> 2] >>> 0 < $offset >>> 0) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 1;
      __label__ = 15;
      break;
    }
   case 14:
    HEAP32[$forwardJump >> 2] = $offset;
    var $_0 = 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis7addJumpEP9JSContextjPjS4_jS4_j["X"] = 1;

function __ZN2js7analyze14ScriptAnalysis10jumpTargetEPKh($this_0_0_val_0_0_val, $this_0_1_val, $pc) {
  var $3 = $pc - $this_0_0_val_0_0_val | 0;
  var $4 = __ZN2js7analyze14ScriptAnalysis10jumpTargetEj($this_0_1_val, $3);
  return $4;
}

function __ZN2js7analyze14ScriptAnalysis12localDefinedEjj($this, $local, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js7analyze14ScriptAnalysis20localHasUseBeforeDefEj($this, $local);
    if ($1) {
      var $12 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (HEAPU32[HEAP32[$this + 32 >> 2] + ($local << 2) >> 2] >>> 0 > $offset >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $12 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $9 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_idx_val, $offset);
    var $10 = __ZN2js7analyze8Bytecode9isDefinedEj($9, $local);
    var $12 = $10;
    __label__ = 4;
    break;
   case 4:
    var $12;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze12UntrapOpcodeD1Ev($this) {
  __ZN2js7analyze12UntrapOpcodeD2Ev($this);
  return;
}

function __ZN2js7analyze14ScriptAnalysis11ranBytecodeEv($this_0_6_val) {
  return ($this_0_6_val & 1) << 24 >> 24 != 0;
}

function __ZN2js7analyze14ScriptAnalysis6failedEv($this_0_4_val) {
  return ($this_0_4_val & 1) << 24 >> 24 != 0;
}

function __ZN2js7analyze14ScriptAnalysis14ensureVariableERNS0_16LifetimeVariableEj($var, $until) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $var + 11 | 0;
    if (HEAP8[$1] << 24 >> 24 < 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$var >> 2] | 0;
    HEAP32[$7 >> 2] = $until;
    var $9 = HEAP8[$1] | -128;
    HEAP8[$1] = $9;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis11slotEscapesEj($this, $slot) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$this + 8 >> 2] >>> 0 > $slot >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = HEAP8[HEAP32[$this + 16 >> 2] + $slot | 0] << 24 >> 24 != 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis16analyzeLifetimesEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $saved = __stackBase__;
    var $savedCount = __stackBase__ + 4;
    var $offset = __stackBase__ + 8;
    var $untrap = __stackBase__ + 12;
    var $1 = __stackBase__ + 20;
    var $untrap7 = __stackBase__ + 24;
    var $2 = __stackBase__ + 32;
    var $this_idx4_val = HEAP8[$this + 20 | 0];
    var $3 = __ZN2js7analyze14ScriptAnalysis11ranBytecodeEv($this_idx4_val);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7analyze14ScriptAnalysis15analyzeBytecodeEP9JSContext($this, $cx);
    var $this_idx5_val = HEAP8[$this + 13 | 0];
    var $5 = __ZN2js7analyze14ScriptAnalysis6failedEv($this_idx5_val);
    if ($5) {
      __label__ = 92;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    var $10 = $this + 8 | 0;
    var $11 = HEAP32[$10 >> 2];
    var $12 = __ZN2js10ArenaArrayINS_7analyze16LifetimeVariableEEEPT_R11JSArenaPoolj($9, $11);
    var $13 = $this + 36 | 0;
    HEAP32[$13 >> 2] = $12;
    if (($12 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 92;
    break;
   case 5:
    var $17 = HEAP32[$10 >> 2];
    __ZN2jsL7PodZeroINS_7analyze16LifetimeVariableEEEvPT_j($12, $17);
    var $18 = $17 << 2;
    var $19 = __ZN9JSContext7calloc_Ej($cx, $18);
    var $20 = $19;
    HEAP32[$saved >> 2] = $20;
    if (($19 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 92;
    break;
   case 7:
    HEAP32[$savedCount >> 2] = 0;
    var $24 = $this | 0;
    var $25 = HEAP32[$24 >> 2];
    var $27 = HEAP32[$25 + 8 >> 2];
    var $28 = $27 - 1 | 0;
    HEAP32[$offset >> 2] = $28;
    var $this_idx2 = $this + 4 | 0;
    var $loop_0_ph = 0;
    var $31 = $25;
    var $30 = $27;
    var $29 = $28;
    __label__ = 8;
    break;
   case 8:
    var $29;
    var $30;
    var $31;
    var $loop_0_ph;
    var $33 = $29;
    __label__ = 9;
    break;
   case 9:
    var $33;
    if ($33 >>> 0 < $30 >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 10:
    var $this_idx2_val = HEAP32[$this_idx2 >> 2];
    var $36 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEj($this_idx2_val, $33);
    if (($36 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $39 = $33 - 1 | 0;
    HEAP32[$offset >> 2] = $39;
    var $33 = $39;
    __label__ = 9;
    break;
   case 12:
    if (($loop_0_ph | 0) == 0) {
      var $52 = $31;
      var $51 = $33;
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if ((HEAP8[$36 + 1 | 0] & 2) << 24 >> 24 == 0) {
      var $52 = $31;
      var $51 = $33;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    HEAP8[$loop_0_ph + 20 | 0] = 1;
    var $52 = HEAP32[$24 >> 2];
    var $51 = HEAP32[$offset >> 2];
    __label__ = 15;
    break;
   case 15:
    var $51;
    var $52;
    var $55 = HEAP32[$52 >> 2] + $51 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $52, $55);
    var $56 = HEAPU8[$55];
    var $57 = $56 & 255;
    if ($56 << 24 >> 24 == -74 || $56 << 24 >> 24 == 109) {
      __label__ = 16;
      break;
    } else {
      var $loop_1 = $loop_0_ph;
      __label__ = 22;
      break;
    }
   case 16:
    var $61 = HEAP32[$36 + 16 >> 2];
    if (($61 | 0) == 0) {
      var $loop_1 = $loop_0_ph;
      __label__ = 22;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $65 = HEAP32[$61 + 8 >> 2];
    var $66 = HEAP32[$10 >> 2];
    if (($66 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      var $i_014 = 0;
      var $68 = $66;
      __label__ = 18;
      break;
    }
   case 18:
    var $68;
    var $i_014;
    var $70 = HEAP32[$13 >> 2] + $i_014 * 12 | 0;
    if ((HEAP32[$70 >> 2] | 0) == 0) {
      var $76 = $68;
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    __ZN2js7analyze14ScriptAnalysis14extendVariableEP9JSContextRNS0_16LifetimeVariableEjj($this, $cx, $70, $51, $65);
    var $76 = HEAP32[$10 >> 2];
    __label__ = 20;
    break;
   case 20:
    var $76;
    var $77 = $i_014 + 1 | 0;
    if ($77 >>> 0 < $76 >>> 0) {
      var $i_014 = $77;
      var $68 = $76;
      __label__ = 18;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $loop_1 = HEAP32[$loop_0_ph >> 2];
    __label__ = 22;
    break;
   case 22:
    var $loop_1;
    var $82 = ($loop_1 | 0) != 0;
    var $83 = $36 | 0;
    if ($82) {
      __label__ = 23;
      break;
    } else {
      var $_pre_phi = $83;
      __label__ = 27;
      break;
    }
   case 23:
    if ((HEAP8[$83] & 1) << 24 >> 24 == 0) {
      var $_pre_phi = $83;
      __label__ = 27;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    if (($51 | 0) == (HEAP32[$loop_1 + 12 >> 2] | 0)) {
      var $_pre_phi = $83;
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $93 = $loop_1 + 16 | 0;
    if ($51 >>> 0 > HEAPU32[$93 >> 2] >>> 0) {
      __label__ = 26;
      break;
    } else {
      var $_pre_phi = $83;
      __label__ = 27;
      break;
    }
   case 26:
    HEAP32[$93 >> 2] = $51;
    var $_pre_phi = $83;
    __label__ = 27;
    break;
   case 27:
    var $_pre_phi;
    if (HEAP8[$_pre_phi] << 24 >> 24 < 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 28:
    var $100 = HEAPU32[$24 >> 2];
    var $_idx_val = HEAP32[$100 + 4 >> 2];
    var $_idx1_val = HEAP8[$100 + 19 | 0];
    var $101 = __ZN8JSScript8trynotesEv($_idx_val, $_idx1_val);
    var $103 = HEAP32[$101 >> 2];
    var $106 = $103 + HEAP32[$101 + 4 >> 2] * 12 | 0;
    var $107 = HEAP32[$offset >> 2];
    var $tn_0 = $103;
    __label__ = 29;
    break;
   case 29:
    var $tn_0;
    if ($tn_0 >>> 0 < $106 >>> 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 30:
    var $115 = HEAP32[$tn_0 + 4 >> 2] + HEAP32[$100 + 32 >> 2] | 0;
    if (($115 + HEAP32[$tn_0 + 8 >> 2] | 0) == ($107 | 0)) {
      __label__ = 31;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 31:
    var $120 = HEAP32[$10 >> 2];
    if (($120 | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $122 = $115 - 1 | 0;
    var $i1_012 = 0;
    var $123 = $120;
    __label__ = 33;
    break;
   case 33:
    var $123;
    var $i1_012;
    var $125 = HEAP32[$13 >> 2] + $i1_012 * 12 | 0;
    if ((HEAP32[$125 >> 2] | 0) == 0) {
      var $131 = $123;
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    __ZN2js7analyze14ScriptAnalysis14ensureVariableERNS0_16LifetimeVariableEj($125, $122);
    var $131 = HEAP32[$10 >> 2];
    __label__ = 35;
    break;
   case 35:
    var $131;
    var $132 = $i1_012 + 1 | 0;
    if ($132 >>> 0 < $131 >>> 0) {
      var $i1_012 = $132;
      var $123 = $131;
      __label__ = 33;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 36:
    var $tn_0 = $tn_0 + 12 | 0;
    __label__ = 29;
    break;
   case 37:
    if (($57 | 0) == 71 || ($57 | 0) == 150 || ($57 | 0) == 70 || ($57 | 0) == 149) {
      __label__ = 38;
      break;
    } else if (($57 | 0) == 134) {
      __label__ = 39;
      break;
    } else if (($57 | 0) == 84 || ($57 | 0) == 216 || ($57 | 0) == 86 || ($57 | 0) == 215 || ($57 | 0) == 65) {
      __label__ = 41;
      break;
    } else if (($57 | 0) == 85 || ($57 | 0) == 87 || ($57 | 0) == 132 || ($57 | 0) == 140 || ($57 | 0) == 223) {
      __label__ = 43;
      break;
    } else if (($57 | 0) == 97 || ($57 | 0) == 98 || ($57 | 0) == 99 || ($57 | 0) == 100 || ($57 | 0) == 101 || ($57 | 0) == 102 || ($57 | 0) == 103 || ($57 | 0) == 104) {
      __label__ = 45;
      break;
    } else if (($57 | 0) == 82 || ($57 | 0) == 58 || ($57 | 0) == 123 || ($57 | 0) == 79 || ($57 | 0) == 108) {
      __label__ = 56;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 38:
    var $136 = HEAPU32[$saved >> 2];
    var $164 = HEAP32[$savedCount >> 2];
    __label__ = 47;
    break;
   case 39:
    var $137 = HEAPU32[$10 >> 2];
    if (($137 | 0) == 0) {
      __label__ = 58;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $139 = HEAP32[$offset >> 2];
    var $i5_07 = 0;
    var $183 = $137;
    __label__ = 52;
    break;
   case 41:
    var $140 = HEAP32[$24 >> 2];
    var $141 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh($140, $55);
    var $142 = __ZN2js7analyze14ScriptAnalysis11slotEscapesEj($this, $141);
    if ($142) {
      __label__ = 58;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $145 = HEAP32[$13 >> 2] + $141 * 12 | 0;
    var $146 = HEAP32[$offset >> 2];
    __ZN2js7analyze14ScriptAnalysis11addVariableEP9JSContextRNS0_16LifetimeVariableEjRPPS4_Rj($this, $cx, $145, $146, $saved, $savedCount);
    __label__ = 58;
    break;
   case 43:
    var $147 = HEAP32[$24 >> 2];
    var $148 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh($147, $55);
    var $149 = __ZN2js7analyze14ScriptAnalysis11slotEscapesEj($this, $148);
    if ($149) {
      __label__ = 58;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $152 = HEAP32[$13 >> 2] + $148 * 12 | 0;
    var $153 = HEAP32[$offset >> 2];
    __ZN2js7analyze14ScriptAnalysis12killVariableEP9JSContextRNS0_16LifetimeVariableEjRPPS4_Rj($this, $cx, $152, $153, $saved, $savedCount);
    __label__ = 58;
    break;
   case 45:
    var $154 = HEAP32[$24 >> 2];
    var $155 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh($154, $55);
    var $156 = __ZN2js7analyze14ScriptAnalysis11slotEscapesEj($this, $155);
    if ($156) {
      __label__ = 58;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $159 = HEAP32[$13 >> 2] + $155 * 12 | 0;
    var $160 = HEAP32[$offset >> 2];
    __ZN2js7analyze14ScriptAnalysis12killVariableEP9JSContextRNS0_16LifetimeVariableEjRPPS4_Rj($this, $cx, $159, $160, $saved, $savedCount);
    var $162 = HEAP32[$13 >> 2] + $155 * 12 | 0;
    __ZN2js7analyze14ScriptAnalysis11addVariableEP9JSContextRNS0_16LifetimeVariableEjRPPS4_Rj($this, $cx, $162, $160, $saved, $savedCount);
    __label__ = 58;
    break;
   case 47:
    var $164;
    if (($164 | 0) == 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    var $167 = HEAP32[$136 >> 2];
    var $171 = HEAP32[$167 + 8 >> 2] & 2147483647;
    HEAP32[$1 >> 2] = $171;
    var $172 = $167 + 4 | 0;
    var $173 = __ZN2js8ArenaNewINS_7analyze8LifetimeEjjPS2_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($9, $offset, $1, $172);
    var $174 = $167 | 0;
    HEAP32[$174 >> 2] = $173;
    if (($173 | 0) == 0) {
      __label__ = 49;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 49:
    var $177 = $136;
    __ZN9JSContext5free_EPv($177);
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 89;
    break;
   case 50:
    HEAP32[$172 >> 2] = 0;
    var $179 = $164 - 1 | 0;
    HEAP32[$savedCount >> 2] = $179;
    var $181 = HEAP32[$136 + ($179 << 2) >> 2];
    HEAP32[$136 >> 2] = $181;
    var $164 = $179;
    __label__ = 47;
    break;
   case 51:
    HEAP32[$savedCount >> 2] = 0;
    __label__ = 58;
    break;
   case 52:
    var $183;
    var $i5_07;
    var $184 = HEAP32[$13 >> 2];
    var $185 = $184 + $i5_07 * 12 + 11 | 0;
    var $186 = HEAP8[$185];
    if ($186 << 24 >> 24 < 0) {
      __label__ = 53;
      break;
    } else {
      var $197 = $183;
      __label__ = 55;
      break;
    }
   case 53:
    if ((HEAP32[HEAP32[$184 + $i5_07 * 12 >> 2] >> 2] | 0) == ($139 | 0)) {
      __label__ = 54;
      break;
    } else {
      var $197 = $183;
      __label__ = 55;
      break;
    }
   case 54:
    var $195 = $186 & 127;
    HEAP8[$185] = $195;
    var $197 = HEAP32[$10 >> 2];
    __label__ = 55;
    break;
   case 55:
    var $197;
    var $198 = $i5_07 + 1 | 0;
    if ($198 >>> 0 < $197 >>> 0) {
      var $i5_07 = $198;
      var $183 = $197;
      __label__ = 52;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 56:
    if ($82) {
      __label__ = 57;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 57:
    HEAP8[$loop_1 + 21 | 0] = 1;
    __label__ = 58;
    break;
   case 58:
    var $205 = HEAP32[_js_CodeSpec + ($57 << 3) + 4 >> 2] & 31;
    if (($205 | 0) == 9 || ($205 | 0) == 1) {
      __label__ = 59;
      break;
    } else {
      var $loop_2 = $loop_1;
      __label__ = 90;
      break;
    }
   case 59:
    var $206 = HEAP32[$24 >> 2];
    var $207 = HEAPU32[$offset >> 2];
    var $208 = __ZN2js7analyzeL12FollowBranchEP9JSContextP8JSScriptj($206, $207);
    if ($82) {
      __label__ = 60;
      break;
    } else {
      var $219 = $207;
      __label__ = 63;
      break;
    }
   case 60:
    var $211 = HEAPU32[$loop_1 + 12 >> 2];
    if (($211 | 0) == ($208 | 0)) {
      __label__ = 61;
      break;
    } else {
      var $219 = $207;
      __label__ = 63;
      break;
    }
   case 61:
    var $214 = $loop_1 + 16 | 0;
    if ($211 >>> 0 > HEAPU32[$214 >> 2] >>> 0) {
      __label__ = 62;
      break;
    } else {
      var $219 = $207;
      __label__ = 63;
      break;
    }
   case 62:
    HEAP32[$214 >> 2] = $211;
    var $219 = HEAP32[$offset >> 2];
    __label__ = 63;
    break;
   case 63:
    var $219;
    if ($208 >>> 0 < $219 >>> 0) {
      __label__ = 65;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    var $221 = HEAP32[$saved >> 2];
    var $i8_0 = 0;
    var $266 = HEAP32[$savedCount >> 2];
    __label__ = 80;
    break;
   case 65:
    if ($82) {
      __label__ = 66;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 66:
    var $225 = HEAPU32[$loop_1 + 12 >> 2];
    var $226 = $loop_1 + 16 | 0;
    if ($225 >>> 0 > HEAPU32[$226 >> 2] >>> 0) {
      __label__ = 67;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 67:
    HEAP32[$226 >> 2] = $225;
    __label__ = 68;
    break;
   case 68:
    var $231 = __ZN2js8ArenaNewINS_7analyze12LoopAnalysisEEEPT_R11JSArenaPool($9);
    if (($231 | 0) == 0) {
      __label__ = 69;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 69:
    var $235 = HEAP32[$saved >> 2];
    __ZN9JSContext5free_EPv($235);
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 89;
    break;
   case 70:
    __ZN2jsL7PodZeroINS_7analyze12LoopAnalysisEEEvPT_($231);
    if ($82) {
      __label__ = 71;
      break;
    } else {
      __label__ = 72;
      break;
    }
   case 71:
    HEAP8[$loop_1 + 21 | 0] = 1;
    __label__ = 72;
    break;
   case 72:
    var $239 = $231 | 0;
    HEAP32[$239 >> 2] = $loop_1;
    var $this_idx3_val = HEAP32[$this_idx2 >> 2];
    var $240 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_idx3_val, $208);
    var $241 = $240 + 16 | 0;
    var $_c = $231;
    HEAP32[$241 >> 2] = $_c;
    var $242 = $231 + 4 | 0;
    HEAP32[$242 >> 2] = $208;
    var $243 = HEAP32[$offset >> 2];
    var $244 = $231 + 8 | 0;
    HEAP32[$244 >> 2] = $243;
    var $245 = $231 + 16 | 0;
    HEAP32[$245 >> 2] = $208;
    if (($208 | 0) == 0) {
      __label__ = 79;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    var $this_idx_val = HEAP32[$this_idx2 >> 2];
    var $entry_0 = $208;
    __label__ = 74;
    break;
   case 74:
    var $entry_0;
    var $247 = $entry_0 - 1 | 0;
    var $248 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEj($this_idx_val, $247);
    if (($248 | 0) == 0) {
      var $entry_0 = $247;
      __label__ = 74;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 75:
    var $251 = HEAP32[$24 >> 2];
    var $254 = HEAP32[$251 >> 2] + $247 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap7, $251, $254);
    var $255 = HEAP8[$254];
    if ($255 << 24 >> 24 == 6 || $255 << 24 >> 24 == -115) {
      __label__ = 76;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 76:
    var $257 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($255, $254);
    var $258 = $257 + $247 | 0;
    var $259 = $231 + 12 | 0;
    HEAP32[$259 >> 2] = $258;
    __label__ = 78;
    break;
   case 77:
    var $261 = $231 + 12 | 0;
    HEAP32[$261 >> 2] = $208;
    __label__ = 78;
    break;
   case 78:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap7);
    var $loop_2 = $231;
    __label__ = 90;
    break;
   case 79:
    var $264 = $231 + 12 | 0;
    HEAP32[$264 >> 2] = 0;
    var $loop_2 = $231;
    __label__ = 90;
    break;
   case 80:
    var $266;
    var $i8_0;
    if ($i8_0 >>> 0 < $266 >>> 0) {
      __label__ = 81;
      break;
    } else {
      var $loop_2 = $loop_1;
      __label__ = 90;
      break;
    }
   case 81:
    var $269 = $221 + ($i8_0 << 2) | 0;
    var $270 = HEAPU32[$269 >> 2];
    var $271 = __ZNK2js7analyze16LifetimeVariable4liveEj($270, $208);
    if (($271 | 0) == 0) {
      __label__ = 85;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 82:
    var $277 = HEAP32[$270 + 8 >> 2] & 2147483647;
    HEAP32[$2 >> 2] = $277;
    var $278 = $270 + 4 | 0;
    var $279 = __ZN2js8ArenaNewINS_7analyze8LifetimeEjjPS2_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($9, $offset, $2, $278);
    var $280 = $270 | 0;
    HEAP32[$280 >> 2] = $279;
    if (($279 | 0) == 0) {
      __label__ = 83;
      break;
    } else {
      __label__ = 84;
      break;
    }
   case 83:
    var $283 = $221;
    __ZN9JSContext5free_EPv($283);
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 89;
    break;
   case 84:
    HEAP32[$278 >> 2] = 0;
    var $285 = $266 - 1 | 0;
    HEAP32[$savedCount >> 2] = $285;
    var $287 = HEAP32[$221 + ($285 << 2) >> 2];
    HEAP32[$269 >> 2] = $287;
    var $i8_1 = $i8_0 - 1 | 0;
    var $302 = $285;
    __label__ = 88;
    break;
   case 85:
    if ($82) {
      __label__ = 86;
      break;
    } else {
      var $i8_1 = $i8_0;
      var $302 = $266;
      __label__ = 88;
      break;
    }
   case 86:
    var $292 = $270 + 8 | 0;
    var $293 = HEAP32[$292 >> 2];
    if (($293 & 2147483647 | 0) == 0) {
      __label__ = 87;
      break;
    } else {
      var $i8_1 = $i8_0;
      var $302 = $266;
      __label__ = 88;
      break;
    }
   case 87:
    var $300 = HEAP32[$offset >> 2] & 2147483647 | $293 & -2147483648;
    HEAP32[$292 >> 2] = $300;
    var $i8_1 = $i8_0;
    var $302 = $266;
    __label__ = 88;
    break;
   case 88:
    var $302;
    var $i8_1;
    var $i8_0 = $i8_1 + 1 | 0;
    var $266 = $302;
    __label__ = 80;
    break;
   case 89:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    __label__ = 92;
    break;
   case 90:
    var $loop_2;
    var $305 = HEAP32[$offset >> 2] - 1 | 0;
    HEAP32[$offset >> 2] = $305;
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_pre = HEAPU32[$24 >> 2];
    var $loop_0_ph = $loop_2;
    var $31 = $_pre;
    var $30 = HEAP32[$_pre + 8 >> 2];
    var $29 = $305;
    __label__ = 8;
    break;
   case 91:
    var $308 = HEAP32[$saved >> 2];
    __ZN9JSContext5free_EPv($308);
    HEAP8[$this + 22 | 0] = 1;
    __label__ = 92;
    break;
   case 92:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis16analyzeLifetimesEP9JSContext["X"] = 1;

function __ZN2js10ArenaArrayINS_7analyze16LifetimeVariableEEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + $count * 12 & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodZeroINS_7analyze16LifetimeVariableEEEvPT_j($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem * 12 | 0;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js7analyze14ScriptAnalysis14extendVariableEP9JSContextRNS0_16LifetimeVariableEjj($this, $cx, $var, $start, $end) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $savedEnd = __stackBase__;
    var $1 = __stackBase__ + 4;
    if (HEAP8[$var + 11 | 0] << 24 >> 24 < 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $var | 0;
    var $8 = HEAP32[$6 >> 2] | 0;
    HEAP32[$8 >> 2] = $start;
    var $9 = $cx + 56 | 0;
    var $segment_0_in = $6;
    __label__ = 3;
    break;
   case 3:
    var $segment_0_in;
    var $segment_0 = HEAPU32[$segment_0_in >> 2];
    if (($segment_0 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (HEAPU32[$segment_0 >> 2] >>> 0 < $end >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 5:
    var $16 = $segment_0 + 8 | 0;
    var $17 = HEAPU32[$16 >> 2];
    HEAP32[$savedEnd >> 2] = $17;
    var $18 = $segment_0 + 16 | 0;
    var $19 = HEAP32[$18 >> 2];
    if (($19 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (HEAPU32[$19 >> 2] >>> 0 < $end >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $32 = $17;
    var $31 = HEAP32[$segment_0 + 4 >> 2];
    __label__ = 10;
    break;
   case 8:
    var $27 = HEAPU32[$segment_0 + 4 >> 2];
    if ($27 >>> 0 < $end >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 9:
    HEAP32[$savedEnd >> 2] = $end;
    var $32 = $end;
    var $31 = $27;
    __label__ = 10;
    break;
   case 10:
    var $31;
    var $32;
    var $33 = $segment_0 + 4 | 0;
    if ($32 >>> 0 > $31 >>> 0) {
      __label__ = 11;
      break;
    } else {
      var $segment_0_in = $18;
      __label__ = 3;
      break;
    }
   case 11:
    var $37 = HEAP32[$9 >> 2] + 344 | 0;
    HEAP32[$1 >> 2] = 0;
    var $38 = __ZN2js8ArenaNewINS_7analyze8LifetimeEjiPS2_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($37, $savedEnd, $1, $18);
    if (($38 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 16;
    break;
   case 13:
    var $42 = HEAP32[$33 >> 2];
    var $43 = $38 | 0;
    HEAP32[$43 >> 2] = $42;
    HEAP8[$38 + 12 | 0] = 1;
    var $45 = HEAPU32[$16 >> 2];
    if ($45 >>> 0 > $end >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $48 = $38 + 8 | 0;
    HEAP32[$48 >> 2] = $45;
    __label__ = 15;
    break;
   case 15:
    HEAP32[$16 >> 2] = 0;
    HEAP32[$18 >> 2] = $38;
    var $segment_0_in = $38 + 16 | 0;
    __label__ = 3;
    break;
   case 16:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis14extendVariableEP9JSContextRNS0_16LifetimeVariableEjj["X"] = 1;

function __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh($script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU8[$pc] & 255;
    if (($2 | 0) == 84 || ($2 | 0) == 216 || ($2 | 0) == 85 || ($2 | 0) == 97 || ($2 | 0) == 98 || ($2 | 0) == 99 || ($2 | 0) == 100) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 86 || ($2 | 0) == 215 || ($2 | 0) == 87 || ($2 | 0) == 132 || ($2 | 0) == 140 || ($2 | 0) == 223 || ($2 | 0) == 101 || ($2 | 0) == 102 || ($2 | 0) == 103 || ($2 | 0) == 104) {
      __label__ = 3;
      break;
    } else if (($2 | 0) == 65) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $11 = (HEAPU8[$pc + 1 | 0] & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255;
    var $12 = __ZN2js7analyzeL7ArgSlotEj($11);
    var $_0 = $12;
    __label__ = 5;
    break;
   case 3:
    var $21 = (HEAPU8[$pc + 1 | 0] & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255;
    var $22 = __ZN2js7analyzeL9LocalSlotEP8JSScriptj($script, $21);
    var $_0 = $22;
    __label__ = 5;
    break;
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis11addVariableEP9JSContextRNS0_16LifetimeVariableEjRPPS4_Rj($this, $cx, $var, $offset, $saved, $savedCount) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $offset;
    var $3 = $var | 0;
    var $4 = HEAP32[$3 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (HEAP8[$var + 11 | 0] << 24 >> 24 < 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = $4 | 0;
    HEAP32[$11 >> 2] = $offset;
    __label__ = 13;
    break;
   case 4:
    var $13 = $var + 4 | 0;
    if ((HEAP32[$13 >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = HEAPU32[$savedCount >> 2];
    var $i_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $i_0;
    if ($i_0 >>> 0 < $16 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    if ((HEAP32[HEAP32[$saved >> 2] + ($i_0 << 2) >> 2] | 0) == ($var | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $25 = $16 - 1 | 0;
    HEAP32[$savedCount >> 2] = $25;
    var $26 = HEAP32[$saved >> 2];
    var $28 = HEAP32[$26 + ($25 << 2) >> 2];
    var $29 = $26 + ($i_0 << 2) | 0;
    HEAP32[$29 >> 2] = $28;
    __label__ = 10;
    break;
   case 9:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 6;
    break;
   case 10:
    var $34 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    var $38 = HEAP32[$var + 8 >> 2] & 2147483647;
    HEAP32[$2 >> 2] = $38;
    var $39 = __ZN2js8ArenaNewINS_7analyze8LifetimeEjjPS2_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($34, $1, $2, $13);
    HEAP32[$3 >> 2] = $39;
    if (($39 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 13;
    break;
   case 12:
    HEAP32[$13 >> 2] = 0;
    __label__ = 13;
    break;
   case 13:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis11addVariableEP9JSContextRNS0_16LifetimeVariableEjRPPS4_Rj["X"] = 1;

function __ZNK2js7analyze16LifetimeVariable4liveEj($this, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (HEAPU32[$2 + 4 >> 2] >>> 0 < $offset >>> 0) {
      var $segment_0 = $2;
      __label__ = 4;
      break;
    } else {
      var $_0 = $2;
      __label__ = 8;
      break;
    }
   case 3:
    var $segment_0 = HEAP32[$this + 4 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $segment_0;
    if (($segment_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (HEAPU32[$segment_0 >> 2] >>> 0 > $offset >>> 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (HEAPU32[$segment_0 + 4 >> 2] >>> 0 < $offset >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = $segment_0;
      __label__ = 8;
      break;
    }
   case 7:
    var $segment_0 = HEAP32[$segment_0 + 16 >> 2];
    __label__ = 4;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis12killVariableEP9JSContextRNS0_16LifetimeVariableEjRPPS4_Rj($this, $cx, $var, $offset, $saved, $savedCount) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $offset;
    var $3 = $var | 0;
    var $4 = HEAP32[$3 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $7 = $var + 4 | 0;
    if ((HEAP32[$7 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = HEAP32[$savedCount >> 2];
    var $12 = $11 + 1 | 0;
    HEAP32[$savedCount >> 2] = $12;
    var $14 = HEAP32[$saved >> 2] + ($11 << 2) | 0;
    HEAP32[$14 >> 2] = $var;
    __label__ = 4;
    break;
   case 4:
    var $18 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    var $20 = $var + 8 | 0;
    var $22 = HEAP32[$20 >> 2] & 2147483647;
    HEAP32[$2 >> 2] = $22;
    var $23 = __ZN2js8ArenaNewINS_7analyze8LifetimeEjjPS2_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($18, $1, $2, $7);
    HEAP32[$7 >> 2] = $23;
    if (($23 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 9;
    break;
   case 6:
    HEAP8[$23 + 13 | 0] = 1;
    var $29 = HEAP32[$20 >> 2] & -2147483648;
    HEAP32[$20 >> 2] = $29;
    __label__ = 9;
    break;
   case 7:
    if (HEAP8[$var + 11 | 0] << 24 >> 24 < 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $35 = $4 | 0;
    HEAP32[$35 >> 2] = $offset;
    HEAP8[HEAP32[$3 >> 2] + 13 | 0] = 1;
    var $38 = HEAP32[$3 >> 2];
    HEAP32[$var + 4 >> 2] = $38;
    var $41 = $var + 8 | 0;
    var $43 = HEAP32[$41 >> 2] & -2147483648;
    HEAP32[$41 >> 2] = $43;
    HEAP32[$3 >> 2] = 0;
    var $44 = HEAP32[$savedCount >> 2];
    var $45 = $44 + 1 | 0;
    HEAP32[$savedCount >> 2] = $45;
    var $47 = HEAP32[$saved >> 2] + ($44 << 2) | 0;
    HEAP32[$47 >> 2] = $var;
    __label__ = 9;
    break;
   case 9:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis12killVariableEP9JSContextRNS0_16LifetimeVariableEjRPPS4_Rj["X"] = 1;

function __ZN2js8ArenaNewINS_7analyze8LifetimeEjjPS2_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($pool, $a, $b, $c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 20 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $28 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    var $26 = HEAP32[$c >> 2];
    __ZN2js7analyze8LifetimeC1EjjPS1_($23, $24, $25, $26);
    var $28 = $23;
    __label__ = 6;
    break;
   case 6:
    var $28;
    return $28;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyzeL12FollowBranchEP9JSContextP8JSScriptj($script, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $untrap = __stackBase__;
    var $2 = HEAP32[$script >> 2];
    var $3 = $2 + $offset | 0;
    var $_val1 = HEAP8[$3];
    var $4 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($_val1, $3);
    var $uadd = _llvm_uadd_with_overflow_i32($4, $offset);
    var $5 = $uadd.f0;
    var $6 = $uadd.f1;
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $_1 = $5;
      __label__ = 5;
      break;
    }
   case 2:
    var $8 = $2 + $5 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $script, $8);
    var $9 = HEAP8[$8];
    if ($9 << 24 >> 24 == -115 || $9 << 24 >> 24 == 6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($9, $8);
    var $11 = $10 + $5 | 0;
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_1 = $11;
    __label__ = 5;
    break;
   case 4:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_1 = $5;
    __label__ = 5;
    break;
   case 5:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8ArenaNewINS_7analyze12LoopAnalysisEEEPT_R11JSArenaPool($pool) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 24 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $26 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = $_p_0;
    HEAP32[$24 >> 2] = 0;
    HEAP32[$24 + 4 >> 2] = 0;
    HEAP32[$24 + 8 >> 2] = 0;
    HEAP32[$24 + 12 >> 2] = 0;
    HEAP32[$24 + 16 >> 2] = 0;
    HEAP32[$24 + 20 >> 2] = 0;
    var $26 = $_p_0;
    __label__ = 6;
    break;
   case 6:
    var $26;
    return $26;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodZeroINS_7analyze12LoopAnalysisEEEvPT_($t) {
  var $1 = $t;
  _memset($1, 0, 24, 1);
  return;
}

function __ZN2js7analyze14ScriptAnalysis12ranLifetimesEv($this_0_8_val) {
  return ($this_0_8_val & 1) << 24 >> 24 != 0;
}

function __ZN2js7analyze14ScriptAnalysis10analyzeSSAEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $free = __stackBase__;
    var $branchTargets = __stackBase__ + 8;
    var $1 = __stackBase__ + 32;
    var $untrap = __stackBase__ + 36;
    var $ov = __stackBase__ + 44;
    var $ov2 = __stackBase__ + 52;
    var $2 = __stackBase__ + 60;
    var $this_idx7_val = HEAP8[$this + 22 | 0];
    var $3 = __ZN2js7analyze14ScriptAnalysis12ranLifetimesEv($this_idx7_val);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7analyze14ScriptAnalysis16analyzeLifetimesEP9JSContext($this, $cx);
    var $this_idx8_val = HEAP8[$this + 13 | 0];
    var $5 = __ZN2js7analyze14ScriptAnalysis6failedEv($this_idx8_val);
    if ($5) {
      __label__ = 115;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $cx + 56 | 0;
    var $9 = HEAP32[$7 >> 2] + 344 | 0;
    var $10 = $this | 0;
    var $11 = HEAPU32[$10 >> 2];
    var $18 = $this + 8 | 0;
    var $22 = HEAP32[$18 >> 2] + (HEAPU16[$11 + 44 >> 1] & 65535) - (HEAPU16[$11 + 14 >> 1] & 65535) << 3;
    var $23 = __ZN9JSContext7calloc_Ej($cx, $22);
    var $24 = $23;
    if (($23 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 115;
    break;
   case 5:
    __ZZN2js7analyze14ScriptAnalysis10analyzeSSAEP9JSContextEN13FreeSSAValuesC2ES3_PNS0_8SSAValueE($free, $cx, $24);
    var $28 = HEAPU32[$18 >> 2];
    var $29 = __ZN2js7analyzeL7ArgSlotEj(0);
    if ($29 >>> 0 < $28 >>> 0) {
      var $slot_067 = $29;
      var $31 = $28;
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $31;
    var $slot_067;
    var $32 = __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $slot_067);
    if ($32) {
      __label__ = 7;
      break;
    } else {
      var $36 = $31;
      __label__ = 8;
      break;
    }
   case 7:
    var $34 = $24 + ($slot_067 << 3) | 0;
    __ZN2js7analyze8SSAValue11initInitialEj($34, $slot_067);
    var $36 = HEAP32[$18 >> 2];
    __label__ = 8;
    break;
   case 8:
    var $36;
    var $37 = $slot_067 + 1 | 0;
    if ($37 >>> 0 < $36 >>> 0) {
      var $slot_067 = $37;
      var $31 = $36;
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
    var $_0_val = HEAP32[$1 >> 2];
    __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEC1ES1_($branchTargets, $_0_val);
    var $39 = $28 - 1 | 0;
    var $40 = $28 - 2 | 0;
    var $41 = $28 - 3 | 0;
    var $42 = $28 - 4 | 0;
    var $43 = $ov;
    var $44 = $ov2;
    var $this_idx2 = $this + 4 | 0;
    var $this_idx15 = $this + 36 | 0;
    var $stackDepth_0 = 0;
    var $offset_0 = 0;
    __label__ = 10;
    break;
   case 10:
    var $offset_0;
    var $stackDepth_0;
    var $46 = HEAPU32[$10 >> 2];
    if ($offset_0 >>> 0 < HEAPU32[$46 + 8 >> 2] >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 11:
    var $52 = HEAPU32[$46 >> 2];
    var $53 = $52 + $offset_0 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $46, $53);
    var $54 = HEAPU8[$53];
    var $55 = $54 & 255;
    var $56 = __ZN2js7analyzeL17GetBytecodeLengthEPh($53);
    var $57 = $56 + $offset_0 | 0;
    var $this_idx2_val = HEAP32[$this_idx2 >> 2];
    var $this_idx_val_idx_val = HEAP32[HEAP32[$10 >> 2] >> 2];
    var $58 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEPKh($this_idx_val_idx_val, $this_idx2_val, $53);
    if (($58 | 0) == 0) {
      var $stackDepth_1_ph35 = $stackDepth_0;
      __label__ = 112;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $62 = HEAPU32[$58 + 4 >> 2];
    if ($62 >>> 0 > $stackDepth_0 >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $65 = $24 + ($stackDepth_0 + $28 << 3) | 0;
    var $66 = $62 - $stackDepth_0 | 0;
    __ZN2jsL7PodZeroINS_7analyze8SSAValueEEEvPT_j($65, $66);
    __label__ = 14;
    break;
   case 14:
    if ($54 << 24 >> 24 == -74 || $54 << 24 >> 24 == 109) {
      __label__ = 15;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 15:
    var $70 = $58 + 16 | 0;
    if ((HEAP32[$70 >> 2] | 0) == 0) {
      __label__ = 43;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $74 = $58 + 32 | 0;
    var $75 = $74;
    if ((HEAP32[$75 >> 2] | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    __ZN2js7analyze14ScriptAnalysis18removeBranchTargetERNS_6VectorIjLj0ENS_15TempAllocPolicyEEEj($branchTargets, $offset_0);
    __label__ = 18;
    break;
   case 18:
    var $79 = $58 | 0;
    var $i_0 = 0;
    __label__ = 21;
    break;
   case 19:
    var $81 = __ZN9JSContext4new_IN2js6VectorINS1_7analyze9SlotValueELj0ENS1_15TempAllocPolicyEEEPS_EEPT_T0_($cx, $cx);
    var $82 = $74 | 0;
    HEAP32[$82 >> 2] = $81;
    if (($81 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 20:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 111;
    break;
   case 21:
    var $i_0;
    var $86 = HEAPU32[$75 >> 2];
    var $_idx11_val = HEAP32[$86 + 8 >> 2];
    var $87 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6lengthEv($_idx11_val);
    if ($i_0 >>> 0 < $87 >>> 0) {
      __label__ = 22;
      break;
    } else {
      var $slot1_0 = $29;
      __label__ = 31;
      break;
    }
   case 22:
    var $_idx13_val = HEAP32[$86 + 4 >> 2];
    var $90 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEixEj($_idx13_val, $i_0);
    var $91 = $90 | 0;
    var $92 = HEAPU32[$91 >> 2];
    if ($92 >>> 0 < HEAPU32[$18 >> 2] >>> 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 23:
    var $this_idx15_val = HEAP32[$this_idx15 >> 2];
    var $96 = __ZN2js7analyze14ScriptAnalysis8livenessEj($this_idx15_val, $92);
    var $97 = HEAP32[$70 >> 2];
    var $_idx18_val = HEAP32[$97 + 4 >> 2];
    var $_idx19_val = HEAP32[$97 + 8 >> 2];
    var $98 = __ZNK2js7analyze16LifetimeVariable10firstWriteEPNS0_12LoopAnalysisE($96, $_idx18_val, $_idx19_val);
    if (($98 | 0) == -1) {
      __label__ = 28;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $101 = $90 + 4 | 0;
    var $102 = __ZNK2js7analyze8SSAValue4kindEv($101);
    if (($102 | 0) == 3) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    var $105 = __ZNK2js7analyze8SSAValue9phiOffsetEv($101);
    if ($105 >>> 0 < $offset_0 >>> 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 26:
    var $108 = $101;
    var $st$1$0 = $108 | 0;
    var $109$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $108 + 4 | 0;
    var $109$1 = HEAP32[$st$1$1 >> 2];
    var $st$5$0 = $43 | 0;
    HEAP32[$st$5$0 >> 2] = $109$0;
    var $st$5$1 = $43 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $109$1;
    var $110 = __ZN2js7analyze14ScriptAnalysis7makePhiEP9JSContextjjPNS0_8SSAValueE($this, $cx, $92, $offset_0, $ov);
    if ($110) {
      __label__ = 27;
      break;
    } else {
      __label__ = 111;
      break;
    }
   case 27:
    __ZN2js7analyze14ScriptAnalysis9insertPhiEP9JSContextRNS0_8SSAValueERKS4_($this, $cx, $ov, $101);
    var $st$1$0 = $43 | 0;
    var $112$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $43 + 4 | 0;
    var $112$1 = HEAP32[$st$1$1 >> 2];
    var $st$5$0 = $108 | 0;
    HEAP32[$st$5$0 >> 2] = $112$0;
    var $st$5$1 = $108 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $112$1;
    __label__ = 28;
    break;
   case 28:
    if ((HEAP8[$79] & 12) << 24 >> 24 == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $119 = $24 + (HEAP32[$91 >> 2] << 3) | 0;
    __ZN2js7analyze14ScriptAnalysis10mergeValueEP9JSContextjRKNS0_8SSAValueEPNS0_9SlotValueE($this, $cx, $offset_0, $119, $90);
    __label__ = 30;
    break;
   case 30:
    var $120 = HEAP32[$91 >> 2];
    var $121 = $24 + ($120 << 3) | 0;
    __ZN2js7analyze14ScriptAnalysis17mergeBranchTargetEP9JSContextRKNS0_8SSAValueEjRKNS_6VectorIjLj0ENS_15TempAllocPolicyEEE($this, $cx, $121, $120, $branchTargets);
    var $125 = $90 + 4 | 0;
    var $126 = $24 + (HEAP32[$91 >> 2] << 3) | 0;
    var $st$8$0 = $125 | 0;
    var $127$0 = HEAP32[$st$8$0 >> 2];
    var $st$8$1 = $125 + 4 | 0;
    var $127$1 = HEAP32[$st$8$1 >> 2];
    var $st$12$0 = $126 | 0;
    HEAP32[$st$12$0 >> 2] = $127$0;
    var $st$12$1 = $126 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $127$1;
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 21;
    break;
   case 31:
    var $slot1_0;
    var $129 = HEAPU32[$18 >> 2];
    if ($slot1_0 >>> 0 < ($129 + $62 | 0) >>> 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 32:
    if ($slot1_0 >>> 0 < $129 >>> 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 33:
    var $135 = __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $slot1_0);
    if ($135) {
      __label__ = 34;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 34:
    var $this_idx14_val = HEAP32[$this_idx15 >> 2];
    var $137 = __ZN2js7analyze14ScriptAnalysis8livenessEj($this_idx14_val, $slot1_0);
    var $138 = HEAP32[$70 >> 2];
    var $_idx16_val = HEAP32[$138 + 4 >> 2];
    var $_idx17_val = HEAP32[$138 + 8 >> 2];
    var $139 = __ZNK2js7analyze16LifetimeVariable10firstWriteEPNS0_12LoopAnalysisE($137, $_idx16_val, $_idx17_val);
    if (($139 | 0) == -1) {
      __label__ = 42;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $142 = $24 + ($slot1_0 << 3) | 0;
    var $143 = __ZNK2js7analyze8SSAValue4kindEv($142);
    if (($143 | 0) == 3) {
      __label__ = 36;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 36:
    var $146 = __ZNK2js7analyze8SSAValue9phiOffsetEv($142);
    if (($146 | 0) == ($offset_0 | 0)) {
      __label__ = 42;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $149 = __ZN2js7analyze14ScriptAnalysis7makePhiEP9JSContextjjPNS0_8SSAValueE($this, $cx, $slot1_0, $offset_0, $ov2);
    if ($149) {
      __label__ = 38;
      break;
    } else {
      __label__ = 111;
      break;
    }
   case 38:
    if ((HEAP8[$79] & 12) << 24 >> 24 == 0) {
      __label__ = 40;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    __ZN2js7analyze14ScriptAnalysis9insertPhiEP9JSContextRNS0_8SSAValueERKS4_($this, $cx, $ov2, $142);
    __label__ = 40;
    break;
   case 40:
    __ZN2js7analyze14ScriptAnalysis17mergeBranchTargetEP9JSContextRKNS0_8SSAValueEjRKNS_6VectorIjLj0ENS_15TempAllocPolicyEEE($this, $cx, $142, $slot1_0, $branchTargets);
    var $156 = $142;
    var $157$0 = HEAP32[$44 >> 2];
    var $157$1 = HEAP32[$44 + 4 >> 2];
    var $st$6$0 = $156 | 0;
    HEAP32[$st$6$0 >> 2] = $157$0;
    var $st$6$1 = $156 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $157$1;
    var $158 = HEAP32[$75 >> 2];
    __ZN2js7analyze9SlotValueC1EjRKNS0_8SSAValueE($2, $slot1_0, $ov2);
    var $159 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($158, $2);
    if ($159) {
      __label__ = 42;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 111;
    break;
   case 42:
    var $slot1_0 = $slot1_0 + 1 | 0;
    __label__ = 31;
    break;
   case 43:
    var $165 = $58 + 32 | 0;
    if ((HEAP32[$165 >> 2] | 0) == 0) {
      __label__ = 50;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    __ZN2js7analyze14ScriptAnalysis18removeBranchTargetERNS_6VectorIjLj0ENS_15TempAllocPolicyEEEj($branchTargets, $offset_0);
    var $169 = HEAP32[$165 >> 2];
    var $_idx10 = $169 + 8 | 0;
    var $_idx10_val = HEAP32[$_idx10 >> 2];
    var $170 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6lengthEv($_idx10_val);
    if (($170 | 0) == 0) {
      __label__ = 49;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $172 = $58 | 0;
    var $_idx12 = $169 + 4 | 0;
    var $i4_055 = 0;
    __label__ = 46;
    break;
   case 46:
    var $i4_055;
    var $_idx12_val = HEAP32[$_idx12 >> 2];
    var $174 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEixEj($_idx12_val, $i4_055);
    var $_pre42 = $174 | 0;
    if ((HEAP8[$172] & 12) << 24 >> 24 == 0) {
      __label__ = 48;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $180 = $24 + (HEAP32[$_pre42 >> 2] << 3) | 0;
    __ZN2js7analyze14ScriptAnalysis10mergeValueEP9JSContextjRKNS0_8SSAValueEPNS0_9SlotValueE($this, $cx, $offset_0, $180, $174);
    __label__ = 48;
    break;
   case 48:
    var $181 = HEAP32[$_pre42 >> 2];
    var $182 = $24 + ($181 << 3) | 0;
    __ZN2js7analyze14ScriptAnalysis17mergeBranchTargetEP9JSContextRKNS0_8SSAValueEjRKNS_6VectorIjLj0ENS_15TempAllocPolicyEEE($this, $cx, $182, $181, $branchTargets);
    var $186 = $174 + 4 | 0;
    var $187 = $24 + (HEAP32[$_pre42 >> 2] << 3) | 0;
    var $st$8$0 = $186 | 0;
    var $188$0 = HEAP32[$st$8$0 >> 2];
    var $st$8$1 = $186 + 4 | 0;
    var $188$1 = HEAP32[$st$8$1 >> 2];
    var $st$12$0 = $187 | 0;
    HEAP32[$st$12$0 >> 2] = $188$0;
    var $st$12$1 = $187 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $188$1;
    var $189 = $i4_055 + 1 | 0;
    var $_idx9_val = HEAP32[$_idx10 >> 2];
    var $190 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6lengthEv($_idx9_val);
    if ($189 >>> 0 < $190 >>> 0) {
      var $i4_055 = $189;
      __label__ = 46;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    __ZN2js7analyze14ScriptAnalysis15freezeNewValuesEP9JSContextj($this, $cx, $offset_0);
    __label__ = 50;
    break;
   case 50:
    var $193 = HEAPU32[_js_CodeSpec + ($55 << 3) + 4 >> 2];
    if (($193 & 134217728 | 0) == 0) {
      __label__ = 51;
      break;
    } else {
      var $stackDepth_1_ph35 = $62;
      __label__ = 112;
      break;
    }
   case 51:
    var $197 = HEAP32[$10 >> 2];
    var $_idx3_val = HEAP32[$197 >> 2];
    var $198 = __ZN2js7analyzeL11GetUseCountEP8JSScriptj($_idx3_val, $offset_0);
    var $199 = __ZN2js7analyzeL11GetDefCountEP8JSScriptj($197, $offset_0);
    var $_val21 = HEAP8[$53];
    var $200 = __ZN2js7analyzeL11ExtendedUseEPh($_val21);
    var $201 = $200 & 1;
    var $202 = $201 + $198 | 0;
    if (($202 | 0) == 0) {
      __label__ = 68;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 52:
    var $205 = __ZN2js10ArenaArrayINS_7analyze8SSAValueEEEPT_R11JSArenaPoolj($9, $202);
    var $206 = $58 + 24 | 0;
    HEAP32[$206 >> 2] = $205;
    if (($205 | 0) == 0) {
      __label__ = 55;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    if (($198 | 0) == 0) {
      __label__ = 58;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    var $209 = $39 + $62 | 0;
    var $i6_049 = 0;
    var $212 = $205;
    __label__ = 56;
    break;
   case 55:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 111;
    break;
   case 56:
    var $212;
    var $i6_049;
    var $213 = $24 + ($209 - $i6_049 << 3) | 0;
    var $215 = $213;
    var $216 = $212 + ($i6_049 << 3) | 0;
    var $st$7$0 = $215 | 0;
    var $217$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $215 + 4 | 0;
    var $217$1 = HEAP32[$st$7$1 >> 2];
    var $st$11$0 = $216 | 0;
    HEAP32[$st$11$0 >> 2] = $217$0;
    var $st$11$1 = $216 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $217$1;
    __ZN2js7analyze8SSAValue5clearEv($213);
    var $218 = $i6_049 + 1 | 0;
    if (($218 | 0) == ($198 | 0)) {
      __label__ = 58;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    var $i6_049 = $218;
    var $212 = HEAP32[$206 >> 2];
    __label__ = 56;
    break;
   case 58:
    if ($202 >>> 0 > $198 >>> 0) {
      __label__ = 59;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 59:
    var $221 = HEAP32[$10 >> 2];
    var $222 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh($221, $53);
    var $223 = __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $222);
    var $225 = HEAP32[$206 >> 2] + ($198 << 3) | 0;
    if ($223) {
      __label__ = 60;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 60:
    var $228 = $24 + ($222 << 3) | 0;
    var $229 = $225;
    var $230$0 = HEAP32[$228 >> 2];
    var $230$1 = HEAP32[$228 + 4 >> 2];
    var $st$7$0 = $229 | 0;
    HEAP32[$st$7$0 >> 2] = $230$0;
    var $st$7$1 = $229 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $230$1;
    __label__ = 62;
    break;
   case 61:
    __ZN2js7analyze8SSAValue5clearEv($225);
    __label__ = 62;
    break;
   case 62:
    var $234 = HEAP32[$7 >> 2] + 344 | 0;
    var $235 = __ZN2js10ArenaArrayINS_7analyze11SSAUseChainEEEPT_R11JSArenaPoolj($234, $202);
    if (($235 | 0) == 0) {
      __label__ = 63;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 63:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 111;
    break;
   case 64:
    __ZN2jsL7PodZeroINS_7analyze11SSAUseChainEEEvPT_j($235, $202);
    var $238 = $offset_0 << 1;
    var $239 = $198 + $201 | 0;
    var $i9_052 = 0;
    __label__ = 65;
    break;
   case 65:
    var $i9_052;
    var $241 = HEAP32[$206 >> 2] + ($i9_052 << 3) | 0;
    var $242 = __ZN2js7analyze14ScriptAnalysis13trackUseChainERKNS0_8SSAValueE($241);
    if ($242) {
      __label__ = 66;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 66:
    var $244 = __ZN2js7analyze14ScriptAnalysis8useChainERKNS0_8SSAValueE($this, $241);
    var $245 = $235 + $i9_052 * 12 | 0;
    var $246 = $245 | 0;
    var $248 = HEAP8[$246] | 1;
    HEAP8[$246] = $248;
    var $249 = $245;
    var $252 = HEAP32[$249 >> 2] & 1 | $238;
    HEAP32[$249 >> 2] = $252;
    var $253 = $235 + $i9_052 * 12 + 4 | 0;
    HEAP32[$253 >> 2] = $i9_052;
    var $254 = HEAP32[$244 >> 2];
    var $255 = $235 + $i9_052 * 12 + 8 | 0;
    HEAP32[$255 >> 2] = $254;
    HEAP32[$244 >> 2] = $245;
    __label__ = 67;
    break;
   case 67:
    var $257 = $i9_052 + 1 | 0;
    if (($257 | 0) == ($239 | 0)) {
      __label__ = 68;
      break;
    } else {
      var $i9_052 = $257;
      __label__ = 65;
      break;
    }
   case 68:
    var $258 = $62 - $198 | 0;
    if (($199 | 0) == 0) {
      __label__ = 71;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 69:
    var $260 = $258 + $28 | 0;
    var $i11_063 = 0;
    __label__ = 70;
    break;
   case 70:
    var $i11_063;
    var $262 = $24 + ($260 + $i11_063 << 3) | 0;
    __ZN2js7analyze8SSAValue10initPushedEjj($262, $offset_0, $i11_063);
    var $263 = $i11_063 + 1 | 0;
    if (($263 | 0) == ($199 | 0)) {
      __label__ = 71;
      break;
    } else {
      var $i11_063 = $263;
      __label__ = 70;
      break;
    }
   case 71:
    var $_val20 = HEAP8[$53];
    var $264 = __ZN2js7analyzeL11ExtendedDefEPh($_val20);
    var $266 = ($264 & 1) + $199 | 0;
    if (($266 | 0) == 0) {
      __label__ = 75;
      break;
    } else {
      __label__ = 72;
      break;
    }
   case 72:
    var $270 = HEAP32[$7 >> 2] + 344 | 0;
    var $271 = __ZN2js10ArenaArrayIPNS_7analyze11SSAUseChainEEEPT_R11JSArenaPoolj($270, $266);
    var $272 = $58 + 28 | 0;
    HEAP32[$272 >> 2] = $271;
    if (($271 | 0) == 0) {
      __label__ = 73;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 73:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 111;
    break;
   case 74:
    __ZN2jsL7PodZeroIPNS_7analyze11SSAUseChainEEEvPT_j($271, $266);
    __label__ = 75;
    break;
   case 75:
    var $277 = $258 + $199 | 0;
    if (($55 | 0) == 85 || ($55 | 0) == 87 || ($55 | 0) == 132 || ($55 | 0) == 140 || ($55 | 0) == 223 || ($55 | 0) == 97 || ($55 | 0) == 98 || ($55 | 0) == 99 || ($55 | 0) == 100 || ($55 | 0) == 101 || ($55 | 0) == 102 || ($55 | 0) == 103 || ($55 | 0) == 104) {
      __label__ = 76;
      break;
    } else if (($55 | 0) == 84 || ($55 | 0) == 86) {
      __label__ = 78;
      break;
    } else if (($55 | 0) == 216 || ($55 | 0) == 215) {
      __label__ = 80;
      break;
    } else if (($55 | 0) == 76) {
      __label__ = 82;
      break;
    } else if (($55 | 0) == 93 || ($55 | 0) == 227) {
      __label__ = 83;
      break;
    } else if (($55 | 0) == 94) {
      __label__ = 84;
      break;
    } else if (($55 | 0) == 12) {
      __label__ = 85;
      break;
    } else if (($55 | 0) == 13) {
      __label__ = 86;
      break;
    } else if (($55 | 0) == 10 || ($55 | 0) == 133) {
      __label__ = 87;
      break;
    } else if (($55 | 0) == 70 || ($55 | 0) == 149) {
      __label__ = 92;
      break;
    } else if (($55 | 0) == 71 || ($55 | 0) == 150) {
      __label__ = 98;
      break;
    } else if (($55 | 0) == 134) {
      __label__ = 101;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 76:
    var $279 = HEAP32[$10 >> 2];
    var $280 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh($279, $53);
    var $281 = __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $280);
    if ($281) {
      __label__ = 77;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 77:
    var $283 = $24 + ($280 << 3) | 0;
    __ZN2js7analyze14ScriptAnalysis17mergeBranchTargetEP9JSContextRKNS0_8SSAValueEjRKNS_6VectorIjLj0ENS_15TempAllocPolicyEEE($this, $cx, $283, $280, $branchTargets);
    __ZN2js7analyze8SSAValue11initWrittenEjj($283, $280, $offset_0);
    __label__ = 108;
    break;
   case 78:
    var $285 = HEAP32[$10 >> 2];
    var $286 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh($285, $53);
    var $287 = __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $286);
    if ($287) {
      __label__ = 79;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 79:
    var $_sum25 = $39 + $277 | 0;
    var $292 = $24 + ($286 << 3) | 0;
    var $293 = HEAP32[$58 + 24 >> 2];
    var $st$6$0 = $292 | 0;
    var $294$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $292 + 4 | 0;
    var $294$1 = HEAP32[$st$6$1 >> 2];
    var $st$10$0 = $293 | 0;
    HEAP32[$st$10$0 >> 2] = $294$0;
    var $st$10$1 = $293 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $294$1;
    var $296 = $24 + ($_sum25 << 3) | 0;
    var $st$16$0 = $296 | 0;
    HEAP32[$st$16$0 >> 2] = $294$0;
    var $st$16$1 = $296 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $294$1;
    __label__ = 108;
    break;
   case 80:
    var $298 = HEAP32[$10 >> 2];
    var $299 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh($298, $53);
    var $300 = __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $299);
    if ($300) {
      __label__ = 81;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 81:
    var $_sum24 = $40 + $277 | 0;
    var $305 = $24 + ($299 << 3) | 0;
    var $306 = HEAP32[$58 + 24 >> 2];
    var $st$6$0 = $305 | 0;
    var $307$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $305 + 4 | 0;
    var $307$1 = HEAP32[$st$6$1 >> 2];
    var $st$10$0 = $306 | 0;
    HEAP32[$st$10$0 >> 2] = $307$0;
    var $st$10$1 = $306 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $307$1;
    var $309 = $24 + ($_sum24 << 3) | 0;
    var $st$16$0 = $309 | 0;
    HEAP32[$st$16$0 >> 2] = $307$0;
    var $st$16$1 = $309 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $307$1;
    __label__ = 108;
    break;
   case 82:
    var $314 = HEAP32[$58 + 24 >> 2];
    var $315 = $24 + ($40 + $277 << 3) | 0;
    var $st$6$0 = $314 | 0;
    var $316$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $314 + 4 | 0;
    var $316$1 = HEAP32[$st$6$1 >> 2];
    var $st$10$0 = $315 | 0;
    HEAP32[$st$10$0 >> 2] = $316$0;
    var $st$10$1 = $315 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $316$1;
    __label__ = 108;
    break;
   case 83:
    var $321 = HEAP32[$58 + 24 >> 2] + 8 | 0;
    var $322 = $24 + ($39 + $277 << 3) | 0;
    var $st$7$0 = $321 | 0;
    var $323$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $321 + 4 | 0;
    var $323$1 = HEAP32[$st$7$1 >> 2];
    var $st$11$0 = $322 | 0;
    HEAP32[$st$11$0 >> 2] = $323$0;
    var $st$11$1 = $322 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $323$1;
    __label__ = 108;
    break;
   case 84:
    var $329 = HEAP32[$58 + 24 >> 2] + 16 | 0;
    var $330 = $24 + ($39 + $277 << 3) | 0;
    var $st$7$0 = $329 | 0;
    var $331$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $329 + 4 | 0;
    var $331$1 = HEAP32[$st$7$1 >> 2];
    var $st$11$0 = $330 | 0;
    HEAP32[$st$11$0 >> 2] = $331$0;
    var $st$11$1 = $330 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $331$1;
    __label__ = 108;
    break;
   case 85:
    var $_sum19 = $39 + $277 | 0;
    var $336 = HEAP32[$58 + 24 >> 2];
    var $337 = $24 + ($40 + $277 << 3) | 0;
    var $st$7$0 = $336 | 0;
    var $338$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $336 + 4 | 0;
    var $338$1 = HEAP32[$st$7$1 >> 2];
    var $st$11$0 = $337 | 0;
    HEAP32[$st$11$0 >> 2] = $338$0;
    var $st$11$1 = $337 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $338$1;
    var $340 = $24 + ($_sum19 << 3) | 0;
    var $st$17$0 = $340 | 0;
    HEAP32[$st$17$0 >> 2] = $338$0;
    var $st$17$1 = $340 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $338$1;
    __label__ = 108;
    break;
   case 86:
    var $_sum15 = $39 + $277 | 0;
    var $342 = $58 + 24 | 0;
    var $345 = HEAP32[$342 >> 2];
    var $346 = $24 + ($41 + $277 << 3) | 0;
    var $st$7$0 = $345 | 0;
    var $347$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $345 + 4 | 0;
    var $347$1 = HEAP32[$st$7$1 >> 2];
    var $st$11$0 = $346 | 0;
    HEAP32[$st$11$0 >> 2] = $347$0;
    var $st$11$1 = $346 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $347$1;
    var $349 = $24 + ($_sum15 << 3) | 0;
    var $st$17$0 = $349 | 0;
    HEAP32[$st$17$0 >> 2] = $347$0;
    var $st$17$1 = $349 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $347$1;
    var $_sum17 = $40 + $277 | 0;
    var $353 = HEAP32[$342 >> 2] + 8 | 0;
    var $354 = $24 + ($42 + $277 << 3) | 0;
    var $355$0 = HEAP32[$353 >> 2];
    var $355$1 = HEAP32[$353 + 4 >> 2];
    var $st$32$0 = $354 | 0;
    HEAP32[$st$32$0 >> 2] = $355$0;
    var $st$32$1 = $354 + 4 | 0;
    HEAP32[$st$32$1 >> 2] = $355$1;
    var $357 = $24 + ($_sum17 << 3) | 0;
    var $st$38$0 = $357 | 0;
    HEAP32[$st$38$0 >> 2] = $355$0;
    var $st$38$1 = $357 + 4 | 0;
    HEAP32[$st$38$1 >> 2] = $355$1;
    __label__ = 108;
    break;
   case 87:
    if ($54 << 24 >> 24 == 10) {
      var $364 = 1;
      __label__ = 89;
      break;
    } else {
      __label__ = 88;
      break;
    }
   case 88:
    var $364 = HEAPU8[$offset_0 + ($52 + 1) | 0] & 255;
    __label__ = 89;
    break;
   case 89:
    var $364;
    var $365 = $58 + 24 | 0;
    var $369 = HEAP32[$365 >> 2] + ($364 << 3) | 0;
    var $370 = $24 + ($39 + $277 << 3) | 0;
    var $st$8$0 = $369 | 0;
    var $371$0 = HEAP32[$st$8$0 >> 2];
    var $st$8$1 = $369 + 4 | 0;
    var $371$1 = HEAP32[$st$8$1 >> 2];
    var $st$12$0 = $370 | 0;
    HEAP32[$st$12$0 >> 2] = $371$0;
    var $st$12$1 = $370 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $371$1;
    if (($364 | 0) == 0) {
      __label__ = 108;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 90:
    var $373 = $40 + $277 | 0;
    var $i15_047 = 0;
    __label__ = 91;
    break;
   case 91:
    var $i15_047;
    var $378 = HEAP32[$365 >> 2] + ($i15_047 << 3) | 0;
    var $379 = $24 + ($373 - $i15_047 << 3) | 0;
    var $st$7$0 = $378 | 0;
    var $380$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $378 + 4 | 0;
    var $380$1 = HEAP32[$st$7$1 >> 2];
    var $st$11$0 = $379 | 0;
    HEAP32[$st$11$0 >> 2] = $380$0;
    var $st$11$1 = $379 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $380$1;
    var $381 = $i15_047 + 1 | 0;
    if (($381 | 0) == ($364 | 0)) {
      __label__ = 108;
      break;
    } else {
      var $i15_047 = $381;
      __label__ = 91;
      break;
    }
   case 92:
    var $383 = $54 << 24 >> 24 == 70 ? 2 : 4;
    var $_val6 = HEAP8[$53];
    var $384 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($_val6, $53);
    var $385 = $384 + $offset_0 | 0;
    var $_sum7 = $383 + $offset_0 | 0;
    var $393 = (HEAPU8[$_sum7 + ($52 + 1) | 0] & 255) << 8 | HEAPU8[$_sum7 + ($52 + 2) | 0] & 255;
    var $398 = $_sum7 + ($52 + 4) | 0;
    var $401 = (HEAPU8[$_sum7 + ($52 + 3) | 0] & 255) << 8 | HEAPU8[$398] & 255;
    __ZN2js7analyze14ScriptAnalysis17checkBranchTargetEP9JSContextjRNS_6VectorIjLj0ENS_15TempAllocPolicyEEEPNS0_8SSAValueEj($this, $cx, $385, $branchTargets, $24);
    if ($393 << 16 >> 16 > $401 << 16 >> 16) {
      __label__ = 108;
      break;
    } else {
      __label__ = 93;
      break;
    }
   case 93:
    var $405 = ($401 << 16 >> 16) + 1 | 0;
    var $pc2_037 = $398;
    var $i16_038 = $393 << 16 >> 16;
    __label__ = 94;
    break;
   case 94:
    var $i16_038;
    var $pc2_037;
    var $_val5 = HEAP8[$53];
    var $407 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($_val5, $pc2_037);
    if (($407 | 0) == 0) {
      __label__ = 96;
      break;
    } else {
      __label__ = 95;
      break;
    }
   case 95:
    var $410 = $407 + $offset_0 | 0;
    __ZN2js7analyze14ScriptAnalysis17checkBranchTargetEP9JSContextjRNS_6VectorIjLj0ENS_15TempAllocPolicyEEEPNS0_8SSAValueEj($this, $cx, $410, $branchTargets, $24);
    __label__ = 96;
    break;
   case 96:
    var $412 = $i16_038 + 1 | 0;
    if (($412 | 0) == ($405 | 0)) {
      __label__ = 108;
      break;
    } else {
      __label__ = 97;
      break;
    }
   case 97:
    var $pc2_037 = $pc2_037 + $383 | 0;
    var $i16_038 = $412;
    __label__ = 94;
    break;
   case 98:
    var $415 = $54 << 24 >> 24 == 71 ? 2 : 4;
    var $_val4 = HEAP8[$53];
    var $416 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($_val4, $53);
    var $417 = $416 + $offset_0 | 0;
    var $_sum = $415 + $offset_0 | 0;
    var $422 = $_sum + ($52 + 2) | 0;
    var $425 = (HEAPU8[$_sum + ($52 + 1) | 0] & 255) << 8 | HEAPU8[$422] & 255;
    __ZN2js7analyze14ScriptAnalysis17checkBranchTargetEP9JSContextjRNS_6VectorIjLj0ENS_15TempAllocPolicyEEEPNS0_8SSAValueEj($this, $cx, $417, $branchTargets, $24);
    if (($425 | 0) == 0) {
      __label__ = 108;
      break;
    } else {
      __label__ = 99;
      break;
    }
   case 99:
    var $_sum6 = $415 + 2 | 0;
    var $pc217_040 = $422;
    var $npairs_041 = $425;
    __label__ = 100;
    break;
   case 100:
    var $npairs_041;
    var $pc217_040;
    var $_val = HEAP8[$53];
    var $429 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($_val, $pc217_040 + 2 | 0);
    var $430 = $429 + $offset_0 | 0;
    __ZN2js7analyze14ScriptAnalysis17checkBranchTargetEP9JSContextjRNS_6VectorIjLj0ENS_15TempAllocPolicyEEEPNS0_8SSAValueEj($this, $cx, $430, $branchTargets, $24);
    var $431 = $pc217_040 + $_sum6 | 0;
    var $432 = $npairs_041 - 1 | 0;
    if (($432 | 0) == 0) {
      __label__ = 108;
      break;
    } else {
      var $pc217_040 = $431;
      var $npairs_041 = $432;
      __label__ = 100;
      break;
    }
   case 101:
    var $435 = HEAP32[$10 >> 2];
    var $_idx_val = HEAP32[$435 + 4 >> 2];
    var $_idx1_val = HEAP8[$435 + 19 | 0];
    var $436 = __ZN8JSScript8trynotesEv($_idx_val, $_idx1_val);
    var $438 = HEAP32[$436 >> 2];
    var $440 = HEAP32[$436 + 4 >> 2];
    var $441 = $438 + $440 * 12 | 0;
    if (($440 | 0) > 0) {
      __label__ = 102;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 102:
    var $443 = $offset_0 + 1 | 0;
    var $tn_044 = $438;
    var $445 = $435;
    __label__ = 103;
    break;
   case 103:
    var $445;
    var $tn_044;
    var $450 = HEAP32[$tn_044 + 4 >> 2] + HEAP32[$445 + 32 >> 2] | 0;
    if (($450 | 0) == ($443 | 0)) {
      __label__ = 104;
      break;
    } else {
      __label__ = 106;
      break;
    }
   case 104:
    if (HEAP8[$tn_044 | 0] << 24 >> 24 == 2) {
      __label__ = 106;
      break;
    } else {
      __label__ = 105;
      break;
    }
   case 105:
    var $459 = HEAP32[$tn_044 + 8 >> 2] + $450 | 0;
    __ZN2js7analyze14ScriptAnalysis17checkBranchTargetEP9JSContextjRNS_6VectorIjLj0ENS_15TempAllocPolicyEEEPNS0_8SSAValueEj($this, $cx, $459, $branchTargets, $24);
    __label__ = 106;
    break;
   case 106:
    var $461 = $tn_044 + 12 | 0;
    if ($461 >>> 0 < $441 >>> 0) {
      __label__ = 107;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 107:
    var $tn_044 = $461;
    var $445 = HEAP32[$10 >> 2];
    __label__ = 103;
    break;
   case 108:
    var $463 = $193 & 31;
    if (($463 | 0) == 9 || ($463 | 0) == 1) {
      __label__ = 109;
      break;
    } else {
      var $stackDepth_1_ph35 = $277;
      __label__ = 112;
      break;
    }
   case 109:
    var $464 = HEAP32[$10 >> 2];
    var $465 = __ZN2js7analyzeL12FollowBranchEP9JSContextP8JSScriptj($464, $offset_0);
    __ZN2js7analyze14ScriptAnalysis17checkBranchTargetEP9JSContextjRNS_6VectorIjLj0ENS_15TempAllocPolicyEEEPNS0_8SSAValueEj($this, $cx, $465, $branchTargets, $24);
    if ($465 >>> 0 < $offset_0 >>> 0) {
      __label__ = 110;
      break;
    } else {
      var $stackDepth_1_ph35 = $277;
      __label__ = 112;
      break;
    }
   case 110:
    __ZN2js7analyze14ScriptAnalysis15freezeNewValuesEP9JSContextj($this, $cx, $465);
    var $stackDepth_1_ph35 = $277;
    __label__ = 112;
    break;
   case 111:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    __label__ = 114;
    break;
   case 112:
    var $stackDepth_1_ph35;
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $stackDepth_0 = $stackDepth_1_ph35;
    var $offset_0 = $57;
    __label__ = 10;
    break;
   case 113:
    HEAP8[$this + 21 | 0] = 1;
    __label__ = 114;
    break;
   case 114:
    __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEED1Ev($branchTargets);
    var $free_idx_val = HEAP32[$free + 4 >> 2];
    __ZZN2js7analyze14ScriptAnalysis10analyzeSSAEP9JSContextEN13FreeSSAValuesD2Ev($free_idx_val);
    __label__ = 115;
    break;
   case 115:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis10analyzeSSAEP9JSContext["X"] = 1;

function __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $slot) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js7analyze14ScriptAnalysis11slotEscapesEj($this, $slot);
    if ($1) {
      var $8 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = (HEAP8[$this + 25 | 0] & 2) << 24 >> 24 != 0;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze8SSAValue11initInitialEj($this, $slot) {
  __ZN2js7analyze8SSAValue5clearEv($this);
  var $1 = $this;
  var $4 = HEAP32[$1 >> 2] & -4 | 2;
  HEAP32[$1 >> 2] = $4;
  HEAP8[$this | 0] = $4 & 255 | 4;
  var $10 = HEAP32[$1 >> 2] & 7 | $slot << 3;
  HEAP32[$1 >> 2] = $10;
  return;
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEC1ES1_($this, $ap_01) {
  __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEC2ES1_($this, $ap_01);
  return;
}

function __ZN2js7analyze14ScriptAnalysis9maybeCodeEPKh($this_0_0_val_0_0_val, $this_0_1_val, $pc) {
  var $3 = $pc - $this_0_0_val_0_0_val | 0;
  var $4 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEj($this_0_1_val, $3);
  return $4;
}

function __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6lengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE6lengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZN2js7analyzeL11ExtendedDefEPh($pc_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $pc_val & 255;
    if (($1 | 0) == 85 || ($1 | 0) == 97 || ($1 | 0) == 98 || ($1 | 0) == 99 || ($1 | 0) == 100 || ($1 | 0) == 87 || ($1 | 0) == 132 || ($1 | 0) == 140 || ($1 | 0) == 223 || ($1 | 0) == 101 || ($1 | 0) == 102 || ($1 | 0) == 103 || ($1 | 0) == 104) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7analyze8SSAValue4kindEv($this) {
  return HEAP32[$this >> 2] & 3;
}

function __ZNK2js7analyze8SSAValue9phiOffsetEv($this) {
  return HEAPU32[$this >> 2] >>> 2;
}

function __ZN2js7analyze14ScriptAnalysis8livenessEj($this_0_14_val, $slot) {
  return $this_0_14_val + $slot * 12 | 0;
}

function __ZNK2js7analyze8SSAValue7phiNodeEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE7popBackEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2jsL7PodZeroINS_7analyze8SSAValueEEEvPT_j($t, $nelem) {
  var $1 = $t | 0;
  var $2 = $nelem << 3;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js7analyze14ScriptAnalysis18removeBranchTargetERNS_6VectorIjLj0ENS_15TempAllocPolicyEEEj($branchTargets, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $branchTargets_idx_val = HEAPU32[$branchTargets + 8 >> 2];
    var $1 = __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE6lengthEv($branchTargets_idx_val);
    var $branchTargets_idx1 = $branchTargets + 4 | 0;
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if ($i_0 >>> 0 < $1 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $branchTargets_idx1_val = HEAPU32[$branchTargets_idx1 >> 2];
    var $5 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEixEj($branchTargets_idx1_val, $i_0);
    if ((HEAP32[$5 >> 2] | 0) == ($offset | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE4backEv($branchTargets_idx1_val, $branchTargets_idx_val);
    var $10 = HEAP32[$9 >> 2];
    HEAP32[$5 >> 2] = $10;
    __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE7popBackEv($branchTargets);
    __label__ = 6;
    break;
   case 5:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext4new_IN2js6VectorINS1_7analyze9SlotValueELj0ENS1_15TempAllocPolicyEEEPS_EEPT_T0_($this, $p1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN9JSContext7malloc_Ej($this, 24);
    if (($2 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $p1);
    var $_0_val = HEAP32[$1 >> 2];
    __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEC1ES3_($5, $_0_val);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    STACKTOP = __stackBase__;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEixEj($this_0_1_val, $i) {
  var $1 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE5beginEv($this_0_1_val);
  return $1 + $i * 12 | 0;
}

function __ZNK2js7analyze16LifetimeVariable10firstWriteEPNS0_12LoopAnalysisE($this, $loop_0_1_val, $loop_0_2_val) {
  var $1 = __ZNK2js7analyze16LifetimeVariable10firstWriteEjj($this, $loop_0_1_val, $loop_0_2_val);
  return $1;
}

function __ZN2js7analyze14ScriptAnalysis7makePhiEP9JSContextjjPNS0_8SSAValueE($this, $cx, $slot, $offset, $pv) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 56 | 0;
    var $3 = HEAP32[$1 >> 2] + 344 | 0;
    var $4 = __ZN2js8ArenaNewINS_7analyze10SSAPhiNodeEEEPT_R11JSArenaPool($3);
    var $6 = HEAP32[$1 >> 2] + 344 | 0;
    var $7 = __ZN2js7analyzeL15PhiNodeCapacityEj(0);
    var $8 = __ZN2js10ArenaArrayINS_7analyze8SSAValueEEEPT_R11JSArenaPoolj($6, $7);
    if (($4 | 0) == 0 | ($8 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $13 = $4 + 12 | 0;
    HEAP32[$13 >> 2] = $slot;
    var $14 = $4 + 20 | 0;
    HEAP32[$14 >> 2] = $8;
    __ZN2js7analyze8SSAValue7initPhiEjPNS0_10SSAPhiNodeE($pv, $offset, $4);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis9insertPhiEP9JSContextRNS0_8SSAValueERKS4_($this, $cx, $phi, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js7analyze8SSAValue7phiNodeEv($phi);
    var $2 = $1 + 16 | 0;
    var $3 = HEAPU32[$2 >> 2];
    if ($3 >>> 0 < 9) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $5 = $1 + 20 | 0;
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    if ($i_0 >>> 0 < $3 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $10 = HEAP32[$5 >> 2] + ($i_0 << 3) | 0;
    var $11 = __ZNK2js7analyze8SSAValue6equalsERKS1_($v, $10);
    if ($11) {
      __label__ = 15;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 3;
    break;
   case 6:
    var $14 = __ZN2js7analyze14ScriptAnalysis13trackUseChainERKNS0_8SSAValueE($v);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $37 = $3;
      __label__ = 10;
      break;
    }
   case 7:
    var $16 = __ZN2js7analyze14ScriptAnalysis8useChainERKNS0_8SSAValueE($this, $v);
    var $19 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    var $20 = __ZN2js8ArenaNewINS_7analyze11SSAUseChainEEEPT_R11JSArenaPool($19);
    if (($20 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 15;
    break;
   case 9:
    var $24 = $20 | 0;
    var $26 = HEAP8[$24] & -2;
    HEAP8[$24] = $26;
    var $27 = __ZNK2js7analyze8SSAValue9phiOffsetEv($phi);
    var $28 = $20;
    var $32 = HEAP32[$28 >> 2] & 1 | $27 << 1;
    HEAP32[$28 >> 2] = $32;
    var $33 = $20 + 4 | 0;
    HEAP32[$33 >> 2] = $1;
    var $34 = HEAP32[$16 >> 2];
    var $35 = $20 + 8 | 0;
    HEAP32[$35 >> 2] = $34;
    HEAP32[$16 >> 2] = $20;
    var $37 = HEAP32[$2 >> 2];
    __label__ = 10;
    break;
   case 10:
    var $37;
    var $38 = __ZN2js7analyzeL15PhiNodeCapacityEj($37);
    if ($37 >>> 0 < $38 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$2 >> 2] = $37 + 1 | 0;
    var $45 = $v;
    var $46 = HEAP32[$1 + 20 >> 2] + ($37 << 3) | 0;
    var $47$0 = HEAP32[$45 >> 2];
    var $47$1 = HEAP32[$45 + 4 >> 2];
    var $st$11$0 = $46 | 0;
    HEAP32[$st$11$0 >> 2] = $47$0;
    var $st$11$1 = $46 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $47$1;
    __label__ = 15;
    break;
   case 12:
    var $51 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    var $53 = __ZN2js7analyzeL15PhiNodeCapacityEj($37 + 1 | 0);
    var $54 = __ZN2js10ArenaArrayINS_7analyze8SSAValueEEEPT_R11JSArenaPoolj($51, $53);
    if (($54 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 15;
    break;
   case 14:
    var $58 = $1 + 20 | 0;
    var $59 = HEAP32[$58 >> 2];
    var $60 = HEAP32[$2 >> 2];
    __ZN2jsL7PodCopyINS_7analyze8SSAValueEEEvPT_PKS3_j($54, $59, $60);
    HEAP32[$58 >> 2] = $54;
    var $61 = HEAP32[$2 >> 2];
    var $62 = $61 + 1 | 0;
    HEAP32[$2 >> 2] = $62;
    var $64 = $v;
    var $65 = $54 + ($61 << 3) | 0;
    var $st$11$0 = $64 | 0;
    var $66$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $64 + 4 | 0;
    var $66$1 = HEAP32[$st$11$1 >> 2];
    var $st$15$0 = $65 | 0;
    HEAP32[$st$15$0 >> 2] = $66$0;
    var $st$15$1 = $65 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $66$1;
    __label__ = 15;
    break;
   case 15:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis9insertPhiEP9JSContextRNS0_8SSAValueERKS4_["X"] = 1;

function __ZN2js7analyze14ScriptAnalysis10mergeValueEP9JSContextjRKNS0_8SSAValueEPNS0_9SlotValueE($this, $cx, $offset, $v, $pv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ov = __stackBase__;
    var $1 = $pv + 4 | 0;
    var $2 = __ZNK2js7analyze8SSAValue6equalsERKS1_($v, $1);
    if ($2) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2js7analyze8SSAValue4kindEv($1);
    if (($4 | 0) == 3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZNK2js7analyze8SSAValue9phiOffsetEv($1);
    if ($7 >>> 0 < $offset >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $10 = $1;
    var $11 = $ov;
    var $12$0 = HEAP32[$10 >> 2];
    var $12$1 = HEAP32[$10 + 4 >> 2];
    HEAP32[$11 >> 2] = $12$0;
    HEAP32[$11 + 4 >> 2] = $12$1;
    var $14 = HEAP32[$pv >> 2];
    var $15 = __ZN2js7analyze14ScriptAnalysis7makePhiEP9JSContextjjPNS0_8SSAValueE($this, $cx, $14, $offset, $1);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    __ZN2js7analyze14ScriptAnalysis9insertPhiEP9JSContextRNS0_8SSAValueERKS4_($this, $cx, $1, $v);
    __ZN2js7analyze14ScriptAnalysis9insertPhiEP9JSContextRNS0_8SSAValueERKS4_($this, $cx, $1, $ov);
    __label__ = 7;
    break;
   case 6:
    __ZN2js7analyze14ScriptAnalysis9insertPhiEP9JSContextRNS0_8SSAValueERKS4_($this, $cx, $1, $v);
    __label__ = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis17mergeBranchTargetEP9JSContextRKNS0_8SSAValueEjRKNS_6VectorIjLj0ENS_15TempAllocPolicyEEE($this, $cx, $value, $slot, $branchTargets) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$this + 8 >> 2] >>> 0 > $slot >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $branchTargets_idx1 = $branchTargets + 8 | 0;
    var $branchTargets_idx1_val = HEAP32[$branchTargets_idx1 >> 2];
    var $4 = __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE6lengthEv($branchTargets_idx1_val);
    if (($4 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $branchTargets_idx2 = $branchTargets + 4 | 0;
    var $this_idx = $this + 4 | 0;
    var $i_01 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_01;
    var $branchTargets_idx2_val = HEAP32[$branchTargets_idx2 >> 2];
    var $6 = __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEEixEj($branchTargets_idx2_val, $i_01);
    var $7 = HEAP32[$6 >> 2];
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $8 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_idx_val, $7);
    var $11 = HEAP32[$8 + 32 >> 2];
    __ZN2js7analyze14ScriptAnalysis17checkPendingValueEP9JSContextRKNS0_8SSAValueEjPNS_6VectorINS0_9SlotValueELj0ENS_15TempAllocPolicyEEE($this, $cx, $value, $slot, $11);
    var $12 = $i_01 + 1 | 0;
    var $branchTargets_idx_val = HEAP32[$branchTargets_idx1 >> 2];
    var $13 = __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE6lengthEv($branchTargets_idx_val);
    if ($12 >>> 0 < $13 >>> 0) {
      var $i_01 = $12;
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __stackBase__ = STACKTOP;
  var tempParam = $t;
  $t = STACKTOP;
  STACKTOP += 12;
  HEAP32[$t >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$t + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  HEAP32[$t + 8 >> 2] = HEAP32[tempParam + 8 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE13growStorageByEj($this);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze9SlotValueC1EjRKNS0_8SSAValueE($this, $slot, $value) {
  __ZN2js7analyze9SlotValueC2EjRKNS0_8SSAValueE($this, $slot, $value);
  return;
}

function __ZN2js7analyze14ScriptAnalysis15freezeNewValuesEP9JSContextj($this, $cx, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $1 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_idx_val, $offset);
    var $2 = $1 + 32 | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = $2 | 0;
    HEAP32[$5 >> 2] = 0;
    var $_idx_val = HEAP32[$4 + 8 >> 2];
    var $6 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6lengthEv($_idx_val);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN9JSContext7delete_IN2js6VectorINS1_7analyze9SlotValueELj0ENS1_15TempAllocPolicyEEEEEvPT_($4);
    __label__ = 8;
    break;
   case 3:
    var $12 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    var $13 = $6 + 1 | 0;
    var $14 = __ZN2js10ArenaArrayINS_7analyze9SlotValueEEEPT_R11JSArenaPoolj($12, $13);
    HEAP32[$5 >> 2] = $14;
    if (($14 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx1 = $4 + 4 | 0;
    var $i_01 = 0;
    var $18 = $14;
    __label__ = 6;
    break;
   case 5:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 8;
    break;
   case 6:
    var $18;
    var $i_01;
    var $19 = $18 + $i_01 * 12 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $20 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEixEj($_idx1_val, $i_01);
    var $21 = $19;
    var $22 = $20;
    HEAP32[$21 >> 2] = HEAP32[$22 >> 2];
    HEAP32[$21 + 4 >> 2] = HEAP32[$22 + 4 >> 2];
    HEAP32[$21 + 8 >> 2] = HEAP32[$22 + 8 >> 2];
    var $23 = $i_01 + 1 | 0;
    var $24 = HEAP32[$5 >> 2];
    if (($23 | 0) == ($6 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $i_01 = $23;
      var $18 = $24;
      __label__ = 6;
      break;
    }
   case 7:
    var $25 = $24 + $6 * 12 | 0;
    HEAP32[$25 >> 2] = 0;
    var $27 = HEAP32[$5 >> 2] + $6 * 12 + 4 | 0;
    __ZN2js7analyze8SSAValue5clearEv($27);
    __ZN9JSContext7delete_IN2js6VectorINS1_7analyze9SlotValueELj0ENS1_15TempAllocPolicyEEEEEvPT_($4);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyzeL11ExtendedUseEPh($pc_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js7analyzeL11ExtendedDefEPh($pc_val);
    if ($1) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $pc_val & 255;
    if (($3 | 0) == 84 || ($3 | 0) == 216 || ($3 | 0) == 86 || ($3 | 0) == 215) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10ArenaArrayINS_7analyze8SSAValueEEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + ($count << 3) & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze8SSAValue5clearEv($this) {
  __ZN2jsL7PodZeroINS_7analyze8SSAValueEEEvPT_($this);
  return;
}

function __ZN2js10ArenaArrayINS_7analyze11SSAUseChainEEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + $count * 12 & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodZeroINS_7analyze11SSAUseChainEEEvPT_j($t, $nelem) {
  var $1 = $t | 0;
  var $2 = $nelem * 12 | 0;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js7analyze14ScriptAnalysis13trackUseChainERKNS0_8SSAValueE($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js7analyze8SSAValue4kindEv($v);
    if (($1 | 0) == 0) {
      var $9 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($1 | 0) == 2) {
      __label__ = 3;
      break;
    } else {
      var $9 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $v_idx_val = HEAP8[$v | 0];
    var $6 = __ZNK2js7analyze8SSAValue10varInitialEv($v_idx_val);
    var $9 = $6 ^ 1;
    __label__ = 4;
    break;
   case 4:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis8useChainERKNS0_8SSAValueE($this, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js7analyze8SSAValue4kindEv($v);
    if (($1 | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $v_idx_val = HEAP32[$v + 4 >> 2];
    var $3 = __ZNK2js7analyze8SSAValue11pushedIndexEv($v_idx_val);
    var $4 = __ZNK2js7analyze8SSAValue12pushedOffsetEv($v);
    var $this_idx1_val = HEAP32[$this + 4 >> 2];
    var $5 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_idx1_val, $4);
    var $_0 = HEAP32[$5 + 28 >> 2] + ($3 << 2) | 0;
    __label__ = 5;
    break;
   case 3:
    var $11 = HEAP32[$this >> 2];
    var $v_idx3 = $v + 4 | 0;
    var $v_idx3_val = HEAP32[$v_idx3 >> 2];
    var $12 = __ZNK2js7analyze8SSAValue9varOffsetEv($v_idx3_val);
    var $13 = __ZN2js7analyzeL11GetDefCountEP8JSScriptj($11, $12);
    var $v_idx2_val = HEAP32[$v_idx3 >> 2];
    var $14 = __ZNK2js7analyze8SSAValue9varOffsetEv($v_idx2_val);
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $15 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_idx_val, $14);
    var $_0 = HEAP32[$15 + 28 >> 2] + ($13 << 2) | 0;
    __label__ = 5;
    break;
   case 4:
    var $20 = __ZNK2js7analyze8SSAValue7phiNodeEv($v);
    var $_0 = $20 + 24 | 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze8SSAValue10initPushedEjj($this, $offset, $index) {
  __ZN2js7analyze8SSAValue5clearEv($this);
  HEAP32[$this >> 2] = $offset << 2 | 1;
  HEAP32[$this + 4 >> 2] = $index;
  return;
}

function __ZN2js10ArenaArrayIPNS_7analyze11SSAUseChainEEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + ($count << 2) & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodZeroIPNS_7analyze11SSAUseChainEEEvPT_j($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem << 2;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js7analyze8SSAValue11initWrittenEjj($this, $slot, $offset) {
  __ZN2js7analyze8SSAValue5clearEv($this);
  var $1 = $this;
  var $4 = HEAP32[$1 >> 2] & -4 | 2;
  HEAP32[$1 >> 2] = $4;
  HEAP8[$this | 0] = $4 & 255 & -6;
  var $10 = HEAP32[$1 >> 2] & 7 | $slot << 3;
  HEAP32[$1 >> 2] = $10;
  HEAP32[$this + 4 >> 2] = $offset;
  return;
}

function __ZN2js7analyze14ScriptAnalysis17checkBranchTargetEP9JSContextjRNS_6VectorIjLj0ENS_15TempAllocPolicyEEEPNS0_8SSAValueEj($this, $cx, $targetOffset, $branchTargets, $values) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $1 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_idx_val, $targetOffset);
    var $3 = HEAP32[$1 + 4 >> 2];
    var $4 = $1 + 32 | 0;
    var $5 = $4;
    var $6 = HEAP32[$5 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$6 + 8 >> 2];
    var $8 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6lengthEv($_idx1_val);
    if (($8 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $i_01 = 0;
      var $10 = $6;
      __label__ = 3;
      break;
    }
   case 3:
    var $10;
    var $i_01;
    var $_idx2_val = HEAP32[$10 + 4 >> 2];
    var $11 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEixEj($_idx2_val, $i_01);
    var $14 = $values + (HEAP32[$11 >> 2] << 3) | 0;
    __ZN2js7analyze14ScriptAnalysis10mergeValueEP9JSContextjRKNS0_8SSAValueEPNS0_9SlotValueE($this, $cx, $targetOffset, $14, $11);
    var $15 = $i_01 + 1 | 0;
    var $16 = HEAPU32[$5 >> 2];
    var $_idx_val = HEAP32[$16 + 8 >> 2];
    var $17 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6lengthEv($_idx_val);
    if ($15 >>> 0 < $17 >>> 0) {
      var $i_01 = $15;
      var $10 = $16;
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $20 = __ZN9JSContext4new_IN2js6VectorINS1_7analyze9SlotValueELj0ENS1_15TempAllocPolicyEEEPS_EEPT_T0_($cx, $cx);
    var $21 = $4 | 0;
    HEAP32[$21 >> 2] = $20;
    if (($20 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE6appendIjEEbT_($branchTargets, $targetOffset);
    if ($24) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 10;
    break;
   case 7:
    if (($3 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = $this | 0;
    var $i1_04 = 0;
    __label__ = 9;
    break;
   case 9:
    var $i1_04;
    var $28 = HEAP32[$27 >> 2];
    var $29 = __ZN2js7analyzeL9StackSlotEP8JSScriptj($28, $i1_04);
    var $30 = $values + ($29 << 3) | 0;
    var $31 = HEAP32[$5 >> 2];
    __ZN2js7analyze14ScriptAnalysis17checkPendingValueEP9JSContextRKNS0_8SSAValueEjPNS_6VectorINS0_9SlotValueELj0ENS_15TempAllocPolicyEEE($this, $cx, $30, $29, $31);
    var $32 = $i1_04 + 1 | 0;
    if (($32 | 0) == ($3 | 0)) {
      __label__ = 10;
      break;
    } else {
      var $i1_04 = $32;
      __label__ = 9;
      break;
    }
   case 10:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis17checkBranchTargetEP9JSContextjRNS_6VectorIjLj0ENS_15TempAllocPolicyEEEPNS0_8SSAValueEj["X"] = 1;

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js8ArenaNewINS_7analyze10SSAPhiNodeEEEPT_R11JSArenaPool($pool) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 28 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $25 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    __ZN2js7analyze10SSAPhiNodeC1Ev($23);
    var $25 = $23;
    __label__ = 6;
    break;
   case 6:
    var $25;
    return $25;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyzeL15PhiNodeCapacityEj($length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 < 5) {
      var $_0 = 4;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $length - 1 | 1;
    var $5 = _llvm_ctlz_i32($4);
    var $_0 = 1 << 32 - $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze8SSAValue7initPhiEjPNS0_10SSAPhiNodeE($this, $offset, $node) {
  __ZN2js7analyze8SSAValue5clearEv($this);
  HEAP32[$this >> 2] = $offset << 2 | 3;
  HEAP32[$this + 4 >> 2] = $node;
  return;
}

function __ZNK2js7analyze8SSAValue6equalsERKS1_($this, $o) {
  var $1 = $this | 0;
  var $2 = $o | 0;
  var $3 = _memcmp($1, $2, 8);
  return ($3 | 0) == 0;
}

function __ZN2js8ArenaNewINS_7analyze11SSAUseChainEEEPT_R11JSArenaPool($pool) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 12 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $25 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    __ZN2js7analyze11SSAUseChainC1Ev($23);
    var $25 = $23;
    __label__ = 6;
    break;
   case 6:
    var $25;
    return $25;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodCopyINS_7analyze8SSAValueEEEvPT_PKS3_j($dst, $src, $nelem) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($nelem >>> 0 < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $src + ($nelem << 3) | 0;
    if (($nelem | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $src;
      var $_03 = $dst;
      __label__ = 3;
      break;
    }
   case 3:
    var $_03;
    var $_012;
    var $5 = $_012;
    var $6 = $_03;
    var $7$0 = HEAP32[$5 >> 2];
    var $7$1 = HEAP32[$5 + 4 >> 2];
    HEAP32[$6 >> 2] = $7$0;
    HEAP32[$6 + 4 >> 2] = $7$1;
    var $8 = $_012 + 8 | 0;
    if (($8 | 0) == ($3 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $8;
      var $_03 = $_03 + 8 | 0;
      __label__ = 3;
      break;
    }
   case 4:
    var $12 = $dst | 0;
    var $13 = $src | 0;
    var $14 = $nelem << 3;
    _memcpy($12, $13, $14, 1);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis17checkPendingValueEP9JSContextRKNS0_8SSAValueEjPNS_6VectorINS0_9SlotValueELj0ENS_15TempAllocPolicyEEE($this, $cx, $v, $slot, $pending) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $pending_idx_val = HEAP32[$pending + 8 >> 2];
    var $2 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6lengthEv($pending_idx_val);
    var $pending_idx1 = $pending + 4 | 0;
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if ($i_0 >>> 0 < $2 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $pending_idx1_val = HEAP32[$pending_idx1 >> 2];
    var $6 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEixEj($pending_idx1_val, $i_0);
    if ((HEAP32[$6 >> 2] | 0) == ($slot | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 5:
    __ZN2js7analyze9SlotValueC1EjRKNS0_8SSAValueE($1, $slot, $v);
    var $13 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($pending, $1);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE6appendIjEEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE14internalAppendIjEEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyzeL9StackSlotEP8JSScriptj($script, $index) {
  var $1 = __ZN2js7analyzeL10TotalSlotsEP8JSScript($script);
  return $1 + $index | 0;
}

function __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEEixEj($this_0_1_val, $i) {
  var $1 = __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE5beginEv($this_0_1_val);
  return $1 + ($i << 2) | 0;
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE4backEv($this_0_1_val, $this_0_2_val) {
  var $1 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val);
  return $1 - 4 | 0;
}

function __ZN9JSContext7delete_IN2js6VectorINS1_7analyze9SlotValueELj0ENS1_15TempAllocPolicyEEEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEED1Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSScript8analysisEv($this_0_32_val_0_0_val) {
  return $this_0_32_val_0_0_val;
}

function __ZNK2js7analyze8SSAValue11pushedIndexEv($this_0_0_0_2_val) {
  return $this_0_0_0_2_val;
}

function __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js7MoveRefINS_7analyze9SlotValueEEcvRS2_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js7analyze8SSAValue9varOffsetEv($this_0_0_0_2_val) {
  return $this_0_0_0_2_val;
}

function __ZNK2js7analyze8SSAValue10varInitialEv($this_0_0_0_0_val) {
  return ($this_0_0_0_0_val & 4) << 24 >> 24 != 0;
}

function __ZNK2js7analyze8SSAValue7varSlotEv($this) {
  return HEAPU32[$this >> 2] >>> 3;
}

function __ZNK2js7analyze8SSAValue12pushedOffsetEv($this) {
  return HEAPU32[$this >> 2] >>> 2;
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + $this_0_2_val * 12 | 0;
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZN2js5types7TypeSetC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN2js7MoveRefINS_7analyze9SlotValueEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7analyze8LifetimeC2EjjPS1_($this, $offset, $savedEnd, $next) {
  HEAP32[$this >> 2] = $offset;
  HEAP32[$this + 4 >> 2] = $offset;
  HEAP32[$this + 8 >> 2] = $savedEnd;
  HEAP8[$this + 12 | 0] = 0;
  HEAP8[$this + 13 | 0] = 0;
  HEAP32[$this + 16 >> 2] = $next;
  return;
}

function __ZN2jsL7PodZeroINS_7analyze8SSAValueEEEvPT_($t) {
  var $1 = $t;
  var $st$3$0 = $1 | 0;
  tempBigInt = 0;
  HEAP8[$st$3$0] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$0 + 1] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$0 + 2] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$0 + 3] = tempBigInt & 255;
  var $st$3$1 = $1 + 4 | 0;
  tempBigInt = 0;
  HEAP8[$st$3$1] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$1 + 1] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$1 + 2] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$1 + 3] = tempBigInt & 255;
  return;
}

function __ZN2js7analyze9SlotValueC2EjRKNS0_8SSAValueE($this, $slot, $value) {
  HEAP32[$this >> 2] = $slot;
  var $3 = $value;
  var $4 = $this + 4 | 0;
  var $5$0 = HEAP32[$3 >> 2];
  var $5$1 = HEAP32[$3 + 4 >> 2];
  HEAP32[$4 >> 2] = $5$0;
  HEAP32[$4 + 4 >> 2] = $5$1;
  return;
}

function __ZNK2js7analyze16LifetimeVariable10firstWriteEjj($this, $start, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $segment_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $segment_0 = HEAP32[$this + 4 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $segment_0;
    if (($segment_0 | 0) == 0) {
      var $_0 = -1;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = HEAPU32[$segment_0 >> 2];
    if ($10 >>> 0 > $end >>> 0) {
      var $_0 = -1;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ($10 >>> 0 < $start >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP8[$segment_0 + 13 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = $10;
      __label__ = 8;
      break;
    }
   case 7:
    var $segment_0 = HEAP32[$segment_0 + 16 >> 2];
    __label__ = 3;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZZN2js7analyze14ScriptAnalysis10analyzeSSAEP9JSContextEN13FreeSSAValuesC2ES3_PNS0_8SSAValueE($this, $cx, $values) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $values;
  return;
}

function __ZN2js7analyze12UntrapOpcode6retrapEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    if ((HEAP8[$1] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP8[HEAP32[$this >> 2]] = 83;
    HEAP8[$1] = 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze8Bytecode9isDefinedEj($this, $slot) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    var $3 = HEAPU32[$this + 8 >> 2];
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if ($i_0 >>> 0 < $3 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    if ((HEAP32[HEAP32[$1 >> 2] + ($i_0 << 2) >> 2] | 0) == ($slot | 0)) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis10jumpTargetEj($this_0_1_val, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this_0_1_val + ($offset << 2) >> 2];
    if (($2 | 0) == 0) {
      var $10 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = (HEAP8[$2 | 0] & 1) << 24 >> 24 != 0;
    __label__ = 3;
    break;
   case 3:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13IMPL_TO_JSVAL12jsval_layout($agg_result, $l_0$0, $l_0$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $l_0$0;
  HEAP32[$1 + 4 >> 2] = $l_0$1;
  return;
}

function _BUILD_JSVAL225($agg_result, $tag, $payload) {
  HEAP32[$agg_result + 4 >> 2] = $tag;
  HEAP32[$agg_result >> 2] = $payload;
  return;
}

function __ZN2js10ArenaArrayINS_7analyze9SlotValueEEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + $count * 12 & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis11poppedValueEPKhj($this_0_0_val_0_0_val, $this_0_1_val, $pc, $which) {
  var $3 = $pc - $this_0_0_val_0_0_val | 0;
  var $4 = __ZN2js7analyze14ScriptAnalysis11poppedValueEjj($this_0_1_val, $3, $which);
  return $4;
}

function __ZN2js7analyze14ScriptAnalysis13getValueTypesERKNS0_8SSAValueE($this, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js7analyze8SSAValue4kindEv($v);
    if (($1 | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 2) {
      __label__ = 3;
      break;
    } else if (($1 | 0) == 3) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $3 = __ZNK2js7analyze8SSAValue12pushedOffsetEv($v);
    var $v_idx2_val = HEAP32[$v + 4 >> 2];
    var $4 = __ZNK2js7analyze8SSAValue11pushedIndexEv($v_idx2_val);
    var $this_idx1_val = HEAP32[$this + 4 >> 2];
    var $5 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEjj($this_idx1_val, $3, $4);
    var $_0 = $5;
    __label__ = 7;
    break;
   case 3:
    var $v_idx_val = HEAP8[$v | 0];
    var $7 = __ZNK2js7analyze8SSAValue10varInitialEv($v_idx_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = HEAP32[$this >> 2];
    var $11 = __ZNK2js7analyze8SSAValue7varSlotEv($v);
    var $_idx_val = HEAP16[$10 + 22 >> 1];
    var $_idx4_val = HEAP32[$10 + 100 >> 2];
    var $12 = __ZN2js5types10TypeScript9SlotTypesEP8JSScriptj($_idx_val, $_idx4_val, $11);
    var $_0 = $12;
    __label__ = 7;
    break;
   case 5:
    var $v_idx3_val = HEAP32[$v + 4 >> 2];
    var $14 = __ZNK2js7analyze8SSAValue9varOffsetEv($v_idx3_val);
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $15 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEjj($this_idx_val, $14, 0);
    var $_0 = $15;
    __label__ = 7;
    break;
   case 6:
    var $17 = __ZNK2js7analyze8SSAValue7phiNodeEv($v);
    var $_0 = $17 | 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE14internalAppendIjEEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $5 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    var $5 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    HEAP32[$this_idx1 >> 2] = $5 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze11SSAUseChainC1Ev($this) {
  __ZN2js7analyze11SSAUseChainC2Ev($this);
  return;
}

function __ZN2js7analyze11SSAUseChainC2Ev($this) {
  __ZN2jsL7PodZeroINS_7analyze11SSAUseChainEEEvPT_($this);
  return;
}

function __ZN2jsL7PodZeroINS_7analyze11SSAUseChainEEEvPT_($t) {
  var $1 = $t | 0;
  for (var $$dest = $1, $$stop = $$dest + 12; $$dest < $$stop; $$dest++) {
    HEAP8[$$dest] = 0;
  }
  return;
}

function __ZN2js7analyze10SSAPhiNodeC1Ev($this) {
  __ZN2js7analyze10SSAPhiNodeC2Ev($this);
  return;
}

function __ZN2js7analyze10SSAPhiNodeC2Ev($this) {
  var $1 = $this | 0;
  __ZN2js5types7TypeSetC1Ev($1);
  __ZN2jsL7PodZeroINS_7analyze10SSAPhiNodeEEEvPT_($this);
  return;
}

function __ZN2js5types7TypeSetC1Ev($this) {
  __ZN2js5types7TypeSetC2Ev($this);
  return;
}

function __ZN2jsL7PodZeroINS_7analyze10SSAPhiNodeEEEvPT_($t) {
  var $1 = $t;
  _memset($1, 0, 28, 1);
  return;
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE13growStorageByEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __stackBase__ = STACKTOP;
  var tempParam = $t;
  $t = STACKTOP;
  STACKTOP += 12;
  HEAP32[$t >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$t + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  HEAP32[$t + 8 >> 2] = HEAP32[tempParam + 8 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $7 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    var $5 = $t;
    HEAP32[$4 >> 2] = HEAP32[$5 >> 2];
    HEAP32[$4 + 4 >> 2] = HEAP32[$5 + 4 >> 2];
    HEAP32[$4 + 8 >> 2] = HEAP32[$5 + 8 >> 2];
    var $7 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $7;
    HEAP32[$this_idx1 >> 2] = $7 + 1 | 0;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 * 12 | 0;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj0ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, 1);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 134217727) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 134217727) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj0ES3_EEj($v, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $v | 0;
    var $3 = $newcap * 12 | 0;
    var $4 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $v_idx = $v + 4 | 0;
    var $v_idx_val = HEAP32[$v_idx >> 2];
    var $8 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($v_idx_val);
    var $v_idx4 = $v + 8 | 0;
    var $v_idx4_val = HEAP32[$v_idx4 >> 2];
    var $9 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($v_idx_val, $v_idx4_val);
    if (($8 | 0) == ($9 | 0)) {
      var $21 = $v_idx_val;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx = $1 | 0;
    var $dst_01 = $5;
    var $src_02 = $8;
    var $v_idx1_val5 = $v_idx_val;
    var $v_idx2_val7 = $v_idx4_val;
    __label__ = 4;
    break;
   case 4:
    var $v_idx2_val7;
    var $v_idx1_val5;
    var $src_02;
    var $dst_01;
    if (($dst_01 | 0) == 0) {
      var $v_idx1_val = $v_idx1_val5;
      var $v_idx2_val = $v_idx2_val7;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js4MoveINS_7analyze9SlotValueEEENS_7MoveRefIT_EERS4_($1, $src_02);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $13 = __ZNK2js7MoveRefINS_7analyze9SlotValueEEcvRS2_Ev($_idx_val);
    var $14 = $dst_01;
    var $15 = $13;
    HEAP32[$14 >> 2] = HEAP32[$15 >> 2];
    HEAP32[$14 + 4 >> 2] = HEAP32[$15 + 4 >> 2];
    HEAP32[$14 + 8 >> 2] = HEAP32[$15 + 8 >> 2];
    var $v_idx1_val = HEAP32[$v_idx >> 2];
    var $v_idx2_val = HEAP32[$v_idx4 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $v_idx2_val;
    var $v_idx1_val;
    var $17 = $dst_01 + 12 | 0;
    var $18 = $src_02 + 12 | 0;
    var $19 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($v_idx1_val, $v_idx2_val);
    if (($18 | 0) == ($19 | 0)) {
      var $21 = $v_idx1_val;
      __label__ = 7;
      break;
    } else {
      var $dst_01 = $17;
      var $src_02 = $18;
      var $v_idx1_val5 = $v_idx1_val;
      var $v_idx2_val7 = $v_idx2_val;
      __label__ = 4;
      break;
    }
   case 7:
    var $21;
    __ZN2js15TempAllocPolicy5free_EPv($21);
    HEAP32[$v_idx >> 2] = $5;
    HEAP32[$v + 12 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_7analyze9SlotValueEEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_7analyze9SlotValueEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_7analyze9SlotValueEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefINS_7analyze9SlotValueEEC2ERS2_($this, $t);
  return;
}

function __ZN2js10VectorImplINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx = $1 | 0;
    var $p_01 = $srcbeg;
    var $_02 = $dst;
    __label__ = 3;
    break;
   case 3:
    var $_02;
    var $p_01;
    if (($_02 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js4MoveINS_7analyze9SlotValueEEENS_7MoveRefIT_EERKS4_($1, $p_01);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $5 = __ZNK2js7MoveRefINS_7analyze9SlotValueEEcvRS2_Ev($_idx_val);
    var $6 = $_02;
    var $7 = $5;
    HEAP32[$6 >> 2] = HEAP32[$7 >> 2];
    HEAP32[$6 + 4 >> 2] = HEAP32[$7 + 4 >> 2];
    HEAP32[$6 + 8 >> 2] = HEAP32[$7 + 8 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $9 = $p_01 + 12 | 0;
    if (($9 | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      var $p_01 = $9;
      var $_02 = $_02 + 12 | 0;
      __label__ = 3;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_7analyze9SlotValueEEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_7analyze9SlotValueEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEC1ES3_($this, $ap_01) {
  __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap_01);
  return;
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZN2js7analyze8LifetimeC1EjjPS1_($this, $offset, $savedEnd, $next) {
  __ZN2js7analyze8LifetimeC2EjjPS1_($this, $offset, $savedEnd, $next);
  return;
}

function __ZN2js7analyze8BytecodeC1Ev($this) {
  __ZN2js7analyze8BytecodeC2Ev($this);
  return;
}

function __ZN2js7analyze8BytecodeC2Ev($this) {
  __ZN2jsL7PodZeroINS_7analyze8BytecodeEEEvPT_($this);
  return;
}

function __ZN2jsL7PodZeroINS_7analyze8BytecodeEEEvPT_($t) {
  var $1 = $t | 0;
  _memset($1, 0, 44, 1);
  return;
}

function __ZN2js7analyze14ScriptAnalysis11pushedTypesEjj($this_0_1_val, $offset, $which) {
  var $1 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_0_1_val, $offset);
  return HEAP32[$1 + 36 >> 2] + $which * 12 | 0;
}

function __ZN2js5types10TypeScript9SlotTypesEP8JSScriptj($script_0_11_val, $script_0_32_val, $slot) {
  var $1 = __ZN2js5types10TypeScript9typeArrayEv($script_0_32_val);
  return $1 + (($script_0_11_val & 65535) + $slot) * 12 | 0;
}

function __ZN2js7analyze14ScriptAnalysis11poppedValueEjj($this_0_1_val, $offset, $which) {
  var $1 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_0_1_val, $offset);
  return HEAP32[$1 + 24 >> 2] + ($which << 3) | 0;
}

function __ZZN2js7analyze14ScriptAnalysis10analyzeSSAEP9JSContextEN13FreeSSAValuesD2Ev($this_0_1_val) {
  var $1 = $this_0_1_val | 0;
  __ZN9JSContext5free_EPv($1);
  return;
}

function __ZN2js8ArenaNewINS_7analyze8LifetimeEjiPS2_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($pool, $a, $b, $c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 20 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $28 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    var $26 = HEAP32[$c >> 2];
    __ZN2js7analyze8LifetimeC1EjjPS1_($23, $24, $25, $26);
    var $28 = $23;
    __label__ = 6;
    break;
   case 6:
    var $28;
    return $28;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze12UntrapOpcodeD2Ev($this) {
  __ZN2js7analyze12UntrapOpcode6retrapEv($this);
  return;
}

function __ZN2js7analyze14ScriptAnalysis20localHasUseBeforeDefEj($this, $local) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js7analyzeL9LocalSlotEP8JSScriptj($2, $local);
    var $4 = __ZN2js7analyze14ScriptAnalysis11slotEscapesEj($this, $3);
    if ($4) {
      var $12 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = (HEAP32[HEAP32[$this + 32 >> 2] + ($local << 2) >> 2] | 0) == -1;
    __label__ = 3;
    break;
   case 3:
    var $12;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z28js_GetVariableBytecodeLengthPh($pc) {
  var $2 = HEAPU8[$pc] & 255;
  var $3 = __Z28js_GetVariableBytecodeLength4JSOpPh($2, $pc);
  return $3;
}

function __ZN2js7analyze12UntrapOpcodeC2EP9JSContextP8JSScriptPh($this, $script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this >> 2] = $pc;
    var $4 = HEAP8[$pc] << 24 >> 24 == 83;
    var $5 = $4 & 1;
    HEAP8[$this + 4 | 0] = $5;
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $script;
    var $8 = _JS_GetTrapOpcode($7, $pc);
    HEAP8[$pc] = $8 & 255;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSScript9getObjectEj($this_0_1_val, $this_0_5_val, $index) {
  var $1 = __ZN8JSScript7objectsEv($this_0_1_val, $this_0_5_val);
  return HEAP32[HEAP32[$1 >> 2] + ($index << 2) >> 2];
}

function ___cxx_global_var_init() {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BUILD_JSVAL225($1, -122, 0);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout(_JSVAL_NULL, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function ___cxx_global_var_init1() {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BUILD_JSVAL225($1, -127, 0);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout(_JSVAL_ZERO, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function ___cxx_global_var_init2() {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BUILD_JSVAL225($1, -127, 1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout(_JSVAL_ONE, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function ___cxx_global_var_init3() {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BUILD_JSVAL225($1, -125, 0);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout(_JSVAL_FALSE, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function ___cxx_global_var_init4() {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BUILD_JSVAL225($1, -125, 1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout(_JSVAL_TRUE, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function ___cxx_global_var_init5() {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BUILD_JSVAL225($1, -126, 0);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout(_JSVAL_VOID, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function _JS_Now() {
  var $1 = _PRMJ_Now();
  return [ $1[0], $1[1] ];
}

function _JS_GetEmptyStringValue($agg_result, $cx_0_11_val_0_50_val) {
  var $1 = $cx_0_11_val_0_50_val | 0;
  _STRING_TO_JSVAL($agg_result, $1);
  return;
}

function _STRING_TO_JSVAL($agg_result, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _STRING_TO_JSVAL_IMPL277($1, $str);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function _JS_ConvertArguments($cx, $argc, $argv, $format) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $ap = __stackBase__;
  HEAP32[$ap >> 2] = arguments[_JS_ConvertArguments.length];
  var $2 = HEAP32[$ap >> 2];
  var $3 = _JS_ConvertArgumentsVA($cx, $argc, $argv, $format, $2);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZNK2js15AutoValueRooter5valueEv($this) {
  return $this + 16 | 0;
}

function _JS_GetTypeName($type) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($type >>> 0 > 7) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[_js_common_atom_names + ($type + 3 << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ConvertArgumentsVA($cx, $argc, $argv, $format, $ap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 68;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $sp = __stackBase__ + 4;
    var $d = __stackBase__ + 8;
    var $obj = __stackBase__ + 16;
    var $2 = __stackBase__ + 20;
    var $numBuf = __stackBase__ + 28;
    var $funNameBytes = __stackBase__ + 40;
    var $3 = __stackBase__ + 44;
    var $4 = __stackBase__ + 52;
    var $5 = __stackBase__ + 60;
    HEAP32[$1 >> 2] = $format;
    var $6 = $argv - 16 | 0;
    var $7 = $argc + 2 | 0;
    __ZN12JSValueArrayC1EPN2JS5ValueEj($2, $6, $7);
    HEAP32[$sp >> 2] = $argv;
    var $8 = $argv + ($argc << 3) | 0;
    var $9 = $cx;
    var $10 = $3 | 0;
    var $11 = $cx;
    var $12 = $obj;
    var $13 = $4 | 0;
    var $14 = $5 | 0;
    var $required_0_ph = 1;
    var $_01_ph = $ap;
    var $15 = $format;
    __label__ = 2;
    break;
   case 2:
    var $15;
    var $_01_ph;
    var $required_0_ph;
    var $16 = $_01_ph;
    var $required_0_ph4 = $required_0_ph;
    var $17 = $15;
    __label__ = 3;
    break;
   case 3:
    var $17;
    var $required_0_ph4;
    var $18 = $17;
    __label__ = 4;
    break;
   case 4:
    var $18;
    var $19 = $18 + 1 | 0;
    HEAP32[$1 >> 2] = $19;
    var $20 = HEAP8[$18];
    var $21 = $20 << 24 >> 24;
    if ($20 << 24 >> 24 == 0) {
      var $_0 = 1;
      __label__ = 40;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = _isspace($21);
    if (($24 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $18 = $19;
      __label__ = 4;
      break;
    }
   case 6:
    if ($20 << 24 >> 24 == 47) {
      var $required_0_ph4 = 0;
      var $17 = $19;
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $29 = HEAP32[$sp >> 2];
    if (($29 | 0) == ($8 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    if (($required_0_ph4 | 0) == 0) {
      var $_0 = 1;
      __label__ = 40;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $34 = __Z18js_ValueToFunctionP9JSContextPKN2JS5ValueEj($cx, $6, 0);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $37 = $numBuf | 0;
    var $38 = _JS_snprintf($37, 12, STRING_TABLE.__str544300 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $argc, tempInt));
    __ZN16JSAutoByteStringC1Ev($funNameBytes);
    var $_idx5_val = HEAP32[$34 + 72 >> 2];
    var $39 = __ZN2js20GetFunctionNameBytesEP9JSContextP10JSFunctionP16JSAutoByteString($cx, $_idx5_val, $funNameBytes);
    if (($39 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $43 = ($argc | 0) == 1 ? __str17668 | 0 : STRING_TABLE.__str226519 | 0;
    _JS_ReportErrorNumber($cx, 4, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $39, HEAP32[tempInt + 4 >> 2] = $37, HEAP32[tempInt + 8 >> 2] = $43, tempInt));
    __label__ = 12;
    break;
   case 12:
    var $funNameBytes_idx_val = HEAP32[$funNameBytes >> 2];
    __ZN16JSAutoByteStringD1Ev($funNameBytes_idx_val);
    var $_0 = 0;
    __label__ = 40;
    break;
   case 13:
    if (($21 | 0) == 98) {
      __label__ = 14;
      break;
    } else if (($21 | 0) == 99) {
      __label__ = 15;
      break;
    } else if (($21 | 0) == 105) {
      __label__ = 17;
      break;
    } else if (($21 | 0) == 117) {
      __label__ = 19;
      break;
    } else if (($21 | 0) == 106) {
      __label__ = 21;
      break;
    } else if (($21 | 0) == 100) {
      __label__ = 23;
      break;
    } else if (($21 | 0) == 73) {
      __label__ = 25;
      break;
    } else if (($21 | 0) == 83 || ($21 | 0) == 87) {
      __label__ = 27;
      break;
    } else if (($21 | 0) == 111) {
      __label__ = 32;
      break;
    } else if (($21 | 0) == 102) {
      __label__ = 34;
      break;
    } else if (($21 | 0) == 118) {
      __label__ = 36;
      break;
    } else if (($21 | 0) == 42) {
      var $_1 = $_01_ph;
      __label__ = 39;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 14:
    var $47 = __Z17js_ValueToBooleanRKN2JS5ValueE($29);
    var $50 = HEAP32[$_01_ph >> 2];
    HEAP32[$50 >> 2] = $47;
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 15:
    var $52 = $29 | 0;
    var $st$1$0 = $52 | 0;
    var $53$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $52 + 4 | 0;
    var $53$1 = HEAP32[$st$1$1 >> 2];
    var $55 = HEAP32[$_01_ph >> 2];
    var $56 = _JS_ValueToUint16($cx, $53$0, $53$1, $55);
    if (($56 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 17:
    var $60 = $29 | 0;
    var $st$1$0 = $60 | 0;
    var $61$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $60 + 4 | 0;
    var $61$1 = HEAP32[$st$1$1 >> 2];
    var $63 = HEAP32[$_01_ph >> 2];
    var $64 = _JS_ValueToECMAInt32($cx, $61$0, $61$1, $63);
    if (($64 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 19:
    var $68 = $29 | 0;
    var $st$1$0 = $68 | 0;
    var $69$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $68 + 4 | 0;
    var $69$1 = HEAP32[$st$1$1 >> 2];
    var $71 = HEAP32[$_01_ph >> 2];
    var $72 = _JS_ValueToECMAUint32($cx, $69$0, $69$1, $71);
    if (($72 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 21:
    var $76 = $29 | 0;
    var $st$1$0 = $76 | 0;
    var $77$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $76 + 4 | 0;
    var $77$1 = HEAP32[$st$1$1 >> 2];
    var $79 = HEAP32[$_01_ph >> 2];
    var $80 = _JS_ValueToInt32($cx, $77$0, $77$1, $79);
    if (($80 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 23:
    var $84 = $29 | 0;
    var $st$1$0 = $84 | 0;
    var $85$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $84 + 4 | 0;
    var $85$1 = HEAP32[$st$1$1 >> 2];
    var $87 = HEAP32[$_01_ph >> 2];
    var $88 = _JS_ValueToNumber($cx, $85$0, $85$1, $87);
    if (($88 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 25:
    var $92 = $29 | 0;
    var $st$1$0 = $92 | 0;
    var $93$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $92 + 4 | 0;
    var $93$1 = HEAP32[$st$1$1 >> 2];
    var $94 = _JS_ValueToNumber($cx, $93$0, $93$1, $d);
    if (($94 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $97 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $98 = __ZL18js_DoubleToIntegerd($97);
    var $101 = HEAP32[$_01_ph >> 2];
    tempDoubleF64[0] = $98, HEAP32[$101 >> 2] = tempDoubleI32[0], HEAP32[$101 + 4 >> 2] = tempDoubleI32[1];
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 27:
    var $_idx6 = $29 | 0;
    var $st$1$0 = $_idx6 | 0;
    var $_idx6_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx6 + 4 | 0;
    var $_idx6_val$1 = HEAP32[$st$1$1 >> 2];
    var $103 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($9, $_idx6_val$0, $_idx6_val$1);
    if (($103 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $106 = HEAP32[$sp >> 2];
    _STRING_TO_JSVAL($3, $103);
    var $st$2$0 = $10 | 0;
    var $107$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $10 + 4 | 0;
    var $107$1 = HEAP32[$st$2$1 >> 2];
    var $108 = $106 | 0;
    var $st$7$0 = $108 | 0;
    HEAP32[$st$7$0 >> 2] = $107$0;
    var $st$7$1 = $108 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $107$1;
    if ($20 << 24 >> 24 == 87) {
      __label__ = 29;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 29:
    var $111 = __ZN8JSString11ensureFixedEP9JSContext($103, $cx);
    if (($111 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $_idx1_val = HEAP32[$111 + 4 >> 2];
    var $114 = __ZNK14JSLinearString5charsEv($_idx1_val);
    var $117 = HEAP32[$_01_ph >> 2];
    HEAP32[$117 >> 2] = $114;
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 31:
    var $121 = HEAP32[$_01_ph >> 2];
    HEAP32[$121 >> 2] = $103;
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 32:
    var $123 = __Z22js_ValueToObjectOrNullP9JSContextRKN2JS5ValueEPP8JSObject($11, $29, $12);
    if (($123 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $126 = HEAP32[$sp >> 2];
    var $127 = HEAP32[$obj >> 2];
    _OBJECT_TO_JSVAL($4, $127);
    var $128$0 = HEAP32[$13 >> 2];
    var $128$1 = HEAP32[$13 + 4 >> 2];
    var $129 = $126 | 0;
    var $st$8$0 = $129 | 0;
    HEAP32[$st$8$0 >> 2] = $128$0;
    var $st$8$1 = $129 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $128$1;
    var $132 = HEAP32[$_01_ph >> 2];
    HEAP32[$132 >> 2] = $127;
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 34:
    var $134 = __Z24js_ValueToFunctionObjectP9JSContextPN2JS5ValueEj($cx, $29, 0);
    HEAP32[$obj >> 2] = $134;
    if (($134 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $137 = HEAP32[$sp >> 2];
    _OBJECT_TO_JSVAL($5, $134);
    var $st$2$0 = $14 | 0;
    var $138$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $14 + 4 | 0;
    var $138$1 = HEAP32[$st$2$1 >> 2];
    var $139 = $137 | 0;
    var $st$7$0 = $139 | 0;
    HEAP32[$st$7$0 >> 2] = $138$0;
    var $st$7$1 = $139 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $138$1;
    var $_idx_val = HEAP32[$134 + 24 >> 2];
    var $140 = __ZNK8JSObject18getFunctionPrivateEv($_idx_val);
    var $143 = HEAP32[$_01_ph >> 2];
    HEAP32[$143 >> 2] = $140;
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 36:
    var $148 = $29 | 0;
    var $149$0 = HEAP32[$148 >> 2];
    var $149$1 = HEAP32[$148 + 4 >> 2];
    var $150 = HEAP32[$_01_ph >> 2] | 0;
    var $st$9$0 = $150 | 0;
    HEAP32[$st$9$0 >> 2] = $149$0;
    var $st$9$1 = $150 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $149$1;
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 37:
    HEAP32[$1 >> 2] = $18;
    var $152 = __ZL20TryArgumentFormatterP9JSContextPPKciPPN2JS5ValueEPPc($cx, $1, $sp, $16);
    if (($152 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $18 = HEAP32[$1 >> 2];
    __label__ = 4;
    break;
   case 39:
    var $_1;
    var $155 = HEAP32[$sp >> 2] + 8 | 0;
    HEAP32[$sp >> 2] = $155;
    var $required_0_ph = $required_0_ph4;
    var $_01_ph = $_1;
    var $15 = $19;
    __label__ = 2;
    break;
   case 40:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_ConvertArgumentsVA["X"] = 1;

function __ZN12JSValueArrayC1EPN2JS5ValueEj($this, $v, $c) {
  __ZN12JSValueArrayC2EPN2JS5ValueEj($this, $v, $c);
  return;
}

function __ZN16JSAutoByteStringC1Ev($this) {
  __ZN16JSAutoByteStringC2Ev($this);
  return;
}

function __ZN2js20GetFunctionNameBytesEP9JSContextP10JSFunctionP16JSAutoByteString($cx, $fun_0_4_val, $bytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($fun_0_4_val | 0) == 0) {
      var $_0 = STRING_TABLE._js_anonymous_str | 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $fun_0_4_val | 0;
    var $4 = __ZN16JSAutoByteString6encodeEP9JSContextP8JSString($bytes, $cx, $3);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ReportErrorNumber($cx, $errorCallback, $errorNumber) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $ap = __stackBase__;
  HEAP32[$ap >> 2] = arguments[_JS_ReportErrorNumber.length];
  var $2 = HEAP32[$ap >> 2];
  var $3 = __Z22js_ReportErrorNumberVAP9JSContextjPFPK19JSErrorFormatStringPvPKcjES4_jiPc($cx, 0, $errorCallback, $errorNumber, 1, $2);
  STACKTOP = __stackBase__;
  return;
}

function __ZN16JSAutoByteStringD1Ev($this_0_0_val) {
  __ZN16JSAutoByteStringD2Ev($this_0_0_val);
  return;
}

function _JS_ValueToUint16($cx, $_0_0_0_val$0, $_0_0_0_val$1, $ip) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var $v = __stackBase__;
  var $tvr = __stackBase__ + 8;
  var $1 = $v | 0;
  HEAP32[$1 >> 2] = $_0_0_0_val$0;
  HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
  __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr, $cx, $v);
  var $2 = __ZNK2js15AutoValueRooter5valueEv($tvr);
  var $3 = __ZN2js13ValueToUint16EP9JSContextRKN2JS5ValueEPt($cx, $2, $ip);
  var $4 = $3 & 1;
  __ZN2js15AutoValueRooterD1Ev($tvr);
  STACKTOP = __stackBase__;
  return $4;
}

function _JS_ValueToECMAInt32($cx, $_0_0_0_val$0, $_0_0_0_val$1, $ip) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var $v = __stackBase__;
  var $tvr = __stackBase__ + 8;
  var $1 = $v | 0;
  HEAP32[$1 >> 2] = $_0_0_0_val$0;
  HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
  __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr, $cx, $v);
  var $2 = __ZNK2js15AutoValueRooter5valueEv($tvr);
  var $3 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $2, $ip);
  var $4 = $3 & 1;
  __ZN2js15AutoValueRooterD1Ev($tvr);
  STACKTOP = __stackBase__;
  return $4;
}

function _JS_ValueToECMAUint32($cx, $_0_0_0_val$0, $_0_0_0_val$1, $ip) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var $v = __stackBase__;
  var $tvr = __stackBase__ + 8;
  var $1 = $v | 0;
  HEAP32[$1 >> 2] = $_0_0_0_val$0;
  HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
  __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr, $cx, $v);
  var $2 = __ZNK2js15AutoValueRooter5valueEv($tvr);
  var $3 = __ZN2js17ValueToECMAUint32EP9JSContextRKN2JS5ValueEPj($cx, $2, $ip);
  var $4 = $3 & 1;
  __ZN2js15AutoValueRooterD1Ev($tvr);
  STACKTOP = __stackBase__;
  return $4;
}

function _JS_ValueToInt32($cx, $_0_0_0_val$0, $_0_0_0_val$1, $ip) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var $v = __stackBase__;
  var $tvr = __stackBase__ + 8;
  var $1 = $v | 0;
  HEAP32[$1 >> 2] = $_0_0_0_val$0;
  HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
  __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr, $cx, $v);
  var $2 = __ZNK2js15AutoValueRooter5valueEv($tvr);
  var $3 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $2, $ip);
  var $4 = $3 & 1;
  __ZN2js15AutoValueRooterD1Ev($tvr);
  STACKTOP = __stackBase__;
  return $4;
}

function _JS_ValueToNumber($cx, $_0_0_0_val$0, $_0_0_0_val$1, $dp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var $v = __stackBase__;
  var $tvr = __stackBase__ + 8;
  var $1 = $v | 0;
  HEAP32[$1 >> 2] = $_0_0_0_val$0;
  HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
  __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr, $cx, $v);
  var $2 = __ZNK2js15AutoValueRooter5valueEv($tvr);
  var $3 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $2, $dp);
  var $4 = $3 & 1;
  __ZN2js15AutoValueRooterD1Ev($tvr);
  STACKTOP = __stackBase__;
  return $4;
}

function __ZL18js_DoubleToIntegerd($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d == 0) {
      var $_0 = $d;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL18JSDOUBLE_IS_FINITEd($d);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZL15JSDOUBLE_IS_NaNd($d);
    var $d_ = ($6 | 0) == 0 ? $d : 0;
    var $_0 = $d_;
    __label__ = 7;
    break;
   case 4:
    if ($d < 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = _floor($d);
    var $_0 = $10;
    __label__ = 7;
    break;
   case 6:
    var $12 = -$d;
    var $13 = _floor($12);
    var $_0 = -$13;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSString11ensureFixedEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSString10ensureFlatEP9JSContext($this, $cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx = $this | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $4 = __ZNK8JSString12isExtensibleEv($this_idx_val);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = $this_idx_val ^ 8;
    HEAP32[$this_idx >> 2] = $6;
    __label__ = 4;
    break;
   case 4:
    var $8 = __ZN8JSString7asFixedEv($this);
    var $_0 = $8;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _OBJECT_TO_JSVAL($agg_result, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL_IMPL284($1, $obj);
    var $_0 = $1 | 0;
    var $_0_val$0 = HEAP32[$_0 >> 2];
    var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
    __ZL13IMPL_TO_JSVAL12jsval_layout($agg_result, $_0_val$0, $_0_val$1);
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $6 = $agg_result | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20TryArgumentFormatterP9JSContextPPKciPPN2JS5ValueEPPc($cx, $formatp, $vpp, $app) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$formatp >> 2];
    var $map_0_in = $cx + 172 | 0;
    __label__ = 2;
    break;
   case 2:
    var $map_0_in;
    var $map_0 = HEAP32[$map_0_in >> 2];
    if (($map_0 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = HEAP32[$map_0 >> 2];
    var $9 = HEAP32[$map_0 + 4 >> 2];
    var $10 = _strncmp($1, $7, $9);
    if (($10 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = $1 + $9 | 0;
    HEAP32[$formatp >> 2] = $13;
    var $15 = HEAP32[$map_0 + 8 >> 2];
    var $16 = FUNCTION_TABLE[$15]($cx, $1, 1, $vpp, $app);
    var $_0 = $16;
    __label__ = 7;
    break;
   case 5:
    var $map_0_in = $map_0 + 12 | 0;
    __label__ = 2;
    break;
   case 6:
    _JS_ReportErrorNumber($cx, 4, 4, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $1, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ConvertValue($cx, $_0_0_0_val$0, $_0_0_0_val$1, $type, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $obj = __stackBase__ + 8;
    var $d = __stackBase__ + 12;
    var $1 = __stackBase__ + 20;
    var $2 = __stackBase__ + 28;
    var $3 = __stackBase__ + 36;
    var $4 = __stackBase__ + 44;
    var $numBuf = __stackBase__ + 52;
    var $5 = $v | 0;
    HEAP32[$5 >> 2] = $_0_0_0_val$0;
    HEAP32[$5 + 4 >> 2] = $_0_0_0_val$1;
    if (($type | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($type | 0) == 1) {
      __label__ = 3;
      break;
    } else if (($type | 0) == 2) {
      __label__ = 5;
      break;
    } else if (($type | 0) == 3) {
      __label__ = 6;
      break;
    } else if (($type | 0) == 4) {
      __label__ = 8;
      break;
    } else if (($type | 0) == 5) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 2:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $7$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $7$1 = HEAP32[$st$1$1 >> 2];
    var $8 = $vp | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    var $_0 = 1;
    __label__ = 12;
    break;
   case 3:
    var $10 = $cx;
    var $11 = $obj;
    var $12 = __Z22js_ValueToObjectOrNullP9JSContextRKN2JS5ValueEPP8JSObject($10, $v, $11);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = HEAP32[$obj >> 2];
    _OBJECT_TO_JSVAL($1, $15);
    var $16 = $1 | 0;
    var $st$3$0 = $16 | 0;
    var $17$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $16 + 4 | 0;
    var $17$1 = HEAP32[$st$3$1 >> 2];
    var $18 = $vp | 0;
    var $st$8$0 = $18 | 0;
    HEAP32[$st$8$0 >> 2] = $17$0;
    var $st$8$1 = $18 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $17$1;
    var $_0 = $12;
    __label__ = 12;
    break;
   case 5:
    var $20 = $vp | 0;
    var $st$1$0 = $20 | 0;
    HEAP32[$st$1$0 >> 2] = $_0_0_0_val$0;
    var $st$1$1 = $20 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $_0_0_0_val$1;
    var $21 = __Z24js_ValueToFunctionObjectP9JSContextPN2JS5ValueEj($cx, $vp, 65536);
    HEAP32[$obj >> 2] = $21;
    var $_0 = ($21 | 0) != 0 & 1;
    __label__ = 12;
    break;
   case 6:
    var $25 = $cx;
    var $26 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($25, $_0_0_0_val$0, $_0_0_0_val$1);
    var $27 = ($26 | 0) != 0;
    var $28 = $27 & 1;
    if ($27) {
      __label__ = 7;
      break;
    } else {
      var $_0 = $28;
      __label__ = 12;
      break;
    }
   case 7:
    _STRING_TO_JSVAL($2, $26);
    var $30 = $2 | 0;
    var $31$0 = HEAP32[$30 >> 2];
    var $31$1 = HEAP32[$30 + 4 >> 2];
    var $32 = $vp | 0;
    HEAP32[$32 >> 2] = $31$0;
    HEAP32[$32 + 4 >> 2] = $31$1;
    var $_0 = $28;
    __label__ = 12;
    break;
   case 8:
    var $34 = _JS_ValueToNumber($cx, $_0_0_0_val$0, $_0_0_0_val$1, $d);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $37 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    _DOUBLE_TO_JSVAL($3, $37);
    var $38 = $3 | 0;
    var $st$3$0 = $38 | 0;
    var $39$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $38 + 4 | 0;
    var $39$1 = HEAP32[$st$3$1 >> 2];
    var $40 = $vp | 0;
    var $st$8$0 = $40 | 0;
    HEAP32[$st$8$0 >> 2] = $39$0;
    var $st$8$1 = $40 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $39$1;
    var $_0 = $34;
    __label__ = 12;
    break;
   case 10:
    var $42 = __Z17js_ValueToBooleanRKN2JS5ValueE($v);
    _BOOLEAN_TO_JSVAL($4, $42);
    var $43 = $4 | 0;
    var $st$3$0 = $43 | 0;
    var $44$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $43 + 4 | 0;
    var $44$1 = HEAP32[$st$3$1 >> 2];
    var $45 = $vp | 0;
    var $st$8$0 = $45 | 0;
    HEAP32[$st$8$0 >> 2] = $44$0;
    var $st$8$1 = $45 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $44$1;
    var $_0 = 1;
    __label__ = 12;
    break;
   case 11:
    var $47 = $numBuf | 0;
    var $48 = _JS_snprintf($47, 12, STRING_TABLE.__str4498 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $type, tempInt));
    _JS_ReportErrorNumber($cx, 4, 5, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $47, tempInt));
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_ConvertValue["X"] = 1;

function _DOUBLE_TO_JSVAL($agg_result, $d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = isNaN($d) || isNaN(0);
    if ($1) {
      var $l_0_0$1 = 2146959360;
      var $l_0_0$0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $l_0_0$1 = tempDoubleI32[1];
    var $l_0_0$0 = tempDoubleI32[0];
    __label__ = 3;
    break;
   case 3:
    var $l_0_0$0;
    var $l_0_0$1;
    __ZL13IMPL_TO_JSVAL12jsval_layout($agg_result, $l_0_0$0, $l_0_0$1);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _BOOLEAN_TO_JSVAL($agg_result, $b) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BOOLEAN_TO_JSVAL_IMPL278($1, $b);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function _JS_ValueToObject($cx, $_0_0_0_val$0, $_0_0_0_val$1, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $v = __stackBase__;
  var $1 = $v | 0;
  HEAP32[$1 >> 2] = $_0_0_0_val$0;
  HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
  var $2 = $cx;
  var $3 = $objp;
  var $4 = __Z22js_ValueToObjectOrNullP9JSContextRKN2JS5ValueEPP8JSObject($2, $v, $3);
  STACKTOP = __stackBase__;
  return $4;
}

function _JS_ValueToFunction($cx, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $v = __stackBase__;
  var $1 = $v | 0;
  HEAP32[$1 >> 2] = $_0_0_0_val$0;
  HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
  var $2 = __Z18js_ValueToFunctionP9JSContextPKN2JS5ValueEj($cx, $v, 65536);
  STACKTOP = __stackBase__;
  return $2;
}

function _JS_ValueToString($cx, $_0_0_0_val$0, $_0_0_0_val$1) {
  var $1 = $cx;
  var $2 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($1, $_0_0_0_val$0, $_0_0_0_val$1);
  return $2;
}

function _JS_ValueToSource($cx, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $v = __stackBase__;
  var $1 = $v | 0;
  HEAP32[$1 >> 2] = $_0_0_0_val$0;
  HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
  var $2 = $cx;
  var $3 = __Z16js_ValueToSourceP9JSContextRKN2JS5ValueE($2, $v);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($this, $cx, $v) {
  __ZN2js15AutoValueRooterC2EP9JSContextRKN2JS5ValueE($this, $cx, $v);
  return;
}

function __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $v, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $1 = __ZNK2JS5Value8isNumberEv($v_idx_val$0, $v_idx_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toNumberEv($v);
    tempDoubleF64[0] = $3, HEAP32[$out >> 2] = tempDoubleI32[0], HEAP32[$out + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($cx, $v_idx_val$0, $v_idx_val$1, $out);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15AutoValueRooterD1Ev($this) {
  __ZN2js15AutoValueRooterD2Ev($this);
  return;
}

function __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $v, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx1 = $v | 0;
    var $v_idx1_val$0 = HEAP32[$v_idx1 >> 2];
    var $v_idx1_val$1 = HEAP32[$v_idx1 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx1_val$0, $v_idx1_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx1_val$0, $v_idx1_val$1);
    HEAP32[$out >> 2] = $3;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js20ValueToECMAInt32SlowEP9JSContextRKN2JS5ValueEPi($cx, $v, $out);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17ValueToECMAUint32EP9JSContextRKN2JS5ValueEPj($cx, $v, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx1 = $v | 0;
    var $v_idx1_val$0 = HEAP32[$v_idx1 >> 2];
    var $v_idx1_val$1 = HEAP32[$v_idx1 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx1_val$0, $v_idx1_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx1_val$0, $v_idx1_val$1);
    HEAP32[$out >> 2] = $3;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js21ValueToECMAUint32SlowEP9JSContextRKN2JS5ValueEPj($cx, $v, $out);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $v, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx1 = $v | 0;
    var $v_idx1_val$0 = HEAP32[$v_idx1 >> 2];
    var $v_idx1_val$1 = HEAP32[$v_idx1 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx1_val$0, $v_idx1_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx1_val$0, $v_idx1_val$1);
    HEAP32[$out >> 2] = $3;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js16ValueToInt32SlowEP9JSContextRKN2JS5ValueEPi($cx, $v, $out);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ValueToUint16EP9JSContextRKN2JS5ValueEPt($cx, $v, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx1 = $v | 0;
    var $v_idx1_val$0 = HEAP32[$v_idx1 >> 2];
    var $v_idx1_val$1 = HEAP32[$v_idx1 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx1_val$0, $v_idx1_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx1_val$0, $v_idx1_val$1);
    HEAP16[$out >> 1] = $3 & 65535;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN2js17ValueToUint16SlowEP9JSContextRKN2JS5ValueEPt($cx, $v, $out);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ValueToBoolean($_0_0_0_val$0, $_0_0_0_val$1, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $v = __stackBase__;
  var $1 = $v | 0;
  HEAP32[$1 >> 2] = $_0_0_0_val$0;
  HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
  var $2 = __Z17js_ValueToBooleanRKN2JS5ValueE($v);
  HEAP32[$bp >> 2] = $2;
  STACKTOP = __stackBase__;
  return;
}

function _JS_TypeOfValue($cx, $_0_0_0_val$0, $_0_0_0_val$1) {
  var $1 = __ZN2js11TypeOfValueEP9JSContextRKN2JS5ValueE($cx, $_0_0_0_val$0, $_0_0_0_val$1);
  return $1;
}

function _JS_SameValue($cx, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $same) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $v1 = __stackBase__;
  var $v2 = __stackBase__ + 8;
  var $1 = $v1 | 0;
  HEAP32[$1 >> 2] = $_0_0_0_val$0;
  HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
  var $2 = $v2 | 0;
  HEAP32[$2 >> 2] = $_0_0_0_val1$0;
  HEAP32[$2 + 4 >> 2] = $_0_0_0_val1$1;
  var $3 = __ZN2js9SameValueEP9JSContextRKN2JS5ValueES5_Pi($cx, $v1, $v2, $same);
  var $4 = $3 & 1;
  STACKTOP = __stackBase__;
  return $4;
}

function __ZN9JSRuntimeC2Ev($this) {
  var $1 = $this + 4 | 0;
  __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEEC1ES3_($1);
  var $2 = $this + 48 | 0;
  __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEEC1ES5_($2);
  var $3 = $this + 88 | 0;
  __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC1ES5_($3);
  var $4 = $this + 112 | 0;
  __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEEC1ES3_($4);
  var $5 = $this + 144280 | 0;
  __ZN2js10ThreadDataC2Ev($5);
  HEAP32[$this + 209940 >> 2] = 0;
  var $7 = $this + 209948 | 0;
  __ZN11JSAtomStateC1Ev($7);
  var $8 = $this + 210584 | 0;
  __ZN2js13StaticStringsC1Ev($8);
  var $9 = $this + 144140 | 0;
  HEAP32[$9 >> 2] = $9;
  HEAP32[$this + 144144 >> 2] = $9;
  var $12 = $this + 144228 | 0;
  HEAP32[$12 >> 2] = $12;
  HEAP32[$this + 144232 >> 2] = $12;
  return;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEEC1ES3_($this) {
  __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEEC2ES3_($this);
  return;
}

function __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEEC1ES5_($this) {
  __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEEC2ES5_($this);
  return;
}

function __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC1ES5_($this) {
  __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC2ES5_($this);
  return;
}

function __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEEC1ES3_($this) {
  __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEEC2ES3_($this);
  return;
}

function __ZN11JSAtomStateC1Ev($this) {
  __ZN11JSAtomStateC2Ev($this);
  return;
}

function __ZN2js13StaticStringsC1Ev($this) {
  __ZN2js13StaticStringsC2Ev($this);
  return;
}

function __ZN9JSRuntime4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z9js_InitGCP9JSRuntimej($this);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN9JSRuntime4new_I13JSCompartmentPS_EEPT_T0_($this, $this);
    var $5 = $this | 0;
    HEAP32[$5 >> 2] = $4;
    if (($4 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZN13JSCompartment4initEP9JSContext($4, 0);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this + 4 | 0;
    var $11 = HEAP32[$5 >> 2];
    var $12 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6appendIS2_EEbT_($10, $11);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = HEAP32[$5 >> 2];
    __ZN2js10Foreground7delete_I13JSCompartmentEEvPT_($13);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 6:
    HEAP8[HEAP32[$5 >> 2] + 341 | 0] = 1;
    var $17 = HEAP32[$5 >> 2];
    __ZN13JSCompartment14setGCLastBytesEj18JSGCInvocationKind($17, 8192, 0);
    var $18 = __Z16js_InitAtomStateP9JSRuntime($this);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$this + 229020 >> 2] = 42;
    HEAP8[$this + 144220 | 0] = 0;
    var $23 = __Z14js_InitThreadsP9JSRuntime($this);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $26 = __ZN2js22InitRuntimeNumberStateEP9JSRuntime($this);
    var $_0 = $26;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime4new_I13JSCompartmentPS_EEPT_T0_($this, $p1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSRuntime7malloc_EjP9JSContext($this, 1988, 0);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN13JSCompartmentC2EP9JSRuntime($4, $p1);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 4 >> 2] | 0) == (HEAP32[$this + 8 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Foreground7delete_I13JSCompartmentEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN13JSCompartmentD2Ev($p);
    var $3 = $p;
    _js_free272($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntimeD2Ev($this) {
  var $this_idx_val = HEAP32[$this + 144260 >> 2];
  __ZN2js24FinishRuntimeNumberStateEP9JSRuntime($this_idx_val);
  __Z18js_FinishAtomStateP9JSRuntime($this);
  __Z11js_FinishGCP9JSRuntime($this);
  var $1 = $this + 209948 | 0;
  __ZN11JSAtomStateD1Ev($1);
  var $2 = $this + 144280 | 0;
  __ZN2js10ThreadDataD2Ev($2);
  var $3 = $this + 112 | 0;
  __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEED1Ev($3);
  var $4 = $this + 88 | 0;
  __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED1Ev($4);
  var $5 = $this + 48 | 0;
  __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEED1Ev($5);
  var $6 = $this + 4 | 0;
  __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEED1Ev($6);
  return;
}

function __ZN11JSAtomStateD1Ev($this) {
  __ZN11JSAtomStateD2Ev($this);
  return;
}

function __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function _JS_GetContextPrivate($cx_0_24_val) {
  return $cx_0_24_val;
}

function _JS_GetRuntime($cx_0_11_val) {
  return $cx_0_11_val;
}

function _JS_PropertyStub($cx, $obj, $id, $vp) {
  return 1;
}

function _JS_StrictPropertyStub($cx, $obj, $id, $strict, $vp) {
  return 1;
}

function _JS_EnumerateStub($cx, $obj) {
  return 1;
}

function _JS_ResolveStub($cx, $obj, $id) {
  return 1;
}

function _JS_GetGlobalObject($cx_0_17_val) {
  return $cx_0_17_val;
}

function _JS_FinalizeStub($cx, $obj) {
  return;
}

function __ZN2jsL13VersionNumberE9JSVersion($version) {
  return $version & 4095;
}

function _JSID_TO_STRING243($iden) {
  return $iden;
}

function _JS_CANONICALIZE_NAN($d) {
  var $1 = isNaN($d) || isNaN(0);
  var $_d = $1 ? NaN : $d;
  return $_d;
}

function __ZN2js8ValueifyEP12JSStackFrame($fp) {
  return $fp;
}

function __ZN2jsL8ValueifyEP7JSClass($c) {
  return $c;
}

function _JS_SetContextPrivate($cx, $data) {
  HEAP32[$cx + 188 >> 2] = $data;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($this_0_0_val) {
  return $this_0_0_val + 8 | 0;
}

function _JS_SetNativeStackQuota($cx) {
  var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 209880 >> 2] + 499999 | 0;
  HEAP32[$cx + 48 >> 2] = $6;
  return;
}

function __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function _JS_Init() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU8[__ZL22js_NewRuntimeWasCalled_b]) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP8[__ZL22js_NewRuntimeWasCalled_b] = 1;
    __label__ = 3;
    break;
   case 3:
    var $3 = __ZN2js11OffTheBooks7calloc_Ej(234944);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $6 = $3;
    __ZN9JSRuntimeC2Ev($6);
    var $7 = __ZN9JSRuntime4initEj($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _JS_Finish($6);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11OffTheBooks7calloc_Ej($bytes) {
  var $1 = _js_calloc299($bytes);
  return $1;
}

function _JS_Finish($rt) {
  __ZN2js10Foreground7delete_I9JSRuntimeEEvPT_($rt);
  return;
}

function __ZN2js10Foreground7delete_I9JSRuntimeEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN9JSRuntimeD2Ev($p);
    var $3 = $p;
    _js_free272($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_NewContext($rt) {
  var $1 = __Z13js_NewContextP9JSRuntimej($rt);
  return $1;
}

function _JS_DestroyContext($cx) {
  __Z17js_DestroyContextP9JSContext20JSDestroyContextMode($cx, 2);
  return;
}

function _JS_DestroyContextNoGC($cx) {
  __Z17js_DestroyContextP9JSContext20JSDestroyContextMode($cx, 0);
  return;
}

function _JS_GetVersion($cx) {
  var $1 = __ZNK9JSContext11findVersionEv($cx);
  var $2 = __ZN2jsL13VersionNumberE9JSVersion($1);
  return $2;
}

function _JS_SetVersion($cx, $newVersion) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $newVersion;
    var $2 = __ZNK9JSContext11findVersionEv($cx);
    var $3 = __ZN2jsL13VersionNumberE9JSVersion($2);
    if (($3 | 0) == ($newVersion | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($newVersion | 0) != 0 & ($newVersion | 0) < 141) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2jsL16VersionCopyFlagsEP9JSVersionS0_($1, $2);
    var $9 = HEAP32[$1 >> 2];
    __ZN9JSContext20maybeOverrideVersionE9JSVersion($cx, $9);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return $3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16VersionCopyFlagsEP9JSVersionS0_($version, $from) {
  var $1 = HEAP32[$version >> 2];
  var $2 = __ZN2jsL13VersionNumberE9JSVersion($1);
  var $3 = __ZN2jsL19VersionExtractFlagsE9JSVersion($from);
  var $4 = $3 | $2;
  HEAP32[$version >> 2] = $4;
  return;
}

function __ZN9JSContext20maybeOverrideVersionE9JSVersion($this, $newVersion) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK9JSContext20canSetDefaultVersionEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN9JSContext17setDefaultVersionE9JSVersion($this, $newVersion);
    __label__ = 4;
    break;
   case 3:
    __ZN9JSContext15overrideVersionE9JSVersion($this, $newVersion);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetOptions($cx) {
  var $1 = __ZNK9JSContext10allOptionsEv($cx);
  return $1;
}

function __ZNK9JSContext10allOptionsEv($this) {
  var $this_idx_val = HEAP32[$this + 32 >> 2];
  var $1 = __ZNK9JSContext13getRunOptionsEv($this_idx_val);
  var $2 = __ZNK9JSContext17getCompileOptionsEv($this);
  return $2 | $1;
}

function _JS_SetOptions($cx, $options) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $lock = __stackBase__;
  var $2 = HEAP32[$cx + 52 >> 2];
  __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $2);
  var $3 = __ZL16SetOptionsCommonP9JSContextj($cx, $options);
  STACKTOP = __stackBase__;
  return;
}

function __ZL16SetOptionsCommonP9JSContextj($cx, $options) {
  var $1 = __ZNK9JSContext10allOptionsEv($cx);
  var $2 = $options & 524223;
  var $3 = $options & 64;
  __ZN9JSContext13setRunOptionsEj($cx, $2);
  __ZN9JSContext17setCompileOptionsEj($cx, $3);
  return $1;
}

function _JS_ToggleOptions($cx, $options) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $lock = __stackBase__;
  var $2 = HEAP32[$cx + 52 >> 2];
  __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $2);
  var $3 = __ZNK9JSContext10allOptionsEv($cx);
  var $4 = $3 ^ $options;
  var $5 = __ZL16SetOptionsCommonP9JSContextj($cx, $4);
  STACKTOP = __stackBase__;
  return $5;
}

function _JS_EnterCrossCompartmentCall($cx, $target) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext4new_IN2js15AutoCompartmentEPS_P8JSObjectEEPT_T0_T1_($cx, $cx, $target);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js15AutoCompartment5enterEv($1);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js10Foreground7delete_INS_15AutoCompartmentEEEvPT_($1);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $_0 = $1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext4new_IN2js15AutoCompartmentEPS_P8JSObjectEEPT_T0_T1_($this, $p1, $p2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 52);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($4, $p1, $p2);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Foreground7delete_INS_15AutoCompartmentEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js15AutoCompartmentD2Ev($p);
    var $3 = $p;
    _js_free272($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ConvertStub($cx, $obj, $type, $vp) {
  var $1 = $cx;
  var $2 = $obj;
  var $3 = __ZN2js12DefaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE($1, $2, $type, $vp);
  return $3;
}

function _JS_NewGlobalObject($cx, $clasp) {
  var $1 = __ZN2jsL8ValueifyEP7JSClass($clasp);
  var $2 = $cx;
  var $3 = $1;
  var $4 = __ZN2js12GlobalObject6createEP9JSContextPNS_5ClassE($2, $3);
  return $4;
}

function _JS_LeaveCrossCompartmentCall($call) {
  var $1 = $call;
  __ZN2js15AutoCompartment5leaveEv($1);
  __ZN2js10Foreground7delete_INS_15AutoCompartmentEEEvPT_($1);
  return;
}

function __ZN22JSAutoEnterCompartment5enterEP9JSContextP8JSObject($this, $cx, $target) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 56 >> 2];
    var $3 = __ZNK8JSObject14getCompartmentEv($target);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$this >> 2] = 1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $8 = _JS_EnterCrossCompartmentCall($cx, $target);
    HEAP32[$this >> 2] = $8;
    var $_0 = ($8 | 0) != 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject14getCompartmentEv($this) {
  var $1 = $this;
  var $2 = __ZNK2js2gc4Cell11compartmentEv($1);
  return $2;
}

function _JS_WrapObject($cx, $objp) {
  var $2 = HEAP32[$cx + 56 >> 2];
  var $3 = __ZN13JSCompartment4wrapEP9JSContextPP8JSObject($2, $cx, $objp);
  return $3 & 1;
}

function __ZN2JSL11ObjectValueER8JSObject239($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZNK2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 44,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($this, $newLength) {
  var $1 = $this + 12 | 0;
  var $2 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE7reserveEj($1, $newLength);
  return $2;
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($this, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  var $1 = $this + 12 | 0;
  __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE16infallibleAppendERKS2_($1, $v_0_0_0_val$0, $v_0_0_0_val$1);
  return;
}

function __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3putERKS2_S7_($this, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZNK2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE12lookupForAddERKS2_($p, $this, $k);
    var $_idx = $p | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $_idx_val_idx_val = HEAP32[$_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($1, $_idx_val_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($_idx_val);
    var $7 = $v | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $6 + 8 | 0;
    var $st$7$0 = $9 | 0;
    HEAP32[$st$7$0 >> 2] = $8$0;
    var $st$7$1 = $9 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $8$1;
    var $10 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrdeEv($_idx_val);
    var $_0 = $10;
    __label__ = 5;
    break;
   case 3:
    var $12 = __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S2_EENS5_13MapHashPolicyES4_E6AddPtrERKS2_SF_($this, $p, $k, $v);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx2_val = HEAP32[$_idx >> 2];
    var $14 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrdeEv($_idx2_val);
    var $_0 = $14;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_SetGlobalObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$cx + 132 >> 2] = $obj;
    var $2 = __ZNK9JSContext5hasfpEv($cx);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN9JSContext16resetCompartmentEv($cx);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_InitStandardClasses($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$cx + 132 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_SetGlobalObject($cx, $obj);
    __label__ = 3;
    break;
   case 3:
    var $6 = $obj;
    var $7 = __ZN8JSObject8asGlobalEv($6);
    var $8 = $cx;
    var $9 = __ZN2js12GlobalObject19initStandardClassesEP9JSContext($7, $8);
    return $9 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ResolveStandardClass($cx, $obj, $id, $resolved) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$resolved >> 2] = 0;
    var $3 = HEAP32[$cx + 52 >> 2];
    if ((HEAP32[$3 + 24 >> 2] | 0) == 3) {
      var $_0 = 1;
      __label__ = 25;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZL12JSID_IS_ATOMi242($id);
    if (($8 | 0) == 0) {
      var $_0 = 1;
      __label__ = 25;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = _JSID_TO_STRING243($id);
    var $13 = HEAP32[$3 + 209984 >> 2];
    if (($11 | 0) == ($13 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = $3 + 209948 | 0;
    var $i_0 = 0;
    __label__ = 6;
    break;
   case 5:
    var $19 = $13 | 0;
    HEAP32[$resolved >> 2] = 1;
    var $20 = __ZL12ATOM_TO_JSIDP6JSAtom244($19);
    __ZN2JSL14UndefinedValueEv245($1);
    var $21 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj, $cx, $20, $1, 10, 12, 6);
    var $_0 = $21;
    __label__ = 25;
    break;
   case 6:
    var $i_0;
    var $23 = __ZL20standard_class_atoms + ($i_0 << 4) | 0;
    if ((HEAP32[$23 >> 2] | 0) == 0) {
      var $i_1 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($11 | 0) == (HEAP32[$17 + HEAP32[__ZL20standard_class_atoms + ($i_0 << 4) + 4 >> 2] >> 2] | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 6;
    break;
   case 9:
    if (($23 | 0) == 0) {
      var $i_1 = 0;
      __label__ = 10;
      break;
    } else {
      var $stdnm_23 = $23;
      __label__ = 21;
      break;
    }
   case 10:
    var $i_1;
    var $39 = __ZL20standard_class_names + ($i_1 << 4) | 0;
    if ((HEAP32[$39 >> 2] | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $44 = __ZL13StdNameToAtomP9JSContextP9JSStdName($cx, $39);
    if (($44 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (($11 | 0) == ($44 | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i_1 = $i_1 + 1 | 0;
    __label__ = 10;
    break;
   case 14:
    if (($39 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      var $stdnm_23 = $39;
      __label__ = 21;
      break;
    }
   case 15:
    var $obj_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $53 = __ZNK8JSObject8getProtoEv($obj_idx_val_idx_val);
    if (($53 | 0) == 0) {
      var $i_2 = 0;
      __label__ = 16;
      break;
    } else {
      var $_0 = 1;
      __label__ = 25;
      break;
    }
   case 16:
    var $i_2;
    var $55 = __ZL22object_prototype_names + ($i_2 << 4) | 0;
    if ((HEAP32[$55 >> 2] | 0) == 0) {
      var $_0 = 1;
      __label__ = 25;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $60 = __ZL13StdNameToAtomP9JSContextP9JSStdName($cx, $55);
    if (($60 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if (($11 | 0) == ($60 | 0)) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $i_2 = $i_2 + 1 | 0;
    __label__ = 16;
    break;
   case 20:
    if (($55 | 0) == 0) {
      var $_0 = 1;
      __label__ = 25;
      break;
    } else {
      var $stdnm_23 = $55;
      __label__ = 21;
      break;
    }
   case 21:
    var $stdnm_23;
    var $72 = HEAP32[HEAP32[$stdnm_23 + 12 >> 2] + 4 >> 2];
    if (($72 & 131072 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 1;
      __label__ = 25;
      break;
    }
   case 22:
    var $76 = $obj;
    var $77 = __ZN2js23IsStandardClassResolvedEP8JSObjectPNS_5ClassE($76, $72);
    if ($77) {
      var $_0 = 1;
      __label__ = 25;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $80 = HEAP32[$stdnm_23 >> 2];
    var $81 = FUNCTION_TABLE[$80]($cx, $obj);
    if (($81 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    HEAP32[$resolved >> 2] = 1;
    var $_0 = 1;
    __label__ = 25;
    break;
   case 25:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_ResolveStandardClass["X"] = 1;

function __ZL12JSID_IS_ATOMi242($id) {
  var $1 = _JSID_IS_STRING293($id);
  return $1;
}

function __ZL12ATOM_TO_JSIDP6JSAtom244($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj300($1);
  return $2;
}

function __ZN2JSL14UndefinedValueEv245($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZL13StdNameToAtomP9JSContextP9JSStdName($cx, $stdn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$stdn + 4 >> 2];
    var $3 = $cx + 52 | 0;
    var $9 = HEAP32[HEAP32[$3 >> 2] + 209948 + $2 >> 2];
    if (($9 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $atom_0 = $9;
      __label__ = 4;
      break;
    }
   case 2:
    var $13 = HEAP32[$stdn + 8 >> 2];
    if (($13 | 0) == 0) {
      var $atom_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = _strlen($13);
    var $17 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $13, $16, 1);
    var $22 = HEAP32[$3 >> 2] + 209948 + $2 | 0;
    HEAP32[$22 >> 2] = $17;
    var $atom_0 = $17;
    __label__ = 4;
    break;
   case 4:
    var $atom_0;
    return $atom_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_EnumerateStandardClasses($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 209984 >> 2] | 0;
    var $7 = __ZL12ATOM_TO_JSIDP6JSAtom244($6);
    var $8 = __ZN8JSObject14nativeContainsEP9JSContexti($obj, $cx, $7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL14UndefinedValueEv245($1);
    var $10 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj, $cx, $7, $1, 10, 12, 6);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $obj;
    var $i_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_0;
    var $14 = __ZL20standard_class_atoms + ($i_0 << 4) | 0;
    if (($i_0 | 0) == 17) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx_val = HEAP32[HEAP32[__ZL20standard_class_atoms + ($i_0 << 4) + 12 >> 2] + 4 >> 2];
    var $20 = __ZN2js23IsStandardClassResolvedEP8JSObjectPNS_5ClassE($12, $_idx_val);
    if ($20) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = HEAP32[$14 >> 2];
    var $23 = FUNCTION_TABLE[$22]($cx, $obj);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 4;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject14nativeContainsEP9JSContexti($this, $cx, $id) {
  var $1 = __ZN8JSObject12nativeLookupEP9JSContexti($this, $cx, $id);
  return ($1 | 0) != 0;
}

function _JS_GetGlobalForScopeChain($cx) {
  var $1 = __ZN2jsL22GetGlobalForScopeChainEP9JSContext($cx);
  return $1 | 0;
}

function __ZN2jsL22GetGlobalForScopeChainEP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $scope = __stackBase__;
    var $1 = __ZNK9JSContext5hasfpEv($cx);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK9JSContext2fpEv($cx);
    var $4 = __ZNK2js10StackFrame10scopeChainEv($3);
    var $5 = $4;
    var $6 = __ZNK8JSObject9getGlobalEv($5);
    var $_0 = $6;
    __label__ = 5;
    break;
   case 3:
    var $10 = HEAP32[$cx + 132 >> 2];
    HEAP32[$scope >> 2] = $10;
    var $11 = $cx;
    var $12 = $scope;
    var $13 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($11, $12);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = HEAP32[$scope >> 2];
    var $17 = __ZN8JSObject8asGlobalEv($16);
    var $_0 = $17;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ComputeThis($agg_result, $cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $call = __stackBase__ + 8;
    __ZN12JSValueArrayC1EPN2JS5ValueEj($1, $vp, 2);
    __ZN2js18CallReceiverFromVpEPN2JS5ValueE($call, $vp);
    var $2 = __ZN2js16BoxNonStrictThisEP9JSContextRKNS_12CallReceiverE($cx, $call);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $4$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $4$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $5 = $agg_result | 0;
    HEAP32[$5 >> 2] = $4$0;
    HEAP32[$5 + 4 >> 2] = $4$1;
    __label__ = 4;
    break;
   case 3:
    var $call_idx_val = HEAP32[$call >> 2];
    var $7 = __ZNK2js12CallReceiver5thisvEv($call_idx_val);
    var $8 = $7 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $agg_result | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18CallReceiverFromVpEPN2JS5ValueE($agg_result, $vp) {
  var $1 = $vp + 16 | 0;
  __ZN2js20CallReceiverFromArgvEPN2JS5ValueE($agg_result, $1);
  return;
}

function _JS_malloc($cx, $nbytes) {
  var $1 = __ZN9JSContext7malloc_Ej($cx, $nbytes);
  return $1;
}

function _JS_realloc($cx, $p, $nbytes) {
  var $1 = __ZN9JSContext8realloc_EPvj($cx, $p, $nbytes);
  return $1;
}

function __ZN9JSContext8realloc_EPvj($this, $p, $bytes) {
  var $2 = HEAP32[$this + 52 >> 2];
  var $3 = __ZN9JSRuntime8realloc_EPvjP9JSContext($2, $p, $bytes, $this);
  return $3;
}

function _JS_free($p) {
  __ZN9JSContext5free_EPv($p);
  return;
}

function _JS_strdup($cx, $s) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _strlen($s);
    var $2 = $1 + 1 | 0;
    var $3 = __ZN9JSContext7malloc_Ej($cx, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _memcpy($3, $s, $2, 1);
    var $_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_NewNumberValue($d, $rval) {
  var $1 = _JS_CANONICALIZE_NAN($d);
  var $2 = __ZN2JS5Value9setNumberEd($rval, $1);
  return;
}

function _JS_AddValueRoot($cx, $vp) {
  var $1 = __Z10js_AddRootP9JSContextPN2JS5ValueEPKc($cx, $vp, 0);
  return $1;
}

function _JS_AddNamedStringRoot($cx, $rp) {
  var $1 = $rp;
  __Z17js_AddGCThingRootP9JSContextPPvPKc($cx, $1);
  return;
}

function _JS_RemoveValueRoot($cx_0_11_val, $vp) {
  var $1 = $vp;
  _js_RemoveRoot($cx_0_11_val, $1);
  return;
}

function _JS_RemoveStringRoot($cx_0_11_val, $rp) {
  var $1 = $rp;
  _js_RemoveRoot($cx_0_11_val, $1);
  return;
}

function _JS_ReportOutOfMemory($cx) {
  __Z20js_ReportOutOfMemoryP9JSContext($cx);
  return;
}

function _JS_TraceRuntime($trc) {
  __ZN2js12TraceRuntimeEP8JSTracer($trc);
  return;
}

function _JS_CallTracer($trc, $thing, $kind) {
  __ZN2js2gc8MarkKindEP8JSTracerPv13JSGCTraceKind($trc, $thing, $kind);
  return;
}

function _JS_CompartmentGC($cx, $comp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 72 | 0;
    if ((HEAP32[$cx + 88 >> 2] | 0) == ($1 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_FinishArenaPool($1);
    __label__ = 3;
    break;
   case 3:
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[__ZN2js8gcReasonE >> 2] = 0;
    __label__ = 6;
    break;
   case 5:
    var $12 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $12;
    __label__ = 6;
    break;
   case 6:
    __Z5js_GCP9JSContextP13JSCompartment18JSGCInvocationKind($cx, $comp, 0);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_MaybeGC($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 72 | 0;
    if ((HEAP32[$cx + 88 >> 2] | 0) == ($1 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_FinishArenaPool($1);
    __label__ = 3;
    break;
   case 3:
    __ZN2js7MaybeGCEP9JSContext($cx);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_SetGCParameter($rt, $key, $value) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($key | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($key | 0) == 1) {
      __label__ = 3;
      break;
    } else if (($key | 0) == 2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    HEAP32[$rt + 152 >> 2] = $value;
    __label__ = 6;
    break;
   case 3:
    __ZN9JSRuntime19setGCMaxMallocBytesEj($rt, $value);
    __label__ = 6;
    break;
   case 4:
    HEAP32[$rt + 160 >> 2] = $value;
    __label__ = 6;
    break;
   case 5:
    HEAP32[$rt + 192 >> 2] = $value;
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime19setGCMaxMallocBytesEj($this, $value) {
  var $2 = ($value | 0) > -1 ? $value : 2147483647;
  HEAP32[$this + 156 >> 2] = $2;
  __ZN9JSRuntime18resetGCMallocBytesEv($this);
  return;
}

function _JS_GetGCParameter($rt, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($key | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($key | 0) == 1) {
      __label__ = 3;
      break;
    } else if (($key | 0) == 2) {
      __label__ = 4;
      break;
    } else if (($key | 0) == 3) {
      __label__ = 5;
      break;
    } else if (($key | 0) == 6) {
      __label__ = 6;
      break;
    } else if (($key | 0) == 7) {
      __label__ = 7;
      break;
    } else if (($key | 0) == 8) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    var $_0 = HEAP32[$rt + 152 >> 2];
    __label__ = 10;
    break;
   case 3:
    var $_0 = HEAP32[$rt + 156 >> 2];
    __label__ = 10;
    break;
   case 4:
    var $_0 = HEAP32[$rt + 160 >> 2];
    __label__ = 10;
    break;
   case 5:
    var $_0 = HEAP32[$rt + 140 >> 2];
    __label__ = 10;
    break;
   case 6:
    var $_0 = HEAP32[$rt + 192 >> 2];
    __label__ = 10;
    break;
   case 7:
    var $_0 = HEAP32[$rt + 84 >> 2];
    __label__ = 10;
    break;
   case 8:
    var $20 = $rt + 48 | 0;
    var $21 = __ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE5countEv($20);
    var $_0 = HEAP32[$rt + 84 >> 2] + $21 | 0;
    __label__ = 10;
    break;
   case 9:
    var $_0 = HEAP32[$rt + 164 >> 2];
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE5countEv($this) {
  var $_idx_val = HEAP32[$this + 8 >> 2];
  var $1 = __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5countEv($_idx_val);
  return $1;
}

function _JS_DestroyIdArray($ida) {
  var $1 = $ida;
  __ZN9JSContext5free_EPv($1);
  return;
}

function _JS_InitClass($cx, $obj) {
  var $1 = __ZN2jsL8ValueifyEP7JSClass(__ZL8pm_class);
  var $2 = $cx;
  var $3 = $obj;
  var $4 = $1;
  var $5 = __Z12js_InitClassP9JSContextP8JSObjectS2_PN2js5ClassEPFiS0_jPN2JS5ValueEEjP14JSPropertySpecP14JSFunctionSpecSC_SE_PS2_($2, $3, 0, $4, 46, 1, __ZL8pm_props, __ZL6pm_fns, 0);
  return $5;
}

function _JS_GetClass($obj_0_1_val) {
  var $1 = __ZNK8JSObject10getJSClassEv($obj_0_1_val);
  return $1;
}

function __ZNK8JSObject10getJSClassEv($this_0_1_val) {
  var $1 = __ZN2jsL8JsvalifyEPNS_5ClassE($this_0_1_val);
  return $1;
}

function __ZNK8JSObject8slotSpanEv($this_0_0_val_0_1_val) {
  return $this_0_0_val_0_1_val;
}

function __ZNK8JSObject9isNewbornEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function _INT_TO_JSID250($i) {
  return $i << 1 | 1;
}

function _JS_InstanceOf($cx, $obj, $argv) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $3 = __ZNK8JSObject10getJSClassEv($obj_idx_val);
    if (($3 | 0) == (__ZL8pm_class | 0)) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($argv | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = $argv - 16 | 0;
    var $9 = __ZN2jsL8ValueifyEP7JSClass(__ZL8pm_class);
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $8, $9);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_HasInstance($cx, $obj, $_0_0_0_val$0, $_0_0_0_val$1, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $v = __stackBase__;
  var $1 = $v | 0;
  HEAP32[$1 >> 2] = $_0_0_0_val$0;
  HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
  var $2 = __ZN2js11HasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPi($cx, $obj, $v, $bp);
  STACKTOP = __stackBase__;
  return $2;
}

function _JS_GetPrivate($obj_0_6_val) {
  var $1 = __ZNK8JSObject10getPrivateEv($obj_0_6_val);
  return $1;
}

function _JS_SetPrivate($obj, $data) {
  __ZN8JSObject10setPrivateEPv($obj, $data);
  return;
}

function _JS_GetInstancePrivate($cx, $obj, $argv) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JS_InstanceOf($cx, $obj, $argv);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $obj_idx_val = HEAP32[$obj + 24 >> 2];
    var $4 = __ZNK8JSObject10getPrivateEv($obj_idx_val);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetParent($obj_0_5_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject9getParentEv($obj_0_5_val);
    if (($1 | 0) == 0) {
      var $7 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$1 >> 2];
    var $4 = __ZNK8JSObject9isNewbornEv($_idx_val);
    if ($4) {
      var $7 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $1;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetConstructor($cx, $proto) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cval = __stackBase__;
    var $rf = __stackBase__ + 8;
    var $funobj = __stackBase__ + 16;
    __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $cx, 1);
    var $4 = HEAP32[HEAP32[$cx + 52 >> 2] + 210204 >> 2];
    var $5 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($proto, $cx, $4, $cval);
    var $6 = ($5 | 0) == 0;
    var $rf_idx_val = HEAP32[$rf >> 2];
    var $rf_idx1_val = HEAP32[$rf + 4 >> 2];
    __ZN18JSAutoResolveFlagsD1Ev($rf_idx_val, $rf_idx1_val);
    if ($6) {
      var $_1 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $cval_idx2 = $cval | 0;
    var $cval_idx2_val$0 = HEAP32[$cval_idx2 >> 2];
    var $cval_idx2_val$1 = HEAP32[$cval_idx2 + 4 >> 2];
    var $8 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject246($cval_idx2_val$0, $cval_idx2_val$1, $funobj);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $proto_idx_val = HEAP32[$proto + 4 >> 2];
    var $10 = __ZNK8JSObject8getClassEv($proto_idx_val);
    var $12 = HEAP32[$10 >> 2];
    _JS_ReportErrorNumber($cx, 4, 9, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $12, tempInt));
    var $_1 = 0;
    __label__ = 5;
    break;
   case 4:
    var $cval_idx_val$0 = HEAP32[$cval_idx2 >> 2];
    var $cval_idx_val$1 = HEAP32[$cval_idx2 + 4 >> 2];
    var $14 = __ZNK2JS5Value8toObjectEv($cval_idx_val$0, $cval_idx_val$1);
    var $_1 = $14;
    __label__ = 5;
    break;
   case 5:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18JSAutoResolveFlagsC1EP9JSContextj($this, $cx, $flags) {
  __ZN18JSAutoResolveFlagsC2EP9JSContextj($this, $cx, $flags);
  return;
}

function __ZN18JSAutoResolveFlagsD1Ev($this_0_0_val, $this_0_1_val) {
  __ZN18JSAutoResolveFlagsD2Ev($this_0_0_val, $this_0_1_val);
  return;
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject246($v_0_0_0_val$0, $v_0_0_0_val$1, $funobj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    HEAP32[$funobj >> 2] = $3;
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZNK8JSObject10isFunctionEv($_idx_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_NewCompartmentAndGlobalObject($cx, $clasp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $hold = __stackBase__;
    var $1 = __ZN2js2gc14NewCompartmentEP9JSContextP12JSPrincipals($cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN19AutoHoldCompartmentC1EP13JSCompartment($hold, $1);
    var $5 = HEAP32[$cx + 56 >> 2];
    var $6 = $cx;
    var $7 = $1;
    __ZN9JSContext14setCompartmentEP13JSCompartment($6, $7);
    var $8 = _JS_NewGlobalObject($cx, $clasp);
    var $9 = $5;
    __ZN9JSContext14setCompartmentEP13JSCompartment($6, $9);
    var $hold_idx_val = HEAP32[$hold >> 2];
    __ZN19AutoHoldCompartmentD1Ev($hold_idx_val);
    var $_0 = $8;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN19AutoHoldCompartmentC1EP13JSCompartment($this, $compartment) {
  __ZN19AutoHoldCompartmentC2EP13JSCompartment($this, $compartment);
  return;
}

function __ZN19AutoHoldCompartmentD1Ev($this_0_0_val) {
  __ZN19AutoHoldCompartmentD2Ev($this_0_0_val);
  return;
}

function _JS_NewObject($cx, $jsclasp, $proto, $parent) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL8ValueifyEP7JSClass($jsclasp);
    var $clasp_0 = ($1 | 0) == 0 ? __ZN2js11ObjectClassE : $1;
    if (($proto | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 1);
    __label__ = 3;
    break;
   case 3:
    var $7 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, $clasp_0, $proto, $parent);
    if (($7 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP32[$clasp_0 + 68 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj($cx, $7, 2097152);
    __label__ = 6;
    break;
   case 6:
    var $15 = $7;
    __ZN8JSObject19syncSpecialEqualityEv($15);
    var $_idx_val = HEAP32[$7 + 36 >> 2];
    var $16 = __ZNK8JSObject4typeEv($_idx_val);
    __ZN2js5types31MarkTypeObjectUnknownPropertiesEP9JSContextPNS0_10TypeObjectEb($cx, $16, 0);
    __label__ = 7;
    break;
   case 7:
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, $clasp, $proto, $parent) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb264($4);
  var $6 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE($cx, $clasp, $proto, $parent, $5);
  return $6;
}

function __ZN2js5types31MarkTypeObjectUnknownPropertiesEP9JSContextPNS0_10TypeObjectEb($cx, $obj, $markSetsUnknown) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $obj_idx = $obj + 12 | 0;
    var $obj_idx_val = HEAP32[$obj_idx >> 2];
    var $3 = __ZN2js5types10TypeObject17unknownPropertiesEv($obj_idx_val);
    if ($3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js5types10TypeObject11markUnknownEP9JSContext($obj, $cx);
    __label__ = 4;
    break;
   case 4:
    if ($markSetsUnknown) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    if ((HEAP32[$obj_idx >> 2] & 8 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js5types15TypeCompartment15markSetsUnknownEP9JSContextPNS0_10TypeObjectE($cx, $obj);
    __label__ = 7;
    break;
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_NewObjectWithGivenProto($cx, $jsclasp, $proto, $parent) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL8ValueifyEP7JSClass($jsclasp);
    var $clasp_0 = ($1 | 0) == 0 ? __ZN2js11ObjectClassE : $1;
    var $3 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_247($cx, $clasp_0, $proto, $parent);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    __ZN8JSObject19syncSpecialEqualityEv($6);
    var $_idx_val = HEAP32[$3 + 36 >> 2];
    var $7 = __ZNK8JSObject4typeEv($_idx_val);
    __ZN2js5types31MarkTypeObjectUnknownPropertiesEP9JSContextPNS0_10TypeObjectEb($cx, $7, 0);
    __label__ = 3;
    break;
   case 3:
    return $3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_247($cx, $clasp, $proto, $parent) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb264($4);
  var $6 = __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE271($cx, $clasp, $proto, $parent, $5);
  return $6;
}

function _JS_NewObjectForConstructor($cx, $vp_0_0_0_val$0, $vp_0_0_0_val$1) {
  var $1 = _JSVAL_TO_OBJECT($vp_0_0_0_val$0, $vp_0_0_0_val$1);
  var $2 = $cx;
  var $3 = $1;
  var $4 = __Z13js_CreateThisP9JSContextP8JSObject($2, $3);
  return $4;
}

function _JSVAL_TO_OBJECT($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_OBJECT_IMPL296($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JS_FreezeObject($cx, $obj) {
  var $1 = __ZN8JSObject6freezeEP9JSContext($obj, $cx);
  return $1 & 1;
}

function __ZNK2JS5Value11isPrimitiveEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_IS_PRIMITIVE_IMPL($this_0_0_0_val$0, $this_0_0_0_val$1);
  return ($1 | 0) != 0;
}

function __ZL18LookupPropertyByIdP9JSContextP8JSObjectijPS2_PP10JSProperty($cx, $obj, $id, $flags, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $rf = __stackBase__;
  __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $cx, $flags);
  var $1 = __Z22js_CheckForStringIndexi($id);
  var $2 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($obj, $cx, $1, $objp, $propp);
  var $rf_idx_val = HEAP32[$rf >> 2];
  var $rf_idx1_val = HEAP32[$rf + 4 >> 2];
  __ZN18JSAutoResolveFlagsD1Ev($rf_idx_val, $rf_idx1_val);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($index >>> 0 < 1073741824) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = _INT_TO_JSID250($index);
    HEAP32[$idp >> 2] = $3;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js13IndexToIdSlowEP9JSContextjPi($cx, $index, $idp);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($this, $cx, $id, $objp, $propp) {
  var $this_idx_val = HEAP32[$this + 4 >> 2];
  var $1 = __ZNK8JSObject6getOpsEv($this_idx_val);
  var $3 = HEAP32[$1 + 4 >> 2];
  var $5 = ($3 | 0) != 0 ? $3 : 48;
  var $6 = FUNCTION_TABLE[$5]($cx, $this, $id, $objp, $propp);
  return $6;
}

function _JS_HasPropertyById($cx, $obj, $id, $foundp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $obj2 = __stackBase__;
  var $prop = __stackBase__ + 4;
  var $1 = __ZL18LookupPropertyByIdP9JSContextP8JSObjectijPS2_PP10JSProperty($cx, $obj, $id, 5, $obj2, $prop);
  var $4 = (HEAP32[$prop >> 2] | 0) != 0 & 1;
  HEAP32[$foundp >> 2] = $4;
  STACKTOP = __stackBase__;
  return $1;
}

function _JS_DefinePropertyById($cx, $obj, $id, $_0_0_0_val$0, $_0_0_0_val$1, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $value = __stackBase__;
  var $1 = $value | 0;
  HEAP32[$1 >> 2] = $_0_0_0_val$0;
  HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
  var $2 = __ZL18DefinePropertyByIdP9JSContextP8JSObjectiRKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ejji($cx, $obj, $id, $value, $getter, $setter, $attrs, 0, 0);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL18DefinePropertyByIdP9JSContextP8JSObjectiRKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ejji($cx, $obj, $id, $value, $getter, $setter, $attrs, $flags, $tinyid) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $rf = __stackBase__;
    __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $cx, 9);
    if (($flags | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $obj_idx_val = HEAP32[$obj >> 2];
    var $3 = __ZNK8JSObject8isNativeEv($obj_idx_val);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = $cx;
    var $6 = $obj;
    var $7 = $getter;
    var $8 = $setter;
    var $9 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($5, $6, $id, $value, $7, $8, $attrs, $flags, $tinyid, 0);
    var $_0 = ($9 | 0) != 0 & 1;
    __label__ = 5;
    break;
   case 4:
    var $13 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj, $cx, $id, $value, $getter, $setter, $attrs);
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    var $rf_idx_val = HEAP32[$rf >> 2];
    var $rf_idx1_val = HEAP32[$rf + 4 >> 2];
    __ZN18JSAutoResolveFlagsD1Ev($rf_idx_val, $rf_idx1_val);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DefineElement($cx, $obj, $index, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $value = __stackBase__;
    var $id = __stackBase__ + 8;
    var $1 = $value | 0;
    HEAP32[$1 >> 2] = $_0_0_0_val$0;
    HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL18DefinePropertyByIdP9JSContextP8JSObjectiRKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ejji($cx, $obj, $4, $value, 0, 0, 1, 0, 0);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DefineProperty($cx, $obj, $name, $_0_0_0_val$0, $_0_0_0_val$1, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $value = __stackBase__;
  var $1 = $value | 0;
  HEAP32[$1 >> 2] = $_0_0_0_val$0;
  HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
  var $2 = __ZL14DefinePropertyP9JSContextP8JSObjectPKcRKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ejji($cx, $obj, $name, $value, $getter, $setter, $attrs, 0, 0);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL14DefinePropertyP9JSContextP8JSObjectPKcRKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ejji($cx, $obj, $name, $value, $getter, $setter, $attrs, $flags, $tinyid) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($attrs & 128 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $name;
    var $5 = _INT_TO_JSID250($4);
    var $id_0 = $5;
    var $_01 = $attrs & -129;
    __label__ = 5;
    break;
   case 3:
    var $8 = _strlen($name);
    var $9 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $8, 0);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = __ZL12ATOM_TO_JSIDP6JSAtom244($9);
    var $id_0 = $12;
    var $_01 = $attrs;
    __label__ = 5;
    break;
   case 5:
    var $_01;
    var $id_0;
    if (($_01 & 8 | 0) == 0) {
      var $_2 = $_01;
      var $_02 = $setter;
      var $_14 = $getter;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = $_01 & -9;
    if (($getter | 0) == 0) {
      var $_1 = $17;
      var $_03 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = $getter;
    var $21 = $obj;
    var $22 = __ZNK8JSObject9getGlobalEv($21);
    var $23 = $22;
    var $24 = _JS_NewFunction($cx, $20, 0, $23);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_1 = $17 | 16;
    var $_03 = $24;
    __label__ = 9;
    break;
   case 9:
    var $_03;
    var $_1;
    if (($setter | 0) == 0) {
      var $_2 = $_1;
      var $_02 = 0;
      var $_14 = $_03;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $32 = $setter;
    var $33 = $obj;
    var $34 = __ZNK8JSObject9getGlobalEv($33);
    var $35 = $34;
    var $36 = _JS_NewFunction($cx, $32, 1, $35);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_2 = $_1 | 32;
    var $_02 = $36;
    var $_14 = $_03;
    __label__ = 12;
    break;
   case 12:
    var $_14;
    var $_02;
    var $_2;
    var $42 = __ZL18DefinePropertyByIdP9JSContextP8JSObjectiRKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ejji($cx, $obj, $id_0, $value, $_14, $_02, $_2, $flags, $tinyid);
    var $_0 = $42;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14DefinePropertyP9JSContextP8JSObjectPKcRKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ejji["X"] = 1;

function _JS_DefineObject($cx, $obj, $name, $jsclasp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN2jsL8ValueifyEP7JSClass($jsclasp);
    var $clasp_0 = ($2 | 0) == 0 ? __ZN2js11ObjectClassE : $2;
    var $4 = __ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, $clasp_0, $obj);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4;
    __ZN8JSObject19syncSpecialEqualityEv($7);
    __ZN2JSL11ObjectValueER8JSObject239($1, $4);
    var $8 = __ZL14DefinePropertyP9JSContextP8JSObjectPKcRKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ejji($cx, $obj, $name, $1, 0, 0, 0, 0, 0);
    var $_ = ($8 | 0) == 0 ? 0 : $4;
    var $_0 = $_;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, $clasp, $parent) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb264($4);
  var $6 = __ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE($cx, $clasp, $parent, $5);
  return $6;
}

function _JS_DefineConstDoubles($cx, $obj, $cds) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $value = __stackBase__;
    var $ok_0 = 1;
    var $_0 = $cds;
    __label__ = 2;
    break;
   case 2:
    var $_0;
    var $ok_0;
    var $2 = $_0 + 8 | 0;
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      var $ok_1 = $ok_0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = $_0 | 0;
    var $7 = (tempDoubleI32[0] = HEAP32[$6 >> 2], tempDoubleI32[1] = HEAP32[$6 + 4 >> 2], tempDoubleF64[0]);
    __ZN2JSL11DoubleValueEd($value, $7);
    var $9 = HEAPU8[$_0 + 12 | 0];
    var $attrs_0 = $9 << 24 >> 24 == 0 ? 6 : $9 & 255;
    var $12 = HEAP32[$2 >> 2];
    var $13 = __ZL14DefinePropertyP9JSContextP8JSObjectPKcRKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ejji($cx, $obj, $12, $value, 0, 0, $attrs_0, 0, 0);
    if (($13 | 0) == 0) {
      var $ok_1 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $ok_0 = $13;
    var $_0 = $_0 + 16 | 0;
    __label__ = 2;
    break;
   case 5:
    var $ok_1;
    STACKTOP = __stackBase__;
    return $ok_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11DoubleValueEd($agg_result, $dbl) {
  __ZN2JS5Value9setDoubleEd($agg_result, $dbl);
  return;
}

function _JS_DefineProperties($cx, $obj, $ps) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $ok_0 = 1;
    var $_0 = $ps;
    __label__ = 2;
    break;
   case 2:
    var $_0;
    var $ok_0;
    var $4 = HEAPU32[$_0 >> 2];
    if (($4 | 0) == 0) {
      var $ok_1 = $ok_0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JSL14UndefinedValueEv245($1);
    var $8 = HEAP32[$_0 + 8 >> 2];
    var $10 = HEAP32[$_0 + 12 >> 2];
    var $13 = HEAPU8[$_0 + 5 | 0] & 255;
    var $16 = HEAP8[$_0 + 4 | 0] << 24 >> 24;
    var $17 = __ZL14DefinePropertyP9JSContextP8JSObjectPKcRKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ejji($cx, $obj, $4, $1, $8, $10, $13, 64, $16);
    if (($17 | 0) == 0) {
      var $ok_1 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $ok_0 = $17;
    var $_0 = $_0 + 16 | 0;
    __label__ = 2;
    break;
   case 5:
    var $ok_1;
    STACKTOP = __stackBase__;
    return $ok_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetPropertyDescriptorById($cx, $obj, $id, $desc) {
  var $1 = __ZL25GetPropertyDescriptorByIdP9JSContextP8JSObjectijiP20JSPropertyDescriptor($cx, $obj, $id, $desc);
  return $1;
}

function __ZL25GetPropertyDescriptorByIdP9JSContextP8JSObjectijiP20JSPropertyDescriptor($cx, $obj, $id, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj2 = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $rf = __stackBase__ + 8;
    var $1 = __ZL18LookupPropertyByIdP9JSContextP8JSObjectijPS2_PP10JSProperty($cx, $obj, $id, 1, $obj2, $prop);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$prop >> 2];
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[$desc >> 2] = 0;
    HEAP32[$desc + 4 >> 2] = 0;
    HEAP32[$desc + 8 >> 2] = 0;
    HEAP32[$desc + 12 >> 2] = 0;
    var $11 = $desc + 16 | 0;
    __ZN2JS5Value12setUndefinedEv($11);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 4:
    var $13 = HEAPU32[$obj2 >> 2];
    HEAP32[$desc >> 2] = $13;
    var $_idx3 = $13 | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $15 = __ZNK8JSObject8isNativeEv($_idx3_val);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 5:
    var $17 = $4;
    var $_idx7_val = HEAP8[$17 + 28 | 0];
    var $18 = __ZNK2js5Shape10attributesEv($_idx7_val);
    var $19 = $18 & 255;
    HEAP32[$desc + 4 >> 2] = $19;
    var $_idx2_val = HEAP8[$17 + 29 | 0];
    var $21 = __ZNK2js5Shape8isMethodEv($_idx2_val);
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$desc + 8 >> 2] = 10;
    HEAP32[$desc + 12 >> 2] = 12;
    var $25 = $desc + 16 | 0;
    var $26 = __ZNK2js5Shape12methodObjectEv($17);
    __ZN2JS5Value9setObjectER8JSObject($25, $26);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 7:
    var $_idx_val = HEAP32[$17 + 16 >> 2];
    var $28 = __ZNK2js5Shape6getterEv($_idx_val);
    HEAP32[$desc + 8 >> 2] = $28;
    var $_idx1_val = HEAP32[$17 + 20 >> 2];
    var $30 = __ZNK2js5Shape6setterEv($_idx1_val);
    HEAP32[$desc + 12 >> 2] = $30;
    var $33 = HEAP32[$17 + 24 >> 2];
    var $_idx4_val_idx_val = HEAP32[HEAP32[$_idx3 >> 2] + 4 >> 2];
    var $34 = __ZNK8JSObject12containsSlotEj($_idx4_val_idx_val, $33);
    var $35 = $desc + 16 | 0;
    if ($34) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $37 = __ZNK8JSObject13nativeGetSlotEj($13, $33);
    var $38 = $37 | 0;
    var $39$0 = HEAP32[$38 >> 2];
    var $39$1 = HEAP32[$38 + 4 >> 2];
    var $40 = $35 | 0;
    HEAP32[$40 >> 2] = $39$0;
    HEAP32[$40 + 4 >> 2] = $39$1;
    var $_0 = 1;
    __label__ = 14;
    break;
   case 9:
    __ZN2JS5Value12setUndefinedEv($35);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 10:
    var $_idx6_val = HEAP32[$13 + 4 >> 2];
    var $43 = __ZNK8JSObject7isProxyEv($_idx6_val);
    if ($43) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $cx, 1);
    var $45 = HEAP32[$obj2 >> 2];
    var $46 = __ZN2js7JSProxy21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($cx, $45, $id, 0, $desc);
    var $47 = $46 & 1;
    var $rf_idx_val = HEAP32[$rf >> 2];
    var $rf_idx5_val = HEAP32[$rf + 4 >> 2];
    __ZN18JSAutoResolveFlagsD1Ev($rf_idx_val, $rf_idx5_val);
    var $_0 = $47;
    __label__ = 14;
    break;
   case 12:
    var $49 = $desc + 4 | 0;
    var $50 = __ZN8JSObject13getAttributesEP9JSContextiPj($13, $cx, $id, $49);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    HEAP32[$desc + 8 >> 2] = 0;
    HEAP32[$desc + 12 >> 2] = 0;
    var $55 = $desc + 16 | 0;
    __ZN2JS5Value12setUndefinedEv($55);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL25GetPropertyDescriptorByIdP9JSContextP8JSObjectijiP20JSPropertyDescriptor["X"] = 1;

function _JS_GetPropertyById($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $rf = __stackBase__;
  __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $cx, 1);
  var $1 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($obj, $cx, $id, $vp);
  var $rf_idx_val = HEAP32[$rf >> 2];
  var $rf_idx1_val = HEAP32[$rf + 4 >> 2];
  __ZN18JSAutoResolveFlagsD1Ev($rf_idx_val, $rf_idx1_val);
  STACKTOP = __stackBase__;
  return $1;
}

function _JS_GetProperty($cx, $obj, $name, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _strlen($name);
    var $2 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $1, 0);
    if (($2 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL12ATOM_TO_JSIDP6JSAtom244($2);
    var $6 = _JS_GetPropertyById($cx, $obj, $5, $vp);
    var $9 = ($6 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_SetPropertyById($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $rf = __stackBase__;
  __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $cx, 3);
  var $1 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($obj, $cx, $id, $vp, 0);
  var $rf_idx_val = HEAP32[$rf >> 2];
  var $rf_idx1_val = HEAP32[$rf + 4 >> 2];
  __ZN18JSAutoResolveFlagsD1Ev($rf_idx_val, $rf_idx1_val);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($this, $cx, $id, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $1 = __ZNK8JSObject6getOpsEv($this_idx_val);
    if ((HEAP32[$1 + 52 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $this;
    var $7 = $cx;
    var $8 = __ZN8JSObject20nonNativeSetPropertyEP9JSContextiPN2JS5ValueEi($6, $7, $id, $vp, $strict);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 3:
    var $10 = $cx;
    var $11 = $this;
    var $12 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($10, $11, $id, 0, $vp, $strict);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_SetElement($cx, $obj, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = _INT_TO_JSID250($index);
    var $4 = _JS_SetPropertyById($cx, $obj, $3, $vp);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_SetProperty($cx, $obj, $name, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _strlen($name);
    var $2 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $1, 0);
    if (($2 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL12ATOM_TO_JSIDP6JSAtom244($2);
    var $6 = _JS_SetPropertyById($cx, $obj, $5, $vp);
    var $9 = ($6 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DeletePropertyById2($cx, $obj, $id, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $rf = __stackBase__;
  __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $cx, 1);
  var $1 = __ZN8JSObject14deletePropertyEP9JSContextiPN2JS5ValueEi($obj, $cx, $id, $rval, 0);
  var $rf_idx_val = HEAP32[$rf >> 2];
  var $rf_idx1_val = HEAP32[$rf + 4 >> 2];
  __ZN18JSAutoResolveFlagsD1Ev($rf_idx_val, $rf_idx1_val);
  STACKTOP = __stackBase__;
  return $1;
}

function _JS_ClearScope($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj_idx2 = $obj + 4 | 0;
    var $obj_idx2_val = HEAP32[$obj_idx2 >> 2];
    var $1 = __ZNK8JSObject6getOpsEv($obj_idx2_val);
    var $3 = HEAP32[$1 + 128 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    FUNCTION_TABLE[$3]($cx, $obj);
    __label__ = 3;
    break;
   case 3:
    var $obj_idx1_val = HEAP32[$obj >> 2];
    var $7 = __ZNK8JSObject8isNativeEv($obj_idx1_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = $cx;
    var $10 = $obj;
    __Z14js_ClearNativeP9JSContextP8JSObject($9, $10);
    __label__ = 5;
    break;
   case 5:
    var $obj_idx_val = HEAP32[$obj_idx2 >> 2];
    var $11 = __ZNK8JSObject8isGlobalEv($obj_idx_val);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $13 = $obj;
    var $14 = __ZN8JSObject8asGlobalEv($13);
    var $15 = $cx;
    __ZN2js12GlobalObject5clearEP9JSContext($14, $15);
    __label__ = 7;
    break;
   case 7:
    var $17 = $cx;
    __Z13js_InitRandomP9JSContext($17);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject8isGlobalEv($this_0_1_val) {
  var $1 = __ZNK8JSObject8getClassEv($this_0_1_val);
  return (HEAP32[$1 + 4 >> 2] & 262144 | 0) != 0;
}

function _JS_Enumerate($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $props = __stackBase__;
    var $ida = __stackBase__ + 60;
    __ZN2js12AutoIdVectorC1EP9JSContext($props, $cx);
    var $1 = $cx;
    var $2 = $obj;
    var $3 = $props;
    var $4 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($1, $2, 8, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = $ida;
    var $7 = __ZN2js15VectorToIdArrayEP9JSContextRNS_12AutoIdVectorEPP9JSIdArray($1, $3, $6);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = HEAP32[$ida >> 2];
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js12AutoIdVectorD1Ev($props);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18prop_iter_finalizeP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj_idx_val = HEAP32[$obj + 24 >> 2];
    var $1 = __ZNK8JSObject10getPrivateEv($obj_idx_val);
    if (($1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject7getSlotEj($obj, 0);
    var $_idx = $4 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $5 = __ZNK2JS5Value7toInt32Ev($_idx_val$0, $_idx_val$1);
    if (($5 | 0) > -1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = $1;
    _JS_DestroyIdArray($8);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15prop_iter_traceP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj_idx_val = HEAP32[$obj + 24 >> 2];
    var $1 = __ZNK8JSObject10getPrivateEv($obj_idx_val);
    if (($1 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject7getSlotEj($obj, 0);
    var $_idx = $4 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $5 = __ZNK2JS5Value7toInt32Ev($_idx_val$0, $_idx_val$1);
    if (($5 | 0) < 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = $1;
    __ZN2js2gc9MarkShapeEP8JSTracerPKNS_5ShapeEPKc($trc, $8);
    __label__ = 5;
    break;
   case 4:
    var $11 = HEAP32[$1 >> 2];
    var $13 = $1 + 4 | 0;
    __ZN2js2gc11MarkIdRangeEP8JSTracerjPiPKc($trc, $11, $13);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetRuntimeSecurityCallbacks($rt_0_58_val) {
  return $rt_0_58_val;
}

function __ZNK2js5Shape5Range5frontEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK16JSAutoByteString3ptrEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js5Shape10enumerableEv($this_0_7_val) {
  return ($this_0_7_val & 1) << 24 >> 24 != 0;
}

function __ZNK2js11UpvarCookie5levelEv($this_0_0_val) {
  return $this_0_0_val >>> 16 & 65535;
}

function __ZN2js11TokenStream15isUnexpectedEOFEv($this_0_5_val) {
  return ($this_0_5_val & 16 | 0) != 0;
}

function _JS_SetRuntimeSecurityCallbacks($rt) {
  HEAP32[$rt + 144244 >> 2] = _securityCallbacks;
  return;
}

function _JS_GetSecurityCallbacks($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 204 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $10 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = HEAP32[HEAP32[$cx + 52 >> 2] + 144244 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime20setTrustedPrincipalsEP12JSPrincipals($this) {
  HEAP32[$this + 209940 >> 2] = _shellTrustedPrincipals;
  return;
}

function __ZN8JSScript6upvarsEv($this_0_1_val, $this_0_6_val) {
  return $this_0_1_val + ($this_0_6_val & 255) | 0;
}

function __ZN2js5Shape5Range8popFrontEv($this) {
  var $1 = $this | 0;
  var $4 = HEAP32[HEAP32[$1 >> 2] + 32 >> 2];
  HEAP32[$1 >> 2] = $4;
  return;
}

function _JS_GetFunctionObject($fun) {
  return $fun | 0;
}

function _JS_GetFunctionId($fun_0_4_val) {
  return $fun_0_4_val | 0;
}

function _JS_SetErrorReporter($cx, $er) {
  var $1 = $cx + 180 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$1 >> 2] = $er;
  return $2;
}

function _JS_SetOperationCallback($cx) {
  HEAP32[$cx + 184 >> 2] = 50;
  return;
}

function _JS_NewPropertyIterator($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __stackBase__ + 16;
    var $2 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, __ZL15prop_iter_class, 0, $obj);
    if (($2 | 0) == 0) {
      var $_1 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $obj_idx1_val = HEAP32[$obj >> 2];
    var $5 = __ZNK8JSObject8isNativeEv($obj_idx1_val);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZNK8JSObject12lastPropertyEv($obj_idx1_val);
    var $index_1 = -1;
    var $pdata_1 = $7;
    __label__ = 7;
    break;
   case 4:
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($tvr, $cx, $2);
    var $10 = _JS_Enumerate($cx, $obj);
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js16AutoObjectRooterD1Ev($tvr);
    var $_1 = 0;
    __label__ = 8;
    break;
   case 6:
    var $13 = $10;
    var $15 = HEAP32[$10 >> 2];
    __ZN2js16AutoObjectRooterD1Ev($tvr);
    var $index_1 = $15;
    var $pdata_1 = $13;
    __label__ = 7;
    break;
   case 7:
    var $pdata_1;
    var $index_1;
    __ZN8JSObject10setPrivateEPv($2, $pdata_1);
    __ZN2JSL10Int32ValueEi251($1, $index_1);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, 0, $_idx_val$0, $_idx_val$1);
    var $_1 = $2;
    __label__ = 8;
    break;
   case 8:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($this, $cx, $obj) {
  __ZN2js16AutoObjectRooterC2EP9JSContextP8JSObject($this, $cx, $obj);
  return;
}

function __ZN2js16AutoObjectRooterD1Ev($this) {
  __ZN2js16AutoObjectRooterD2Ev($this);
  return;
}

function __ZN2JSL10Int32ValueEi251($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function _JS_NextProperty($iterobj, $idp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK8JSObject7getSlotEj($iterobj, 0);
    var $_idx = $2 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $3 = __ZNK2JS5Value7toInt32Ev($_idx_val$0, $_idx_val$1);
    var $4 = ($3 | 0) < 0;
    var $iterobj_idx_val = HEAP32[$iterobj + 24 >> 2];
    var $5 = __ZNK8JSObject10getPrivateEv($iterobj_idx_val);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $shape_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $shape_0;
    var $shape_0_idx2_val = HEAP32[$shape_0 + 32 >> 2];
    var $9 = __ZNK2js5Shape8previousEv($shape_0_idx2_val);
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $shape_0_idx4_val = HEAP8[$shape_0 + 28 | 0];
    var $12 = __ZNK2js5Shape10enumerableEv($shape_0_idx4_val);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      var $shape_0 = $9;
      __label__ = 3;
      break;
    }
   case 5:
    HEAP32[$idp >> 2] = 2;
    __label__ = 10;
    break;
   case 6:
    var $15 = $9;
    __ZN8JSObject10setPrivateEPv($iterobj, $15);
    var $17 = HEAP32[$shape_0 + 12 >> 2];
    HEAP32[$idp >> 2] = $17;
    __label__ = 10;
    break;
   case 7:
    if (($3 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    HEAP32[$idp >> 2] = 2;
    __label__ = 10;
    break;
   case 9:
    var $22 = $3 - 1 | 0;
    var $26 = HEAP32[$5 + 4 + ($22 << 2) >> 2];
    HEAP32[$idp >> 2] = $26;
    __ZN2JSL10Int32ValueEi251($1, $22);
    var $_idx3 = $1 | 0;
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($iterobj, 0, $_idx3_val$0, $_idx3_val$1);
    __label__ = 10;
    break;
   case 10:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_NextProperty["X"] = 1;

function _JS_GetReservedSlot($obj, $vp) {
  var $1 = $obj;
  __Z18js_GetReservedSlotP9JSContextP8JSObjectjPN2JS5ValueE($1, $vp);
  return;
}

function _JS_SetReservedSlot($cx, $obj, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $v = __stackBase__;
  var $1 = $v | 0;
  HEAP32[$1 >> 2] = $_0_0_0_val$0;
  HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
  var $2 = $cx;
  var $3 = $obj;
  var $4 = __Z18js_SetReservedSlotP9JSContextP8JSObjectjRKN2JS5ValueE($2, $3, 0, $v);
  STACKTOP = __stackBase__;
  return;
}

function _JS_NewArrayObject($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN12JSValueArrayC1EPN2JS5ValueEj($1, 0, 0);
  var $2 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($cx, 0, 0);
  STACKTOP = __stackBase__;
  return $2;
}

function _JS_IsArrayObject($obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $1 = __ZNK8JSObject7isArrayEv($obj_idx_val);
    if ($1) {
      var $8 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject9isWrapperEv($obj);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $8 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = __ZN8JSObject6unwrapEPj($obj, 0);
    var $_idx_val = HEAP32[$5 + 4 >> 2];
    var $6 = __ZNK8JSObject7isArrayEv($_idx_val);
    var $8 = $6;
    __label__ = 4;
    break;
   case 4:
    var $8;
    return $8 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject7isArrayEv($this_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject11isSlowArrayEv($this_0_1_val);
    if ($1) {
      var $5 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject12isDenseArrayEv($this_0_1_val);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_SetTrustedPrincipals($rt) {
  __ZN9JSRuntime20setTrustedPrincipalsEP12JSPrincipals($rt);
  return;
}

function _JS_NewFunction($cx, $native, $nargs, $parent) {
  var $1 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($cx, 0, $native, $nargs, 0, $parent, 0);
  return $1;
}

function _JS_CloneFunctionObject($cx, $funobj, $parent) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $r = __stackBase__ + 8;
    var $v1 = __stackBase__ + 16;
    if (($parent | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_1 = $parent;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = __ZNK9JSContext5hasfpEv($cx);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = __ZNK9JSContext2fpEv($cx);
    var $6 = __ZN2js13GetScopeChainEP9JSContextPNS_10StackFrameE($cx, $5);
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_1 = $6;
      __label__ = 5;
      break;
    }
   case 4:
    var $_1 = HEAP32[$cx + 132 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $_1;
    var $funobj_idx_val = HEAP32[$funobj + 4 >> 2];
    var $11 = __ZNK8JSObject10isFunctionEv($funobj_idx_val);
    if ($11) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2JSL11ObjectValueER8JSObject239($v, $funobj);
    __Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj($cx, $v, 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 7:
    var $funobj_idx1_val = HEAP32[$funobj + 24 >> 2];
    var $14 = __ZNK8JSObject18getFunctionPrivateEv($funobj_idx1_val);
    var $_idx_val = HEAP16[$14 + 58 >> 1];
    var $15 = __ZNK10JSFunction13isInterpretedEv($_idx_val);
    if ($15) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $17 = __Z19CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectb($cx, $14, $_1, 0);
    var $_0 = $17;
    __label__ = 23;
    break;
   case 9:
    var $19 = __ZNK10JSFunction6scriptEv($14);
    if ((HEAP8[$19 + 36 | 0] & 16) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    _JS_ReportErrorNumber($cx, 4, 142, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 11:
    var $26 = __ZNK10JSFunction13isFlatClosureEv($_idx_val);
    if ($26) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $28 = __Z19CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectb($cx, $14, $_1, 0);
    var $_0 = $28;
    __label__ = 23;
    break;
   case 13:
    var $30 = __Z19js_AllocFlatClosureP9JSContextP10JSFunctionP8JSObject($cx, $14, $_1);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $33 = __ZNK10JSFunction6scriptEv($14);
    var $_idx2_val = HEAP32[$33 + 4 >> 2];
    var $_idx3_val = HEAP8[$33 + 17 | 0];
    var $34 = __ZN8JSScript6upvarsEv($_idx2_val, $_idx3_val);
    var $36 = HEAP32[$34 + 4 >> 2];
    var $_idx5_val = HEAP32[$33 + 64 >> 2];
    var $38 = __ZNK2js8Bindings9lastUpvarEv($_idx5_val);
    var $39 = $38;
    __ZN2js5Shape5RangeC1EPKS0_($r, $39);
    var $40 = $34 | 0;
    var $41 = $v1 | 0;
    var $r_idx = $r | 0;
    var $i_0 = $36;
    __label__ = 15;
    break;
   case 15:
    var $i_0;
    var $43 = $i_0 - 1 | 0;
    if (($i_0 | 0) == 0) {
      var $_0 = $30;
      __label__ = 23;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $_idx4_val = HEAP32[HEAP32[$40 >> 2] + ($43 << 2) >> 2];
    var $47 = __ZNK2js11UpvarCookie5levelEv($_idx4_val);
    var $skip_0 = $47 & 65535;
    var $obj_0 = $_1;
    __label__ = 17;
    break;
   case 17:
    var $obj_0;
    var $skip_0;
    var $50 = $skip_0 - 1 | 0;
    if (($50 | 0) > 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 18:
    if (($obj_0 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    _JS_ReportErrorNumber($cx, 4, 142, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 20:
    var $obj_0_idx_val = HEAP32[$obj_0 + 20 >> 2];
    var $56 = __ZNK8JSObject9getParentEv($obj_0_idx_val);
    var $skip_0 = $50;
    var $obj_0 = $56;
    __label__ = 17;
    break;
   case 21:
    var $r_idx_val = HEAP32[$r_idx >> 2];
    var $58 = __ZNK2js5Shape5Range5frontEv($r_idx_val);
    var $60 = HEAP32[$58 + 12 >> 2];
    var $61 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($obj_0, $cx, $60, $v1);
    if (($61 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $64 = __ZNK8JSObject20getFlatClosureUpvarsEv($30);
    var $65$0 = HEAP32[$41 >> 2];
    var $65$1 = HEAP32[$41 + 4 >> 2];
    var $66 = $64 + ($43 << 3) | 0;
    var $st$6$0 = $66 | 0;
    HEAP32[$st$6$0 >> 2] = $65$0;
    var $st$6$1 = $66 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $65$1;
    __ZN2js5Shape5Range8popFrontEv($r);
    var $i_0 = $43;
    __label__ = 15;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_CloneFunctionObject["X"] = 1;

function __Z19CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectb($cx, $fun, $parent, $ignoreSingletonClone) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $proto = __stackBase__;
    var $1 = $cx;
    var $2 = $parent;
    var $3 = $proto;
    var $4 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($1, $2, 2, $3, 0);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($ignoreSingletonClone) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $8 = $fun | 0;
    var $_idx_val = HEAP32[$fun + 8 >> 2];
    var $9 = __ZNK8JSObject16hasSingletonTypeEv($_idx_val);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN8JSObject9setParentEPS_($8, $parent);
    var $_0 = $8;
    __label__ = 6;
    break;
   case 5:
    var $12 = HEAP32[$proto >> 2];
    var $13 = __Z22js_CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectS4_($cx, $fun, $parent, $12);
    var $_0 = $13;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK10JSFunction13isFlatClosureEv($this_0_2_val) {
  var $1 = __ZNK10JSFunction4kindEv($this_0_2_val);
  return $1 << 16 >> 16 == -32768;
}

function __ZN2js5Shape5RangeC1EPKS0_($this, $shape) {
  __ZN2js5Shape5RangeC2EPKS0_($this, $shape);
  return;
}

function __ZNK8JSObject20getFlatClosureUpvarsEv($this) {
  var $1 = __ZNK8JSObject12getFixedSlotEj($this, 0);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $2 = __ZNK2JS5Value9toPrivateEv($_idx_val$0, $_idx_val$1);
  return $2;
}

function _JS_DefineFunctions($cx, $obj, $fs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $priv = __stackBase__;
    var $1 = $cx;
    var $ctor_0 = 0;
    var $_01 = $fs;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $ctor_0;
    var $4 = HEAPU32[$_01 >> 2];
    if (($4 | 0) == 0) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAPU16[$_01 + 10 >> 1] & 65535;
    var $10 = _strlen($4);
    var $11 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $4, $10, 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($9 & 8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $_pre = __ZL12ATOM_TO_JSIDP6JSAtom244($11);
    var $ctor_2 = $ctor_0;
    var $flags_0 = $9;
    var $_pre_phi = $_pre;
    var $_pre_phi2 = $_01 + 8 | 0;
    __label__ = 10;
    break;
   case 6:
    if (($ctor_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $ctor_1 = $ctor_0;
      __label__ = 8;
      break;
    }
   case 7:
    var $19 = _JS_GetConstructor($cx, $obj);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      var $ctor_1 = $19;
      __label__ = 8;
      break;
    }
   case 8:
    var $ctor_1;
    var $22 = __ZL12ATOM_TO_JSIDP6JSAtom244($11);
    var $23 = $_01 + 8 | 0;
    var $26 = (HEAPU16[$23 >> 1] & 65535) + 1 | 0;
    var $27 = $9 & 57335;
    var $28 = __Z17js_DefineFunctionP9JSContextP8JSObjectiPFiS0_jPN2JS5ValueEEjj($cx, $ctor_1, $22, 52, $26, $27);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $31 = $9 & 65527;
    __ZN2JSL12PrivateValueEPv257($priv, $_01);
    var $33 = $28;
    var $34 = __Z18js_SetReservedSlotP9JSContextP8JSObjectjRKN2JS5ValueE($1, $33, 0, $priv);
    if ($34) {
      var $ctor_2 = $ctor_1;
      var $flags_0 = $31;
      var $_pre_phi = $22;
      var $_pre_phi2 = $23;
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 10:
    var $_pre_phi2;
    var $_pre_phi;
    var $flags_0;
    var $ctor_2;
    var $37 = HEAP32[$_01 + 4 >> 2];
    var $39 = HEAPU16[$_pre_phi2 >> 1] & 65535;
    var $40 = __Z17js_DefineFunctionP9JSContextP8JSObjectiPFiS0_jPN2JS5ValueEEjj($cx, $obj, $_pre_phi, $37, $39, $flags_0);
    if (($40 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $ctor_0 = $ctor_2;
    var $_01 = $_01 + 12 | 0;
    __label__ = 2;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_DefineFunctions["X"] = 1;

function __ZL35js_generic_native_method_dispatcherP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $2 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
    __ZNK8JSObject15getReservedSlotEj($1, $2, 0);
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __Z19js_ReportMissingArgP9JSContextRKN2JS5ValueEj($cx, $vp, 0);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $6 = __ZNK2JS5Value9toPrivateEv($_idx_val$0, $_idx_val$1);
    var $8 = $vp + 8 | 0;
    var $10 = $vp + 16 | 0;
    var $11 = $argc << 3;
    _llvm_memmove_p0i8_p0i8_i32($8, $10, $11, 1, 0);
    var $12 = $argc - 1 | 0;
    var $14 = $vp + ($argc + 1 << 3) | 0;
    __ZN2JS5Value12setUndefinedEv($14);
    var $17 = HEAP32[$6 + 4 >> 2];
    var $18 = FUNCTION_TABLE[$17]($cx, $12, $vp);
    var $_0 = $18;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL12PrivateValueEPv257($agg_result, $ptr) {
  __ZN2JS5Value10setPrivateEPv($agg_result, $ptr);
  return;
}

function _JS_DefineFunction($cx, $obj, $name, $call, $attrs) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _strlen($name);
    var $2 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $1, 0);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL12ATOM_TO_JSIDP6JSAtom244($2);
    var $6 = __Z17js_DefineFunctionP9JSContextP8JSObjectiPFiS0_jPN2JS5ValueEEjj($cx, $obj, $5, $call, 1, $attrs);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL34CompileUCScriptForPrincipalsCommonP9JSContextP8JSObjectP12JSPrincipalsPKtjPKcj9JSVersion($cx, $obj, $chars, $length, $filename, $lineno, $version) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $lfc = __stackBase__;
  __ZN18AutoLastFrameCheckC1EP9JSContext($lfc, $cx);
  var $cx_idx_val = HEAP32[$cx + 32 >> 2];
  var $1 = __ZL21JS_OPTIONS_TO_TCFLAGSP9JSContext($cx_idx_val);
  var $2 = $1 | 1073872896;
  var $3 = __ZN2js8Compiler13compileScriptEP9JSContextP8JSObjectPNS_10StackFrameEP12JSPrincipalsjPKtjPKcj9JSVersionP8JSStringj($cx, $obj, 0, 0, $2, $chars, $length, $filename, $lineno, $version, 0, 0);
  var $lfc_idx_val = HEAP32[$lfc >> 2];
  __ZN18AutoLastFrameCheckD1Ev($lfc_idx_val);
  STACKTOP = __stackBase__;
  return $3;
}

function _JS_CompileUCScriptForPrincipals($cx, $obj, $chars, $length, $filename, $lineno) {
  var $1 = __ZNK9JSContext11findVersionEv($cx);
  var $2 = __ZL34CompileUCScriptForPrincipalsCommonP9JSContextP8JSObjectP12JSPrincipalsPKtjPKcj9JSVersion($cx, $obj, $chars, $length, $filename, $lineno, $1);
  return $2;
}

function _JS_CompileUCScript($cx, $obj, $chars, $length, $filename, $lineno) {
  var $1 = _JS_CompileUCScriptForPrincipals($cx, $obj, $chars, $length, $filename, $lineno);
  return $1;
}

function _JS_BufferIsCompilableUnit($cx, $obj, $bytes, $length) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 996;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $parser = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $length;
    var $2 = $cx;
    var $3 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($2, $bytes, $1, 1);
    if (($3 | 0) == 0) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = _JS_SaveExceptionState($cx);
    var $7 = $parser;
    __ZN2js6ParserC2EP9JSContextP12JSPrincipalsPNS_10StackFrameEb($7, $cx, 0, 0, 1);
    var $8 = HEAP32[$1 >> 2];
    var $9 = __ZNK9JSContext11findVersionEv($cx);
    var $10 = __ZN2js6Parser4initEPKtjPKcj9JSVersion($7, $3, $8, 0, 1, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $result_1 = 1;
      __label__ = 7;
      break;
    }
   case 3:
    var $12 = _JS_SetErrorReporter($cx, 0);
    var $13 = __ZN2js6Parser5parseEP8JSObject($7, $obj);
    if (($13 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $result_0 = 1;
      __label__ = 6;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$parser + 184 >> 2];
    var $16 = __ZN2js11TokenStream15isUnexpectedEOFEv($_idx_val);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      var $result_0 = 1;
      __label__ = 6;
      break;
    }
   case 5:
    var $result_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $result_0;
    var $19 = _JS_SetErrorReporter($cx, $12);
    var $result_1 = $result_0;
    __label__ = 7;
    break;
   case 7:
    var $result_1;
    __ZN2js6ParserD2Ev($7);
    var $21 = $3;
    __ZN9JSContext5free_EPv($21);
    _JS_RestoreExceptionState($cx, $6);
    var $_0 = $result_1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_SaveExceptionState($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($cx, 16);
    var $2 = $1;
    if (($1 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $1 + 8 | 0;
    var $6 = $5;
    var $7 = _JS_GetPendingException($cx, $6);
    HEAP32[$1 >> 2] = $7;
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = $5;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = _JSVAL_IS_GCTHING($12$0, $12$1);
    if (($13 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = __Z10js_AddRootP9JSContextPN2JS5ValueEPKc($cx, $6, STRING_TABLE.__str29222 | 0);
    __label__ = 5;
    break;
   case 5:
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_RestoreExceptionState($cx, $state) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($state | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$state >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $state + 8 | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    _JS_SetPendingException($cx, $8$0, $8$1);
    __label__ = 5;
    break;
   case 4:
    _JS_ClearPendingException($cx);
    __label__ = 5;
    break;
   case 5:
    _JS_DropExceptionState($cx, $state);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_CompileFile($cx, $obj, $filename) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lfc = __stackBase__;
    __ZN18AutoLastFrameCheckC1EP9JSContext($lfc, $cx);
    if (($filename | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = _strcmp($filename, STRING_TABLE.__str135428 | 0);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $fp_0 = HEAP32[_stdin >> 2];
    __label__ = 6;
    break;
   case 4:
    var $8 = _fopen($filename, STRING_TABLE.__str136429 | 0);
    if (($8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $fp_0 = $8;
      __label__ = 6;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 4, 60, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $filename, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str26219 | 0, tempInt));
    var $_0 = 0;
    __label__ = 8;
    break;
   case 6:
    var $fp_0;
    var $12 = __ZL17CompileFileHelperP9JSContextP8JSObjectP12JSPrincipalsPKcP7__sFILE($cx, $obj, $filename, $fp_0);
    if (($fp_0 | 0) == (HEAP32[_stdin >> 2] | 0)) {
      var $_0 = $12;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $16 = _fclose($fp_0);
    var $_0 = $12;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    var $lfc_idx_val = HEAP32[$lfc >> 2];
    __ZN18AutoLastFrameCheckD1Ev($lfc_idx_val);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18AutoLastFrameCheckC1EP9JSContext($this, $cx) {
  __ZN18AutoLastFrameCheckC2EP9JSContext($this, $cx);
  return;
}

function __ZL17CompileFileHelperP9JSContextP8JSObjectP12JSPrincipalsPKcP7__sFILE($cx, $obj, $filename, $fp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $st = __stackBase__;
    var $1 = _fileno($fp);
    var $2 = _fstat($1, $st);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 2:
    var $6 = HEAPU32[$st + 28 >> 2];
    if ((HEAP32[_stdin >> 2] | 0) == ($fp | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 3:
    var $len_0 = ($6 | 0) == 0 ? 8 : $6;
    var $hitEOF_0 = 0;
    var $i_0 = 0;
    var $len_1 = $len_0;
    var $buf_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $buf_0;
    var $len_1;
    var $i_0;
    var $hitEOF_0;
    if ($hitEOF_0 << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      var $i_3 = $i_0;
      var $buf_1 = $buf_0;
      __label__ = 14;
      break;
    }
   case 5:
    var $13 = $len_1 << 1;
    var $14 = $buf_0;
    var $16 = __ZN9JSContext8realloc_EPvj($cx, $14, $len_1 << 2);
    var $17 = $16;
    if (($16 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $i_1 = $i_0;
      __label__ = 7;
      break;
    }
   case 6:
    __ZN9JSContext5free_EPv($14);
    var $_0 = 0;
    __label__ = 15;
    break;
   case 7:
    var $i_1;
    if ($i_1 >>> 0 < $13 >>> 0) {
      __label__ = 8;
      break;
    } else {
      var $hitEOF_0 = 0;
      var $i_0 = $i_1;
      var $len_1 = $13;
      var $buf_0 = $17;
      __label__ = 4;
      break;
    }
   case 8:
    var $22 = _getc_unlocked($fp);
    if (($22 | 0) == -1) {
      var $hitEOF_0 = 1;
      var $i_0 = $i_1;
      var $len_1 = $13;
      var $buf_0 = $17;
      __label__ = 4;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    HEAP16[$17 + ($i_1 << 1) >> 1] = $22 & 65535 & 255;
    var $i_1 = $i_1 + 1 | 0;
    __label__ = 7;
    break;
   case 10:
    var $30 = $6 << 1;
    var $31 = __ZN9JSContext7malloc_Ej($cx, $30);
    var $32 = $31;
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      var $i_2 = 0;
      __label__ = 11;
      break;
    }
   case 11:
    var $i_2;
    if ($i_2 >>> 0 < $6 >>> 0) {
      __label__ = 12;
      break;
    } else {
      var $i_3 = $i_2;
      var $buf_1 = $32;
      __label__ = 14;
      break;
    }
   case 12:
    var $36 = _getc_unlocked($fp);
    if (($36 | 0) == -1) {
      var $i_3 = $i_2;
      var $buf_1 = $32;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    HEAP16[$32 + ($i_2 << 1) >> 1] = $36 & 65535 & 255;
    var $i_2 = $i_2 + 1 | 0;
    __label__ = 11;
    break;
   case 14:
    var $buf_1;
    var $i_3;
    var $cx_idx_val = HEAP32[$cx + 32 >> 2];
    var $43 = __ZL21JS_OPTIONS_TO_TCFLAGSP9JSContext($cx_idx_val);
    var $44 = $43 | 1073872896;
    var $45 = __ZNK9JSContext11findVersionEv($cx);
    var $46 = __ZN2js8Compiler13compileScriptEP9JSContextP8JSObjectPNS_10StackFrameEP12JSPrincipalsjPKtjPKcj9JSVersionP8JSStringj($cx, $obj, 0, 0, $44, $buf_1, $i_3, $filename, 1, $45, 0, 0);
    __ZN9JSContext5free_EPv($buf_1);
    var $_0 = $46;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17CompileFileHelperP9JSContextP8JSObjectP12JSPrincipalsPKcP7__sFILE["X"] = 1;

function __ZN18AutoLastFrameCheckD1Ev($this_0_0_val) {
  __ZN18AutoLastFrameCheckD2Ev($this_0_0_val);
  return;
}

function _JS_CompileFileHandleForPrincipals($cx, $obj, $filename, $file) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $lfc = __stackBase__;
  __ZN18AutoLastFrameCheckC1EP9JSContext($lfc, $cx);
  var $1 = __ZL17CompileFileHelperP9JSContextP8JSObjectP12JSPrincipalsPKcP7__sFILE($cx, $obj, $filename, $file);
  var $lfc_idx_val = HEAP32[$lfc >> 2];
  __ZN18AutoLastFrameCheckD1Ev($lfc_idx_val);
  STACKTOP = __stackBase__;
  return $1;
}

function _JS_CompileFileHandle($cx, $obj, $filename, $file) {
  var $1 = _JS_CompileFileHandleForPrincipals($cx, $obj, $filename, $file);
  return $1;
}

function _JS_DecompileFunction($cx, $fun, $indent) {
  var $1 = $indent & -32769;
  var $3 = $indent >>> 15 & 1 ^ 1;
  var $4 = _js_DecompileToString($cx, $fun, $1, $3, 0, 0);
  return $4;
}

function _JS_ExecuteScript($cx, $obj, $script, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $lfc = __stackBase__;
  __ZN18AutoLastFrameCheckC1EP9JSContext($lfc, $cx);
  var $1 = __ZN2js7ExecuteEP9JSContextP8JSScriptR8JSObjectPN2JS5ValueE($cx, $script, $obj, $rval);
  var $2 = $1 & 1;
  var $lfc_idx_val = HEAP32[$lfc >> 2];
  __ZN18AutoLastFrameCheckD1Ev($lfc_idx_val);
  STACKTOP = __stackBase__;
  return $2;
}

function __Z35EvaluateUCScriptForPrincipalsCommonP9JSContextP8JSObjectP12JSPrincipalsPKtjPKcjPN2JS5ValueE9JSVersion($cx, $obj, $chars, $length, $filename, $lineno, $rval, $compileVersion) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lfc = __stackBase__;
    var $flags_0 = ($rval | 0) == 0 ? 1073766400 : 1073750016;
    __ZN18AutoLastFrameCheckC1EP9JSContext($lfc, $cx);
    var $2 = __ZN2js8Compiler13compileScriptEP9JSContextP8JSObjectPNS_10StackFrameEP12JSPrincipalsjPKtjPKcj9JSVersionP8JSStringj($cx, $obj, 0, 0, $flags_0, $chars, $length, $filename, $lineno, $compileVersion, 0, 0);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js7ExecuteEP9JSContextP8JSScriptR8JSObjectPN2JS5ValueE($cx, $2, $obj, $rval);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    var $lfc_idx_val = HEAP32[$lfc >> 2];
    __ZN18AutoLastFrameCheckD1Ev($lfc_idx_val);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_EvaluateUCScriptForPrincipals($cx, $obj, $chars, $length, $filename, $lineno, $rval) {
  var $1 = __ZNK9JSContext11findVersionEv($cx);
  var $2 = __Z35EvaluateUCScriptForPrincipalsCommonP9JSContextP8JSObjectP12JSPrincipalsPKtjPKcjPN2JS5ValueE9JSVersion($cx, $obj, $chars, $length, $filename, $lineno, $rval, $1);
  return $2 & 1;
}

function _JS_EvaluateUCScript($cx, $obj, $chars, $length, $filename, $lineno, $rval) {
  var $1 = _JS_EvaluateUCScriptForPrincipals($cx, $obj, $chars, $length, $filename, $lineno, $rval);
  return $1;
}

function _JS_EvaluateScriptForPrincipals($cx, $obj, $bytes, $nbytes, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $length = __stackBase__;
    HEAP32[$length >> 2] = $nbytes;
    var $1 = $cx;
    var $2 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($1, $bytes, $length, 0);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$length >> 2];
    var $6 = _JS_EvaluateUCScriptForPrincipals($cx, $obj, $2, $5, STRING_TABLE.__str134427 | 0, 1, $rval);
    var $7 = $2;
    __ZN9JSContext5free_EPv($7);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_EvaluateScript($cx, $obj, $bytes, $nbytes, $rval) {
  var $1 = _JS_EvaluateScriptForPrincipals($cx, $obj, $bytes, $nbytes, $rval);
  return $1;
}

function __ZN2js15InvokeArgsGuardC1Ev($this) {
  __ZN2js15InvokeArgsGuardC2Ev($this);
  return;
}

function __ZN2js17InvokeConstructorEP9JSContextRNS_15InvokeArgsGuardE($cx, $args) {
  var $1 = $args | 0;
  __ZN2js12CallArgsList9setActiveEv($1);
  var $2 = $args;
  var $3 = __ZN2js12ImplicitCastINS_8CallArgsENS_15InvokeArgsGuardEEERT_RT0_($2);
  var $4 = __ZN2js23InvokeConstructorKernelEP9JSContextRKNS_8CallArgsE($cx, $3);
  __ZN2js12CallArgsList11setInactiveEv($1);
  return $4;
}

function __ZN2js15InvokeArgsGuardD1Ev($this) {
  __ZN2js15InvokeArgsGuardD2Ev($this);
  return;
}

function _JS_TriggerAllOperationCallbacks($rt) {
  __ZN2js28TriggerAllOperationCallbacksEP9JSRuntime($rt);
  return;
}

function _JS_SetCStringsAreUTF8() {
  HEAP8[_js_CStringsAreUTF8_b] = 1;
  return;
}

function __ZNK2js6RegExp9getSourceEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5countEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZNK8JSString6isAtomEv($this_0_0_0_val) {
  return ($this_0_0_0_val & 7 | 0) == 0;
}

function _JS_CStringsAreUTF8() {
  return HEAPU8[_js_CStringsAreUTF8_b] & 1;
}

function __ZNK8JSObject6isDateEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js9DateClassE | 0);
}

function __ZNK8JSObject8isRegExpEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js11RegExpClassE | 0);
}

function __ZN2jsL16GetClassProtoKeyEPNS_5ClassE($clasp_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $clasp_0_1_val >>> 24;
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $clasp_0_1_val >>> 17 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10overloadedEv($this_0_1_val, $this_0_2_val, $this_0_4_val) {
  return ($this_0_4_val + $this_0_2_val | 0) >>> 0 >= ($this_0_1_val * 192 | 0) >>> 8 >>> 0;
}

function __ZNK2js6RegExp8getFlagsEv($this) {
  return $this + 16 | 0;
}

function __ZN2js2gcL15GetGCObjectKindEjb264($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrdeEv($this_0_0_val) {
  return $this_0_0_val + 8 | 0;
}

function _JS_IsRunning($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK9JSContext7maybefpEv($cx);
    var $fp_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $fp_0;
    var $3 = ($fp_0 | 0) != 0;
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $fp_0_idx1_val = HEAP32[$fp_0 >> 2];
    var $5 = __ZNK2js10StackFrame12isDummyFrameEv($fp_0_idx1_val);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $fp_0_idx_val = HEAP32[$fp_0 + 16 >> 2];
    var $7 = __ZNK2js10StackFrame4prevEv($fp_0_idx_val);
    var $fp_0 = $7;
    __label__ = 2;
    break;
   case 5:
    return $3 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK9JSContext7maybefpEv($this) {
  var $_idx_val = HEAP32[$this + 60 >> 2];
  var $2 = __ZNK2js12ContextStack7maybefpEv($_idx_val);
  return $2;
}

function _JS_SaveFrameChain($cx) {
  var $2 = $cx + 60 | 0;
  var $3 = __ZN2js12ContextStack14saveFrameChainEv($2);
  return $3 & 1;
}

function _JS_RestoreFrameChain($cx) {
  var $2 = $cx + 60 | 0;
  __ZN2js12ContextStack17restoreFrameChainEv($2);
  return;
}

function _JS_NewStringCopyN($cx, $s, $n) {
  var $1 = $cx;
  var $2 = __Z17js_NewStringCopyNP9JSContextPKcj($1, $s, $n);
  return $2 | 0;
}

function _JS_NewStringCopyZ($cx, $s) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $n = __stackBase__;
    if (($s | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 6;
    break;
   case 3:
    var $9 = _strlen($s);
    HEAP32[$n >> 2] = $9;
    var $10 = $cx;
    var $11 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($10, $s, $n, 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = HEAP32[$n >> 2];
    var $15 = __Z12js_NewStringP9JSContextPtj($10, $11, $14);
    var $16 = $15 | 0;
    if (($15 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $16;
      __label__ = 6;
      break;
    }
   case 5:
    var $19 = $11;
    __ZN9JSContext5free_EPv($19);
    var $_0 = $16;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_InternString($cx, $s) {
  var $1 = _strlen($s);
  var $2 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $s, $1, 1);
  return $2 | 0;
}

function _JS_NewUCString($cx, $chars, $length) {
  var $1 = $cx;
  var $2 = __Z12js_NewStringP9JSContextPtj($1, $chars, $length);
  return $2 | 0;
}

function _JS_NewUCStringCopyN($cx, $s, $n) {
  var $1 = $cx;
  var $2 = __Z17js_NewStringCopyNP9JSContextPKtj($1, $s, $n);
  return $2 | 0;
}

function _JS_InternUCStringN($cx, $s, $length) {
  var $1 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($cx, $s, $length, 1);
  return $1 | 0;
}

function _JS_GetStringLength($str_0_0_0_val) {
  var $1 = __ZNK8JSString6lengthEv($str_0_0_0_val);
  return $1;
}

function _JS_GetStringCharsZ($cx, $str) {
  var $1 = __ZN8JSString9getCharsZEP9JSContext($str, $cx);
  return $1;
}

function _JS_GetStringCharsAndLength($cx, $str, $plength) {
  var $str_idx_val = HEAP32[$str >> 2];
  var $1 = __ZNK8JSString6lengthEv($str_idx_val);
  HEAP32[$plength >> 2] = $1;
  var $2 = __ZN8JSString8getCharsEP9JSContext($str, $cx);
  return $2;
}

function _JS_FlattenString($cx, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSString9getCharsZEP9JSContext($str, $cx);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $str;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_StringEqualsAscii($cx, $str, $asciiBytes, $match) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSString12ensureLinearEP9JSContext($str, $cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js17StringEqualsAsciiEP14JSLinearStringPKc($1, $asciiBytes);
    HEAP32[$match >> 2] = $4 & 1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_FlatStringEqualsAscii($str, $asciiBytes) {
  var $1 = $str | 0;
  var $2 = __ZN2js17StringEqualsAsciiEP14JSLinearStringPKc($1, $asciiBytes);
  return $2 & 1;
}

function _JS_FileEscapedString($fp, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSString12ensureLinearEP9JSContext($str, 0);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js17FileEscapedStringEP7__sFILEP14JSLinearStringj($fp, $1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17FileEscapedStringEP7__sFILEP14JSLinearStringj($fp, $str) {
  var $1 = __ZN2js20PutEscapedStringImplEPcjP7__sFILEP14JSLinearStringj($fp, $str);
  return ($1 | 0) != -1;
}

function _JS_EncodeCharacters($cx, $dst, $dstlenp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $cx;
    if (($dst | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = __ZN2js23GetDeflatedStringLengthEP9JSContextPKtj($2, __ZL12badSurrogate | 0, 6);
    if (($4 | 0) == -1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[$dstlenp >> 2] = 0;
    __label__ = 6;
    break;
   case 4:
    HEAP32[$dstlenp >> 2] = $4;
    __label__ = 6;
    break;
   case 5:
    var $9 = __ZN2js21DeflateStringToBufferEP9JSContextPKtjPcPj($2, __ZL12badSurrogate | 0, 6, $dst, $dstlenp);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DecodeBytes($cx, $dst, $dstlenp) {
  var $1 = $cx;
  var $2 = __ZN2js21InflateStringToBufferEP9JSContextPKcjPtPj($1, STRING_TABLE.__str258551 | 0, 10, $dst, $dstlenp);
  return;
}

function _JS_DecodeUTF8($cx, $src, $srclen, $dst, $dstlenp) {
  var $1 = $cx;
  var $2 = __ZN2js25InflateUTF8StringToBufferEP9JSContextPKcjPtPjNS_13FlationCodingE($1, $src, $srclen, $dst, $dstlenp, 0);
  return $2 & 1;
}

function _JS_EncodeString($cx, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSString8getCharsEP9JSContext($str, $cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $str_idx_val = HEAP32[$str >> 2];
    var $4 = __ZNK8JSString6lengthEv($str_idx_val);
    var $5 = $cx;
    var $6 = __ZN2js13DeflateStringEP9JSContextPKtj($5, $1, $4);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBufferC1EP9JSContext($this, $cx) {
  __ZN2js12StringBufferC2EP9JSContext($this, $cx);
  return;
}

function __ZNK2js12StringBuffer5emptyEv($this) {
  var $_idx_val = HEAP32[$this + 8 >> 2];
  var $1 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE5emptyEv($_idx_val);
  return $1;
}

function __ZN2js12StringBuffer5beginEv($this) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $1 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE5beginEv($_idx_val);
  return $1;
}

function __ZNK2js12StringBuffer6lengthEv($this) {
  var $_idx_val = HEAP32[$this + 8 >> 2];
  var $1 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv($_idx_val);
  return $1;
}

function __ZN2js12StringBufferD1Ev($this) {
  __ZN2js12StringBufferD2Ev($this);
  return;
}

function __ZN2JSL9NullValueEv259($agg_result) {
  __ZN2JS5Value7setNullEv($agg_result);
  return;
}

function _JS_ReadStructuredClone($cx, $buf, $nbytes, $vp) {
  var $4 = HEAP32[HEAP32[$cx + 52 >> 2] + 144248 >> 2];
  var $5 = __ZN2js19ReadStructuredCloneEP9JSContextPKyjPN2JS5ValueEPK26JSStructuredCloneCallbacksPv($cx, $buf, $nbytes, $vp, $4);
  return $5 & 1;
}

function _JS_WriteStructuredClone($cx, $_0_0_0_val$0, $_0_0_0_val$1, $bufp, $nbytesp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $v = __stackBase__;
  var $1 = $v | 0;
  HEAP32[$1 >> 2] = $_0_0_0_val$0;
  HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
  var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 144248 >> 2];
  var $6 = __ZN2js20WriteStructuredCloneEP9JSContextRKN2JS5ValueEPPyPjPK26JSStructuredCloneCallbacksPv($cx, $v, $bufp, $nbytesp, $5);
  var $7 = $6 & 1;
  STACKTOP = __stackBase__;
  return $7;
}

function _JS_ReportError($cx, $format) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $ap = __stackBase__;
  HEAP32[$ap >> 2] = arguments[_JS_ReportError.length];
  var $2 = HEAP32[$ap >> 2];
  var $3 = __Z16js_ReportErrorVAP9JSContextjPKcPc($cx, 0, $format, $2);
  STACKTOP = __stackBase__;
  return;
}

function _JS_ReportWarning($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $ap = __stackBase__;
  HEAP32[$ap >> 2] = arguments[_JS_ReportWarning.length];
  var $2 = HEAP32[$ap >> 2];
  var $3 = __Z16js_ReportErrorVAP9JSContextjPKcPc($cx, 1, STRING_TABLE.__ZZL17WarnOnTooManyArgsP9JSContextRKN2js8CallArgsEE20TWO_ARGUMENT_WARNING | 0, $2);
  STACKTOP = __stackBase__;
  return $3;
}

function _JS_ReportErrorFlagsAndNumber($cx, $flags, $errorNumber) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $ap = __stackBase__;
  HEAP32[$ap >> 2] = arguments[_JS_ReportErrorFlagsAndNumber.length];
  var $2 = HEAP32[$ap >> 2];
  var $3 = __Z22js_ReportErrorNumberVAP9JSContextjPFPK19JSErrorFormatStringPvPKcjES4_jiPc($cx, $flags, 4, $errorNumber, 1, $2);
  STACKTOP = __stackBase__;
  return $3;
}

function _JS_ReportErrorFlagsAndNumberUC($cx, $errorNumber) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $ap = __stackBase__;
  HEAP32[$ap >> 2] = arguments[_JS_ReportErrorFlagsAndNumberUC.length];
  var $2 = HEAP32[$ap >> 2];
  var $3 = __Z22js_ReportErrorNumberVAP9JSContextjPFPK19JSErrorFormatStringPvPKcjES4_jiPc($cx, 0, 4, $errorNumber, 0, $2);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6RegExp12createObjectEP9JSContextPNS_13RegExpStaticsEPKtjjPNS_11TokenStreamE($cx, $res_0_3_val, $chars, $length, $flags) {
  var $1 = __ZNK2js13RegExpStatics8getFlagsEv($res_0_3_val);
  var $2 = $1 | $flags;
  var $3 = __ZN2js6RegExp21createObjectNoStaticsEP9JSContextPKtjjPNS_11TokenStreamE($cx, $chars, $length, $2);
  return $3;
}

function __ZN2js6RegExp11extractFromEP8JSObject($obj_0_6_val) {
  var $1 = __ZNK8JSObject10getPrivateEv($obj_0_6_val);
  return $1;
}

function __ZN2js6RegExp7executeEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE($this, $cx, $res, $input, $lastIndex, $test, $rval) {
  var $1 = __ZN2js6RegExp15executeInternalEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE($this, $cx, $res, $input, $lastIndex, $test, $rval);
  return $1;
}

function __ZN2js6RegExp21createObjectNoStaticsEP9JSContextPKtjjPNS_11TokenStreamE($cx, $chars, $length, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $anchor = __stackBase__;
    var $re = __stackBase__ + 4;
    var $1 = $cx;
    var $2 = __Z17js_NewStringCopyNP9JSContextPKtj($1, $chars, $length);
    var $3 = $2 | 0;
    if (($2 | 0) == 0) {
      var $_1 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $3);
    __ZN2js6RegExp6createEP9JSContextP8JSStringjPNS_11TokenStreamE($re, $cx, $3, $flags);
    var $re_idx_val = HEAP32[$re >> 2];
    var $6 = __ZNK2js15AlreadyIncRefedINS_6RegExpEEcvPPPPPS1_Ev($re_idx_val);
    if (($6 | 0) == 0) {
      var $_1 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE279($cx);
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = __ZNK2js15AlreadyIncRefedINS_6RegExpEE3getEv($re_idx_val);
    var $13 = __ZN8JSObject10initRegExpEP9JSContextPN2js6RegExpE($9, $cx, $12);
    if ($13) {
      var $_1 = $9;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = __ZNK2js15AlreadyIncRefedINS_6RegExpEEptEv($re_idx_val);
    __ZN2js6RegExp6decrefEP9JSContext($15);
    var $_1 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_IsExceptionPending($cx_0_4_val) {
  var $1 = __ZN9JSContext18isExceptionPendingEv($cx_0_4_val);
  return $1 & 1;
}

function _JS_GetPendingException($cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $cx_idx_val = HEAP32[$cx + 20 >> 2];
    var $2 = __ZN9JSContext18isExceptionPendingEv($cx_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $cx_idx1 = $cx + 24 | 0;
    var $cx_idx1_val$0 = HEAP32[$cx_idx1 >> 2];
    var $cx_idx1_val$1 = HEAP32[$cx_idx1 + 4 >> 2];
    __ZN9JSContext19getPendingExceptionEv($1, $cx_idx1_val$0, $cx_idx1_val$1);
    var $4 = $1 | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = $vp | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_SetPendingException($cx, $_0_0_0_val$0, $_0_0_0_val$1) {
  __ZN9JSContext19setPendingExceptionEN2JS5ValueE($cx, $_0_0_0_val$0, $_0_0_0_val$1);
  return;
}

function _JS_ClearPendingException($cx) {
  __ZN9JSContext21clearPendingExceptionEv($cx);
  return;
}

function _JS_ReportPendingException($cx) {
  var $1 = $cx + 44 | 0;
  var $2 = HEAP8[$1];
  HEAP8[$1] = 1;
  var $3 = $cx;
  var $4 = __Z26js_ReportUncaughtExceptionP9JSContext($3);
  HEAP8[$1] = $2;
  return $4;
}

function _JSVAL_IS_GCTHING($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_GCTHING_IMPL($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JS_DropExceptionState($cx, $state) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($state | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$state >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $state + 8 | 0;
    var $8 = $7 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = _JSVAL_IS_GCTHING($9$0, $9$1);
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    _JS_RemoveValueRoot($cx_idx_val, $7);
    __label__ = 5;
    break;
   case 5:
    var $14 = $state;
    __ZN9JSContext5free_EPv($14);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE($cx, $clasp, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($clasp | 0) == (__ZN2js13FunctionClassE | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detailL9NewObjectILb0ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE($cx, __ZN2js13FunctionClassE, $parent, $kind);
    var $_0 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE($cx, $clasp, 0, $parent, $kind);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb0ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE($cx, $clasp, $parent, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = 0;
    var $2 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_($cx, $clasp, $parent, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    var $_pr = HEAP32[$1 >> 2];
    var $4 = ($_pr | 0) == 0;
    if ($4) {
      var $7 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($_pr, $cx, 0, 0);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      var $7 = $5;
      __label__ = 4;
      break;
    }
   case 4:
    var $7;
    var $8 = $cx;
    var $9 = __Z16js_NewGCFunctionP9JSContext($8);
    var $10 = $9;
    if (($9 | 0) == 0) {
      var $_0 = $10;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_not = ($parent | 0) == 0 ^ 1;
    var $parent_mux = $_not ? $parent : 0;
    if ($_not | $4) {
      var $17 = $parent_mux;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx_val = HEAP32[$_pr + 20 >> 2];
    var $15 = __ZNK8JSObject9getParentEv($_idx_val);
    var $17 = $15;
    __label__ = 7;
    break;
   case 7:
    var $17;
    var $18 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($10, $clasp, $7, $17, 0, $18);
    var $clasp_idx_val = HEAP32[$clasp + 4 >> 2];
    var $19 = __ZNK2js5Class8isNativeEv($clasp_idx_val);
    if ($19) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $21 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE267($cx, $10, $clasp, $7, $kind);
    if ($21) {
      var $_0 = $10;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_0 = 0;
    __label__ = 11;
    break;
   case 10:
    __ZN8JSObject21setSharedNonNativeMapEv($10);
    var $_0 = $10;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE($cx, $clasp, $proto, $parent, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $proto;
    if (($proto | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $7 = $proto;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_($cx, $clasp, $parent, $1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 3:
    var $_pr = HEAP32[$1 >> 2];
    if (($_pr | 0) == 0) {
      var $11 = __ZN2js5types15emptyTypeObjectE;
      var $10 = $_pr;
      __label__ = 5;
      break;
    } else {
      var $7 = $_pr;
      __label__ = 4;
      break;
    }
   case 4:
    var $7;
    var $8 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($7, $cx, 0, 0);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      var $11 = $8;
      var $10 = $7;
      __label__ = 5;
      break;
    }
   case 5:
    var $10;
    var $11;
    var $12 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($parent | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $21 = $parent;
      __label__ = 9;
      break;
    }
   case 7:
    if (($10 | 0) == 0) {
      var $21 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx_val = HEAP32[$10 + 20 >> 2];
    var $19 = __ZNK8JSObject9getParentEv($_idx_val);
    var $21 = $19;
    __label__ = 9;
    break;
   case 9:
    var $21;
    var $22 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($12, $clasp, $11, $21, 0, $22);
    var $clasp_idx_val = HEAP32[$clasp + 4 >> 2];
    var $23 = __ZNK2js5Class8isNativeEv($clasp_idx_val);
    if ($23) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $25 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE267($cx, $12, $clasp, $11, $kind);
    if ($25) {
      var $_0 = $12;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_0 = 0;
    __label__ = 13;
    break;
   case 12:
    __ZN8JSObject21setSharedNonNativeMapEv($12);
    var $_0 = $12;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_($cx, $clasp, $parent, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $clasp_idx_val = HEAP32[$clasp + 4 >> 2];
    var $1 = __ZN2jsL16GetClassProtoKeyEPNS_5ClassE($clasp_idx_val);
    var $2 = $cx;
    var $3 = $parent;
    var $4 = $proto;
    var $5 = $clasp;
    var $6 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, $1, $4, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$proto >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, 1, $4, 0);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE267($cx, $obj, $clasp, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
    var $obj_idx_val = HEAP32[$obj + 28 >> 2];
    var $5 = __ZNK8JSObject8numSlotsEv($obj_idx_val);
    if ($4 >>> 0 > $5 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $obj;
    var $9 = $cx;
    var $10 = __ZN8JSObject10allocSlotsEP9JSContextj($8, $9, $4);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $12 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($type, $clasp);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($type, $cx, $clasp, $kind);
    var $empty_0 = $14;
    __label__ = 6;
    break;
   case 5:
    var $16 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, $clasp);
    var $empty_0 = $16;
    __label__ = 6;
    break;
   case 6:
    var $empty_0;
    if (($empty_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($obj, $empty_0 | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE271($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($proto | 0) != 0;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $5 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      var $5 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $5;
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($parent | 0) != 0 | $1 ^ 1) {
      var $12 = $parent;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $proto_idx_val = HEAP32[$proto + 20 >> 2];
    var $10 = __ZNK8JSObject9getParentEv($proto_idx_val);
    var $12 = $10;
    __label__ = 6;
    break;
   case 6:
    var $12;
    var $13 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, $clasp, $5, $12, 0, $13);
    var $clasp_idx_val = HEAP32[$clasp + 4 >> 2];
    var $14 = __ZNK2js5Class8isNativeEv($clasp_idx_val);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $16 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE267($cx, $6, $clasp, $5, $kind);
    if ($16) {
      var $_0 = $6;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = 0;
    __label__ = 10;
    break;
   case 9:
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    var $_0 = $6;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S2_EENS5_13MapHashPolicyES4_E6AddPtrERKS2_SF_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrEPPS5_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$pentry >> 2];
    var $5 = $k | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $4 | 0;
    var $st$7$0 = $7 | 0;
    HEAP32[$st$7$0 >> 2] = $6$0;
    var $st$7$1 = $7 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $6$1;
    var $8 = $v | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $4 + 8 | 0;
    var $st$17$0 = $10 | 0;
    HEAP32[$st$17$0 >> 2] = $9$0;
    var $st$17$1 = $10 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $9$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrEPPS5_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 8 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 8 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 16 >> 2];
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j($10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + $5 * 24 | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 5;
    break;
   case 5:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $22 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isLiveEv($src_01_idx_val);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE10getKeyHashEv($src_01_idx1_val);
    var $25 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEENS_7MoveRefIT_EERS9_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEEaSENS_7MoveRefIS6_EE($25, $_02_val);
    __label__ = 7;
    break;
   case 7:
    var $27 = $src_01 + 24 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj($3);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIN2JS5ValueES3_EEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2JS5Value9asRawBitsEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  return [ $this_0_0_0_val$0, $this_0_0_0_val$1 ];
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr7nonNullEv($this) {
  return;
}

function __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE12hasCollisionEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function _JSVAL_IS_GCTHING_IMPL($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 > 4294967172 & 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEC2ERS7_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIN2JS5ValueES3_EEEC2ERS4_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js12HashMapEntryIN2JS5ValueES2_EC2Ev($this) {
  var $1 = $this | 0;
  HEAP32[$1 >> 2] = 0;
  HEAP32[$1 + 4 >> 2] = 0;
  var $2 = $this + 8 | 0;
  HEAP32[$2 >> 2] = 0;
  HEAP32[$2 + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S2_EE($e) {
  return $e | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12HashMapEntryIN2JS5ValueES2_EaSERKS3_($this, $rhs) {
  var $1 = $rhs | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $this | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  var $4 = $rhs + 8 | 0;
  var $5$0 = HEAP32[$4 >> 2];
  var $5$1 = HEAP32[$4 + 4 >> 2];
  var $6 = $this + 8 | 0;
  HEAP32[$6 >> 2] = $5$0;
  HEAP32[$6 + 4 >> 2] = $5$1;
  return;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE10endNoCheckEv($this_0_0_val, $this_0_1_val) {
  return $this_0_0_val + ($this_0_1_val << 2) | 0;
}

function __ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_EC2ES7_($this) {
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this) {
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_($this) {
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  return;
}

function __ZL13JSVAL_TO_IMPLN2JS5ValueE($agg_result, $_0_0_0_val$0, $_0_0_0_val$1) {
  var $agg_result_0 = $agg_result | 0;
  HEAP32[$agg_result_0 >> 2] = $_0_0_0_val$0;
  HEAP32[$agg_result_0 + 4 >> 2] = $_0_0_0_val$1;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 24 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 24 | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j($capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 24 | 0;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej($1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 24 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 24 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEEaSENS_7MoveRefIS6_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 8 | 0;
  var $7 = $2 + 8 | 0;
  __ZN2js4MoveINS_12HashMapEntryIN2JS5ValueES3_EEEENS_7MoveRefIT_EERS6_($1, $7);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js12HashMapEntryIN2JS5ValueES2_EaSENS_7MoveRefIS3_EE($6, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEENS_7MoveRefIT_EERS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv($0);
  return;
}

function _js_free272($p) {
  _free($p);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEC1ERS7_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEC2ERS7_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIN2JS5ValueES2_EaSENS_7MoveRefIS3_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIN2JS5ValueES3_EEEptEv($rhs_0);
  var $4 = $3 | 0;
  __ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERKS4_($1, $4);
  var $_idx2_val = HEAP32[$1 >> 2];
  var $5 = __ZNK2js7MoveRefIN2JS5ValueEEcvRS2_Ev($_idx2_val);
  var $6 = $5 | 0;
  var $7$0 = HEAP32[$6 >> 2];
  var $7$1 = HEAP32[$6 + 4 >> 2];
  var $8 = $this | 0;
  HEAP32[$8 >> 2] = $7$0;
  HEAP32[$8 + 4 >> 2] = $7$1;
  var $9 = $3 + 8 | 0;
  __ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERS4_($2, $9);
  var $_idx_val = HEAP32[$2 >> 2];
  var $10 = __ZNK2js7MoveRefIN2JS5ValueEEcvRS2_Ev($_idx_val);
  var $11 = $10 | 0;
  var $12$0 = HEAP32[$11 >> 2];
  var $12$1 = HEAP32[$11 + 4 >> 2];
  var $13 = $this + 8 | 0;
  HEAP32[$13 >> 2] = $12$0;
  HEAP32[$13 + 4 >> 2] = $12$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIN2JS5ValueES3_EEEENS_7MoveRefIT_EERS6_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIN2JS5ValueES3_EEEC1ERS4_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIN2JS5ValueES3_EEEC1ERS4_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIN2JS5ValueES3_EEEC2ERS4_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 8 | 0;
  __ZN2js12HashMapEntryIN2JS5ValueES2_EC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIN2JS5ValueES2_EC1Ev($this) {
  __ZN2js12HashMapEntryIN2JS5ValueES2_EC2Ev($this);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $l_idx = $l | 0;
  var $l_idx_val$0 = HEAP32[$l_idx >> 2];
  var $l_idx_val$1 = HEAP32[$l_idx + 4 >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKS4_($l_idx_val$0, $l_idx_val$1);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKS4_($l_0_0_0_val$0, $l_0_0_0_val$1) {
  var $1 = __ZN2js13WrapperHasher4hashEN2JS5ValueE($l_0_0_0_val$0, $l_0_0_0_val$1);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 24 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE9matchHashEj($_idx1_val, $keyHash);
    var $l_idx4 = $l | 0;
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $l_idx_pre_phi = $l_idx4;
      __label__ = 4;
      break;
    }
   case 3:
    var $st$0$0 = $l_idx4 | 0;
    var $l_idx4_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $l_idx4 + 4 | 0;
    var $l_idx4_val$1 = HEAP32[$st$0$1 >> 2];
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS5_EERKS4_($6, $l_idx4_val$0, $l_idx4_val$1);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      var $l_idx_pre_phi = $l_idx4;
      __label__ = 4;
      break;
    }
   case 4:
    var $l_idx_pre_phi;
    var $12 = 32 - $2 | 0;
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj($keyHash, $12, $2);
    var $15 = (1 << $12) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $16 = $5;
    __label__ = 5;
    break;
   case 5:
    var $16;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $17 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE9isRemovedEv($entry_0_idx_val);
    if ($17) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $23 = $16;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $23 = $16;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $23 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $23;
    var $firstRemoved_1;
    var $25 = $h1_0 - $13 & $15;
    var $26 = $23 + $25 * 24 | 0;
    var $_idx_val = HEAP32[$26 >> 2];
    var $27 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isFreeEv($_idx_val);
    if ($27) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $30 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $26;
    var $_0 = $30;
    __label__ = 13;
    break;
   case 11:
    var $32 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE9matchHashEj($_idx_val, $keyHash);
    if ($32) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $26;
      var $h1_0 = $25;
      var $entry_0_idx_val = $_idx_val;
      var $16 = $23;
      __label__ = 5;
      break;
    }
   case 12:
    var $st$0$0 = $l_idx_pre_phi | 0;
    var $l_idx_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $l_idx_pre_phi + 4 | 0;
    var $l_idx_val$1 = HEAP32[$st$0$1 >> 2];
    var $34 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS5_EERKS4_($26, $l_idx_val$0, $l_idx_val$1);
    if ($34) {
      var $_0 = $26;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $26;
      var $h1_0 = $25;
      var $entry_0_idx_val = $_idx_val;
      var $16 = $23;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS4_jj["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS5_EERKS4_($e, $l_0_0_0_val$0, $l_0_0_0_val$1) {
  var $1 = $e + 8 | 0;
  var $2 = __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S2_EE($1);
  var $_idx = $2 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $3 = __ZN2js13WrapperHasher5matchERKN2JS5ValueES4_($_idx_val$0, $_idx_val$1, $l_0_0_0_val$0, $l_0_0_0_val$1);
  return $3;
}

function __ZN2js13WrapperHasher5matchERKN2JS5ValueES4_($l_0_0_0_val$0, $l_0_0_0_val$1, $k_0_0_0_val$0, $k_0_0_0_val$1) {
  var $1 = __ZNK2JS5ValueeqERKS0_($l_0_0_0_val$0, $l_0_0_0_val$1, $k_0_0_0_val$0, $k_0_0_0_val$1);
  return $1;
}

function __ZN2js13WrapperHasher4hashEN2JS5ValueE($_0_0_0_val$0, $_0_0_0_val$1) {
  var $1 = __ZNK2JS5Value9asRawBitsEv($_0_0_0_val$0, $_0_0_0_val$1);
  return $1[1] ^ $1[0];
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE16infallibleAppendERKS2_($this, $t_0_0_0_val$0, $t_0_0_0_val$1) {
  __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t_0_0_0_val$0, $t_0_0_0_val$1);
  return;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE7reserveEj($this, $request) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$this + 12 >> 2] >>> 0 < $request >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $request - HEAP32[$this + 8 >> 2] | 0;
    var $8 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE13growStorageByEj($this, $7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6removeERNS0_14HashTableEntryIS5_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e_idx_val = HEAP32[$e >> 2];
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE12hasCollisionEv($e_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 8 | 0;
  __ZN2js12HashMapEntryIN2JS5ValueES2_EC1Ev($1);
  __ZN2js12HashMapEntryIN2JS5ValueES2_EaSERKS3_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 8 | 0;
  __ZN2js12HashMapEntryIN2JS5ValueES2_EC1Ev($1);
  __ZN2js12HashMapEntryIN2JS5ValueES2_EaSERKS3_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS4_($agg_result, $this, $l) {
  var $l_idx = $l | 0;
  var $l_idx_val$0 = HEAP32[$l_idx >> 2];
  var $l_idx_val$1 = HEAP32[$l_idx + 4 >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKS4_($l_idx_val$0, $l_idx_val$1);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC1ERNS0_14HashTableEntryIS5_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC1ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry);
  return;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this >> 2];
    var $this_idx1 = $this + 4 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $5 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    var $5 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    HEAP32[$this_idx1 >> 2] = $5 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = $this + 12 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 2;
    var $7 = __ZN2js17SystemAllocPolicy7malloc_Ej($6);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $11 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $12 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($8, $11, $12);
    HEAP32[$this_idx >> 2] = $8;
    HEAP32[$this + 8 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $5;
    if ($5 >>> 0 > 536870911) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = __ZN2js17SystemAllocPolicy8realloc_EPvjj($4, $1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5;
    var $9 = $v + 8 | 0;
    HEAP32[$2 >> 2] = $8;
    HEAP32[$9 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_realloc274($p, $bytes) {
  var $1 = _realloc($p, $bytes);
  return $1;
}

function __ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this >> 2];
    var $3 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js17SystemAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEEC2ES3_($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_EC1ES7_($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_EC1ES7_($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_EC2ES7_($this);
  return;
}

function __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC2ES5_($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this);
  return;
}

function __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEEC2ES5_($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_($1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_($this) {
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_($this);
  return;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEEC2ES3_($this) {
  var $1 = $this | 0;
  var $2 = $this + 12 | 0;
  var $3 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($2);
  HEAP32[$1 >> 2] = $3;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN2js6RegExp15executeInternalEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE($this, $cx, $res, $inputstr, $lastIndex, $test, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $aaa = __stackBase__;
    var $anchor = __stackBase__ + 8;
    var $1 = __stackBase__ + 12;
    var $2 = __stackBase__ + 20;
    var $3 = __stackBase__ + 28;
    var $5 = HEAP32[$this + 12 >> 2];
    var $6 = $5 + 1 | 0;
    var $7 = $6 * 3 | 0;
    var $8 = $6 << 1;
    var $9 = __ZN2js6RegExp9initArenaEP9JSContext($cx);
    if ($9) {
      __label__ = 2;
      break;
    } else {
      var $_2 = 0;
      __label__ = 22;
      break;
    }
   case 2:
    var $11 = $cx + 104 | 0;
    __ZN2js18AutoArenaAllocatorC1EP11JSArenaPool($aaa, $11);
    var $aaa_idx3_val = HEAP32[$aaa >> 2];
    var $12 = __ZN2js18AutoArenaAllocator5allocIiEEPT_j($aaa_idx3_val, $7);
    var $13 = $12;
    if (($12 | 0) == 0) {
      var $_1 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = ($8 | 0) == 0;
    if ($15) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $18 = ($5 << 3 | 4) + 4 | 0;
    _memset($13, -1, $18, 4);
    __label__ = 5;
    break;
   case 5:
    var $20 = __ZN8JSString12ensureLinearEP9JSContext($inputstr, $cx);
    if (($20 | 0) == 0) {
      var $_1 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = $20 | 0;
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $23);
    var $_idx_val = HEAP32[$20 >> 2];
    var $24 = __ZNK8JSString6lengthEv($_idx_val);
    var $_idx1_val = HEAP32[$20 + 4 >> 2];
    var $25 = __ZNK14JSLinearString5charsEv($_idx1_val);
    var $this_idx_val = HEAP32[$this + 16 >> 2];
    var $26 = __ZNK2js6RegExp6stickyEv($this_idx_val);
    var $27 = HEAP32[$lastIndex >> 2];
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $inputOffset_0 = 0;
      var $chars_0 = $25;
      var $len_0 = $24;
      var $31 = $27;
      __label__ = 8;
      break;
    }
   case 7:
    var $inputOffset_0 = $27;
    var $chars_0 = $25 + ($27 << 1) | 0;
    var $len_0 = $24 - $27 | 0;
    var $31 = $27;
    __label__ = 8;
    break;
   case 8:
    var $31;
    var $len_0;
    var $chars_0;
    var $inputOffset_0;
    var $33 = HEAP32[$this >> 2];
    var $35 = __Z15jsRegExpExecuteP9JSContextPK8JSRegExpPKtiiPii($cx, $33, $chars_0, $len_0, $31 - $inputOffset_0 | 0, $12, $7);
    if (($35 | 0) == -1) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    __ZN2JSL9NullValueEv259($1);
    var $38 = $1 | 0;
    var $st$2$0 = $38 | 0;
    var $39$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $38 + 4 | 0;
    var $39$1 = HEAP32[$st$2$1 >> 2];
    var $40 = $rval | 0;
    var $st$7$0 = $40 | 0;
    HEAP32[$st$7$0 >> 2] = $39$0;
    var $st$7$1 = $40 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $39$1;
    var $_1 = 1;
    __label__ = 21;
    break;
   case 10:
    if (($35 | 0) < 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $44 = $cx;
    __ZN2js6RegExp15reportPCREErrorEP9JSContexti($44, $35);
    var $_1 = 0;
    __label__ = 21;
    break;
   case 12:
    if (($inputOffset_0 | 0) == 0 | $15) {
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $48 = ($5 << 1) + 2 | 0;
    var $i_01 = 0;
    __label__ = 14;
    break;
   case 14:
    var $i_01;
    var $50 = $12 + ($i_01 << 2) | 0;
    var $51 = HEAP32[$50 >> 2];
    var $_ = ($51 | 0) < 0 ? -1 : $51 + $inputOffset_0 | 0;
    HEAP32[$50 >> 2] = $_;
    var $54 = $i_01 + 1 | 0;
    if (($54 | 0) == ($48 | 0)) {
      __label__ = 15;
      break;
    } else {
      var $i_01 = $54;
      __label__ = 14;
      break;
    }
   case 15:
    if (($res | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN2js13RegExpStatics15updateFromMatchEP9JSContextP14JSLinearStringPij($res, $cx, $20, $12, $8);
    __label__ = 17;
    break;
   case 17:
    var $59 = HEAP32[$12 + 4 >> 2];
    HEAP32[$lastIndex >> 2] = $59;
    if ($test) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    __ZN2JSL12BooleanValueEb275($2, 1);
    var $61 = $2 | 0;
    var $st$2$0 = $61 | 0;
    var $62$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $61 + 4 | 0;
    var $62$1 = HEAP32[$st$2$1 >> 2];
    var $63 = $rval | 0;
    var $st$7$0 = $63 | 0;
    HEAP32[$st$7$0 >> 2] = $62$0;
    var $st$7$1 = $63 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $62$1;
    var $_1 = 1;
    __label__ = 21;
    break;
   case 19:
    var $65 = __ZN2js6RegExp12createResultEP9JSContextP8JSStringPij($cx, $23, $12, $8);
    if (($65 | 0) == 0) {
      var $_1 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    __ZN2JSL11ObjectValueER8JSObject239($3, $65);
    var $68 = $3 | 0;
    var $st$2$0 = $68 | 0;
    var $69$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $68 + 4 | 0;
    var $69$1 = HEAP32[$st$2$1 >> 2];
    var $70 = $rval | 0;
    var $st$7$0 = $70 | 0;
    HEAP32[$st$7$0 >> 2] = $69$0;
    var $st$7$1 = $70 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $69$1;
    var $_1 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_1;
    var $aaa_idx2_val = HEAP32[$aaa + 4 >> 2];
    __ZN2js18AutoArenaAllocatorD1Ev($aaa_idx3_val, $aaa_idx2_val);
    var $_2 = $_1;
    __label__ = 22;
    break;
   case 22:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6RegExp15executeInternalEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE["X"] = 1;

function __ZN2js6RegExp9initArenaEP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 104 | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 120 >> 2];
    var $9 = HEAP32[$cx + 128 >> 2];
    var $12 = $9 + 8 & ($9 ^ -1);
    var $13 = $7 + 12 | 0;
    var $14 = HEAPU32[$13 >> 2];
    var $16 = HEAPU32[$7 + 8 >> 2];
    if ($12 >>> 0 > $16 >>> 0 | $14 >>> 0 > ($16 - $12 | 0) >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $21 = _JS_ArenaAllocate($1, $12);
    var $_p_0 = $21;
    __label__ = 5;
    break;
   case 4:
    var $24 = $12 + $14 | 0;
    HEAP32[$13 >> 2] = $24;
    var $_p_0 = $14;
    __label__ = 5;
    break;
   case 5:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $28 = $_p_0;
    var $29 = _JS_Now();
    var $29$1 = $29[1];
    HEAP32[$28 >> 2] = $29[0];
    HEAP32[$28 + 4 >> 2] = $29$1;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18AutoArenaAllocatorC1EP11JSArenaPool($this, $pool) {
  __ZN2js18AutoArenaAllocatorC2EP11JSArenaPool($this, $pool);
  return;
}

function __ZNK2js15AlreadyIncRefedINS_6RegExpEE3getEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js15AlreadyIncRefedINS_6RegExpEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6RegExp6stickyEv($this_0_4_val) {
  return ($this_0_4_val & 8 | 0) != 0;
}

function __ZNK2js6RegExp6globalEv($this_0_4_val) {
  return ($this_0_4_val & 2 | 0) != 0;
}

function __ZNK2js6RegExp10ignoreCaseEv($this_0_4_val) {
  return ($this_0_4_val & 1 | 0) != 0;
}

function __ZNK2js6RegExp9multilineEv($this_0_4_val) {
  return ($this_0_4_val & 4 | 0) != 0;
}

function __ZNK7mozilla14AlignedStorageILj80EE4addrEv($this) {
  return $this;
}

function __ZNK2js15AlreadyIncRefedINS_6RegExpEEcvPPPPPS1_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function _STRING_TO_JSVAL_IMPL277($agg_result, $str) {
  HEAP32[$agg_result + 4 >> 2] = -123;
  HEAP32[$agg_result >> 2] = $str;
  return;
}

function __ZN2js18RegExpMatchBuilderC2EP9JSContextP8JSObject($this, $cx, $array) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $array;
  return;
}

function _BOOLEAN_TO_JSVAL_IMPL278($agg_result, $b) {
  HEAP32[$agg_result + 4 >> 2] = -125;
  HEAP32[$agg_result >> 2] = $b;
  return;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE8shrinkByEj($this, $incr) {
  var $1 = $this + 4 | 0;
  var $3 = HEAP32[$1 >> 2] - $incr | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js18AutoArenaAllocatorC2EP11JSArenaPool($this, $pool) {
  HEAP32[$this >> 2] = $pool;
  var $7 = HEAP32[HEAP32[$pool + 16 >> 2] + 12 >> 2];
  HEAP32[$this + 4 >> 2] = $7;
  return;
}

function __ZN8JSObject15setLastPropertyEPKN2js5ShapeE($this, $shape) {
  HEAP32[$this >> 2] = $shape;
  return;
}

function __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP16[$p_01 >> 1];
    HEAP16[$_02 >> 1] = $2;
    var $3 = $p_01 + 2 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 2 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 1) | 0;
}

function __ZN2js18AutoArenaAllocator5allocIiEEPT_j($this_0_0_val, $elems) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this_0_0_val + 16 >> 2];
    var $5 = HEAP32[$this_0_0_val + 24 >> 2];
    var $8 = $5 + ($elems << 2) & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($this_0_0_val, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13RegExpStatics15updateFromMatchEP9JSContextP14JSLinearStringPij($this, $cx, $input, $buf, $matchItemCount) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    __ZN2js13RegExpStatics12aboutToWriteEv($1);
    HEAP32[$this + 96 >> 2] = $input | 0;
    var $4 = $this | 0;
    var $5 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE19resizeUninitializedEj($4, $matchItemCount);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    if (($matchItemCount | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx = $this | 0;
    var $i_01 = 0;
    __label__ = 5;
    break;
   case 4:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    __label__ = 7;
    break;
   case 5:
    var $i_01;
    var $9 = HEAP32[$buf + ($i_01 << 2) >> 2];
    var $_idx_val = HEAP32[$_idx >> 2];
    var $10 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEEixEj($_idx_val, $i_01);
    HEAP32[$10 >> 2] = $9;
    var $11 = $i_01 + 1 | 0;
    if (($11 | 0) == ($matchItemCount | 0)) {
      __label__ = 6;
      break;
    } else {
      var $i_01 = $11;
      __label__ = 5;
      break;
    }
   case 6:
    HEAP32[$this + 92 >> 2] = $input;
    __label__ = 7;
    break;
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL12BooleanValueEb275($agg_result, $boo) {
  __ZN2JS5Value10setBooleanEb($agg_result, $boo);
  return;
}

function __ZN2js6RegExp12createResultEP9JSContextP8JSStringPij($cx, $input, $buf, $matchItemCount) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $builder = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __ZN2js17NewSlowEmptyArrayEP9JSContext($cx);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js18RegExpMatchBuilderC1EP9JSContextP8JSObject($builder, $cx, $3);
    var $6 = $cx;
    var $builder_idx2_val = HEAPU32[$builder >> 2];
    var $builder_idx3_val = HEAPU32[$builder + 4 >> 2];
    var $_idx4 = $1 | 0;
    var $_idx = $2 | 0;
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    if ($i_0 >>> 0 < $matchItemCount >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    var $11 = HEAPU32[$buf + ($i_0 << 2) >> 2];
    if (($11 | 0) > -1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $17 = HEAP32[$buf + (($i_0 | 1) << 2) >> 2] - $11 | 0;
    var $18 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($6, $input, $11, $17);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = $18 | 0;
    var $22 = $i_0 >>> 1;
    __ZN2JSL11StringValueEP8JSString276($1, $21);
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    var $23 = __ZN2js18RegExpMatchBuilder6appendEjN2JS5ValueE($builder_idx2_val, $builder_idx3_val, $22, $_idx4_val$0, $_idx4_val$1);
    if ($23) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 7:
    var $25 = $i_0 >>> 1;
    __ZN2JSL14UndefinedValueEv245($2);
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $26 = __ZN2js18RegExpMatchBuilder6appendEjN2JS5ValueE($builder_idx2_val, $builder_idx3_val, $25, $_idx_val$0, $_idx_val$1);
    if ($26) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 8:
    var $i_0 = $i_0 + 2 | 0;
    __label__ = 3;
    break;
   case 9:
    var $30 = HEAP32[$buf >> 2];
    var $31 = __ZN2js18RegExpMatchBuilder8setIndexEi($builder, $30);
    if ($31) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 10:
    var $33 = __ZN2js18RegExpMatchBuilder8setInputEP8JSString($builder, $input);
    if ($33) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 11:
    var $_0 = $3;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6RegExp12createResultEP9JSContextP8JSStringPij["X"] = 1;

function __ZN2js18AutoArenaAllocatorD1Ev($this_0_0_val, $this_0_1_val) {
  __ZN2js18AutoArenaAllocatorD2Ev($this_0_0_val, $this_0_1_val);
  return;
}

function __ZN2js18AutoArenaAllocatorD2Ev($this_0_0_val, $this_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this_0_0_val + 16 >> 2];
    if (($2 | 0) == ($this_0_0_val | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $this_0_1_val;
    var $8 = HEAP32[$2 + 4 >> 2];
    var $10 = $2 + 12 | 0;
    if (($6 - $8 | 0) >>> 0 > (HEAP32[$10 >> 2] - $8 | 0) >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = HEAP32[$this_0_0_val + 24 >> 2];
    var $19 = $16 + $6 & ($16 ^ -1);
    HEAP32[$10 >> 2] = $19;
    __label__ = 5;
    break;
   case 4:
    _JS_ArenaRelease($this_0_0_val, $this_0_1_val);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18RegExpMatchBuilderC1EP9JSContextP8JSObject($this, $cx, $array) {
  __ZN2js18RegExpMatchBuilderC2EP9JSContextP8JSObject($this, $cx, $array);
  return;
}

function __ZN2js18RegExpMatchBuilder6appendEjN2JS5ValueE($this_0_0_val, $this_0_1_val, $index, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $v = __stackBase__;
  var $1 = $v | 0;
  HEAP32[$1 >> 2] = $_0_0_0_val$0;
  HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
  var $2 = $this_0_0_val;
  var $3 = $this_0_1_val;
  var $4 = __Z16js_DefineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($2, $3, $index, $v, 10, 12, 1);
  var $5 = ($4 | 0) != 0;
  STACKTOP = __stackBase__;
  return $5;
}

function __ZN2JSL11StringValueEP8JSString276($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2js18RegExpMatchBuilder8setIndexEi($this, $index) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $8 = HEAP32[HEAP32[HEAP32[$2 >> 2] + 52 >> 2] + 210232 >> 2] | 0;
  __ZN2JSL10Int32ValueEi251($1, $index);
  var $this_idx_val = HEAP32[$2 >> 2];
  var $this_idx1_val = HEAP32[$this + 4 >> 2];
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $9 = __ZN2js18RegExpMatchBuilder11setPropertyEP6JSAtomN2JS5ValueE($this_idx_val, $this_idx1_val, $8, $_idx_val$0, $_idx_val$1);
  STACKTOP = __stackBase__;
  return $9;
}

function __ZN2js18RegExpMatchBuilder8setInputEP8JSString($this, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $8 = HEAP32[HEAP32[HEAP32[$2 >> 2] + 52 >> 2] + 210236 >> 2] | 0;
  __ZN2JSL11StringValueEP8JSString276($1, $str);
  var $this_idx_val = HEAP32[$2 >> 2];
  var $this_idx1_val = HEAP32[$this + 4 >> 2];
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $9 = __ZN2js18RegExpMatchBuilder11setPropertyEP6JSAtomN2JS5ValueE($this_idx_val, $this_idx1_val, $8, $_idx_val$0, $_idx_val$1);
  STACKTOP = __stackBase__;
  return $9;
}

function __ZN2js18RegExpMatchBuilder11setPropertyEP6JSAtomN2JS5ValueE($this_0_0_val, $this_0_1_val, $name, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $v = __stackBase__;
  var $1 = $v | 0;
  HEAP32[$1 >> 2] = $_0_0_0_val$0;
  HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom244($name);
  var $3 = $this_0_0_val;
  var $4 = $this_0_1_val;
  var $5 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($3, $4, $2, $v, 10, 12, 1);
  var $6 = ($5 | 0) != 0;
  STACKTOP = __stackBase__;
  return $6;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE19resizeUninitializedEj($this, $newLength) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 < $newLength >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $newLength - $2 | 0;
    var $6 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE19growByUninitializedEj($this, $5);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 3:
    var $8 = $2 - $newLength | 0;
    __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE8shrinkByEj($this, $8);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEEixEj($this_0_0_val, $i) {
  var $1 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE5beginEv($this_0_0_val);
  return $1 + ($i << 2) | 0;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE19growByUninitializedEj($this, $incr) {
  var $1 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE10growByImplILb0EEEbj($this, $incr);
  return $1;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE10growByImplILb0EEEbj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 4 | 0;
    var $4 = HEAPU32[$3 >> 2];
    if ((HEAP32[$this + 8 >> 2] - $4 | 0) >>> 0 < $incr >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $10 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE13growStorageByEj($this, $incr);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = HEAP32[$3 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $10;
    HEAP32[$3 >> 2] = $10 + $incr | 0;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = $this + 12 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj80EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 2;
    var $7 = __ZN2js17SystemAllocPolicy7malloc_Ej($6);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $11 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $12 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplIiLj20ENS_17SystemAllocPolicyELb1EE13moveConstructIiEEvPiPKT_S7_($8, $11, $12);
    HEAP32[$this_idx >> 2] = $8;
    HEAP32[$this + 8 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIiLj20ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIiLj20ES1_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $5;
    if ($5 >>> 0 > 536870911) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIiLj20ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIiLj20ES1_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = __ZN2js17SystemAllocPolicy8realloc_EPvjj($4, $1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5;
    var $9 = $v + 8 | 0;
    HEAP32[$2 >> 2] = $8;
    HEAP32[$9 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIiLj20ENS_17SystemAllocPolicyELb1EE13moveConstructIiEEvPiPKT_S7_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIiLj20ENS_17SystemAllocPolicyELb1EE13copyConstructIiEEvPiPKT_S7_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6RegExp6createEP9JSContextP8JSStringjPNS_11TokenStreamE($agg_result, $cx, $source, $flags) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSString12ensureLinearEP9JSContext($source, $cx);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js15AlreadyIncRefedINS_6RegExpEEC1EPS1_($agg_result, 0);
    __label__ = 8;
    break;
   case 3:
    var $5 = __ZN9JSContext4new_IN2js6RegExpEP14JSLinearStringjP13JSCompartmentEEPT_T0_T1_T2_($cx, $1, $flags);
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js15AlreadyIncRefedINS_6RegExpEEC1EPS1_($agg_result, 0);
    __label__ = 8;
    break;
   case 5:
    var $9 = __ZN2js6RegExp7compileEP9JSContextPNS_11TokenStreamE($5, $cx);
    if ($9) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js10Foreground7delete_INS_6RegExpEEEvPT_($5);
    __ZN2js15AlreadyIncRefedINS_6RegExpEEC1EPS1_($agg_result, 0);
    __label__ = 8;
    break;
   case 7:
    __ZN2js15AlreadyIncRefedINS_6RegExpEEC1EPS1_($agg_result, $5);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE279($cx) {
  var $3 = HEAPU32[__ZN2js11RegExpClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb264($3);
  var $5 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE280($cx, $4);
  return $5;
}

function __ZN8JSObject10initRegExpEP9JSContextPN2js6RegExpE($this, $cx, $re) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK8JSObject11nativeEmptyEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $5 = HEAP32[$cx + 56 >> 2] + 796 | 0;
    var $6 = HEAP32[$5 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $15 = $6;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = $this;
    var $10 = $cx;
    var $11 = __ZN8JSObject24assignInitialRegExpShapeEP9JSContext($9, $10);
    var $12 = $11;
    HEAP32[$5 >> 2] = $12;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      var $15 = $12;
      __label__ = 4;
      break;
    }
   case 4:
    var $15;
    __ZN8JSObject15setLastPropertyEPKN2js5ShapeE($this, $15);
    __label__ = 5;
    break;
   case 5:
    var $17 = $re;
    __ZN8JSObject10setPrivateEPv($this, $17);
    __ZN8JSObject19zeroRegExpLastIndexEv($this);
    var $re_idx_val = HEAP32[$re + 4 >> 2];
    var $18 = __ZNK2js6RegExp9getSourceEv($re_idx_val);
    var $19 = $18 | 0;
    __ZN8JSObject15setRegExpSourceEP8JSString($this, $19);
    var $re_idx4 = $re + 16 | 0;
    var $re_idx4_val = HEAP32[$re_idx4 >> 2];
    var $20 = __ZNK2js6RegExp6globalEv($re_idx4_val);
    __ZN8JSObject15setRegExpGlobalEb($this, $20);
    var $re_idx2_val = HEAP32[$re_idx4 >> 2];
    var $21 = __ZNK2js6RegExp10ignoreCaseEv($re_idx2_val);
    __ZN8JSObject19setRegExpIgnoreCaseEb($this, $21);
    var $re_idx3_val = HEAP32[$re_idx4 >> 2];
    var $22 = __ZNK2js6RegExp9multilineEv($re_idx3_val);
    __ZN8JSObject18setRegExpMultilineEb($this, $22);
    var $re_idx1_val = HEAP32[$re_idx4 >> 2];
    var $23 = __ZNK2js6RegExp6stickyEv($re_idx1_val);
    __ZN8JSObject15setRegExpStickyEb($this, $23);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6RegExp6decrefEP9JSContext($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 8 | 0;
    var $3 = HEAP32[$1 >> 2] - 1 | 0;
    HEAP32[$1 >> 2] = $3;
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN9JSContext7delete_IN2js6RegExpEEEvPT_($this);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext7delete_IN2js6RegExpEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $p_idx_val = HEAP32[$p >> 2];
    __ZN2js6RegExpD1Ev($p_idx_val);
    var $3 = $p;
    __ZN9JSContext5free_EPv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6RegExpD1Ev($this_0_0_val) {
  __ZN2js6RegExpD2Ev($this_0_0_val);
  return;
}

function __ZN2js6RegExpD2Ev($this_0_0_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_0_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z12jsRegExpFreeP8JSRegExp($this_0_0_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject19zeroRegExpLastIndexEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL10Int32ValueEi251($1, 0);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, 0, $_idx_val$0, $_idx_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN8JSObject15setRegExpSourceEP8JSString($this, $source) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL11StringValueEP8JSString276($1, $source);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, 1, $_idx_val$0, $_idx_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN8JSObject15setRegExpGlobalEb($this, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL12BooleanValueEb275($1, $global);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, 2, $_idx_val$0, $_idx_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN8JSObject19setRegExpIgnoreCaseEb($this, $ignoreCase) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL12BooleanValueEb275($1, $ignoreCase);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, 3, $_idx_val$0, $_idx_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN8JSObject18setRegExpMultilineEb($this, $multiline) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL12BooleanValueEb275($1, $multiline);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, 4, $_idx_val$0, $_idx_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN8JSObject15setRegExpStickyEb($this, $sticky) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL12BooleanValueEb275($1, $sticky);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, 5, $_idx_val$0, $_idx_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE280($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js11RegExpClassE + 4 >> 2] >>> 24;
    var $4 = __ZNK9JSContext5hasfpEv($cx);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $7;
    var $8 = $cx;
    var $9 = $global;
    var $10 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($8, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $18 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZNK9JSContext2fpEv($cx);
    var $13 = __ZNK2js10StackFrame10scopeChainEv($12);
    var $14 = $13;
    var $15 = __ZNK8JSObject9getGlobalEv($14);
    var $16 = $15;
    HEAP32[$global >> 2] = $16;
    var $18 = $16;
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $18, $19);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $20 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    HEAP32[$proto >> 2] = $22;
    var $29 = $22;
    __label__ = 9;
    break;
   case 7:
    var $24 = $cx;
    var $26 = $proto;
    var $27 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($24, $18, $3, $26, __ZN2js11RegExpClassE);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $29 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $29;
    var $30 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE281($cx, $29, $18, $kind);
    var $_0 = $30;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE281($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, __ZN2js11RegExpClassE, $1, $parent, 0, (__ZN2js11RegExpClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $7 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, __ZN2js11RegExpClassE, $kind);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $10);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15AlreadyIncRefedINS_6RegExpEEC1EPS1_($this, $obj) {
  __ZN2js15AlreadyIncRefedINS_6RegExpEEC2EPS1_($this, $obj);
  return;
}

function __ZN9JSContext4new_IN2js6RegExpEP14JSLinearStringjP13JSCompartmentEEPT_T0_T1_T2_($this, $p1, $p2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 20);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js6RegExpC1EP14JSLinearStringjP13JSCompartment($4, $p1, $p2);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6RegExp7compileEP9JSContextPNS_11TokenStreamE($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sb = __stackBase__;
    var $1 = $this + 4 | 0;
    var $3 = HEAP32[$1 >> 2] | 0;
    var $4 = __ZN8JSString12ensureLinearEP9JSContext($3, $cx);
    if (($4 | 0) == 0) {
      var $_1 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 16 >> 2];
    var $7 = __ZNK2js6RegExp6stickyEv($this_idx_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAP32[$1 >> 2];
    var $10 = __ZN2js6RegExp13compileHelperEP9JSContextR14JSLinearStringPNS_11TokenStreamE($this, $cx, $9);
    var $_1 = $10;
    __label__ = 8;
    break;
   case 4:
    __ZN2js12StringBufferC1EP9JSContext($sb, $cx);
    var $_idx1_val = HEAP32[HEAP32[$1 >> 2] >> 2];
    var $13 = __ZNK8JSString6lengthEv($_idx1_val);
    var $14 = $13 + 5 | 0;
    var $15 = __ZN2js12StringBuffer7reserveEj($sb, $14);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    __ZN2js12StringBuffer16infallibleAppendEPKtj($sb, __ZZN2js6RegExp7compileEP9JSContextPNS_11TokenStreamEE6prefix | 0, 4);
    var $17 = HEAP32[$1 >> 2];
    var $_idx2_val = HEAP32[$17 + 4 >> 2];
    var $18 = __ZNK14JSLinearString5charsEv($_idx2_val);
    var $_idx_val = HEAP32[$17 >> 2];
    var $19 = __ZNK8JSString6lengthEv($_idx_val);
    __ZN2js12StringBuffer16infallibleAppendEPKtj($sb, $18, $19);
    __ZN2js12StringBuffer16infallibleAppendEPKtj($sb, __ZZN2js6RegExp7compileEP9JSContextPNS_11TokenStreamEE7postfix | 0, 1);
    var $20 = $sb;
    var $21 = __ZN2js12StringBuffer12finishStringEv($20);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $24 = $21 | 0;
    var $25 = __ZN2js6RegExp13compileHelperEP9JSContextR14JSLinearStringPNS_11TokenStreamE($this, $cx, $24);
    var $_0 = $25;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    __ZN2js12StringBufferD1Ev($sb);
    var $_1 = $_0;
    __label__ = 8;
    break;
   case 8:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Foreground7delete_INS_6RegExpEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $p_idx_val = HEAP32[$p >> 2];
    __ZN2js6RegExpD1Ev($p_idx_val);
    var $3 = $p;
    _js_free272($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6RegExp13compileHelperEP9JSContextR14JSLinearStringPNS_11TokenStreamE($this, $cx, $pattern) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $error = __stackBase__;
    HEAP32[$error >> 2] = 0;
    var $pattern_idx_val = HEAP32[$pattern + 4 >> 2];
    var $1 = __ZNK14JSLinearString5charsEv($pattern_idx_val);
    var $_idx_val = HEAP32[$pattern >> 2];
    var $2 = __ZNK8JSString6lengthEv($_idx_val);
    var $this_idx_val = HEAPU32[$this + 16 >> 2];
    var $3 = __ZNK2js6RegExp10ignoreCaseEv($this_idx_val);
    var $4 = $3 & 1;
    var $5 = __ZNK2js6RegExp9multilineEv($this_idx_val);
    var $6 = $5 & 1;
    var $7 = $this + 12 | 0;
    var $8 = __Z15jsRegExpCompilePKti24JSRegExpIgnoreCaseOption23JSRegExpMultilineOptionPjPi($1, $2, $4, $6, $7, $error);
    HEAP32[$this >> 2] = $8;
    var $10 = HEAP32[$error >> 2];
    if (($10 | 0) == 0) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = $cx;
    __ZN2js6RegExp15reportPCREErrorEP9JSContexti($13, $10);
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer7reserveEj($this, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js12StringBuffer11checkLengthEj($this, $len);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this | 0;
    var $4 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE7reserveEj($3, $len);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer16infallibleAppendEPKtj($this, $chars, $len) {
  var $1 = $this | 0;
  __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16infallibleAppendItEEvPKT_j($1, $chars, $len);
  return;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16infallibleAppendItEEvPKT_j($this, $begin, $length) {
  __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendItEEvPKT_j($this, $begin, $length);
  return;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendItEEvPKT_j($this, $insBegin, $length) {
  var $this_idx_val = HEAP32[$this + 4 >> 2];
  var $this_idx1 = $this + 8 | 0;
  var $this_idx1_val = HEAP32[$this_idx1 >> 2];
  var $1 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
  var $2 = $insBegin + ($length << 1) | 0;
  __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_($1, $insBegin, $2);
  var $4 = HEAP32[$this_idx1 >> 2] + $length | 0;
  HEAP32[$this_idx1 >> 2] = $4;
  return;
}

function __ZN2js12StringBuffer11checkLengthEj($this, $length) {
  var $1 = __ZNK2js12StringBuffer7contextEv($this);
  var $2 = __ZN2jsL17CheckStringLengthEP9JSContextj($1, $length);
  return $2;
}

function __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js18ContextAllocPolicy7contextEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js13RegExpStatics8getFlagsEv($this_0_3_val) {
  return $this_0_3_val;
}

function __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js5Shape10attributesEv($this_0_7_val) {
  return $this_0_7_val;
}

function __ZNK2js5Shape6getterEv($this_0_4_0_val) {
  return $this_0_4_0_val;
}

function __ZNK2js5Shape6setterEv($this_0_5_0_val) {
  return $this_0_5_0_val;
}

function __ZN19AutoHoldCompartmentD2Ev($this_0_0_val) {
  HEAP8[$this_0_0_val] = 0;
  return;
}

function __ZL14JSID_FROM_BITSj300($bits) {
  return $bits;
}

function __ZNK9JSContext13getRunOptionsEv($this_0_6_val) {
  return $this_0_6_val;
}

function __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE5emptyEv($this_0_2_val) {
  return ($this_0_2_val | 0) == 0;
}

function __ZNK2js15InvokeArgsGuard6pushedEv($this_0_1_val) {
  return ($this_0_1_val | 0) != 0;
}

function __ZNK9JSContext12hasRunOptionEj($this_0_6_val, $ropt) {
  return ($this_0_6_val & $ropt | 0) != 0;
}

function __ZNK8JSObject11isSlowArrayEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js14SlowArrayClassE | 0);
}

function _JSID_IS_STRING293($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function __ZNK2js5Shape8isMethodEv($this_0_8_val) {
  return $this_0_8_val << 24 >> 24 < 0;
}

function _JSVAL_IS_PRIMITIVE_IMPL($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 < 4294967175 & 1;
}

function _JSVAL_TO_OBJECT_IMPL296($l_0$0, $l_0$1) {
  return $l_0$0;
}

function __ZNK2js5Shape8hasTableEv($this_0_2_0_val) {
  return $this_0_2_0_val >>> 0 > 7;
}

function __ZN2jsL13VersionSetXMLEP9JSVersionb($version, $enable) {
  var $1 = HEAP32[$version >> 2];
  var $storemerge = $enable ? $1 | 4096 : $1 & -4097;
  HEAP32[$version >> 2] = $storemerge;
  return;
}

function __ZN2jsL13OptionsHasXMLEj($options) {
  return ($options & 64 | 0) != 0;
}

function __ZN2jsL13VersionHasXMLE9JSVersion($version) {
  return ($version & 4096 | 0) != 0;
}

function __ZN2jsL19VersionExtractFlagsE9JSVersion($version) {
  return $version & -4096;
}

function _JSVAL_IS_INT32_IMPL($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -127) & 1;
}

function __ZN2jsL8JsvalifyEPNS_5ClassE($c) {
  return $c;
}

function __ZL18JSDOUBLE_IS_FINITEd($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE11allocPolicyEv($this) {
  return $this | 0;
}

function __ZN2js6RegExpC2EP14JSLinearStringjP13JSCompartment($this, $source, $flags) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = $source;
  HEAP32[$this + 8 >> 2] = 1;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = $flags;
  return;
}

function __ZN2js15AlreadyIncRefedINS_6RegExpEEC2EPS1_($this, $obj) {
  HEAP32[$this >> 2] = $obj;
  return;
}

function __ZN2js18ContextAllocPolicyC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  return;
}

function __ZN2js12CallArgsList9setActiveEv($this) {
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZN2js12CallArgsList11setInactiveEv($this) {
  HEAP8[$this + 12 | 0] = 0;
  return;
}

function _OBJECT_TO_JSVAL_IMPL284($agg_result, $obj) {
  HEAP32[$agg_result + 4 >> 2] = -121;
  HEAP32[$agg_result >> 2] = $obj;
  return;
}

function __ZN18AutoLastFrameCheckC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  return;
}

function __ZN9JSContext17setDefaultVersionE9JSVersion($this, $version) {
  HEAP32[$this + 8 >> 2] = $version;
  return;
}

function __ZN9JSContext15overrideVersionE9JSVersion($this, $newVersion) {
  HEAP32[$this + 12 >> 2] = $newVersion;
  HEAP8[$this + 16 | 0] = 1;
  return;
}

function __ZN2js5Shape5RangeC2EPKS0_($this, $shape) {
  HEAP32[$this >> 2] = $shape;
  return;
}

function __ZNK2js5Shape12methodObjectEv($this) {
  return HEAP32[$this + 16 >> 2];
}

function __ZN19AutoHoldCompartmentC2EP13JSCompartment($this, $compartment) {
  var $2 = $compartment + 340 | 0;
  HEAP32[$this >> 2] = $2;
  HEAP8[$2] = 1;
  return;
}

function __ZN18JSAutoResolveFlagsD2Ev($this_0_0_val, $this_0_1_val) {
  HEAP32[$this_0_0_val + 208 >> 2] = $this_0_1_val;
  return;
}

function __ZN18JSAutoResolveFlagsC2EP9JSContextj($this, $cx, $flags) {
  HEAP32[$this >> 2] = $cx;
  var $3 = $cx + 208 | 0;
  var $4 = HEAP32[$3 >> 2];
  HEAP32[$this + 4 >> 2] = $4;
  HEAP32[$3 >> 2] = $flags;
  return;
}

function __ZN9JSRuntime18resetGCMallocBytesEv($this) {
  var $2 = HEAP32[$this + 156 >> 2];
  HEAP32[$this + 144096 >> 2] = $2;
  return;
}

function __ZNK2js5Shape8getTableEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN9JSContext13setRunOptionsEj($this, $ropts) {
  HEAP32[$this + 32 >> 2] = $ropts;
  return;
}

function __ZN2js13StaticStringsC2Ev($this) {
  HEAP8[$this | 0] = 0;
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_($this) {
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  return;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE7reserveEj($this, $request) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$this + 12 >> 2] >>> 0 < $request >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $request - HEAP32[$this + 8 >> 2] | 0;
    var $8 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE13growStorageByEj($this, $7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj64EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 1;
    var $_idx_val = HEAP32[$this >> 2];
    var $7 = __ZN2js18ContextAllocPolicy7malloc_Ej($_idx_val, $6);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $11 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $12 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13moveConstructItEEvPtPKT_S7_($8, $11, $12);
    HEAP32[$this_idx >> 2] = $8;
    HEAP32[$this + 12 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE6growToERNS_6VectorItLj32ES1_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 1073741823) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js18ContextAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 1073741823) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js18ContextAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE6growToERNS_6VectorItLj32ES1_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 1;
    var $2 = $v + 12 | 0;
    var $4 = HEAP32[$2 >> 2] << 1;
    var $5 = $v + 4 | 0;
    var $7 = HEAP32[$5 >> 2];
    var $_idx_val = HEAP32[$v >> 2];
    var $8 = __ZN2js18ContextAllocPolicy8realloc_EPvjj($_idx_val, $7, $4, $1);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = $8;
    HEAP32[$5 >> 2] = $11;
    HEAP32[$2 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18ContextAllocPolicy8realloc_EPvjj($this_0_0_val, $p, $oldBytes, $bytes) {
  var $1 = __ZN9JSContext8realloc_EPvjj($this_0_0_val, $p, $oldBytes, $bytes);
  return $1;
}

function __ZN9JSContext8realloc_EPvjj($this, $p, $oldBytes, $newBytes) {
  var $2 = HEAP32[$this + 52 >> 2];
  var $3 = __ZN9JSRuntime8realloc_EPvjjP9JSContext($2, $p, $oldBytes, $newBytes, $this);
  return $3;
}

function __ZN9JSRuntime8realloc_EPvjjP9JSContext($this, $p, $oldBytes, $newBytes, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newBytes - $oldBytes | 0;
    __ZN9JSRuntime19updateMallocCounterEj($this, $1);
    var $2 = _js_realloc274($p, $newBytes);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $6 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    __ZN9JSRuntime13onOutOfMemoryEPvjP9JSContext($cx);
    var $6 = 0;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js18ContextAllocPolicy19reportAllocOverflowEv($this_0_0_val) {
  __Z27js_ReportAllocationOverflowP9JSContext($this_0_0_val);
  return;
}

function __ZN2js18ContextAllocPolicy7malloc_Ej($this_0_0_val, $bytes) {
  var $1 = __ZN9JSContext7malloc_Ej($this_0_0_val, $bytes);
  return $1;
}

function __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13moveConstructItEEvPtPKT_S7_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2jsL17CheckStringLengthEP9JSContextj($cx, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 268435455) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    __Z27js_ReportAllocationOverflowP9JSContext($cx);
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12StringBuffer7contextEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE11allocPolicyEv($1);
  var $_idx_val = HEAP32[$2 >> 2];
  var $3 = __ZNK2js18ContextAllocPolicy7contextEv($_idx_val);
  return $3;
}

function __ZN2js6RegExpC1EP14JSLinearStringjP13JSCompartment($this, $source, $flags) {
  __ZN2js6RegExpC2EP14JSLinearStringjP13JSCompartment($this, $source, $flags);
  return;
}

function __ZN2js13RegExpStatics12setMultilineEb($this, $enabled) {
  var $1 = $this;
  __ZN2js13RegExpStatics12aboutToWriteEv($1);
  var $2 = $this + 100 | 0;
  var $3 = HEAP32[$2 >> 2];
  var $storemerge = $enabled ? $3 | 4 : $3 & -5;
  HEAP32[$2 >> 2] = $storemerge;
  return;
}

function __ZN2js12StringBufferD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEED1Ev($1);
  return;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEED1Ev($this) {
  __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js18ContextAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18ContextAllocPolicy5free_EPv($p) {
  __ZN9JSContext5free_EPv($p);
  return;
}

function __ZN2js12StringBufferC2EP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js18ContextAllocPolicyC1EP9JSContext($1, $cx);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEEC1ES1_($2, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEEC1ES1_($this, $ap_01) {
  __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEEC2ES1_($this, $ap_01);
  return;
}

function __ZN2js18ContextAllocPolicyC1EP9JSContext($this, $cx) {
  __ZN2js18ContextAllocPolicyC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEEC2ES1_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj64EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 32;
  return;
}

function __ZN2js15InvokeArgsGuardD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 16 >> 2];
    var $1 = __ZNK2js15InvokeArgsGuard6pushedEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this_idx_val;
    var $4 = $this;
    __ZN2js12ContextStack13popInvokeArgsERKNS_15InvokeArgsGuardE($3, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15InvokeArgsGuardC2Ev($this) {
  var $1 = $this;
  HEAP32[$1 >> 2] = 0;
  HEAP32[$1 + 4 >> 2] = 0;
  HEAP32[$1 + 8 >> 2] = 0;
  HEAP8[$1 + 12] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP8[$this + 20 | 0] = 0;
  return;
}

function __ZN2js8BindingsC1EP9JSContext($this) {
  __ZN2js8BindingsC2EP9JSContext($this);
  return;
}

function __ZN2js8Bindings11addArgumentEP9JSContextP6JSAtomPt($this, $cx, $name, $slotp) {
  var $2 = HEAP16[$this + 4 >> 1];
  HEAP16[$slotp >> 1] = $2;
  var $3 = $this;
  var $4 = $cx;
  var $5 = __ZN2js8Bindings3addEP9JSContextP6JSAtomNS_11BindingKindE($3, $4, $name, 1);
  return $5;
}

function __ZN2js8BindingsC2EP9JSContext($this) {
  var $1 = $this;
  HEAP32[$1 >> 2] = 0;
  HEAP32[$1 + 4 >> 2] = 0;
  HEAP16[$1 + 8 >> 1] = 0;
  HEAP8[$1 + 10] = 0;
  return;
}

function __ZN18AutoLastFrameCheckD2Ev($this_0_0_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx1_val = HEAP32[$this_0_0_val + 20 >> 2];
    var $1 = __ZN9JSContext18isExceptionPendingEv($_idx1_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = _JS_IsRunning($this_0_0_val);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$this_0_0_val + 32 >> 2];
    var $6 = __ZNK9JSContext12hasRunOptionEj($_idx_val, 256);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = $this_0_0_val;
    var $9 = __Z26js_ReportUncaughtExceptionP9JSContext($8);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21JS_OPTIONS_TO_TCFLAGSP9JSContext($cx_0_6_val) {
  var $1 = __ZNK9JSContext12hasRunOptionEj($cx_0_6_val, 16);
  var $2 = $1 ? 8192 : 0;
  var $3 = __ZNK9JSContext12hasRunOptionEj($cx_0_6_val, 4096);
  var $4 = $3 ? 16384 : 0;
  return $4 | $2;
}

function __ZNK8JSObject12getFixedSlotEj($this, $slot) {
  var $1 = __ZNK8JSObject10fixedSlotsEv($this);
  return $1 + ($slot << 3) | 0;
}

function __ZN2js16AutoObjectRooterD2Ev($this) {
  var $_idx_val = HEAP32[$this >> 2];
  var $_idx1_val = HEAP32[$this + 8 >> 2];
  __ZN2js12AutoGCRooterD2Ev($_idx_val, $_idx1_val);
  return;
}

function __ZN2js16AutoObjectRooterC2EP9JSContextP8JSObject($this, $cx, $obj) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($1, $cx, -10);
  HEAP32[$this + 12 >> 2] = $obj;
  return;
}

function __ZN8JSObject13setAttributesEP9JSContextiPj($this, $cx, $id, $attrsp) {
  __ZN2js5types26MarkTypePropertyConfiguredEP9JSContextP8JSObjecti($cx, $this, $id);
  var $this_idx_val = HEAP32[$this + 4 >> 2];
  var $1 = __ZNK8JSObject6getOpsEv($this_idx_val);
  var $3 = HEAP32[$1 + 84 >> 2];
  var $5 = ($3 | 0) != 0 ? $3 : 54;
  var $6 = FUNCTION_TABLE[$5]($cx, $this, $id, $attrsp);
  return $6;
}

function __ZNK8JSObject12containsSlotEj($this_0_0_val_0_1_val, $slot) {
  var $1 = __ZNK8JSObject8slotSpanEv($this_0_0_val_0_1_val);
  return $1 >>> 0 > $slot >>> 0;
}

function __ZNK8JSObject13nativeGetSlotEj($this, $slot) {
  var $1 = __ZNK8JSObject7getSlotEj($this, $slot);
  return $1;
}

function __ZN8JSObject13getAttributesEP9JSContextiPj($this, $cx, $id, $attrsp) {
  var $this_idx_val = HEAP32[$this + 4 >> 2];
  var $1 = __ZNK8JSObject6getOpsEv($this_idx_val);
  var $3 = HEAP32[$1 + 68 >> 2];
  var $5 = ($3 | 0) != 0 ? $3 : 56;
  var $6 = FUNCTION_TABLE[$5]($cx, $this, $id, $attrsp);
  return $6;
}

function __ZN8JSObject17methodReadBarrierEP9JSContextRKN2js5ShapeEPN2JS5ValueE($this, $cx, $shape, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $vp_idx = $vp | 0;
    var $st$1$0 = $vp_idx | 0;
    var $vp_idx_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $vp_idx + 4 | 0;
    var $vp_idx_val$1 = HEAP32[$st$1$1 >> 2];
    var $1 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $2 = __ZNK8JSObject18getFunctionPrivateEv($_idx_val);
    var $3 = __Z19CloneFunctionObjectP9JSContextP10JSFunction($cx, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN8JSObject12setMethodObjERS_($3, $this);
    var $7 = HEAP32[$shape + 24 >> 2];
    var $8 = __ZN8JSObject17methodShapeChangeEP9JSContextRKN2js5ShapeE($this, $cx, $shape);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value9setObjectER8JSObject($vp, $3);
    var $st$1$0 = $vp_idx | 0;
    var $vp_idx1_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $vp_idx + 4 | 0;
    var $vp_idx1_val$1 = HEAP32[$st$1$1 >> 2];
    __ZN8JSObject13nativeSetSlotEjRKN2JS5ValueE($this, $7, $vp_idx1_val$0, $vp_idx1_val$1);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19CloneFunctionObjectP9JSContextP10JSFunction($cx, $fun) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $fun | 0;
    var $_idx1_val = HEAP32[$fun + 8 >> 2];
    var $2 = __ZNK8JSObject16hasSingletonTypeEv($_idx1_val);
    if ($2) {
      var $_0 = $1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$fun + 20 >> 2];
    var $4 = __ZNK8JSObject9getParentEv($_idx_val);
    var $_idx2_val_idx_val = HEAP32[HEAP32[$fun + 36 >> 2] >> 2];
    var $5 = __ZNK8JSObject8getProtoEv($_idx2_val_idx_val);
    var $6 = __Z22js_CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectS4_($cx, $fun, $4, $5);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject12setMethodObjERS_($this, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL11ObjectValueER8JSObject239($1, $obj);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  __ZN8JSObject12setFixedSlotEjRKN2JS5ValueE($this, 1, $_idx_val$0, $_idx_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN8JSObject13nativeSetSlotEjRKN2JS5ValueE($this, $slot, $value_0_0_0_val$0, $value_0_0_0_val$1) {
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, $slot, $value_0_0_0_val$0, $value_0_0_0_val$1);
  return;
}

function __ZN9JSRuntime8realloc_EPvjP9JSContext($this, $p, $bytes, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN9JSRuntime19updateMallocCounterEj($this, $bytes);
    __label__ = 3;
    break;
   case 3:
    var $4 = _js_realloc274($p, $bytes);
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $8 = $4;
      __label__ = 5;
      break;
    }
   case 4:
    __ZN9JSRuntime13onOutOfMemoryEPvjP9JSContext($cx);
    var $8 = 0;
    __label__ = 5;
    break;
   case 5:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_calloc299($bytes) {
  var $1 = _calloc($bytes);
  return $1;
}

function __ZN8JSObject12nativeLookupEP9JSContexti($this, $cx, $id) {
  var $1 = __ZN8JSObject12nativeSearchEP9JSContextib($this, $cx, $id, 0);
  return HEAP32[$1 >> 2] & -2;
}

function __ZN8JSObject12nativeSearchEP9JSContextib($this, $cx, $id, $adding) {
  var $1 = $this | 0;
  var $2 = __ZN2js5Shape6searchEP9JSContextPPS0_ib($cx, $1, $id, $adding);
  return $2;
}

function __ZN2js5Shape6searchEP9JSContextPPS0_ib($cx, $startp, $id, $adding) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$startp >> 2];
    var $_idx = $1 + 8 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $2 = __ZNK2js5Shape8hasTableEv($_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2js5Shape8getTableEv($1);
    var $5 = __ZN2js13PropertyTable6searchEib($4, $id, $adding);
    var $_0 = $5;
    __label__ = 10;
    break;
   case 3:
    if (($_idx_val | 0) == 7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    var $9 = __ZN2js5Shape7hashifyEP9JSContext($1, $cx_idx_val);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $spp_0 = $startp;
      __label__ = 7;
      break;
    }
   case 5:
    var $11 = __ZNK2js5Shape8getTableEv($1);
    var $12 = __ZN2js13PropertyTable6searchEib($11, $id, $adding);
    var $_0 = $12;
    __label__ = 10;
    break;
   case 6:
    var $14 = $_idx_val + 1 | 0;
    HEAP32[$_idx >> 2] = $14;
    var $spp_0 = $startp;
    __label__ = 7;
    break;
   case 7:
    var $spp_0;
    var $15 = HEAP32[$spp_0 >> 2];
    if (($15 | 0) == 0) {
      var $_0 = $spp_0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((HEAP32[$15 + 12 >> 2] | 0) == ($id | 0)) {
      var $_0 = $spp_0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $spp_0 = $15 + 32 | 0;
    __label__ = 7;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext17setCompileOptionsEj($this, $newcopts) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK9JSContext17getCompileOptionsEv($this);
    if (($1 | 0) == ($newcopts | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK9JSContext11findVersionEv($this);
    var $5 = __ZN2jsL20OptionFlagsToVersionEj9JSVersion($newcopts, $4);
    __ZN9JSContext20maybeOverrideVersionE9JSVersion($this, $5);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK9JSContext17getCompileOptionsEv($this) {
  var $1 = __ZNK9JSContext11findVersionEv($this);
  var $2 = __ZN2jsL21VersionFlagsToOptionsE9JSVersion($1);
  return $2;
}

function __ZN2jsL20OptionFlagsToVersionEj9JSVersion($options, $version) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$1 >> 2] = $version;
  var $2 = __ZN2jsL13OptionsHasXMLEj($options);
  __ZN2jsL13VersionSetXMLEP9JSVersionb($1, $2);
  var $3 = HEAP32[$1 >> 2];
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN2jsL21VersionFlagsToOptionsE9JSVersion($version) {
  var $1 = __ZN2jsL13VersionHasXMLE9JSVersion($version);
  var $2 = $1 ? 64 : 0;
  return $2;
}

function __ZNK9JSContext20canSetDefaultVersionEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this + 60 >> 2];
    var $1 = __ZNK2js12ContextStack5hasfpEv($_idx_val);
    if ($1) {
      var $8 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = (HEAP8[$this + 16 | 0] & 1) << 24 >> 24 == 0;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev($this_0_5_val) {
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev($this_0_5_val);
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev($this_0_5_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_5_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj($this_0_5_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv($0);
  return;
}

function __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev($this_0_5_val) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev($this_0_5_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev($this_0_5_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_5_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($this_0_5_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv($0);
  return;
}

function __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_ED1Ev($this_0_5_val) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_ED2Ev($this_0_5_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_ED2Ev($this_0_5_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_5_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E12destroyTableERS7_PNS0_14HashTableEntryIS4_EEj($this_0_5_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E12destroyTableERS7_PNS0_14HashTableEntryIS4_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv($0);
  return;
}

function __ZN11JSAtomStateD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEED1Ev($1);
  return;
}

function __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev($this_0_5_val) {
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev($this_0_5_val);
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev($this_0_5_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_5_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj($this_0_5_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv($0);
  return;
}

function __ZN11JSAtomStateC2Ev($this) {
  var $1 = $this | 0;
  __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEEC1ES5_($1);
  return;
}

function __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEEC1ES5_($this) {
  __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEEC2ES5_($this);
  return;
}

function __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEEC2ES5_($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_($1);
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_($this) {
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_($this);
  return;
}

function __ZNK2JS5Value7isInt32Ev($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_IS_INT32_IMPL($this_0_0_0_val$0, $this_0_0_0_val$1);
  return ($1 | 0) != 0;
}

function __ZN8JSObject21getDenseArrayElementsEv($this_0_8_val) {
  return $this_0_8_val;
}

function __ZNK8JSObject9isIndexedEv($this_0_2_val) {
  return ($this_0_2_val & 64 | 0) != 0;
}

function __ZL15JSDOUBLE_IS_NaNd($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZN8JSObject11asArgumentsEv($this) {
  return $this;
}

function __ZN16JSAutoByteStringC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  return;
}

function __ZN12JSValueArrayC2EPN2JS5ValueEj($this, $v, $c) {
  HEAP32[$this >> 2] = $v;
  HEAP32[$this + 4 >> 2] = $c;
  return;
}

function _JS_InitArenaPool($pool, $size, $align) {
  var $align_off = $align - 1 | 0;
  var $align_off_ = $align_off >>> 0 < 2 | ($align | 0) == 4 | ($align | 0) == 8 ? $align_off : 7;
  HEAP32[$pool + 24 >> 2] = $align_off_;
  var $5 = $pool | 0;
  HEAP32[$pool >> 2] = 0;
  var $11 = $5 + ($align_off_ + 16) & ($align_off_ ^ -1);
  HEAP32[$pool + 8 >> 2] = $11;
  HEAP32[$pool + 12 >> 2] = $11;
  HEAP32[$pool + 4 >> 2] = $11;
  HEAP32[$pool + 16 >> 2] = $5;
  HEAP32[$pool + 20 >> 2] = $size;
  return;
}

function __ZN2js15AutoValueRooter4addrEv($this) {
  return $this + 16 | 0;
}

function __ZN8JSObject30getDenseArrayInitializedLengthEv($this) {
  return HEAP32[$this + 16 >> 2];
}

function __ZN8JSObject20getDenseArrayElementEj($this_0_8_val, $idx) {
  return $this_0_8_val + ($idx << 3) | 0;
}

function __ZN2js15AutoValueRooterD2Ev($this) {
  var $_idx_val = HEAP32[$this >> 2];
  var $_idx1_val = HEAP32[$this + 8 >> 2];
  __ZN2js12AutoGCRooterD2Ev($_idx_val, $_idx1_val);
  return;
}

function __ZN2js15AutoValueRooterC2EP9JSContextRKN2JS5ValueE($this, $cx, $v) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($1, $cx, -1);
  var $2 = $v | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this + 16 | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  return;
}

function __ZN16JSAutoByteStringD2Ev($this_0_0_val) {
  __ZN2js10Foreground5free_EPv($this_0_0_val);
  return;
}

function __ZN16JSAutoByteString6encodeEP9JSContextP8JSString($this, $cx, $str) {
  var $1 = _JS_EncodeString($cx, $str);
  HEAP32[$this >> 2] = $1;
  return $1;
}

function __GLOBAL__I_a() {
  ___cxx_global_var_init();
  ___cxx_global_var_init1();
  ___cxx_global_var_init2();
  ___cxx_global_var_init3();
  ___cxx_global_var_init4();
  ___cxx_global_var_init5();
  return;
}

function _JS_ArenaAllocate($pool, $nb) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $pool + 16 | 0;
    var $3 = $pool + 20 | 0;
    var $a_0 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $a_0;
    var $6 = HEAPU32[$a_0 + 8 >> 2];
    if ($6 >>> 0 < $nb >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $a_0 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    if ($10 >>> 0 > ($6 - $nb | 0) >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $13 = $a_0 | 0;
    var $14 = HEAPU32[$13 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $a_1 = $14;
      __label__ = 7;
      break;
    }
   case 5:
    var $17 = HEAPU32[$3 >> 2];
    var $nb_ = $17 >>> 0 < $nb >>> 0 ? $nb : $17;
    var $19 = $nb_ + 16 | 0;
    var $20 = __ZN2js11OffTheBooks7malloc_Ej($19);
    var $21 = $20;
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    HEAP32[$20 >> 2] = 0;
    var $25 = $20;
    var $26 = $25 + 16 | 0;
    HEAP32[$20 + 12 >> 2] = $26;
    HEAP32[$20 + 4 >> 2] = $26;
    HEAP32[$20 + 8 >> 2] = $19 + $25 | 0;
    HEAP32[$13 >> 2] = $21;
    var $a_1 = $21;
    __label__ = 7;
    break;
   case 7:
    var $a_1;
    HEAP32[$1 >> 2] = $a_1;
    var $a_0 = $a_1;
    __label__ = 2;
    break;
   case 8:
    var $36 = $10;
    HEAP32[$9 >> 2] = $10 + $nb | 0;
    var $_0 = $36;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_ArenaAllocate["X"] = 1;

function _JS_ArenaRealloc($pool, $p, $size, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $pool | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = $p;
    var $5 = HEAP32[$2 + 4 >> 2];
    if (($3 - $5 | 0) >>> 0 > (HEAP32[$2 + 12 >> 2] - $5 | 0) >>> 0) {
      var $11 = $2;
      __label__ = 2;
      break;
    } else {
      var $ap_0_lcssa = $1;
      var $_lcssa = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $11;
    var $12 = $11 | 0;
    var $13 = HEAPU32[$12 >> 2];
    var $15 = HEAP32[$13 + 4 >> 2];
    if (($3 - $15 | 0) >>> 0 > (HEAP32[$13 + 12 >> 2] - $15 | 0) >>> 0) {
      var $11 = $13;
      __label__ = 2;
      break;
    } else {
      var $ap_0_lcssa = $12;
      var $_lcssa = $13;
      __label__ = 3;
      break;
    }
   case 3:
    var $_lcssa;
    var $ap_0_lcssa;
    var $22 = HEAP32[$pool + 24 >> 2];
    var $27 = ($incr + $size + $22 & ($22 ^ -1)) + 16 | 0;
    var $29 = __ZN2js11OffTheBooks8realloc_EPvj($_lcssa, $27);
    var $30 = $29;
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $33 = $29;
    var $34 = $33 + 16 | 0;
    var $36 = $29 + 4 | 0;
    HEAP32[$36 >> 2] = $34;
    var $37 = $27 + $33 | 0;
    var $39 = $29 + 8 | 0;
    HEAP32[$39 >> 2] = $37;
    var $41 = $29 + 12 | 0;
    HEAP32[$41 >> 2] = $37;
    var $42 = HEAP32[$ap_0_lcssa >> 2];
    if (($30 | 0) == ($42 | 0)) {
      var $51 = $34;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $45 = $pool + 16 | 0;
    if ((HEAP32[$45 >> 2] | 0) == ($42 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$45 >> 2] = $30;
    __label__ = 7;
    break;
   case 7:
    HEAP32[$ap_0_lcssa >> 2] = $30;
    var $51 = HEAP32[$36 >> 2];
    __label__ = 8;
    break;
   case 8:
    var $51;
    var $_0 = $51;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_ArenaRealloc["X"] = 1;

function __ZN2js11OffTheBooks8realloc_EPvj($p, $bytes) {
  var $1 = _js_realloc311($p, $bytes);
  return $1;
}

function _JS_ArenaGrow($pool, $p, $size, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$pool + 20 >> 2] >>> 0 < $size >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = _JS_ArenaRealloc($pool, $p, $size, $incr);
    var $_0 = $5;
    __label__ = 8;
    break;
   case 3:
    var $8 = HEAP32[$pool + 16 >> 2];
    var $10 = HEAP32[$pool + 24 >> 2];
    var $14 = $incr + $size + $10 & ($10 ^ -1);
    var $15 = $8 + 12 | 0;
    var $16 = HEAPU32[$15 >> 2];
    var $18 = HEAPU32[$8 + 8 >> 2];
    if ($14 >>> 0 > $18 >>> 0 | $16 >>> 0 > ($18 - $14 | 0) >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $23 = _JS_ArenaAllocate($pool, $14);
    var $_p_0 = $23;
    __label__ = 6;
    break;
   case 5:
    var $26 = $14 + $16 | 0;
    HEAP32[$15 >> 2] = $26;
    var $_p_0 = $16;
    __label__ = 6;
    break;
   case 6:
    var $_p_0;
    var $28 = $_p_0;
    if (($_p_0 | 0) == 0) {
      var $_0 = $28;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _memcpy($28, $p, $size, 1);
    var $_0 = $28;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ArenaRelease($pool, $mark) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $mark;
    var $a_0 = $pool | 0;
    __label__ = 2;
    break;
   case 2:
    var $a_0;
    if (($a_0 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = HEAP32[$a_0 + 4 >> 2];
    var $9 = $a_0 + 12 | 0;
    if (($2 - $7 | 0) >>> 0 > (HEAP32[$9 >> 2] - $7 | 0) >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = HEAP32[$pool + 24 >> 2];
    var $18 = $15 + $2 & ($15 ^ -1);
    HEAP32[$9 >> 2] = $18;
    __ZL13FreeArenaListP11JSArenaPoolP7JSArena($pool, $a_0);
    __label__ = 6;
    break;
   case 5:
    var $a_0 = HEAP32[$a_0 >> 2];
    __label__ = 2;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13FreeArenaListP11JSArenaPoolP7JSArena($pool, $head) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $head | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $a_0 = $2;
      __label__ = 2;
      break;
    }
   case 2:
    var $a_0;
    var $5 = HEAP32[$a_0 >> 2];
    HEAP32[$1 >> 2] = $5;
    __ZN2js10Foreground5free_EPv($a_0);
    var $7 = HEAP32[$1 >> 2];
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $a_0 = $7;
      __label__ = 2;
      break;
    }
   case 3:
    HEAP32[$pool + 16 >> 2] = $head;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_FreeArenaPool($pool) {
  var $1 = $pool | 0;
  __ZL13FreeArenaListP11JSArenaPoolP7JSArena($pool, $1);
  return;
}

function _JS_FinishArenaPool($pool) {
  var $1 = $pool | 0;
  __ZL13FreeArenaListP11JSArenaPoolP7JSArena($pool, $1);
  return;
}

function _js_realloc311($p, $bytes) {
  var $1 = _realloc($p, $bytes);
  return $1;
}

function __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $obj, $lengthp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $obj_idx2_val = HEAP32[$obj + 4 >> 2];
    var $1 = __ZNK8JSObject7isArrayEv($obj_idx2_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $obj_idx_val = HEAP32[$obj + 24 >> 2];
    var $3 = __ZNK8JSObject14getArrayLengthEv($obj_idx_val);
    HEAP32[$lengthp >> 2] = $3;
    var $_1 = 1;
    __label__ = 11;
    break;
   case 3:
    var $5 = __ZNK8JSObject11isArgumentsEv($obj);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $7 = __ZN8JSObject11asArgumentsEv($obj);
    var $8 = __ZNK2js15ArgumentsObject19hasOverriddenLengthEv($7);
    if ($8) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = __ZNK2js15ArgumentsObject13initialLengthEv($7);
    HEAP32[$lengthp >> 2] = $10;
    var $_1 = 1;
    __label__ = 11;
    break;
   case 6:
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $15 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2];
    var $16 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $17 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($obj, $cx, $15, $16);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $_idx1 = $20 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $21 = __ZNK2JS5Value7isInt32Ev($_idx1_val$0, $_idx1_val$1);
    if ($21) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $23 = __ZNK2JS5Value7toInt32Ev($_idx1_val$0, $_idx1_val$1);
    HEAP32[$lengthp >> 2] = $23;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 9:
    var $25 = __ZN2js17ValueToECMAUint32EP9JSContextRKN2JS5ValueEPj($cx, $20, $lengthp);
    var $_0 = $25 & 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 11;
    break;
   case 11:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject14getArrayLengthEv($this_0_6_val) {
  var $1 = __ZNK8JSObject10getPrivateEv($this_0_6_val);
  return $1;
}

function __ZNK8JSObject11isArgumentsEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$this + 4 >> 2];
    var $_idx_val = $1;
    var $2 = __ZNK8JSObject17isNormalArgumentsEv($_idx_val);
    if ($2) {
      var $6 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject17isStrictArgumentsEv($1);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js15ArgumentsObject19hasOverriddenLengthEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK8JSObject7getSlotEj($1, 0);
  var $_idx = $2 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $3 = __ZNK2JS5Value7toInt32Ev($_idx_val$0, $_idx_val$1);
  return ($3 & 1 | 0) != 0;
}

function __ZN2js15AutoValueRooterC1EP9JSContext($this, $cx) {
  __ZN2js15AutoValueRooterC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js18StringIsArrayIndexEP14JSLinearStringPj($str, $indexp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str_idx_val = HEAP32[$str + 4 >> 2];
    var $1 = __ZNK14JSLinearString5charsEv($str_idx_val);
    var $_idx_val = HEAP32[$str >> 2];
    var $2 = __ZNK8JSString6lengthEv($_idx_val);
    var $3 = $1 + ($2 << 1) | 0;
    if (($2 | 0) == 0 | $2 >>> 0 > 10) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = (HEAPU16[$1 >> 1] & 65535) - 48 | 0;
    if ($9 >>> 0 < 10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    if (($9 | 0) != 0 | ($2 | 0) == 1) {
      var $index_0 = $9;
      var $previous_0 = 0;
      var $s_0_pn = $1;
      var $c_0 = 0;
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 4:
    var $c_0;
    var $s_0_pn;
    var $previous_0;
    var $index_0;
    var $s_0 = $s_0_pn + 2 | 0;
    if ($s_0 >>> 0 < $3 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $18 = (HEAPU16[$s_0 >> 1] & 65535) - 48 | 0;
    if ($18 >>> 0 < 10) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $previous_0 = $index_0;
    var $index_0 = $18 + $index_0 * 10 | 0;
    var $s_0_pn = $s_0;
    var $c_0 = $18;
    __label__ = 4;
    break;
   case 7:
    if ($previous_0 >>> 0 < 429496729) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if (($previous_0 | 0) == 429496729 & $c_0 >>> 0 < 5) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    HEAP32[$indexp >> 2] = $index_0;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject22willBeSparseDenseArrayEjj($this, $requiredCapacity, $newElementsHint) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 28 >> 2];
    var $1 = __ZNK8JSObject8numSlotsEv($this_idx_val);
    if ($requiredCapacity >>> 0 > 536870911) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $requiredCapacity >>> 2;
    if ($4 >>> 0 > $newElementsHint >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 3:
    var $7 = $4 - $newElementsHint | 0;
    if ($7 >>> 0 > $1 >>> 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZN8JSObject30getDenseArrayInitializedLengthEv($this);
    var $this_idx1_val = HEAP32[$this + 32 >> 2];
    var $11 = __ZN8JSObject21getDenseArrayElementsEv($this_idx1_val);
    var $i_0 = 0;
    var $minimalDenseCount_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $minimalDenseCount_0;
    var $i_0;
    if ($i_0 >>> 0 < $10 >>> 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 6:
    var $_idx = $11 + ($i_0 << 3) | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $15 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx_val$0, $_idx_val$1);
    if ($15) {
      var $minimalDenseCount_1 = $minimalDenseCount_0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $17 = $minimalDenseCount_0 - 1 | 0;
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      var $minimalDenseCount_1 = $17;
      __label__ = 8;
      break;
    }
   case 8:
    var $minimalDenseCount_1;
    var $i_0 = $i_0 + 1 | 0;
    var $minimalDenseCount_0 = $minimalDenseCount_1;
    __label__ = 5;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value7isMagicE10JSWhyMagic($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_IS_MAGIC_IMPL($this_0_0_0_val$0, $this_0_0_0_val$1);
  return ($1 | 0) != 0;
}

function __ZN8JSObject22arrayGetOwnDataElementEP9JSContextjPN2JS5ValueE($this, $cx, $i, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $hole = __stackBase__;
    var $id = __stackBase__ + 4;
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $1 = __ZNK8JSObject12isDenseArrayEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $this_idx2_val = HEAP32[$this + 24 >> 2];
    var $3 = __ZNK8JSObject14getArrayLengthEv($this_idx2_val);
    if ($3 >>> 0 > $i >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value8setMagicE10JSWhyMagic($vp, 0);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 4:
    var $this_idx1_val = HEAP32[$this + 32 >> 2];
    var $7 = __ZN8JSObject20getDenseArrayElementEj($this_idx1_val, $i);
    var $8 = $7 | 0;
    var $st$4$0 = $8 | 0;
    var $9$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $8 + 4 | 0;
    var $9$1 = HEAP32[$st$4$1 >> 2];
    var $10 = $vp | 0;
    var $st$9$0 = $10 | 0;
    HEAP32[$st$9$0 >> 2] = $9$0;
    var $st$9$1 = $10 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $9$1;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 5:
    var $12 = $i >>> 0;
    var $13 = __ZL9IndexToIdP9JSContextP8JSObjectdPiS3_i($cx, $this, $12, $hole, $id, 0);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $15 = HEAP32[$id >> 2];
    var $16 = __ZN8JSObject12nativeLookupEP9JSContexti($this, $cx, $15);
    if (($16 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx_val = HEAP8[$16 + 28 | 0];
    var $19 = __ZNK2js5Shape16isDataDescriptorEv($_idx_val);
    if ($19) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2JS5Value8setMagicE10JSWhyMagic($vp, 0);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 9:
    var $23 = HEAP32[$16 + 24 >> 2];
    var $24 = __ZNK8JSObject7getSlotEj($this, $23);
    var $25 = $24 | 0;
    var $st$4$0 = $25 | 0;
    var $26$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $25 + 4 | 0;
    var $26$1 = HEAP32[$st$4$1 >> 2];
    var $27 = $vp | 0;
    var $st$9$0 = $27 | 0;
    HEAP32[$st$9$0 >> 2] = $26$0;
    var $st$9$1 = $27 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $26$1;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject22arrayGetOwnDataElementEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL9IndexToIdP9JSContextP8JSObjectdPiS3_i($cx, $obj, $index, $hole, $idp, $createAtom) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($index > 1073741823) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $index & -1;
    var $4 = _INT_TO_JSID398($3);
    HEAP32[$idp >> 2] = $4;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    if ($index > 4294967295) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = $index >= 0 ? Math.floor($index) : Math.ceil($index);
    var $9 = __ZL12BigIndexToIdP9JSContextP8JSObjectjiPi($cx, $obj, $8, $createAtom, $idp);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($hole | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = HEAP32[$idp >> 2];
    var $15 = _JSID_IS_VOID($14);
    if (($15 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$hole >> 2] = 1;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 8:
    var $19 = __ZL18ReallyBigIndexToIdP9JSContextdPi($cx, $index, $idp);
    var $_0 = $19;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11GetElementsEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $aobj, $length, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $aobj_idx_val = HEAP32[$aobj + 4 >> 2];
    var $2 = __ZNK8JSObject12isDenseArrayEv($aobj_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 2:
    var $4 = __ZN8JSObject30getDenseArrayInitializedLengthEv($aobj);
    if ($4 >>> 0 < $length >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject($aobj);
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 4:
    var $aobj_idx1_val = HEAP32[$aobj + 32 >> 2];
    var $10 = __ZN8JSObject21getDenseArrayElementsEv($aobj_idx1_val);
    var $11 = $10 + ($length << 3) | 0;
    if (($length | 0) > 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 14;
      break;
    }
   case 5:
    var $13 = $1 | 0;
    var $src_01 = $10;
    var $dst_02 = $vp;
    __label__ = 6;
    break;
   case 6:
    var $dst_02;
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $st$3$0 = $src_01_idx | 0;
    var $src_01_idx_val$0 = HEAPU32[$st$3$0 >> 2];
    var $st$3$1 = $src_01_idx + 4 | 0;
    var $src_01_idx_val$1 = HEAP32[$st$3$1 >> 2];
    var $15 = __ZNK2JS5Value7isMagicE10JSWhyMagic($src_01_idx_val$0, $src_01_idx_val$1);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2JSL14UndefinedValueEv351($1);
    var $19$1 = HEAP32[$13 + 4 >> 2];
    var $19$0 = HEAP32[$13 >> 2];
    __label__ = 9;
    break;
   case 8:
    HEAP32[$13 >> 2] = $src_01_idx_val$0;
    HEAP32[$13 + 4 >> 2] = $src_01_idx_val$1;
    var $19$1 = $src_01_idx_val$1;
    var $19$0 = $src_01_idx_val$0;
    __label__ = 9;
    break;
   case 9:
    var $19$0;
    var $19$1;
    var $20 = $dst_02 | 0;
    var $st$3$0 = $20 | 0;
    HEAP32[$st$3$0 >> 2] = $19$0;
    var $st$3$1 = $20 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $19$1;
    var $22 = $src_01 + 8 | 0;
    if ($22 >>> 0 < $11 >>> 0) {
      var $src_01 = $22;
      var $dst_02 = $dst_02 + 8 | 0;
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 14;
      break;
    }
   case 10:
    var $25 = __ZNK8JSObject11isArgumentsEv($aobj);
    if ($25) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $27 = __ZN8JSObject11asArgumentsEv($aobj);
    var $28 = __ZNK2js15ArgumentsObject19hasOverriddenLengthEv($27);
    if ($28) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $30 = __ZN2js15ArgumentsObject11getElementsEjjPN2JS5ValueE($27, $length, $vp);
    if ($30) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $32 = __ZN2jsL15GetElementsSlowEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $aobj, $length, $vp);
    var $_0 = $32;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11GetElementsEP9JSContextP8JSObjectjPN2JS5ValueE["X"] = 1;

function __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject($obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $_01_idx_val_idx_val = HEAP32[HEAP32[$_01 + 36 >> 2] >> 2];
    var $2 = __ZNK8JSObject8getProtoEv($_01_idx_val_idx_val);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$2 >> 2];
    var $5 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx1_val = HEAP32[$2 + 8 >> 2];
    var $7 = __ZNK8JSObject9isIndexedEv($_idx1_val);
    if ($7) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      var $_01 = $2;
      __label__ = 2;
      break;
    }
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL14UndefinedValueEv351($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2js15ArgumentsObject11getElementsEjjPN2JS5ValueE($this, $count, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2js15ArgumentsObject13initialLengthEv($this);
    if ($2 >>> 0 < $count >>> 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2js15ArgumentsObject15maybeStackFrameEv($this);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    var $8 = __ZNK2js15ArgumentsObject8elementsEv($this);
    var $9 = $8 + ($count << 3) | 0;
    var $dst_0 = $vp;
    var $src_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $src_0;
    var $dst_0;
    if ($src_0 >>> 0 < $9 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 5:
    var $src_0_idx = $src_0 | 0;
    var $st$1$0 = $src_0_idx | 0;
    var $src_0_idx_val$0 = HEAPU32[$st$1$0 >> 2];
    var $st$1$1 = $src_0_idx + 4 | 0;
    var $src_0_idx_val$1 = HEAPU32[$st$1$1 >> 2];
    var $13 = __ZNK2JS5Value7isMagicE10JSWhyMagic($src_0_idx_val$0, $src_0_idx_val$1);
    if ($13) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $dst_0 | 0;
    var $st$1$0 = $15 | 0;
    HEAP32[$st$1$0 >> 2] = $src_0_idx_val$0;
    var $st$1$1 = $15 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $src_0_idx_val$1;
    var $dst_0 = $dst_0 + 8 | 0;
    var $src_0 = $src_0 + 8 | 0;
    __label__ = 4;
    break;
   case 7:
    var $19 = __ZNK2js15ArgumentsObject7onTraceEv($this);
    if ($19) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2js6detail17CopyNonHoleArgsToC1EPNS_15ArgumentsObjectEPN2JS5ValueE($1, $this, $vp);
    var $_01_val = HEAP32[$1 >> 2];
    var $_1_val = HEAP32[$1 + 4 >> 2];
    var $21 = __ZN2js10StackFrame25forEachCanonicalActualArgINS_6detail17CopyNonHoleArgsToEEEbT_jj($5, $_01_val, $_1_val, $count);
    var $_0 = $21;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL15GetElementsSlowEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $aobj, $length, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if ($i_0 >>> 0 < $length >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 3:
    var $4 = $vp + ($i_0 << 3) | 0;
    var $5 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($aobj, $cx, $i_0, $4);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z20js_SetLengthPropertyP9JSContextP8JSObjectd($cx, $obj, $length) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $v = __stackBase__;
  var $1 = __ZN2JS5Value9setNumberEd($v, $length);
  var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
  var $7 = __ZL12ATOM_TO_JSIDP6JSAtom354($6);
  var $8 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($obj, $cx, $7, $v, 0);
  STACKTOP = __stackBase__;
  return $8;
}

function __ZL12ATOM_TO_JSIDP6JSAtom354($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj423($1);
  return $2;
}

function __Z12js_IdIsIndexiPj($id, $indexp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_INT387($id);
    if (($1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_INT420($id);
    if (($4 | 0) < 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$indexp >> 2] = $4;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 4:
    var $8 = _JSID_IS_STRING388($id);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZL12JSID_TO_ATOMi421($id);
    var $12 = $11 | 0;
    var $13 = __ZN2js18StringIsArrayIndexEP14JSLinearStringPj($12, $indexp);
    var $_0 = $13 & 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26array_getElementAttributesP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  HEAP32[$attrsp >> 2] = 1;
  return 1;
}

function __ZL12array_typeOfP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZN2js20array_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ej($cx, $obj, $id, $value, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 2:
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $9 = __ZNK8JSObject12isDenseArrayEv($obj_idx_val);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = $cx;
    var $12 = $obj;
    var $13 = $getter;
    var $14 = $setter;
    var $15 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($11, $12, $id, $value, $13, $14, $attrs);
    var $_0 = $15;
    __label__ = 11;
    break;
   case 4:
    HEAP32[$i >> 2] = 0;
    var $17 = __Z12js_IdIsIndexiPj($id, $i);
    if (($17 | 0) != 0 & ($attrs | 0) == 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 5:
    var $21 = HEAPU32[$i >> 2];
    var $22 = __ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj($obj, $cx, $21, 1);
    if (($22 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($22 | 0) == 1) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $obj_idx1_val = HEAP32[$obj + 24 >> 2];
    var $24 = __ZNK8JSObject14getArrayLengthEv($obj_idx1_val);
    if ($21 >>> 0 < $24 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $27 = $21 + 1 | 0;
    __ZN8JSObject19setDenseArrayLengthEj($obj, $27);
    __label__ = 8;
    break;
   case 8:
    __ZN8JSObject28setDenseArrayElementWithTypeEP9JSContextjRKN2JS5ValueE($obj, $cx, $21, $value);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 9:
    var $30 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($obj, $cx);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $33 = $cx;
    var $34 = $obj;
    var $35 = $getter;
    var $36 = $setter;
    var $37 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($33, $34, $id, $value, $35, $36, $attrs);
    var $_0 = $37;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12JSID_IS_ATOMiP6JSAtom($id, $atom) {
  var $1 = __ZL12ATOM_TO_JSIDP6JSAtom354($atom);
  return ($1 | 0) == ($id | 0) & 1;
}

function __ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj($this, $cx, $index, $extra) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 28 >> 2];
    var $1 = __ZNK8JSObject8numSlotsEv($this_idx_val);
    if (($extra | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    if ($1 >>> 0 > $index >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN8JSObject33ensureDenseArrayInitializedLengthEP9JSContextjj($this, $cx, $index, 1);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 4:
    var $7 = $index + 1 | 0;
    if (($7 | 0) == 0) {
      var $_0 = 2;
      __label__ = 12;
      break;
    } else {
      var $requiredCapacity_0 = $7;
      __label__ = 8;
      break;
    }
   case 5:
    var $uadd = _llvm_uadd_with_overflow_i32($index, $extra);
    var $10 = $uadd.f0;
    var $11 = $uadd.f1;
    if ($11) {
      var $_0 = 2;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ($10 >>> 0 > $1 >>> 0) {
      var $requiredCapacity_0 = $10;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject33ensureDenseArrayInitializedLengthEP9JSContextjj($this, $cx, $index, $extra);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 8:
    var $requiredCapacity_0;
    if ($requiredCapacity_0 >>> 0 > 256) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $18 = __ZN8JSObject22willBeSparseDenseArrayEjj($this, $requiredCapacity_0, $extra);
    if ($18) {
      var $_0 = 2;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $20 = $this;
    var $21 = $cx;
    var $22 = __ZN8JSObject9growSlotsEP9JSContextj($20, $21, $requiredCapacity_0);
    if ($22) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    __ZN8JSObject33ensureDenseArrayInitializedLengthEP9JSContextjj($this, $cx, $index, $extra);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject19setDenseArrayLengthEj($this, $length) {
  var $1 = $length;
  __ZN8JSObject10setPrivateEPv($this, $1);
  return;
}

function __ZN8JSObject28setDenseArrayElementWithTypeEP9JSContextjRKN2JS5ValueE($this, $cx, $idx, $val) {
  __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiRKN2JS5ValueE($cx, $this, 2, $val);
  var $this_idx_val = HEAP32[$this + 32 >> 2];
  var $val_idx = $val | 0;
  var $val_idx_val$0 = HEAP32[$val_idx >> 2];
  var $val_idx_val$1 = HEAP32[$val_idx + 4 >> 2];
  __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($this_idx_val, $idx, $val_idx_val$0, $val_idx_val$1);
  return;
}

function __ZN8JSObject18makeDenseArraySlowEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $autoArray = __stackBase__;
    var $id = __stackBase__ + 20;
    var $1 = __stackBase__ + 24;
    __ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj($cx, $this, 196608);
    __ZN8JSObject23markDenseArrayNotPackedEP9JSContext($this, $cx);
    var $3 = HEAPU32[$this >> 2];
    var $4 = $this;
    var $5 = __ZNK2js2gc4Cell12getAllocKindEv($4);
    var $this_idx2_val_idx_val = HEAP32[HEAP32[$this + 36 >> 2] >> 2];
    var $6 = __ZNK8JSObject8getProtoEv($this_idx2_val_idx_val);
    var $7 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($6, $cx, 0, 0);
    var $8 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE359($cx, $this, __ZN2js14SlowArrayClassE, $7, $5);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 16;
      break;
    }
   case 2:
    __ZN8JSObject23backfillDenseArrayHolesEP9JSContext($this, $cx);
    var $this_idx3 = $this + 28 | 0;
    var $this_idx3_val = HEAP32[$this_idx3 >> 2];
    var $10 = __ZN8JSObject21getDenseArrayCapacityEv($this_idx3_val);
    var $11 = __ZN8JSObject30getDenseArrayInitializedLengthEv($this);
    var $12 = __ZNK8JSObject24denseArrayHasInlineSlotsEv($this);
    if ($12) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $14 = __ZNK8JSObject8numSlotsEv($this_idx3_val);
    var $15 = $this;
    var $16 = $cx;
    var $17 = __ZN8JSObject10allocSlotsEP9JSContextj($15, $16, $14);
    if ($17) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN8JSObject6setMapEPN2js5ShapeE($this, $3);
    var $_1 = 0;
    __label__ = 16;
    break;
   case 5:
    var $this_idx_val = HEAP32[$this + 8 >> 2];
    var $20 = __ZNK8JSObject13numFixedSlotsEv($this_idx_val);
    var $21 = $20 + $10 | 0;
    HEAP32[$this_idx3 >> 2] = $21;
    var $22 = $this + 4 | 0;
    HEAP32[$22 >> 2] = __ZN2js14SlowArrayClassE;
    var $23 = $this + 32 | 0;
    var $24 = HEAP32[$23 >> 2];
    __ZN2js14AutoValueArrayC1EP9JSContextPN2JS5ValueEj($autoArray, $cx, $24, $11);
    var $25 = $this + 16 | 0;
    HEAP32[$25 >> 2] = 0;
    var $26 = __ZL17AddLengthPropertyP9JSContextP8JSObject($cx, $this);
    if ($26) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $27 = $this;
    var $28 = $cx;
    var $i_0 = 0;
    var $next_0 = 0;
    __label__ = 8;
    break;
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($this, $3);
    HEAP32[$this_idx3 >> 2] = $10;
    HEAP32[$25 >> 2] = $11;
    HEAP32[$22 >> 2] = __ZN2js10ArrayClassE;
    var $_0 = 0;
    __label__ = 15;
    break;
   case 8:
    var $next_0;
    var $i_0;
    if ($i_0 >>> 0 < $10 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 9:
    __ZN2JSL10Int32ValueEi360($1, $i_0);
    var $33 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($cx, $1, $id);
    var $_idx4 = HEAP32[$23 >> 2] + ($i_0 << 3) | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    var $35 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx4_val$0, $_idx4_val$1);
    if ($35) {
      var $next_1 = $next_0;
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, $next_0, $_idx4_val$0, $_idx4_val$1);
    var $37 = HEAP32[$id >> 2];
    var $38 = __ZN8JSObject15addDataPropertyEP9JSContextijj($27, $28, $37, $next_0, 1);
    if (($38 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    __ZN8JSObject6setMapEPN2js5ShapeE($this, $3);
    HEAP32[$this_idx3 >> 2] = $10;
    HEAP32[$25 >> 2] = $11;
    HEAP32[$22 >> 2] = __ZN2js10ArrayClassE;
    var $_0 = 0;
    __label__ = 15;
    break;
   case 12:
    var $next_1 = $next_0 + 1 | 0;
    __label__ = 13;
    break;
   case 13:
    var $next_1;
    var $i_0 = $i_0 + 1 | 0;
    var $next_0 = $next_1;
    __label__ = 8;
    break;
   case 14:
    var $47 = HEAP32[$this_idx3 >> 2] - $next_0 | 0;
    var $48 = $this;
    __ZN8JSObject14clearSlotRangeEjj($48, $next_0, $47);
    var $_0 = 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    __ZN2js14AutoValueArrayD1Ev($autoArray);
    var $_1 = $_0;
    __label__ = 16;
    break;
   case 16:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject18makeDenseArraySlowEP9JSContext["X"] = 1;

function __ZN2js19array_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ej($cx, $obj, $index, $value, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $1 = __ZNK8JSObject12isDenseArrayEv($obj_idx_val);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $cx;
    var $4 = $obj;
    var $5 = $getter;
    var $6 = $setter;
    var $7 = __Z16js_DefineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($3, $4, $index, $value, $5, $6, $attrs);
    var $_0 = $7;
    __label__ = 11;
    break;
   case 3:
    var $9 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 4:
    if (($attrs | 0) != 1 | ($index | 0) == -1) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = __ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj($obj, $cx, $index, 1);
    if (($14 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($14 | 0) == 1) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $obj_idx1_val = HEAP32[$obj + 24 >> 2];
    var $16 = __ZNK8JSObject14getArrayLengthEv($obj_idx1_val);
    if ($16 >>> 0 > $index >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = $index + 1 | 0;
    __ZN8JSObject19setDenseArrayLengthEj($obj, $19);
    __label__ = 8;
    break;
   case 8:
    __ZN8JSObject28setDenseArrayElementWithTypeEP9JSContextjRKN2JS5ValueE($obj, $cx, $index, $value);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 9:
    var $22 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($obj, $cx);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $25 = $cx;
    var $26 = $obj;
    var $27 = $getter;
    var $28 = $setter;
    var $29 = __Z16js_DefineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($25, $26, $index, $value, $27, $28, $attrs);
    var $_0 = $29;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js20array_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $2 = __ZNK8JSObject12isDenseArrayEv($obj_idx_val);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $obj;
    var $6 = __Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($4, $5, $id, $rval, $strict);
    var $_0 = $6;
    __label__ = 10;
    break;
   case 3:
    var $12 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $13 = __ZL12JSID_IS_ATOMiP6JSAtom($id, $12);
    if (($13 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 5:
    var $17 = __Z12js_IdIsIndexiPj($id, $i);
    if (($17 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = HEAPU32[$i >> 2];
    var $21 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
    if ($20 >>> 0 < $21 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN8JSObject23markDenseArrayNotPackedEP9JSContext($obj, $cx);
    __ZN2JSL10MagicValueE10JSWhyMagic($1);
    var $obj_idx1_val = HEAP32[$obj + 32 >> 2];
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($obj_idx1_val, $20, $_idx_val$0, $_idx_val$1);
    __label__ = 8;
    break;
   case 8:
    var $25 = $cx;
    var $26 = $obj;
    var $27 = __Z26js_SuppressDeletedPropertyP9JSContextP8JSObjecti($25, $26, $id);
    if ($27) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL10MagicValueE10JSWhyMagic($agg_result) {
  __ZN2JS5Value8setMagicE10JSWhyMagic($agg_result, 0);
  return;
}

function __ZN2js19array_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $2 = __ZNK8JSObject12isDenseArrayEv($obj_idx_val);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $obj;
    var $6 = __Z16js_DeleteElementP9JSContextP8JSObjectjPN2JS5ValueEi($4, $5, $index, $rval, $strict);
    var $_0 = $6;
    __label__ = 7;
    break;
   case 3:
    var $8 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
    if ($8 >>> 0 > $index >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN8JSObject23markDenseArrayNotPackedEP9JSContext($obj, $cx);
    __ZN2JSL10MagicValueE10JSWhyMagic($1);
    var $obj_idx1_val = HEAP32[$obj + 32 >> 2];
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($obj_idx1_val, $index, $_idx_val$0, $_idx_val$1);
    __label__ = 5;
    break;
   case 5:
    var $12 = $cx;
    var $13 = $obj;
    var $14 = __Z25js_SuppressDeletedElementP9JSContextP8JSObjectj($12, $13, $index);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11array_traceP8JSTracerP8JSObject($trc, $obj) {
  var $1 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
  var $obj_idx_val = HEAP32[$obj + 32 >> 2];
  var $2 = __ZN8JSObject21getDenseArrayElementsEv($obj_idx_val);
  __ZN2js2gc14MarkValueRangeEP8JSTracerjPKN2JS5ValueEPKc($trc, $1, $2);
  return;
}

function __ZL20array_lookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $id, $objp, $propp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $1 = __ZNK8JSObject12isDenseArrayEv($obj_idx_val);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $cx;
    var $4 = $obj;
    var $5 = $objp;
    var $6 = $propp;
    var $7 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($3, $4, $id, $5, $6);
    var $_0 = $7;
    __label__ = 8;
    break;
   case 3:
    var $cx_idx_val_idx_val = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2];
    var $9 = __ZL14IsDenseArrayIdP9JSContextP8JSObjecti($cx_idx_val_idx_val, $obj, $id);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$propp >> 2] = 1;
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 5:
    var $obj_idx1_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $12 = __ZNK8JSObject8getProtoEv($obj_idx1_val_idx_val);
    if (($12 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$objp >> 2] = 0;
    HEAP32[$propp >> 2] = 0;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 7:
    var $16 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($12, $cx, $id, $objp, $propp);
    var $_0 = $16;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19array_lookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty($cx, $obj, $index, $objp, $propp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $1 = __ZNK8JSObject12isDenseArrayEv($obj_idx_val);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $cx;
    var $4 = $obj;
    var $5 = $objp;
    var $6 = $propp;
    var $7 = __Z16js_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty($3, $4, $index, $5, $6);
    var $_0 = $7;
    __label__ = 8;
    break;
   case 3:
    var $9 = __ZL17IsDenseArrayIndexP8JSObjectj($obj, $index);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$propp >> 2] = 1;
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 5:
    var $obj_idx1_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $12 = __ZNK8JSObject8getProtoEv($obj_idx1_val_idx_val);
    if (($12 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = __ZN8JSObject13lookupElementEP9JSContextjPPS_PP10JSProperty($12, $cx, $index, $objp, $propp);
    var $_0 = $15;
    __label__ = 8;
    break;
   case 7:
    HEAP32[$objp >> 2] = 0;
    HEAP32[$propp >> 2] = 0;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19array_lookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty($cx, $obj, $sid, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE($sid_idx_val);
  var $2 = __ZL20array_lookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $1, $objp, $propp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL19array_defineSpecialP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ej($cx, $obj, $sid, $value, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE($sid_idx_val);
  var $2 = __ZN2js20array_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ej($cx, $obj, $1, $value, $getter, $setter, $attrs);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL16array_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $2 = HEAP32[$cx + 52 >> 2];
    var $5 = HEAP32[$2 + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $obj_idx5_val = HEAP32[$obj + 24 >> 2];
    var $9 = __ZNK8JSObject14getArrayLengthEv($obj_idx5_val);
    var $10 = __ZN2JS5Value9setNumberEj($vp, $9);
    var $_0 = 1;
    __label__ = 17;
    break;
   case 3:
    var $14 = HEAP32[$2 + 210292 >> 2] | 0;
    var $15 = __ZL12JSID_IS_ATOMiP6JSAtom($id, $14);
    if (($15 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $obj_idx3_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $18 = __ZNK8JSObject8getProtoEv($obj_idx3_val_idx_val);
    __ZN2JS5Value15setObjectOrNullEP8JSObject($vp, $18);
    var $_0 = 1;
    __label__ = 17;
    break;
   case 5:
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $20 = __ZNK8JSObject12isDenseArrayEv($obj_idx_val);
    if ($20) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = __Z14js_GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp);
    var $_0 = $22;
    __label__ = 17;
    break;
   case 7:
    var $24 = __Z12js_IdIsIndexiPj($id, $i);
    if (($24 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = HEAPU32[$i >> 2];
    var $28 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
    if ($27 >>> 0 < $28 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $obj_idx1_val = HEAP32[$obj + 32 >> 2];
    var $31 = __ZN8JSObject20getDenseArrayElementEj($obj_idx1_val, $27);
    var $_idx4 = $31 | 0;
    var $_idx4_val$0 = HEAPU32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAPU32[$_idx4 + 4 >> 2];
    var $32 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx4_val$0, $_idx4_val$1);
    if ($32) {
      __label__ = 10;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 10:
    var $obj_idx2_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $34 = __ZNK8JSObject8getProtoEv($obj_idx2_val_idx_val);
    var $35 = ($34 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($35) {
      var $_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $38 = HEAP32[$cx + 208 >> 2];
    var $39 = $cx;
    var $40 = $34;
    var $41 = $obj2;
    var $42 = $prop;
    var $43 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($39, $40, $id, $38, $41, $42);
    if ($43) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 12:
    var $45 = HEAP32[$prop >> 2];
    if (($45 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $48 = HEAP32[$obj2 >> 2];
    var $_idx_val = HEAP32[$48 >> 2];
    var $49 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($49) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $51 = $obj;
    var $52 = $48;
    var $53 = $45;
    var $54 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($39, $51, $52, $53, 0, $vp);
    if (($54 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $_0 = 1;
    __label__ = 17;
    break;
   case 16:
    var $58 = $vp | 0;
    HEAP32[$58 >> 2] = $_idx4_val$0;
    HEAP32[$58 + 4 >> 2] = $_idx4_val$1;
    var $_0 = 1;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16array_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE["X"] = 1;

function __ZL17array_getPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom354($1);
  var $3 = __ZL16array_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $2, $vp);
  return $3;
}

function __ZL16array_getElementP9JSContextP8JSObjectS2_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $1 = __ZNK8JSObject12isDenseArrayEv($obj_idx_val);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __Z13js_GetElementP9JSContextP8JSObjectjPN2JS5ValueE($cx, $obj, $index, $vp);
    var $_0 = $3;
    __label__ = 12;
    break;
   case 3:
    var $obj_idx3_val = HEAP32[$obj + 28 >> 2];
    var $5 = __ZN8JSObject21getDenseArrayCapacityEv($obj_idx3_val);
    if ($5 >>> 0 > $index >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $obj_idx1_val = HEAP32[$obj + 32 >> 2];
    var $8 = __ZN8JSObject20getDenseArrayElementEj($obj_idx1_val, $index);
    var $_idx4 = $8 | 0;
    var $_idx4_val$0 = HEAPU32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    var $9 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx4_val$0, $_idx4_val$1);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = $vp | 0;
    HEAP32[$11 >> 2] = $_idx4_val$0;
    HEAP32[$11 + 4 >> 2] = $_idx4_val$1;
    var $_0 = 1;
    __label__ = 12;
    break;
   case 6:
    var $obj_idx2_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $13 = __ZNK8JSObject8getProtoEv($obj_idx2_val_idx_val);
    var $14 = ($13 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($14) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $16 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($16) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 8:
    var $18 = HEAP32[$id >> 2];
    var $20 = HEAP32[$cx + 208 >> 2];
    var $21 = $cx;
    var $22 = $13;
    var $23 = $obj2;
    var $24 = $prop;
    var $25 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($21, $22, $18, $20, $23, $24);
    if ($25) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 9:
    var $27 = HEAP32[$prop >> 2];
    if (($27 | 0) == 0) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $30 = HEAP32[$obj2 >> 2];
    var $_idx_val = HEAP32[$30 >> 2];
    var $31 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($31) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    var $33 = $obj;
    var $34 = $30;
    var $35 = $27;
    var $36 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($21, $33, $34, $35, 0, $vp);
    var $_0 = $36;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16array_getElementP9JSContextP8JSObjectS2_jPN2JS5ValueE["X"] = 1;

function __ZL16array_getSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE($sid_idx_val);
  var $2 = __ZL16array_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL17array_setPropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZL19array_length_setterP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp);
    var $_0 = $9;
    __label__ = 13;
    break;
   case 3:
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $11 = __ZNK8JSObject12isDenseArrayEv($obj_idx_val);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $cx;
    var $14 = $obj;
    var $15 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($13, $14, $id, 0, $vp, $strict);
    var $_0 = $15;
    __label__ = 13;
    break;
   case 5:
    var $17 = __Z12js_IdIsIndexiPj($id, $i);
    if (($17 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject($obj);
    if (($20 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 7:
    var $23 = HEAPU32[$i >> 2];
    var $24 = __ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj($obj, $cx, $23, 1);
    if (($24 | 0) == 0) {
      __label__ = 8;
      break;
    } else if (($24 | 0) == 1) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $obj_idx1_val = HEAP32[$obj + 24 >> 2];
    var $26 = __ZNK8JSObject14getArrayLengthEv($obj_idx1_val);
    if ($23 >>> 0 < $26 >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $29 = $23 + 1 | 0;
    __ZN8JSObject19setDenseArrayLengthEj($obj, $29);
    __label__ = 10;
    break;
   case 10:
    __ZN8JSObject28setDenseArrayElementWithTypeEP9JSContextjRKN2JS5ValueE($obj, $cx, $23, $vp);
    var $_0 = 1;
    __label__ = 13;
    break;
   case 11:
    var $32 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($obj, $cx);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $35 = $cx;
    var $36 = $obj;
    var $37 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($35, $36, $id, 0, $vp, $strict);
    var $_0 = $37;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16array_setElementP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 2:
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $3 = __ZNK8JSObject12isDenseArrayEv($obj_idx_val);
    if ($3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = HEAP32[$id >> 2];
    var $6 = $cx;
    var $7 = $obj;
    var $8 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($6, $7, $5, 0, $vp, $strict);
    var $_0 = $8;
    __label__ = 12;
    break;
   case 4:
    if (($index | 0) == -1) {
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject($obj);
    if (($12 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $15 = __ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj($obj, $cx, $index, 1);
    if (($15 | 0) == 0) {
      __label__ = 7;
      break;
    } else if (($15 | 0) == 1) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    var $obj_idx1_val = HEAP32[$obj + 24 >> 2];
    var $17 = __ZNK8JSObject14getArrayLengthEv($obj_idx1_val);
    if ($17 >>> 0 > $index >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = $index + 1 | 0;
    __ZN8JSObject19setDenseArrayLengthEj($obj, $20);
    __label__ = 9;
    break;
   case 9:
    __ZN8JSObject28setDenseArrayElementWithTypeEP9JSContextjRKN2JS5ValueE($obj, $cx, $index, $vp);
    var $_0 = 1;
    __label__ = 12;
    break;
   case 10:
    var $23 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($obj, $cx);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = HEAP32[$id >> 2];
    var $27 = $cx;
    var $28 = $obj;
    var $29 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($27, $28, $26, 0, $vp, $strict);
    var $_0 = $29;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16array_setSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE($sid_idx_val);
  var $2 = __ZL17array_setPropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, $strict);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL19array_getAttributesP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
  var $6 = __ZL12JSID_IS_ATOMiP6JSAtom($id, $5);
  var $8 = ($6 | 0) != 0 ? 4 : 1;
  HEAP32[$attrsp >> 2] = $8;
  return 1;
}

function __ZL26array_getSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE($sid_idx_val);
  var $2 = __ZL19array_getAttributesP9JSContextP8JSObjectiPj($cx, $obj, $1, $attrsp);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZL19array_setAttributesP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var __stackBase__ = STACKTOP;
  _JS_ReportErrorNumber($cx, 4, 225, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
  STACKTOP = __stackBase__;
  return 0;
}

function __ZL26array_setElementAttributesP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __stackBase__ = STACKTOP;
  _JS_ReportErrorNumber($cx, 4, 225, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
  STACKTOP = __stackBase__;
  return 0;
}

function __ZL26array_setSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE($sid_idx_val);
  var $2 = __ZL19array_setAttributesP9JSContextP8JSObjectiPj($cx, $obj, $1, $attrsp);
  STACKTOP = __stackBase__;
  return 0;
}

function __ZL19array_deleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE($sid_idx_val);
  var $2 = __ZN2js20array_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, $strict);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js15AutoArrayRooter12changeLengthEj($this, $newLength) {
  HEAP32[$this + 4 >> 2] = $newLength;
  return;
}

function __ZL9array_fixP9JSContextP8JSObjectPbPN2js12AutoIdVectorE($cx, $obj, $success, $props) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($obj, $cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $obj;
    var $6 = $props;
    var $7 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($4, $5, 24, $6);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    HEAP8[$success] = 1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21slowarray_addPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = __Z12js_IdIsIndexiPj($id, $index);
    if (($1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $obj_idx_val = HEAP32[$obj + 24 >> 2];
    var $4 = __ZNK8JSObject14getArrayLengthEv($obj_idx_val);
    var $5 = HEAPU32[$index >> 2];
    if ($5 >>> 0 < $4 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $5 + 1 | 0;
    __ZN8JSObject14setArrayLengthEP9JSContextj($obj, $cx, $8);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE359($cx, $obj, $clasp, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
    var $obj_idx_val = HEAP32[$obj + 28 >> 2];
    var $5 = __ZNK8JSObject8numSlotsEv($obj_idx_val);
    if ($4 >>> 0 > $5 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $obj;
    var $9 = $cx;
    var $10 = __ZN8JSObject10allocSlotsEP9JSContextj($8, $9, $4);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $12 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($type, $clasp);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($type, $cx, $clasp, $kind);
    var $empty_0 = $14;
    __label__ = 6;
    break;
   case 5:
    var $16 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, $clasp);
    var $empty_0 = $16;
    __label__ = 6;
    break;
   case 6:
    var $empty_0;
    if (($empty_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($obj, $empty_0 | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject23backfillDenseArrayHolesEP9JSContext($this, $cx) {
  var $this_idx_val = HEAP32[$this + 28 >> 2];
  var $1 = __ZN8JSObject21getDenseArrayCapacityEv($this_idx_val);
  __ZN8JSObject33ensureDenseArrayInitializedLengthEP9JSContextjj($this, $cx, $1, 0);
  return;
}

function __ZN8JSObject21getDenseArrayCapacityEv($this_0_7_val) {
  var $1 = __ZNK8JSObject8numSlotsEv($this_0_7_val);
  return $1;
}

function __ZNK8JSObject24denseArrayHasInlineSlotsEv($this) {
  var $2 = HEAP32[$this + 32 >> 2];
  var $3 = __ZNK8JSObject10fixedSlotsEv($this);
  return ($2 | 0) == ($3 | 0);
}

function __ZN2js14AutoValueArrayC1EP9JSContextPN2JS5ValueEj($this, $cx, $start, $length) {
  __ZN2js14AutoValueArrayC2EP9JSContextPN2JS5ValueEj($this, $cx, $start, $length);
  return;
}

function __ZL17AddLengthPropertyP9JSContextP8JSObject($cx, $obj) {
  var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
  var $6 = __ZL12ATOM_TO_JSIDP6JSAtom354($5);
  var $7 = __ZN8JSObject11addPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji($obj, $cx, $6, 58, 60, -1, 68, 0, 0);
  return ($7 | 0) != 0;
}

function __ZN2JSL10Int32ValueEi360($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZN2js14AutoValueArrayD1Ev($this) {
  __ZN2js14AutoValueArrayD2Ev($this);
  return;
}

function __Z12js_MergeSortPvjjPFiS_PKvS1_PiES_S_19JSMergeSortElemType($src, $nel, $elsize, $cmp, $arg, $tmp, $elemType) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $msa = __stackBase__;
    var $cmp_result = __stackBase__ + 16;
    var $1 = ($elemType | 0) == 0;
    var $2 = -$elsize | 0;
    var $3 = $tmp;
    var $lo_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $lo_0;
    if ($lo_0 >>> 0 < $nel >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 3:
    var $6 = $lo_0 + 4 | 0;
    var $hi_0 = $6 >>> 0 < $nel >>> 0 ? $6 : $nel;
    var $i_0 = $lo_0 | 1;
    __label__ = 4;
    break;
   case 4:
    var $i_0;
    if ($i_0 >>> 0 < $hi_0 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $lo_0 = $6;
      __label__ = 2;
      break;
    }
   case 5:
    var $12 = $i_0 * $elsize | 0;
    var $j_0 = $i_0;
    var $vec2_0 = $src + ($12 - $elsize) | 0;
    var $vec1_0 = $src + $12 | 0;
    __label__ = 6;
    break;
   case 6:
    var $vec1_0;
    var $vec2_0;
    var $j_0;
    if ($j_0 >>> 0 > $lo_0 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 7:
    var $18 = FUNCTION_TABLE[$cmp]($arg, $vec2_0, $vec1_0, $cmp_result);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((HEAP32[$cmp_result >> 2] | 0) < 1) {
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ($1) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $25 = $vec2_0;
    var $26$0 = HEAP32[$25 >> 2];
    var $26$1 = HEAP32[$25 + 4 >> 2];
    HEAP32[$3 >> 2] = $26$0;
    HEAP32[$3 + 4 >> 2] = $26$1;
    var $27 = $vec1_0;
    var $28$0 = HEAP32[$27 >> 2];
    var $28$1 = HEAP32[$27 + 4 >> 2];
    HEAP32[$25 >> 2] = $28$0;
    HEAP32[$25 + 4 >> 2] = $28$1;
    var $29$0 = HEAP32[$3 >> 2];
    var $29$1 = HEAP32[$3 + 4 >> 2];
    HEAP32[$27 >> 2] = $29$0;
    HEAP32[$27 + 4 >> 2] = $29$1;
    __label__ = 12;
    break;
   case 11:
    _memcpy($tmp, $vec2_0, $elsize, 1);
    _memcpy($vec2_0, $vec1_0, $elsize, 1);
    _memcpy($vec1_0, $tmp, $elsize, 1);
    __label__ = 12;
    break;
   case 12:
    var $j_0 = $j_0 - 1 | 0;
    var $vec1_0 = $vec2_0;
    var $vec2_0 = $vec2_0 + $2 | 0;
    __label__ = 6;
    break;
   case 13:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 4;
    break;
   case 14:
    HEAP32[$msa >> 2] = $elsize;
    HEAP32[$msa + 4 >> 2] = $cmp;
    HEAP32[$msa + 8 >> 2] = $arg;
    HEAP32[$msa + 12 >> 2] = $1 & 1;
    var $run_0 = 4;
    var $vec2_1 = $tmp;
    var $vec1_1 = $src;
    __label__ = 15;
    break;
   case 15:
    var $vec1_1;
    var $vec2_1;
    var $run_0;
    if ($run_0 >>> 0 < $nel >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 16:
    var $43 = $run_0 << 1;
    var $lo_1 = 0;
    __label__ = 17;
    break;
   case 17:
    var $lo_1;
    if ($lo_1 >>> 0 < $nel >>> 0) {
      __label__ = 18;
      break;
    } else {
      var $vec2_1 = $vec1_1;
      var $vec1_1$phi = $vec2_1;
      var $run_0 = $43;
      var $vec1_1 = $vec1_1$phi;
      __label__ = 15;
      break;
    }
   case 18:
    var $47 = $lo_1 + $run_0 | 0;
    var $49 = $lo_1 * $elsize | 0;
    if ($47 >>> 0 < $nel >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $51 = $vec2_1 + $49 | 0;
    var $52 = $vec1_1 + $49 | 0;
    var $54 = ($nel - $lo_1) * $elsize | 0;
    _memcpy($51, $52, $54, 1);
    var $vec2_1 = $vec1_1;
    var $vec1_1$phi = $vec2_1;
    var $run_0 = $43;
    var $vec1_1 = $vec1_1$phi;
    __label__ = 15;
    break;
   case 20:
    var $56 = $vec1_1 + $49 | 0;
    var $57 = $vec2_1 + $49 | 0;
    var $61 = ($47 + $run_0 | 0) >>> 0 > $nel >>> 0 ? $nel - $47 | 0 : $run_0;
    var $62 = __ZL11MergeArraysP9MSortArgsPvS1_jj($msa, $56, $57, $run_0, $61);
    if (($62 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $lo_1 = $lo_1 + $43 | 0;
    __label__ = 17;
    break;
   case 22:
    if (($vec1_1 | 0) == ($src | 0)) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $69 = $elsize * $nel | 0;
    _memcpy($src, $tmp, $69, 1);
    var $_0 = 1;
    __label__ = 24;
    break;
   case 24:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z12js_MergeSortPvjjPFiS_PKvS1_PiES_S_19JSMergeSortElemType["X"] = 1;

function __ZL11MergeArraysP9MSortArgsPvS1_jj($msa, $src, $dest, $run1, $run2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cmp_result = __stackBase__;
    var $1 = $run2 + $run1 | 0;
    var $3 = HEAPU32[$msa >> 2];
    var $5 = HEAPU32[$msa + 4 >> 2];
    var $7 = HEAPU32[$msa + 8 >> 2];
    var $9 = HEAP32[$msa + 12 >> 2];
    var $10 = $3 * $run1 | 0;
    var $11 = $src + $10 | 0;
    var $12 = $src + ($10 - $3) | 0;
    var $13 = FUNCTION_TABLE[$5]($7, $12, $11, $cmp_result);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$cmp_result >> 2] | 0) < 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $18 = ($9 | 0) != 0;
    var $runtotal_0 = $1;
    var $c_0 = $dest;
    var $_01 = $run1;
    var $_02 = $run2;
    var $b_0 = $11;
    var $a_0 = $src;
    __label__ = 5;
    break;
   case 4:
    var $20 = $3 * $1 | 0;
    _memcpy($dest, $src, $20, 1);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 5:
    var $a_0;
    var $b_0;
    var $_02;
    var $_01;
    var $c_0;
    var $runtotal_0;
    if (($runtotal_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $24 = ($_02 | 0) == 0;
    if ($24 | ($_01 | 0) == 0) {
      var $from_a_0 = $24 & 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $28 = FUNCTION_TABLE[$5]($7, $a_0, $b_0, $cmp_result);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $from_a_0 = (HEAP32[$cmp_result >> 2] | 0) < 1 & 1;
    __label__ = 9;
    break;
   case 9:
    var $from_a_0;
    if (($from_a_0 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ($18) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $38 = $a_0;
    var $39 = $c_0;
    var $st$2$0 = $38 | 0;
    var $40$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $38 + 4 | 0;
    var $40$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $39 | 0;
    HEAP32[$st$6$0 >> 2] = $40$0;
    var $st$6$1 = $39 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $40$1;
    __label__ = 13;
    break;
   case 12:
    _memcpy($c_0, $a_0, $3, 1);
    __label__ = 13;
    break;
   case 13:
    var $_1 = $_01 - 1 | 0;
    var $_13 = $_02;
    var $b_1 = $b_0;
    var $a_1 = $a_0 + $3 | 0;
    __label__ = 18;
    break;
   case 14:
    if ($18) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $47 = $b_0;
    var $48 = $c_0;
    var $st$2$0 = $47 | 0;
    var $49$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $47 + 4 | 0;
    var $49$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $48 | 0;
    HEAP32[$st$6$0 >> 2] = $49$0;
    var $st$6$1 = $48 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $49$1;
    __label__ = 17;
    break;
   case 16:
    _memcpy($c_0, $b_0, $3, 1);
    __label__ = 17;
    break;
   case 17:
    var $_1 = $_01;
    var $_13 = $_02 - 1 | 0;
    var $b_1 = $b_0 + $3 | 0;
    var $a_1 = $a_0;
    __label__ = 18;
    break;
   case 18:
    var $a_1;
    var $b_1;
    var $_13;
    var $_1;
    var $runtotal_0 = $runtotal_0 - 1 | 0;
    var $c_0 = $c_0 + $3 | 0;
    var $_01 = $_1;
    var $_02 = $_13;
    var $b_0 = $b_1;
    var $a_0 = $a_1;
    __label__ = 5;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11MergeArraysP9MSortArgsPvS1_jj["X"] = 1;

function __ZN2js10array_sortEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 92;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $fval = __stackBase__ + 4;
    var $vec = __stackBase__ + 12;
    var $free_ = __stackBase__ + 16;
    var $tvr = __stackBase__ + 24;
    var $hole = __stackBase__ + 40;
    var $ca = __stackBase__ + 44;
    var $1 = __stackBase__ + 84;
    if (($argc | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1 = $vp + 16 | 0;
    var $st$1$0 = $_idx1 | 0;
    var $_idx1_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx1 + 4 | 0;
    var $_idx1_val$1 = HEAP32[$st$1$1 >> 2];
    var $4 = __ZNK2JS5Value11isUndefinedEv($_idx1_val$0, $_idx1_val$1);
    if ($4) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZNK2JS5Value11isPrimitiveEv($_idx1_val$0, $_idx1_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    _JS_ReportErrorNumber($cx, 4, 12, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_3 = 0;
    __label__ = 57;
    break;
   case 5:
    var $9 = $fval | 0;
    var $st$1$0 = $9 | 0;
    HEAP32[$st$1$0 >> 2] = $_idx1_val$0;
    var $st$1$1 = $9 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $_idx1_val$1;
    __label__ = 7;
    break;
   case 6:
    __ZN2JS5Value7setNullEv($fval);
    __label__ = 7;
    break;
   case 7:
    var $12 = $vp + 8 | 0;
    var $13 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $12);
    if (($13 | 0) == 0) {
      var $_3 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $16 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $13, $len);
    if (($16 | 0) == 0) {
      var $_3 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $19 = HEAPU32[$len >> 2];
    if (($19 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    __ZN2JS5Value9setObjectER8JSObject($vp, $13);
    var $_3 = 1;
    __label__ = 57;
    break;
   case 11:
    if ($19 >>> 0 > 268435455) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    __Z27js_ReportAllocationOverflowP9JSContext($cx);
    var $_3 = 0;
    __label__ = 57;
    break;
   case 13:
    var $26 = $19 << 4;
    var $27 = __ZN9JSContext7malloc_Ej($cx, $26);
    HEAP32[$vec >> 2] = $27;
    if (($27 | 0) == 0) {
      var $_3 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZZN2js10array_sortEP9JSContextjPN2JS5ValueEEN14AutoFreeVectorC2ES1_RS4_($free_, $cx, $vec);
    var $31 = HEAP32[$vec >> 2];
    __ZN2js15AutoArrayRooterC1EP9JSContextjPN2JS5ValueE($tvr, $cx, 0, $31);
    var $32 = $cx + 52 | 0;
    var $allStrings_0 = 1;
    var $newlen_0 = 0;
    var $i_0 = 0;
    var $undefs_0 = 0;
    __label__ = 15;
    break;
   case 15:
    var $undefs_0;
    var $i_0;
    var $newlen_0;
    var $allStrings_0;
    if ($i_0 >>> 0 < $19 >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 16:
    if ((HEAP32[HEAP32[$32 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $41 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($41 | 0) == 0) {
      var $_2 = 0;
      var $_16 = 1;
      __label__ = 46;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $44 = HEAP32[$vec >> 2] + ($newlen_0 << 3) | 0;
    __ZN2JS5Value7setNullEv($44);
    var $45 = $newlen_0 + 1 | 0;
    __ZN2js15AutoArrayRooter12changeLengthEj($tvr, $45);
    var $48 = HEAP32[$vec >> 2] + ($newlen_0 << 3) | 0;
    var $49 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $13, $i_0 >>> 0, $hole, $48);
    if (($49 | 0) == 0) {
      var $_2 = 0;
      var $_16 = 1;
      __label__ = 46;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      var $allStrings_1 = $allStrings_0;
      var $newlen_1 = $newlen_0;
      var $undefs_1 = $undefs_0;
      __label__ = 25;
      break;
    }
   case 20:
    var $_idx = HEAP32[$vec >> 2] + ($newlen_0 << 3) | 0;
    var $st$2$0 = $_idx | 0;
    var $_idx_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAP32[$st$2$1 >> 2];
    var $56 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($56) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    var $allStrings_1 = $allStrings_0;
    var $newlen_1 = $newlen_0;
    var $undefs_1 = $undefs_0 + 1 | 0;
    __label__ = 25;
    break;
   case 22:
    if (($allStrings_0 & 1) << 24 >> 24 == 0) {
      var $65 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $63 = __ZNK2JS5Value8isStringEv($_idx_val$0, $_idx_val$1);
    var $65 = $63;
    __label__ = 24;
    break;
   case 24:
    var $65;
    var $allStrings_1 = $65 & 1;
    var $newlen_1 = $45;
    var $undefs_1 = $undefs_0;
    __label__ = 25;
    break;
   case 25:
    var $undefs_1;
    var $newlen_1;
    var $allStrings_1;
    var $allStrings_0 = $allStrings_1;
    var $newlen_0 = $newlen_1;
    var $i_0 = $i_0 + 1 | 0;
    var $undefs_0 = $undefs_1;
    __label__ = 15;
    break;
   case 26:
    if (($newlen_0 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 27:
    __ZN2JS5Value9setObjectER8JSObject($vp, $13);
    var $_2 = 1;
    var $_16 = 1;
    __label__ = 46;
    break;
   case 28:
    var $74 = HEAP32[$vec >> 2] + ($newlen_0 << 3) | 0;
    __ZN2jsL15MakeRangeGCSafeEPN2JS5ValueEj($74, $newlen_0);
    var $75 = $newlen_0 << 1;
    __ZN2js15AutoArrayRooter12changeLengthEj($tvr, $75);
    var $fval_idx = $fval | 0;
    var $fval_idx_val$0 = HEAPU32[$fval_idx >> 2];
    var $fval_idx_val$1 = HEAPU32[$fval_idx + 4 >> 2];
    var $76 = __ZNK2JS5Value6isNullEv($fval_idx_val$0, $fval_idx_val$1);
    if ($76) {
      __label__ = 29;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 29:
    var $79 = ($allStrings_0 & 1) << 24 >> 24 != 0;
    if ($79) {
      var $mergesort_tmp_0 = $74;
      var $elemsize_0 = 8;
      __label__ = 40;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    if ($newlen_0 >>> 0 > 134217727) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $82 = $cx;
    var $i_1 = $newlen_0;
    __label__ = 33;
    break;
   case 32:
    __Z27js_ReportAllocationOverflowP9JSContext($cx);
    var $_2 = 0;
    var $_16 = 1;
    __label__ = 46;
    break;
   case 33:
    var $i_1;
    var $85 = $i_1 - 1 | 0;
    if ((HEAP32[HEAP32[$32 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $91 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($91 | 0) == 0) {
      var $_2 = 0;
      var $_16 = 1;
      __label__ = 46;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $_idx4 = HEAP32[$vec >> 2] + ($85 << 3) | 0;
    var $st$2$0 = $_idx4 | 0;
    var $_idx4_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx4 + 4 | 0;
    var $_idx4_val$1 = HEAP32[$st$2$1 >> 2];
    var $94 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($82, $_idx4_val$0, $_idx4_val$1);
    if (($94 | 0) == 0) {
      var $_2 = 0;
      var $_16 = 1;
      __label__ = 46;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $97 = $85 << 1;
    var $99 = HEAP32[$vec >> 2];
    var $100$0 = HEAP32[$_idx4 >> 2];
    var $100$1 = HEAP32[$_idx4 + 4 >> 2];
    var $101 = $99 + (($97 | 1) << 3) | 0;
    var $st$8$0 = $101 | 0;
    HEAP32[$st$8$0 >> 2] = $100$0;
    var $st$8$1 = $101 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $100$1;
    var $102 = $99 + ($97 << 3) | 0;
    __ZN2JS5Value9setStringEP8JSString($102, $94);
    if (($85 | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      var $i_1 = $85;
      __label__ = 33;
      break;
    }
   case 37:
    var $106 = HEAP32[$vec >> 2];
    var $108 = __ZN9JSContext8realloc_EPvj($cx, $106, $newlen_0 << 5);
    var $109 = $108;
    HEAP32[$vec >> 2] = $109;
    if (($108 | 0) == 0) {
      __label__ = 38;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 38:
    var $113 = HEAP32[$tvr + 12 >> 2];
    HEAP32[$vec >> 2] = $113;
    var $_2 = 0;
    var $_16 = 1;
    __label__ = 46;
    break;
   case 39:
    var $115 = $109 + ($75 << 3) | 0;
    __ZN2jsL15MakeRangeGCSafeEPN2JS5ValueEj($115, $75);
    __ZN2js15AutoArrayRooter11changeArrayEPN2JS5ValueEj($tvr, $109, $newlen_0 << 2);
    var $mergesort_tmp_0 = $115;
    var $elemsize_0 = 16;
    __label__ = 40;
    break;
   case 40:
    var $elemsize_0;
    var $mergesort_tmp_0;
    var $119 = HEAP32[$vec >> 2];
    var $120 = $cx;
    var $122 = __Z12js_MergeSortPvjjPFiS_PKvS1_PiES_S_19JSMergeSortElemType($119, $newlen_0, $elemsize_0, 62, $120, $mergesort_tmp_0, 1);
    if ($122) {
      __label__ = 41;
      break;
    } else {
      var $_2 = 0;
      var $_16 = 1;
      __label__ = 46;
      break;
    }
   case 41:
    if ($79) {
      __label__ = 45;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $124 = HEAP32[$vec >> 2];
    var $i_2 = 0;
    __label__ = 43;
    break;
   case 43:
    var $i_2;
    var $128 = $124 + (($i_2 << 1 | 1) << 3) | 0;
    var $129$0 = HEAP32[$128 >> 2];
    var $129$1 = HEAP32[$128 + 4 >> 2];
    var $130 = $124 + ($i_2 << 3) | 0;
    var $st$9$0 = $130 | 0;
    HEAP32[$st$9$0 >> 2] = $129$0;
    var $st$9$1 = $130 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $129$1;
    var $131 = $i_2 + 1 | 0;
    if (($131 | 0) == ($newlen_0 | 0)) {
      __label__ = 45;
      break;
    } else {
      var $i_2 = $131;
      __label__ = 43;
      break;
    }
   case 44:
    __ZN11CompareArgsC1EP9JSContextN2JS5ValueE($ca, $cx, $fval_idx_val$0, $fval_idx_val$1);
    var $135 = HEAP32[$vec >> 2];
    var $136 = $ca;
    var $137 = $74;
    var $138 = __Z12js_MergeSortPvjjPFiS_PKvS1_PiES_S_19JSMergeSortElemType($135, $newlen_0, 8, 64, $136, $137, 0);
    var $_ = $138 & 1 ^ 1;
    __ZN11CompareArgsD1Ev($ca);
    if ($138) {
      __label__ = 45;
      break;
    } else {
      var $_2 = 0;
      var $_16 = $_;
      __label__ = 46;
      break;
    }
   case 45:
    __ZN2js15AutoArrayRooter12changeLengthEj($tvr, $newlen_0);
    var $140 = HEAP32[$vec >> 2];
    var $141 = __ZL17InitArrayElementsP9JSContextP8JSObjectjjPN2JS5ValueEb($cx, $13, 0, $newlen_0, $140, 0);
    var $_2 = 0;
    var $_16 = ($141 | 0) == 0 & 1;
    __label__ = 46;
    break;
   case 46:
    var $_16;
    var $_2;
    __ZN2js15AutoArrayRooterD1Ev($tvr);
    var $free__idx_val_val = HEAP32[HEAP32[$free_ + 4 >> 2] >> 2];
    __ZZN2js10array_sortEP9JSContextjPN2JS5ValueEEN14AutoFreeVectorD2Ev($free__idx_val_val);
    if (($_16 | 0) == 1) {
      var $_3 = $_2;
      __label__ = 57;
      break;
    } else {
      var $newlen_2 = $newlen_0;
      var $undefs_2 = $undefs_0;
      __label__ = 47;
      break;
    }
   case 47:
    var $undefs_2;
    var $newlen_2;
    if (($undefs_2 | 0) == 0) {
      __label__ = 48;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 48:
    var $158 = HEAP32[$len >> 2];
    __label__ = 52;
    break;
   case 49:
    var $145 = $undefs_2 - 1 | 0;
    if ((HEAP32[HEAP32[$32 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    var $151 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($151 | 0) == 0) {
      var $_3 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $153 = $newlen_2 + 1 | 0;
    var $154 = $newlen_2 >>> 0;
    __ZN2JSL14UndefinedValueEv351($1);
    var $155 = __ZL15SetArrayElementP9JSContextP8JSObjectdRKN2JS5ValueE($cx, $13, $154, $1);
    if (($155 | 0) == 0) {
      var $_3 = 0;
      __label__ = 57;
      break;
    } else {
      var $newlen_2 = $153;
      var $undefs_2 = $145;
      __label__ = 47;
      break;
    }
   case 52:
    var $158;
    if ($158 >>> 0 > $newlen_2 >>> 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 53:
    if ((HEAP32[HEAP32[$32 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 55;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    var $166 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($166 | 0) == 0) {
      var $_3 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    var $169 = HEAP32[$len >> 2] - 1 | 0;
    HEAP32[$len >> 2] = $169;
    var $170 = $169 >>> 0;
    var $171 = __ZL18DeleteArrayElementP9JSContextP8JSObjectdb($cx, $13, $170, 1);
    if (($171 | 0) < 0) {
      var $_3 = 0;
      __label__ = 57;
      break;
    } else {
      var $158 = $169;
      __label__ = 52;
      break;
    }
   case 56:
    __ZN2JS5Value9setObjectER8JSObject($vp, $13);
    var $_3 = 1;
    __label__ = 57;
    break;
   case 57:
    var $_3;
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js10array_sortEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2js15AutoArrayRooterC1EP9JSContextjPN2JS5ValueE($this, $cx, $len, $vec) {
  __ZN2js15AutoArrayRooterC2EP9JSContextjPN2JS5ValueE($this, $cx, $len, $vec);
  return;
}

function __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $obj, $index, $hole, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $idr = __stackBase__;
    var $obj2 = __stackBase__ + 16;
    var $prop = __stackBase__ + 20;
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $1 = __ZNK8JSObject12isDenseArrayEv($obj_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
    if ($3 >>> 0 > $index) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $7 = $index >= 0 ? Math.floor($index) : Math.ceil($index);
    var $obj_idx1_val = HEAP32[$obj + 32 >> 2];
    var $8 = __ZN8JSObject20getDenseArrayElementEj($obj_idx1_val, $7);
    var $9 = $8 | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $vp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZNK2JS5Value7isMagicE10JSWhyMagic($10$0, $10$1);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$hole >> 2] = 0;
    var $_1 = 1;
    __label__ = 17;
    break;
   case 5:
    var $15 = __ZNK8JSObject11isArgumentsEv($obj);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $17 = __ZN8JSObject11asArgumentsEv($obj);
    var $18 = $index >= 0 ? Math.floor($index) : Math.ceil($index);
    var $19 = __ZN2js15ArgumentsObject10getElementEjPN2JS5ValueE($17, $18, $vp);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    HEAP32[$hole >> 2] = 0;
    var $_1 = 1;
    __label__ = 17;
    break;
   case 8:
    var $22 = _INT_TO_JSID398(0);
    __ZN2js12AutoIdRooterC1EP9JSContexti($idr, $cx, $22);
    HEAP32[$hole >> 2] = 0;
    var $23 = __ZN2js12AutoIdRooter4addrEv($idr);
    var $24 = __ZL9IndexToIdP9JSContextP8JSObjectdPiS3_i($cx, $obj, $index, $hole, $23, 0);
    if ($24) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 9:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 16;
    break;
   case 11:
    var $idr_idx2 = $idr + 12 | 0;
    var $idr_idx2_val = HEAP32[$idr_idx2 >> 2];
    var $30 = __ZN2js12AutoIdRooter2idEv($idr_idx2_val);
    var $31 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($obj, $cx, $30, $obj2, $prop);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[$prop >> 2] | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    HEAP32[$hole >> 2] = 1;
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 16;
    break;
   case 14:
    var $idr_idx_val = HEAP32[$idr_idx2 >> 2];
    var $38 = __ZN2js12AutoIdRooter2idEv($idr_idx_val);
    var $39 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($obj, $cx, $38, $vp);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    HEAP32[$hole >> 2] = 0;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    __ZN2js12AutoIdRooterD1Ev($idr);
    var $_1 = $_0;
    __label__ = 17;
    break;
   case 17:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE["X"] = 1;

function __ZN2jsL15MakeRangeGCSafeEPN2JS5ValueEj($vec, $len) {
  __ZN2jsL7PodZeroIN2JS5ValueEEEvPT_j412($vec, $len);
  return;
}

function __ZN2js15AutoArrayRooter11changeArrayEPN2JS5ValueEj($this, $newArray, $newLength) {
  __ZN2js15AutoArrayRooter12changeLengthEj($this, $newLength);
  HEAP32[$this + 12 >> 2] = $newArray;
  return;
}

function __ZL20sort_compare_stringsPvPKvS1_Pi($arg, $a, $b, $result) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx1 = $a;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $1 = __ZNK2JS5Value8toStringEv($_idx1_val$0, $_idx1_val$1);
    var $_idx = $b;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $2 = __ZNK2JS5Value8toStringEv($_idx_val$0, $_idx_val$1);
    if ((HEAP32[HEAP32[$arg + 52 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $arg;
    var $11 = __Z26js_InvokeOperationCallbackP9JSContext($10);
    if (($11 | 0) == 0) {
      var $16 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = $arg;
    var $14 = __ZN2js14CompareStringsEP9JSContextP8JSStringS3_Pi($13, $1, $2, $result);
    var $16 = $14;
    __label__ = 4;
    break;
   case 4:
    var $16;
    return $16 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11CompareArgsC1EP9JSContextN2JS5ValueE($this, $cx, $_0_0_0_val$0, $_0_0_0_val$1) {
  __ZN11CompareArgsC2EP9JSContextN2JS5ValueE($this, $cx, $_0_0_0_val$0, $_0_0_0_val$1);
  return;
}

function __ZL12sort_comparePvPKvS1_Pi($arg, $a, $b, $result) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $cmp = __stackBase__ + 8;
    var $3 = HEAP32[$arg >> 2];
    if ((HEAP32[HEAP32[$3 + 52 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __Z26js_InvokeOperationCallbackP9JSContext($3);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $arg + 4 | 0;
    var $13 = $12;
    var $_idx5_val = HEAP32[$arg + 20 >> 2];
    var $15 = __ZNK2js15InvokeArgsGuard6pushedEv($_idx5_val);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $18 = $3 + 60 | 0;
    var $19 = $3;
    var $20 = $12;
    var $21 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($18, $19, 2, $20);
    if ($21) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $_idx = $12;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $23 = __ZNK2js12CallReceiver7calleevEv($_idx_val);
    var $25 = $arg + 32 | 0;
    var $26$0 = HEAP32[$25 >> 2];
    var $26$1 = HEAP32[$25 + 4 >> 2];
    var $27 = $23 | 0;
    var $st$10$0 = $27 | 0;
    HEAP32[$st$10$0 >> 2] = $26$0;
    var $st$10$1 = $27 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $26$1;
    var $_idx1_val = HEAP32[$_idx >> 2];
    var $28 = __ZNK2js12CallReceiver5thisvEv($_idx1_val);
    __ZN2JSL14UndefinedValueEv351($1);
    var $29 = $1 | 0;
    var $30$0 = HEAP32[$29 >> 2];
    var $30$1 = HEAP32[$29 + 4 >> 2];
    var $31 = $28 | 0;
    var $st$23$0 = $31 | 0;
    HEAP32[$st$23$0 >> 2] = $30$0;
    var $st$23$1 = $31 + 4 | 0;
    HEAP32[$st$23$1 >> 2] = $30$1;
    var $_idx3_val = HEAP32[$_idx >> 2];
    var $32 = __ZNK2js8CallArgsixEj($_idx3_val, 0);
    var $33 = $a;
    var $34$0 = HEAP32[$33 >> 2];
    var $34$1 = HEAP32[$33 + 4 >> 2];
    var $35 = $32 | 0;
    var $st$35$0 = $35 | 0;
    HEAP32[$st$35$0 >> 2] = $34$0;
    var $st$35$1 = $35 + 4 | 0;
    HEAP32[$st$35$1 >> 2] = $34$1;
    var $_idx2_val = HEAP32[$_idx >> 2];
    var $36 = __ZNK2js8CallArgsixEj($_idx2_val, 1);
    var $37 = $b;
    var $38$0 = HEAP32[$37 >> 2];
    var $38$1 = HEAP32[$37 + 4 >> 2];
    var $39 = $36 | 0;
    var $st$47$0 = $39 | 0;
    HEAP32[$st$47$0 >> 2] = $38$0;
    var $st$47$1 = $39 + 4 | 0;
    HEAP32[$st$47$1 >> 2] = $38$1;
    var $40 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($3, $13, 0);
    if ($40) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $_idx4_val = HEAP32[$_idx >> 2];
    var $42 = __ZNK2js12CallReceiver4rvalEv($_idx4_val);
    var $43 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($3, $42, $cmp);
    if ($43) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    HEAP32[$result >> 2] = 0;
    var $45 = (tempDoubleI32[0] = HEAP32[$cmp >> 2], tempDoubleI32[1] = HEAP32[$cmp + 4 >> 2], tempDoubleF64[0]);
    var $46 = __ZL15JSDOUBLE_IS_NaNd397($45);
    if (($46 | 0) == 0 & $45 != 0) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 8:
    var $51 = $45 > 0 ? 1 : -1;
    HEAP32[$result >> 2] = $51;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12sort_comparePvPKvS1_Pi["X"] = 1;

function __ZN11CompareArgsD1Ev($this) {
  __ZN11CompareArgsD2Ev($this);
  return;
}

function __ZL17InitArrayElementsP9JSContextP8JSObjectjjPN2JS5ValueEb($cx, $obj, $start, $count, $vector, $updateTypes) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $idr = __stackBase__ + 24;
    var $idval = __stackBase__ + 40;
    if (($count | 0) == 0) {
      var $_1 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($updateTypes) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $4 = $obj;
    var $5 = $cx;
    var $6 = __ZN8JSObject7getTypeEP9JSContext($4, $5);
    var $7 = $6;
    var $8 = __ZL14InitArrayTypesP9JSContextPN2js5types10TypeObjectEPKN2JS5ValueEj($cx, $7, $vector, $count);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_1 = 0;
      __label__ = 23;
      break;
    }
   case 4:
    var $obj_idx1 = $obj + 4 | 0;
    var $obj_idx1_val = HEAP32[$obj_idx1 >> 2];
    var $10 = __ZNK8JSObject12isDenseArrayEv($obj_idx1_val);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 5:
    var $12 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject($obj);
    if (($12 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $15 = __ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj($obj, $cx, $start, $count);
    if (($15 | 0) == 0) {
      __label__ = 7;
      break;
    } else if (($15 | 0) == 1) {
      var $_1 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    var $17 = $count + $start | 0;
    var $obj_idx2_val = HEAP32[$obj + 24 >> 2];
    var $18 = __ZNK8JSObject14getArrayLengthEv($obj_idx2_val);
    if ($17 >>> 0 > $18 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    __ZN8JSObject19setDenseArrayLengthEj($obj, $17);
    __label__ = 9;
    break;
   case 9:
    __ZN8JSObject22copyDenseArrayElementsEjPKN2JS5ValueEj($obj, $start, $vector, $count);
    var $_1 = 1;
    __label__ = 23;
    break;
   case 10:
    var $23 = $vector + ($count << 3) | 0;
    var $24 = $cx + 52 | 0;
    var $_02 = $vector;
    var $_04 = $start;
    __label__ = 11;
    break;
   case 11:
    var $_04;
    var $_02;
    var $26 = ($_02 | 0) == ($23 | 0);
    if ($26 | ($_04 | 0) == -1) {
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[HEAP32[$24 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $34 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($34 | 0) == 0) {
      var $_1 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $36 = $_04 + 1 | 0;
    var $38 = $_02 + 8 | 0;
    var $39 = __ZL15SetArrayElementP9JSContextP8JSObjectdRKN2JS5ValueE($cx, $obj, $_04 >>> 0, $_02);
    if (($39 | 0) == 0) {
      var $_1 = 0;
      __label__ = 23;
      break;
    } else {
      var $_02 = $38;
      var $_04 = $36;
      __label__ = 11;
      break;
    }
   case 15:
    if ($26) {
      var $_1 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $obj_idx_val = HEAP32[$obj_idx1 >> 2];
    var $42 = __ZNK8JSObject12isDenseArrayEv($obj_idx_val);
    if ($42) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $44 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($obj, $cx);
    if (($44 | 0) == 0) {
      var $_1 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $47 = _INT_TO_JSID398(0);
    __ZN2js12AutoIdRooterC1EP9JSContexti($idr, $cx, $47);
    __ZN2JSL11DoubleValueEd408($idval, 4294967295);
    var $48 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $49 = $48 | 0;
    var $50 = __ZN2js12AutoIdRooter4addrEv($idr);
    var $idr_idx = $idr + 12 | 0;
    var $idval_idx = $idval | 0;
    var $_13 = $_02;
    __label__ = 19;
    break;
   case 19:
    var $_13;
    var $52 = $_13 + 8 | 0;
    var $53 = $_13 | 0;
    var $54$0 = HEAP32[$53 >> 2];
    var $54$1 = HEAP32[$53 + 4 >> 2];
    HEAP32[$49 >> 2] = $54$0;
    HEAP32[$49 + 4 >> 2] = $54$1;
    var $idval_idx_val$0 = HEAP32[$idval_idx >> 2];
    var $idval_idx_val$1 = HEAP32[$idval_idx + 4 >> 2];
    var $55 = __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($cx, $idval_idx_val$0, $idval_idx_val$1, $50);
    if ($55) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 20:
    var $idr_idx_val = HEAP32[$idr_idx >> 2];
    var $57 = __ZN2js12AutoIdRooter2idEv($idr_idx_val);
    var $58 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($obj, $cx, $57, $48, 1);
    if (($58 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $61 = __ZN2JS5Value12getDoubleRefEv($idval);
    var $62 = (tempDoubleI32[0] = HEAP32[$61 >> 2], tempDoubleI32[1] = HEAP32[$61 + 4 >> 2], tempDoubleF64[0]);
    var $63 = $62 + 1;
    tempDoubleF64[0] = $63, HEAP32[$61 >> 2] = tempDoubleI32[0], HEAP32[$61 + 4 >> 2] = tempDoubleI32[1];
    if (($52 | 0) == ($23 | 0)) {
      var $_0 = 1;
      __label__ = 22;
      break;
    } else {
      var $_13 = $52;
      __label__ = 19;
      break;
    }
   case 22:
    var $_0;
    __ZN2js12AutoIdRooterD1Ev($idr);
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 23;
    break;
   case 23:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17InitArrayElementsP9JSContextP8JSObjectjjPN2JS5ValueEb["X"] = 1;

function __ZN2js15AutoArrayRooterD1Ev($this) {
  __ZN2js15AutoArrayRooterD2Ev($this);
  return;
}

function __ZL15SetArrayElementP9JSContextP8JSObjectdRKN2JS5ValueE($cx, $obj, $index, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $idr = __stackBase__;
    var $tmp = __stackBase__ + 16;
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $1 = __ZNK8JSObject12isDenseArrayEv($obj_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    if ($index > 4294967295) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = $index >= 0 ? Math.floor($index) : Math.ceil($index);
    var $6 = __ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj($obj, $cx, $5, 1);
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($6 | 0) == 1) {
      var $_1 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $obj_idx1_val = HEAP32[$obj + 24 >> 2];
    var $8 = __ZNK8JSObject14getArrayLengthEv($obj_idx1_val);
    if ($5 >>> 0 < $8 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = $5 + 1 | 0;
    __ZN8JSObject19setDenseArrayLengthEj($obj, $11);
    __label__ = 6;
    break;
   case 6:
    __ZN8JSObject28setDenseArrayElementWithTypeEP9JSContextjRKN2JS5ValueE($obj, $cx, $5, $v);
    var $_1 = 1;
    __label__ = 11;
    break;
   case 7:
    var $13 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($obj, $cx);
    if (($13 | 0) == 0) {
      var $_1 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $16 = _INT_TO_JSID398(0);
    __ZN2js12AutoIdRooterC1EP9JSContexti($idr, $cx, $16);
    var $17 = __ZN2js12AutoIdRooter4addrEv($idr);
    var $18 = __ZL9IndexToIdP9JSContextP8JSObjectdPiS3_i($cx, $obj, $index, 0, $17, 1);
    if ($18) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    var $20 = $v | 0;
    var $21$0 = HEAP32[$20 >> 2];
    var $21$1 = HEAP32[$20 + 4 >> 2];
    var $22 = $tmp | 0;
    HEAP32[$22 >> 2] = $21$0;
    HEAP32[$22 + 4 >> 2] = $21$1;
    var $idr_idx_val = HEAP32[$idr + 12 >> 2];
    var $23 = __ZN2js12AutoIdRooter2idEv($idr_idx_val);
    var $24 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($obj, $cx, $23, $tmp, 1);
    var $_0 = $24;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    __ZN2js12AutoIdRooterD1Ev($idr);
    var $_1 = $_0;
    __label__ = 11;
    break;
   case 11:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18DeleteArrayElementP9JSContextP8JSObjectdb($cx, $obj, $index, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $idr = __stackBase__ + 8;
    var $v = __stackBase__ + 24;
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $2 = __ZNK8JSObject12isDenseArrayEv($obj_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    if ($index > 4294967295) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = $index >= 0 ? Math.floor($index) : Math.ceil($index);
    var $7 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
    if ($6 >>> 0 < $7 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN8JSObject23markDenseArrayNotPackedEP9JSContext($obj, $cx);
    __ZN2JSL10MagicValueE10JSWhyMagic($1);
    var $obj_idx1_val = HEAP32[$obj + 32 >> 2];
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($obj_idx1_val, $6, $_idx_val$0, $_idx_val$1);
    var $10 = $6 + 1 | 0;
    var $11 = $cx;
    var $12 = $obj;
    var $13 = __Z33js_SuppressDeletedIndexPropertiesP9JSContextP8JSObjectii($11, $12, $6, $10);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      var $_1 = -1;
      __label__ = 11;
      break;
    }
   case 5:
    var $_1 = 1;
    __label__ = 11;
    break;
   case 6:
    var $16 = _INT_TO_JSID398(0);
    __ZN2js12AutoIdRooterC1EP9JSContexti($idr, $cx, $16);
    var $17 = __ZN2js12AutoIdRooter4addrEv($idr);
    var $18 = __ZL9IndexToIdP9JSContextP8JSObjectdPiS3_i($cx, $obj, $index, 0, $17, 0);
    if ($18) {
      __label__ = 7;
      break;
    } else {
      var $_0 = -1;
      __label__ = 10;
      break;
    }
   case 7:
    var $idr_idx_val = HEAP32[$idr + 12 >> 2];
    var $20 = __ZN2js12AutoIdRooter2idEv($idr_idx_val);
    var $21 = _JSID_IS_VOID($20);
    if (($21 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 10;
      break;
    }
   case 8:
    var $24 = $strict & 1;
    var $25 = __ZN8JSObject14deletePropertyEP9JSContextiPN2JS5ValueEi($obj, $cx, $20, $v, $24);
    if (($25 | 0) == 0) {
      var $_0 = -1;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $28 = __ZNK2JS5Value6isTrueEv($v_idx_val$0, $v_idx_val$1);
    var $_0 = $28 & 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    __ZN2js12AutoIdRooterD1Ev($idr);
    var $_1 = $_0;
    __label__ = 11;
    break;
   case 11:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18DeleteArrayElementP9JSContextP8JSObjectdb["X"] = 1;

function __Z19js_NewbornArrayPushP9JSContextP8JSObjectRKN2JS5ValueE($cx, $obj, $vp) {
  var $1 = __Z20NewbornArrayPushImplP9JSContextP8JSObjectRKN2JS5ValueE($cx, $obj, $vp);
  return $1;
}

function __Z20NewbornArrayPushImplP9JSContextP8JSObjectRKN2JS5ValueE($cx, $obj, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $obj_idx1_val = HEAP32[$obj + 24 >> 2];
    var $1 = __ZNK8JSObject14getArrayLengthEv($obj_idx1_val);
    var $obj_idx2_val = HEAP32[$obj + 4 >> 2];
    var $2 = __ZNK8JSObject11isSlowArrayEv($obj_idx2_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $1, $id);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $12 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = HEAP32[$id >> 2];
    var $7 = $cx;
    var $8 = $obj;
    var $9 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($7, $8, $6, $v, 0, 0, 1);
    var $12 = ($9 | 0) != 0;
    __label__ = 4;
    break;
   case 4:
    var $12;
    var $_0 = $12 & 1;
    __label__ = 10;
    break;
   case 5:
    var $obj_idx_val = HEAP32[$obj + 28 >> 2];
    var $15 = __ZN8JSObject21getDenseArrayCapacityEv($obj_idx_val);
    if (($1 | 0) == ($15 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $18 = $1 + 1 | 0;
    var $19 = __ZN8JSObject11ensureSlotsEP9JSContextj($obj, $cx, $18);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $21 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    var $22 = $1 + 1 | 0;
    if ($21) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    __ZN8JSObject30setDenseArrayInitializedLengthEj($obj, $22);
    __label__ = 9;
    break;
   case 9:
    __ZN8JSObject19setDenseArrayLengthEj($obj, $22);
    __ZN8JSObject28setDenseArrayElementWithTypeEP9JSContextjRKN2JS5ValueE($obj, $cx, $1, $v);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10array_pushEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($argc | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$2 + 4 >> 2];
    var $7 = __ZNK8JSObject12isDenseArrayEv($_idx_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $vp + 16 | 0;
    var $10 = __ZL17array_push_slowlyP9JSContextP8JSObjectjPN2JS5ValueES5_($cx, $2, $argc, $9, $vp);
    var $_0 = $10;
    __label__ = 6;
    break;
   case 5:
    var $12 = $vp + 16 | 0;
    var $13 = __ZL17array_push1_denseP9JSContextP8JSObjectRKN2JS5ValueEPS4_($cx, $2, $12, $vp);
    var $_0 = $13;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17array_push_slowlyP9JSContextP8JSObjectjPN2JS5ValueES5_($cx, $obj, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $length = __stackBase__;
    var $1 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $obj, $length);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAPU32[$length >> 2];
    var $5 = __ZL17InitArrayElementsP9JSContextP8JSObjectjjPN2JS5ValueEb($cx, $obj, $4, $argc, $argv, 1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = ($4 >>> 0) + ($argc >>> 0);
    var $11 = __ZN2JS5Value9setNumberEd($rval, $10);
    var $12 = __Z20js_SetLengthPropertyP9JSContextP8JSObjectd($cx, $obj, $10);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17array_push1_denseP9JSContextP8JSObjectRKN2JS5ValueEPS4_($cx, $obj, $v, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $obj_idx1 = $obj + 24 | 0;
    var $obj_idx1_val = HEAP32[$obj_idx1 >> 2];
    var $1 = __ZNK8JSObject14getArrayLengthEv($obj_idx1_val);
    var $2 = __ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj($obj, $cx, $1, 1);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 1) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $1 + 1 | 0;
    __ZN8JSObject19setDenseArrayLengthEj($obj, $4);
    __ZN8JSObject28setDenseArrayElementWithTypeEP9JSContextjRKN2JS5ValueE($obj, $cx, $1, $v);
    var $obj_idx_val = HEAP32[$obj_idx1 >> 2];
    var $5 = __ZNK8JSObject14getArrayLengthEv($obj_idx_val);
    var $6 = __ZN2JS5Value9setNumberEj($rval, $5);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $8 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($obj, $cx);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $v | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $tmp | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $14 = __ZL17array_push_slowlyP9JSContextP8JSObjectjPN2JS5ValueES5_($cx, $obj, 1, $tmp, $rval);
    var $_0 = $14;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9array_popEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$2 + 4 >> 2];
    var $5 = __ZNK8JSObject12isDenseArrayEv($_idx_val);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZL15array_pop_denseP9JSContextP8JSObjectPN2JS5ValueE($cx, $2, $vp);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 4:
    var $9 = __ZL16array_pop_slowlyP9JSContextP8JSObjectPN2JS5ValueE($cx, $2, $vp);
    var $_0 = $9;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15array_pop_denseP9JSContextP8JSObjectPN2JS5ValueE($cx, $obj, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $hole = __stackBase__;
    var $obj_idx_val = HEAP32[$obj + 24 >> 2];
    var $1 = __ZNK8JSObject14getArrayLengthEv($obj_idx_val);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 3:
    var $5 = $1 - 1 | 0;
    var $6 = $5 >>> 0;
    var $7 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $obj, $6, $hole, $vp);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $13 = __ZL18DeleteArrayElementP9JSContextP8JSObjectdb($cx, $obj, $6, 1);
    if (($13 | 0) < 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $16 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $18 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
    if ($18 >>> 0 > $5 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    __ZN8JSObject30setDenseArrayInitializedLengthEj($obj, $5);
    __label__ = 9;
    break;
   case 9:
    __ZN8JSObject14setArrayLengthEP9JSContextj($obj, $cx, $5);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16array_pop_slowlyP9JSContextP8JSObjectPN2JS5ValueE($cx, $obj, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $hole = __stackBase__ + 4;
    var $1 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $obj, $index);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAPU32[$index >> 2];
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $19 = $4;
    __label__ = 7;
    break;
   case 4:
    var $8 = $4 - 1 | 0;
    HEAP32[$index >> 2] = $8;
    var $9 = $8 >>> 0;
    var $10 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $obj, $9, $hole, $vp);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $19 = $8;
      __label__ = 7;
      break;
    }
   case 6:
    var $16 = __ZL18DeleteArrayElementP9JSContextP8JSObjectdb($cx, $obj, $9, 1);
    if (($16 | 0) < 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      var $19 = $8;
      __label__ = 7;
      break;
    }
   case 7:
    var $19;
    var $21 = __Z20js_SetLengthPropertyP9JSContextP8JSObjectd($cx, $obj, $19 >>> 0);
    var $_0 = $21;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14array_toSourceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 124;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $detector = __stackBase__ + 4;
    var $sb = __stackBase__ + 20;
    var $length = __stackBase__ + 100;
    var $hole = __stackBase__ + 104;
    var $tmp = __stackBase__ + 108;
    var $1 = __stackBase__ + 116;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_2 = 0;
    __label__ = 31;
    break;
   case 3:
    var $8 = $vp + 8 | 0;
    var $9 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $8);
    if (($9 | 0) == 0) {
      var $_2 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$9 + 4 >> 2];
    var $12 = __ZNK8JSObject7isArrayEv($_idx_val);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10ArrayClassE);
    var $_2 = 0;
    __label__ = 31;
    break;
   case 6:
    __ZN18ArraySharpDetectorC1EP9JSContext($detector, $cx);
    var $15 = __ZN18ArraySharpDetector4initEP8JSObject($detector, $9);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 7:
    __ZN2js12StringBufferC1EP9JSContext($sb, $cx);
    var $detector_idx_val = HEAP8[$detector + 12 | 0];
    var $17 = __ZNK18ArraySharpDetector14initiallySharpEv($detector_idx_val);
    if ($17) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $19 = __ZN18ArraySharpDetector14takeSharpCharsEv($detector);
    var $20 = __Z9js_strlenPKt($19);
    __ZN2js12StringBuffer16replaceRawBufferEPtj($sb, $19, $20);
    __label__ = 27;
    break;
   case 9:
    var $detector_idx1_val = HEAP32[$detector + 4 >> 2];
    var $22 = __ZNK18ArraySharpDetector13hasSharpCharsEv($detector_idx1_val);
    if ($22) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $detector_idx2_val = HEAP32[$detector + 8 >> 2];
    __ZN18ArraySharpDetector9makeSharpEv($detector_idx2_val);
    var $24 = __ZN18ArraySharpDetector14takeSharpCharsEv($detector);
    var $25 = __Z9js_strlenPKt($24);
    __ZN2js12StringBuffer16replaceRawBufferEPtj($sb, $24, $25);
    __label__ = 11;
    break;
   case 11:
    var $27 = __ZN2js12StringBuffer6appendEt($sb, 91);
    if ($27) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 12:
    var $29 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $9, $length);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $31 = HEAPU32[$length >> 2];
    var $32 = $cx + 52 | 0;
    var $33 = $cx;
    var $index_0 = 0;
    __label__ = 14;
    break;
   case 14:
    var $index_0;
    if ($index_0 >>> 0 < $31 >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 15:
    if ((HEAP32[HEAP32[$32 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $41 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $44 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $9, $index_0 >>> 0, $hole, $tmp);
    if (($44 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $str_0 = HEAP32[HEAP32[$32 >> 2] + 144136 >> 2] | 0;
    __label__ = 21;
    break;
   case 20:
    var $55 = __Z16js_ValueToSourceP9JSContextRKN2JS5ValueE($33, $tmp);
    if (($55 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      var $str_0 = $55;
      __label__ = 21;
      break;
    }
   case 21:
    var $str_0;
    var $58 = __ZN2js12StringBuffer6appendEP8JSString($sb, $str_0);
    if ($58) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 22:
    var $60 = $index_0 + 1 | 0;
    if (($60 | 0) == ($31 | 0)) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $63 = __ZN2js12StringBuffer6appendILj3EEEbRAT__Kc($sb, STRING_TABLE.__str296);
    if ($63) {
      var $index_0 = $60;
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 24:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      var $index_0 = $60;
      __label__ = 14;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $68 = __ZN2js12StringBuffer6appendEt($sb, 44);
    if ($68) {
      var $index_0 = $60;
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 26:
    var $70 = __ZN2js12StringBuffer6appendEt($sb, 93);
    if ($70) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 27:
    var $72 = $sb;
    var $73 = __ZN2js12StringBuffer12finishStringEv($72);
    if (($73 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $76 = $73 | 0;
    __ZN2JSL11StringValueEP8JSString406($1, $76);
    var $77 = $1 | 0;
    var $78$0 = HEAP32[$77 >> 2];
    var $78$1 = HEAP32[$77 + 4 >> 2];
    var $79 = $vp | 0;
    HEAP32[$79 >> 2] = $78$0;
    HEAP32[$79 + 4 >> 2] = $78$1;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 29:
    var $_0;
    __ZN2js12StringBufferD1Ev($sb);
    var $_1 = $_0;
    __label__ = 30;
    break;
   case 30:
    var $_1;
    __ZN18ArraySharpDetectorD1Ev($detector);
    var $_2 = $_1;
    __label__ = 31;
    break;
   case 31:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14array_toSourceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL14array_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_1 = 0;
    __label__ = 12;
    break;
   case 3:
    var $7 = $vp + 8 | 0;
    var $8 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $7);
    if (($8 | 0) == 0) {
      var $_1 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = HEAP32[HEAP32[$cx + 52 >> 2] + 210248 >> 2];
    var $15 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($8, $cx, $14, $vp);
    if (($15 | 0) == 0) {
      var $_1 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $18 = __ZL13js_IsCallableRKN2JS5ValueE405($vp_idx_val$0, $vp_idx_val$1);
    if ($18) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = $cx;
    var $21 = $8;
    var $22 = __ZN2js18obj_toStringHelperEP9JSContextP8JSObject($20, $21);
    if (($22 | 0) == 0) {
      var $_1 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JS5Value9setStringEP8JSString($vp, $22);
    var $_1 = 1;
    __label__ = 12;
    break;
   case 8:
    __ZN2js15InvokeArgsGuardC1Ev($args);
    var $27 = $cx + 60 | 0;
    var $28 = $cx;
    var $29 = $args;
    var $30 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($27, $28, 0, $29);
    if ($30) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 9:
    var $_idx = $args | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $32 = __ZNK2js12CallReceiver7calleevEv($_idx_val);
    var $st$3$0 = $vp_idx | 0;
    var $33$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $vp_idx + 4 | 0;
    var $33$1 = HEAP32[$st$3$1 >> 2];
    var $34 = $32 | 0;
    var $st$8$0 = $34 | 0;
    HEAP32[$st$8$0 >> 2] = $33$0;
    var $st$8$1 = $34 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $33$1;
    var $_idx1_val = HEAP32[$_idx >> 2];
    var $35 = __ZNK2js12CallReceiver5thisvEv($_idx1_val);
    __ZN2JS5Value9setObjectER8JSObject($35, $8);
    var $36 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($cx, $args, 0);
    if ($36) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $_idx2_val = HEAP32[$_idx >> 2];
    var $38 = __ZNK2js12CallReceiver4rvalEv($_idx2_val);
    var $39 = $38 | 0;
    var $st$3$0 = $39 | 0;
    var $40$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $39 + 4 | 0;
    var $40$1 = HEAP32[$st$3$1 >> 2];
    HEAP32[$vp_idx >> 2] = $40$0;
    HEAP32[$vp_idx + 4 >> 2] = $40$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    __ZN2js15InvokeArgsGuardD1Ev($args);
    var $_1 = $_0;
    __label__ = 12;
    break;
   case 12:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14array_toStringP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL20array_toLocaleStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = $vp + 8 | 0;
    var $8 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $7);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = __ZL18array_toString_subP9JSContextP8JSObjectiP8JSStringPN2JS5ValueE($cx, $8, 1, 0, $vp);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10array_joinP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 3:
    if (($argc | 0) == 0) {
      var $str_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $vp + 16 | 0;
    var $_idx = $9 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $10 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($10) {
      var $str_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $cx;
    var $13 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($12, $_idx_val$0, $_idx_val$1);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2JS5Value9setStringEP8JSString($9, $13);
    var $str_0 = $13;
    __label__ = 7;
    break;
   case 7:
    var $str_0;
    var $17 = $vp + 8 | 0;
    var $18 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $17);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = __ZL18array_toString_subP9JSContextP8JSObjectiP8JSStringPN2JS5ValueE($cx, $18, 0, $str_0, $vp);
    var $_0 = $21;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13array_reverseP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $tvr = __stackBase__ + 4;
    var $hole = __stackBase__ + 28;
    var $hole2 = __stackBase__ + 32;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_1 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $2, $len);
    if (($5 | 0) == 0) {
      var $_1 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $_idx_val = HEAP32[$2 + 4 >> 2];
    var $8 = __ZNK8JSObject12isDenseArrayEv($_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 4:
    var $10 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject($2);
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 5:
    var $13 = HEAP32[$len >> 2];
    if (($13 | 0) == 0) {
      var $_1 = 1;
      __label__ = 26;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx3_val = HEAP32[$2 + 28 >> 2];
    var $16 = __ZN8JSObject21getDenseArrayCapacityEv($_idx3_val);
    if (($16 | 0) == 0) {
      var $_1 = 1;
      __label__ = 26;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = __ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj($2, $cx, $13, 0);
    if (($19 | 0) == 0) {
      __label__ = 8;
      break;
    } else if (($19 | 0) == 1) {
      var $_1 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 8:
    __ZN8JSObject33ensureDenseArrayInitializedLengthEP9JSContextjj($2, $cx, $13, 0);
    var $21 = $cx;
    var $22 = $2;
    var $_idx2 = $2 + 32 | 0;
    var $hi_0_in = $13;
    var $lo_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $lo_0;
    var $hi_0_in;
    var $hi_0 = $hi_0_in - 1 | 0;
    if ($lo_0 >>> 0 < $hi_0 >>> 0) {
      __label__ = 10;
      break;
    } else {
      var $_1 = 1;
      __label__ = 26;
      break;
    }
   case 10:
    var $_idx2_val = HEAPU32[$_idx2 >> 2];
    var $26 = __ZN8JSObject20getDenseArrayElementEj($_idx2_val, $lo_0);
    var $27 = $26 | 0;
    var $28$0 = HEAP32[$27 >> 2];
    var $28$1 = HEAP32[$27 + 4 >> 2];
    var $29 = __ZN8JSObject20getDenseArrayElementEj($_idx2_val, $hi_0);
    var $30 = $29 | 0;
    var $31$0 = HEAP32[$30 >> 2];
    var $31$1 = HEAP32[$30 + 4 >> 2];
    __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($_idx2_val, $lo_0, $31$0, $31$1);
    var $32 = __ZNK2JS5Value7isMagicE10JSWhyMagic($31$0, $31$1);
    if ($32) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $34 = _INT_TO_JSID398($lo_0);
    var $35 = __Z26js_SuppressDeletedPropertyP9JSContextP8JSObjecti($21, $22, $34);
    if ($35) {
      __label__ = 12;
      break;
    } else {
      var $_1 = 0;
      __label__ = 26;
      break;
    }
   case 12:
    var $_idx4_val = HEAP32[$_idx2 >> 2];
    __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($_idx4_val, $hi_0, $28$0, $28$1);
    var $37 = __ZNK2JS5Value7isMagicE10JSWhyMagic($28$0, $28$1);
    if ($37) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $39 = _INT_TO_JSID398($hi_0);
    var $40 = __Z26js_SuppressDeletedPropertyP9JSContextP8JSObjecti($21, $22, $39);
    if ($40) {
      __label__ = 14;
      break;
    } else {
      var $_1 = 0;
      __label__ = 26;
      break;
    }
   case 14:
    var $hi_0_in = $hi_0;
    var $lo_0 = $lo_0 + 1 | 0;
    __label__ = 9;
    break;
   case 15:
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $43 = HEAPU32[$len >> 2];
    var $44 = $43 >>> 1;
    var $45 = $cx + 52 | 0;
    var $i_0 = 0;
    __label__ = 16;
    break;
   case 16:
    var $i_0;
    if ($i_0 >>> 0 < $44 >>> 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 17:
    if ((HEAP32[HEAP32[$45 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $54 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($54 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $56 = $i_0 >>> 0;
    var $57 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $58 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $2, $56, $hole, $57);
    if (($58 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $63 = ($43 + ($i_0 ^ -1) | 0) >>> 0;
    var $64 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $2, $63, $hole2, $vp);
    if (($64 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $67 = HEAP32[$hole >> 2];
    var $68 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $69 = __ZL23SetOrDeleteArrayElementP9JSContextP8JSObjectdiRKN2JS5ValueE($cx, $2, $63, $67, $68);
    if (($69 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $72 = HEAP32[$hole2 >> 2];
    var $73 = __ZL23SetOrDeleteArrayElementP9JSContextP8JSObjectdiRKN2JS5ValueE($cx, $2, $56, $72, $vp);
    if (($73 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 16;
    break;
   case 24:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $_0 = 1;
    __label__ = 25;
    break;
   case 25:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 26;
    break;
   case 26:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13array_reverseP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL11array_shiftP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $length = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $hole = __stackBase__ + 12;
    var $tvr = __stackBase__ + 16;
    var $2 = $vp + 8 | 0;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $2);
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $3, $length);
    if (($6 | 0) == 0) {
      var $_1 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAPU32[$length >> 2];
    if (($9 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $76 = $9;
    __label__ = 26;
    break;
   case 5:
    var $13 = $9 - 1 | 0;
    HEAP32[$length >> 2] = $13;
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $14 = __ZNK8JSObject12isDenseArrayEv($_idx_val);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 6:
    var $16 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject($3);
    if (($16 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 7:
    var $_idx2_val = HEAP32[$3 + 28 >> 2];
    var $19 = __ZN8JSObject21getDenseArrayCapacityEv($_idx2_val);
    if ($13 >>> 0 < $19 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 8:
    var $22 = __ZN8JSObject30getDenseArrayInitializedLengthEv($3);
    if (($22 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_idx1 = $3 + 32 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $25 = __ZN8JSObject20getDenseArrayElementEj($_idx1_val, 0);
    var $26 = $25 | 0;
    var $27$0 = HEAP32[$26 >> 2];
    var $27$1 = HEAP32[$26 + 4 >> 2];
    var $28 = $vp | 0;
    HEAP32[$28 >> 2] = $27$0;
    HEAP32[$28 + 4 >> 2] = $27$1;
    var $29 = __ZNK2JS5Value7isMagicE10JSWhyMagic($27$0, $27$1);
    if ($29) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 11;
    break;
   case 11:
    var $_idx5_val = HEAP32[$_idx1 >> 2];
    __ZN8JSObject22moveDenseArrayElementsEjjj($_idx5_val, 0, 1, $13);
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $32 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($32) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $34 = __ZN8JSObject30getDenseArrayInitializedLengthEv($3);
    var $35 = $34 - 1 | 0;
    __ZN8JSObject30setDenseArrayInitializedLengthEj($3, $35);
    __label__ = 14;
    break;
   case 13:
    __ZN2JSL10MagicValueE10JSWhyMagic($1);
    var $_idx3_val = HEAP32[$_idx1 >> 2];
    var $_idx4 = $1 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($_idx3_val, $13, $_idx4_val$0, $_idx4_val$1);
    __label__ = 14;
    break;
   case 14:
    __ZN8JSObject14setArrayLengthEP9JSContextj($3, $cx, $13);
    var $38 = _INT_TO_JSID398($13);
    var $39 = $cx;
    var $40 = $3;
    var $41 = __Z26js_SuppressDeletedPropertyP9JSContextP8JSObjecti($39, $40, $38);
    var $_1 = $41 & 1;
    __label__ = 27;
    break;
   case 15:
    var $43 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $3, 0, $hole, $vp);
    if (($43 | 0) == 0) {
      var $_1 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $46 = $cx + 52 | 0;
    var $i_0 = 0;
    __label__ = 17;
    break;
   case 17:
    var $i_0;
    if ($i_0 >>> 0 < $13 >>> 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 18:
    if ((HEAP32[HEAP32[$46 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $55 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($55 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $57 = $i_0 + 1 | 0;
    var $58 = $57 >>> 0;
    var $59 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $60 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $3, $58, $hole, $59);
    if (($60 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $63 = $i_0 >>> 0;
    var $64 = HEAP32[$hole >> 2];
    var $65 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $66 = __ZL23SetOrDeleteArrayElementP9JSContextP8JSObjectdiRKN2JS5ValueE($cx, $3, $63, $64, $65);
    if (($66 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      var $i_0 = $57;
      __label__ = 17;
      break;
    }
   case 22:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 23:
    var $72 = $13 >>> 0;
    var $73 = __ZL18DeleteArrayElementP9JSContextP8JSObjectdb($cx, $3, $72, 1);
    if (($73 | 0) < 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = 0;
    __label__ = 27;
    break;
   case 25:
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $76 = HEAP32[$length >> 2];
    __label__ = 26;
    break;
   case 26:
    var $76;
    var $78 = __Z20js_SetLengthPropertyP9JSContextP8JSObjectd($cx, $3, $76 >>> 0);
    var $_1 = $78;
    __label__ = 27;
    break;
   case 27:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11array_shiftP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL13array_unshiftP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $hole = __stackBase__;
    var $length = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $tvr = __stackBase__ + 16;
    var $2 = $vp + 8 | 0;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $2);
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $3, $length);
    if (($6 | 0) == 0) {
      var $_1 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAPU32[$length >> 2];
    var $10 = $9 >>> 0;
    if (($argc | 0) == 0) {
      var $newlen_0 = $10;
      __label__ = 19;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $vp + 16 | 0;
    if (($9 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $16 = __ZNK8JSObject12isDenseArrayEv($_idx_val);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $18 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject($3);
    if (($18 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    var $21 = __ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj($3, $cx, $9, $argc);
    if (($21 | 0) == 0) {
      __label__ = 8;
      break;
    } else if (($21 | 0) == 1) {
      var $_1 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $_idx3 = $3 + 32 | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    __ZN8JSObject22moveDenseArrayElementsEjjj($_idx3_val, $argc, 0, $9);
    var $_idx2 = $1 | 0;
    var $i_08 = 0;
    __label__ = 9;
    break;
   case 9:
    var $i_08;
    __ZN2JSL10MagicValueE10JSWhyMagic($1);
    var $_idx1_val = HEAP32[$_idx3 >> 2];
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($_idx1_val, $i_08, $_idx2_val$0, $_idx2_val$1);
    var $22 = $i_08 + 1 | 0;
    if (($22 | 0) == ($argc | 0)) {
      __label__ = 17;
      break;
    } else {
      var $i_08 = $22;
      __label__ = 9;
      break;
    }
   case 10:
    var $24 = $10 + ($argc >>> 0);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $25 = $cx + 52 | 0;
    var $upperIndex_0 = $24;
    var $last_0 = $10;
    __label__ = 11;
    break;
   case 11:
    var $last_0;
    var $upperIndex_0;
    var $27 = $last_0 - 1;
    var $28 = $upperIndex_0 - 1;
    if ((HEAP32[HEAP32[$25 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $34 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($34 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $36 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $37 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $3, $27, $hole, $36);
    if (($37 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $40 = HEAP32[$hole >> 2];
    var $41 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $42 = __ZL23SetOrDeleteArrayElementP9JSContextP8JSObjectdiRKN2JS5ValueE($cx, $3, $28, $40, $41);
    if (($42 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    if ($27 != 0) {
      var $upperIndex_0 = $28;
      var $last_0 = $27;
      __label__ = 11;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN2js15AutoValueRooterD1Ev($tvr);
    __label__ = 17;
    break;
   case 17:
    var $47 = __ZL17InitArrayElementsP9JSContextP8JSObjectjjPN2JS5ValueEb($cx, $3, 0, $argc, $13, 1);
    if (($47 | 0) == 0) {
      var $_1 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $newlen_0 = $10 + ($argc >>> 0);
    __label__ = 19;
    break;
   case 19:
    var $newlen_0;
    var $53 = __Z20js_SetLengthPropertyP9JSContextP8JSObjectd($cx, $3, $newlen_0);
    if (($53 | 0) == 0) {
      var $_1 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $56 = __ZN2JS5Value9setNumberEd($vp, $newlen_0);
    var $_1 = 1;
    __label__ = 24;
    break;
   case 21:
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = 0;
    __label__ = 24;
    break;
   case 22:
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = 0;
    __label__ = 24;
    break;
   case 23:
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = 0;
    __label__ = 24;
    break;
   case 24:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13array_unshiftP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL12array_spliceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $length = __stackBase__;
    var $hole = __stackBase__ + 4;
    var $d = __stackBase__ + 8;
    var $tvr = __stackBase__ + 16;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_1 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($cx);
    if (($5 | 0) == 0) {
      var $_1 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZL17TryReuseArrayTypeP8JSObjectS0_($2, $5);
    __ZN2JS5Value9setObjectER8JSObject($vp, $5);
    if (($argc | 0) == 0) {
      var $_1 = 1;
      __label__ = 69;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $2, $length);
    if (($10 | 0) == 0) {
      var $_1 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = $vp + 16 | 0;
    var $14 = HEAPU32[$length >> 2];
    var $15 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd($cx, $13, $d);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      var $_1 = 0;
      __label__ = 69;
      break;
    }
   case 6:
    var $17 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $19 = $14 >>> 0;
    if ($17 < 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $21 = $17 + $19;
    tempDoubleF64[0] = $21, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    if ($21 < 0) {
      __label__ = 8;
      break;
    } else {
      var $28 = $21;
      __label__ = 11;
      break;
    }
   case 8:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = 0;
    __label__ = 11;
    break;
   case 9:
    if ($17 > $19) {
      __label__ = 10;
      break;
    } else {
      var $28 = $17;
      __label__ = 11;
      break;
    }
   case 10:
    tempDoubleF64[0] = $19, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $19;
    __label__ = 11;
    break;
   case 11:
    var $28;
    var $29 = $28 >= 0 ? Math.floor($28) : Math.ceil($28);
    var $30 = $vp + 24 | 0;
    var $31 = $14 - $29 | 0;
    if (($argc | 0) == 1) {
      var $_03 = 0;
      var $argv_0 = $30;
      var $end_0 = $14;
      var $count_0 = $31;
      __label__ = 18;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $34 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd($cx, $30, $d);
    if ($34) {
      __label__ = 13;
      break;
    } else {
      var $_1 = 0;
      __label__ = 69;
      break;
    }
   case 13:
    var $36 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    if ($36 < 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $44 = 0;
    __label__ = 17;
    break;
   case 15:
    var $40 = $31 >>> 0;
    if ($36 > $40) {
      __label__ = 16;
      break;
    } else {
      var $44 = $36;
      __label__ = 17;
      break;
    }
   case 16:
    tempDoubleF64[0] = $40, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $44 = $40;
    __label__ = 17;
    break;
   case 17:
    var $44;
    var $45 = $44 >= 0 ? Math.floor($44) : Math.ceil($44);
    var $_03 = $argc - 2 | 0;
    var $argv_0 = $vp + 32 | 0;
    var $end_0 = $45 + $29 | 0;
    var $count_0 = $45;
    __label__ = 18;
    break;
   case 18:
    var $count_0;
    var $end_0;
    var $argv_0;
    var $_03;
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    if (($count_0 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $_idx2_val = HEAP32[$2 + 4 >> 2];
    var $52 = __ZNK8JSObject12isDenseArrayEv($_idx2_val);
    if ($52) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $53 = $cx + 52 | 0;
    var $last_0 = $29;
    __label__ = 24;
    break;
   case 21:
    var $55 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject($2);
    if (($55 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 22:
    var $58 = __ZN8JSObject30getDenseArrayInitializedLengthEv($2);
    if ($end_0 >>> 0 > $58 >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $_idx6_val = HEAP32[$2 + 32 >> 2];
    var $61 = __ZN8JSObject21getDenseArrayElementsEv($_idx6_val);
    var $62 = $61 + ($29 << 3) | 0;
    var $63 = __ZL15InitArrayObjectP9JSContextP8JSObjectjPKN2JS5ValueE($cx, $5, $count_0, $62);
    if (($63 | 0) == 0) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 24:
    var $last_0;
    if ($last_0 >>> 0 < $end_0 >>> 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 25:
    if ((HEAP32[HEAP32[$53 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $73 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($73 | 0) == 0) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $75 = $last_0 >>> 0;
    var $76 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $77 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $2, $75, $hole, $76);
    if (($77 | 0) == 0) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 29:
    var $84 = ($last_0 - $29 | 0) >>> 0;
    var $85 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $86 = __ZL15SetArrayElementP9JSContextP8JSObjectdRKN2JS5ValueE($cx, $5, $84, $85);
    if (($86 | 0) == 0) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $last_0 = $last_0 + 1 | 0;
    __label__ = 24;
    break;
   case 31:
    var $92 = __Z20js_SetLengthPropertyP9JSContextP8JSObjectd($cx, $5, $count_0 >>> 0);
    if (($92 | 0) == 0) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    if ($_03 >>> 0 > $count_0 >>> 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 33:
    var $97 = $_03 - $count_0 | 0;
    var $98 = HEAPU32[$length >> 2];
    var $_idx1_val = HEAP32[$2 + 4 >> 2];
    var $99 = __ZNK8JSObject12isDenseArrayEv($_idx1_val);
    if ($99) {
      __label__ = 34;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 34:
    var $101 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject($2);
    if (($101 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 35:
    var $104 = __ZN8JSObject30getDenseArrayInitializedLengthEv($2);
    if ($98 >>> 0 > $104 >>> 0) {
      __label__ = 38;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    if (($98 | 0) == 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $109 = $98 - 1 | 0;
    var $_idx3_val = HEAP32[$2 + 32 >> 2];
    var $110 = __ZN8JSObject20getDenseArrayElementEj($_idx3_val, $109);
    var $_idx4 = $110 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    var $111 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx4_val$0, $_idx4_val$1);
    if ($111) {
      __label__ = 38;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 38:
    var $112 = $cx + 52 | 0;
    var $last_1 = $98;
    __label__ = 41;
    break;
   case 39:
    var $114 = __ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj($2, $cx, $98, $97);
    if (($114 | 0) == 0) {
      __label__ = 40;
      break;
    } else if (($114 | 0) == 1) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 40:
    var $116 = $98 - $end_0 | 0;
    var $_idx8_val = HEAP32[$2 + 32 >> 2];
    __ZN8JSObject22moveDenseArrayElementsEjjj($_idx8_val, $97 + $end_0 | 0, $end_0, $116);
    var $_idx5_val = HEAP32[$2 + 24 >> 2];
    var $117 = __ZNK8JSObject14getArrayLengthEv($_idx5_val);
    var $118 = $117 + $97 | 0;
    __ZN8JSObject14setArrayLengthEP9JSContextj($2, $cx, $118);
    var $140 = $98;
    __label__ = 47;
    break;
   case 41:
    var $last_1;
    var $119 = $last_1 - 1 | 0;
    if ($last_1 >>> 0 > $end_0 >>> 0) {
      __label__ = 42;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 42:
    if ((HEAP32[HEAP32[$112 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    var $127 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($127 | 0) == 0) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $129 = $119 >>> 0;
    var $130 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $131 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $2, $129, $hole, $130);
    if (($131 | 0) == 0) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $135 = ($119 + $97 | 0) >>> 0;
    var $136 = HEAP32[$hole >> 2];
    var $137 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $138 = __ZL23SetOrDeleteArrayElementP9JSContextP8JSObjectdiRKN2JS5ValueE($cx, $2, $135, $136, $137);
    if (($138 | 0) == 0) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      var $last_1 = $119;
      __label__ = 41;
      break;
    }
   case 46:
    var $140 = HEAP32[$length >> 2];
    __label__ = 47;
    break;
   case 47:
    var $140;
    var $141 = $140 + $97 | 0;
    HEAP32[$length >> 2] = $141;
    var $185 = $141;
    __label__ = 63;
    break;
   case 48:
    if ($_03 >>> 0 < $count_0 >>> 0) {
      __label__ = 50;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $185 = HEAP32[$length >> 2];
    __label__ = 63;
    break;
   case 50:
    var $145 = $count_0 - $_03 | 0;
    var $_idx_val = HEAP32[$2 + 4 >> 2];
    var $146 = __ZNK8JSObject12isDenseArrayEv($_idx_val);
    if ($146) {
      __label__ = 52;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $147 = HEAPU32[$length >> 2];
    var $148 = $cx + 52 | 0;
    var $last_2 = $end_0;
    __label__ = 55;
    break;
   case 52:
    var $150 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject($2);
    if (($150 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 53:
    var $153 = HEAPU32[$length >> 2];
    var $154 = __ZN8JSObject30getDenseArrayInitializedLengthEv($2);
    if ($153 >>> 0 > $154 >>> 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    var $158 = $153 - $end_0 | 0;
    var $_idx7_val = HEAP32[$2 + 32 >> 2];
    __ZN8JSObject22moveDenseArrayElementsEjjj($_idx7_val, $end_0 - $145 | 0, $end_0, $158);
    var $182 = $153;
    __label__ = 62;
    break;
   case 55:
    var $last_2;
    if ($last_2 >>> 0 < $147 >>> 0) {
      __label__ = 56;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 56:
    if ((HEAP32[HEAP32[$148 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 58;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    var $167 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($167 | 0) == 0) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 58:
    var $169 = $last_2 >>> 0;
    var $170 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $171 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $2, $169, $hole, $170);
    if (($171 | 0) == 0) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 59:
    var $175 = ($last_2 - $145 | 0) >>> 0;
    var $176 = HEAP32[$hole >> 2];
    var $177 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $178 = __ZL23SetOrDeleteArrayElementP9JSContextP8JSObjectdiRKN2JS5ValueE($cx, $2, $175, $176, $177);
    if (($178 | 0) == 0) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 60:
    var $last_2 = $last_2 + 1 | 0;
    __label__ = 55;
    break;
   case 61:
    var $182 = HEAP32[$length >> 2];
    __label__ = 62;
    break;
   case 62:
    var $182;
    var $183 = $182 - $145 | 0;
    HEAP32[$length >> 2] = $183;
    var $185 = $183;
    __label__ = 63;
    break;
   case 63:
    var $185;
    if ($185 >>> 0 < $14 >>> 0) {
      __label__ = 64;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 64:
    var $188 = $cx;
    var $189 = $2;
    var $190 = __Z33js_SuppressDeletedIndexPropertiesP9JSContextP8JSObjectii($188, $189, $185, $14);
    if ($190) {
      __label__ = 65;
      break;
    } else {
      var $_0 = 0;
      __label__ = 68;
      break;
    }
   case 65:
    var $192 = __ZL17InitArrayElementsP9JSContextP8JSObjectjjPN2JS5ValueEb($cx, $2, $29, $_03, $argv_0, 1);
    if (($192 | 0) == 0) {
      var $199 = 0;
      __label__ = 67;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 66:
    var $196 = __Z20js_SetLengthPropertyP9JSContextP8JSObjectd($cx, $2, $185 >>> 0);
    var $199 = ($196 | 0) != 0;
    __label__ = 67;
    break;
   case 67:
    var $199;
    var $_0 = $199 & 1;
    __label__ = 68;
    break;
   case 68:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 69;
    break;
   case 69:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12array_spliceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2jsL16GetClassProtoKeyEPNS_5ClassE382($clasp_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $clasp_0_1_val >>> 24;
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $clasp_0_1_val >>> 17 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject30setDenseArrayInitializedLengthEj($this, $length) {
  HEAP32[$this + 16 >> 2] = $length;
  return;
}

function __ZN2js2gcL15GetGCObjectKindEjb374($numSlots, $isArray) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $isArray ? 0 : 10;
    var $_0 = $3;
    __label__ = 4;
    break;
   case 3:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12array_concatP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $alength = __stackBase__;
    var $hole = __stackBase__ + 4;
    var $tmp = __stackBase__ + 8;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx2_val = HEAP32[$2 + 4 >> 2];
    var $5 = __ZNK8JSObject12isDenseArrayEv($_idx2_val);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    var $_idx3_val = HEAP32[$2 + 24 >> 2];
    var $7 = __ZNK8JSObject14getArrayLengthEv($_idx3_val);
    var $_idx4_val = HEAP32[$2 + 32 >> 2];
    var $8 = __ZN8JSObject21getDenseArrayElementsEv($_idx4_val);
    var $9 = __ZN8JSObject30getDenseArrayInitializedLengthEv($2);
    var $10 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($cx, $9, $8);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZL17TryReuseArrayTypeP8JSObjectS0_($2, $10);
    __ZN8JSObject14setArrayLengthEP9JSContextj($10, $cx, $7);
    var $_idx7_val = HEAP32[$2 + 8 >> 2];
    var $13 = __ZN8JSObject18isPackedDenseArrayEv($_idx7_val);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN8JSObject23markDenseArrayNotPackedEP9JSContext($10, $cx);
    __label__ = 6;
    break;
   case 6:
    __ZN2JS5Value9setObjectER8JSObject($vp, $10);
    if (($argc | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_02 = $argc - 1 | 0;
    var $p_0 = $vp + 16 | 0;
    var $nobj_0 = $10;
    var $length_0 = $7;
    __label__ = 10;
    break;
   case 8:
    var $21 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($cx);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2JS5Value9setObjectER8JSObject($vp, $21);
    var $_02 = $argc;
    var $p_0 = $1;
    var $nobj_0 = $21;
    var $length_0 = 0;
    __label__ = 10;
    break;
   case 10:
    var $length_0;
    var $nobj_0;
    var $p_0;
    var $_02;
    var $25 = $cx + 52 | 0;
    var $i_0 = 0;
    var $length_1 = $length_0;
    __label__ = 11;
    break;
   case 11:
    var $length_1;
    var $i_0;
    if ($i_0 >>> 0 > $_02 >>> 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[HEAP32[$25 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $34 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $36 = $p_0 + ($i_0 << 3) | 0;
    var $_idx = $36 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $37 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($37) {
      __label__ = 15;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    var $39 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $_idx6_val = HEAP32[$39 + 4 >> 2];
    var $40 = __ZNK8JSObject7isArrayEv($_idx6_val);
    if ($40) {
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $42 = __ZNK8JSObject9isWrapperEv($39);
    if ($42) {
      __label__ = 17;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 17:
    var $44 = __ZN8JSObject6unwrapEPj($39, 0);
    var $_idx5_val = HEAP32[$44 + 4 >> 2];
    var $45 = __ZNK8JSObject7isArrayEv($_idx5_val);
    if ($45) {
      __label__ = 18;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 18:
    var $47 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $39, $alength);
    if (($47 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $49 = HEAPU32[$alength >> 2];
    var $slot_0 = 0;
    __label__ = 20;
    break;
   case 20:
    var $slot_0;
    if ($slot_0 >>> 0 < $49 >>> 0) {
      __label__ = 21;
      break;
    } else {
      var $_pn = $49;
      __label__ = 28;
      break;
    }
   case 21:
    if ((HEAP32[HEAP32[$25 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $58 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($58 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $61 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $39, $slot_0 >>> 0, $hole, $tmp);
    if (($61 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    var $69 = __ZL15SetArrayElementP9JSContextP8JSObjectdRKN2JS5ValueE($cx, $nobj_0, ($slot_0 + $length_1 | 0) >>> 0, $tmp);
    if (($69 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $slot_0 = $slot_0 + 1 | 0;
    __label__ = 20;
    break;
   case 27:
    var $75 = __ZL15SetArrayElementP9JSContextP8JSObjectdRKN2JS5ValueE($cx, $nobj_0, $length_1 >>> 0, $36);
    if (($75 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      var $_pn = 1;
      __label__ = 28;
      break;
    }
   case 28:
    var $_pn;
    var $i_0 = $i_0 + 1 | 0;
    var $length_1 = $_pn + $length_1 | 0;
    __label__ = 11;
    break;
   case 29:
    var $80 = __Z20js_SetLengthPropertyP9JSContextP8JSObjectd($cx, $nobj_0, $length_1 >>> 0);
    var $_0 = $80;
    __label__ = 30;
    break;
   case 30:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12array_concatP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL11array_sliceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $length = __stackBase__;
    var $hole = __stackBase__ + 4;
    var $d = __stackBase__ + 8;
    var $tvr = __stackBase__ + 16;
    var $1 = $vp + 16 | 0;
    var $2 = $vp + 8 | 0;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $2);
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $3, $length);
    if (($6 | 0) == 0) {
      var $_1 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAPU32[$length >> 2];
    if (($argc | 0) == 0) {
      var $end_0 = $9;
      var $begin_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd($cx, $1, $d);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      var $_1 = 0;
      __label__ = 36;
      break;
    }
   case 5:
    var $14 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $16 = $9 >>> 0;
    if ($14 < 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $14 + $16;
    tempDoubleF64[0] = $18, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    if ($18 < 0) {
      __label__ = 7;
      break;
    } else {
      var $25 = $18;
      __label__ = 10;
      break;
    }
   case 7:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $25 = 0;
    __label__ = 10;
    break;
   case 8:
    if ($14 > $16) {
      __label__ = 9;
      break;
    } else {
      var $25 = $14;
      __label__ = 10;
      break;
    }
   case 9:
    tempDoubleF64[0] = $16, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $25 = $16;
    __label__ = 10;
    break;
   case 10:
    var $25;
    var $26 = $25 >= 0 ? Math.floor($25) : Math.ceil($25);
    if ($argc >>> 0 > 1) {
      __label__ = 11;
      break;
    } else {
      var $end_0 = $9;
      var $begin_0 = $26;
      __label__ = 19;
      break;
    }
   case 11:
    var $29 = $vp + 24 | 0;
    var $_idx = $29 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $30 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($30) {
      var $end_0 = $9;
      var $begin_0 = $26;
      __label__ = 19;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $32 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd($cx, $29, $d);
    if ($32) {
      __label__ = 13;
      break;
    } else {
      var $_1 = 0;
      __label__ = 36;
      break;
    }
   case 13:
    var $34 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    if ($34 < 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    var $37 = $34 + $16;
    tempDoubleF64[0] = $37, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    if ($37 < 0) {
      __label__ = 15;
      break;
    } else {
      var $44 = $37;
      __label__ = 18;
      break;
    }
   case 15:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $44 = 0;
    __label__ = 18;
    break;
   case 16:
    if ($34 > $16) {
      __label__ = 17;
      break;
    } else {
      var $44 = $34;
      __label__ = 18;
      break;
    }
   case 17:
    tempDoubleF64[0] = $16, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $44 = $16;
    __label__ = 18;
    break;
   case 18:
    var $44;
    var $45 = $44 >= 0 ? Math.floor($44) : Math.ceil($44);
    var $end_0 = $45;
    var $begin_0 = $26;
    __label__ = 19;
    break;
   case 19:
    var $begin_0;
    var $end_0;
    var $begin_1 = $begin_0 >>> 0 > $end_0 >>> 0 ? $end_0 : $begin_0;
    var $_idx1_val = HEAP32[$3 + 4 >> 2];
    var $48 = __ZNK8JSObject12isDenseArrayEv($_idx1_val);
    if ($48) {
      __label__ = 20;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 20:
    var $50 = __ZN8JSObject30getDenseArrayInitializedLengthEv($3);
    if ($end_0 >>> 0 > $50 >>> 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $53 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject($3);
    if (($53 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 22:
    var $56 = $end_0 - $begin_1 | 0;
    var $_idx2_val = HEAP32[$3 + 32 >> 2];
    var $57 = __ZN8JSObject21getDenseArrayElementsEv($_idx2_val);
    var $58 = $57 + ($begin_1 << 3) | 0;
    var $59 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($cx, $56, $58);
    if (($59 | 0) == 0) {
      var $_1 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    __ZL17TryReuseArrayTypeP8JSObjectS0_($3, $59);
    var $_idx3_val = HEAP32[$3 + 8 >> 2];
    var $62 = __ZN8JSObject18isPackedDenseArrayEv($_idx3_val);
    if ($62) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    __ZN8JSObject23markDenseArrayNotPackedEP9JSContext($59, $cx);
    __label__ = 25;
    break;
   case 25:
    __ZN2JS5Value9setObjectER8JSObject($vp, $59);
    var $_1 = 1;
    __label__ = 36;
    break;
   case 26:
    var $67 = __ZN2js22NewDenseAllocatedArrayEP9JSContextjP8JSObject($cx, $end_0 - $begin_1 | 0);
    if (($67 | 0) == 0) {
      var $_1 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZL17TryReuseArrayTypeP8JSObjectS0_($3, $67);
    __ZN2JS5Value9setObjectER8JSObject($vp, $67);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $70 = $cx + 52 | 0;
    var $slot_0 = $begin_1;
    __label__ = 28;
    break;
   case 28:
    var $slot_0;
    if ($slot_0 >>> 0 < $end_0 >>> 0) {
      __label__ = 29;
      break;
    } else {
      var $_0 = 1;
      __label__ = 35;
      break;
    }
   case 29:
    if ((HEAP32[HEAP32[$70 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $79 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($79 | 0) == 0) {
      var $_0 = 0;
      __label__ = 35;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $81 = $slot_0 >>> 0;
    var $82 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $83 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $3, $81, $hole, $82);
    if (($83 | 0) == 0) {
      var $_0 = 0;
      __label__ = 35;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 33:
    var $90 = ($slot_0 - $begin_1 | 0) >>> 0;
    var $91 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $92 = __ZL15SetArrayElementP9JSContextP8JSObjectdRKN2JS5ValueE($cx, $67, $90, $91);
    if (($92 | 0) == 0) {
      var $_0 = 0;
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $slot_0 = $slot_0 + 1 | 0;
    __label__ = 28;
    break;
   case 35:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 36;
    break;
   case 36:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11array_sliceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL13array_indexOfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL19array_indexOfHelperP9JSContextijPN2JS5ValueE($cx, 0, $argc, $vp);
  return $1;
}

function __ZL17array_lastIndexOfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL19array_indexOfHelperP9JSContextijPN2JS5ValueE($cx, 1, $argc, $vp);
  return $1;
}

function __ZL13array_forEachP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL11array_extraP9JSContext14ArrayExtraModejPN2JS5ValueE($cx, 0, $argc, $vp);
  return $1;
}

function __ZL9array_mapP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL11array_extraP9JSContext14ArrayExtraModejPN2JS5ValueE($cx, 3, $argc, $vp);
  return $1;
}

function __ZL12array_reduceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL11array_extraP9JSContext14ArrayExtraModejPN2JS5ValueE($cx, 1, $argc, $vp);
  return $1;
}

function __ZL17array_reduceRightP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL11array_extraP9JSContext14ArrayExtraModejPN2JS5ValueE($cx, 2, $argc, $vp);
  return $1;
}

function __ZL12array_filterP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL11array_extraP9JSContext14ArrayExtraModejPN2JS5ValueE($cx, 4, $argc, $vp);
  return $1;
}

function __ZL10array_someP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL11array_extraP9JSContext14ArrayExtraModejPN2JS5ValueE($cx, 5, $argc, $vp);
  return $1;
}

function __ZL11array_everyP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL11array_extraP9JSContext14ArrayExtraModejPN2JS5ValueE($cx, 6, $argc, $vp);
  return $1;
}

function __ZL13array_isArrayP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($argc | 0) == 0) {
      var $13 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx = $vp + 16 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $3 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $13 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $5 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $_idx3_val = HEAP32[$5 + 4 >> 2];
    var $6 = __ZNK8JSObject7isArrayEv($_idx3_val);
    if ($6) {
      var $13 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZNK8JSObject9isWrapperEv($5);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      var $13 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $10 = __ZN8JSObject6unwrapEPj($5, 0);
    var $_idx2_val = HEAP32[$10 + 4 >> 2];
    var $11 = __ZNK8JSObject7isArrayEv($_idx2_val);
    var $13 = $11;
    __label__ = 6;
    break;
   case 6:
    var $13;
    __ZN2JS5Value10setBooleanEb($vp, $13);
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z8js_ArrayP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, 3);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $vp + 16 | 0;
    if (($argc | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      var $_pre_phi = $5;
      __label__ = 4;
      break;
    }
   case 3:
    var $_idx2 = $5 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    var $7 = __ZNK2JS5Value8isNumberEv($_idx2_val$0, $_idx2_val$1);
    if ($7) {
      __label__ = 10;
      break;
    } else {
      var $_pre_phi = $5;
      __label__ = 4;
      break;
    }
   case 4:
    var $_pre_phi;
    var $8 = __ZL14InitArrayTypesP9JSContextPN2js5types10TypeObjectEPKN2JS5ValueEj($cx, $1, $_pre_phi, $argc);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 5:
    if (($argc | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $12 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($cx);
    var $16 = $12;
    __label__ = 8;
    break;
   case 7:
    var $14 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($cx, $argc, $_pre_phi);
    var $16 = $14;
    __label__ = 8;
    break;
   case 8:
    var $16;
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($16, $1);
    __ZN2JS5Value9setObjectER8JSObject($vp, $16);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 10:
    var $20 = __ZNK2JS5Value7isInt32Ev($_idx2_val$0, $_idx2_val$1);
    if ($20) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $22 = __ZNK2JS5Value7toInt32Ev($_idx2_val$0, $_idx2_val$1);
    if (($22 | 0) < 0) {
      __label__ = 12;
      break;
    } else {
      var $length_0 = $22;
      __label__ = 15;
      break;
    }
   case 12:
    _JS_ReportErrorNumber($cx, 4, 152, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 19;
    break;
   case 13:
    var $26 = __ZNK2JS5Value8toDoubleEv($5);
    var $27 = __Z21js_DoubleToECMAUint32d($26);
    if ($26 != $27 >>> 0) {
      __label__ = 14;
      break;
    } else {
      var $length_0 = $27;
      __label__ = 15;
      break;
    }
   case 14:
    _JS_ReportErrorNumber($cx, 4, 152, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 19;
    break;
   case 15:
    var $length_0;
    var $32 = __ZN2js24NewDenseUnallocatedArrayEP9JSContextjP8JSObject($cx, $length_0);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($32, $1);
    var $_idx3_val = HEAP32[$32 + 24 >> 2];
    var $35 = __ZNK8JSObject14getArrayLengthEv($_idx3_val);
    if (($35 | 0) < 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    __ZN8JSObject14setArrayLengthEP9JSContextj($32, $cx, $35);
    __label__ = 18;
    break;
   case 18:
    __ZN2JS5Value9setObjectER8JSObject($vp, $32);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z8js_ArrayP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pc = __stackBase__;
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $cx + 60 | 0;
    var $4 = __ZNK2js12ContextStack13currentScriptEPPh($3, $pc);
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = HEAP32[$pc >> 2];
    var $8 = __ZN2js5types10TypeScript10InitObjectEP9JSContextP8JSScriptPKh10JSProtoKey($cx, $4, $7, $key);
    var $_0 = $8;
    __label__ = 5;
    break;
   case 4:
    var $10 = __ZN2js5types16GetTypeNewObjectEP9JSContext10JSProtoKey($cx, $key);
    var $_0 = $10;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14InitArrayTypesP9JSContextPN2js5types10TypeObjectEPKN2JS5ValueEj($cx, $type, $vector, $count) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $2 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 1;
      __label__ = 11;
      break;
    }
   case 2:
    var $type_idx_val = HEAP32[$type + 12 >> 2];
    var $4 = __ZN2js5types10TypeObject17unknownPropertiesEv($type_idx_val);
    if ($4) {
      var $_1 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    var $6 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($type, $cx, 2, 1);
    if (($6 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($count | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_0 = $1 | 0;
    var $i_02 = 0;
    __label__ = 6;
    break;
   case 6:
    var $i_02;
    var $_idx1 = $vector + ($i_02 << 3) | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $9 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx1_val$0, $_idx1_val$1);
    if ($9) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2js5types12GetValueTypeEP9JSContextRKN2JS5ValueE($1, $_idx1_val$0, $_idx1_val$1);
    var $_0_val = HEAP32[$_0 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($6, $cx, $_0_val);
    __label__ = 8;
    break;
   case 8:
    var $12 = $i_02 + 1 | 0;
    if (($12 | 0) == ($count | 0)) {
      __label__ = 9;
      break;
    } else {
      var $i_02 = $12;
      __label__ = 6;
      break;
    }
   case 9:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    var $_1 = 1;
    __label__ = 11;
    break;
   case 10:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    var $_1 = 0;
    __label__ = 11;
    break;
   case 11:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($cx) {
  var $1 = __ZN2jsL8NewArrayILb0EEEP8JSObjectP9JSContextjS2_($cx, 0);
  return $1;
}

function __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($cx, $length, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL8NewArrayILb1EEEP8JSObjectP9JSContextjS2_($cx, $length);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $4 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = ($vp | 0) != 0 ? $length : 0;
    __ZN8JSObject30setDenseArrayInitializedLengthEj($1, $7);
    __label__ = 4;
    break;
   case 4:
    if (($vp | 0) == 0) {
      var $_0 = $1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN8JSObject22copyDenseArrayElementsEjPKN2JS5ValueEj($1, 0, $vp, $length);
    var $_0 = $1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js24NewDenseUnallocatedArrayEP9JSContextjP8JSObject($cx, $length) {
  var $1 = __ZN2jsL8NewArrayILb0EEEP8JSObjectP9JSContextjS2_($cx, $length);
  return $1;
}

function __ZN8JSObject14setArrayLengthEP9JSContextj($this, $cx, $length) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($length | 0) < 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj($cx, $this, 196608);
    var $8 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $9 = __ZL12ATOM_TO_JSIDP6JSAtom354($8);
    __ZN2js5types4Type10DoubleTypeEv($1);
    var $_0_val = HEAP32[$1 >> 2];
    __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiNS0_4TypeE($cx, $this, $9, $_0_val);
    __label__ = 3;
    break;
   case 3:
    var $11 = $length;
    __ZN8JSObject10setPrivateEPv($this, $11);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_InitArrayClassP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZN8JSObject8asGlobalEv($1);
    var $3 = $2;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($2, $4, __ZN2js14SlowArrayClassE);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZL17AddLengthPropertyP9JSContextP8JSObject($cx, $6);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    __ZN8JSObject14setArrayLengthEP9JSContextj($6, $cx, 0);
    var $15 = HEAP32[HEAP32[$cx + 52 >> 2] + 210032 >> 2];
    var $16 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($2, $4, 66, __ZN2js10ArrayClassE, $15, 1);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($6, $cx, 0, 1);
    var $20 = $16;
    var $21 = $16 | 0;
    var $22 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $21, $5);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $24 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, 0, __ZL13array_methods);
    if ($24) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $26 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $21, 0, __ZL20array_static_methods);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $28 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $3, 3, $20, $6);
    var $_ = $28 ? $6 : 0;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $global, $key, $ctor, $proto) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __stackBase__ + 40;
    var $11 = HEAP32[HEAP32[$cx + 52 >> 2] + 210020 + ($key << 2) >> 2] | 0;
    var $12 = __ZL12ATOM_TO_JSIDP6JSAtom354($11);
    var $13 = $global | 0;
    __ZN2JSL11ObjectValueER8JSObject383($1, $ctor);
    var $_idx4 = $1 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($13, $key, $_idx4_val$0, $_idx4_val$1);
    var $14 = $key + 37 | 0;
    __ZN2JSL11ObjectValueER8JSObject383($2, $proto);
    var $_idx3 = $2 | 0;
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($13, $14, $_idx3_val$0, $_idx3_val$1);
    __ZN2JSL11ObjectValueER8JSObject383($3, $ctor);
    __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiRKN2JS5ValueE($cx, $13, $12, $3);
    var $15 = $key + 74 | 0;
    var $16 = $global;
    var $17 = $cx;
    var $18 = __ZN8JSObject15addDataPropertyEP9JSContextijj($16, $17, $12, $15, 0);
    if (($18 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JSL14UndefinedValueEv351($4);
    var $_idx2 = $4 | 0;
    var $st$2$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$2$1 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($13, $key, $_idx2_val$0, $_idx2_val$1);
    __ZN2JSL14UndefinedValueEv351($5);
    var $_idx1 = $5 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($13, $14, $_idx1_val$0, $_idx1_val$1);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL11ObjectValueER8JSObject383($6, $ctor);
    var $_idx = $6 | 0;
    var $st$2$0 = $_idx | 0;
    var $_idx_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAP32[$st$2$1 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($13, $15, $_idx_val$0, $_idx_val$1);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_["X"] = 1;

function __ZN2jsL8NewArrayILb0EEEP8JSObjectP9JSContextjS2_($cx, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL17GuessObjectGCKindEjb($length);
    var $2 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE375($cx, __ZN2js10ArrayClassE, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN8JSObject14setArrayLengthEP9JSContextj($2, $cx, $length);
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $5 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($5) {
      var $_0 = $2;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject23markDenseArrayNotPackedEP9JSContext($2, $cx);
    __ZN8JSObject23backfillDenseArrayHolesEP9JSContext($2, $cx);
    var $_0 = $2;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js22NewDenseAllocatedArrayEP9JSContextjP8JSObject($cx, $length) {
  var $1 = __ZN2jsL8NewArrayILb1EEEP8JSObjectP9JSContextjS2_($cx, $length);
  return $1;
}

function __ZN2jsL8NewArrayILb1EEEP8JSObjectP9JSContextjS2_($cx, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL17GuessObjectGCKindEjb($length);
    var $2 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE375($cx, __ZN2js10ArrayClassE, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN8JSObject14setArrayLengthEP9JSContextj($2, $cx, $length);
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $5 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject23markDenseArrayNotPackedEP9JSContext($2, $cx);
    __ZN8JSObject23backfillDenseArrayHolesEP9JSContext($2, $cx);
    __label__ = 4;
    break;
   case 4:
    var $8 = __ZN8JSObject11ensureSlotsEP9JSContextj($2, $cx, $length);
    var $_ = $8 ? $2 : 0;
    var $_0 = $_;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject22copyDenseArrayElementsEjPKN2JS5ValueEj($this, $dstStart, $src, $count) {
  var $1 = $this;
  __ZN8JSObject13copySlotRangeEjPKN2JS5ValueEj($1, $dstStart, $src, $count);
  return;
}

function __ZN2js17NewSlowEmptyArrayEP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_373($cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZL17AddLengthPropertyP9JSContextP8JSObject($cx, $1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN8JSObject14setArrayLengthEP9JSContextj($1, $cx, 0);
    var $_0 = $1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_373($cx) {
  var $3 = HEAPU32[__ZN2js14SlowArrayClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb374($3, 0);
  var $5 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE375($cx, __ZN2js14SlowArrayClassE, $4);
  return $5;
}

function __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE375($cx, $clasp, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = 0;
    var $2 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_376($cx, $clasp, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    var $_pr = HEAP32[$1 >> 2];
    var $4 = ($_pr | 0) == 0;
    if ($4) {
      var $7 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($_pr, $cx, 0, 0);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      var $7 = $5;
      __label__ = 4;
      break;
    }
   case 4:
    var $7;
    var $8 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ($4) {
      var $14 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx_val = HEAP32[$_pr + 20 >> 2];
    var $12 = __ZNK8JSObject9getParentEv($_idx_val);
    var $14 = $12;
    __label__ = 7;
    break;
   case 7:
    var $14;
    var $15 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($8, $clasp, $7, $14, 0, $15);
    var $clasp_idx_val = HEAP32[$clasp + 4 >> 2];
    var $16 = __ZNK2js5Class8isNativeEv($clasp_idx_val);
    if ($16) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $18 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE359($cx, $8, $clasp, $7, $kind);
    if ($18) {
      var $_0 = $8;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_0 = 0;
    __label__ = 11;
    break;
   case 10:
    __ZN8JSObject21setSharedNonNativeMapEv($8);
    var $_0 = $8;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_376($cx, $clasp, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $clasp_idx_val = HEAP32[$clasp + 4 >> 2];
    var $1 = __ZN2jsL16GetClassProtoKeyEPNS_5ClassE382($clasp_idx_val);
    var $2 = $cx;
    var $3 = $proto;
    var $4 = $clasp;
    var $5 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, 0, $1, $3, $4);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$proto >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, 0, 1, $3, 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types13TypeObjectKey6getKeyEPS1_($obj) {
  return $obj;
}

function _JSID_IS_INT387($iden) {
  return $iden & 1;
}

function _JSID_IS_STRING388($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function __ZNK2js5types7TypeSet7unknownEv($this_0_0_val) {
  return ($this_0_0_val & 65536 | 0) != 0;
}

function __ZNK2js5types4Type9isUnknownEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 32;
}

function __ZNK2js5types7TypeSet9baseFlagsEv($this_0_0_val) {
  return $this_0_0_val & 65791;
}

function __ZNK2js5types4Type11isPrimitiveEv($this_0_0_val) {
  return $this_0_0_val >>> 0 < 7;
}

function __ZN2js5types17PrimitiveTypeFlagE11JSValueType($type) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $type & 255;
    if (($1 | 0) == 6) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 3) {
      __label__ = 3;
      break;
    } else if (($1 | 0) == 1) {
      __label__ = 4;
      break;
    } else if (($1 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($1 | 0) == 5) {
      __label__ = 6;
      break;
    } else if (($1 | 0) == 4) {
      __label__ = 7;
      break;
    } else if (($1 | 0) == 2) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $_0 = 2;
    __label__ = 9;
    break;
   case 3:
    var $_0 = 4;
    __label__ = 9;
    break;
   case 4:
    var $_0 = 8;
    __label__ = 9;
    break;
   case 5:
    var $_0 = 16;
    __label__ = 9;
    break;
   case 6:
    var $_0 = 32;
    __label__ = 9;
    break;
   case 7:
    var $_0 = 64;
    __label__ = 9;
    break;
   case 8:
    var $_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5types4Type9primitiveEv($this_0_0_val) {
  return $this_0_0_val & 255;
}

function __ZNK2js5types4Type11isAnyObjectEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 7;
}

function __ZNK2js5types7TypeSet15baseObjectCountEv($this_0_0_val) {
  return $this_0_0_val >>> 8 & 255;
}

function __ZNK2js5types4Type9objectKeyEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js5types4Type10typeObjectEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js5types4Type8isObjectEv($this_0_0_val) {
  return $this_0_0_val >>> 0 > 32;
}

function __ZN2js5types13TypeObjectKey7keyBitsEPS1_($obj) {
  return $obj;
}

function _JSVAL_EXTRACT_NON_DOUBLE_TYPE_IMPL($l_0$0, $l_0$1) {
  return $l_0$1 & 255 & 15;
}

function __ZN2js5types7TypeSet18setBaseObjectCountEj($this, $count) {
  var $1 = $this | 0;
  var $5 = HEAP32[$1 >> 2] & -65281 | $count << 8;
  HEAP32[$1 >> 2] = $5;
  return;
}

function __ZN2js5types10TypeObject20setBasePropertyCountEj($this, $count) {
  var $1 = $this + 12 | 0;
  var $5 = HEAP32[$1 >> 2] & -65521 | $count << 4;
  HEAP32[$1 >> 2] = $5;
  return;
}

function __ZN2jsL17GuessObjectGCKindEjb($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($numSlots | 0) == 0) {
      var $_0 = 6;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2js2gcL15GetGCObjectKindEjb374($numSlots, 1);
    var $_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject11ensureSlotsEP9JSContextj($this, $cx, $nslots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 28 >> 2];
    var $1 = __ZNK8JSObject8numSlotsEv($this_idx_val);
    if ($1 >>> 0 < $nslots >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this;
    var $5 = $cx;
    var $6 = __ZN8JSObject9growSlotsEP9JSContextj($4, $5, $nslots);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11ObjectValueER8JSObject383($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiRKN2JS5ValueE($cx, $obj, $id, $value) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cx_idx = $cx + 232 | 0;
    var $cx_idx_val = HEAP8[$cx_idx];
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $id;
      var $cx_idx1_val = $cx_idx_val;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js5types10MakeTypeIdEP9JSContexti($cx, $id);
    var $_0 = $3;
    var $cx_idx1_val = HEAP8[$cx_idx];
    __label__ = 3;
    break;
   case 3:
    var $cx_idx1_val;
    var $_0;
    var $5 = __ZN2js5types18TrackPropertyTypesEP9JSContextP8JSObjecti($cx_idx1_val, $obj, $_0);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $obj_idx_val = HEAP32[$obj + 36 >> 2];
    var $7 = __ZNK8JSObject4typeEv($obj_idx_val);
    var $value_idx = $value | 0;
    var $value_idx_val$0 = HEAP32[$value_idx >> 2];
    var $value_idx_val$1 = HEAP32[$value_idx + 4 >> 2];
    __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextiRKN2JS5ValueE($7, $cx, $_0, $value_idx_val$0, $value_idx_val$1);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5typesL15HashSetCapacityEj385($count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 < 9) {
      var $_0 = 8;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $count | 1;
    var $4 = _llvm_ctlz_i32($3);
    var $_0 = 1 << 33 - $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5typesL7HashKeyIiNS0_8PropertyEEEjT_386($v) {
  var $1 = __ZN2js5types8Property7keyBitsEi($v);
  return ((($1 & 255 ^ 84696351) * 16777619 ^ $1 >>> 8 & 255) * 16777619 ^ $1 >>> 16 & 255) * 16777619 ^ $1 >>> 24;
}

function __ZN2js5types4Type10DoubleTypeEv($agg_result) {
  __ZN2js5types4TypeC1Ej($agg_result, 0);
  return;
}

function __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($this, $cx) {
  __ZN2js5types22AutoEnterTypeInferenceC2EP9JSContextb($this, $cx);
  return;
}

function __ZN2js5types10TypeObject11getPropertyEP9JSContextib($this, $cx, $id, $assign) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $propertyCount = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $this_idx_val = HEAP32[$this + 12 >> 2];
    var $2 = __ZNK2js5types10TypeObject17basePropertyCountEv($this_idx_val);
    HEAP32[$propertyCount >> 2] = $2;
    var $3 = $cx + 56 | 0;
    var $4 = HEAP32[$3 >> 2];
    var $5 = $this + 24 | 0;
    var $6 = __ZN2js5typesL13HashSetInsertIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_($4, $5, $propertyCount, $id);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = HEAP32[$3 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($10, $cx);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 3:
    var $12 = HEAP32[$6 >> 2];
    if (($12 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $22 = $12;
      __label__ = 8;
      break;
    }
   case 4:
    var $15 = HEAP32[$propertyCount >> 2];
    __ZN2js5types10TypeObject20setBasePropertyCountEj($this, $15);
    var $16 = __ZN2js5types10TypeObject11addPropertyEP9JSContextiPPNS0_8PropertyE($this, $cx, $id, $6);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 5:
    if (($15 | 0) == 4095) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = HEAP32[$6 >> 2];
    __label__ = 8;
    break;
   case 7:
    __ZN2js5types10TypeObject11markUnknownEP9JSContext($this, $cx);
    var $20 = __ZN2js5types7TypeSet4makeEP9JSContextPKc($cx);
    __ZN2js5types4Type11UnknownTypeEv($1);
    var $_01_val = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($20, $cx, $_01_val);
    var $_0 = $20;
    __label__ = 10;
    break;
   case 8:
    var $22;
    var $23 = $22 + 4 | 0;
    if ($assign) {
      __label__ = 9;
      break;
    } else {
      var $_0 = $23;
      __label__ = 10;
      break;
    }
   case 9:
    __ZN2js5types7TypeSet14setOwnPropertyEP9JSContextb($23, $cx, 0);
    var $_0 = $23;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types12GetValueTypeEP9JSContextRKN2JS5ValueE($agg_result, $val_0_0_0_val$0, $val_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isDoubleEv($val_0_0_0_val$0, $val_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js5types4Type10DoubleTypeEv($agg_result);
    __label__ = 6;
    break;
   case 3:
    var $4 = __ZNK2JS5Value8isObjectEv($val_0_0_0_val$0, $val_0_0_0_val$1);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $6 = __ZNK2JS5Value8toObjectEv($val_0_0_0_val$0, $val_0_0_0_val$1);
    __ZN2js5types4Type10ObjectTypeEP8JSObject($agg_result, $6);
    __label__ = 6;
    break;
   case 5:
    var $8 = __ZNK2JS5Value20extractNonDoubleTypeEv($val_0_0_0_val$0, $val_0_0_0_val$1);
    __ZN2js5types4Type13PrimitiveTypeE11JSValueType($agg_result, $8);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($this, $cx, $type_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $objectCount = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $this_idx5 = $this | 0;
    var $this_idx5_val = HEAP32[$this_idx5 >> 2];
    var $2 = __ZNK2js5types7TypeSet7unknownEv($this_idx5_val);
    if ($2) {
      __label__ = 21;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2js5types4Type9isUnknownEv($type_0);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZNK2js5types7TypeSet9baseFlagsEv($this_idx5_val);
    var $9 = ($6 ^ -65537) & $this_idx5_val | 65536;
    HEAP32[$this_idx5 >> 2] = $9;
    __ZN2js5types7TypeSet12clearObjectsEv($this);
    var $type_02_0 = $type_0;
    __label__ = 18;
    break;
   case 4:
    var $11 = __ZNK2js5types4Type11isPrimitiveEv($type_0);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $13 = __ZNK2js5types4Type9primitiveEv($type_0);
    var $14 = __ZN2js5types17PrimitiveTypeFlagE11JSValueType($13);
    if (($this_idx5_val & $14 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 6:
    var $_ = ($14 | 0) == 16 ? $14 | 8 : $14;
    var $20 = $_ | $this_idx5_val;
    HEAP32[$this_idx5 >> 2] = $20;
    var $type_02_0 = $type_0;
    __label__ = 18;
    break;
   case 7:
    if (($this_idx5_val & 128 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 8:
    var $25 = __ZNK2js5types4Type11isAnyObjectEv($type_0);
    if ($25) {
      __label__ = 17;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $27 = __ZNK2js5types7TypeSet15baseObjectCountEv($this_idx5_val);
    HEAP32[$objectCount >> 2] = $27;
    var $28 = __ZNK2js5types4Type9objectKeyEv($type_0);
    var $29 = $cx + 56 | 0;
    var $30 = HEAP32[$29 >> 2];
    var $31 = $this + 4 | 0;
    var $32 = __ZN2js5typesL13HashSetInsertIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_($30, $31, $objectCount, $28);
    if (($32 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $36 = HEAP32[$29 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($36, $cx);
    __label__ = 21;
    break;
   case 11:
    if ((HEAP32[$32 >> 2] | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 12:
    HEAP32[$32 >> 2] = $28;
    var $41 = HEAPU32[$objectCount >> 2];
    __ZN2js5types7TypeSet18setBaseObjectCountEj($this, $41);
    if (($41 | 0) == 255) {
      __label__ = 17;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $44 = __ZNK2js5types4Type12isTypeObjectEv($type_0);
    if ($44) {
      __label__ = 14;
      break;
    } else {
      var $type_02_0 = $type_0;
      __label__ = 18;
      break;
    }
   case 14:
    var $46 = __ZNK2js5types4Type10typeObjectEv($type_0);
    var $_idx_val = HEAP32[$46 + 12 >> 2];
    var $47 = __ZN2js5types10TypeObject17unknownPropertiesEv($_idx_val);
    if ($47) {
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    if ($41 >>> 0 > 1) {
      __label__ = 16;
      break;
    } else {
      var $type_02_0 = $type_0;
      __label__ = 18;
      break;
    }
   case 16:
    var $51 = $41 - 1 | 0;
    var $53 = $46 + 20 | 0;
    var $55 = HEAP32[$53 >> 2] + $51 * $51 | 0;
    HEAP32[$53 >> 2] = $55;
    if ($55 >>> 0 > 1999) {
      __label__ = 17;
      break;
    } else {
      var $type_02_0 = $type_0;
      __label__ = 18;
      break;
    }
   case 17:
    __ZN2js5types4Type13AnyObjectTypeEv($1);
    var $59 = HEAP32[$1 >> 2];
    var $61 = HEAP32[$this_idx5 >> 2] | 128;
    HEAP32[$this_idx5 >> 2] = $61;
    __ZN2js5types7TypeSet12clearObjectsEv($this);
    var $type_02_0 = $59;
    __label__ = 18;
    break;
   case 18:
    var $type_02_0;
    var $constraint_01 = HEAP32[$this + 8 >> 2];
    var $65 = $cx + 56 | 0;
    var $67 = HEAP32[$65 >> 2] + 376 | 0;
    if (($constraint_01 | 0) == 0) {
      var $_lcssa = $67;
      __label__ = 20;
      break;
    } else {
      var $constraint_02 = $constraint_01;
      var $68 = $67;
      __label__ = 19;
      break;
    }
   case 19:
    var $68;
    var $constraint_02;
    __ZN2js5types15TypeCompartment10addPendingEP9JSContextPNS0_14TypeConstraintEPNS0_7TypeSetENS0_4TypeE($68, $cx, $constraint_02, $this, $type_02_0);
    var $constraint_0 = HEAP32[$constraint_02 + 4 >> 2];
    var $72 = HEAP32[$65 >> 2] + 376 | 0;
    if (($constraint_0 | 0) == 0) {
      var $_lcssa = $72;
      __label__ = 20;
      break;
    } else {
      var $constraint_02 = $constraint_0;
      var $68 = $72;
      __label__ = 19;
      break;
    }
   case 20:
    var $_lcssa;
    __ZN2js5types15TypeCompartment14resolvePendingEP9JSContext($_lcssa, $cx);
    __label__ = 21;
    break;
   case 21:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE["X"] = 1;

function __ZN2js5types22AutoEnterTypeInferenceD1Ev($this) {
  __ZN2js5types22AutoEnterTypeInferenceD2Ev($this);
  return;
}

function __ZN2js5types22AutoEnterTypeInferenceD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP8[$this + 4 | 0] & 1;
    var $4 = $this | 0;
    HEAP8[HEAP32[HEAP32[$4 >> 2] + 56 >> 2] + 372 | 0] = $3;
    var $11 = HEAP8[$this + 5 | 0] & 1;
    HEAP8[HEAP32[HEAP32[$4 >> 2] + 56 >> 2] + 373 | 0] = $11;
    var $16 = HEAP32[$4 >> 2];
    var $18 = HEAP32[$16 + 56 >> 2];
    if ((HEAP8[$18 + 373 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $24 = $18 + 376 | 0;
    if ((HEAP8[$18 + 384 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js5types15TypeCompartment9nukeTypesEP9JSContext($24, $16);
    __label__ = 6;
    break;
   case 4:
    if ((HEAP32[$18 + 388 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js5types15TypeCompartment24processPendingRecompilesEP9JSContext($24);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet12clearObjectsEv($this) {
  __ZN2js5types7TypeSet18setBaseObjectCountEj($this, 0);
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js5typesL13HashSetInsertIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_($compartment, $values, $count, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[$count >> 2];
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    HEAP32[$count >> 2] = 1;
    var $_0 = $values;
    __label__ = 15;
    break;
   case 3:
    var $5 = HEAP32[$values >> 2];
    var $6 = $5;
    var $7 = __ZN2js5types13TypeObjectKey6getKeyEPS1_($6);
    if (($7 | 0) == ($key | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = $values;
    __label__ = 15;
    break;
   case 5:
    var $12 = $compartment + 344 | 0;
    var $13 = __ZN2js10ArenaArrayIPNS_5types13TypeObjectKeyEEEPT_R11JSArenaPoolj($12, 8);
    HEAP32[$values >> 2] = $13;
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$values >> 2] = $5;
    var $_0 = 0;
    __label__ = 15;
    break;
   case 7:
    __ZN2jsL7PodZeroIPNS_5types13TypeObjectKeyEEEvPT_j($13, 8);
    var $18 = HEAP32[$count >> 2] + 1 | 0;
    HEAP32[$count >> 2] = $18;
    var $19 = HEAP32[$values >> 2];
    HEAP32[$19 >> 2] = $6;
    var $_0 = HEAP32[$values >> 2] + 4 | 0;
    __label__ = 15;
    break;
   case 8:
    if ($1 >>> 0 < 9) {
      var $i_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 9:
    var $i_0;
    if ($i_0 >>> 0 < $1 >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $27 = HEAP32[$values >> 2] + ($i_0 << 2) | 0;
    var $28 = HEAP32[$27 >> 2];
    var $29 = __ZN2js5types13TypeObjectKey6getKeyEPS1_($28);
    if (($29 | 0) == ($key | 0)) {
      var $_0 = $27;
      __label__ = 15;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 9;
    break;
   case 12:
    if ($1 >>> 0 < 8) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    HEAP32[$count >> 2] = $1 + 1 | 0;
    var $_0 = HEAP32[$values >> 2] + ($1 << 2) | 0;
    __label__ = 15;
    break;
   case 14:
    var $40 = __ZN2js5typesL16HashSetInsertTryIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_($compartment, $values, $count, $key);
    var $_0 = $40;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5typesL13HashSetInsertIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_["X"] = 1;

function __ZNK2js5types4Type12isTypeObjectEv($this_0_0_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5types4Type8isObjectEv($this_0_0_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = ($this_0_0_val & 1 | 0) == 0;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types4Type13AnyObjectTypeEv($agg_result) {
  __ZN2js5types4TypeC1Ej($agg_result, 7);
  return;
}

function __ZN2js5types15TypeCompartment10addPendingEP9JSContextPNS0_14TypeConstraintEPNS0_7TypeSetENS0_4TypeE($this, $cx, $constraint, $source, $type_0) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 44 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == (HEAP32[$this + 48 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      var $8 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js5types15TypeCompartment16growPendingArrayEP9JSContext($this, $cx);
    var $8 = HEAP32[$1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $8;
    HEAP32[$1 >> 2] = $8 + 1 | 0;
    var $11 = HEAP32[$this + 40 >> 2];
    var $12 = $11 + $8 * 12 | 0;
    HEAP32[$12 >> 2] = $constraint;
    var $13 = $11 + $8 * 12 + 4 | 0;
    HEAP32[$13 >> 2] = $source;
    var $14 = $11 + $8 * 12 + 8 | 0;
    HEAP32[$14 >> 2] = $type_0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15TypeCompartment14resolvePendingEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 52 | 0;
    if ((HEAP8[$2] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    HEAP8[$2] = 1;
    var $7 = $this + 44 | 0;
    var $8 = HEAP32[$7 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $this + 40 | 0;
    var $11 = $1 | 0;
    var $13 = $8;
    __label__ = 4;
    break;
   case 4:
    var $13;
    var $14 = $13 - 1 | 0;
    HEAP32[$7 >> 2] = $14;
    var $15 = HEAP32[$10 >> 2];
    var $18 = HEAP32[$15 + $14 * 12 >> 2];
    var $21 = HEAP32[HEAP32[$18 >> 2] >> 2];
    var $23 = HEAP32[$15 + $14 * 12 + 4 >> 2];
    var $24 = HEAP32[$15 + $14 * 12 + 8 >> 2];
    HEAP32[$11 >> 2] = $24;
    FUNCTION_TABLE[$21]($18, $cx, $23, $1);
    var $25 = HEAP32[$7 >> 2];
    if (($25 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $13 = $25;
      __label__ = 4;
      break;
    }
   case 5:
    HEAP8[$2] = 0;
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10ArenaArrayIPNS_5types13TypeObjectKeyEEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + ($count << 2) & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodZeroIPNS_5types13TypeObjectKeyEEEvPT_j($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem << 2;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js5typesL16HashSetInsertTryIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_($compartment, $values, $count, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$count >> 2];
    var $2 = __ZN2js5typesL15HashSetCapacityEj385($1);
    var $3 = __ZN2js5typesL7HashKeyIPNS0_13TypeObjectKeyES2_EEjT_($key);
    var $4 = $2 - 1 | 0;
    var $5 = $3 & $4;
    if (($1 | 0) == 8) {
      var $insertpos_1 = $5;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$values >> 2];
    var $insertpos_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $insertpos_0;
    var $9 = $7 + ($insertpos_0 << 2) | 0;
    var $10 = HEAP32[$9 >> 2];
    if (($10 | 0) == 0) {
      var $insertpos_1 = $insertpos_0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = __ZN2js5types13TypeObjectKey6getKeyEPS1_($10);
    if (($13 | 0) == ($key | 0)) {
      var $_0 = $9;
      __label__ = 17;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $insertpos_0 = $insertpos_0 + 1 & $4;
    __label__ = 3;
    break;
   case 6:
    var $insertpos_1;
    var $18 = $1 + 1 | 0;
    HEAP32[$count >> 2] = $18;
    var $19 = __ZN2js5typesL15HashSetCapacityEj385($18);
    if (($19 | 0) == ($2 | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $_0 = HEAP32[$values >> 2] + ($insertpos_1 << 2) | 0;
    __label__ = 17;
    break;
   case 8:
    var $25 = $compartment + 344 | 0;
    var $26 = __ZN2js10ArenaArrayIPNS_5types13TypeObjectKeyEEEPT_R11JSArenaPoolj($25, $19);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2jsL7PodZeroIPNS_5types13TypeObjectKeyEEEvPT_j($26, $19);
    var $_pre = $19 - 1 | 0;
    if (($2 | 0) == 0) {
      var $_pre_phi = $_pre;
      __label__ = 15;
      break;
    } else {
      var $i_013 = 0;
      __label__ = 10;
      break;
    }
   case 10:
    var $i_013;
    var $32 = HEAP32[HEAP32[$values >> 2] + ($i_013 << 2) >> 2];
    if (($32 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $35 = __ZN2js5types13TypeObjectKey6getKeyEPS1_($32);
    var $36 = __ZN2js5typesL7HashKeyIPNS0_13TypeObjectKeyES2_EEjT_($35);
    var $pos_09 = $36 & $_pre;
    var $37 = $26 + ($pos_09 << 2) | 0;
    if ((HEAP32[$37 >> 2] | 0) == 0) {
      var $_lcssa8 = $37;
      __label__ = 13;
      break;
    } else {
      var $pos_010 = $pos_09;
      __label__ = 12;
      break;
    }
   case 12:
    var $pos_010;
    var $pos_0 = $pos_010 + 1 & $_pre;
    var $41 = $26 + ($pos_0 << 2) | 0;
    if ((HEAP32[$41 >> 2] | 0) == 0) {
      var $_lcssa8 = $41;
      __label__ = 13;
      break;
    } else {
      var $pos_010 = $pos_0;
      __label__ = 12;
      break;
    }
   case 13:
    var $_lcssa8;
    HEAP32[$_lcssa8 >> 2] = $32;
    __label__ = 14;
    break;
   case 14:
    var $45 = $i_013 + 1 | 0;
    if (($45 | 0) == ($2 | 0)) {
      var $_pre_phi = $_pre;
      __label__ = 15;
      break;
    } else {
      var $i_013 = $45;
      __label__ = 10;
      break;
    }
   case 15:
    var $_pre_phi;
    HEAP32[$values >> 2] = $26;
    var $insertpos_26 = $3 & $_pre_phi;
    var $46 = $26 + ($insertpos_26 << 2) | 0;
    if ((HEAP32[$46 >> 2] | 0) == 0) {
      var $_0 = $46;
      __label__ = 17;
      break;
    } else {
      var $insertpos_27 = $insertpos_26;
      __label__ = 16;
      break;
    }
   case 16:
    var $insertpos_27;
    var $insertpos_2 = $insertpos_27 + 1 & $_pre_phi;
    var $50 = $26 + ($insertpos_2 << 2) | 0;
    if ((HEAP32[$50 >> 2] | 0) == 0) {
      var $_0 = $50;
      __label__ = 17;
      break;
    } else {
      var $insertpos_27 = $insertpos_2;
      __label__ = 16;
      break;
    }
   case 17:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5typesL16HashSetInsertTryIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_["X"] = 1;

function __ZN2js5typesL7HashKeyIPNS0_13TypeObjectKeyES2_EEjT_($v) {
  var $1 = __ZN2js5types13TypeObjectKey7keyBitsEPS1_($v);
  return ((($1 & 255 ^ 84696351) * 16777619 ^ $1 >>> 8 & 255) * 16777619 ^ $1 >>> 16 & 255) * 16777619 ^ $1 >>> 24;
}

function __ZN2js5types4Type10ObjectTypeEP8JSObject($agg_result, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj_idx_val = HEAP32[$obj + 8 >> 2];
    var $1 = __ZNK8JSObject16hasSingletonTypeEv($obj_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $obj | 1;
    __ZN2js5types4TypeC1Ej($agg_result, $4);
    __label__ = 4;
    break;
   case 3:
    var $obj_idx1_val = HEAP32[$obj + 36 >> 2];
    var $6 = __ZNK8JSObject4typeEv($obj_idx1_val);
    var $7 = $6;
    __ZN2js5types4TypeC1Ej($agg_result, $7);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types4Type13PrimitiveTypeE11JSValueType($agg_result, $type) {
  var $1 = $type & 255;
  __ZN2js5types4TypeC1Ej($agg_result, $1);
  return;
}

function __ZNK2JS5Value20extractNonDoubleTypeEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_EXTRACT_NON_DOUBLE_TYPE_IMPL($this_0_0_0_val$0, $this_0_0_0_val$1);
  return $1;
}

function __ZN2js5typesL13HashSetInsertIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_($compartment, $values, $count, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[$count >> 2];
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    HEAP32[$count >> 2] = 1;
    var $_0 = $values;
    __label__ = 15;
    break;
   case 3:
    var $5 = HEAP32[$values >> 2];
    var $6 = $5;
    var $_idx1_val = HEAP32[$5 >> 2];
    var $7 = __ZN2js5types8Property6getKeyEPS1_($_idx1_val);
    if (($7 | 0) == ($key | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = $values;
    __label__ = 15;
    break;
   case 5:
    var $12 = $compartment + 344 | 0;
    var $13 = __ZN2js10ArenaArrayIPNS_5types8PropertyEEEPT_R11JSArenaPoolj($12, 8);
    HEAP32[$values >> 2] = $13;
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$values >> 2] = $5;
    var $_0 = 0;
    __label__ = 15;
    break;
   case 7:
    __ZN2jsL7PodZeroIPNS_5types8PropertyEEEvPT_j($13, 8);
    var $18 = HEAP32[$count >> 2] + 1 | 0;
    HEAP32[$count >> 2] = $18;
    var $19 = HEAP32[$values >> 2];
    HEAP32[$19 >> 2] = $6;
    var $_0 = HEAP32[$values >> 2] + 4 | 0;
    __label__ = 15;
    break;
   case 8:
    if ($1 >>> 0 < 9) {
      var $i_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 9:
    var $i_0;
    if ($i_0 >>> 0 < $1 >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $27 = HEAP32[$values >> 2] + ($i_0 << 2) | 0;
    var $_idx_val = HEAP32[HEAP32[$27 >> 2] >> 2];
    var $29 = __ZN2js5types8Property6getKeyEPS1_($_idx_val);
    if (($29 | 0) == ($key | 0)) {
      var $_0 = $27;
      __label__ = 15;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 9;
    break;
   case 12:
    if ($1 >>> 0 < 8) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    HEAP32[$count >> 2] = $1 + 1 | 0;
    var $_0 = HEAP32[$values >> 2] + ($1 << 2) | 0;
    __label__ = 15;
    break;
   case 14:
    var $40 = __ZN2js5typesL16HashSetInsertTryIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_($compartment, $values, $count, $key);
    var $_0 = $40;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5typesL13HashSetInsertIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_["X"] = 1;

function __ZN2js5types4Type11UnknownTypeEv($agg_result) {
  __ZN2js5types4TypeC1Ej($agg_result, 32);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js5types22AutoEnterTypeInferenceC2EP9JSContextb($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  var $3 = $cx + 56 | 0;
  var $7 = HEAP8[HEAP32[$3 >> 2] + 372 | 0] & 1;
  HEAP8[$this + 4 | 0] = $7;
  var $12 = HEAP8[HEAP32[$3 >> 2] + 373 | 0] & 1;
  HEAP8[$this + 5 | 0] = $12;
  HEAP8[HEAP32[$3 >> 2] + 372 | 0] = 1;
  HEAP8[HEAP32[$3 >> 2] + 373 | 0] = 1;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js5types17AllocationSiteKey5matchERKS1_S3_($a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$a >> 2] | 0) == (HEAP32[$b >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      var $21 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $9 = HEAPU32[$a + 4 >> 2];
    var $12 = HEAPU32[$b + 4 >> 2];
    if ((($12 ^ $9) & 16777215 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $21 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $21 = ($9 >>> 24 | 0) == ($12 >>> 24 | 0);
    __label__ = 4;
    break;
   case 4:
    var $21;
    return $21;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($e) {
  return $e | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js5types17AllocationSiteKey4hashES1_($key) {
  var __stackBase__ = STACKTOP;
  var tempParam = $key;
  $key = STACKTOP;
  STACKTOP += 8;
  HEAP32[$key >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$key + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $7 = HEAPU32[$key + 4 >> 2];
  var $12 = HEAP32[HEAP32[$key >> 2] >> 2] + ($7 & 16777215) ^ $7 >>> 24;
  STACKTOP = __stackBase__;
  return $12;
}

function __ZN2jsL7PodZeroINS_5types17AllocationSiteKeyEEEvPT_($t) {
  var $1 = $t;
  var $st$3$0 = $1 | 0;
  tempBigInt = 0;
  HEAP8[$st$3$0] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$0 + 1] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$0 + 2] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$0 + 3] = tempBigInt & 255;
  var $st$3$1 = $1 + 4 | 0;
  tempBigInt = 0;
  HEAP8[$st$3$1] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$1 + 1] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$1 + 2] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$1 + 3] = tempBigInt & 255;
  return;
}

function __ZN2js5types7TypeSet14setOwnPropertyEP9JSContextb($this, $cx, $configured) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $configured ? 786432 : 262144;
    var $2 = $this | 0;
    var $3 = HEAP32[$2 >> 2];
    if (($3 & $1 | 0) == ($1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $3 | $1;
    HEAP32[$2 >> 2] = $7;
    var $constraint_01 = HEAP32[$this + 8 >> 2];
    if (($constraint_01 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $constraint_02 = $constraint_01;
      __label__ = 3;
      break;
    }
   case 3:
    var $constraint_02;
    var $13 = HEAP32[HEAP32[$constraint_02 >> 2] + 4 >> 2];
    FUNCTION_TABLE[$13]($constraint_02, $cx, $this);
    var $constraint_0 = HEAP32[$constraint_02 + 4 >> 2];
    if (($constraint_0 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $constraint_02 = $constraint_0;
      __label__ = 3;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10ArenaArrayIPNS_5types8PropertyEEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + ($count << 2) & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodZeroIPNS_5types8PropertyEEEvPT_j($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem << 2;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js5typesL16HashSetInsertTryIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_($compartment, $values, $count, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$count >> 2];
    var $2 = __ZN2js5typesL15HashSetCapacityEj385($1);
    var $3 = __ZN2js5typesL7HashKeyIiNS0_8PropertyEEEjT_386($key);
    var $4 = $2 - 1 | 0;
    var $5 = $3 & $4;
    if (($1 | 0) == 8) {
      var $insertpos_1 = $5;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$values >> 2];
    var $insertpos_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $insertpos_0;
    var $9 = $7 + ($insertpos_0 << 2) | 0;
    var $10 = HEAP32[$9 >> 2];
    if (($10 | 0) == 0) {
      var $insertpos_1 = $insertpos_0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx1_val = HEAP32[$10 >> 2];
    var $13 = __ZN2js5types8Property6getKeyEPS1_($_idx1_val);
    if (($13 | 0) == ($key | 0)) {
      var $_0 = $9;
      __label__ = 17;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $insertpos_0 = $insertpos_0 + 1 & $4;
    __label__ = 3;
    break;
   case 6:
    var $insertpos_1;
    var $18 = $1 + 1 | 0;
    HEAP32[$count >> 2] = $18;
    var $19 = __ZN2js5typesL15HashSetCapacityEj385($18);
    if (($19 | 0) == ($2 | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $_0 = HEAP32[$values >> 2] + ($insertpos_1 << 2) | 0;
    __label__ = 17;
    break;
   case 8:
    var $25 = $compartment + 344 | 0;
    var $26 = __ZN2js10ArenaArrayIPNS_5types8PropertyEEEPT_R11JSArenaPoolj($25, $19);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2jsL7PodZeroIPNS_5types8PropertyEEEvPT_j($26, $19);
    var $_pre = $19 - 1 | 0;
    if (($2 | 0) == 0) {
      var $_pre_phi = $_pre;
      __label__ = 15;
      break;
    } else {
      var $i_013 = 0;
      __label__ = 10;
      break;
    }
   case 10:
    var $i_013;
    var $32 = HEAP32[HEAP32[$values >> 2] + ($i_013 << 2) >> 2];
    if (($32 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_idx_val = HEAP32[$32 >> 2];
    var $35 = __ZN2js5types8Property6getKeyEPS1_($_idx_val);
    var $36 = __ZN2js5typesL7HashKeyIiNS0_8PropertyEEEjT_386($35);
    var $pos_09 = $36 & $_pre;
    var $37 = $26 + ($pos_09 << 2) | 0;
    if ((HEAP32[$37 >> 2] | 0) == 0) {
      var $_lcssa8 = $37;
      __label__ = 13;
      break;
    } else {
      var $pos_010 = $pos_09;
      __label__ = 12;
      break;
    }
   case 12:
    var $pos_010;
    var $pos_0 = $pos_010 + 1 & $_pre;
    var $41 = $26 + ($pos_0 << 2) | 0;
    if ((HEAP32[$41 >> 2] | 0) == 0) {
      var $_lcssa8 = $41;
      __label__ = 13;
      break;
    } else {
      var $pos_010 = $pos_0;
      __label__ = 12;
      break;
    }
   case 13:
    var $_lcssa8;
    HEAP32[$_lcssa8 >> 2] = $32;
    __label__ = 14;
    break;
   case 14:
    var $45 = $i_013 + 1 | 0;
    if (($45 | 0) == ($2 | 0)) {
      var $_pre_phi = $_pre;
      __label__ = 15;
      break;
    } else {
      var $i_013 = $45;
      __label__ = 10;
      break;
    }
   case 15:
    var $_pre_phi;
    HEAP32[$values >> 2] = $26;
    var $insertpos_26 = $3 & $_pre_phi;
    var $46 = $26 + ($insertpos_26 << 2) | 0;
    if ((HEAP32[$46 >> 2] | 0) == 0) {
      var $_0 = $46;
      __label__ = 17;
      break;
    } else {
      var $insertpos_27 = $insertpos_26;
      __label__ = 16;
      break;
    }
   case 16:
    var $insertpos_27;
    var $insertpos_2 = $insertpos_27 + 1 & $_pre_phi;
    var $50 = $26 + ($insertpos_2 << 2) | 0;
    if ((HEAP32[$50 >> 2] | 0) == 0) {
      var $_0 = $50;
      __label__ = 17;
      break;
    } else {
      var $insertpos_27 = $insertpos_2;
      __label__ = 16;
      break;
    }
   case 17:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5typesL16HashSetInsertTryIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_["X"] = 1;

function __ZNK2js12ContextStack13currentScriptEPPh($this, $ppc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($ppc | 0) != 0;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$ppc >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    var $4 = $this;
    var $_idx2_val = HEAP32[$this >> 2];
    var $5 = __ZNK2js12ContextStack9maybeRegsEv($_idx2_val);
    if (($5 | 0) == 0) {
      var $fp_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$5 + 12 >> 2];
    var $9 = __ZNK2js9FrameRegs2fpEv($_idx_val);
    var $fp_0 = $9;
    __label__ = 5;
    break;
   case 5:
    var $fp_0;
    if (($fp_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $fp_0_idx1_val = HEAP32[$fp_0 >> 2];
    var $12 = __ZNK2js10StackFrame12isDummyFrameEv($fp_0_idx1_val);
    if ($12) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $fp_0_idx_val = HEAP32[$fp_0 + 16 >> 2];
    var $14 = __ZNK2js10StackFrame4prevEv($fp_0_idx_val);
    var $fp_0 = $14;
    __label__ = 5;
    break;
   case 8:
    var $15 = __ZNK2js10StackFrame6scriptEv($fp_0);
    var $16 = $15;
    var $17 = __ZNK2js2gc4Cell11compartmentEv($16);
    var $_not = ($17 | 0) != (HEAP32[HEAP32[$this + 8 >> 2] + 56 >> 2] | 0);
    var $_mux = $_not ? 0 : $15;
    if ($_not | $1 ^ 1) {
      var $_0 = $_mux;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $24 = __ZN2js10StackFrame11pcQuadraticERKNS_12ContextStackEPS0_PPNS_13JSInlinedSiteE($fp_0, $4, 0);
    HEAP32[$ppc >> 2] = $24;
    var $_0 = $15;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript10InitObjectEP9JSContextP8JSScriptPKh10JSProtoKey($cx, $script, $pc, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $key = __stackBase__;
    var $p = __stackBase__ + 8;
    var $1 = __stackBase__ + 12;
    var $6 = $pc - HEAP32[$script >> 2] | 0;
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $7 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $script_idx_val_idx_val = HEAP32[HEAP32[$script + 100 >> 2] + 8 >> 2];
    var $9 = __ZNK8JSScript9hasGlobalEv($script_idx_val_idx_val);
    if ($6 >>> 0 > 8388607 | $9 ^ 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = __ZN2js5types16GetTypeNewObjectEP9JSContext10JSProtoKey($cx, $kind);
    var $_0 = $12;
    __label__ = 9;
    break;
   case 4:
    __ZN2js5types17AllocationSiteKeyC1Ev($key);
    HEAP32[$key >> 2] = $script;
    var $19 = $6 & 16777215 | $kind << 24;
    HEAP32[$key + 4 >> 2] = $19;
    var $20 = $cx + 56 | 0;
    var $21 = HEAP32[$20 >> 2];
    var $23 = HEAP32[$21 + 404 >> 2];
    if (($23 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $26 = $21 + 376 | 0;
    var $27 = __ZN2js5types15TypeCompartment27newAllocationSiteTypeObjectEP9JSContextRKNS0_17AllocationSiteKeyE($26, $cx, $key);
    var $_0 = $27;
    __label__ = 9;
    break;
   case 6:
    __ZNK2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE6lookupERKS2_($p, $23, $key);
    var $p_idx_val = HEAP32[$p >> 2];
    var $p_idx_val_idx_val = HEAP32[$p_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($1, $p_idx_val_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $33 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($p_idx_val);
    var $_0 = HEAP32[$33 + 8 >> 2];
    __label__ = 9;
    break;
   case 8:
    var $38 = HEAP32[$20 >> 2] + 376 | 0;
    var $39 = __ZN2js5types15TypeCompartment27newAllocationSiteTypeObjectEP9JSContextRKNS0_17AllocationSiteKeyE($38, $cx, $key);
    var $_0 = $39;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types10TypeScript10InitObjectEP9JSContextP8JSScriptPKh10JSProtoKey["X"] = 1;

function __ZN2js5types16GetTypeNewObjectEP9JSContext10JSProtoKey($cx, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $proto = __stackBase__;
    var $1 = $cx;
    var $2 = $proto;
    var $3 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($1, 0, $key, $2, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$proto >> 2];
    var $7 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($6, $cx, 0, 0);
    var $_0 = $7;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSScript9hasGlobalEv($this_0_32_val_0_2_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_32_val_0_2_val | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js12GlobalObject9isClearedEv($this_0_32_val_0_2_val);
    var $6 = $3 ^ 1;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types17AllocationSiteKeyC1Ev($this) {
  __ZN2js5types17AllocationSiteKeyC2Ev($this);
  return;
}

function __ZNK2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 68,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS7_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $l;
  var $3 = $1;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  var $5 = __ZN2js5types17AllocationSiteKey4hashES1_($1);
  var $6 = $5 * -1640531527 | 0;
  var $7 = $6 - 2 | 0;
  var $8 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($6);
  var $_ = $8 ? $6 : $7;
  var $9 = $_ & -2;
  STACKTOP = __stackBase__;
  return $9;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 4) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS7_EERKS4_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + ($26 << 4) | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS7_EERKS4_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS7_EERKS4_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($1);
  var $3 = __ZN2js5types17AllocationSiteKey5matchERKS1_S3_($2, $l);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js5types17AllocationSiteKeyC2Ev($this) {
  __ZN2jsL7PodZeroINS_5types17AllocationSiteKeyEEEvPT_($this);
  return;
}

function __ZNK2js12GlobalObject9isClearedEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK8JSObject7getSlotEj($1, 117);
  var $_idx = $2 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $3 = __ZNK2JS5Value7toInt32Ev($_idx_val$0, $_idx_val$1);
  return ($3 & 1 | 0) != 0;
}

function __ZL11array_extraP9JSContext14ArrayExtraModejPN2JS5ValueE($cx, $mode, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 92;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $length = __stackBase__;
    var $hole = __stackBase__ + 4;
    var $thisv = __stackBase__ + 8;
    var $objv = __stackBase__ + 16;
    var $tvr = __stackBase__ + 24;
    var $args = __stackBase__ + 48;
    var $hole1 = __stackBase__ + 72;
    var $1 = __stackBase__ + 76;
    var $2 = __stackBase__ + 84;
    var $3 = $vp + 8 | 0;
    var $4 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $3);
    if (($4 | 0) == 0) {
      var $_1 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $4, $length);
    if (($7 | 0) == 0) {
      var $_1 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($argc | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __Z19js_ReportMissingArgP9JSContextRKN2JS5ValueEj($cx, $vp, 0);
    var $_1 = 0;
    __label__ = 55;
    break;
   case 5:
    var $13 = $vp + 16 | 0;
    var $14 = __Z24js_ValueToCallableObjectP9JSContextPN2JS5ValueEj($cx, $13, 65536);
    if (($14 | 0) == 0) {
      var $_1 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = HEAPU32[$length >> 2];
    if (($mode | 0) == 2) {
      __label__ = 7;
      break;
    } else if (($mode | 0) == 1) {
      var $step_0 = 1;
      var $start_0 = 0;
      var $end_0 = $17;
      __label__ = 8;
      break;
    } else if (($mode | 0) == 3 || ($mode | 0) == 4) {
      __label__ = 16;
      break;
    } else if (($mode | 0) == 5) {
      __label__ = 19;
      break;
    } else if (($mode | 0) == 6) {
      __label__ = 20;
      break;
    } else if (($mode | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      var $step_1 = 1;
      var $newlen_0 = 0;
      var $newarr_0 = 0;
      var $start_2 = 0;
      var $end_1 = $17;
      __label__ = 22;
      break;
    }
   case 7:
    var $step_0 = -1;
    var $start_0 = $17 - 1 | 0;
    var $end_0 = -1;
    __label__ = 8;
    break;
   case 8:
    var $end_0;
    var $start_0;
    var $step_0;
    if (($17 | 0) == 0 & ($argc | 0) == 1) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 4, 218, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 55;
    break;
   case 10:
    if ($argc >>> 0 > 1) {
      __label__ = 11;
      break;
    } else {
      var $start_1 = $start_0;
      __label__ = 12;
      break;
    }
   case 11:
    var $27 = $vp + 24 | 0;
    var $st$1$0 = $27 | 0;
    var $28$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $27 + 4 | 0;
    var $28$1 = HEAP32[$st$1$1 >> 2];
    var $29 = $vp | 0;
    var $st$6$0 = $29 | 0;
    HEAP32[$st$6$0 >> 2] = $28$0;
    var $st$6$1 = $29 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $28$1;
    var $step_1 = $step_0;
    var $newlen_0 = 0;
    var $newarr_0 = 0;
    var $start_2 = $start_0;
    var $end_1 = $end_0;
    __label__ = 22;
    break;
   case 12:
    var $start_1;
    var $31 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $4, $start_1 >>> 0, $hole, $vp);
    if (($31 | 0) == 0) {
      var $_1 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $34 = $start_1 + $step_0 | 0;
    var $35 = HEAPU32[$hole >> 2];
    var $37 = ($34 | 0) == ($end_0 | 0);
    if (($35 | 0) == 0 | $37) {
      __label__ = 14;
      break;
    } else {
      var $start_1 = $34;
      __label__ = 12;
      break;
    }
   case 14:
    if (($35 | 0) != 0 & $37) {
      __label__ = 15;
      break;
    } else {
      var $step_1 = $step_0;
      var $newlen_0 = 0;
      var $newarr_0 = 0;
      var $start_2 = $34;
      var $end_1 = $end_0;
      __label__ = 22;
      break;
    }
   case 15:
    _JS_ReportErrorNumber($cx, 4, 218, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 55;
    break;
   case 16:
    var $42 = ($mode | 0) == 3 ? $17 : 0;
    var $43 = __ZN2js22NewDenseAllocatedArrayEP9JSContextjP8JSObject($cx, $42);
    if (($43 | 0) == 0) {
      var $_1 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $46 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, 3);
    if (($46 | 0) == 0) {
      var $_1 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($43, $46);
    __ZN2JS5Value9setObjectER8JSObject($vp, $43);
    var $step_1 = 1;
    var $newlen_0 = $42;
    var $newarr_0 = $43;
    var $start_2 = 0;
    var $end_1 = $17;
    __label__ = 22;
    break;
   case 19:
    __ZN2JS5Value10setBooleanEb($vp, 0);
    var $step_1 = 1;
    var $newlen_0 = 0;
    var $newarr_0 = 0;
    var $start_2 = 0;
    var $end_1 = $17;
    __label__ = 22;
    break;
   case 20:
    __ZN2JS5Value10setBooleanEb($vp, 1);
    var $step_1 = 1;
    var $newlen_0 = 0;
    var $newarr_0 = 0;
    var $start_2 = 0;
    var $end_1 = $17;
    __label__ = 22;
    break;
   case 21:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $step_1 = 1;
    var $newlen_0 = 0;
    var $newarr_0 = 0;
    var $start_2 = 0;
    var $end_1 = $17;
    __label__ = 22;
    break;
   case 22:
    var $end_1;
    var $start_2;
    var $newarr_0;
    var $newlen_0;
    var $step_1;
    if (($17 | 0) == 0) {
      var $_1 = 1;
      __label__ = 55;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    if ($argc >>> 0 > 1) {
      __label__ = 24;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 24:
    if (($mode - 1 | 0) >>> 0 < 2) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $58 = $vp + 24 | 0;
    var $st$1$0 = $58 | 0;
    var $59$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $58 + 4 | 0;
    var $59$1 = HEAP32[$st$1$1 >> 2];
    var $60 = $thisv | 0;
    var $st$6$0 = $60 | 0;
    HEAP32[$st$6$0 >> 2] = $59$0;
    var $st$6$1 = $60 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $59$1;
    __label__ = 27;
    break;
   case 26:
    __ZN2JSL14UndefinedValueEv351($thisv);
    __label__ = 27;
    break;
   case 27:
    if (($mode | 0) == 1) {
      var $66 = 4;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $phitmp = ($mode | 0) == 2 ? 4 : 3;
    var $66 = $phitmp;
    __label__ = 29;
    break;
   case 29:
    var $66;
    __ZN2JSL11ObjectValueER8JSObject383($objv, $4);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    __ZN2js15InvokeArgsGuardC1Ev($args);
    var $67 = $cx + 52 | 0;
    var $68 = $1 | 0;
    var $69 = $thisv | 0;
    var $st$7$0 = $69 | 0;
    var $70$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $69 + 4 | 0;
    var $70$1 = HEAP32[$st$7$1 >> 2];
    var $71 = ($mode - 1 | 0) >>> 0 < 2;
    var $72 = $vp | 0;
    var $73 = $2 | 0;
    var $74 = $objv | 0;
    var $75$0 = HEAP32[$74 >> 2];
    var $75$1 = HEAP32[$74 + 4 >> 2];
    var $76 = ($mode | 0) > 3;
    var $78 = $cx + 60 | 0;
    var $79 = $cx;
    var $80 = $args;
    var $args_idx = $args + 16 | 0;
    var $_idx = $args | 0;
    var $i_0 = $start_2;
    var $ok_0 = 1;
    var $newlen_1 = $newlen_0;
    __label__ = 30;
    break;
   case 30:
    var $newlen_1;
    var $ok_0;
    var $i_0;
    if (($i_0 | 0) == ($end_1 | 0)) {
      var $ok_2 = $ok_0;
      __label__ = 52;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    if ((HEAP32[HEAP32[$67 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $89 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($89 | 0) == 0) {
      var $_0 = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $92 = $i_0 >>> 0;
    var $93 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $94 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $4, $92, $hole1, $93);
    var $95 = ($94 | 0) != 0;
    var $96 = $95 & 1;
    if ($95) {
      __label__ = 34;
      break;
    } else {
      var $ok_2 = $96;
      __label__ = 52;
      break;
    }
   case 34:
    if ((HEAP32[$hole1 >> 2] | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      var $ok_1 = $96;
      var $newlen_2 = $newlen_1;
      __label__ = 51;
      break;
    }
   case 35:
    var $args_idx_val = HEAP32[$args_idx >> 2];
    var $101 = __ZNK2js15InvokeArgsGuard6pushedEv($args_idx_val);
    if ($101) {
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $103 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($78, $79, $66, $80);
    if ($103) {
      __label__ = 37;
      break;
    } else {
      var $_0 = 0;
      __label__ = 54;
      break;
    }
   case 37:
    var $_idx_val = HEAP32[$_idx >> 2];
    var $105 = __ZNK2js12CallReceiver7calleevEv($_idx_val);
    __ZN2JSL11ObjectValueER8JSObject383($1, $14);
    var $106$0 = HEAP32[$68 >> 2];
    var $106$1 = HEAP32[$68 + 4 >> 2];
    var $107 = $105 | 0;
    var $st$8$0 = $107 | 0;
    HEAP32[$st$8$0 >> 2] = $106$0;
    var $st$8$1 = $107 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $106$1;
    var $_idx1_val = HEAP32[$_idx >> 2];
    var $108 = __ZNK2js12CallReceiver5thisvEv($_idx1_val);
    var $109 = $108 | 0;
    var $st$15$0 = $109 | 0;
    HEAP32[$st$15$0 >> 2] = $70$0;
    var $st$15$1 = $109 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $70$1;
    if ($71) {
      __label__ = 38;
      break;
    } else {
      var $argi_0 = 0;
      __label__ = 39;
      break;
    }
   case 38:
    var $_idx5_val = HEAP32[$_idx >> 2];
    var $111 = __ZNK2js8CallArgsixEj($_idx5_val, 0);
    var $112$0 = HEAP32[$72 >> 2];
    var $112$1 = HEAP32[$72 + 4 >> 2];
    var $113 = $111 | 0;
    var $st$7$0 = $113 | 0;
    HEAP32[$st$7$0 >> 2] = $112$0;
    var $st$7$1 = $113 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $112$1;
    var $argi_0 = 1;
    __label__ = 39;
    break;
   case 39:
    var $argi_0;
    var $115 = $argi_0 + 1 | 0;
    var $_idx4_val = HEAP32[$_idx >> 2];
    var $116 = __ZNK2js8CallArgsixEj($_idx4_val, $argi_0);
    var $117 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $118 = $117 | 0;
    var $st$6$0 = $118 | 0;
    var $119$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $118 + 4 | 0;
    var $119$1 = HEAP32[$st$6$1 >> 2];
    var $120 = $116 | 0;
    var $st$11$0 = $120 | 0;
    HEAP32[$st$11$0 >> 2] = $119$0;
    var $st$11$1 = $120 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $119$1;
    var $121 = $argi_0 | 2;
    var $_idx3_val = HEAP32[$_idx >> 2];
    var $122 = __ZNK2js8CallArgsixEj($_idx3_val, $115);
    __ZN2JSL10Int32ValueEi360($2, $i_0);
    var $123$0 = HEAP32[$73 >> 2];
    var $123$1 = HEAP32[$73 + 4 >> 2];
    var $124 = $122 | 0;
    var $st$24$0 = $124 | 0;
    HEAP32[$st$24$0 >> 2] = $123$0;
    var $st$24$1 = $124 + 4 | 0;
    HEAP32[$st$24$1 >> 2] = $123$1;
    var $_idx2_val = HEAP32[$_idx >> 2];
    var $125 = __ZNK2js8CallArgsixEj($_idx2_val, $121);
    var $126 = $125 | 0;
    var $st$31$0 = $126 | 0;
    HEAP32[$st$31$0 >> 2] = $75$0;
    var $st$31$1 = $126 + 4 | 0;
    HEAP32[$st$31$1 >> 2] = $75$1;
    var $127 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($cx, $args, 0);
    var $128 = $127 & 1;
    if ($127) {
      __label__ = 40;
      break;
    } else {
      var $ok_2 = $128;
      __label__ = 52;
      break;
    }
   case 40:
    var $_idx6_val = HEAP32[$_idx >> 2];
    var $130 = __ZNK2js12CallReceiver4rvalEv($_idx6_val);
    if ($76) {
      __label__ = 41;
      break;
    } else {
      var $cond_0 = 0;
      __label__ = 42;
      break;
    }
   case 41:
    var $132 = __Z17js_ValueToBooleanRKN2JS5ValueE($130);
    var $cond_0 = $132;
    __label__ = 42;
    break;
   case 42:
    var $cond_0;
    if (($mode | 0) == 1 || ($mode | 0) == 2) {
      __label__ = 43;
      break;
    } else if (($mode | 0) == 3) {
      __label__ = 44;
      break;
    } else if (($mode | 0) == 4) {
      __label__ = 45;
      break;
    } else if (($mode | 0) == 5) {
      __label__ = 47;
      break;
    } else if (($mode | 0) == 6) {
      __label__ = 49;
      break;
    } else {
      var $ok_1 = $128;
      var $newlen_2 = $newlen_1;
      __label__ = 51;
      break;
    }
   case 43:
    var $135 = $130 | 0;
    var $st$1$0 = $135 | 0;
    var $136$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $135 + 4 | 0;
    var $136$1 = HEAP32[$st$1$1 >> 2];
    HEAP32[$72 >> 2] = $136$0;
    HEAP32[$72 + 4 >> 2] = $136$1;
    var $ok_1 = $128;
    var $newlen_2 = $newlen_1;
    __label__ = 51;
    break;
   case 44:
    var $138 = __ZL15SetArrayElementP9JSContextP8JSObjectdRKN2JS5ValueE($cx, $newarr_0, $92, $130);
    if (($138 | 0) == 0) {
      var $_0 = 0;
      __label__ = 54;
      break;
    } else {
      var $ok_1 = $138;
      var $newlen_2 = $newlen_1;
      __label__ = 51;
      break;
    }
   case 45:
    if (($cond_0 | 0) == 0) {
      var $ok_1 = $128;
      var $newlen_2 = $newlen_1;
      __label__ = 51;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $143 = $newlen_1 + 1 | 0;
    var $145 = __ZL15SetArrayElementP9JSContextP8JSObjectdRKN2JS5ValueE($cx, $newarr_0, $newlen_1 >>> 0, $117);
    if (($145 | 0) == 0) {
      var $_0 = 0;
      __label__ = 54;
      break;
    } else {
      var $ok_1 = $145;
      var $newlen_2 = $143;
      __label__ = 51;
      break;
    }
   case 47:
    if (($cond_0 | 0) == 0) {
      var $ok_1 = $128;
      var $newlen_2 = $newlen_1;
      __label__ = 51;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    __ZN2JS5Value10setBooleanEb($vp, 1);
    var $_0 = $128;
    __label__ = 54;
    break;
   case 49:
    if (($cond_0 | 0) == 0) {
      __label__ = 50;
      break;
    } else {
      var $ok_1 = $128;
      var $newlen_2 = $newlen_1;
      __label__ = 51;
      break;
    }
   case 50:
    __ZN2JS5Value10setBooleanEb($vp, 0);
    var $_0 = $128;
    __label__ = 54;
    break;
   case 51:
    var $newlen_2;
    var $ok_1;
    var $i_0 = $i_0 + $step_1 | 0;
    var $ok_0 = $ok_1;
    var $newlen_1 = $newlen_2;
    __label__ = 30;
    break;
   case 52:
    var $ok_2;
    if (($ok_2 | 0) != 0 & ($mode | 0) == 4) {
      __label__ = 53;
      break;
    } else {
      var $_0 = $ok_2;
      __label__ = 54;
      break;
    }
   case 53:
    var $160 = __Z20js_SetLengthPropertyP9JSContextP8JSObjectd($cx, $newarr_0, $newlen_1 >>> 0);
    var $_0 = $160;
    __label__ = 54;
    break;
   case 54:
    var $_0;
    __ZN2js15InvokeArgsGuardD1Ev($args);
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 55;
    break;
   case 55:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11array_extraP9JSContext14ArrayExtraModejPN2JS5ValueE["X"] = 1;

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_($t) {
  return $t;
}

function __ZN8JSObject18isPackedDenseArrayEv($this_0_2_val) {
  return ($this_0_2_val & 16384 | 0) != 0;
}

function _INT_TO_JSID398($i) {
  return $i << 1 | 1;
}

function __ZN22AutoArrayCycleDetector10foundCycleEv($this_0_4_val) {
  return ($this_0_4_val & 1) << 24 >> 24 != 0;
}

function __ZN2jsL3MinIjEET_S1_S1_($t1, $t2) {
  var $2 = $t1 >>> 0 < $t2 >>> 0 ? $t1 : $t2;
  return $2;
}

function __ZN2js6detail14HashTableEntryIKP8JSObjectE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail14HashTableEntryIKP8JSObjectE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZNK2js6detail14HashTableEntryIKP8JSObjectE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZL18JSDOUBLE_IS_FINITEd396($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function __ZL15JSDOUBLE_IS_NaNd397($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZN2js6detail14HashTableEntryIKP8JSObjectE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($cx, $args, $construct) {
  var $1 = $args | 0;
  __ZN2js12CallArgsList9setActiveEv($1);
  var $2 = $args | 0;
  var $3 = __ZN2js12InvokeKernelEP9JSContextRKNS_8CallArgsENS_14MaybeConstructE($cx, $2, $construct);
  __ZN2js12CallArgsList11setInactiveEv($1);
  return $3;
}

function __ZL19array_indexOfHelperP9JSContextijPN2JS5ValueE($cx, $isLast, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $length = __stackBase__;
    var $hole = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $start = __stackBase__ + 16;
    var $equal = __stackBase__ + 24;
    var $2 = $vp + 8 | 0;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $3, $length);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAPU32[$length >> 2];
    if (($9 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ($argc >>> 0 < 2) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $_ = ($isLast | 0) == 0 ? 0 : $9 - 1 | 0;
    if (($argc | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = $vp + 16 | 0;
    var $st$1$0 = $18 | 0;
    var $19$0 = HEAPU32[$st$1$0 >> 2];
    var $st$1$1 = $18 + 4 | 0;
    var $19$1 = HEAPU32[$st$1$1 >> 2];
    var $20 = $1 | 0;
    HEAP32[$20 >> 2] = $19$0;
    HEAP32[$20 + 4 >> 2] = $19$1;
    var $i_0 = $_;
    var $tosearch_0_0_0$1 = $19$1;
    var $tosearch_0_0_0$0 = $19$0;
    __label__ = 17;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv351($1);
    var $_phi_trans_insert = $1 | 0;
    var $i_0 = $_;
    var $tosearch_0_0_0$1 = HEAP32[$_phi_trans_insert + 4 >> 2];
    var $tosearch_0_0_0$0 = HEAP32[$_phi_trans_insert >> 2];
    __label__ = 17;
    break;
   case 8:
    var $23 = $vp + 16 | 0;
    var $st$1$0 = $23 | 0;
    var $24$0 = HEAPU32[$st$1$0 >> 2];
    var $st$1$1 = $23 + 4 | 0;
    var $24$1 = HEAPU32[$st$1$1 >> 2];
    var $25 = $vp + 24 | 0;
    var $26 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd($cx, $25, $start);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 30;
      break;
    }
   case 9:
    var $28 = (tempDoubleI32[0] = HEAP32[$start >> 2], tempDoubleI32[1] = HEAP32[$start + 4 >> 2], tempDoubleF64[0]);
    var $30 = $9 >>> 0;
    if ($28 < 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 10:
    var $32 = $28 + $30;
    tempDoubleF64[0] = $32, HEAP32[$start >> 2] = tempDoubleI32[0], HEAP32[$start + 4 >> 2] = tempDoubleI32[1];
    if ($32 < 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    if (($isLast | 0) == 0) {
      var $i_01 = 0;
      var $tosearch_0_0_1$1 = $24$1;
      var $tosearch_0_0_1$0 = $24$0;
      __label__ = 18;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 12:
    var $37 = $32 >= 0 ? Math.floor($32) : Math.ceil($32);
    var $i_0 = $37;
    var $tosearch_0_0_0$1 = $24$1;
    var $tosearch_0_0_0$0 = $24$0;
    __label__ = 17;
    break;
   case 13:
    if ($28 < $30) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    if (($isLast | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $direction_0_ph = -1;
    var $stop_0_ph = 0;
    var $i_1_ph = $9 - 1 | 0;
    var $tosearch_0_0_2$1 = $24$1;
    var $tosearch_0_0_2$0 = $24$0;
    __label__ = 19;
    break;
   case 16:
    var $44 = $28 >= 0 ? Math.floor($28) : Math.ceil($28);
    var $i_0 = $44;
    var $tosearch_0_0_0$1 = $24$1;
    var $tosearch_0_0_0$0 = $24$0;
    __label__ = 17;
    break;
   case 17:
    var $tosearch_0_0_0$0;
    var $tosearch_0_0_0$1;
    var $i_0;
    if (($isLast | 0) == 0) {
      var $i_01 = $i_0;
      var $tosearch_0_0_1$1 = $tosearch_0_0_0$1;
      var $tosearch_0_0_1$0 = $tosearch_0_0_0$0;
      __label__ = 18;
      break;
    } else {
      var $direction_0_ph = -1;
      var $stop_0_ph = 0;
      var $i_1_ph = $i_0;
      var $tosearch_0_0_2$1 = $tosearch_0_0_0$1;
      var $tosearch_0_0_2$0 = $tosearch_0_0_0$0;
      __label__ = 19;
      break;
    }
   case 18:
    var $tosearch_0_0_1$0;
    var $tosearch_0_0_1$1;
    var $i_01;
    var $direction_0_ph = 1;
    var $stop_0_ph = $9 - 1 | 0;
    var $i_1_ph = $i_01;
    var $tosearch_0_0_2$1 = $tosearch_0_0_1$1;
    var $tosearch_0_0_2$0 = $tosearch_0_0_1$0;
    __label__ = 19;
    break;
   case 19:
    var $tosearch_0_0_2$0;
    var $tosearch_0_0_2$1;
    var $i_1_ph;
    var $stop_0_ph;
    var $direction_0_ph;
    var $48 = $cx + 52 | 0;
    var $vp_idx = $vp | 0;
    var $i_1 = $i_1_ph;
    __label__ = 20;
    break;
   case 20:
    var $i_1;
    if ((HEAP32[HEAP32[$48 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $55 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($55 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $58 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $3, $i_1 >>> 0, $hole, $vp);
    if (($58 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $64 = __ZN2js13StrictlyEqualEP9JSContextRKN2JS5ValueES5_Pi($cx, $vp_idx_val$0, $vp_idx_val$1, $tosearch_0_0_2$0, $tosearch_0_0_2$1, $equal);
    if ($64) {
      __label__ = 25;
      break;
    } else {
      var $_0 = 0;
      __label__ = 30;
      break;
    }
   case 25:
    if ((HEAP32[$equal >> 2] | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $69 = __ZN2JS5Value9setNumberEj($vp, $i_1);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 27:
    if (($i_1 | 0) == ($stop_0_ph | 0)) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $i_1 = $direction_0_ph + $i_1 | 0;
    __label__ = 20;
    break;
   case 29:
    __ZN2JS5Value8setInt32Ei($vp, -1);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 30:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19array_indexOfHelperP9JSContextijPN2JS5ValueE["X"] = 1;

function __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd($cx, $v, $dp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx2 = $v | 0;
    var $v_idx2_val$0 = HEAP32[$v_idx2 >> 2];
    var $v_idx2_val$1 = HEAP32[$v_idx2 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx2_val$0, $v_idx2_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx2_val$0, $v_idx2_val$1);
    tempDoubleF64[0] = $3 | 0, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 8;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($v_idx2_val$0, $v_idx2_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($v);
    tempDoubleF64[0] = $8, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $12 = $8;
    __label__ = 7;
    break;
   case 5:
    var $10 = __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($cx, $v_idx2_val$0, $v_idx2_val$1, $dp);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $_pre = (tempDoubleI32[0] = HEAP32[$dp >> 2], tempDoubleI32[1] = HEAP32[$dp + 4 >> 2], tempDoubleF64[0]);
    var $12 = $_pre;
    __label__ = 7;
    break;
   case 7:
    var $12;
    var $13 = __ZL18js_DoubleToIntegerd395($12);
    tempDoubleF64[0] = $13, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18js_DoubleToIntegerd395($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d == 0) {
      var $_0 = $d;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL18JSDOUBLE_IS_FINITEd396($d);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZL15JSDOUBLE_IS_NaNd397($d);
    var $d_ = ($6 | 0) == 0 ? $d : 0;
    var $_0 = $d_;
    __label__ = 7;
    break;
   case 4:
    if ($d < 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = _floor($d);
    var $_0 = $10;
    __label__ = 7;
    break;
   case 6:
    var $12 = -$d;
    var $13 = _floor($12);
    var $_0 = -$13;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17TryReuseArrayTypeP8JSObjectS0_($obj, $nobj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj_idx3_val = HEAP32[$obj + 4 >> 2];
    var $1 = __ZNK8JSObject7isArrayEv($obj_idx3_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $obj_idx_val = HEAP32[$obj + 8 >> 2];
    var $3 = __ZNK8JSObject16hasSingletonTypeEv($obj_idx_val);
    if ($3) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $obj_idx1_val = HEAP32[$obj + 36 >> 2];
    var $obj_idx1_val_idx_val = HEAP32[$obj_idx1_val >> 2];
    var $5 = __ZNK8JSObject8getProtoEv($obj_idx1_val_idx_val);
    var $nobj_idx_val_idx_val = HEAP32[HEAP32[$nobj + 36 >> 2] >> 2];
    var $6 = __ZNK8JSObject8getProtoEv($nobj_idx_val_idx_val);
    if (($5 | 0) == ($6 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZNK8JSObject4typeEv($obj_idx1_val);
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($nobj, $9);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15InitArrayObjectP9JSContextP8JSObjectjPKN2JS5ValueE($cx, $obj, $length, $vector) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __ZN8JSObject14setArrayLengthEP9JSContextj($obj, $cx, $length);
    if (($vector | 0) == 0 | ($length | 0) == 0) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $obj;
    var $5 = $cx;
    var $6 = __ZN8JSObject7getTypeEP9JSContext($4, $5);
    var $7 = $6;
    var $8 = __ZL14InitArrayTypesP9JSContextPN2js5types10TypeObjectEPKN2JS5ValueEj($cx, $7, $vector, $length);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 3:
    var $10 = __ZN8JSObject11ensureSlotsEP9JSContextj($obj, $cx, $length);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 4:
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $12 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN8JSObject30setDenseArrayInitializedLengthEj($obj, $length);
    __label__ = 7;
    break;
   case 6:
    __ZN8JSObject23backfillDenseArrayHolesEP9JSContext($obj, $cx);
    __label__ = 7;
    break;
   case 7:
    var $obj_idx = $obj + 32 | 0;
    var $hole_01 = 0;
    var $i_02 = 0;
    __label__ = 8;
    break;
   case 8:
    var $i_02;
    var $hole_01;
    var $obj_idx_val = HEAP32[$obj_idx >> 2];
    var $_idx1 = $vector + ($i_02 << 3) | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($obj_idx_val, $i_02, $_idx1_val$0, $_idx1_val$1);
    var $_idx_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $15 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx_val$0, $_idx_val$1);
    var $16 = $hole_01 | $15;
    var $17 = $i_02 + 1 | 0;
    if (($17 | 0) == ($length | 0)) {
      __label__ = 9;
      break;
    } else {
      var $hole_01 = $16;
      var $i_02 = $17;
      __label__ = 8;
      break;
    }
   case 9:
    if ($16) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 10:
    __ZN8JSObject23markDenseArrayNotPackedEP9JSContext($obj, $cx);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject22moveDenseArrayElementsEjjj($this_0_8_val, $dstStart, $srcStart, $count) {
  var $2 = $this_0_8_val + ($dstStart << 3) | 0;
  var $4 = $this_0_8_val + ($srcStart << 3) | 0;
  var $5 = $count << 3;
  _llvm_memmove_p0i8_p0i8_i32($2, $4, $5, 1, 0);
  return;
}

function __ZL23SetOrDeleteArrayElementP9JSContextP8JSObjectdiRKN2JS5ValueE($cx, $obj, $index, $hole, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($hole | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL18DeleteArrayElementP9JSContextP8JSObjectdb($cx, $obj, $index, 1);
    var $_0 = $3 >>> 31 ^ 1;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZL15SetArrayElementP9JSContextP8JSObjectdRKN2JS5ValueE($cx, $obj, $index, $v);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18array_toString_subP9JSContextP8JSObjectiP8JSStringPN2JS5ValueE($cx, $obj, $locale, $sepstr, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 112;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $detector = __stackBase__;
    var $length = __stackBase__ + 24;
    var $sb = __stackBase__ + 28;
    var $hole = __stackBase__ + 108;
    if (($sepstr | 0) == 0) {
      var $seplen_0 = 1;
      var $sep_0 = __ZZL18array_toString_subP9JSContextP8JSObjectiP8JSStringPN2JS5ValueEE5comma;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $sepstr_idx_val = HEAP32[$sepstr >> 2];
    var $3 = __ZNK8JSString6lengthEv($sepstr_idx_val);
    var $4 = __ZN8JSString8getCharsEP9JSContext($sepstr, $cx);
    if (($4 | 0) == 0) {
      var $_2 = 0;
      __label__ = 36;
      break;
    } else {
      var $seplen_0 = $3;
      var $sep_0 = $4;
      __label__ = 3;
      break;
    }
   case 3:
    var $sep_0;
    var $seplen_0;
    __ZN22AutoArrayCycleDetectorC1EP9JSContextP8JSObject($detector, $cx, $obj);
    var $7 = __ZN22AutoArrayCycleDetector4initEv($detector);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_1 = 0;
      __label__ = 35;
      break;
    }
   case 4:
    var $detector_idx_val = HEAP8[$detector + 20 | 0];
    var $9 = __ZN22AutoArrayCycleDetector10foundCycleEv($detector_idx_val);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $15 = HEAP32[HEAP32[$cx + 52 >> 2] + 209972 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($rval, $15);
    var $_1 = 1;
    __label__ = 35;
    break;
   case 6:
    var $17 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $obj, $length);
    if (($17 | 0) == 0) {
      var $_1 = 0;
      __label__ = 35;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2js12StringBufferC1EP9JSContext($sb, $cx);
    var $20 = ($locale | 0) != 0;
    if (($seplen_0 | 0) == 0 & ($20 ^ 1)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $23 = __ZNK8JSObject12isDenseArrayEv($obj_idx_val);
    if ($23) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $24 = HEAPU32[$length >> 2];
    var $25 = $cx + 52 | 0;
    var $26 = $cx;
    var $rval_idx = $rval | 0;
    var $index_0 = 0;
    __label__ = 19;
    break;
   case 10:
    var $28 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject($obj);
    if (($28 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 11:
    var $obj_idx1_val = HEAP32[$obj + 32 >> 2];
    var $31 = __ZN8JSObject21getDenseArrayElementsEv($obj_idx1_val);
    var $32 = HEAP32[$length >> 2];
    var $33 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
    var $34 = __ZN2jsL3MinIjEET_S1_S1_($32, $33);
    var $35 = $31 + ($34 << 3) | 0;
    var $36 = $cx + 52 | 0;
    var $vp_0 = $31;
    __label__ = 12;
    break;
   case 12:
    var $vp_0;
    if (($vp_0 | 0) == ($35 | 0)) {
      __label__ = 32;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if ((HEAP32[HEAP32[$36 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $45 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($45 | 0) == 0) {
      var $_0 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $vp_0_idx = $vp_0 | 0;
    var $vp_0_idx_val$0 = HEAP32[$vp_0_idx >> 2];
    var $vp_0_idx_val$1 = HEAP32[$vp_0_idx + 4 >> 2];
    var $47 = __ZNK2JS5Value7isMagicE10JSWhyMagic($vp_0_idx_val$0, $vp_0_idx_val$1);
    if ($47) {
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $49 = __ZNK2JS5Value17isNullOrUndefinedEv($vp_0_idx_val$0, $vp_0_idx_val$1);
    if ($49) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $51 = __ZN2js19ValueToStringBufferEP9JSContextRKN2JS5ValueERNS_12StringBufferE($cx, $vp_0_idx_val$0, $vp_0_idx_val$1, $sb);
    if ($51) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 34;
      break;
    }
   case 18:
    var $vp_0 = $vp_0 + 8 | 0;
    __label__ = 12;
    break;
   case 19:
    var $index_0;
    if ($index_0 >>> 0 < $24 >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 20:
    if ((HEAP32[HEAP32[$25 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $61 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($61 | 0) == 0) {
      var $_0 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $64 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $obj, $index_0 >>> 0, $hole, $rval);
    if (($64 | 0) == 0) {
      var $_0 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 24:
    var $st$0$0 = $rval_idx | 0;
    var $rval_idx_val$0 = HEAPU32[$st$0$0 >> 2];
    var $st$0$1 = $rval_idx + 4 | 0;
    var $rval_idx_val$1 = HEAPU32[$st$0$1 >> 2];
    var $70 = __ZNK2JS5Value17isNullOrUndefinedEv($rval_idx_val$0, $rval_idx_val$1);
    if ($70) {
      __label__ = 30;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    if ($20) {
      __label__ = 26;
      break;
    } else {
      var $rval_idx3_val$1 = $rval_idx_val$1;
      var $rval_idx3_val$0 = $rval_idx_val$0;
      __label__ = 29;
      break;
    }
   case 26:
    var $73 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $rval);
    if (($73 | 0) == 0) {
      var $_0 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $79 = HEAP32[HEAP32[$25 >> 2] + 210316 >> 2] | 0;
    var $80 = __ZL12ATOM_TO_JSIDP6JSAtom354($79);
    var $81 = $73;
    var $82 = __ZN8JSObject10callMethodEP9JSContextijPN2JS5ValueES4_($81, $26, $80, $rval);
    if ($82) {
      __label__ = 28;
      break;
    } else {
      var $_0 = 0;
      __label__ = 34;
      break;
    }
   case 28:
    var $st$0$0 = $rval_idx | 0;
    var $st$0$1 = $rval_idx + 4 | 0;
    var $rval_idx3_val$1 = HEAP32[$st$0$1 >> 2];
    var $rval_idx3_val$0 = HEAP32[$st$0$0 >> 2];
    __label__ = 29;
    break;
   case 29:
    var $rval_idx3_val$0;
    var $rval_idx3_val$1;
    var $84 = __ZN2js19ValueToStringBufferEP9JSContextRKN2JS5ValueERNS_12StringBufferE($cx, $rval_idx3_val$0, $rval_idx3_val$1, $sb);
    if ($84) {
      __label__ = 30;
      break;
    } else {
      var $_0 = 0;
      __label__ = 34;
      break;
    }
   case 30:
    var $86 = $index_0 + 1 | 0;
    if (($86 | 0) == ($24 | 0)) {
      var $index_0 = $86;
      __label__ = 19;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $89 = __ZN2js12StringBuffer6appendEPKtj($sb, $sep_0, $seplen_0);
    if ($89) {
      var $index_0 = $86;
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 34;
      break;
    }
   case 32:
    var $90 = $sb;
    var $91 = __ZN2js12StringBuffer12finishStringEv($90);
    if (($91 | 0) == 0) {
      var $_0 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $94 = $91 | 0;
    __ZN2JS5Value9setStringEP8JSString($rval, $94);
    var $_0 = 1;
    __label__ = 34;
    break;
   case 34:
    var $_0;
    __ZN2js12StringBufferD1Ev($sb);
    var $_1 = $_0;
    __label__ = 35;
    break;
   case 35:
    var $_1;
    __ZN22AutoArrayCycleDetectorD1Ev($detector);
    var $_2 = $_1;
    __label__ = 36;
    break;
   case 36:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18array_toString_subP9JSContextP8JSObjectiP8JSStringPN2JS5ValueE["X"] = 1;

function __ZN22AutoArrayCycleDetectorC1EP9JSContextP8JSObject($this, $cx, $obj) {
  __ZN22AutoArrayCycleDetectorC2EP9JSContextP8JSObject($this, $cx, $obj);
  return;
}

function __ZN22AutoArrayCycleDetector4initEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $5 = HEAP32[$this >> 2] + 148 | 0;
    var $6 = $this + 12 | 0;
    var $7 = $this + 4 | 0;
    __ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE12lookupForAddERKS2_($1, $5, $7);
    var $8 = $1;
    var $9 = $6;
    var $10$0 = HEAP32[$8 >> 2];
    var $10$1 = HEAP32[$8 + 4 >> 2];
    HEAP32[$9 >> 2] = $10$0;
    HEAP32[$9 + 4 >> 2] = $10$1;
    var $_idx_val_idx_val = HEAP32[$10$0 >> 2];
    __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($2, $_idx_val_idx_val);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 2:
    var $15 = __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS6_6SetOpsES5_E6AddPtrERS9_($5, $6, $7);
    if ($15) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    HEAP8[$this + 20 | 0] = 0;
    var $18 = __ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE10generationEv($5);
    HEAP32[$this + 8 >> 2] = $18;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js19ValueToStringBufferEP9JSContextRKN2JS5ValueERNS_12StringBufferE($cx, $v_0_0_0_val$0, $v_0_0_0_val$1, $sb) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isStringEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toStringEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $4 = __ZN2js12StringBuffer6appendEP8JSString($sb, $3);
    var $_0 = $4;
    __label__ = 4;
    break;
   case 3:
    var $6 = $cx;
    var $7 = $sb;
    var $8 = __ZN2js23ValueToStringBufferSlowEP9JSContextRKN2JS5ValueERNS_12StringBufferE($6, $v_0_0_0_val$0, $v_0_0_0_val$1, $7);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer6appendEPKtj($this, $chars, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this + 8 >> 2];
    var $1 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv($_idx_val);
    var $2 = $1 + $len | 0;
    var $3 = __ZN2js12StringBuffer11checkLengthEj($this, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbPKT_j($5, $chars, $len);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN22AutoArrayCycleDetectorD1Ev($this) {
  __ZN22AutoArrayCycleDetectorD2Ev($this);
  return;
}

function __ZN22AutoArrayCycleDetectorD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 20 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    var $10 = HEAP32[$this >> 2] + 148 | 0;
    var $11 = __ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE10generationEv($10);
    if (($7 | 0) == ($11 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $15 = HEAP32[$this + 12 >> 2];
    __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS6_6SetOpsES5_E3PtrE($10, $15);
    __label__ = 5;
    break;
   case 4:
    var $17 = $this + 4 | 0;
    __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeERKS2_($10, $17);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE10generationEv($this) {
  var $_idx_val = HEAP32[$this + 12 >> 2];
  var $1 = __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10generationEv($_idx_val);
  return $1;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS6_6SetOpsES5_E3PtrE($this, $p_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE($1, $p_0);
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeERKS2_($this, $l) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 4;
    __ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6lookupERKS2_($p, $this, $l);
    var $p_idx_val = HEAP32[$p >> 2];
    var $p_idx_val_idx_val = HEAP32[$p_idx_val >> 2];
    __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($1, $p_idx_val_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS6_6SetOpsES5_E3PtrE($this, $p_idx_val);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 70,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryIKP8JSObjectE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS4_($l_val);
  var $2 = __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS4_($l_val1) {
  var $1 = __ZN2js13PointerHasherIP8JSObjectLj2EE4hashERKS2_($l_val1);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry);
  return;
}

function __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 3) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryIKP8JSObjectE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $l_val4 = HEAP32[$l >> 2];
    var $11 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_($6, $l_val4);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryIKP8JSObjectE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + ($26 << 3) | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryIKP8JSObjectE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $l_val = HEAP32[$l >> 2];
    var $35 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_($27, $l_val);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_jj["X"] = 1;

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_($e, $l_val1) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_($1);
  var $_val = HEAP32[$2 >> 2];
  var $3 = __ZN2js13PointerHasherIP8JSObjectLj2EE5matchERKS2_S5_($_val, $l_val1);
  return $3;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryIKP8JSObjectE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE($this, $p_0) {
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS4_EE($this, $p_0);
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv($this);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS4_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e_idx_val = HEAP32[$e >> 2];
    var $1 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE12hasCollisionEv($e_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryIKP8JSObjectE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryIKP8JSObjectE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryIKP8JSObjectE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryIKP8JSObjectEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10generationEv($this_0_3_val) {
  return $this_0_3_val;
}

function __ZN2js12AutoIdRooter2idEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6detail14HashTableEntryIKP8JSObjectE12hasCollisionEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv($this_0_1_val, $this_0_2_val, $this_0_4_val) {
  return ($this_0_4_val + $this_0_2_val | 0) >>> 0 >= ($this_0_1_val * 192 | 0) >>> 8 >>> 0;
}

function __ZNK18ArraySharpDetector14initiallySharpEv($this_0_3_val) {
  return ($this_0_3_val & 1) << 24 >> 24 != 0;
}

function __ZNK18ArraySharpDetector13hasSharpCharsEv($this_0_1_val) {
  return ($this_0_1_val | 0) != 0;
}

function _JSID_IS_VOID($iden) {
  return ($iden | 0) == 2 & 1;
}

function _JSVAL_IS_SPECIFIC_BOOLEAN407($l_0$0, $l_0$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -125) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = ($l_0$0 | 0) == 1;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JS5Value12getDoubleRefEv($this) {
  return $this;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryIKP8JSObjectE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKP8JSObjectEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail14HashTableEntryIKP8JSObjectE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail14HashTableEntryIKP8JSObjectEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail14HashTableEntryIKP8JSObjectE10setRemovedEv($this) {
  HEAP32[$this >> 2] = 1;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail14HashTableEntryIKP8JSObjectE7setFreeEv($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail14HashTableEntryIKP8JSObjectE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN22AutoArrayCycleDetectorC2EP9JSContextP8JSObject($this, $cx, $obj) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $obj;
  HEAP8[$this + 20 | 0] = 1;
  return;
}

function __ZN18ArraySharpDetector14takeSharpCharsEv($this) {
  var $1 = $this + 4 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$1 >> 2] = 0;
  return $2;
}

function __ZN18ArraySharpDetector9makeSharpEv($this_0_2_val) {
  var $1 = $this_0_2_val + 12 | 0;
  var $5 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $5;
  return;
}

function __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13copyConstructIcEEvPtPKT_S7_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    HEAP16[$_02 >> 1] = HEAP8[$p_01] << 24 >> 24;
    var $4 = $p_01 + 1 | 0;
    if (($4 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $4;
      var $_02 = $_02 + 2 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18ArraySharpDetectorC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP8[$this + 12 | 0] = 0;
  return;
}

function __ZN2js12AutoIdRooter4addrEv($this) {
  return $this + 12 | 0;
}

function __ZZN2js10array_sortEP9JSContextjPN2JS5ValueEEN14AutoFreeVectorC2ES1_RS4_($this, $cx, $vec) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $vec;
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j($10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + ($5 << 3) | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 5;
    break;
   case 5:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $22 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isLiveEv($src_01_idx_val);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryIKP8JSObjectE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE10getKeyHashEv($src_01_idx1_val);
    var $25 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryIKP8JSObjectEEEENS_7MoveRefIT_EERS8_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryIKP8JSObjectEaSENS_7MoveRefIS5_EE($25, $_02_val);
    __label__ = 7;
    break;
   case 7:
    var $27 = $src_01 + 8 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($3);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j($capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 3;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej($1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + ($capacity << 3) | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryIKP8JSObjectEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 8 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 3) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryIKP8JSObjectE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + ($15 << 3) | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryIKP8JSObjectEaSENS_7MoveRefIS5_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryIKP8JSObjectEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $2 + 4 | 0;
  __ZN2js4MoveIP8JSObjectEENS_7MoveRefIT_EERS4_($1, $6);
  var $_idx_val = HEAP32[$1 >> 2];
  var $7 = __ZNK2js7MoveRefIP8JSObjectEcvRS2_Ev($_idx_val);
  var $8 = HEAP32[$7 >> 2];
  HEAP32[$this + 4 >> 2] = $8;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryIKP8JSObjectEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKP8JSObjectEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv($0);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKP8JSObjectEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKP8JSObjectEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryIKP8JSObjectEC1Ev($this) {
  __ZN2js6detail14HashTableEntryIKP8JSObjectEC2Ev($this);
  return;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbPKT_j($this, $insBegin, $length) {
  var $1 = $insBegin + ($length << 1) | 0;
  var $2 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbPKT_S6_($this, $insBegin, $1);
  return $2;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbPKT_S6_($this, $insBegin, $insEnd) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = ($insEnd - $insBegin | 0) >>> 1;
    if ((HEAP32[$this + 8 >> 2] + $4 | 0) >>> 0 > HEAPU32[$this + 12 >> 2] >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $12 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE13growStorageByEj($this, $4);
    if ($12) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendItEEvPKT_j($this, $insBegin, $4);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer6appendEP8JSString($this, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js12StringBuffer7contextEv($this);
    var $2 = __ZN8JSString12ensureLinearEP9JSContext($str, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$2 >> 2];
    var $5 = __ZNK8JSString6lengthEv($_idx_val);
    var $_idx2_val = HEAP32[$this + 8 >> 2];
    var $6 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv($_idx2_val);
    var $7 = $6 + $5 | 0;
    var $8 = __ZN2js12StringBuffer11checkLengthEj($this, $7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = $this | 0;
    var $_idx1_val = HEAP32[$2 + 4 >> 2];
    var $11 = __ZNK14JSLinearString5charsEv($_idx1_val);
    var $12 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbPKT_j($10, $11, $5);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERS4_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS6_6SetOpsES5_E6AddPtrERS9_($this, $p, $t) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS4_($1, $p, $t);
  return $2;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS4_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$t >> 2];
    var $6 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$6 >> 2] = $3;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 8 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 16 >> 2];
    var $12 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryIKP8JSObjectE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERS4_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS4_($l_val);
  var $2 = __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZL13js_IsCallableRKN2JS5ValueE405($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZN8JSObject10isCallableEv($_idx_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18ArraySharpDetectorC1EP9JSContext($this, $cx) {
  __ZN18ArraySharpDetectorC2EP9JSContext($this, $cx);
  return;
}

function __ZN18ArraySharpDetector4initEP8JSObject($this, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 4 | 0;
    var $4 = HEAP32[$this >> 2];
    var $5 = $obj;
    var $6 = __Z19js_EnterSharpObjectP9JSContextP8JSObjectPP9JSIdArrayPPt($4, $5, 0, $3);
    var $7 = $6;
    HEAP32[$this + 8 >> 2] = $7;
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP8[$this + 12 | 0] = HEAP32[$6 + 12 >> 2] & 255 & 1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer16replaceRawBufferEPtj($this, $chars, $len) {
  var $1 = $this | 0;
  __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16replaceRawBufferEPtj($1, $chars, $len);
  return;
}

function __ZN2js12StringBuffer6appendEt($this, $c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this + 8 >> 2];
    var $1 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv($_idx_val);
    var $2 = $1 + 1 | 0;
    var $3 = __ZN2js12StringBuffer11checkLengthEj($this, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbT_($5, $c);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer6appendILj3EEEbRAT__Kc($this, $array) {
  var $1 = $this | 0;
  var $2 = $array | 0;
  var $3 = $array + 2 | 0;
  var $4 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendIcEEbPKT_S6_($1, $2, $3);
  return $4;
}

function __ZN2JSL11StringValueEP8JSString406($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN18ArraySharpDetectorD1Ev($this) {
  __ZN18ArraySharpDetectorD2Ev($this);
  return;
}

function __ZN18ArraySharpDetectorD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN9JSContext5free_EPv($5);
    __label__ = 3;
    break;
   case 3:
    if ((HEAP32[$this + 8 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $18 = HEAP32[$this >> 2];
    __Z19js_LeaveSharpObjectP9JSContextPP9JSIdArray($18, 0);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendIcEEbPKT_S6_($this, $insBegin, $insEnd) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $insEnd - $insBegin | 0;
    if ((HEAP32[$this + 8 >> 2] + $3 | 0) >>> 0 > HEAPU32[$this + 12 >> 2] >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE13growStorageByEj($this, $3);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendIcEEvPKT_j($this, $insBegin, $3);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendIcEEvPKT_j($this, $insBegin, $length) {
  var $this_idx_val = HEAP32[$this + 4 >> 2];
  var $this_idx1 = $this + 8 | 0;
  var $this_idx1_val = HEAP32[$this_idx1 >> 2];
  var $1 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
  var $2 = $insBegin + $length | 0;
  __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13copyConstructIcEEvPtPKT_S7_($1, $insBegin, $2);
  var $4 = HEAP32[$this_idx1 >> 2] + $length | 0;
  HEAP32[$this_idx1 >> 2] = $4;
  return;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendItEEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendItEEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $5 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP16[$1 >> 1] = $t;
    var $5 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    HEAP32[$this_idx1 >> 2] = $5 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16replaceRawBufferEPtj($this, $p, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js18ContextAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    if ($length >>> 0 < 33) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = $this + 16 | 0;
    var $9 = __ZN7mozilla14AlignedStorageILj64EE4addrEv($8);
    var $10 = $9;
    HEAP32[$this + 4 >> 2] = $10;
    HEAP32[$this + 8 >> 2] = $length;
    HEAP32[$this + 12 >> 2] = 32;
    var $14 = $p + ($length << 1) | 0;
    __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13moveConstructItEEvPtPKT_S7_($10, $p, $14);
    var $15 = $p;
    __ZN2js18ContextAllocPolicy5free_EPv($15);
    __label__ = 6;
    break;
   case 5:
    HEAP32[$this + 4 >> 2] = $p;
    HEAP32[$this + 8 >> 2] = $length;
    HEAP32[$this + 12 >> 2] = $length;
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12AutoIdRooterC1EP9JSContexti($this, $cx, $id) {
  __ZN2js12AutoIdRooterC2EP9JSContexti($this, $cx, $id);
  return;
}

function __ZNK2JS5Value6isTrueEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_IS_SPECIFIC_BOOLEAN407($this_0_0_0_val$0, $this_0_0_0_val$1);
  return ($1 | 0) != 0;
}

function __ZN2js12AutoIdRooterD1Ev($this) {
  __ZN2js12AutoIdRooterD2Ev($this);
  return;
}

function __ZN2js12AutoIdRooterD2Ev($this) {
  var $_idx_val = HEAP32[$this >> 2];
  var $_idx1_val = HEAP32[$this + 8 >> 2];
  __ZN2js12AutoGCRooterD2Ev($_idx_val, $_idx1_val);
  return;
}

function __ZN2js12AutoIdRooterC2EP9JSContexti($this, $cx, $id) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($1, $cx, -11);
  HEAP32[$this + 12 >> 2] = $id;
  return;
}

function __ZZN2js10array_sortEP9JSContextjPN2JS5ValueEEN14AutoFreeVectorD2Ev($this_0_1_val_val) {
  var $1 = $this_0_1_val_val;
  __ZN9JSContext5free_EPv($1);
  return;
}

function __ZN2js15AutoArrayRooterD2Ev($this) {
  var $_idx_val = HEAP32[$this >> 2];
  var $_idx1_val = HEAP32[$this + 8 >> 2];
  __ZN2js12AutoGCRooterD2Ev($_idx_val, $_idx1_val);
  return;
}

function __ZN2JSL11DoubleValueEd408($agg_result, $dbl) {
  __ZN2JS5Value9setDoubleEd($agg_result, $dbl);
  return;
}

function __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($cx, $v_0_0_0_val$0, $v_0_0_0_val$1, $idp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $atom = __stackBase__;
    var $1 = __Z14js_ValueToAtomP9JSContextRKN2JS5ValueEPP6JSAtom($cx, $v_0_0_0_val$0, $v_0_0_0_val$1, $atom);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$atom >> 2];
    var $4 = __ZL12ATOM_TO_JSIDP6JSAtom354($3);
    HEAP32[$idp >> 2] = $4;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z14js_ValueToAtomP9JSContextRKN2JS5ValueEPP6JSAtom($cx, $v_0_0_0_val$0, $v_0_0_0_val$1, $atomp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $anchor = __stackBase__;
    var $1 = __ZNK2JS5Value8isStringEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $cx;
    var $4 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($3, $v_0_0_0_val$0, $v_0_0_0_val$1);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $4);
    var $7 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($cx, $4);
    HEAP32[$atomp >> 2] = $7;
    var $_0 = ($7 | 0) != 0;
    __label__ = 7;
    break;
   case 4:
    var $10 = __ZNK2JS5Value8toStringEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_idx_val = HEAP32[$10 >> 2];
    var $11 = __ZNK8JSString6isAtomEv($_idx_val);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $13 = __ZNK8JSString6asAtomEv($10);
    HEAP32[$atomp >> 2] = $13;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 6:
    var $15 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($cx, $10);
    HEAP32[$atomp >> 2] = $15;
    var $_0 = ($15 | 0) != 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11CompareArgsD2Ev($this) {
  var $1 = $this + 4 | 0;
  __ZN2js15InvokeArgsGuardD1Ev($1);
  return;
}

function __ZN11CompareArgsC2EP9JSContextN2JS5ValueE($this, $cx, $_0_0_0_val$0, $_0_0_0_val$1) {
  HEAP32[$this >> 2] = $cx;
  var $2 = $this + 4 | 0;
  __ZN2js15InvokeArgsGuardC1Ev($2);
  var $_03 = $this + 32 | 0;
  HEAP32[$_03 >> 2] = $_0_0_0_val$0;
  HEAP32[$_03 + 4 >> 2] = $_0_0_0_val$1;
  return;
}

function __ZN2jsL7PodZeroIN2JS5ValueEEEvPT_j412($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem << 3;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js15ArgumentsObject10getElementEjPN2JS5ValueE($this, $i, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js15ArgumentsObject13initialLengthEv($this);
    if ($1 >>> 0 > $i >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $4 = __ZNK2js15ArgumentsObject7elementEj($this, $i);
    var $5 = $4 | 0;
    var $st$2$0 = $5 | 0;
    var $6$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $5 + 4 | 0;
    var $6$1 = HEAP32[$st$2$1 >> 2];
    var $7 = $vp | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $8 = __ZNK2JS5Value7isMagicE10JSWhyMagic($6$0, $6$1);
    if ($8) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK2js15ArgumentsObject7onTraceEv($this);
    if ($10) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = __ZNK2js15ArgumentsObject15maybeStackFrameEv($this);
    if (($12 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = __ZNK2js10StackFrame18canonicalActualArgEj($12, $i);
    var $16 = $15 | 0;
    var $st$2$0 = $16 | 0;
    var $17$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $16 + 4 | 0;
    var $17$1 = HEAP32[$st$2$1 >> 2];
    HEAP32[$7 >> 2] = $17$0;
    HEAP32[$7 + 4 >> 2] = $17$1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js15ArgumentsObject7elementEj($this, $i) {
  var $1 = __ZNK2js15ArgumentsObject4dataEv($this);
  return $1 + 8 + ($i << 3) | 0;
}

function __ZNK2js15ArgumentsObject7onTraceEv($this) {
  var $_idx_val = HEAP32[$this + 24 >> 2];
  var $1 = __ZNK8JSObject10getPrivateEv($_idx_val);
  return ($1 | 0) == 41254;
}

function __ZNK2js15ArgumentsObject15maybeStackFrameEv($this) {
  var $_idx_val = HEAP32[$this + 24 >> 2];
  var $1 = __ZNK8JSObject10getPrivateEv($_idx_val);
  return $1;
}

function __ZNK2js15ArgumentsObject4dataEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK8JSObject7getSlotEj($1, 1);
  var $_idx = $2 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $3 = __ZNK2JS5Value9toPrivateEv($_idx_val$0, $_idx_val$1);
  return $3;
}

function __ZN2js15AutoArrayRooterC2EP9JSContextjPN2JS5ValueE($this, $cx, $len, $vec) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($1, $cx, $len);
  HEAP32[$this + 12 >> 2] = $vec;
  return;
}

function __ZN2js14AutoValueArrayD2Ev($this) {
  var $_idx_val = HEAP32[$this >> 2];
  var $_idx1_val = HEAP32[$this + 8 >> 2];
  __ZN2js12AutoGCRooterD2Ev($_idx_val, $_idx1_val);
  return;
}

function __ZL19array_length_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $_01_idx2_val = HEAP32[$_01 + 4 >> 2];
    var $2 = __ZNK8JSObject7isArrayEv($_01_idx2_val);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $_01_idx1_val = HEAP32[$_01 + 24 >> 2];
    var $4 = __ZNK8JSObject14getArrayLengthEv($_01_idx1_val);
    var $5 = __ZN2JS5Value9setNumberEj($vp, $4);
    __label__ = 5;
    break;
   case 4:
    var $_01_idx_val_idx_val = HEAP32[HEAP32[$_01 + 36 >> 2] >> 2];
    var $7 = __ZNK8JSObject8getProtoEv($_01_idx_val_idx_val);
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_01 = $7;
      __label__ = 2;
      break;
    }
   case 5:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE($sid_0_0_val) {
  return $sid_0_0_val;
}

function __ZL14JSID_FROM_BITSj423($bits) {
  return $bits;
}

function _JSID_TO_INT420($iden) {
  return $iden >> 1;
}

function _JSID_TO_STRING422($iden) {
  return $iden;
}

function _JSVAL_IS_MAGIC_IMPL($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -124) & 1;
}

function __ZNK8JSObject17isStrictArgumentsEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js26StrictArgumentsObjectClassE | 0);
}

function __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($this_0_0_val, $this_0_1_val) {
  return ($this_0_0_val | 0) == ($this_0_1_val | 0);
}

function __ZNK2js18TaggedPointerEntryI6JSAtomE5asPtrEv($this_0_0_val) {
  return $this_0_0_val & -2;
}

function __ZNK2js18TaggedPointerEntryI6JSAtomE8isTaggedEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function __ZNK2js10StackFrame13formalArgsEndEv($this) {
  return $this;
}

function __ZN6JSAtom14asPropertyNameEv($this) {
  return $this;
}

function __ZN2js6detail17CopyNonHoleArgsToC2EPNS_15ArgumentsObjectEPN2JS5ValueE($this, $argsobj, $dst) {
  HEAP32[$this >> 2] = $argsobj;
  HEAP32[$this + 4 >> 2] = $dst;
  return;
}

function __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN11JSAtomState16commonAtomsStartEv($this) {
  return $this + 24 | 0;
}

function __Z20js_FinishCommonAtomsP9JSContext($cx_0_11_val) {
  HEAP32[$cx_0_11_val + 144136 >> 2] = 0;
  return;
}

function __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrptEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZNK2js18TaggedPointerEntryI6JSAtomE9setTaggedEb($this, $enabled) {
  var $2 = $this | 0;
  var $4 = HEAP32[$2 >> 2] | $enabled & 1;
  HEAP32[$2 >> 2] = $4;
  return;
}

function __ZL19array_length_setterP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $newlen = __stackBase__ + 4;
    var $d = __stackBase__ + 8;
    var $tvr = __stackBase__ + 16;
    var $index = __stackBase__ + 32;
    var $junk = __stackBase__ + 36;
    HEAP32[$1 >> 2] = $id;
    var $obj_idx3 = $obj + 4 | 0;
    var $obj_idx3_val = HEAP32[$obj_idx3 >> 2];
    var $2 = __ZNK8JSObject7isArrayEv($obj_idx3_val);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $9 = __ZL12ATOM_TO_JSIDP6JSAtom354($8);
    var $10 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj, $cx, $9, $vp, 0, 0, 1);
    var $_1 = $10;
    __label__ = 36;
    break;
   case 3:
    var $12 = __ZN2js17ValueToECMAUint32EP9JSContextRKN2JS5ValueEPj($cx, $vp, $newlen);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_1 = 0;
      __label__ = 36;
      break;
    }
   case 4:
    var $14 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      var $_1 = 0;
      __label__ = 36;
      break;
    }
   case 5:
    var $16 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $17 = HEAPU32[$newlen >> 2];
    if ($16 != $17 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 4, 152, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 36;
    break;
   case 7:
    var $obj_idx2_val = HEAP32[$obj + 24 >> 2];
    var $22 = __ZNK8JSObject14getArrayLengthEv($obj_idx2_val);
    if (($22 | 0) == ($17 | 0)) {
      var $_1 = 1;
      __label__ = 36;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $25 = __ZN2JS5Value9setNumberEj($vp, $17);
    if ($22 >>> 0 < $17 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    __ZN8JSObject14setArrayLengthEP9JSContextj($obj, $cx, $17);
    var $_1 = 1;
    __label__ = 36;
    break;
   case 10:
    var $obj_idx_val = HEAP32[$obj_idx3 >> 2];
    var $29 = __ZNK8JSObject12isDenseArrayEv($obj_idx_val);
    if ($29) {
      __label__ = 11;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 11:
    var $obj_idx1_val = HEAP32[$obj + 28 >> 2];
    var $31 = __ZN8JSObject21getDenseArrayCapacityEv($obj_idx1_val);
    if ($31 >>> 0 > $17 >>> 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    __ZN8JSObject24shrinkDenseArrayElementsEP9JSContextj($obj, $cx, $17);
    __label__ = 13;
    break;
   case 13:
    var $35 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
    if ($35 >>> 0 > $17 >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 14:
    __ZN8JSObject30setDenseArrayInitializedLengthEj($obj, $17);
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $38 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($38) {
      __label__ = 33;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    __ZN8JSObject23backfillDenseArrayHolesEP9JSContext($obj, $cx);
    __label__ = 33;
    break;
   case 16:
    var $41 = $22 - $17 | 0;
    if ($41 >>> 0 < 16777216) {
      __label__ = 17;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 17:
    var $43 = $cx + 52 | 0;
    var $44 = ($strict | 0) != 0;
    var $oldlen_0 = $22;
    __label__ = 18;
    break;
   case 18:
    var $oldlen_0;
    var $46 = $oldlen_0 - 1 | 0;
    if ((HEAP32[HEAP32[$43 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $52 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($52 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    __ZN8JSObject14setArrayLengthEP9JSContextj($obj, $cx, $oldlen_0);
    var $_1 = 0;
    __label__ = 36;
    break;
   case 21:
    var $56 = __ZL18DeleteArrayElementP9JSContextP8JSObjectdb($cx, $obj, $46 >>> 0, $44);
    if (($56 | 0) < 1) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    __ZN8JSObject14setArrayLengthEP9JSContextj($obj, $cx, $oldlen_0);
    var $_1 = $56 >>> 31 ^ 1;
    __label__ = 36;
    break;
   case 23:
    if (($46 | 0) == ($17 | 0)) {
      __label__ = 33;
      break;
    } else {
      var $oldlen_0 = $46;
      __label__ = 18;
      break;
    }
   case 24:
    var $62 = _JS_NewPropertyIterator($cx, $obj);
    if (($62 | 0) == 0) {
      var $_1 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($tvr, $cx, $62);
    var $65 = $cx + 52 | 0;
    __label__ = 26;
    break;
   case 26:
    if ((HEAP32[HEAP32[$65 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $71 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($71 | 0) == 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    _JS_NextProperty($62, $1);
    var $73 = HEAPU32[$1 >> 2];
    var $74 = _JSID_IS_VOID($73);
    if (($74 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 29:
    var $77 = __Z12js_IdIsIndexiPj($73, $index);
    if (($77 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    if ((HEAP32[$index >> 2] - $17 | 0) >>> 0 < $41 >>> 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 31:
    var $84 = __ZN8JSObject14deletePropertyEP9JSContextiPN2JS5ValueEi($obj, $cx, $73, $junk, 0);
    if (($84 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 32:
    __ZN2js16AutoObjectRooterD1Ev($tvr);
    __label__ = 33;
    break;
   case 33:
    var $87 = HEAP32[$newlen >> 2];
    __ZN8JSObject14setArrayLengthEP9JSContextj($obj, $cx, $87);
    var $_1 = 1;
    __label__ = 36;
    break;
   case 34:
    __ZN2js16AutoObjectRooterD1Ev($tvr);
    var $_1 = 0;
    __label__ = 36;
    break;
   case 35:
    __ZN2js16AutoObjectRooterD1Ev($tvr);
    var $_1 = 0;
    __label__ = 36;
    break;
   case 36:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19array_length_setterP9JSContextP8JSObjectiiPN2JS5ValueE["X"] = 1;

function __ZN8JSObject24shrinkDenseArrayElementsEP9JSContextj($this, $cx, $cap) {
  var $1 = $this;
  var $2 = $cx;
  __ZN8JSObject11shrinkSlotsEP9JSContextj($1, $2, $cap);
  return;
}

function __ZN2js14AutoValueArrayC2EP9JSContextPN2JS5ValueEj($this, $cx, $start, $length) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($1, $cx, -2);
  HEAP32[$this + 12 >> 2] = $start;
  HEAP32[$this + 16 >> 2] = $length;
  return;
}

function __Z13js_GetElementP9JSContextP8JSObjectjPN2JS5ValueE($cx, $obj, $index, $vp) {
  var $1 = $cx;
  var $2 = $obj;
  var $3 = __Z13js_GetElementP9JSContextP8JSObjectS2_jPN2JS5ValueE($1, $2, $2, $index, $vp);
  return $3;
}

function __Z14js_GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = $obj;
  var $3 = __Z14js_GetPropertyP9JSContextP8JSObjectS2_iPN2JS5ValueE($1, $2, $2, $id, $vp);
  return $3;
}

function __ZL17IsDenseArrayIndexP8JSObjectj($obj, $index) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
    if ($1 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $obj_idx_val = HEAP32[$obj + 32 >> 2];
    var $4 = __ZN8JSObject20getDenseArrayElementEj($obj_idx_val, $index);
    var $_idx = $4 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $5 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx_val$0, $_idx_val$1);
    var $8 = $5 ^ 1;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject13lookupElementEP9JSContextjPPS_PP10JSProperty($this, $cx, $index, $objp, $propp) {
  var $this_idx_val = HEAP32[$this + 4 >> 2];
  var $1 = __ZNK8JSObject6getOpsEv($this_idx_val);
  var $3 = HEAP32[$1 + 8 >> 2];
  var $5 = ($3 | 0) != 0 ? $3 : 72;
  var $6 = FUNCTION_TABLE[$5]($cx, $this, $index, $objp, $propp);
  return $6;
}

function __ZL14IsDenseArrayIdP9JSContextP8JSObjecti($cx_0_11_val_0_70_28_val, $obj, $id) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $1 = $cx_0_11_val_0_70_28_val | 0;
    var $2 = __ZL12JSID_IS_ATOMiP6JSAtom($id, $1);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $11 = 1;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = __Z12js_IdIsIndexiPj($id, $i);
    if (($5 | 0) == 0) {
      var $11 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = HEAP32[$i >> 2];
    var $9 = __ZL17IsDenseArrayIndexP8JSObjectj($obj, $8);
    var $11 = $9;
    __label__ = 4;
    break;
   case 4:
    var $11;
    STACKTOP = __stackBase__;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12JSID_TO_ATOMi421($id) {
  var $1 = _JSID_TO_STRING422($id);
  return $1;
}

function __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($this, $cx, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$id >> 2];
    var $4 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($this, $cx, $3, $vp);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js15ArgumentsObject8elementsEv($this) {
  var $1 = __ZNK2js15ArgumentsObject4dataEv($this);
  return $1 + 8 | 0;
}

function __ZN2js10StackFrame25forEachCanonicalActualArgINS_6detail17CopyNonHoleArgsToEEEbT_jj($this, $op_0, $op_1, $count) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $op = __stackBase__;
    HEAP32[$op >> 2] = $op_0;
    HEAP32[$op + 4 >> 2] = $op_1;
    var $1 = __ZNK2js10StackFrame3funEv($this);
    var $4 = HEAPU16[$1 + 56 >> 1] & 65535;
    var $5 = __ZNK2js10StackFrame13formalArgsEndEv($this);
    var $6 = __ZNK2js10StackFrame13numActualArgsEv($this);
    var $_02 = ($count | 0) == -1 ? $6 : $count;
    var $9 = $5 + (-$4 << 3) | 0;
    if ($_02 >>> 0 > $4 >>> 0) {
      var $_1 = 0;
      var $p1_0 = $9;
      __label__ = 5;
      break;
    } else {
      var $_01 = 0;
      var $p_0 = $9;
      __label__ = 2;
      break;
    }
   case 2:
    var $p_0;
    var $_01;
    if ($_01 >>> 0 < $_02 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 3:
    var $12 = __ZN2js6detail17CopyNonHoleArgsToclEjPN2JS5ValueE($op, $_01, $p_0);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 4:
    var $_01 = $_01 + 1 | 0;
    var $p_0 = $p_0 + 8 | 0;
    __label__ = 2;
    break;
   case 5:
    var $p1_0;
    var $_1;
    if ($_1 >>> 0 < $4 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = __ZN2js6detail17CopyNonHoleArgsToclEjPN2JS5ValueE($op, $_1, $p1_0);
    if ($18) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 7:
    var $_1 = $_1 + 1 | 0;
    var $p1_0 = $p1_0 + 8 | 0;
    __label__ = 5;
    break;
   case 8:
    var $p2_0 = $5 + (-2 - $4 - $6 + $_1 << 3) | 0;
    var $_2 = $_1;
    __label__ = 9;
    break;
   case 9:
    var $_2;
    var $p2_0;
    if ($_2 >>> 0 < $_02 >>> 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 10:
    var $28 = __ZN2js6detail17CopyNonHoleArgsToclEjPN2JS5ValueE($op, $_2, $p2_0);
    if ($28) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 11:
    var $p2_0 = $p2_0 + 8 | 0;
    var $_2 = $_2 + 1 | 0;
    __label__ = 9;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js10StackFrame25forEachCanonicalActualArgINS_6detail17CopyNonHoleArgsToEEEbT_jj["X"] = 1;

function __ZN2js6detail17CopyNonHoleArgsToC1EPNS_15ArgumentsObjectEPN2JS5ValueE($this, $argsobj, $dst) {
  __ZN2js6detail17CopyNonHoleArgsToC2EPNS_15ArgumentsObjectEPN2JS5ValueE($this, $argsobj, $dst);
  return;
}

function __ZN2js6detail17CopyNonHoleArgsToclEjPN2JS5ValueE($this, $argi, $src) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZNK2js15ArgumentsObject7elementEj($2, $argi);
    var $_idx = $3 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $4 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx_val$0, $_idx_val$1);
    if ($4) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $this + 4 | 0;
    var $7 = HEAP32[$6 >> 2];
    var $8 = $7 + 8 | 0;
    HEAP32[$6 >> 2] = $8;
    var $9 = $src | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $7 | 0;
    var $st$10$0 = $11 | 0;
    HEAP32[$st$10$0 >> 2] = $10$0;
    var $st$10$1 = $11 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $10$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12BigIndexToIdP9JSContextP8JSObjectjiPi($cx, $obj, $index, $createAtom, $idp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__ + 20 | 0;
    var $start_0 = $1;
    var $_01 = $index;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $start_0;
    var $3 = $start_0 - 2 | 0;
    HEAP16[$3 >> 1] = (($_01 >>> 0) % 10 | 48) & 65535;
    var $7 = Math.floor(($_01 >>> 0) / 10);
    if ($_01 >>> 0 > 9) {
      var $start_0 = $3;
      var $_01 = $7;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($createAtom | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    var $obj_idx1_val = HEAPU32[$obj + 4 >> 2];
    var $12 = __ZNK8JSObject11isSlowArrayEv($obj_idx1_val);
    if ($12) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = __ZNK8JSObject11isArgumentsEv($obj);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = __ZNK8JSObject8isObjectEv($obj_idx1_val);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $21 = $1 - $3 >> 1;
    var $22 = __Z24js_GetExistingStringAtomP9JSContextPKtj($cx, $3, $21);
    if (($22 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $atom_0 = $22;
      __label__ = 10;
      break;
    }
   case 8:
    HEAP32[$idp >> 2] = 2;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 9:
    var $29 = $1 - $3 >> 1;
    var $30 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($cx, $3, $29, 0);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      var $atom_0 = $30;
      __label__ = 10;
      break;
    }
   case 10:
    var $atom_0;
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom354($atom_0);
    HEAP32[$idp >> 2] = $33;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18ReallyBigIndexToIdP9JSContextdPi($cx, $index, $idp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL11DoubleValueEd408($1, $index);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $2 = __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($cx, $_idx_val$0, $_idx_val$1, $idp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js15AutoValueRooterC2EP9JSContext($this, $cx) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($1, $cx, -1);
  var $2 = $this + 16 | 0;
  __ZN2JSL9NullValueEv429($2);
  return;
}

function __ZN2JSL9NullValueEv429($agg_result) {
  __ZN2JS5Value7setNullEv($agg_result);
  return;
}

function __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $atom, $bytes) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $atom | 0;
  __ZN2JSL11StringValueEP8JSString478($1, $2);
  var $3 = $cx;
  var $4 = $bytes;
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $5 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($3, $_idx_val$0, $_idx_val$1, $4);
  STACKTOP = __stackBase__;
  return $5;
}

function __ZN2JSL11StringValueEP8JSString478($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __Z16js_InitAtomStateP9JSRuntime($rt) {
  var $1 = $rt + 209948 | 0;
  var $2 = __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE4initEj($1);
  return $2 & 1;
}

function __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj($1);
  return $2;
}

function __Z18js_FinishAtomStateP9JSRuntime($rt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $rt + 209948 | 0;
    var $2 = __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE11initializedEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE3allEv($r, $1);
    var $r_idx2 = $r | 0;
    var $r_idx2_val = HEAP32[$r_idx2 >> 2];
    var $r_idx3 = $r + 4 | 0;
    var $r_idx3_val = HEAP32[$r_idx3 >> 2];
    var $4 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r_idx2_val, $r_idx3_val);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      var $r_idx4_val = $r_idx2_val;
      __label__ = 3;
      break;
    }
   case 3:
    var $r_idx4_val;
    var $5 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($r_idx4_val);
    var $_idx_val = HEAP32[$5 >> 2];
    var $6 = __ZNK2js18TaggedPointerEntryI6JSAtomE5asPtrEv($_idx_val);
    __ZN6JSAtom8finalizeEP9JSRuntime($6);
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($r);
    var $r_idx_val = HEAP32[$r_idx2 >> 2];
    var $r_idx1_val = HEAP32[$r_idx3 >> 2];
    var $7 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r_idx_val, $r_idx1_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $r_idx4_val = $r_idx_val;
      __label__ = 3;
      break;
    }
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE11initializedEv($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  var $1 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11initializedEv($_idx_val);
  return $1;
}

function __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE3allEv($agg_result, $this) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $_idx1_val = HEAP32[$this + 20 >> 2];
  __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3allEv($agg_result, $_idx_val, $_idx1_val);
  return;
}

function __ZN6JSAtom8finalizeEP9JSRuntime($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js2gc4Cell12getAllocKindEv($1);
    if (($2 | 0) == 18) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = __ZN8JSString6asFlatEv($5);
    __ZN12JSFlatString8finalizeEP9JSRuntime($6);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 8 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$5 >> 2];
    var $8 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isLiveEv($_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18js_InitCommonAtomsP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 52 | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = $2 + 209948 | 0;
    var $4 = __ZN11JSAtomState16commonAtomsStartEv($3);
    var $i_0 = 0;
    var $atoms_0 = $4;
    __label__ = 2;
    break;
   case 2:
    var $atoms_0;
    var $i_0;
    if ($i_0 >>> 0 < 131) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = HEAP32[_js_common_atom_names + ($i_0 << 2) >> 2];
    var $10 = _strlen($9);
    var $11 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $9, $10, 1);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = __ZN6JSAtom14asPropertyNameEv($11);
    var $15 = $14 | 0;
    HEAP32[$atoms_0 >> 2] = $15;
    var $i_0 = $i_0 + 1 | 0;
    var $atoms_0 = $atoms_0 + 4 | 0;
    __label__ = 2;
    break;
   case 5:
    __ZN11JSAtomState14clearLazyAtomsEv($3);
    var $21 = HEAP32[$2 + 209972 >> 2] | 0;
    var $23 = HEAP32[$1 >> 2] + 144136 | 0;
    HEAP32[$23 >> 2] = $21;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $bytes, $length, $ib) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $inflated = __stackBase__;
    var $inflatedLength = __stackBase__ + 64;
    var $chars = __stackBase__ + 68;
    var $1 = __ZN2jsL17CheckStringLengthEP9JSContextj489($cx, $length);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    HEAP32[$inflatedLength >> 2] = 31;
    if ($length >>> 0 < 32) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$inflatedLength >> 2] = $length;
    var $5 = $cx;
    var $6 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($5, $bytes, $inflatedLength, 0);
    HEAP32[$chars >> 2] = $6;
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = $inflated | 0;
    var $10 = $cx;
    var $11 = __ZN2js21InflateStringToBufferEP9JSContextPKcjPtPj($10, $bytes, $length, $9, $inflatedLength);
    var $12 = HEAP32[$inflatedLength >> 2];
    HEAP16[$inflated + ($12 << 1) >> 1] = 0;
    HEAP32[$chars >> 2] = $9;
    var $14 = __ZL7AtomizeP9JSContextPPKtjN2js14InternBehaviorE16OwnCharsBehavior($cx, $chars, $12, $ib, 0);
    var $_0 = $14;
    __label__ = 7;
    break;
   case 5:
    var $16 = HEAP32[$inflatedLength >> 2];
    var $17 = __ZL7AtomizeP9JSContextPPKtjN2js14InternBehaviorE16OwnCharsBehavior($cx, $chars, $16, $ib, 1);
    var $18 = HEAP32[$chars >> 2];
    if (($18 | 0) == 0) {
      var $_0 = $17;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = $18;
    __ZN9JSContext5free_EPv($21);
    var $_0 = $17;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11JSAtomState14clearLazyAtomsEv($this) {
  var $2 = $this + 548 | 0;
  _memset($2, 0, 88, 1);
  return;
}

function __Z17js_TraceAtomStateP8JSTracer($trc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $r1 = __stackBase__ + 8;
    var $entry = __stackBase__ + 16;
    var $4 = HEAP32[HEAP32[$trc >> 2] + 52 >> 2];
    var $8 = $4 + 209948 | 0;
    if ((HEAP32[$4 + 136 >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE3allEv($r, $8);
    var $r_idx5 = $r | 0;
    var $r_idx5_val = HEAP32[$r_idx5 >> 2];
    var $r_idx6 = $r + 4 | 0;
    var $r_idx6_val = HEAP32[$r_idx6 >> 2];
    var $10 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r_idx5_val, $r_idx6_val);
    if ($10) {
      __label__ = 9;
      break;
    } else {
      var $r_idx8_val = $r_idx5_val;
      __label__ = 3;
      break;
    }
   case 3:
    var $r_idx8_val;
    var $11 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($r_idx8_val);
    var $_idx_val = HEAP32[$11 >> 2];
    var $12 = __ZNK2js18TaggedPointerEntryI6JSAtomE5asPtrEv($_idx_val);
    var $13 = $12 | 0;
    __ZN2js2gc10MarkStringEP8JSTracerP8JSString($trc, $13);
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($r);
    var $r_idx_val = HEAP32[$r_idx5 >> 2];
    var $r_idx4_val = HEAP32[$r_idx6 >> 2];
    var $14 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r_idx_val, $r_idx4_val);
    if ($14) {
      __label__ = 9;
      break;
    } else {
      var $r_idx8_val = $r_idx_val;
      __label__ = 3;
      break;
    }
   case 4:
    __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE3allEv($r1, $8);
    var $r1_idx2 = $r1 | 0;
    var $r1_idx2_val = HEAP32[$r1_idx2 >> 2];
    var $r1_idx3 = $r1 + 4 | 0;
    var $r1_idx3_val = HEAP32[$r1_idx3 >> 2];
    var $16 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r1_idx2_val, $r1_idx3_val);
    if ($16) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $entry_idx10 = $entry | 0;
    var $r1_idx7_val = $r1_idx2_val;
    __label__ = 6;
    break;
   case 6:
    var $r1_idx7_val;
    var $17 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($r1_idx7_val);
    var $_idx9_val = HEAP32[$17 >> 2];
    __ZN2js18TaggedPointerEntryI6JSAtomEC1ERKS2_($entry, $_idx9_val);
    var $entry_idx10_val = HEAP32[$entry_idx10 >> 2];
    var $18 = __ZNK2js18TaggedPointerEntryI6JSAtomE8isTaggedEv($entry_idx10_val);
    if ($18) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = __ZNK2js18TaggedPointerEntryI6JSAtomE5asPtrEv($entry_idx10_val);
    var $21 = $20 | 0;
    __ZN2js2gc10MarkStringEP8JSTracerP8JSString($trc, $21);
    __label__ = 8;
    break;
   case 8:
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($r1);
    var $r1_idx_val = HEAP32[$r1_idx2 >> 2];
    var $r1_idx1_val = HEAP32[$r1_idx3 >> 2];
    var $23 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r1_idx_val, $r1_idx1_val);
    if ($23) {
      __label__ = 9;
      break;
    } else {
      var $r1_idx7_val = $r1_idx_val;
      __label__ = 6;
      break;
    }
   case 9:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z17js_TraceAtomStateP8JSTracer["X"] = 1;

function __ZN2js18TaggedPointerEntryI6JSAtomEC1ERKS2_($this, $other_0_0_val) {
  __ZN2js18TaggedPointerEntryI6JSAtomEC2ERKS2_($this, $other_0_0_val);
  return;
}

function __Z17js_SweepAtomStateP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e = __stackBase__;
    var $entry = __stackBase__ + 16;
    var $1 = $cx + 52 | 0;
    var $3 = HEAP32[$1 >> 2] + 209948 | 0;
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC1IS9_EERT_($e, $3);
    var $4 = $e | 0;
    var $_idx2 = $e | 0;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $_idx3 = $e + 4 | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $5 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($_idx2_val, $_idx3_val);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $entry_idx6 = $entry | 0;
    var $_idx4_val = $_idx2_val;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD1Ev($e);
    STACKTOP = __stackBase__;
    return;
   case 4:
    var $_idx4_val;
    var $6 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($_idx4_val);
    var $_idx5_val = HEAP32[$6 >> 2];
    __ZN2js18TaggedPointerEntryI6JSAtomEC1ERKS2_($entry, $_idx5_val);
    var $entry_idx6_val = HEAP32[$entry_idx6 >> 2];
    var $7 = __ZNK2js18TaggedPointerEntryI6JSAtomE8isTaggedEv($entry_idx6_val);
    if ($7) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZNK2js18TaggedPointerEntryI6JSAtomE5asPtrEv($entry_idx6_val);
    var $10 = $9;
    var $cx_idx_val_idx_val = HEAP32[HEAP32[$1 >> 2] + 144080 >> 2];
    var $11 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx_idx_val_idx_val, $10);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4Enum11removeFrontEv($e);
    __label__ = 7;
    break;
   case 7:
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($4);
    var $_idx_val = HEAP32[$_idx2 >> 2];
    var $_idx1_val = HEAP32[$_idx3 >> 2];
    var $14 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($_idx_val, $_idx1_val);
    if ($14) {
      __label__ = 3;
      break;
    } else {
      var $_idx4_val = $_idx_val;
      __label__ = 4;
      break;
    }
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC1IS9_EERT_($this, $map) {
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC2IS9_EERT_($this, $map);
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS5_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD2Ev($this);
  return;
}

function __ZN2js24AutoLockAtomsCompartmentC1EP9JSContext($this, $cx) {
  __ZN2js24AutoLockAtomsCompartmentC2EP9JSContext($this, $cx);
  return;
}

function __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE6lookupERKNS4_6LookupE($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERKNS7_6LookupE($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 74,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($cx, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $chars = __stackBase__;
    var $str_idx1_val = HEAP32[$str >> 2];
    var $1 = __ZNK8JSString6isAtomEv($str_idx1_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK8JSString6asAtomEv($str);
    var $_0 = $3;
    __label__ = 5;
    break;
   case 3:
    var $5 = __ZN8JSString8getCharsEP9JSContext($str, $cx);
    HEAP32[$chars >> 2] = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZNK8JSString6lengthEv($str_idx1_val);
    var $9 = __ZL7AtomizeP9JSContextPPKtjN2js14InternBehaviorE16OwnCharsBehavior($cx, $chars, $8, 0, 0);
    var $_0 = $9;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL7AtomizeP9JSContextPPKtjN2js14InternBehaviorE16OwnCharsBehavior($cx, $pchars, $length, $ib, $ocb) {
  var $1 = __ZL13AtomizeInlineP9JSContextPPKtjN2js14InternBehaviorE16OwnCharsBehavior($cx, $pchars, $length, $ib, $ocb);
  return $1;
}

function __ZN2jsL17CheckStringLengthEP9JSContextj489($cx, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 268435455) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    __Z27js_ReportAllocationOverflowP9JSContext($cx);
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($cx, $chars, $length, $ib) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $chars;
    var $2 = __ZN2jsL17CheckStringLengthEP9JSContextj489($cx, $length);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZL13AtomizeInlineP9JSContextPPKtjN2js14InternBehaviorE16OwnCharsBehavior($cx, $1, $length, $ib, 0);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK7mozilla9RangedPtrItE3getEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK7mozilla9RangedPtrItEdeEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS3_($t) {
  return $t;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($this_0_0_val, $this_0_1_val) {
  return ($this_0_0_val | 0) == ($this_0_1_val | 0);
}

function __ZNK7mozilla9RangedPtrItEmiERKS1_($this_0_0_val, $other_0_0_val) {
  return ($this_0_0_val - $other_0_0_val | 0) >>> 1;
}

function _INT_TO_JSID501($i) {
  return $i << 1 | 1;
}

function __ZNK8JSObject5isXMLEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js8XMLClassE | 0);
}

function _OBJECT_TO_JSID502($obj) {
  return $obj | 4;
}

function _JSID_TO_STRING504($iden) {
  return $iden;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZNK2js9InlineMapIP6JSAtomjLj24EE8usingMapEv($this_0_0_val) {
  return $this_0_0_val >>> 0 > 24;
}

function __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZNK2js9InlineMapIP6JSAtomjLj24EE5asMapEv($this) {
  return $this + 200 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZNK2js9InlineMapIP6JSAtomjLj24EE8asInlineEv($this) {
  return $this + 8 | 0;
}

function __ZNK2js9InlineMapIP6JSAtomjLj24EE9inlineEndEv($this) {
  return $this + 8 + (HEAP32[$this >> 2] << 3) | 0;
}

function __ZN7mozilla9RangedPtrItEaSItEERS1_RKNS0_IT_EE($this, $p_0_0_val) {
  HEAP32[$this >> 2] = $p_0_0_val;
  return;
}

function __ZN7mozilla9RangedPtrItEC2EPtS2_j($this, $p) {
  HEAP32[$this >> 2] = $p;
  return;
}

function __ZN7mozilla9RangedPtrItEC2EPtS2_S2_($this, $p) {
  HEAP32[$this >> 2] = $p;
  return;
}

function __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js9HashCharsEPKtj($chars, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($length | 0) == 0) {
      var $h_0_lcssa = 0;
      __label__ = 3;
      break;
    } else {
      var $h_02 = 0;
      var $_013 = $length;
      var $_04 = $chars;
      __label__ = 2;
      break;
    }
   case 2:
    var $_04;
    var $_013;
    var $h_02;
    var $7 = HEAPU16[$_04 >> 1] & 65535 ^ ($h_02 << 4 | $h_02 >>> 28);
    var $9 = $_013 - 1 | 0;
    if (($9 | 0) == 0) {
      var $h_0_lcssa = $7;
      __label__ = 3;
      break;
    } else {
      var $h_02 = $7;
      var $_013 = $9;
      var $_04 = $_04 + 2 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    var $h_0_lcssa;
    return $h_0_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13AtomizeInlineP9JSContextPPKtjN2js14InternBehaviorE16OwnCharsBehavior($cx, $pchars, $length, $ib, $ocb) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lock = __stackBase__;
    var $p = __stackBase__ + 4;
    var $1 = __stackBase__ + 12;
    var $2 = __stackBase__ + 24;
    var $sc = __stackBase__ + 32;
    var $lookup = __stackBase__ + 44;
    var $3 = __stackBase__ + 56;
    var $4 = HEAP32[$pchars >> 2];
    var $5 = $cx + 52 | 0;
    var $7 = HEAP32[$5 >> 2] + 210584 | 0;
    var $8 = __ZN2js13StaticStrings6lookupEPKtj($7, $4, $length);
    if (($8 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_2 = $8;
      __label__ = 12;
      break;
    }
   case 2:
    __ZN2js24AutoLockAtomsCompartmentC1EP9JSContext($lock, $cx);
    var $12 = HEAP32[$5 >> 2] + 209948 | 0;
    __ZN2js10AtomHasher6LookupC1EPKtj($1, $4, $length);
    __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE12lookupForAddERKNS4_6LookupE($p, $12, $1);
    var $_idx1_val = HEAP32[$p >> 2];
    var $_idx1_val_idx_val = HEAP32[$_idx1_val >> 2];
    __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($2, $_idx1_val_idx_val);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrptEv($_idx1_val);
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js18TaggedPointerEntryI6JSAtomE5asPtrEv($_idx_val);
    var $19 = ($ib | 0) != 0;
    __ZNK2js18TaggedPointerEntryI6JSAtomE9setTaggedEb($17, $19);
    var $_2 = $18;
    __label__ = 12;
    break;
   case 4:
    var $23 = HEAP32[HEAP32[$5 >> 2] >> 2];
    __ZN2js19SwitchToCompartmentC1EP9JSContextP13JSCompartment($sc, $cx, $23);
    var $25 = $cx;
    if (($ocb | 0) == 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $27 = __Z12js_NewStringP9JSContextPtj($25, $4, $length);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    HEAP32[$pchars >> 2] = 0;
    var $key_0 = $27;
    __label__ = 8;
    break;
   case 7:
    var $31 = __Z17js_NewStringCopyNP9JSContextPKtj($25, $4, $length);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      var $key_0 = $31;
      __label__ = 8;
      break;
    }
   case 8:
    var $key_0;
    __ZN2js10AtomHasher6LookupC1EPKtj($lookup, $4, $length);
    var $35 = ($ib | 0) != 0;
    __ZN2js18TaggedPointerEntryI6JSAtomEC1EPS1_b($3, $key_0, $35);
    var $36 = __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE13relookupOrAddERNS_6detail9HashTableIKS3_NS6_6SetOpsES5_E6AddPtrERKNS4_6LookupERS9_($12, $p, $lookup, $3);
    if ($36) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    _JS_ReportOutOfMemory($cx);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 10:
    var $39 = __ZN13JSFixedString27morphAtomizedStringIntoAtomEv($key_0);
    var $_0 = $39;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    __ZN2js19SwitchToCompartmentD1Ev($sc);
    var $_2 = $_0;
    __label__ = 12;
    break;
   case 12:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13AtomizeInlineP9JSContextPPKtjN2js14InternBehaviorE16OwnCharsBehavior["X"] = 1;

function __Z24js_GetExistingStringAtomP9JSContextPKtj($cx, $chars, $length) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lock = __stackBase__;
    var $p = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 20;
    var $3 = $cx + 52 | 0;
    var $5 = HEAP32[$3 >> 2] + 210584 | 0;
    var $6 = __ZN2js13StaticStrings6lookupEPKtj($5, $chars, $length);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $6;
      __label__ = 4;
      break;
    }
   case 2:
    __ZN2js24AutoLockAtomsCompartmentC1EP9JSContext($lock, $cx);
    var $10 = HEAP32[$3 >> 2] + 209948 | 0;
    __ZN2js10AtomHasher6LookupC1EPKtj($1, $chars, $length);
    __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE6lookupERKNS4_6LookupE($p, $10, $1);
    var $p_idx_val = HEAP32[$p >> 2];
    var $p_idx_val_idx_val = HEAP32[$p_idx_val >> 2];
    __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($2, $p_idx_val_idx_val);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrptEv($p_idx_val);
    var $_idx_val = HEAP32[$15 >> 2];
    var $16 = __ZNK2js18TaggedPointerEntryI6JSAtomE5asPtrEv($_idx_val);
    var $_0 = $16;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13StaticStrings6lookupEPKtj($this, $chars, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($length | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($length | 0) == 2) {
      __label__ = 4;
      break;
    } else if (($length | 0) == 3) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 2:
    var $2 = HEAPU16[$chars >> 1];
    if (($2 & 65535) < 256) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 3:
    var $5 = __ZN2js13StaticStrings7getUnitEt($this, $2);
    var $_0 = $5;
    __label__ = 12;
    break;
   case 4:
    var $7 = HEAPU16[$chars >> 1];
    var $8 = __ZN2js13StaticStrings15fitsInSmallCharEt($7);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 5:
    var $11 = HEAP16[$chars + 2 >> 1];
    var $12 = __ZN2js13StaticStrings15fitsInSmallCharEt($11);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 6:
    var $14 = __ZN2js13StaticStrings10getLength2Ett($this, $7, $11);
    var $_0 = $14;
    __label__ = 12;
    break;
   case 7:
    var $16 = HEAPU16[$chars >> 1];
    var $17 = $16 & 65535;
    if (($16 - 49 & 65535 & 65535) < 9) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 8:
    var $21 = HEAPU16[$chars + 2 >> 1];
    var $22 = $21 & 65535;
    if (($21 - 48 & 65535 & 65535) < 10) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 9:
    var $26 = HEAPU16[$chars + 4 >> 1];
    if (($26 - 48 & 65535 & 65535) < 10) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 10:
    var $34 = $17 * 100 - 5328 + $22 * 10 + ($26 & 65535) | 0;
    if ($34 >>> 0 < 256) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 11:
    var $37 = __ZN2js13StaticStrings6getIntEi($this, $34);
    var $_0 = $37;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10AtomHasher6LookupC1EPKtj($this, $chars, $length) {
  __ZN2js10AtomHasher6LookupC2EPKtj($this, $chars, $length);
  return;
}

function __Z14js_InitAtomMapP9JSContextPN2js9InlineMapIP6JSAtomjLj24EEEPS4_($indices, $atoms) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $indices_idx_val = HEAP32[$indices >> 2];
    var $1 = __ZNK2js9InlineMapIP6JSAtomjLj24EE5isMapEv($indices_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZNK2js9InlineMapIP6JSAtomjLj24EE5asMapEv($indices);
    __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3allEv($r, $3);
    var $r_idx2 = $r | 0;
    var $r_idx2_val = HEAP32[$r_idx2 >> 2];
    var $r_idx3 = $r + 4 | 0;
    var $r_idx3_val = HEAP32[$r_idx3 >> 2];
    var $4 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r_idx2_val, $r_idx3_val);
    if ($4) {
      __label__ = 8;
      break;
    } else {
      var $r_idx4_val = $r_idx2_val;
      __label__ = 3;
      break;
    }
   case 3:
    var $r_idx4_val;
    var $5 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($r_idx4_val);
    var $7 = HEAP32[$5 >> 2];
    var $10 = $atoms + (HEAP32[$5 + 4 >> 2] << 2) | 0;
    HEAP32[$10 >> 2] = $7;
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($r);
    var $r_idx_val = HEAP32[$r_idx2 >> 2];
    var $r_idx1_val = HEAP32[$r_idx3 >> 2];
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r_idx_val, $r_idx1_val);
    if ($11) {
      __label__ = 8;
      break;
    } else {
      var $r_idx4_val = $r_idx_val;
      __label__ = 3;
      break;
    }
   case 4:
    var $13 = __ZNK2js9InlineMapIP6JSAtomjLj24EE8asInlineEv($indices);
    var $14 = __ZNK2js9InlineMapIP6JSAtomjLj24EE9inlineEndEv($indices);
    if (($13 | 0) == ($14 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $it_01 = $13;
      __label__ = 5;
      break;
    }
   case 5:
    var $it_01;
    var $17 = HEAP32[$it_01 >> 2];
    if (($17 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = $atoms + (HEAP32[$it_01 + 4 >> 2] << 2) | 0;
    HEAP32[$22 >> 2] = $17;
    __label__ = 7;
    break;
   case 7:
    var $24 = $it_01 + 8 | 0;
    if (($24 | 0) == ($14 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $it_01 = $24;
      __label__ = 5;
      break;
    }
   case 8:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js9InlineMapIP6JSAtomjLj24EE5isMapEv($this_0_0_val) {
  var $1 = __ZNK2js9InlineMapIP6JSAtomjLj24EE8usingMapEv($this_0_0_val);
  return $1;
}

function __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3allEv($agg_result, $this) {
  var $_idx_val = HEAP32[$this + 8 >> 2];
  var $_idx1_val = HEAP32[$this + 24 >> 2];
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $_idx_val, $_idx1_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$5 >> 2];
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isLiveEv($_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13IndexToIdSlowEP9JSContextjPi($cx, $index, $idp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $end = __stackBase__ + 20;
    var $start = __stackBase__ + 24;
    var $1 = __stackBase__ + 20 | 0;
    __ZN7mozilla9RangedPtrItEC1EPtS2_S2_($end, $1);
    var $3 = HEAP32[$end >> 2];
    __ZN2js25BackfillIndexInCharBufferItEEN7mozilla9RangedPtrIT_EEjS4_($start, $index, $3);
    var $start_idx_val = HEAP32[$start >> 2];
    var $4 = __ZNK7mozilla9RangedPtrItE3getEv($start_idx_val);
    var $5 = __ZNK7mozilla9RangedPtrItEmiERKS1_($3, $start_idx_val);
    var $6 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($cx, $4, $5, 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZL12ATOM_TO_JSIDP6JSAtom496($6);
    HEAP32[$idp >> 2] = $9;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla9RangedPtrItEC1EPtS2_S2_($this, $p) {
  __ZN7mozilla9RangedPtrItEC2EPtS2_S2_($this, $p);
  return;
}

function __ZN2js25BackfillIndexInCharBufferItEEN7mozilla9RangedPtrIT_EEjS4_($agg_result, $index, $end_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $end = __stackBase__;
    var $_01 = $end | 0;
    HEAP32[$_01 >> 2] = $end_0;
    var $_0 = $index;
    __label__ = 2;
    break;
   case 2:
    var $_0;
    var $2 = Math.floor(($_0 >>> 0) / 10);
    var $5 = (($_0 >>> 0) % 10 | 48) & 65535;
    var $6 = __ZN7mozilla9RangedPtrItEmmEv($end);
    var $_idx_val = HEAP32[$6 >> 2];
    var $7 = __ZNK7mozilla9RangedPtrItEdeEv($_idx_val);
    HEAP16[$7 >> 1] = $5;
    if ($_0 >>> 0 > 9) {
      var $_0 = $2;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = HEAP32[$_01 >> 2];
    HEAP32[$agg_result >> 2] = $10;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12ATOM_TO_JSIDP6JSAtom496($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj522($1);
  return $2;
}

function __Z22js_CheckForStringIndexi($id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL12JSID_IS_ATOMi499($id);
    if (($1 | 0) == 0) {
      var $_0 = $id;
      __label__ = 18;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZL12JSID_TO_ATOMi500($id);
    var $_idx1_val = HEAP32[$4 + 4 >> 2];
    var $5 = __ZNK14JSLinearString5charsEv($_idx1_val);
    var $6 = HEAPU16[$5 >> 1];
    var $7 = $6 << 16 >> 16 == 45;
    var $8 = $7 & 1;
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $s_0 = $5;
      var $13 = $6;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = $5 + 2 | 0;
    var $s_0 = $10;
    var $13 = HEAP16[$10 >> 1];
    __label__ = 4;
    break;
   case 4:
    var $13;
    var $s_0;
    var $15 = ($13 & 65535) - 48 | 0;
    if ($15 >>> 0 < 10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $id;
      __label__ = 18;
      break;
    }
   case 5:
    var $_idx_val = HEAP32[$4 >> 2];
    var $18 = __ZNK8JSString6lengthEv($_idx_val);
    var $19 = $18 - $8 | 0;
    if ($19 >>> 0 > 10) {
      var $_0 = $id;
      __label__ = 18;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = $s_0 + ($19 << 1) | 0;
    var $23 = $s_0 + 2 | 0;
    if (($15 | 0) == 0) {
      var $c_1 = 0;
      var $oldIndex_1 = 0;
      var $index_1 = 0;
      var $cp_1 = $23;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $26 = HEAPU16[$23 >> 1] & 65535;
    if (($26 - 48 | 0) >>> 0 < 10) {
      var $cp_04 = $23;
      var $index_05 = $15;
      var $29 = $26;
      __label__ = 8;
      break;
    } else {
      var $c_1 = 0;
      var $oldIndex_1 = 0;
      var $index_1 = $15;
      var $cp_1 = $23;
      __label__ = 9;
      break;
    }
   case 8:
    var $29;
    var $index_05;
    var $cp_04;
    var $30 = $29 - 48 | 0;
    var $32 = $30 + $index_05 * 10 | 0;
    var $33 = $cp_04 + 2 | 0;
    var $35 = HEAPU16[$33 >> 1] & 65535;
    if (($35 - 48 | 0) >>> 0 < 10) {
      var $cp_04 = $33;
      var $index_05 = $32;
      var $29 = $35;
      __label__ = 8;
      break;
    } else {
      var $c_1 = $30;
      var $oldIndex_1 = $index_05;
      var $index_1 = $32;
      var $cp_1 = $33;
      __label__ = 9;
      break;
    }
   case 9:
    var $cp_1;
    var $index_1;
    var $oldIndex_1;
    var $c_1;
    if (($cp_1 | 0) == ($22 | 0)) {
      __label__ = 10;
      break;
    } else {
      var $_0 = $id;
      __label__ = 18;
      break;
    }
   case 10:
    if ($7 & ($index_1 | 0) == 0) {
      var $_0 = $id;
      __label__ = 18;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $42 = $oldIndex_1 >>> 0 < 107374182;
    if ($7) {
      __label__ = 12;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 12:
    if ($42) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if (($oldIndex_1 | 0) == 107374182 & $c_1 >>> 0 < 5) {
      __label__ = 14;
      break;
    } else {
      var $_0 = $id;
      __label__ = 18;
      break;
    }
   case 14:
    var $49 = _INT_TO_JSID501(-$index_1 | 0);
    var $_0 = $49;
    __label__ = 18;
    break;
   case 15:
    if ($42) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if (($oldIndex_1 | 0) == 107374182 & $c_1 >>> 0 < 4) {
      __label__ = 17;
      break;
    } else {
      var $_0 = $id;
      __label__ = 18;
      break;
    }
   case 17:
    var $55 = _INT_TO_JSID501($index_1);
    var $_0 = $55;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z22js_CheckForStringIndexi["X"] = 1;

function __ZL12JSID_IS_ATOMi499($id) {
  var $1 = _JSID_IS_STRING508($id);
  return $1;
}

function __ZL12JSID_TO_ATOMi500($id) {
  var $1 = _JSID_TO_STRING504($id);
  return $1;
}

function __Z28js_InternNonIntElementIdSlowP9JSContextP8JSObjectRKN2JS5ValueEPi($cx, $obj_0_1_val, $idval, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject5isXMLEv($obj_0_1_val);
    var $idval_idx = $idval | 0;
    var $idval_idx_val$0 = HEAP32[$idval_idx >> 2];
    var $idval_idx_val$1 = HEAP32[$idval_idx + 4 >> 2];
    var $2 = __ZNK2JS5Value8toObjectEv($idval_idx_val$0, $idval_idx_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = _OBJECT_TO_JSID502($2);
    HEAP32[$idp >> 2] = $4;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $6 = $2;
    var $7 = $cx;
    var $8 = __Z32js_GetLocalNameFromFunctionQNameP8JSObjectPiP9JSContext($6, $idp, $7);
    if ($8) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $idval_idx1_val$0 = HEAP32[$idval_idx >> 2];
    var $idval_idx1_val$1 = HEAP32[$idval_idx + 4 >> 2];
    var $10 = __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($cx, $idval_idx1_val$0, $idval_idx1_val$1, $idp);
    var $_0 = $10;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z28js_InternNonIntElementIdSlowP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $obj_0_1_val, $idval, $idp, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK8JSObject5isXMLEv($obj_0_1_val);
    var $idval_idx = $idval | 0;
    var $st$3$0 = $idval_idx | 0;
    var $idval_idx_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $idval_idx + 4 | 0;
    var $idval_idx_val$1 = HEAP32[$st$3$1 >> 2];
    var $3 = __ZNK2JS5Value8toObjectEv($idval_idx_val$0, $idval_idx_val$1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = _OBJECT_TO_JSID502($3);
    HEAP32[$idp >> 2] = $5;
    __ZN2JS5Value9setObjectER8JSObject($vp, $3);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 3:
    var $7 = $3;
    var $8 = $cx;
    var $9 = __Z32js_GetLocalNameFromFunctionQNameP8JSObjectPiP9JSContext($7, $idp, $8);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = HEAP32[$idp >> 2];
    __ZN2jsL9IdToValueEi503($1, $11);
    var $12 = $1 | 0;
    var $st$3$0 = $12 | 0;
    var $13$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $12 + 4 | 0;
    var $13$1 = HEAP32[$st$3$1 >> 2];
    var $14 = $vp | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 5:
    var $idval_idx1_val$0 = HEAP32[$idval_idx >> 2];
    var $idval_idx1_val$1 = HEAP32[$idval_idx + 4 >> 2];
    var $16 = __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($cx, $idval_idx1_val$0, $idval_idx1_val$1, $idp);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $18 = HEAP32[$idp >> 2];
    var $19 = _JSID_TO_STRING504($18);
    __ZN2JS5Value9setStringEP8JSString($vp, $19);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9IdToValueEi503($agg_result, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_STRING508($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_STRING504($id);
    __ZN2JSL11StringValueEP8JSString478($agg_result, $4);
    __label__ = 8;
    break;
   case 3:
    var $6 = _JSID_IS_INT509($id);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _JSID_TO_INT511($id);
    __ZN2JSL10Int32ValueEi510($agg_result, $9);
    __label__ = 8;
    break;
   case 5:
    var $11 = _JSID_IS_OBJECT512($id);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = _JSID_TO_OBJECT514($id);
    __ZN2JSL11ObjectValueER8JSObject513($agg_result, $14);
    __label__ = 8;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv515($agg_result);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla9RangedPtrItEmmEv($this) {
  var $1 = __ZN7mozilla9RangedPtrItEmIEj($this);
  return $1;
}

function __ZN7mozilla9RangedPtrItEmIEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $this_idx_val = HEAP32[$this >> 2];
  __ZN7mozilla9RangedPtrItEmiEj($1, $this_idx_val);
  var $_idx_val = HEAP32[$1 >> 2];
  __ZN7mozilla9RangedPtrItEaSItEERS1_RKNS0_IT_EE($this, $_idx_val);
  STACKTOP = __stackBase__;
  return $this;
}

function __ZN7mozilla9RangedPtrItEmiEj($agg_result, $this_0_0_val) {
  var $1 = $this_0_0_val - 2 | 0;
  __ZNK7mozilla9RangedPtrItE6createEPt($agg_result, $1);
  return;
}

function __ZNK7mozilla9RangedPtrItE6createEPt($agg_result, $ptr) {
  __ZN7mozilla9RangedPtrItEC1EPtS2_j($agg_result, $ptr);
  return;
}

function __ZN7mozilla9RangedPtrItEC1EPtS2_j($this, $p) {
  __ZN7mozilla9RangedPtrItEC2EPtS2_j($this, $p);
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $this_0_2_val, $this_0_6_val) {
  var $1 = $this_0_6_val + $this_0_2_val * 12 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_($agg_result, $this_0_6_val, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$4 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isLiveEv($_idx_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERKNS7_6LookupE($agg_result, $this, $l) {
  var $l_idx_val = HEAP32[$l >> 2];
  var $l_idx1_val = HEAP32[$l + 4 >> 2];
  var $1 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERKNS7_6LookupE($l_idx_val, $l_idx1_val);
  var $2 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERKNS7_6LookupEjj($this, $l, $1, 0);
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS5_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERKNS7_6LookupE($l_0_0_val, $l_0_1_val) {
  var $1 = __ZN2js10AtomHasher4hashERKNS0_6LookupE($l_0_0_val, $l_0_1_val);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry);
  return;
}

function __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERKNS7_6LookupEjj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 3) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS5_EERKNS7_6LookupE($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + ($26 << 3) | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS5_EERKNS7_6LookupE($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERKNS7_6LookupEjj["X"] = 1;

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS5_EERKNS7_6LookupE($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS3_($1);
  var $_idx_val = HEAP32[$2 >> 2];
  var $3 = __ZN2js10AtomHasher5matchERKNS_18TaggedPointerEntryI6JSAtomEERKNS0_6LookupE($_idx_val, $l);
  return $3;
}

function __ZN2js10AtomHasher5matchERKNS_18TaggedPointerEntryI6JSAtomEERKNS0_6LookupE($entry_0_0_val, $lookup) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js18TaggedPointerEntryI6JSAtomE5asPtrEv($entry_0_0_val);
    var $3 = HEAP32[$lookup + 8 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = ($3 | 0) == ($1 | 0);
    __label__ = 5;
    break;
   case 3:
    var $_idx_val = HEAP32[$1 >> 2];
    var $8 = __ZNK8JSString6lengthEv($_idx_val);
    var $10 = HEAP32[$lookup + 4 >> 2];
    if (($8 | 0) == ($10 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx1_val = HEAP32[$1 + 4 >> 2];
    var $13 = __ZNK14JSLinearString5charsEv($_idx1_val);
    var $15 = HEAP32[$lookup >> 2];
    var $16 = __ZN2jsL8PodEqualIKtEEbPT_S3_j($13, $15, $10);
    var $_0 = $16;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL8PodEqualIKtEEbPT_S3_j($one, $two, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($len >>> 0 < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $3 = $one + ($len << 1) | 0;
    var $p2_0 = $two;
    var $p1_0 = $one;
    __label__ = 3;
    break;
   case 3:
    var $p1_0;
    var $p2_0;
    if (($p1_0 | 0) == ($3 | 0)) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (HEAP16[$p1_0 >> 1] << 16 >> 16 == HEAP16[$p2_0 >> 1] << 16 >> 16) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $p2_0 = $p2_0 + 2 | 0;
    var $p1_0 = $p1_0 + 2 | 0;
    __label__ = 3;
    break;
   case 6:
    var $14 = $one;
    var $15 = $two;
    var $16 = $len << 1;
    var $17 = _memcmp($14, $15, $16);
    var $_0 = ($17 | 0) == 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10AtomHasher4hashERKNS0_6LookupE($l_0_0_val, $l_0_1_val) {
  var $1 = __ZN2js9HashCharsEPKtj($l_0_0_val, $l_0_1_val);
  return $1;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE10isLiveHashEj($hash);
  return $1;
}

function __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_18TaggedPointerEntryI6JSAtomEEEcvRS3_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZL14JSID_FROM_BITSj522($bits) {
  return $bits;
}

function _JSVAL_TO_BOOLEAN_IMPL($l_0$0, $l_0$1) {
  return $l_0$0;
}

function __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE12hasCollisionEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11initializedEv($this_0_5_val) {
  return ($this_0_5_val | 0) != 0;
}

function _JSID_IS_STRING508($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_IS_INT509($iden) {
  return $iden & 1;
}

function _JSID_TO_INT511($iden) {
  return $iden >> 1;
}

function _JSID_IS_OBJECT512($iden) {
  return ($iden & 7 | 0) == 4 & ($iden | 0) != 4 & 1;
}

function _JSID_TO_OBJECT514($iden) {
  return $iden & -8;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv($this_0_1_val, $this_0_2_val, $this_0_4_val) {
  return ($this_0_4_val + $this_0_2_val | 0) >>> 0 >= ($this_0_1_val * 192 | 0) >>> 8 >>> 0;
}

function __ZL15JSDOUBLE_IS_NaNd535($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZN2js18TaggedPointerEntryI6JSAtomEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEC2ERS7_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_18TaggedPointerEntryI6JSAtomEEEC2ERS3_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js18TaggedPointerEntryI6JSAtomEC2ERKS2_($this, $other_0_0_val) {
  HEAP32[$this >> 2] = $other_0_0_val;
  return;
}

function __ZN2js10AtomHasher6LookupC2EPKtj($this, $chars, $length) {
  HEAP32[$this >> 2] = $chars;
  HEAP32[$this + 4 >> 2] = $length;
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN2js13StaticStrings7getUnitEt($this, $c) {
  return HEAP32[$this + 17412 + (($c & 65535) << 2) >> 2];
}

function __ZN2js13StaticStrings10getLength2Ett($this, $c1, $c2) {
  var $2 = STRING_TABLE.__ZN2js13StaticStrings11toSmallCharE + ($c1 & 65535) | 0;
  var $7 = STRING_TABLE.__ZN2js13StaticStrings11toSmallCharE + ($c2 & 65535) | 0;
  return HEAP32[$this + 4 + (((HEAPU8[$2] & 255) << 6) + (HEAPU8[$7] & 255) << 2) >> 2];
}

function __ZN2js13StaticStrings7getUintEj($this, $u) {
  return HEAP32[$this + 16388 + ($u << 2) >> 2];
}

function __ZN2js18TaggedPointerEntryI6JSAtomEC2EPS1_b($this, $ptr, $tagged) {
  HEAP32[$this >> 2] = $tagged & 1 | $ptr;
  return;
}

function __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js24AutoLockAtomsCompartmentC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  return;
}

function __Z18js_BooleanToStringP9JSContexti($cx_0_11_val, $b) {
  return HEAP32[$cx_0_11_val + 209976 + ((($b | 0) != 0 & 1) << 2) >> 2] | 0;
}

function __ZN2js2gcL15GetGCObjectKindEjb560($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS5_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e_idx_val = HEAP32[$e >> 2];
    var $1 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE12hasCollisionEv($e_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  __ZN2js18TaggedPointerEntryI6JSAtomEC1Ev($1);
  var $4 = HEAP32[$1 >> 2];
  HEAP32[$this + 4 >> 2] = $4;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  __ZN2js18TaggedPointerEntryI6JSAtomEC1Ev($1);
  var $4 = HEAP32[$1 >> 2];
  HEAP32[$this + 4 >> 2] = $4;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js18TaggedPointerEntryI6JSAtomEC1Ev($this) {
  __ZN2js18TaggedPointerEntryI6JSAtomEC2Ev($this);
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j($10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + ($5 << 3) | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 5;
    break;
   case 5:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $22 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isLiveEv($src_01_idx_val);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE10getKeyHashEv($src_01_idx1_val);
    var $25 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEENS_7MoveRefIT_EERS9_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEaSENS_7MoveRefIS6_EE($25, $_02_val);
    __label__ = 7;
    break;
   case 7:
    var $27 = $src_01 + 8 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj($3);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j($capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 3;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej($1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + ($capacity << 3) | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 8 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 3) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + ($15 << 3) | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEaSENS_7MoveRefIS6_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $2 + 4 | 0;
  __ZN2js4MoveINS_18TaggedPointerEntryI6JSAtomEEEENS_7MoveRefIT_EERS5_($1, $6);
  var $_idx_val = HEAP32[$1 >> 2];
  var $7 = __ZNK2js7MoveRefINS_18TaggedPointerEntryI6JSAtomEEEcvRS3_Ev($_idx_val);
  var $9 = HEAP32[$7 >> 2];
  HEAP32[$this + 4 >> 2] = $9;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEENS_7MoveRefIT_EERS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEC1ERS7_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEC2ERS7_($this, $t);
  return;
}

function __ZN2js4MoveINS_18TaggedPointerEntryI6JSAtomEEEENS_7MoveRefIT_EERS5_($agg_result, $t) {
  __ZN2js7MoveRefINS_18TaggedPointerEntryI6JSAtomEEEC1ERS3_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_18TaggedPointerEntryI6JSAtomEEEC1ERS3_($this, $t) {
  __ZN2js7MoveRefINS_18TaggedPointerEntryI6JSAtomEEEC2ERS3_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js18TaggedPointerEntryI6JSAtomEC1Ev($2);
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC2IS9_EERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE3allEv($1, $map);
  var $2 = $1;
  var $3 = $this;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  HEAP32[$this + 8 >> 2] = $map | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3allEv($agg_result, $this_0_1_val, $this_0_5_val) {
  var $1 = $this_0_5_val + ($this_0_1_val << 3) | 0;
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC1EPNS0_14HashTableEntryIS5_EESF_($agg_result, $this_0_5_val, $1);
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC1EPNS0_14HashTableEntryIS5_EESF_($this, $c, $e) {
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC2EPNS0_14HashTableEntryIS5_EESF_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC2EPNS0_14HashTableEntryIS5_EESF_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$4 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isLiveEv($_idx_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 8 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $roundUp_01 = 16;
    var $roundUpLog2_02 = 4;
    __label__ = 2;
    break;
   case 2:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $1 = $roundUp_01 << 1;
    var $2 = $roundUpLog2_02 + 1 | 0;
    if ($1 >>> 0 < 1368) {
      var $roundUp_01 = $1;
      var $roundUpLog2_02 = $2;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $4 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j($1);
    HEAP32[$this + 20 >> 2] = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $2);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL10Int32ValueEi510($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZN2JSL11ObjectValueER8JSObject513($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN2JSL14UndefinedValueEv515($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2js13StaticStrings6getIntEi($this, $i) {
  var $1 = __ZN2js13StaticStrings7getUintEj($this, $i);
  return $1;
}

function __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE12lookupForAddERKNS4_6LookupE($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERKNS7_6LookupE($agg_result, $1, $l);
  return;
}

function __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE13relookupOrAddERNS_6detail9HashTableIKS3_NS6_6SetOpsES5_E6AddPtrERKNS4_6LookupERS9_($this, $p, $l, $t) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E13relookupOrAddERNSB_6AddPtrERKNS7_6LookupERS5_($1, $p, $l, $t);
  return $2;
}

function __ZN2js18TaggedPointerEntryI6JSAtomEC1EPS1_b($this, $ptr, $tagged) {
  __ZN2js18TaggedPointerEntryI6JSAtomEC2EPS1_b($this, $ptr, $tagged);
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E13relookupOrAddERNSB_6AddPtrERKNS7_6LookupERS5_($this, $p, $l, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$p + 4 >> 2];
    var $3 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERKNS7_6LookupEjj($this, $l, $2, 1);
    HEAP32[$p >> 2] = $3;
    var $_idx_val_idx_val = HEAP32[$3 >> 2];
    var $5 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv($_idx_val_idx_val);
    if ($5) {
      var $9 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS5_($this, $p, $t);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS5_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = HEAP32[$t >> 2];
    var $7 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$7 >> 2] = $6;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 8 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 16 >> 2];
    var $12 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERKNS7_6LookupE($agg_result, $this, $l) {
  var $l_idx_val = HEAP32[$l >> 2];
  var $l_idx1_val = HEAP32[$l + 4 >> 2];
  var $1 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERKNS7_6LookupE($l_idx_val, $l_idx1_val);
  var $2 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERKNS7_6LookupEjj($this, $l, $1, 1);
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN12JSFlatString8finalizeEP9JSRuntime($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this + 4 >> 2];
    var $1 = __ZNK14JSLinearString5charsEv($_idx_val);
    if (($1 | 0) == ($this + 8 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $1;
    __ZN9JSRuntime5free_EPv($6);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13bool_toSourceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $b = __stackBase__;
    var $buf = __stackBase__ + 4;
    var $1 = __ZN2js16GetPrimitiveThisIbEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $b);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $buf | 0;
    var $9 = HEAP32[_js_common_atom_names + ((HEAP8[$b] & 1 & 255) + 1 << 2) >> 2];
    var $10 = _JS_snprintf($3, 32, STRING_TABLE.__str3529 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $9, tempInt));
    var $11 = $cx;
    var $12 = _JS_NewStringCopyZ($11, $3);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value9setStringEP8JSString($vp, $12);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13bool_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $b = __stackBase__;
    var $1 = __ZN2js16GetPrimitiveThisIbEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $b);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $9 = HEAP32[HEAP32[$cx + 52 >> 2] + 209976 + ((HEAP8[$b] & 1 & 255) << 2) >> 2];
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $9 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $12);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12bool_valueOfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $b = __stackBase__;
    var $1 = __ZN2js16GetPrimitiveThisIbEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $b);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = (HEAP8[$b] & 1) << 24 >> 24 != 0;
    __ZN2JS5Value10setBooleanEb($vp, $5);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19js_InitBooleanClassP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $obj;
    var $3 = __ZN8JSObject8asGlobalEv($2);
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js12BooleanClassE);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL12BooleanValueEb532($1, 0);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject16setPrimitiveThisERKN2JS5ValueE($6, $_idx_val$0, $_idx_val$1);
    var $13 = HEAP32[HEAP32[$cx + 52 >> 2] + 210036 >> 2];
    var $14 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 76, __ZN2js12BooleanClassE, $13, 1);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $14 | 0;
    var $18 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $17, $5);
    if ($18) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $20 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, 0, __ZL15boolean_methods);
    if ($20) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $22 = $cx;
    var $23 = $3;
    var $24 = $14;
    var $25 = $5;
    var $26 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($22, $23, 4, $24, $25);
    var $_ = $26 ? $6 : 0;
    var $_0 = $_;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject16setPrimitiveThisERKN2JS5ValueE($this, $pthis_0_0_0_val$0, $pthis_0_0_0_val$1) {
  var $1 = $this;
  __ZN8JSObject12setFixedSlotEjRKN2JS5ValueE($1, 0, $pthis_0_0_0_val$0, $pthis_0_0_0_val$1);
  return;
}

function __ZN2JSL12BooleanValueEb532($agg_result, $boo) {
  __ZN2JS5Value10setBooleanEb($agg_result, $boo);
  return;
}

function __ZL7BooleanP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($argc | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $vp + 16 | 0;
    var $5 = __Z17js_ValueToBooleanRKN2JS5ValueE($4);
    var $7 = ($5 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $7;
    var $8 = __ZN2jsL14IsConstructingEPKN2JS5ValueE($vp);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $10 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE558($cx);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JSL12BooleanValueEb532($1, $7);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject16setPrimitiveThisERKN2JS5ValueE($10, $_idx_val$0, $_idx_val$1);
    var $13 = $10;
    __ZN2JS5Value9setObjectER8JSObject($vp, $13);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 6:
    __ZN2JS5Value10setBooleanEb($vp, $7);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js21BooleanToStringBufferEP9JSContextiRNS_12StringBufferE($b, $sb) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($b | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2js12StringBuffer6appendILj5EEEbRAT__Kc($sb, STRING_TABLE.__str32534);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js12StringBuffer6appendILj6EEEbRAT__Kc($sb, STRING_TABLE.__str42535);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer6appendILj5EEEbRAT__Kc($this, $array) {
  var $1 = $array | 0;
  var $2 = $array + 4 | 0;
  var $3 = $this;
  var $4 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendIcEEbPKT_S6_($3, $1, $2);
  return $4;
}

function __ZN2js12StringBuffer6appendILj6EEEbRAT__Kc($this, $array) {
  var $1 = $array | 0;
  var $2 = $array + 5 | 0;
  var $3 = $this;
  var $4 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendIcEEbPKT_S6_($3, $1, $2);
  return $4;
}

function __Z17js_ValueToBooleanRKN2JS5ValueE($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx5 = $v | 0;
    var $v_idx5_val$0 = HEAPU32[$v_idx5 >> 2];
    var $v_idx5_val$1 = HEAPU32[$v_idx5 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx5_val$0, $v_idx5_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx5_val$0, $v_idx5_val$1);
    var $_0 = ($3 | 0) != 0 & 1;
    __label__ = 12;
    break;
   case 3:
    var $7 = __ZNK2JS5Value8isStringEv($v_idx5_val$0, $v_idx5_val$1);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZNK2JS5Value8toStringEv($v_idx5_val$0, $v_idx5_val$1);
    var $_idx_val = HEAP32[$9 >> 2];
    var $10 = __ZNK8JSString6lengthEv($_idx_val);
    var $_0 = ($10 | 0) != 0 & 1;
    __label__ = 12;
    break;
   case 5:
    var $14 = __ZNK2JS5Value8isObjectEv($v_idx5_val$0, $v_idx5_val$1);
    if ($14) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = __ZNK2JS5Value17isNullOrUndefinedEv($v_idx5_val$0, $v_idx5_val$1);
    if ($16) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = __ZNK2JS5Value8isDoubleEv($v_idx5_val$0, $v_idx5_val$1);
    if ($18) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $20 = __ZNK2JS5Value8toDoubleEv($v);
    var $21 = __ZL15JSDOUBLE_IS_NaNd535($20);
    if (($21 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $26 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    var $26 = $20 != 0;
    __label__ = 10;
    break;
   case 10:
    var $26;
    var $_0 = $26 & 1;
    __label__ = 12;
    break;
   case 11:
    var $29 = __ZNK2JS5Value9toBooleanEv($v_idx5_val$0, $v_idx5_val$1);
    var $_0 = $29 & 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value9toBooleanEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_TO_BOOLEAN_IMPL($this_0_0_0_val$0, $this_0_0_0_val$1);
  return ($1 | 0) != 0;
}

function __ZN2jsL14IsConstructingEPKN2JS5ValueE($vp) {
  var $_idx = $vp + 8 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $1 = __ZNK2JS5Value7isMagicEv($_idx_val$0, $_idx_val$1);
  return $1;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE558($cx) {
  var $3 = HEAPU32[__ZN2js12BooleanClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb560($3);
  var $5 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE561($cx, $4);
  return $5;
}

function __ZL9SwapBytesy($u$0, $u$1) {
  return [ $u$0, $u$1 ];
}

function __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE6lengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function _JSVAL_IS_MAGIC_IMPL571($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -124) & 1;
}

function _JSVAL_IS_BOOLEAN_IMPL($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -125) & 1;
}

function __ZL12PairToUInt64jj($tag, $data) {
  return [ $data | 0, 0 | $tag ];
}

function _JSID_IS_INT594($iden) {
  return $iden & 1;
}

function _JSID_TO_INT595($iden) {
  return $iden >> 1;
}

function _JSID_TO_STRING596($iden) {
  return $iden;
}

function __ZL14ArrayTypeToTagj($type) {
  return $type - 65280 | 0;
}

function __ZL25ReinterpretDoubleAsUInt64d($d) {
  tempDoubleF64[0] = $d;
  return [ tempDoubleI32[0], tempDoubleI32[1] ];
}

function __ZN2js7SCInputC2EP9JSContextPKyj($this, $cx, $data, $nbytes) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $data;
  HEAP32[$this + 8 >> 2] = $data + ($nbytes >>> 3 << 3) | 0;
  return;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE561($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js12BooleanClassE + 4 >> 2] >>> 24;
    var $4 = $cx;
    var $5 = __ZNK9JSContext5hasfpEv($4);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $8;
    var $9 = $cx;
    var $10 = $global;
    var $11 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($9, $10);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $19 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $13 = __ZNK9JSContext2fpEv($4);
    var $14 = __ZNK2js10StackFrame10scopeChainEv($13);
    var $15 = $14;
    var $16 = __ZNK8JSObject9getGlobalEv($15);
    var $17 = $16;
    HEAP32[$global >> 2] = $17;
    var $19 = $17;
    __label__ = 5;
    break;
   case 5:
    var $19;
    var $20 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $19, $20);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $22 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $24 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $25 = $24;
    HEAP32[$proto >> 2] = $25;
    var $32 = $25;
    __label__ = 9;
    break;
   case 7:
    var $27 = $cx;
    var $29 = $proto;
    var $30 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($27, $19, $3, $29, __ZN2js12BooleanClassE);
    if ($30) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $32 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $32;
    var $33 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE562($cx, $32, $19, $kind);
    var $_0 = $33;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE561["X"] = 1;

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE562($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $proto;
    var $2 = $cx;
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($1, $2, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($2, $kind);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_0 = $7;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $parent;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, __ZN2js12BooleanClassE, $3, $10, 0, (__ZN2js12BooleanClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $11 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($3, $2, __ZN2js12BooleanClassE, $kind);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $11 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($6, $14);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value7isMagicEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_IS_MAGIC_IMPL571($this_0_0_0_val$0, $this_0_0_0_val$1);
  return ($1 | 0) != 0;
}

function __ZN2js16GetPrimitiveThisIbEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx3 = $vp + 8 | 0;
    var $_idx3_val$0 = HEAPU32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAPU32[$_idx3 + 4 >> 2];
    var $1 = __ZN2js6detail17PrimitiveBehaviorIbE6isTypeERKN2JS5ValueE($_idx3_val$0, $_idx3_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail17PrimitiveBehaviorIbE7extractERKN2JS5ValueE($_idx3_val$0, $_idx3_val$1);
    HEAP8[$v] = $3 & 1;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isObjectEv($_idx3_val$0, $_idx3_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toObjectEv($_idx3_val$0, $_idx3_val$1);
    var $_idx2_val = HEAP32[$8 + 4 >> 2];
    var $9 = __ZNK8JSObject8getClassEv($_idx2_val);
    if (($9 | 0) == (__ZN2js12BooleanClassE | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $12 = $8;
    var $13 = __ZNK8JSObject16getPrimitiveThisEv($12);
    var $_idx4 = $13 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    var $14 = __ZN2js6detail17PrimitiveBehaviorIbE7extractERKN2JS5ValueE($_idx4_val$0, $_idx4_val$1);
    HEAP8[$v] = $14 & 1;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 6:
    var $17 = $cx;
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($17, $vp, __ZN2js12BooleanClassE);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail17PrimitiveBehaviorIbE6isTypeERKN2JS5ValueE($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var $1 = __ZNK2JS5Value9isBooleanEv($v_0_0_0_val$0, $v_0_0_0_val$1);
  return $1;
}

function __ZN2js6detail17PrimitiveBehaviorIbE7extractERKN2JS5ValueE($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var $1 = __ZNK2JS5Value9toBooleanEv($v_0_0_0_val$0, $v_0_0_0_val$1);
  return $1;
}

function __ZNK8JSObject16getPrimitiveThisEv($this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject12getFixedSlotEj($1, 0);
  return $2;
}

function __ZNK2JS5Value9isBooleanEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_IS_BOOLEAN_IMPL($this_0_0_0_val$0, $this_0_0_0_val$1);
  return ($1 | 0) != 0;
}

function __ZN2js20WriteStructuredCloneEP9JSContextRKN2JS5ValueEPPyPjPK26JSStructuredCloneCallbacksPv($cx, $v, $bufp, $nbytesp, $cb) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 244;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $out = __stackBase__;
    var $w = __stackBase__ + 28;
    __ZN2js8SCOutputC2EP9JSContext($out, $cx);
    __ZN23JSStructuredCloneWriterC1ERN2js8SCOutputEPK26JSStructuredCloneCallbacksPv($w, $out, $cb);
    var $1 = __ZN23JSStructuredCloneWriter4initEv($w);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZN23JSStructuredCloneWriter5writeERKN2JS5ValueE($w, $v);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $7 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = __ZN2js8SCOutput13extractBufferEPPyPj($out, $bufp, $nbytesp);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    __ZN23JSStructuredCloneWriterD1Ev($w);
    __ZN2js8SCOutputD1Ev($out);
    STACKTOP = __stackBase__;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN23JSStructuredCloneWriterC1ERN2js8SCOutputEPK26JSStructuredCloneCallbacksPv($this, $out, $cb) {
  __ZN23JSStructuredCloneWriterC2ERN2js8SCOutputEPK26JSStructuredCloneCallbacksPv($this, $out, $cb);
  return;
}

function __ZN23JSStructuredCloneWriter4initEv($this) {
  var $1 = $this + 180 | 0;
  var $2 = __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($1);
  return $2;
}

function __ZN23JSStructuredCloneWriter5writeERKN2JS5ValueE($this, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj2 = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $val = __stackBase__ + 8;
    var $1 = __ZN23JSStructuredCloneWriter10startWriteERKN2JS5ValueE($this, $v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 2:
    var $3 = $this + 4 | 0;
    var $4 = $this + 96 | 0;
    var $5 = $this | 0;
    var $6 = $this + 120 | 0;
    var $7 = $prop;
    var $_idx5 = $this + 104 | 0;
    var $8 = $this + 100 | 0;
    __label__ = 3;
    break;
   case 3:
    var $_idx5_val = HEAP32[$_idx5 >> 2];
    var $9 = __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE5emptyEv($_idx5_val);
    if ($9) {
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE4backEv($3);
    var $_idx = $11 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $12 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $_idx2_val = HEAP32[$8 >> 2];
    var $13 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE4backEv($_idx2_val, $_idx5_val);
    var $14 = HEAP32[$13 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = $14 - 1 | 0;
    HEAP32[$13 >> 2] = $17;
    var $18 = __ZNK2js16AutoVectorRooterIiE4backEv($6);
    var $19 = HEAP32[$18 >> 2];
    __ZN2js16AutoVectorRooterIiE7popBackEv($6);
    var $20 = _JSID_IS_STRING598($19);
    if (($20 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $23 = _JSID_IS_INT594($19);
    if (($23 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $this_idx4_val_idx_val = HEAP32[HEAP32[$5 >> 2] >> 2];
    var $26 = __ZN23JSStructuredCloneWriter7contextEv($this_idx4_val_idx_val);
    var $_idx1_val = HEAP32[$12 + 4 >> 2];
    var $27 = __ZNK8JSObject6getOpsEv($_idx1_val);
    var $30 = $26;
    var $31 = HEAP32[$27 + 4 >> 2];
    var $32 = $12;
    var $33 = __Z17js_HasOwnPropertyP9JSContextPFiS0_P8JSObjectiPS2_PP10JSPropertyES2_iS3_S6_($30, $31, $32, $19, $obj2, $7);
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((HEAP32[$prop >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $39 = __ZN23JSStructuredCloneWriter7writeIdEi($this, $19);
    if ($39) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 10:
    var $this_idx_val_idx_val = HEAP32[HEAP32[$5 >> 2] >> 2];
    var $41 = __ZN23JSStructuredCloneWriter7contextEv($this_idx_val_idx_val);
    var $42 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($12, $41, $19, $val);
    if (($42 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $45 = __ZN23JSStructuredCloneWriter10startWriteERKN2JS5ValueE($this, $val);
    if ($45) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 12:
    var $47 = HEAP32[$5 >> 2];
    var $48 = __ZN2js8SCOutput9writePairEjj($47, -65536, 0);
    __ZN2js16AutoVectorRooterIN2JS5ValueEE7popBackEv($3);
    __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE7popBackEv($4);
    __label__ = 3;
    break;
   case 13:
    var $50 = $this + 180 | 0;
    __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv($50);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN23JSStructuredCloneWriter5writeERKN2JS5ValueE["X"] = 1;

function __ZN2js8SCOutput13extractBufferEPPyPj($this, $datap, $sizep) {
  var $1 = $this + 4 | 0;
  var $_idx_val = HEAP32[$this + 12 >> 2];
  var $2 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE6lengthEv($_idx_val);
  var $3 = $2 << 3;
  HEAP32[$sizep >> 2] = $3;
  var $4 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE16extractRawBufferEv($1);
  HEAP32[$datap >> 2] = $4;
  return ($4 | 0) != 0;
}

function __ZN23JSStructuredCloneWriterD1Ev($this) {
  __ZN23JSStructuredCloneWriterD2Ev($this);
  return;
}

function __ZN2js8SCOutputD1Ev($this) {
  __ZN2js8SCOutputD2Ev($this);
  return;
}

function __ZN2js19ReadStructuredCloneEP9JSContextPKyjPN2JS5ValueEPK26JSStructuredCloneCallbacksPv($cx, $data, $nbytes, $vp, $cb) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 208;
  var $in = __stackBase__;
  var $r = __stackBase__ + 12;
  __ZN2js7SCInputC2EP9JSContextPKyj($in, $cx, $data, $nbytes);
  __ZN23JSStructuredCloneReaderC1ERN2js7SCInputEPK26JSStructuredCloneCallbacksPv($r, $in, $cb);
  var $1 = __ZN23JSStructuredCloneReader4readEPN2JS5ValueE($r, $vp);
  __ZN23JSStructuredCloneReaderD1Ev($r);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZN23JSStructuredCloneReaderC1ERN2js7SCInputEPK26JSStructuredCloneCallbacksPv($this, $in, $cb) {
  __ZN23JSStructuredCloneReaderC2ERN2js7SCInputEPK26JSStructuredCloneCallbacksPv($this, $in, $cb);
  return;
}

function __ZN23JSStructuredCloneReader4readEPN2JS5ValueE($this, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $v = __stackBase__ + 4;
    var $1 = __ZN23JSStructuredCloneReader9startReadEPN2JS5ValueE($this, $vp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 2:
    var $2 = $this + 4 | 0;
    var $this_idx = $this | 0;
    __label__ = 3;
    break;
   case 3:
    var $3 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($2);
    if (($3 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $6 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE4backEv($2);
    var $_idx = $6 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $7 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $8 = __ZN23JSStructuredCloneReader6readIdEPi($this, $id);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 5:
    var $10 = HEAP32[$id >> 2];
    var $11 = _JSID_IS_VOID605($10);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js16AutoVectorRooterIN2JS5ValueEE7popBackEv($2);
    __label__ = 3;
    break;
   case 7:
    var $15 = __ZN23JSStructuredCloneReader9startReadEPN2JS5ValueE($this, $v);
    if ($15) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $this_idx_val_idx_val = HEAP32[HEAP32[$this_idx >> 2] >> 2];
    var $17 = __ZN23JSStructuredCloneReader7contextEv($this_idx_val_idx_val);
    var $18 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($7, $17, $10, $v, 10, 12, 1);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 9:
    var $21 = $this + 96 | 0;
    __ZN2js16AutoVectorRooterIN2JS5ValueEE5clearEv($21);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN23JSStructuredCloneReaderD1Ev($this) {
  __ZN23JSStructuredCloneReaderD2Ev($this);
  return;
}

function __ZN2js7SCInput3eofEv($this_0_0_val) {
  var __stackBase__ = STACKTOP;
  _JS_ReportErrorNumber($this_0_0_val, 4, 260, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str573 | 0, tempInt));
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7SCInput4readEPy($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == (HEAP32[$this + 8 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this >> 2];
    __ZN2js7SCInput3eofEv($this_idx_val);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $8 = $2 + 8 | 0;
    HEAP32[$1 >> 2] = $8;
    var $9$0 = HEAP32[$2 >> 2];
    var $9$1 = HEAP32[$2 + 4 >> 2];
    var $10 = __ZL9SwapBytesy($9$0, $9$1);
    var $10$0 = $10[0];
    var $10$1 = $10[1];
    HEAP32[$p >> 2] = $10$0;
    HEAP32[$p + 4 >> 2] = $10$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7SCInput8readPairEPjS1_($this, $tagp, $datap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $u = __stackBase__;
    HEAP32[$u >> 2] = 0;
    HEAP32[$u + 4 >> 2] = 0;
    var $1 = __ZN2js7SCInput4readEPy($this, $u);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3$0 = HEAP32[$u >> 2];
    var $5 = HEAP32[$u + 4 >> 2];
    HEAP32[$tagp >> 2] = $5;
    var $6 = $3$0;
    HEAP32[$datap >> 2] = $6;
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7SCInput10readDoubleEPd($this, $p) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pun = __stackBase__;
    var $1 = $pun | 0;
    var $2 = __ZN2js7SCInput4readEPy($this, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $pun;
    var $5 = (tempDoubleI32[0] = HEAP32[$4 >> 2], tempDoubleI32[1] = HEAP32[$4 + 4 >> 2], tempDoubleF64[0]);
    var $6 = __ZL15CanonicalizeNand($5);
    tempDoubleF64[0] = $6, HEAP32[$p >> 2] = tempDoubleI32[0], HEAP32[$p + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15CanonicalizeNand($d) {
  var $1 = _JS_CANONICALIZE_NAN644($d);
  return $1;
}

function __ZN2js7SCInput9readArrayIhEEbPT_j($this, $p, $nelems) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($nelems, 7);
    var $1 = $uadd.f0;
    var $2 = $1 >>> 3;
    var $3 = $uadd.f1;
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this + 4 | 0;
    var $8 = HEAPU32[$7 >> 2];
    if ($2 >>> 0 > HEAP32[$this + 8 >> 2] - $8 >> 3 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $this_idx_val = HEAP32[$this >> 2];
    __ZN2js7SCInput3eofEv($this_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $16 = $8;
    _memcpy($p, $16, $nelems, 1);
    var $18 = HEAP32[$7 >> 2] + ($2 << 3) | 0;
    HEAP32[$7 >> 2] = $18;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7SCInput9readCharsEPtj($this, $p, $nchars) {
  var $1 = __ZN2js7SCInput9readArrayItEEbPT_j($this, $p, $nchars);
  return $1;
}

function __ZN2js7SCInput9readArrayItEEbPT_j($this, $p, $nelems) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($nelems, 3);
    var $1 = $uadd.f0;
    var $2 = $1 >>> 2;
    var $3 = $uadd.f1;
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this + 4 | 0;
    var $8 = HEAPU32[$7 >> 2];
    if ($2 >>> 0 > HEAP32[$this + 8 >> 2] - $8 >> 3 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $this_idx_val = HEAP32[$this >> 2];
    __ZN2js7SCInput3eofEv($this_idx_val);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 4:
    var $16 = $8;
    var $17 = $16 + ($nelems << 1) | 0;
    if (($16 | 0) == ($17 | 0)) {
      var $24 = $8;
      __label__ = 7;
      break;
    } else {
      var $_012 = $p;
      var $q_03 = $16;
      __label__ = 5;
      break;
    }
   case 5:
    var $q_03;
    var $_012;
    var $19 = $q_03 + 2 | 0;
    var $20 = HEAP16[$q_03 >> 1];
    var $21 = __ZL9SwapBytest($20);
    HEAP16[$_012 >> 1] = $21;
    if (($19 | 0) == ($17 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $_012 = $_012 + 2 | 0;
      var $q_03 = $19;
      __label__ = 5;
      break;
    }
   case 6:
    var $24 = HEAP32[$7 >> 2];
    __label__ = 7;
    break;
   case 7:
    var $24;
    HEAP32[$7 >> 2] = $24 + ($2 << 3) | 0;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8SCOutputC2EP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = $cx;
  var $3 = $this + 4 | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEC1ES1_($3, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEC1ES1_($this, $ap_01) {
  __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEC2ES1_($this, $ap_01);
  return;
}

function __ZN2js8SCOutput5writeEy($this, $u$0, $u$1) {
  var $1 = $this + 4 | 0;
  var $2 = __ZL9SwapBytesy($u$0, $u$1);
  var $2$0 = $2[0];
  var $2$1 = $2[1];
  var $3 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE6appendIyEEbT_($1, $2$0, $2$1);
  return $3;
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE6appendIyEEbT_($this, $t$0, $t$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE14internalAppendIyEEvT_($this, $t$0, $t$1);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8SCOutput9writePairEjj($this, $tag, $data) {
  var $1 = __ZL12PairToUInt64jj($tag, $data);
  var $1$0 = $1[0];
  var $1$1 = $1[1];
  var $2 = __ZN2js8SCOutput5writeEy($this, $1$0, $1$1);
  return $2;
}

function __ZN2js8SCOutput11writeDoubleEd($this, $d) {
  var $1 = __ZL15CanonicalizeNand($d);
  var $2 = __ZL25ReinterpretDoubleAsUInt64d($1);
  var $2$0 = $2[0];
  var $2$1 = $2[1];
  var $3 = __ZN2js8SCOutput5writeEy($this, $2$0, $2$1);
  return $3;
}

function __ZN2js8SCOutput10writeBytesEPKvj($this, $p, $nbytes) {
  var $1 = __ZN2js8SCOutput10writeArrayIhEEbPKT_j($this, $p, $nbytes);
  return $1;
}

function __ZN2js8SCOutput10writeArrayIhEEbPKT_j($this, $p, $nelems) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($nelems | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $uadd = _llvm_uadd_with_overflow_i32($nelems, 7);
    var $3 = $uadd.f1;
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $this_idx_val = HEAP32[$this >> 2];
    var $5 = __ZNK2js8SCOutput7contextEv($this_idx_val);
    __Z27js_ReportAllocationOverflowP9JSContext($5);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    var $7 = $uadd.f0;
    var $8 = $7 >>> 3;
    var $9 = $this + 4 | 0;
    var $_idx = $this + 12 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $10 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE19growByUninitializedEj($9, $8);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $12 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE6lengthEv($_idx_val);
    var $_idx1 = $this + 8 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $_idx2_val = HEAP32[$_idx >> 2];
    var $13 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE4backEv($_idx1_val, $_idx2_val);
    var $st$7$0 = $13 | 0;
    HEAP32[$st$7$0 >> 2] = 0;
    var $st$7$1 = $13 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = 0;
    var $_idx3_val = HEAP32[$_idx1 >> 2];
    var $14 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEixEj($_idx3_val, $12);
    var $15 = $14;
    _memcpy($15, $p, $nelems, 1);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8SCOutput10writeCharsEPKtj($this, $p, $nchars) {
  var $1 = __ZN2js8SCOutput10writeArrayItEEbPKT_j($this, $p, $nchars);
  return $1;
}

function __ZN2js8SCOutput10writeArrayItEEbPKT_j($this, $p, $nelems) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($nelems | 0) == 0) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $uadd = _llvm_uadd_with_overflow_i32($nelems, 3);
    var $3 = $uadd.f1;
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $this_idx_val = HEAP32[$this >> 2];
    var $5 = __ZNK2js8SCOutput7contextEv($this_idx_val);
    __Z27js_ReportAllocationOverflowP9JSContext($5);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 4:
    var $7 = $uadd.f0;
    var $8 = $7 >>> 2;
    var $9 = $this + 4 | 0;
    var $_idx = $this + 12 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $10 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE6lengthEv($_idx_val);
    var $11 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE19growByUninitializedEj($9, $8);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $_idx1 = $this + 8 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $_idx2_val = HEAP32[$_idx >> 2];
    var $12 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE4backEv($_idx1_val, $_idx2_val);
    var $st$6$0 = $12 | 0;
    HEAP32[$st$6$0 >> 2] = 0;
    var $st$6$1 = $12 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = 0;
    var $13 = $p + ($nelems << 1) | 0;
    var $_idx3_val = HEAP32[$_idx1 >> 2];
    var $14 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEixEj($_idx3_val, $10);
    var $_012 = $p;
    var $q_03 = $14;
    __label__ = 6;
    break;
   case 6:
    var $q_03;
    var $_012;
    var $17 = $_012 + 2 | 0;
    var $18 = HEAP16[$_012 >> 1];
    var $19 = __ZL9SwapBytest($18);
    HEAP16[$q_03 >> 1] = $19;
    if (($17 | 0) == ($13 | 0)) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      var $_012 = $17;
      var $q_03 = $q_03 + 2 | 0;
      __label__ = 6;
      break;
    }
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE16extractRawBufferEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $this | 0;
    var $4 = $this + 8 | 0;
    var $6 = HEAP32[$4 >> 2] << 3;
    var $7 = __ZN2js15TempAllocPolicy7malloc_Ej($3, $6);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $11 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$4 >> 2];
    var $12 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplIyLj0ENS_15TempAllocPolicyELb1EE13copyConstructIyEEvPyPKT_S7_($8, $11, $12);
    HEAP32[$4 >> 2] = 0;
    var $_0 = $8;
    __label__ = 5;
    break;
   case 4:
    var $14 = $this + 4 | 0;
    var $15 = HEAP32[$14 >> 2];
    var $16 = $this + 16 | 0;
    var $17 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($16);
    HEAP32[$14 >> 2] = $17;
    HEAP32[$this + 8 >> 2] = 0;
    HEAP32[$this + 12 >> 2] = 0;
    var $_0 = $15;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN23JSStructuredCloneWriter11writeStringEjP8JSString($this, $tag, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str_idx_val = HEAP32[$str >> 2];
    var $1 = __ZNK8JSString6lengthEv($str_idx_val);
    var $this_idx = $this | 0;
    var $this_idx_val_idx_val = HEAP32[HEAP32[$this_idx >> 2] >> 2];
    var $2 = __ZN23JSStructuredCloneWriter7contextEv($this_idx_val_idx_val);
    var $3 = __ZN8JSString8getCharsEP9JSContext($str, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$this_idx >> 2];
    var $7 = __ZN2js8SCOutput9writePairEjj($6, $tag, $1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = HEAP32[$this_idx >> 2];
    var $10 = __ZN2js8SCOutput10writeCharsEPKtj($9, $3, $1);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN23JSStructuredCloneWriter7contextEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js8SCOutput7contextEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZN23JSStructuredCloneWriter7writeIdEi($this, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_INT594($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$this >> 2];
    var $6 = _JSID_TO_INT595($id);
    var $7 = __ZN2js8SCOutput9writePairEjj($5, -65533, $6);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 3:
    var $9 = _JSID_TO_STRING596($id);
    var $10 = __ZN23JSStructuredCloneWriter11writeStringEjP8JSString($this, -65532, $9);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN23JSStructuredCloneWriter15writeTypedArrayEP8JSObject($this, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = $this | 0;
    var $3 = HEAP32[$2 >> 2];
    var $4 = __ZN2js10TypedArray7getTypeEP8JSObject($1);
    var $5 = __ZL14ArrayTypeToTagj($4);
    var $6 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $7 = __ZN2js8SCOutput9writePairEjj($3, $5, $6);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $9 = __ZN2js10TypedArray7getTypeEP8JSObject($1);
    if (($9 | 0) == 0 || ($9 | 0) == 1 || ($9 | 0) == 8) {
      __label__ = 3;
      break;
    } else if (($9 | 0) == 2 || ($9 | 0) == 3) {
      __label__ = 4;
      break;
    } else if (($9 | 0) == 4 || ($9 | 0) == 5 || ($9 | 0) == 6) {
      __label__ = 5;
      break;
    } else if (($9 | 0) == 7) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    var $11 = HEAP32[$2 >> 2];
    var $_idx3_val = HEAP32[$1 + 24 >> 2];
    var $12 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx3_val);
    var $13 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $14 = __ZN2js8SCOutput10writeArrayIhEEbPKT_j($11, $12, $13);
    var $_0 = $14;
    __label__ = 7;
    break;
   case 4:
    var $16 = HEAP32[$2 >> 2];
    var $_idx2_val = HEAP32[$1 + 24 >> 2];
    var $17 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx2_val);
    var $18 = $17;
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $20 = __ZN2js8SCOutput10writeArrayItEEbPKT_j($16, $18, $19);
    var $_0 = $20;
    __label__ = 7;
    break;
   case 5:
    var $22 = HEAP32[$2 >> 2];
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    var $23 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx1_val);
    var $24 = $23;
    var $25 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $26 = __ZN2js8SCOutput10writeArrayIjEEbPKT_j($22, $24, $25);
    var $_0 = $26;
    __label__ = 7;
    break;
   case 6:
    var $28 = HEAP32[$2 >> 2];
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $29 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx_val);
    var $30 = $29;
    var $31 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $32 = __ZN2js8SCOutput10writeArrayIyEEbPKT_j($28, $30, $31);
    var $_0 = $32;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10TypedArray7getTypeEP8JSObject($obj) {
  var $1 = __ZNK8JSObject12getFixedSlotEj($obj, 3);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $2 = __ZNK2JS5Value7toInt32Ev($_idx_val$0, $_idx_val$1);
  return $2;
}

function __ZN2js10TypedArray9getLengthEP8JSObject($obj) {
  var $1 = __ZNK8JSObject12getFixedSlotEj($obj, 0);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $2 = __ZNK2JS5Value7toInt32Ev($_idx_val$0, $_idx_val$1);
  return $2;
}

function __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj_0_6_val) {
  var $1 = __ZNK8JSObject10getPrivateEv($obj_0_6_val);
  return $1;
}

function __ZN2js8SCOutput10writeArrayIjEEbPKT_j($this, $p, $nelems) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($nelems | 0) == 0) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $uadd = _llvm_uadd_with_overflow_i32($nelems, 1);
    var $3 = $uadd.f1;
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $this_idx_val = HEAP32[$this >> 2];
    var $5 = __ZNK2js8SCOutput7contextEv($this_idx_val);
    __Z27js_ReportAllocationOverflowP9JSContext($5);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 4:
    var $7 = $uadd.f0;
    var $8 = $7 >>> 1;
    var $9 = $this + 4 | 0;
    var $_idx = $this + 12 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $10 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE6lengthEv($_idx_val);
    var $11 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE19growByUninitializedEj($9, $8);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $_idx1 = $this + 8 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $_idx2_val = HEAP32[$_idx >> 2];
    var $12 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE4backEv($_idx1_val, $_idx2_val);
    var $st$6$0 = $12 | 0;
    HEAP32[$st$6$0 >> 2] = 0;
    var $st$6$1 = $12 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = 0;
    var $13 = $p + ($nelems << 2) | 0;
    var $_idx3_val = HEAP32[$_idx1 >> 2];
    var $14 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEixEj($_idx3_val, $10);
    var $_012 = $p;
    var $q_03 = $14;
    __label__ = 6;
    break;
   case 6:
    var $q_03;
    var $_012;
    var $17 = $_012 + 4 | 0;
    var $18 = HEAP32[$_012 >> 2];
    var $19 = __ZL9SwapBytesj($18);
    HEAP32[$q_03 >> 2] = $19;
    if (($17 | 0) == ($13 | 0)) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      var $_012 = $17;
      var $q_03 = $q_03 + 4 | 0;
      __label__ = 6;
      break;
    }
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN5Chars3getEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK8JSObject9isBooleanEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js12BooleanClassE | 0);
}

function __ZNK8JSObject8isNumberEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js11NumberClassE | 0);
}

function __ZNK8JSObject8isStringEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js11StringClassE | 0);
}

function __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE5emptyEv($this_0_2_val) {
  return ($this_0_2_val | 0) == 0;
}

function _JSID_IS_STRING598($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSVAL_IS_DOUBLE_IMPL599($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 < 4294967169 & 1;
}

function __ZL14TagToArrayTypej($tag) {
  return $tag + 65280 | 0;
}

function __ZN8JSObject21arrayBufferByteLengthEv($this_0_8_val) {
  return HEAP32[$this_0_8_val >> 2];
}

function __ZN8JSObject21arrayBufferDataOffsetEv($this_0_8_val) {
  return $this_0_8_val + 8 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN2jsL7ReverseIiEEvPT_S2_($beg, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_0 = $beg;
    var $_01 = $end;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $_0;
    if (($_0 | 0) == ($_01 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $4 = $_01 - 4 | 0;
    if (($4 | 0) == ($_0 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = HEAP32[$_0 >> 2];
    var $8 = HEAP32[$4 >> 2];
    HEAP32[$_0 >> 2] = $8;
    HEAP32[$4 >> 2] = $7;
    var $_0 = $_0 + 4 | 0;
    var $_01 = $4;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN5Chars6forgetEv($this) {
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js8SCOutput10writeArrayIyEEbPKT_j($this, $p, $nelems) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($nelems | 0) == 0) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $this + 4 | 0;
    var $_idx = $this + 12 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $4 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE19growByUninitializedEj($3, $nelems);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $5 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE6lengthEv($_idx_val);
    var $_idx1 = $this + 8 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $_idx2_val = HEAP32[$_idx >> 2];
    var $6 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE4backEv($_idx1_val, $_idx2_val);
    var $st$7$0 = $6 | 0;
    HEAP32[$st$7$0 >> 2] = 0;
    var $st$7$1 = $6 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = 0;
    var $7 = $p + ($nelems << 3) | 0;
    var $_idx3_val = HEAP32[$_idx1 >> 2];
    var $8 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEixEj($_idx3_val, $5);
    var $_012 = $p;
    var $q_03 = $8;
    __label__ = 4;
    break;
   case 4:
    var $q_03;
    var $_012;
    var $10 = $_012 + 8 | 0;
    var $11$0 = HEAP32[$_012 >> 2];
    var $11$1 = HEAP32[$_012 + 4 >> 2];
    var $12 = __ZL9SwapBytesy($11$0, $11$1);
    var $12$0 = $12[0];
    var $12$1 = $12[1];
    HEAP32[$q_03 >> 2] = $12$0;
    HEAP32[$q_03 + 4 >> 2] = $12$1;
    if (($10 | 0) == ($7 | 0)) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      var $_012 = $10;
      var $q_03 = $q_03 + 8 | 0;
      __label__ = 4;
      break;
    }
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN23JSStructuredCloneWriter16writeArrayBufferEP8JSObject($this, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11ArrayBuffer14getArrayBufferEP8JSObject($obj);
    var $2 = $this | 0;
    var $3 = HEAP32[$2 >> 2];
    var $_idx1 = $1 + 32 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $4 = __ZN8JSObject21arrayBufferByteLengthEv($_idx1_val);
    var $5 = __ZN2js8SCOutput9writePairEjj($3, -65527, $4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $12 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = HEAP32[$2 >> 2];
    var $_idx2_val = HEAP32[$_idx1 >> 2];
    var $8 = __ZN8JSObject21arrayBufferDataOffsetEv($_idx2_val);
    var $9 = __ZN8JSObject21arrayBufferByteLengthEv($_idx2_val);
    var $10 = __ZN2js8SCOutput10writeBytesEPKvj($7, $8, $9);
    var $12 = $10;
    __label__ = 3;
    break;
   case 3:
    var $12;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN23JSStructuredCloneWriter11startObjectEP8JSObject($this, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $3 = __stackBase__ + 20;
    var $4 = __stackBase__ + 24;
    HEAP32[$1 >> 2] = $obj;
    var $5 = $this + 180 | 0;
    __ZNK2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($p, $5, $1);
    var $_idx3_val = HEAP32[$p >> 2];
    var $_idx3_val_idx_val = HEAP32[$_idx3_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($2, $_idx3_val_idx_val);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = HEAP32[$this >> 2];
    var $12 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($_idx3_val);
    var $14 = HEAP32[$12 + 4 >> 2];
    var $15 = __ZN2js8SCOutput9writePairEjj($11, -65523, $14);
    var $_0 = $15;
    __label__ = 10;
    break;
   case 3:
    var $17 = __ZNK2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv($5);
    HEAP32[$3 >> 2] = $17;
    var $18 = __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKj($5, $p, $1, $3);
    if ($18) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 4:
    var $20 = __ZNK2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv($5);
    if (($20 | 0) == -1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $this_idx2_val_idx_val = HEAP32[HEAP32[$this >> 2] >> 2];
    var $23 = __ZN23JSStructuredCloneWriter7contextEv($this_idx2_val_idx_val);
    _JS_ReportErrorNumber($23, 4, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str1574 | 0, tempInt));
    var $_0 = 0;
    __label__ = 10;
    break;
   case 6:
    var $25 = $this + 120 | 0;
    var $26 = $25 | 0;
    var $27 = __ZNK2js16AutoVectorRooterIiE6lengthEv($26);
    var $this_idx = $this | 0;
    var $this_idx_val_idx_val = HEAP32[HEAP32[$this_idx >> 2] >> 2];
    var $28 = __ZN23JSStructuredCloneWriter7contextEv($this_idx_val_idx_val);
    var $29 = HEAP32[$1 >> 2];
    var $30 = $28;
    var $31 = $29;
    var $32 = $25;
    var $33 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($30, $31, 8, $32);
    if ($33) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    var $35 = __ZN2js16AutoVectorRooterIiE5beginEv($26);
    var $36 = $35 + ($27 << 2) | 0;
    var $37 = __ZN2js16AutoVectorRooterIiE3endEv($26);
    __ZN2jsL7ReverseIiEEvPT_S2_($36, $37);
    var $38 = $this + 4 | 0;
    __ZN2JSL11ObjectValueER8JSObject597($4, $29);
    var $_idx1 = $4 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $39 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($38, $_idx1_val$0, $_idx1_val$1);
    if ($39) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $44 = $37 - $36 >> 2;
    var $46 = $this + 96 | 0;
    var $47 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE6appendIjEEbT_($46, $44);
    if ($47) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    var $49 = HEAP32[$this_idx >> 2];
    var $_idx_val = HEAP32[$29 + 4 >> 2];
    var $50 = __ZNK8JSObject7isArrayEv($_idx_val);
    var $51 = $50 ? -65529 : -65528;
    var $52 = __ZN2js8SCOutput9writePairEjj($49, $51, 0);
    var $_0 = $52;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN23JSStructuredCloneWriter11startObjectEP8JSObject["X"] = 1;

function __ZNK2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 78,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKj($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $7 = HEAP32[$v >> 2];
    var $8 = $5 + 4 | 0;
    HEAP32[$8 >> 2] = $7;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv($this) {
  var $_idx_val = HEAP32[$this + 12 >> 2];
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5countEv($_idx_val);
  return $1;
}

function __ZN2js16AutoVectorRooterIiE5beginEv($this) {
  var $_idx_val = HEAP32[$this + 16 >> 2];
  var $1 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE5beginEv($_idx_val);
  return $1;
}

function __ZN2js16AutoVectorRooterIiE3endEv($this) {
  var $_idx_val = HEAP32[$this + 16 >> 2];
  var $_idx1_val = HEAP32[$this + 20 >> 2];
  var $1 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE3endEv($_idx_val, $_idx1_val);
  return $1;
}

function __ZN2JSL11ObjectValueER8JSObject597($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN23JSStructuredCloneWriter10startWriteERKN2JS5ValueE($this, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx4 = $v | 0;
    var $v_idx4_val$0 = HEAPU32[$v_idx4 >> 2];
    var $v_idx4_val$1 = HEAPU32[$v_idx4 + 4 >> 2];
    var $1 = __ZNK2JS5Value8isStringEv($v_idx4_val$0, $v_idx4_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toStringEv($v_idx4_val$0, $v_idx4_val$1);
    var $4 = __ZN23JSStructuredCloneWriter11writeStringEjP8JSString($this, -65532, $3);
    var $_0 = $4;
    __label__ = 36;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isNumberEv($v_idx4_val$0, $v_idx4_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = HEAP32[$this >> 2];
    var $10 = __ZNK2JS5Value8toNumberEv($v);
    var $11 = __ZN2js8SCOutput11writeDoubleEd($9, $10);
    var $_0 = $11;
    __label__ = 36;
    break;
   case 5:
    var $13 = __ZNK2JS5Value9isBooleanEv($v_idx4_val$0, $v_idx4_val$1);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $16 = HEAP32[$this >> 2];
    var $17 = __ZNK2JS5Value9toBooleanEv($v_idx4_val$0, $v_idx4_val$1);
    var $18 = $17 & 1;
    var $19 = __ZN2js8SCOutput9writePairEjj($16, -65534, $18);
    var $_0 = $19;
    __label__ = 36;
    break;
   case 7:
    var $21 = __ZNK2JS5Value6isNullEv($v_idx4_val$0, $v_idx4_val$1);
    if ($21) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $24 = HEAP32[$this >> 2];
    var $25 = __ZN2js8SCOutput9writePairEjj($24, -65536, 0);
    var $_0 = $25;
    __label__ = 36;
    break;
   case 9:
    var $27 = __ZNK2JS5Value11isUndefinedEv($v_idx4_val$0, $v_idx4_val$1);
    if ($27) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $30 = HEAP32[$this >> 2];
    var $31 = __ZN2js8SCOutput9writePairEjj($30, -65535, 0);
    var $_0 = $31;
    __label__ = 36;
    break;
   case 11:
    var $33 = __ZNK2JS5Value8isObjectEv($v_idx4_val$0, $v_idx4_val$1);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 12:
    var $35 = __ZNK2JS5Value8toObjectEv($v_idx4_val$0, $v_idx4_val$1);
    var $_idx19_val = HEAPU32[$35 + 4 >> 2];
    var $36 = __ZNK8JSObject8isRegExpEv($_idx19_val);
    if ($36) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $_idx9_val = HEAP32[$35 + 24 >> 2];
    var $38 = __ZN2js6RegExp11extractFromEP8JSObject($_idx9_val);
    var $40 = HEAP32[$this >> 2];
    var $41 = __ZNK2js6RegExp8getFlagsEv($38);
    var $42 = HEAP32[$41 >> 2];
    var $43 = __ZN2js8SCOutput9writePairEjj($40, -65530, $42);
    if ($43) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 36;
      break;
    }
   case 14:
    var $_idx10_val = HEAP32[$38 + 4 >> 2];
    var $45 = __ZNK2js6RegExp9getSourceEv($_idx10_val);
    var $46 = $45 | 0;
    var $47 = __ZN23JSStructuredCloneWriter11writeStringEjP8JSString($this, -65532, $46);
    var $_0 = $47;
    __label__ = 36;
    break;
   case 15:
    var $49 = __ZNK8JSObject6isDateEv($_idx19_val);
    if ($49) {
      __label__ = 16;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 16:
    var $this_idx22 = $this | 0;
    var $this_idx22_val_idx_val = HEAP32[HEAP32[$this_idx22 >> 2] >> 2];
    var $51 = __ZN23JSStructuredCloneWriter7contextEv($this_idx22_val_idx_val);
    var $52 = $51;
    var $53 = $35;
    var $54 = __Z24js_DateGetMsecSinceEpochP9JSContextP8JSObject($52, $53);
    var $55 = HEAP32[$this_idx22 >> 2];
    var $56 = __ZN2js8SCOutput9writePairEjj($55, -65531, 0);
    if ($56) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 36;
      break;
    }
   case 17:
    var $58 = HEAP32[$this_idx22 >> 2];
    var $59 = __ZN2js8SCOutput11writeDoubleEd($58, $54);
    var $_0 = $59;
    __label__ = 36;
    break;
   case 18:
    var $61 = __ZNK8JSObject8isObjectEv($_idx19_val);
    if ($61) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $63 = __ZNK8JSObject7isArrayEv($_idx19_val);
    if ($63) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $65 = __ZN23JSStructuredCloneWriter11startObjectEP8JSObject($this, $35);
    var $_0 = $65;
    __label__ = 36;
    break;
   case 21:
    var $67 = __Z15js_IsTypedArrayP8JSObject($_idx19_val);
    if (($67 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $70 = __ZN23JSStructuredCloneWriter15writeTypedArrayEP8JSObject($this, $35);
    var $_0 = $70;
    __label__ = 36;
    break;
   case 23:
    var $72 = __Z16js_IsArrayBufferP8JSObject($_idx19_val);
    if (($72 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $75 = __ZN23JSStructuredCloneWriter16writeArrayBufferEP8JSObject($this, $35);
    var $_0 = $75;
    __label__ = 36;
    break;
   case 25:
    var $77 = __ZNK8JSObject9isBooleanEv($_idx19_val);
    if ($77) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $80 = HEAP32[$this >> 2];
    var $81 = $35;
    var $82 = __ZNK8JSObject16getPrimitiveThisEv($81);
    var $_idx6 = $82 | 0;
    var $_idx6_val$0 = HEAP32[$_idx6 >> 2];
    var $_idx6_val$1 = HEAP32[$_idx6 + 4 >> 2];
    var $83 = __ZNK2JS5Value9toBooleanEv($_idx6_val$0, $_idx6_val$1);
    var $84 = $83 & 1;
    var $85 = __ZN2js8SCOutput9writePairEjj($80, -65526, $84);
    var $_0 = $85;
    __label__ = 36;
    break;
   case 27:
    var $87 = __ZNK8JSObject8isNumberEv($_idx19_val);
    if ($87) {
      __label__ = 28;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 28:
    var $89 = $this | 0;
    var $90 = HEAP32[$89 >> 2];
    var $91 = __ZN2js8SCOutput9writePairEjj($90, -65524, 0);
    if ($91) {
      __label__ = 29;
      break;
    } else {
      var $_0 = 0;
      __label__ = 36;
      break;
    }
   case 29:
    var $93 = HEAP32[$89 >> 2];
    var $94 = $35;
    var $95 = __ZNK8JSObject16getPrimitiveThisEv($94);
    var $96 = __ZNK2JS5Value8toNumberEv($95);
    var $97 = __ZN2js8SCOutput11writeDoubleEd($93, $96);
    var $_0 = $97;
    __label__ = 36;
    break;
   case 30:
    var $99 = __ZNK8JSObject8isStringEv($_idx19_val);
    if ($99) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    var $101 = $35;
    var $102 = __ZNK8JSObject16getPrimitiveThisEv($101);
    var $_idx = $102 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $103 = __ZNK2JS5Value8toStringEv($_idx_val$0, $_idx_val$1);
    var $104 = __ZN23JSStructuredCloneWriter11writeStringEjP8JSString($this, -65525, $103);
    var $_0 = $104;
    __label__ = 36;
    break;
   case 32:
    var $107 = HEAP32[$this + 208 >> 2];
    if (($107 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $111 = HEAP32[$107 + 4 >> 2];
    if (($111 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $this_idx21_val_idx_val = HEAP32[HEAP32[$this >> 2] >> 2];
    var $114 = __ZN23JSStructuredCloneWriter7contextEv($this_idx21_val_idx_val);
    var $116 = HEAP32[$this + 212 >> 2];
    var $117 = FUNCTION_TABLE[$111]($114, $this, $35, $116);
    var $_0 = ($117 | 0) != 0;
    __label__ = 36;
    break;
   case 35:
    var $this_idx_val_idx_val = HEAP32[HEAP32[$this >> 2] >> 2];
    var $120 = __ZN23JSStructuredCloneWriter7contextEv($this_idx_val_idx_val);
    _JS_ReportErrorNumber($120, 4, 261, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 36;
    break;
   case 36:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN23JSStructuredCloneWriter10startWriteERKN2JS5ValueE["X"] = 1;

function __ZNK2js16AutoVectorRooterIN2JS5ValueEE4backEv($this) {
  var $_idx_val = HEAP32[$this + 16 >> 2];
  var $_idx1_val = HEAP32[$this + 20 >> 2];
  var $1 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE4backEv($_idx_val, $_idx1_val);
  return $1;
}

function __ZNK2js16AutoVectorRooterIiE4backEv($this) {
  var $_idx_val = HEAP32[$this + 16 >> 2];
  var $_idx1_val = HEAP32[$this + 20 >> 2];
  var $1 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE4backEv($_idx_val, $_idx1_val);
  return $1;
}

function __ZN2js16AutoVectorRooterIiE7popBackEv($this) {
  var $1 = $this + 12 | 0;
  __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE7popBackEv($1);
  return;
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEE7popBackEv($this) {
  var $1 = $this + 12 | 0;
  __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE7popBackEv($1);
  return;
}

function __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5clearEv($1);
  return;
}

function __ZN23JSStructuredCloneReader11checkDoubleEd($this, $d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    tempDoubleF64[0] = $d;
    var $1$0 = tempDoubleI32[0];
    var $1$1 = tempDoubleI32[1];
    var $2 = _JSVAL_IS_DOUBLE_IMPL599($1$0, $1$1);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $this_idx_val_idx_val = HEAP32[HEAP32[$this >> 2] >> 2];
    var $5 = __ZN23JSStructuredCloneReader7contextEv($this_idx_val_idx_val);
    _JS_ReportErrorNumber($5, 4, 260, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str2575 | 0, tempInt));
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN23JSStructuredCloneReader7contextEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js7SCInput7contextEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZN23JSStructuredCloneReader10readStringEj($this, $nchars) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $chars = __stackBase__;
    if ($nchars >>> 0 > 268435455) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $this_idx2_val_idx_val = HEAP32[HEAP32[$this >> 2] >> 2];
    var $3 = __ZN23JSStructuredCloneReader7contextEv($this_idx2_val_idx_val);
    _JS_ReportErrorNumber($3, 4, 260, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str3576 | 0, tempInt));
    var $_1 = 0;
    __label__ = 9;
    break;
   case 3:
    __ZN5CharsC1Ev($chars);
    var $this_idx1 = $this | 0;
    var $this_idx1_val_idx_val = HEAP32[HEAP32[$this_idx1 >> 2] >> 2];
    var $5 = __ZN23JSStructuredCloneReader7contextEv($this_idx1_val_idx_val);
    var $6 = __ZN5Chars8allocateEP9JSContextj($chars, $5, $nchars);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 0;
    var $chars_idx4_pre_phi = $chars + 4 | 0;
    __label__ = 8;
    break;
   case 5:
    var $8 = HEAP32[$this_idx1 >> 2];
    var $chars_idx3 = $chars + 4 | 0;
    var $chars_idx3_val = HEAP32[$chars_idx3 >> 2];
    var $9 = __ZN5Chars3getEv($chars_idx3_val);
    var $10 = __ZN2js7SCInput9readCharsEPtj($8, $9, $nchars);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      var $chars_idx4_pre_phi = $chars_idx3;
      __label__ = 8;
      break;
    }
   case 6:
    var $this_idx_val_idx_val = HEAP32[HEAP32[$this_idx1 >> 2] >> 2];
    var $12 = __ZN23JSStructuredCloneReader7contextEv($this_idx_val_idx_val);
    var $13 = $12;
    var $14 = __Z12js_NewStringP9JSContextPtj($13, $9, $nchars);
    var $15 = $14 | 0;
    if (($14 | 0) == 0) {
      var $_0 = $15;
      var $chars_idx4_pre_phi = $chars_idx3;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN5Chars6forgetEv($chars);
    var $_0 = $15;
    var $chars_idx4_pre_phi = $chars_idx3;
    __label__ = 8;
    break;
   case 8:
    var $chars_idx4_pre_phi;
    var $_0;
    var $chars_idx4_val = HEAP32[$chars_idx4_pre_phi >> 2];
    __ZN5CharsD1Ev($chars_idx4_val);
    var $_1 = $_0;
    __label__ = 9;
    break;
   case 9:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN5CharsC1Ev($this) {
  __ZN5CharsC2Ev($this);
  return;
}

function __ZN5Chars8allocateEP9JSContextj($this, $cx, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = ($len << 1) + 2 | 0;
    var $3 = __ZN9JSContext7malloc_Ej($cx, $2);
    var $4 = $3;
    HEAP32[$this + 4 >> 2] = $4;
    HEAP32[$this >> 2] = $cx;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP16[$4 + ($len << 1) >> 1] = 0;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN5CharsD1Ev($this_0_1_val) {
  __ZN5CharsD2Ev($this_0_1_val);
  return;
}

function __ZN23JSStructuredCloneReader14readTypedArrayEjjPN2JS5ValueE($this, $tag, $nelems, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL14TagToArrayTypej($tag);
    var $this_idx = $this | 0;
    var $this_idx_val_idx_val = HEAP32[HEAP32[$this_idx >> 2] >> 2];
    var $2 = __ZN23JSStructuredCloneReader7contextEv($this_idx_val_idx_val);
    var $3 = __Z19js_CreateTypedArrayP9JSContextij($2, $1, $nelems);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $3);
    var $6 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($3);
    if (($1 | 0) == 0 || ($1 | 0) == 1 || ($1 | 0) == 8) {
      __label__ = 3;
      break;
    } else if (($1 | 0) == 2 || ($1 | 0) == 3) {
      __label__ = 4;
      break;
    } else if (($1 | 0) == 4 || ($1 | 0) == 5 || ($1 | 0) == 6) {
      __label__ = 5;
      break;
    } else if (($1 | 0) == 7) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    var $8 = HEAP32[$this_idx >> 2];
    var $_idx3_val = HEAP32[$6 + 24 >> 2];
    var $9 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx3_val);
    var $10 = __ZN2js7SCInput9readArrayIhEEbPT_j($8, $9, $nelems);
    var $_0 = $10;
    __label__ = 7;
    break;
   case 4:
    var $12 = HEAP32[$this_idx >> 2];
    var $_idx2_val = HEAP32[$6 + 24 >> 2];
    var $13 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx2_val);
    var $14 = $13;
    var $15 = __ZN2js7SCInput9readArrayItEEbPT_j($12, $14, $nelems);
    var $_0 = $15;
    __label__ = 7;
    break;
   case 5:
    var $17 = HEAP32[$this_idx >> 2];
    var $_idx1_val = HEAP32[$6 + 24 >> 2];
    var $18 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx1_val);
    var $19 = $18;
    var $20 = __ZN2js7SCInput9readArrayIjEEbPT_j($17, $19, $nelems);
    var $_0 = $20;
    __label__ = 7;
    break;
   case 6:
    var $22 = HEAP32[$this_idx >> 2];
    var $_idx_val = HEAP32[$6 + 24 >> 2];
    var $23 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx_val);
    var $24 = $23;
    var $25 = __ZN2js7SCInput9readArrayIyEEbPT_j($22, $24, $nelems);
    var $_0 = $25;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7SCInput9readArrayIjEEbPT_j($this, $p, $nelems) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($nelems, 1);
    var $1 = $uadd.f0;
    var $2 = $1 >>> 1;
    var $3 = $uadd.f1;
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this + 4 | 0;
    var $8 = HEAPU32[$7 >> 2];
    if ($2 >>> 0 > HEAP32[$this + 8 >> 2] - $8 >> 3 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $this_idx_val = HEAP32[$this >> 2];
    __ZN2js7SCInput3eofEv($this_idx_val);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 4:
    var $16 = $8;
    var $17 = $16 + ($nelems << 2) | 0;
    if (($16 | 0) == ($17 | 0)) {
      var $24 = $8;
      __label__ = 7;
      break;
    } else {
      var $_012 = $p;
      var $q_03 = $16;
      __label__ = 5;
      break;
    }
   case 5:
    var $q_03;
    var $_012;
    var $19 = $q_03 + 4 | 0;
    var $20 = HEAP32[$q_03 >> 2];
    var $21 = __ZL9SwapBytesj($20);
    HEAP32[$_012 >> 2] = $21;
    if (($19 | 0) == ($17 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $_012 = $_012 + 4 | 0;
      var $q_03 = $19;
      __label__ = 5;
      break;
    }
   case 6:
    var $24 = HEAP32[$7 >> 2];
    __label__ = 7;
    break;
   case 7:
    var $24;
    HEAP32[$7 >> 2] = $24 + ($2 << 3) | 0;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7SCInput9readArrayIyEEbPT_j($this, $p, $nelems) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 4 | 0;
    var $4 = HEAPU32[$3 >> 2];
    if (HEAP32[$this + 8 >> 2] - $4 >> 3 >>> 0 < $nelems >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this >> 2];
    __ZN2js7SCInput3eofEv($this_idx_val);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $12 = $4 + ($nelems << 3) | 0;
    if (($nelems | 0) == 0) {
      var $19 = $4;
      __label__ = 6;
      break;
    } else {
      var $_012 = $p;
      var $q_03 = $4;
      __label__ = 4;
      break;
    }
   case 4:
    var $q_03;
    var $_012;
    var $14 = $q_03 + 8 | 0;
    var $15$0 = HEAP32[$q_03 >> 2];
    var $15$1 = HEAP32[$q_03 + 4 >> 2];
    var $16 = __ZL9SwapBytesy($15$0, $15$1);
    var $16$0 = $16[0];
    var $16$1 = $16[1];
    HEAP32[$_012 >> 2] = $16$0;
    HEAP32[$_012 + 4 >> 2] = $16$1;
    if (($14 | 0) == ($12 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $_012 + 8 | 0;
      var $q_03 = $14;
      __label__ = 4;
      break;
    }
   case 5:
    var $19 = HEAP32[$3 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $19;
    HEAP32[$3 >> 2] = $19 + ($nelems << 3) | 0;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN23JSStructuredCloneReader15readArrayBufferEjPN2JS5ValueE($this, $nbytes, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx = $this | 0;
    var $this_idx_val_idx_val = HEAP32[HEAP32[$this_idx >> 2] >> 2];
    var $1 = __ZN23JSStructuredCloneReader7contextEv($this_idx_val_idx_val);
    var $2 = __Z20js_CreateArrayBufferP9JSContextj($1, $nbytes);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $5 = HEAP32[$this_idx >> 2];
    var $_idx_val = HEAP32[$2 + 32 >> 2];
    var $6 = __ZN8JSObject21arrayBufferDataOffsetEv($_idx_val);
    var $7 = __ZN2js7SCInput9readArrayIhEEbPT_j($5, $6, $nbytes);
    var $_0 = $7;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9SwapBytesj($u) {
  return $u;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIP8JSObjectjEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefIjEcvRjEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5countEv($this_0_3_val) {
  return $this_0_3_val;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv($this) {
  return;
}

function _INT_TO_JSID603($i) {
  return $i << 1 | 1;
}

function _JSID_IS_VOID605($iden) {
  return ($iden | 0) == 2 & 1;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this_0_2_val, $this_0_3_val, $this_0_5_val) {
  return ($this_0_5_val + $this_0_3_val | 0) >>> 0 >= ($this_0_2_val * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZL18JSDOUBLE_IS_FINITEd600($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE5clearEv($this) {
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE7popBackEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE7popBackEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 3) | 0;
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEC2ERS7_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectjEEEC2ERS4_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefIjEC2ERj($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js12HashMapEntryIP8JSObjectjEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN23JSStructuredCloneReader9startReadEPN2JS5ValueE($this, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tag = __stackBase__;
    var $data = __stackBase__ + 4;
    var $d = __stackBase__ + 8;
    var $d1 = __stackBase__ + 16;
    var $tag2 = __stackBase__ + 24;
    var $nchars = __stackBase__ + 28;
    var $1 = __stackBase__ + 32;
    var $2 = __stackBase__ + 40;
    var $3 = $this | 0;
    var $4 = HEAP32[$3 >> 2];
    var $5 = __ZN2js7SCInput8readPairEPjS1_($4, $tag, $data);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 55;
      break;
    }
   case 2:
    var $7 = HEAPU32[$tag >> 2];
    if (($7 | 0) == -65536) {
      __label__ = 3;
      break;
    } else if (($7 | 0) == -65535) {
      __label__ = 4;
      break;
    } else if (($7 | 0) == -65534 || ($7 | 0) == -65526) {
      __label__ = 5;
      break;
    } else if (($7 | 0) == -65532 || ($7 | 0) == -65525) {
      __label__ = 7;
      break;
    } else if (($7 | 0) == -65524) {
      __label__ = 10;
      break;
    } else if (($7 | 0) == -65531) {
      __label__ = 13;
      break;
    } else if (($7 | 0) == -65530) {
      __label__ = 26;
      break;
    } else if (($7 | 0) == -65529 || ($7 | 0) == -65528) {
      __label__ = 33;
      break;
    } else if (($7 | 0) == -65523) {
      __label__ = 40;
      break;
    } else if (($7 | 0) == -65527) {
      __label__ = 43;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 3:
    __ZN2JS5Value7setNullEv($vp);
    __label__ = 54;
    break;
   case 4:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 54;
    break;
   case 5:
    var $12 = (HEAP32[$data >> 2] | 0) != 0;
    __ZN2JS5Value10setBooleanEb($vp, $12);
    if (($7 | 0) == -65526) {
      __label__ = 6;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 6:
    var $this_idx13_val_idx_val = HEAP32[HEAP32[$3 >> 2] >> 2];
    var $15 = __ZN23JSStructuredCloneReader7contextEv($this_idx13_val_idx_val);
    var $16 = $15;
    var $17 = __Z20js_PrimitiveToObjectP9JSContextPN2JS5ValueE($16, $vp);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 7:
    var $20 = HEAP32[$data >> 2];
    var $21 = __ZN23JSStructuredCloneReader10readStringEj($this, $20);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2JS5Value9setStringEP8JSString($vp, $21);
    if (($7 | 0) == -65525) {
      __label__ = 9;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 9:
    var $this_idx12_val_idx_val = HEAP32[HEAP32[$3 >> 2] >> 2];
    var $26 = __ZN23JSStructuredCloneReader7contextEv($this_idx12_val_idx_val);
    var $27 = $26;
    var $28 = __Z20js_PrimitiveToObjectP9JSContextPN2JS5ValueE($27, $vp);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 10:
    var $31 = HEAP32[$3 >> 2];
    var $32 = __ZN2js7SCInput10readDoubleEPd($31, $d);
    if ($32) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 55;
      break;
    }
   case 11:
    var $34 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $35 = __ZN23JSStructuredCloneReader11checkDoubleEd($this, $34);
    if ($35) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 55;
      break;
    }
   case 12:
    __ZN2JS5Value9setDoubleEd($vp, $34);
    var $this_idx11_val_idx_val = HEAP32[HEAP32[$3 >> 2] >> 2];
    var $37 = __ZN23JSStructuredCloneReader7contextEv($this_idx11_val_idx_val);
    var $38 = $37;
    var $39 = __Z20js_PrimitiveToObjectP9JSContextPN2JS5ValueE($38, $vp);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 13:
    var $42 = HEAP32[$3 >> 2];
    var $43 = __ZN2js7SCInput10readDoubleEPd($42, $d1);
    if ($43) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 55;
      break;
    }
   case 14:
    var $45 = (tempDoubleI32[0] = HEAP32[$d1 >> 2], tempDoubleI32[1] = HEAP32[$d1 + 4 >> 2], tempDoubleF64[0]);
    var $46 = __ZN23JSStructuredCloneReader11checkDoubleEd($this, $45);
    if ($46) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 55;
      break;
    }
   case 15:
    var $48 = !isNaN($45) && !isNaN(0);
    if ($48) {
      __label__ = 16;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 16:
    var $50 = __ZL18JSDOUBLE_IS_FINITEd600($45);
    if (($50 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    if ($45 < 0) {
      __label__ = 18;
      break;
    } else {
      var $57 = $45;
      __label__ = 19;
      break;
    }
   case 18:
    var $57 = -$45;
    __label__ = 19;
    break;
   case 19:
    var $57;
    if ($57 > 864e13) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $60 = $45;
    var $61 = __ZL18js_DoubleToIntegerd601($60);
    var $65 = $61;
    __label__ = 22;
    break;
   case 21:
    var $63 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $65 = $63;
    __label__ = 22;
    break;
   case 22:
    var $65;
    if ($45 != $65) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $this_idx10_val_idx_val = HEAP32[HEAP32[$3 >> 2] >> 2];
    var $68 = __ZN23JSStructuredCloneReader7contextEv($this_idx10_val_idx_val);
    _JS_ReportErrorNumber($68, 4, 260, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str4577 | 0, tempInt));
    var $_0 = 0;
    __label__ = 55;
    break;
   case 24:
    var $this_idx9_val_idx_val = HEAP32[HEAP32[$3 >> 2] >> 2];
    var $70 = __ZN23JSStructuredCloneReader7contextEv($this_idx9_val_idx_val);
    var $71 = $70;
    var $72 = __Z20js_NewDateObjectMsecP9JSContextd($71, $45);
    if (($72 | 0) == 0) {
      var $_0 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $75 = $72;
    __ZN2JS5Value9setObjectER8JSObject($vp, $75);
    __label__ = 54;
    break;
   case 26:
    var $77 = HEAP32[$3 >> 2];
    var $78 = __ZN2js7SCInput8readPairEPjS1_($77, $tag2, $nchars);
    if ($78) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 0;
      __label__ = 55;
      break;
    }
   case 27:
    if ((HEAP32[$tag2 >> 2] | 0) == -65532) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $this_idx8_val_idx_val = HEAP32[HEAP32[$3 >> 2] >> 2];
    var $83 = __ZN23JSStructuredCloneReader7contextEv($this_idx8_val_idx_val);
    _JS_ReportErrorNumber($83, 4, 260, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str5578 | 0, tempInt));
    var $_0 = 0;
    __label__ = 55;
    break;
   case 29:
    var $85 = HEAP32[$nchars >> 2];
    var $86 = __ZN23JSStructuredCloneReader10readStringEj($this, $85);
    if (($86 | 0) == 0) {
      var $_0 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $_idx_val = HEAP32[$86 >> 2];
    var $this_idx7_val_idx_val = HEAP32[HEAP32[$3 >> 2] >> 2];
    var $89 = __ZN23JSStructuredCloneReader7contextEv($this_idx7_val_idx_val);
    var $90 = __ZN8JSString8getCharsEP9JSContext($86, $89);
    if (($90 | 0) == 0) {
      var $_0 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $93 = __ZNK8JSString6lengthEv($_idx_val);
    var $this_idx6_val_idx_val = HEAP32[HEAP32[$3 >> 2] >> 2];
    var $94 = __ZN23JSStructuredCloneReader7contextEv($this_idx6_val_idx_val);
    var $95 = HEAP32[$data >> 2];
    var $96 = __ZN2js6RegExp21createObjectNoStaticsEP9JSContextPKtjjPNS_11TokenStreamE($94, $90, $93, $95);
    if (($96 | 0) == 0) {
      var $_0 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    __ZN2JS5Value9setObjectER8JSObject($vp, $96);
    __label__ = 54;
    break;
   case 33:
    var $100 = ($7 | 0) == -65529;
    var $this_idx5_val_idx_val = HEAP32[HEAP32[$3 >> 2] >> 2];
    var $101 = __ZN23JSStructuredCloneReader7contextEv($this_idx5_val_idx_val);
    if ($100) {
      __label__ = 34;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 34:
    var $103 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($101);
    var $107 = $103;
    __label__ = 36;
    break;
   case 35:
    var $105 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE602($101);
    var $107 = $105;
    __label__ = 36;
    break;
   case 36:
    var $107;
    if (($107 | 0) == 0) {
      var $_0 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $110 = $this + 4 | 0;
    __ZN2JSL11ObjectValueER8JSObject597($1, $107);
    var $_idx2 = $1 | 0;
    var $st$3$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$3$1 >> 2];
    var $111 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($110, $_idx2_val$0, $_idx2_val$1);
    if ($111) {
      __label__ = 38;
      break;
    } else {
      var $_0 = 0;
      __label__ = 55;
      break;
    }
   case 38:
    var $113 = $this + 96 | 0;
    __ZN2JSL11ObjectValueER8JSObject597($2, $107);
    var $_idx1 = $2 | 0;
    var $st$3$0 = $_idx1 | 0;
    var $_idx1_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx1 + 4 | 0;
    var $_idx1_val$1 = HEAP32[$st$3$1 >> 2];
    var $114 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($113, $_idx1_val$0, $_idx1_val$1);
    if ($114) {
      __label__ = 39;
      break;
    } else {
      var $_0 = 0;
      __label__ = 55;
      break;
    }
   case 39:
    __ZN2JS5Value9setObjectER8JSObject($vp, $107);
    __label__ = 54;
    break;
   case 40:
    var $117 = HEAPU32[$data >> 2];
    var $118 = $this + 96 | 0;
    var $119 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($118);
    if ($117 >>> 0 < $119 >>> 0) {
      __label__ = 42;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    var $this_idx4_val_idx_val = HEAP32[HEAP32[$3 >> 2] >> 2];
    var $122 = __ZN23JSStructuredCloneReader7contextEv($this_idx4_val_idx_val);
    _JS_ReportErrorNumber($122, 4, 260, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str6579 | 0, tempInt));
    __label__ = 42;
    break;
   case 42:
    var $124 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($118, $117);
    var $125 = $124 | 0;
    var $126$0 = HEAP32[$125 >> 2];
    var $126$1 = HEAP32[$125 + 4 >> 2];
    var $127 = $vp | 0;
    HEAP32[$127 >> 2] = $126$0;
    HEAP32[$127 + 4 >> 2] = $126$1;
    __label__ = 54;
    break;
   case 43:
    var $129 = HEAP32[$data >> 2];
    var $130 = __ZN23JSStructuredCloneReader15readArrayBufferEjPN2JS5ValueE($this, $129, $vp);
    var $_0 = $130;
    __label__ = 55;
    break;
   case 44:
    if ($7 >>> 0 < 4293918721) {
      __label__ = 45;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 45:
    var $134 = HEAP32[$data >> 2];
    var $135 = __ZL23ReinterpretPairAsDoublejj($7, $134);
    var $136 = __ZN23JSStructuredCloneReader11checkDoubleEd($this, $135);
    if ($136) {
      __label__ = 46;
      break;
    } else {
      var $_0 = 0;
      __label__ = 55;
      break;
    }
   case 46:
    var $138 = __ZN2JS5Value9setNumberEd($vp, $135);
    __label__ = 54;
    break;
   case 47:
    if (($7 + 65280 | 0) >>> 0 < 9) {
      __label__ = 48;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 48:
    var $142 = HEAP32[$data >> 2];
    var $143 = __ZN23JSStructuredCloneReader14readTypedArrayEjjPN2JS5ValueE($this, $7, $142, $vp);
    var $_0 = $143;
    __label__ = 55;
    break;
   case 49:
    var $146 = HEAP32[$this + 188 >> 2];
    if (($146 | 0) == 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    var $150 = HEAPU32[$146 >> 2];
    if (($150 | 0) == 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 51:
    var $this_idx3_val_idx_val = HEAP32[HEAP32[$3 >> 2] >> 2];
    var $153 = __ZN23JSStructuredCloneReader7contextEv($this_idx3_val_idx_val);
    _JS_ReportErrorNumber($153, 4, 260, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str7580 | 0, tempInt));
    var $_0 = 0;
    __label__ = 55;
    break;
   case 52:
    var $this_idx_val_idx_val = HEAP32[HEAP32[$3 >> 2] >> 2];
    var $155 = __ZN23JSStructuredCloneReader7contextEv($this_idx_val_idx_val);
    var $156 = HEAP32[$data >> 2];
    var $158 = HEAP32[$this + 192 >> 2];
    var $159 = FUNCTION_TABLE[$150]($155, $this, $7, $156, $158);
    if (($159 | 0) == 0) {
      var $_0 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    __ZN2JS5Value9setObjectER8JSObject($vp, $159);
    __label__ = 54;
    break;
   case 54:
    var $_0 = 1;
    __label__ = 55;
    break;
   case 55:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN23JSStructuredCloneReader9startReadEPN2JS5ValueE["X"] = 1;

function __ZL18js_DoubleToIntegerd601($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d == 0) {
      var $_0 = $d;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL18JSDOUBLE_IS_FINITEd600($d);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZL15JSDOUBLE_IS_NaNd628($d);
    var $d_ = ($6 | 0) == 0 ? $d : 0;
    var $_0 = $d_;
    __label__ = 7;
    break;
   case 4:
    if ($d < 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = _floor($d);
    var $_0 = $10;
    __label__ = 7;
    break;
   case 6:
    var $12 = -$d;
    var $13 = _floor($12);
    var $_0 = -$13;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE602($cx) {
  var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb613($3);
  var $5 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE614($cx, $4);
  return $5;
}

function __ZL23ReinterpretPairAsDoublejj($tag, $data) {
  var $1 = __ZL12PairToUInt64jj($tag, $data);
  var $1$0 = $1[0];
  var $1$1 = $1[1];
  var $2 = __ZL25ReinterpretUInt64AsDoubley($1$0, $1$1);
  return $2;
}

function __ZN23JSStructuredCloneReader6readIdEPi($this, $idp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tag = __stackBase__;
    var $data = __stackBase__ + 4;
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js7SCInput8readPairEPjS1_($2, $tag, $data);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    var $5 = HEAP32[$tag >> 2];
    if (($5 | 0) == -65533) {
      __label__ = 3;
      break;
    } else if (($5 | 0) == -65532) {
      __label__ = 4;
      break;
    } else if (($5 | 0) == -65536) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    var $7 = HEAP32[$data >> 2];
    var $8 = _INT_TO_JSID603($7);
    HEAP32[$idp >> 2] = $8;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 4:
    var $10 = HEAP32[$data >> 2];
    var $11 = __ZN23JSStructuredCloneReader10readStringEj($this, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $this_idx1_val_idx_val = HEAP32[HEAP32[$1 >> 2] >> 2];
    var $14 = __ZN23JSStructuredCloneReader7contextEv($this_idx1_val_idx_val);
    var $15 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($14, $11);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = __ZL12ATOM_TO_JSIDP6JSAtom604($15);
    HEAP32[$idp >> 2] = $18;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 7:
    HEAP32[$idp >> 2] = 2;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 8:
    var $this_idx_val_idx_val = HEAP32[HEAP32[$1 >> 2] >> 2];
    var $21 = __ZN23JSStructuredCloneReader7contextEv($this_idx_val_idx_val);
    _JS_ReportErrorNumber($21, 4, 260, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str246539 | 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12ATOM_TO_JSIDP6JSAtom604($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj609($1);
  return $2;
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEE5clearEv($this) {
  var $1 = $this + 12 | 0;
  __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE5clearEv($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5clearEv($this) {
  var $3 = HEAP32[$this + 24 >> 2];
  var $6 = HEAP32[$this + 8 >> 2] * 12 | 0;
  _memset($3, 0, $6, 1);
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE4backEv($this_0_1_val, $this_0_2_val) {
  var $1 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val);
  return $1 - 4 | 0;
}

function __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE4backEv($this_0_1_val, $this_0_2_val) {
  var $1 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val);
  return $1 - 8 | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 12 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 8 >> 2];
    var $this_idx1 = $this + 12 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 20 >> 2];
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 3:
    var $14 = $this | 0;
    var $15 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($14, $10);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $19 = $this + 16 | 0;
    var $21 = HEAP32[$19 >> 2] + 1 | 0;
    HEAP32[$19 >> 2] = $21;
    HEAP32[$2 >> 2] = $15;
    var $22 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 6;
    break;
   case 6:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE6isLiveEv($src_01_idx_val);
    if ($24) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $26 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE10getKeyHashEv($src_01_idx1_val);
    var $27 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $26);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEENS_7MoveRefIT_EERS9_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEaSENS_7MoveRefIS6_EE($27, $_02_val);
    __label__ = 8;
    break;
   case 8:
    var $29 = $src_01 + 12 | 0;
    if (($29 | 0) == ($22 | 0)) {
      __label__ = 9;
      break;
    } else {
      var $src_01 = $29;
      __label__ = 6;
      break;
    }
   case 9:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($3);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js15TempAllocPolicy7malloc_Ej($alloc, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEaSENS_7MoveRefIS6_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = $2 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIP8JSObjectjEEEENS_7MoveRefIT_EERS6_($1, $7);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js12HashMapEntryIP8JSObjectjEaSENS_7MoveRefIS3_EE($6, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEENS_7MoveRefIT_EERS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js15TempAllocPolicy5free_EPv($0);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEC1ERS7_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEC2ERS7_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIP8JSObjectjEaSENS_7MoveRefIS3_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIP8JSObjectjEEEptEv($rhs_0);
  var $4 = $3 | 0;
  __ZN2js4MoveIP8JSObjectEENS_7MoveRefIT_EERKS4_($1, $4);
  var $_idx_val = HEAP32[$1 >> 2];
  var $5 = __ZNK2js7MoveRefIP8JSObjectEcvRS2_Ev($_idx_val);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = $3 + 4 | 0;
  __ZN2js4MoveIjEENS_7MoveRefIT_EERS2_($2, $8);
  var $_idx1_val = HEAP32[$2 >> 2];
  var $9 = __ZNK2js7MoveRefIjEcvRjEv($_idx1_val);
  var $10 = HEAP32[$9 >> 2];
  HEAP32[$this + 4 >> 2] = $10;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIP8JSObjectjEEEENS_7MoveRefIT_EERS6_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectjEEEC1ERS4_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectjEEEC1ERS4_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectjEEEC2ERS4_($this, $t);
  return;
}

function __ZN2js4MoveIjEENS_7MoveRefIT_EERS2_($agg_result, $t) {
  __ZN2js7MoveRefIjEC1ERj($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIjEC1ERj($this, $t) {
  __ZN2js7MoveRefIjEC2ERj($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP8JSObjectjEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIP8JSObjectjEC1Ev($this) {
  __ZN2js12HashMapEntryIP8JSObjectjEC2Ev($this);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l_val1) {
  var $1 = __ZN2js13PointerHasherIP8JSObjectLj2EE4hashERKS2_($l_val1);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js8SCOutput7contextEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZL9SwapBytest($u) {
  return $u;
}

function __ZL14JSID_FROM_BITSj609($bits) {
  return $bits;
}

function __ZNK2js7SCInput7contextEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function _JS_CANONICALIZE_NAN644($d) {
  var $1 = isNaN($d) || isNaN(0);
  var $_d = $1 ? NaN : $d;
  return $_d;
}

function __ZL25ReinterpretUInt64AsDoubley($u$0, $u$1) {
  var $1 = (tempDoubleI32[0] = $u$0, tempDoubleI32[1] = $u$1, tempDoubleF64[0]);
  return $1;
}

function __ZL15JSDOUBLE_IS_NaNd628($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE12setCollisionEj($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_jEE($e) {
  return $e | 0;
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 3) | 0;
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 3) | 0;
}

function __ZN2js10VectorImplIyLj0ENS_15TempAllocPolicyELb1EE13copyConstructIyEEvPyPKT_S7_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2$0 = HEAP32[$p_01 >> 2];
    var $2$1 = HEAP32[$p_01 + 4 >> 2];
    HEAP32[$_02 >> 2] = $2$0;
    HEAP32[$_02 + 4 >> 2] = $2$1;
    var $3 = $p_01 + 8 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 8 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL15GetGCObjectKindEjb613($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN5CharsC2Ev($this) {
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  return;
}

function __ZN2js10ThreadData24triggerOperationCallbackEP9JSRuntime($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = 1;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $l_val4 = HEAP32[$l >> 2];
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($6, $l_val4);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE12setCollisionEj($entry_0);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $l_val = HEAP32[$l >> 2];
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($27, $l_val);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($e, $l_val1) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_jEE($1);
  var $_val = HEAP32[$2 >> 2];
  var $3 = __ZN2js13PointerHasherIP8JSObjectLj2EE5matchERKS2_S5_($_val, $l_val1);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE19growByUninitializedEj($this, $incr) {
  var $1 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr);
  return $1;
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE4backEv($this_0_1_val, $this_0_2_val) {
  var $1 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val);
  return $1 - 8 | 0;
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEixEj($this_0_1_val, $i) {
  var $1 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE5beginEv($this_0_1_val);
  return $1 + ($i << 3) | 0;
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 8 | 0;
    var $4 = HEAPU32[$3 >> 2];
    if ((HEAP32[$this + 12 >> 2] - $4 | 0) >>> 0 < $incr >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $10 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = HEAP32[$3 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $10;
    HEAP32[$3 >> 2] = $10 + $incr | 0;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 3;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplIyLj0ENS_15TempAllocPolicyELb1EE13moveConstructIyEEvPyPKT_S7_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIyLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIyLj0ES1_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 268435455) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 268435455) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIyLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIyLj0ES1_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 3;
    var $2 = $v | 0;
    var $3 = $v + 4 | 0;
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($2, $5, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    var $10 = $v + 12 | 0;
    HEAP32[$3 >> 2] = $9;
    HEAP32[$10 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIyLj0ENS_15TempAllocPolicyELb1EE13moveConstructIyEEvPyPKT_S7_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIyLj0ENS_15TempAllocPolicyELb1EE13copyConstructIyEEvPyPKT_S7_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE14internalAppendIyEEvT_($this, $t$0, $t$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $5 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $st$0$0 = $1 | 0;
    HEAP32[$st$0$0 >> 2] = $t$0;
    var $st$0$1 = $1 + 4 | 0;
    HEAP32[$st$0$1 >> 2] = $t$1;
    var $5 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    HEAP32[$this_idx1 >> 2] = $5 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEC2ES1_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE614($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 24;
    var $4 = __ZNK9JSContext5hasfpEv($cx);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $7;
    var $8 = $cx;
    var $9 = $global;
    var $10 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($8, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $18 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZNK9JSContext2fpEv($cx);
    var $13 = __ZNK2js10StackFrame10scopeChainEv($12);
    var $14 = $13;
    var $15 = __ZNK8JSObject9getGlobalEv($14);
    var $16 = $15;
    HEAP32[$global >> 2] = $16;
    var $18 = $16;
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $18, $19);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $20 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    HEAP32[$proto >> 2] = $22;
    var $29 = $22;
    __label__ = 9;
    break;
   case 7:
    var $24 = $cx;
    var $26 = $proto;
    var $27 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($24, $18, $3, $26, __ZN2js11ObjectClassE);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $29 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $29;
    var $30 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE615($cx, $29, $18, $kind);
    var $_0 = $30;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE615($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, __ZN2js11ObjectClassE, $1, $parent, 0, (__ZN2js11ObjectClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $7 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, __ZN2js11ObjectClassE, $kind);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $10);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN5CharsD2Ev($this_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_1_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $this_0_1_val;
    __ZN9JSContext5free_EPv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN23JSStructuredCloneReaderD2Ev($this) {
  var $1 = $this + 96 | 0;
  __ZN2js15AutoValueVectorD1Ev($1);
  var $2 = $this + 4 | 0;
  __ZN2js15AutoValueVectorD1Ev($2);
  return;
}

function __ZN23JSStructuredCloneReaderC2ERN2js7SCInputEPK26JSStructuredCloneCallbacksPv($this, $in, $cb) {
  HEAP32[$this >> 2] = $in;
  var $2 = $this + 4 | 0;
  var $in_idx1 = $in | 0;
  var $in_idx1_val = HEAP32[$in_idx1 >> 2];
  var $3 = __ZNK2js7SCInput7contextEv($in_idx1_val);
  __ZN2js15AutoValueVectorC1EP9JSContext($2, $3);
  var $4 = $this + 96 | 0;
  var $in_idx_val = HEAP32[$in_idx1 >> 2];
  var $5 = __ZNK2js7SCInput7contextEv($in_idx_val);
  __ZN2js15AutoValueVectorC1EP9JSContext($4, $5);
  HEAP32[$this + 188 >> 2] = $cb;
  HEAP32[$this + 192 >> 2] = 0;
  return;
}

function __ZN2js8SCOutputD2Ev($this) {
  var $1 = $this + 4 | 0;
  __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEED1Ev($1);
  return;
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN23JSStructuredCloneWriterD2Ev($this) {
  var $1 = $this + 180 | 0;
  __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev($1);
  var $2 = $this + 120 | 0;
  __ZN2js12AutoIdVectorD1Ev($2);
  var $4 = $this + 96 | 0;
  __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEED1Ev($4);
  var $5 = $this + 4 | 0;
  __ZN2js15AutoValueVectorD1Ev($5);
  return;
}

function __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 24 >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED1Ev($this_0_6_val) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED2Ev($this_0_6_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED2Ev($this_0_6_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_6_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($this_0_6_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E4initEj($1);
  return $2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $0 = $this | 0;
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($0, 16);
    HEAP32[$this + 24 >> 2] = $1;
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, 4);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN23JSStructuredCloneWriterC2ERN2js8SCOutputEPK26JSStructuredCloneCallbacksPv($this, $out, $cb) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  HEAP32[$this >> 2] = $out;
  var $4 = $this + 4 | 0;
  var $out_idx3 = $out | 0;
  var $out_idx3_val = HEAP32[$out_idx3 >> 2];
  var $5 = __ZNK2js8SCOutput7contextEv($out_idx3_val);
  __ZN2js15AutoValueVectorC1EP9JSContext($4, $5);
  var $6 = $this + 96 | 0;
  var $out_idx2_val = HEAP32[$out_idx3 >> 2];
  var $7 = __ZNK2js8SCOutput7contextEv($out_idx2_val);
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $7);
  var $8 = $6;
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEC1ES1_($8, $_0_val);
  var $9 = $this + 120 | 0;
  var $out_idx1_val = HEAP32[$out_idx3 >> 2];
  var $10 = __ZNK2js8SCOutput7contextEv($out_idx1_val);
  __ZN2js12AutoIdVectorC1EP9JSContext($9, $10);
  var $11 = $this + 180 | 0;
  var $out_idx_val = HEAP32[$out_idx3 >> 2];
  var $12 = __ZNK2js8SCOutput7contextEv($out_idx_val);
  __ZN2js15TempAllocPolicyC1EP9JSContext($2, $12);
  var $_04_val = HEAP32[$2 >> 2];
  __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_($11, $_04_val);
  HEAP32[$this + 208 >> 2] = $cb;
  HEAP32[$this + 212 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_($this, $a_01) {
  __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_($this, $a_01);
  return;
}

function __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_($this, $a_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC1ES9_($1, $a_0);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC1ES9_($this, $ap_01) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap_01);
  return;
}

function __ZN2js10ThreadDataC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js10StackSpaceC2Ev($3);
  HEAP8[$this + 24 | 0] = 0;
  var $5 = $this + 28 | 0;
  __ZN2js8GSNCacheC1Ev($5);
  var $6 = $this + 56 | 0;
  __ZN2js13PropertyCacheC1Ev($6);
  HEAP32[$this + 65596 >> 2] = 0;
  var $8 = $this + 65600 | 0;
  var $9 = __ZN2js18GetNativeStackBaseEv();
  HEAP32[$8 >> 2] = $9;
  HEAP32[$this + 65604 >> 2] = 0;
  var $11 = $this + 65608 | 0;
  __ZN2js24ConservativeGCThreadDataC1Ev($11);
  HEAP32[$this + 65656 >> 2] = 0;
  return;
}

function __ZN2js8GSNCacheC1Ev($this) {
  __ZN2js8GSNCacheC2Ev($this);
  return;
}

function __ZN2js13PropertyCacheC1Ev($this) {
  __ZN2js13PropertyCacheC2Ev($this);
  return;
}

function __ZN2js18GetNativeStackBaseEv() {
  var $1 = __ZN2js22GetNativeStackBaseImplEv();
  return $1;
}

function __ZN2js24ConservativeGCThreadDataC1Ev($this) {
  __ZN2js24ConservativeGCThreadDataC2Ev($this);
  return;
}

function __ZN2js10ThreadDataD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 65596 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _js_DestroyDtoaState($2);
    __label__ = 3;
    break;
   case 3:
    var $6 = $this + 28 | 0;
    __ZN2js8GSNCacheD1Ev($6);
    var $_idx_val = HEAP32[$this + 8 >> 2];
    __ZN2js10StackSpaceD2Ev($_idx_val);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8GSNCacheD1Ev($this) {
  __ZN2js8GSNCacheD2Ev($this);
  return;
}

function __ZN2js10ThreadData4initEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $this + 4 | 0;
    var $3 = __ZN2js10StackSpace4initEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $9 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = _js_NewDtoaState();
    HEAP32[$this + 65596 >> 2] = $5;
    var $9 = ($5 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z14js_InitThreadsP9JSRuntime($rt) {
  var $1 = $rt + 144280 | 0;
  var $2 = __ZN2js10ThreadData4initEv($1);
  return $2 & 1;
}

function __Z15js_PurgeThreadsP9JSContext($cx_0_11_val) {
  var $1 = $cx_0_11_val + 144280 | 0;
  __ZN2js10ThreadData5purgeEP9JSContext($1);
  return;
}

function __ZN2js10ThreadData5purgeEP9JSContext($this) {
  var $2 = $this + 28 | 0;
  __ZN2js8GSNCache5purgeEv($2);
  var $3 = $this + 56 | 0;
  __ZN2js13PropertyCache5purgeEP9JSContext($3);
  return;
}

function __Z13js_NewContextP9JSRuntimej($rt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lock = __stackBase__;
    var $1 = __ZN2js11OffTheBooks7calloc_Ej(312);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN9JSContextC2EP9JSRuntime($4, $rt);
    HEAP32[$1 + 200 >> 2] = $rt + 144148 | 0;
    HEAP32[$1 + 48 >> 2] = -1;
    var $11 = $1 + 224 | 0;
    __ZN2JS5Value8setMagicE10JSWhyMagic($11, 3);
    var $13 = $1 + 72 | 0;
    _JS_InitArenaPool($13, 4056, 8);
    var $15 = $1 + 104 | 0;
    _JS_InitArenaPool($15, 4056, 4);
    var $17 = $1 + 148 | 0;
    var $18 = __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE4initEj($17);
    if ($18) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $19 = $rt + 24 | 0;
    var $20 = HEAP32[$19 >> 2];
    __label__ = 5;
    break;
   case 4:
    __ZN2js10Foreground7delete_I9JSContextEEvPT_($4);
    var $_0 = 0;
    __label__ = 16;
    break;
   case 5:
    if (($20 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($20 | 0) == 2) {
      var $first_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 6:
    HEAP32[$19 >> 2] = 1;
    var $first_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $first_0;
    var $25 = $1;
    HEAP32[$1 >> 2] = $rt + 144140 | 0;
    var $27 = $rt + 144144 | 0;
    var $28 = HEAP32[$27 >> 2];
    HEAP32[$1 + 4 >> 2] = $28;
    var $32 = HEAP32[$27 >> 2] | 0;
    HEAP32[$32 >> 2] = $25;
    HEAP32[$27 >> 2] = $25;
    var $33 = $1;
    __Z13js_InitRandomP9JSContext($33);
    if ($first_0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $35 = $rt + 210584 | 0;
    var $36 = __ZN2js13StaticStrings4initEP9JSContext($35, $4);
    var $37 = $36 & 1;
    if ($36) {
      __label__ = 9;
      break;
    } else {
      var $ok_0 = $37;
      __label__ = 10;
      break;
    }
   case 9:
    var $39 = __Z18js_InitCommonAtomsP9JSContext($4);
    var $ok_0 = $39 & 1;
    __label__ = 10;
    break;
   case 10:
    var $ok_0;
    if ($ok_0 << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    __Z17js_DestroyContextP9JSContext20JSDestroyContextMode($4, 3);
    var $_0 = 0;
    __label__ = 16;
    break;
   case 12:
    __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $rt);
    HEAP32[$19 >> 2] = 2;
    __label__ = 13;
    break;
   case 13:
    var $47 = HEAP32[$rt + 28 >> 2];
    if (($47 | 0) == 0) {
      var $_0 = $4;
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $50 = FUNCTION_TABLE[$47]($4, 0);
    if (($50 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      var $_0 = $4;
      __label__ = 16;
      break;
    }
   case 15:
    __Z17js_DestroyContextP9JSContext20JSDestroyContextMode($4, 3);
    var $_0 = 0;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z13js_NewContextP9JSRuntimej["X"] = 1;

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj($1);
  return $2;
}

function __ZN2js10Foreground7delete_I9JSContextEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN9JSContextD2Ev($p);
    var $3 = $p;
    _js_free816($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext13fromLinkFieldEP10JSCListStr($link) {
  return $link;
}

function __ZNK2js13AutoResolving18alreadyStartedSlowEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 12 | 0;
    var $5 = HEAP32[$this + 4 >> 2];
    var $6 = $this + 8 | 0;
    var $cursor_0 = HEAP32[$this + 16 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $cursor_0;
    if (($5 | 0) == (HEAP32[$cursor_0 + 4 >> 2] | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    if ((HEAP32[$6 >> 2] | 0) == (HEAP32[$cursor_0 + 8 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    if ((HEAP32[$3 >> 2] | 0) == (HEAP32[$cursor_0 + 12 >> 2] | 0)) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = HEAP32[$cursor_0 + 16 >> 2];
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      var $cursor_0 = $23;
      __label__ = 2;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18js_GetErrorMessagePvPKcj($userRef, $locale, $errorNumber) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($errorNumber | 0) != 0 & $errorNumber >>> 0 < 287) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = _js_ErrorFormatString + ($errorNumber << 3) | 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_DestroyContextP9JSContext20JSDestroyContextMode($cx, $mode) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lock = __stackBase__;
    var $1 = $cx + 52 | 0;
    var $2 = HEAPU32[$1 >> 2];
    if (($mode | 0) == 3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$2 + 28 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = FUNCTION_TABLE[$6]($cx, 1);
    __label__ = 4;
    break;
   case 4:
    var $11 = $cx | 0;
    var $12 = HEAP32[$11 >> 2];
    var $13 = $cx + 4 | 0;
    var $15 = HEAP32[$13 >> 2] | 0;
    HEAP32[$15 >> 2] = $12;
    var $16 = HEAP32[$13 >> 2];
    var $18 = HEAP32[$11 >> 2] + 4 | 0;
    HEAP32[$18 >> 2] = $16;
    var $19 = $2 + 144140 | 0;
    if ((HEAP32[$19 >> 2] | 0) == ($19 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($mode - 1 | 0) >>> 0 < 2) {
      __label__ = 14;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 6:
    var $25 = $2 + 24 | 0;
    HEAP32[$25 >> 2] = 3;
    __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $2);
    var $_idx1 = $2 + 4 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $26 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($_idx1_val);
    var $_idx7 = $2 + 8 | 0;
    var $_idx7_val = HEAP32[$_idx7 >> 2];
    var $27 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx1_val, $_idx7_val);
    if ($26 >>> 0 < $27 >>> 0) {
      var $compartment_05 = $26;
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $compartment_05;
    var $30 = HEAP32[$compartment_05 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment5printEP9JSContextb($30, $cx, 0);
    var $31 = $compartment_05 + 4 | 0;
    if ($31 >>> 0 < $27 >>> 0) {
      var $compartment_05 = $31;
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $cx_idx_val = HEAP32[$1 >> 2];
    __Z20js_FinishCommonAtomsP9JSContext($cx_idx_val);
    var $_idx_val = HEAP32[$_idx1 >> 2];
    var $33 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($_idx_val);
    var $_idx5_val = HEAP32[$_idx7 >> 2];
    var $34 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx_val, $_idx5_val);
    if (($33 | 0) == ($34 | 0)) {
      __label__ = 10;
      break;
    } else {
      var $c_04 = $33;
      __label__ = 9;
      break;
    }
   case 9:
    var $c_04;
    var $36 = HEAP32[$c_04 >> 2];
    __ZN13JSCompartment10clearTrapsEP9JSContextP8JSScript($36, 0);
    var $37 = $c_04 + 4 | 0;
    var $_idx2_val = HEAP32[$_idx1 >> 2];
    var $_idx3_val = HEAP32[$_idx7 >> 2];
    var $38 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx2_val, $_idx3_val);
    if (($37 | 0) == ($38 | 0)) {
      __label__ = 10;
      break;
    } else {
      var $c_04 = $37;
      __label__ = 9;
      break;
    }
   case 10:
    var $_idx8_val = HEAP32[$cx + 56 >> 2];
    _JS_ClearAllWatchPoints($_idx8_val);
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[__ZN2js8gcReasonE >> 2] = 2;
    __label__ = 13;
    break;
   case 12:
    var $46 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $46;
    __label__ = 13;
    break;
   case 13:
    __Z5js_GCP9JSContextP13JSCompartment18JSGCInvocationKind($cx, 0, 1);
    HEAP32[$25 >> 2] = 0;
    __label__ = 23;
    break;
   case 14:
    if (($mode | 0) == 2) {
      __label__ = 15;
      break;
    } else if (($mode | 0) == 1) {
      __label__ = 19;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 15:
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    HEAP32[__ZN2js8gcReasonE >> 2] = 3;
    __label__ = 18;
    break;
   case 17:
    var $53 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $53;
    __label__ = 18;
    break;
   case 18:
    __Z5js_GCP9JSContextP13JSCompartment18JSGCInvocationKind($cx, 0, 0);
    __label__ = 23;
    break;
   case 19:
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[__ZN2js8gcReasonE >> 2] = 3;
    __label__ = 22;
    break;
   case 21:
    var $60 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $60;
    __label__ = 22;
    break;
   case 22:
    _JS_MaybeGC($cx);
    __label__ = 23;
    break;
   case 23:
    __ZN2js10Foreground7delete_I9JSContextEEvPT_($cx);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z17js_DestroyContextP9JSContext20JSDestroyContextMode["X"] = 1;

function __Z18js_ContextIteratorP9JSRuntimeiPP9JSContext($rt, $iterp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $lockIf = __stackBase__;
  var $1 = HEAP32[$iterp >> 2];
  __ZN7mozilla5MaybeIN2js10AutoLockGCEEC1Ev($lockIf);
  __ZN7mozilla5MaybeIN2js10AutoLockGCEE9constructIP9JSRuntimeEEvRKT_($lockIf, $rt);
  var $_in = ($1 | 0) == 0 ? $rt + 144140 | 0 : $1 | 0;
  var $5 = HEAP32[$_in >> 2];
  var $6 = __ZN9JSContext13fromLinkFieldEP10JSCListStr($5);
  var $cx_0 = ($6 | 0) == ($rt + 144140 | 0) ? 0 : $6;
  HEAP32[$iterp >> 2] = $cx_0;
  STACKTOP = __stackBase__;
  return $cx_0;
}

function __ZN7mozilla5MaybeIN2js10AutoLockGCEEC1Ev($this) {
  __ZN7mozilla5MaybeIN2js10AutoLockGCEEC2Ev($this);
  return;
}

function __ZN7mozilla5MaybeIN2js10AutoLockGCEE9constructIP9JSRuntimeEEvRKT_($this, $t1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZN7mozilla15AlignedStorage2IN2js10AutoLockGCEE4addrEv($1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js10AutoLockGCC1EP9JSRuntime($2, $t1_val);
    __label__ = 3;
    break;
   case 3:
    HEAP8[$this + 8 | 0] = 1;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z20js_ReportOutOfMemoryP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $report = __stackBase__;
    var $incr = __stackBase__ + 40;
    var $1 = $cx + 52 | 0;
    var $3 = HEAP32[$1 >> 2] + 144224 | 0;
    HEAP32[$3 >> 2] = 1;
    var $5 = HEAP32[$cx + 180 >> 2];
    var $_idx_val = HEAP32[$cx + 36 >> 2];
    var $7 = __Z27js_GetLocalizedErrorMessageP9JSContextPvPKcj($_idx_val, 137);
    if (($7 | 0) == 0) {
      var $13 = STRING_TABLE.__str2647 | 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = HEAP32[$7 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $13;
    __ZN2jsL7PodZeroI13JSErrorReportEEvPT_($report);
    HEAP32[$report + 24 >> 2] = 0;
    HEAP32[$report + 28 >> 2] = 137;
    __ZL19PopulateReportBlameP9JSContextP13JSErrorReport($cx, $report);
    __ZN9JSContext21clearPendingExceptionEv($cx);
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = HEAP32[$cx + 200 >> 2];
    var $21 = HEAP32[$19 + 64 >> 2];
    if (($21 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $25 = HEAP32[$19 + 68 >> 2];
    var $26 = FUNCTION_TABLE[$21]($cx, $13, $report, $25);
    if (($26 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $29 = HEAP32[$1 >> 2] + 229028 | 0;
    __ZN2js19AutoAtomicIncrementC1EPi($incr, $29);
    FUNCTION_TABLE[$5]($cx, $13, $report);
    var $incr_idx_val = HEAP32[$incr >> 2];
    __ZN2js19AutoAtomicIncrementD1Ev($incr_idx_val);
    __label__ = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodZeroI13JSErrorReportEEvPT_($t) {
  var $1 = $t;
  _memset($1, 0, 40, 1);
  return;
}

function __ZL19PopulateReportBlameP9JSContextP13JSErrorReport($cx, $report) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $iter = __stackBase__;
    __ZN2js13FrameRegsIterC1EP9JSContextNS_9StackIter11SavedOptionE($iter, $cx);
    __label__ = 2;
    break;
   case 2:
    var $2 = __ZNK2js13FrameRegsIter4doneEv($iter);
    if ($2) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $4 = __ZNK2js13FrameRegsIter2fpEv($iter);
    var $_idx_val = HEAP32[$4 >> 2];
    var $5 = __ZNK2js10StackFrame13isScriptFrameEv($_idx_val);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZNK2js10StackFrame6scriptEv($4);
    var $9 = HEAP32[$7 + 52 >> 2];
    HEAP32[$report >> 2] = $9;
    var $11 = __ZNK2js13FrameRegsIter2fpEv($iter);
    var $12 = __ZNK2js13FrameRegsIter2pcEv($iter);
    var $13 = $cx;
    var $14 = $11;
    var $15 = __Z22js_FramePCToLineNumberP9JSContextPN2js10StackFrameEPh($13, $14, $12);
    HEAP32[$report + 4 >> 2] = $15;
    __label__ = 6;
    break;
   case 5:
    __ZN2js13FrameRegsIterppEv($iter);
    __label__ = 2;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js19AutoAtomicIncrementC1EPi($this, $p) {
  __ZN2js19AutoAtomicIncrementC2EPi($this, $p);
  return;
}

function __ZN2js19AutoAtomicIncrementD1Ev($this_0_0_val) {
  __ZN2js19AutoAtomicIncrementD2Ev($this_0_0_val);
  return;
}

function __Z21js_ReportOverRecursedP9JSContext($maybecx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($maybecx | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($maybecx, 4, 26, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z27js_ReportAllocationOverflowP9JSContext($maybecx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($maybecx | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($maybecx, 4, 6, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_ReportErrorVAP9JSContextjPKcPc($cx, $flags, $format, $ap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $messagelen = __stackBase__ + 4;
    var $report = __stackBase__ + 8;
    HEAP32[$1 >> 2] = $flags;
    var $2 = __ZL16checkReportFlagsP9JSContextPj($cx, $1);
    if ($2) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JS_vsmprintf($format, $ap);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = _strlen($4);
    HEAP32[$messagelen >> 2] = $7;
    __ZN2jsL7PodZeroI13JSErrorReportEEvPT_($report);
    var $8 = HEAP32[$1 >> 2];
    var $9 = $report + 24 | 0;
    HEAP32[$9 >> 2] = $8;
    HEAP32[$report + 28 >> 2] = 206;
    var $11 = $cx;
    var $12 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($11, $4, $messagelen, 0);
    HEAP32[$report + 32 >> 2] = $12;
    __ZL19PopulateReportBlameP9JSContextP13JSErrorReport($cx, $report);
    var $15 = HEAP32[$9 >> 2] & 1;
    __ZL11ReportErrorP9JSContextPKcP13JSErrorReportPFPK19JSErrorFormatStringPvS2_jES8_($cx, $4, $report, 0);
    __ZN2js10Foreground5free_EPv($4);
    var $16 = $12;
    __ZN2js10Foreground5free_EPv($16);
    var $_0 = $15;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16checkReportFlagsP9JSContextPj($cx, $flags) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$flags >> 2];
    if (($1 & 8 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $cx + 60 | 0;
    var $6 = __ZNK2js12ContextStack13currentScriptEPPh($5, 0);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP8[$6 + 36 | 0] & 8) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = HEAP32[$flags >> 2] & -2;
    HEAP32[$flags >> 2] = $15;
    var $27 = $15;
    __label__ = 9;
    break;
   case 5:
    var $cx_idx1_val = HEAP32[$cx + 32 >> 2];
    var $17 = __ZNK9JSContext15hasStrictOptionEv($cx_idx1_val);
    if ($17) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 6:
    var $20 = HEAP32[$flags >> 2] | 1;
    HEAP32[$flags >> 2] = $20;
    var $27 = $20;
    __label__ = 9;
    break;
   case 7:
    if (($1 & 4 | 0) == 0) {
      var $27 = $1;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $cx_idx_val = HEAP32[$cx + 32 >> 2];
    var $25 = __ZNK9JSContext15hasStrictOptionEv($cx_idx_val);
    if ($25) {
      var $27 = $1;
      __label__ = 9;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 9:
    var $27;
    if (($27 & 1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $cx_idx2_val = HEAP32[$cx + 32 >> 2];
    var $31 = __ZNK9JSContext15hasWErrorOptionEv($cx_idx2_val);
    if ($31) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$flags >> 2] = $27 & -2;
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11ReportErrorP9JSContextPKcP13JSErrorReportPFPK19JSErrorFormatStringPvS2_jES8_($cx, $message, $reportp, $callback) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($callback | 0) == 0 | ($callback | 0) == 4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    if ((HEAP32[$reportp + 28 >> 2] | 0) == 147) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = $reportp + 24 | 0;
    var $10 = HEAP32[$8 >> 2] | 2;
    HEAP32[$8 >> 2] = $10;
    __label__ = 4;
    break;
   case 4:
    var $12 = _JS_IsRunning($cx);
    if (($12 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = $cx;
    var $16 = $reportp;
    var $17 = __Z19js_ErrorToExceptionP9JSContextPKcP13JSErrorReportPFPK19JSErrorFormatStringPvS2_jES8_($15, $message, $16, $callback);
    if (($17 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __Z19js_ReportErrorAgainP9JSContextPKcP13JSErrorReport($cx, $message, $reportp);
    __label__ = 10;
    break;
   case 7:
    var $22 = HEAP32[$cx + 200 >> 2];
    var $24 = HEAP32[$22 + 64 >> 2];
    if (($24 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((HEAP32[$cx + 180 >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = HEAP32[$22 + 68 >> 2];
    var $33 = FUNCTION_TABLE[$24]($cx, $message, $reportp, $32);
    __label__ = 10;
    break;
   case 10:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z23js_ExpandErrorArgumentsP9JSContextPFPK19JSErrorFormatStringPvPKcjES4_jPPcP13JSErrorReportbS9_($cx, $callback, $errorNumber, $messagep, $reportp, $charArgs, $ap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $argLengths = __stackBase__;
    var $charArgLength = __stackBase__ + 40;
    var $len = __stackBase__ + 44;
    var $len1 = __stackBase__ + 48;
    HEAP32[$messagep >> 2] = 0;
    if (($callback | 0) == 0 | ($callback | 0) == 4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$cx + 36 >> 2];
    var $5 = __Z27js_GetLocalizedErrorMessageP9JSContextPvPKcj($_idx_val, $errorNumber);
    var $efs_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $7 = FUNCTION_TABLE[$callback](0, 0, $errorNumber);
    var $efs_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $efs_0;
    if (($efs_0 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = HEAPU16[$efs_0 + 4 >> 1];
    var $13 = $12 & 65535;
    if ($12 << 16 >> 16 == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $16 = HEAPU32[$efs_0 >> 2];
    if (($16 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 7:
    var $20 = ($13 << 2) + 4 | 0;
    var $21 = __ZN9JSContext7malloc_Ej($cx, $20);
    var $22 = $21;
    var $23 = $reportp + 36 | 0;
    HEAP32[$23 >> 2] = $22;
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP32[$22 + ($13 << 2) >> 2] = 0;
    var $27 = $cx;
    var $totalArgsLength_0 = 0;
    var $i_0 = 0;
    var $_02 = $ap;
    __label__ = 9;
    break;
   case 9:
    var $_02;
    var $i_0;
    var $totalArgsLength_0;
    if (($i_0 | 0) < ($13 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 10:
    if ($charArgs) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $33 = HEAP32[$_02 >> 2];
    var $34 = _strlen($33);
    HEAP32[$charArgLength >> 2] = $34;
    var $35 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($27, $33, $charArgLength, 0);
    var $37 = HEAP32[$23 >> 2] + ($i_0 << 2) | 0;
    HEAP32[$37 >> 2] = $35;
    var $40 = HEAP32[HEAP32[$23 >> 2] + ($i_0 << 2) >> 2];
    if (($40 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      var $48 = $40;
      __label__ = 13;
      break;
    }
   case 12:
    var $44 = HEAP32[$_02 >> 2];
    var $46 = HEAP32[$23 >> 2] + ($i_0 << 2) | 0;
    HEAP32[$46 >> 2] = $44;
    var $48 = HEAP32[HEAP32[$23 >> 2] + ($i_0 << 2) >> 2];
    __label__ = 13;
    break;
   case 13:
    var $48;
    var $_1 = $_02 + 4 | 0;
    var $49 = __Z9js_strlenPKt($48);
    HEAP32[$argLengths + ($i_0 << 2) >> 2] = $49;
    var $totalArgsLength_0 = $49 + $totalArgsLength_0 | 0;
    var $i_0 = $i_0 + 1 | 0;
    var $_02 = $_1;
    __label__ = 9;
    break;
   case 14:
    var $55 = HEAP32[$23 >> 2] + ($i_0 << 2) | 0;
    HEAP32[$55 >> 2] = 0;
    var $57 = HEAP32[$efs_0 >> 2];
    if (($57 | 0) != 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 15:
    var $60 = _strlen($57);
    HEAP32[$len >> 2] = $60;
    var $61 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($27, $57, $len, 0);
    if (($61 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $69 = ($totalArgsLength_0 + $13 * -3 + HEAP32[$len >> 2] << 1) + 2 | 0;
    var $70 = __ZN9JSContext7malloc_Ej($cx, $69);
    var $71 = $70;
    var $72 = $reportp + 32 | 0;
    HEAP32[$72 >> 2] = $71;
    if (($70 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $out_0 = $71;
      var $fmt_0 = $61;
      __label__ = 18;
      break;
    }
   case 17:
    var $75 = $61;
    __ZN9JSContext5free_EPv($75);
    __label__ = 29;
    break;
   case 18:
    var $fmt_0;
    var $out_0;
    var $76 = HEAPU16[$fmt_0 >> 1];
    if ($76 << 16 >> 16 == 123) {
      __label__ = 20;
      break;
    } else if ($76 << 16 >> 16 == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $_pre_phi = $fmt_0 + 2 | 0;
    __label__ = 22;
    break;
   case 20:
    var $78 = $fmt_0 + 2 | 0;
    var $isdigittmp = (HEAPU16[$78 >> 1] & 65535) - 48 | 0;
    if ($isdigittmp >>> 0 < 10) {
      __label__ = 21;
      break;
    } else {
      var $_pre_phi = $78;
      __label__ = 22;
      break;
    }
   case 21:
    var $86 = HEAP32[HEAP32[$23 >> 2] + ($isdigittmp << 2) >> 2];
    var $87 = $argLengths + ($isdigittmp << 2) | 0;
    var $89 = HEAP32[$87 >> 2] << 1;
    _memcpy($out_0, $86, $89, 1);
    var $out_0 = $out_0 + (HEAP32[$87 >> 2] << 1) | 0;
    var $fmt_0 = $fmt_0 + 6 | 0;
    __label__ = 18;
    break;
   case 22:
    var $_pre_phi;
    HEAP16[$out_0 >> 1] = $76;
    var $out_0 = $out_0 + 2 | 0;
    var $fmt_0 = $_pre_phi;
    __label__ = 18;
    break;
   case 23:
    HEAP16[$out_0 >> 1] = 0;
    var $96 = $61;
    __ZN9JSContext5free_EPv($96);
    var $97 = HEAP32[$72 >> 2];
    var $101 = $out_0 - $97 >> 1;
    var $102 = __ZN2js13DeflateStringEP9JSContextPKtj($27, $97, $101);
    HEAP32[$messagep >> 2] = $102;
    if (($102 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      var $_0 = 1;
      __label__ = 38;
      break;
    }
   case 24:
    var $105 = _JS_strdup($cx, $16);
    HEAP32[$messagep >> 2] = $105;
    if (($105 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $108 = _strlen($105);
    HEAP32[$len1 >> 2] = $108;
    var $109 = $cx;
    var $110 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($109, $105, $len1, 0);
    HEAP32[$reportp + 32 >> 2] = $110;
    if (($110 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    if ((HEAP32[$messagep >> 2] | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 1;
      __label__ = 38;
      break;
    }
   case 27:
    var $116 = __ZN9JSContext7malloc_Ej($cx, 62);
    HEAP32[$messagep >> 2] = $116;
    if (($116 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $119 = _JS_snprintf($116, 62, STRING_TABLE.__str3648 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $errorNumber, tempInt));
    var $_0 = 1;
    __label__ = 38;
    break;
   case 29:
    var $120 = $reportp + 36 | 0;
    var $121 = HEAP32[$120 >> 2];
    if (($121 | 0) == 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    if ($charArgs) {
      __label__ = 31;
      break;
    } else {
      var $133 = $121;
      __label__ = 33;
      break;
    }
   case 31:
    var $124 = HEAP32[$121 >> 2];
    if (($124 | 0) == 0) {
      var $133 = $121;
      __label__ = 33;
      break;
    } else {
      var $i_110 = 0;
      var $126 = $124;
      __label__ = 32;
      break;
    }
   case 32:
    var $126;
    var $i_110;
    var $127 = $i_110 + 1 | 0;
    __ZN9JSContext5free_EPv($126);
    var $129 = HEAP32[$120 >> 2];
    var $131 = HEAP32[$129 + ($127 << 2) >> 2];
    if (($131 | 0) == 0) {
      var $133 = $129;
      __label__ = 33;
      break;
    } else {
      var $i_110 = $127;
      var $126 = $131;
      __label__ = 32;
      break;
    }
   case 33:
    var $133;
    __ZN9JSContext5free_EPv($133);
    HEAP32[$120 >> 2] = 0;
    __label__ = 34;
    break;
   case 34:
    var $135 = $reportp + 32 | 0;
    var $136 = HEAP32[$135 >> 2];
    if (($136 | 0) == 0) {
      __label__ = 36;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $139 = $136;
    __ZN9JSContext5free_EPv($139);
    HEAP32[$135 >> 2] = 0;
    __label__ = 36;
    break;
   case 36:
    var $140 = HEAP32[$messagep >> 2];
    if (($140 | 0) == 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    __ZN9JSContext5free_EPv($140);
    HEAP32[$messagep >> 2] = 0;
    var $_0 = 0;
    __label__ = 38;
    break;
   case 38:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z23js_ExpandErrorArgumentsP9JSContextPFPK19JSErrorFormatStringPvPKcjES4_jPPcP13JSErrorReportbS9_["X"] = 1;

function __Z22js_ReportErrorNumberVAP9JSContextjPFPK19JSErrorFormatStringPvPKcjES4_jiPc($cx, $flags, $callback, $errorNumber, $charArgs, $ap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $report = __stackBase__ + 4;
    var $message = __stackBase__ + 44;
    HEAP32[$1 >> 2] = $flags;
    var $2 = __ZL16checkReportFlagsP9JSContextPj($cx, $1);
    if ($2) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$1 >> 2];
    var $5 = $4 & 1;
    __ZN2jsL7PodZeroI13JSErrorReportEEvPT_($report);
    HEAP32[$report + 24 >> 2] = $4;
    HEAP32[$report + 28 >> 2] = $errorNumber;
    __ZL19PopulateReportBlameP9JSContextP13JSErrorReport($cx, $report);
    var $8 = ($charArgs | 0) != 0;
    var $9 = __Z23js_ExpandErrorArgumentsP9JSContextPFPK19JSErrorFormatStringPvPKcjES4_jPPcP13JSErrorReportbS9_($cx, $callback, $errorNumber, $message, $report, $8, $ap);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAP32[$message >> 2];
    __ZL11ReportErrorP9JSContextPKcP13JSErrorReportPFPK19JSErrorFormatStringPvS2_jES8_($cx, $12, $report, $callback);
    if (($12 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN9JSContext5free_EPv($12);
    __label__ = 5;
    break;
   case 5:
    var $16 = $report + 36 | 0;
    var $17 = HEAP32[$16 >> 2];
    if (($17 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ($8) {
      __label__ = 7;
      break;
    } else {
      var $29 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $20 = HEAP32[$17 >> 2];
    if (($20 | 0) == 0) {
      var $29 = $17;
      __label__ = 9;
      break;
    } else {
      var $i_01 = 0;
      var $22 = $20;
      __label__ = 8;
      break;
    }
   case 8:
    var $22;
    var $i_01;
    var $23 = $i_01 + 1 | 0;
    __ZN9JSContext5free_EPv($22);
    var $25 = HEAP32[$16 >> 2];
    var $27 = HEAP32[$25 + ($23 << 2) >> 2];
    if (($27 | 0) == 0) {
      var $29 = $25;
      __label__ = 9;
      break;
    } else {
      var $i_01 = $23;
      var $22 = $27;
      __label__ = 8;
      break;
    }
   case 9:
    var $29;
    __ZN9JSContext5free_EPv($29);
    __label__ = 10;
    break;
   case 10:
    var $33 = HEAP32[$report + 32 >> 2];
    if (($33 | 0) == 0) {
      var $_0 = $5;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $36 = $33;
    __ZN9JSContext5free_EPv($36);
    var $_0 = $5;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z22js_ReportErrorNumberVAP9JSContextjPFPK19JSErrorFormatStringPvPKcjES4_jiPc["X"] = 1;

function __Z19js_ReportErrorAgainP9JSContextPKcP13JSErrorReport($cx, $message, $reportp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($message | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $cx + 176 | 0;
    var $4 = HEAP32[$3 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js10Foreground5free_EPv($4);
    __label__ = 4;
    break;
   case 4:
    var $8 = _JS_strdup($cx, $message);
    HEAP32[$3 >> 2] = $8;
    if (($8 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = HEAP32[$cx + 180 >> 2];
    if (($12 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = HEAP32[$cx + 200 >> 2];
    var $18 = HEAP32[$16 + 64 >> 2];
    if (($18 | 0) == 0) {
      var $25 = $8;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = HEAP32[$16 + 68 >> 2];
    var $23 = FUNCTION_TABLE[$18]($cx, $8, $reportp, $22);
    if (($23 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $25 = HEAP32[$3 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $25;
    FUNCTION_TABLE[$12]($cx, $25, $reportp);
    __label__ = 10;
    break;
   case 10:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z21js_ReportIsNotDefinedP9JSContextPKc($cx, $name) {
  var __stackBase__ = STACKTOP;
  _JS_ReportErrorNumber($cx, 4, 1, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $name, tempInt));
  STACKTOP = __stackBase__;
  return;
}

function __ZN9JSContext22thisDuringConstructionEv($this) {
  return $this;
}

function __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE6lengthEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE5beginEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js10StackFrame8imacropcEv($this_0_9_val) {
  return $this_0_9_val;
}

function __ZNK2js9StackIter2pcEv($this_0_7_val) {
  return $this_0_7_val;
}

function __ZNK2js14ThreadDataIter5emptyEv($this_0_1_val) {
  return ($this_0_1_val & 1) << 24 >> 24 != 0;
}

function __ZNK2js10StackFrame11hasImacropcEv($this_0_0_val) {
  return ($this_0_0_val & 8192 | 0) != 0;
}

function __ZN2js19AutoAtomicIncrementD2Ev($this_0_0_val) {
  var $2 = HEAP32[$this_0_0_val >> 2] - 1 | 0;
  HEAP32[$this_0_0_val >> 2] = $2;
  return;
}

function __ZNK7mozilla14AlignedStorageILj8EE4addrEv($this) {
  return $this;
}

function __ZN7mozilla14AlignedStorageILj8EE4addrEv($this) {
  return $this;
}

function __ZN7mozilla15AlignedStorage2IN2js10AutoLockGCEE4addrEv($this) {
  return $this;
}

function __ZNK2js14ThreadDataIter10threadDataEv($this_0_0_val) {
  return $this_0_0_val + 144280 | 0;
}

function __ZN2js14ThreadDataIter8popFrontEv($this) {
  HEAP8[$this + 4 | 0] = 1;
  return;
}

function __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE3endEv($this_0_0_val, $this_0_1_val) {
  return $this_0_0_val + ($this_0_1_val << 2) | 0;
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE10endNoCheckEv($this_0_0_val, $this_0_1_val) {
  return $this_0_0_val + ($this_0_1_val << 2) | 0;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_($this) {
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  return;
}

function __ZN7mozilla5MaybeIN2js10AutoLockGCEEC2Ev($this) {
  HEAP8[$this + 8 | 0] = 0;
  return;
}

function __ZN14DSTOffsetCache5purgeEv($this) {
  var $1 = $this | 0;
  HEAP32[$1 >> 2] = 0;
  HEAP32[$1 + 4 >> 2] = 0;
  var $2 = $this + 16 | 0;
  HEAP32[$2 >> 2] = 0;
  HEAP32[$2 + 4 >> 2] = -2147483648;
  var $3 = $this + 8 | 0;
  HEAP32[$3 >> 2] = 0;
  HEAP32[$3 + 4 >> 2] = -2147483648;
  var $4 = $this + 24 | 0;
  HEAP32[$4 >> 2] = 0;
  HEAP32[$4 + 4 >> 2] = 0;
  var $5 = $this + 40 | 0;
  HEAP32[$5 >> 2] = 0;
  HEAP32[$5 + 4 >> 2] = -2147483648;
  var $6 = $this + 32 | 0;
  HEAP32[$6 >> 2] = 0;
  HEAP32[$6 + 4 >> 2] = -2147483648;
  return;
}

function __ZN2js14ThreadDataIterC2EP9JSRuntime($this, $rt) {
  HEAP32[$this >> 2] = $rt;
  HEAP8[$this + 4 | 0] = 0;
  return;
}

function __ZN2js19AutoAtomicIncrementC2EPi($this, $p) {
  HEAP32[$this >> 2] = $p;
  var $3 = HEAP32[$p >> 2] + 1 | 0;
  HEAP32[$p >> 2] = $3;
  return;
}

function __ZN2js24ConservativeGCThreadDataC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 44 >> 2] = 0;
  return;
}

function __Z26js_ReportIsNullOrUndefinedP9JSContextiRKN2JS5ValueEP8JSString($cx, $spindex, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx1 = $v | 0;
    var $v_idx1_val$0 = HEAP32[$v_idx1 >> 2];
    var $v_idx1_val$1 = HEAP32[$v_idx1 + 4 >> 2];
    var $1 = __ZN2jsL23DecompileValueGeneratorEP9JSContextiRKN2JS5ValueEP8JSString($cx, $spindex, $v_idx1_val$0, $v_idx1_val$1, 0);
    if (($1 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _strcmp($1, STRING_TABLE.__str493818 | 0);
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = _strcmp($1, STRING_TABLE.__str483817 | 0);
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = _JS_ReportErrorFlagsAndNumber($cx, 0, 39, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1, HEAP32[tempInt + 4 >> 2] = 0, HEAP32[tempInt + 8 >> 2] = 0, tempInt));
    __label__ = 8;
    break;
   case 5:
    var $v_idx_val$0 = HEAP32[$v_idx1 >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx1 + 4 >> 2];
    var $12 = __ZNK2JS5Value11isUndefinedEv($v_idx_val$0, $v_idx_val$1);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $14 = _JS_ReportErrorFlagsAndNumber($cx, 0, 222, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str493818 | 0, HEAP32[tempInt + 8 >> 2] = 0, tempInt));
    __label__ = 8;
    break;
   case 7:
    var $16 = _JS_ReportErrorFlagsAndNumber($cx, 0, 222, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str483817 | 0, HEAP32[tempInt + 8 >> 2] = 0, tempInt));
    __label__ = 8;
    break;
   case 8:
    __ZN9JSContext5free_EPv($1);
    __label__ = 9;
    break;
   case 9:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23DecompileValueGeneratorEP9JSContextiRKN2JS5ValueEP8JSString($cx, $spindex, $v_0_0_0_val$0, $v_0_0_0_val$1, $fallback) {
  var $1 = _js_DecompileValueGenerator($cx, $spindex, $v_0_0_0_val$0, $v_0_0_0_val$1, $fallback);
  return $1;
}

function __Z19js_ReportMissingArgP9JSContextRKN2JS5ValueEj($cx, $v, $arg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__ | 0;
    var $2 = _JS_snprintf($1, 11, STRING_TABLE.__str544300 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $arg, tempInt));
    var $v_idx2 = $v | 0;
    var $v_idx2_val$0 = HEAP32[$v_idx2 >> 2];
    var $v_idx2_val$1 = HEAP32[$v_idx2 + 4 >> 2];
    var $3 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueE($v_idx2_val$0, $v_idx2_val$1);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $bytes_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZNK2JS5Value8toObjectEv($v_idx2_val$0, $v_idx2_val$1);
    var $_idx_val = HEAP32[$5 + 24 >> 2];
    var $6 = __ZNK8JSObject18getFunctionPrivateEv($_idx_val);
    var $9 = HEAP32[$6 + 72 >> 2] | 0;
    var $10 = __ZN2jsL23DecompileValueGeneratorEP9JSContextiRKN2JS5ValueEP8JSString($cx, 1, $v_idx2_val$0, $v_idx2_val$1, $9);
    if (($10 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $bytes_0 = $10;
      __label__ = 3;
      break;
    }
   case 3:
    var $bytes_0;
    var $14 = ($bytes_0 | 0) != 0 ? $bytes_0 : __str17668 | 0;
    _JS_ReportErrorNumber($cx, 4, 227, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $1, HEAP32[tempInt + 4 >> 2] = $14, tempInt));
    __ZN9JSContext5free_EPv($bytes_0);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueE($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZNK8JSObject10isFunctionEv($_idx_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, $flags, $errorNumber, $spindex, $v_0_0_0_val$0, $v_0_0_0_val$1, $fallback, $arg1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL23DecompileValueGeneratorEP9JSContextiRKN2JS5ValueEP8JSString($cx, $spindex, $v_0_0_0_val$0, $v_0_0_0_val$1, $fallback);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JS_ReportErrorFlagsAndNumber($cx, $flags, $errorNumber, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1, HEAP32[tempInt + 4 >> 2] = $arg1, HEAP32[tempInt + 8 >> 2] = 0, tempInt));
    __ZN9JSContext5free_EPv($1);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16checkOutOfMemoryP9JSRuntime($rt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $lock = __stackBase__;
  __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $rt);
  var $5 = HEAPU32[$rt + 140 >> 2] >>> 0 > HEAPU32[$rt + 152 >> 2] >>> 0;
  STACKTOP = __stackBase__;
  return $5;
}

function __Z26js_InvokeOperationCallbackP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 52 >> 2];
    var $3 = $2 + 144280 | 0;
    HEAP32[$3 >> 2] = 0;
    if ((HEAP32[$2 + 196 >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$2 + 144076 >> 2];
    __Z5js_GCP9JSContextP13JSCompartment18JSGCInvocationKind($cx, $9, 0);
    var $10 = __Z16checkOutOfMemoryP9JSRuntime($2);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 4:
    var $14 = HEAP32[$cx + 184 >> 2];
    if (($14 | 0) == 0) {
      var $20 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = FUNCTION_TABLE[$14]($cx);
    var $20 = ($17 | 0) != 0;
    __label__ = 6;
    break;
   case 6:
    var $20;
    var $_0 = $20 & 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z27js_HandleExecutionInterruptP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[HEAP32[$cx + 52 >> 2] + 144280 >> 2] | 0) == 0) {
      var $result_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    var $result_0 = ($7 | 0) != 0 & 1;
    __label__ = 3;
    break;
   case 3:
    var $result_0;
    return $result_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js28TriggerAllOperationCallbacksEP9JSRuntime($rt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    __ZN2js14ThreadDataIterC1EP9JSRuntime($i, $rt);
    var $i_idx1 = $i + 4 | 0;
    var $i_idx1_val = HEAP8[$i_idx1];
    var $1 = __ZNK2js14ThreadDataIter5emptyEv($i_idx1_val);
    if ($1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $i_idx2 = $i | 0;
    __label__ = 3;
    break;
   case 3:
    var $i_idx2_val = HEAP32[$i_idx2 >> 2];
    var $2 = __ZNK2js14ThreadDataIter10threadDataEv($i_idx2_val);
    __ZN2js10ThreadData24triggerOperationCallbackEP9JSRuntime($2);
    __ZN2js14ThreadDataIter8popFrontEv($i);
    var $i_idx_val = HEAP8[$i_idx1];
    var $3 = __ZNK2js14ThreadDataIter5emptyEv($i_idx_val);
    if ($3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14ThreadDataIterC1EP9JSRuntime($this, $rt) {
  __ZN2js14ThreadDataIterC2EP9JSRuntime($this, $rt);
  return;
}

function __Z20js_GetScriptedCallerP9JSContextPN2js10StackFrameE($cx, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($fp | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $fp;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind($cx);
    var $_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    if (($_0 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0_idx1_val = HEAP32[$_0 >> 2];
    var $6 = __ZNK2js10StackFrame12isDummyFrameEv($_0_idx1_val);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $_0_idx_val = HEAP32[$_0 + 16 >> 2];
    var $8 = __ZNK2js10StackFrame4prevEv($_0_idx_val);
    var $_0 = $8;
    __label__ = 3;
    break;
   case 6:
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind($cx) {
  var $1 = __ZNK9JSContext7maybefpEv($cx);
  return $1;
}

function __Z23js_GetCurrentBytecodePCP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK9JSContext5hasfpEv($cx);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = __ZNK9JSContext4regsEv($cx);
    var $5 = HEAP32[$3 + 4 >> 2];
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK9JSContext2fpEv($cx);
    var $9 = __ZNK2js10StackFrame13maybeImacropcEv($8);
    if (HEAP8[$5] << 24 >> 24 == 58) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $5;
      __label__ = 5;
      break;
    }
   case 4:
    var $phitmp = ($9 | 0) != 0 ? $9 : $5;
    var $_0 = $phitmp;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame13maybeImacropcEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK2js10StackFrame11hasImacropcEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $5 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $this_idx1_val = HEAP32[$this + 40 >> 2];
    var $3 = __ZNK2js10StackFrame8imacropcEv($this_idx1_val);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContextC2EP9JSRuntime($this, $rt) {
  HEAP8[$this + 16 | 0] = 0;
  HEAP32[$this + 52 >> 2] = $rt;
  HEAP32[$this + 56 >> 2] = 0;
  var $4 = $this + 60 | 0;
  var $5 = __ZN9JSContext22thisDuringConstructionEv($this);
  var $6 = $4;
  var $7 = $5;
  __ZN2js12ContextStackC2EP9JSContext($6, $7);
  var $8 = $this + 148 | 0;
  __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES5_($8);
  var $9 = $this + 236 | 0;
  __ZN14DSTOffsetCacheC1Ev($9);
  var $10 = $this + 288 | 0;
  __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEEC1ES3_($10);
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES5_($this) {
  __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES5_($this);
  return;
}

function __ZN14DSTOffsetCacheC1Ev($this) {
  __ZN14DSTOffsetCacheC2Ev($this);
  return;
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEEC1ES3_($this) {
  __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEEC2ES3_($this);
  return;
}

function __ZN9JSContextD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 100 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js10Foreground7delete_INS_12ParseMapPoolEEEvPT_($2);
    __label__ = 3;
    break;
   case 3:
    var $6 = $this + 104 | 0;
    _JS_FinishArenaPool($6);
    var $7 = $this + 72 | 0;
    _JS_FinishArenaPool($7);
    var $9 = HEAP32[$this + 176 >> 2];
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js10Foreground5free_EPv($9);
    __label__ = 5;
    break;
   case 5:
    var $14 = HEAP32[$this + 172 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $map_01 = $14;
      __label__ = 6;
      break;
    }
   case 6:
    var $map_01;
    var $17 = HEAP32[$map_01 + 12 >> 2];
    __ZN2js10Foreground5free_EPv($map_01);
    if (($17 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $map_01 = $17;
      __label__ = 6;
      break;
    }
   case 7:
    var $20 = $this + 288 | 0;
    __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEED1Ev($20);
    var $21 = $this + 148 | 0;
    __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev($21);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Foreground7delete_INS_12ParseMapPoolEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js12ParseMapPoolD1Ev($p);
    var $3 = $p;
    _js_free816($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN9JSContext16resetCompartmentEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $scopeobj = __stackBase__;
    var $_idx_val = HEAP32[$this + 60 >> 2];
    var $1 = __ZNK2js12ContextStack5hasfpEv($_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK9JSContext2fpEv($this);
    var $4 = __ZNK2js10StackFrame10scopeChainEv($3);
    HEAP32[$scopeobj >> 2] = $4;
    var $13 = $4;
    __label__ = 5;
    break;
   case 3:
    var $7 = HEAP32[$this + 132 >> 2];
    HEAP32[$scopeobj >> 2] = $7;
    if (($7 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __Z19OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($this, $scopeobj);
    var $10 = HEAP32[$scopeobj >> 2];
    if (($10 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $13 = $10;
      __label__ = 5;
      break;
    }
   case 5:
    var $13;
    var $15 = __ZNK2js2gc4Cell11compartmentEv($13);
    HEAP32[$this + 56 >> 2] = $15;
    var $19 = HEAP8[$15 + 376 | 0] & 1;
    HEAP8[$this + 232 | 0] = $19;
    var $this_idx_val = HEAP32[$this + 20 >> 2];
    var $21 = __ZN9JSContext18isExceptionPendingEv($this_idx_val);
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    __ZN9JSContext20wrapPendingExceptionEv($this);
    __label__ = 8;
    break;
   case 7:
    HEAP32[$this + 56 >> 2] = 0;
    __label__ = 8;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$obj >> 2];
    var $_idx_val = HEAP32[$1 + 4 >> 2];
    var $2 = __ZNK8JSObject8getClassEv($_idx_val);
    var $4 = HEAP32[$2 + 76 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = FUNCTION_TABLE[$4]($cx, $1);
    HEAP32[$obj >> 2] = $7;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext20wrapPendingExceptionEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $this_idx = $this + 24 | 0;
    var $this_idx_val$0 = HEAP32[$this_idx >> 2];
    var $this_idx_val$1 = HEAP32[$this_idx + 4 >> 2];
    __ZN9JSContext19getPendingExceptionEv($v, $this_idx_val$0, $this_idx_val$1);
    __ZN9JSContext21clearPendingExceptionEv($this);
    var $2 = HEAP32[$this + 56 >> 2];
    var $3 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($2, $this, $v);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $v | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($this, $6$0, $6$1);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK9JSContext12generatorForEPN2js10StackFrameE($this, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAPU32[$this + 288 >> 2];
    var $_idx1_val = HEAP32[$this + 292 >> 2];
    var $1 = __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE4backEv($_idx_val, $_idx1_val);
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZN11JSGenerator9liveFrameEv($2);
    if (($3 | 0) == ($fp | 0)) {
      var $_0 = $2;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE6lengthEv($_idx1_val);
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    if ($i_0 >>> 0 < $5 >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEEixEj($_idx_val, $i_0);
    var $10 = HEAPU32[$9 >> 2];
    var $11 = __ZN11JSGenerator9liveFrameEv($10);
    if (($11 | 0) == ($fp | 0)) {
      var $_0 = $10;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 3;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE4backEv($this_0_0_val, $this_0_1_val) {
  var $1 = __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE3endEv($this_0_0_val, $this_0_1_val);
  return $1 - 4 | 0;
}

function __ZN11JSGenerator9liveFrameEv($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  var $1 = __ZNK2js9FrameRegs2fpEv($_idx_val);
  return $1;
}

function __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEEixEj($this_0_0_val, $i) {
  var $1 = __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE5beginEv($this_0_0_val);
  return $1 + ($i << 2) | 0;
}

function __ZNK9JSContext28runningWithTrustedPrincipalsEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 56 >> 2];
    if (($2 | 0) == 0) {
      var $14 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$2 + 4 >> 2];
    var $_idx_val = HEAP32[HEAP32[$this + 52 >> 2] + 209940 >> 2];
    var $10 = __ZNK9JSRuntime17trustedPrincipalsEv($_idx_val);
    var $14 = ($6 | 0) == ($10 | 0);
    __label__ = 3;
    break;
   case 3:
    var $14;
    return $14;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime15onTooMuchMallocEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[__ZN2js8gcReasonE >> 2] = 6;
    __label__ = 4;
    break;
   case 3:
    var $5 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $5;
    __label__ = 4;
    break;
   case 4:
    __ZN2js9TriggerGCEP9JSRuntime($this);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime13onOutOfMemoryEPvjP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($cx | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext5purgeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 52 >> 2];
    var $3 = $this + 104 | 0;
    __ZL13FreeOldArenasP9JSRuntimeP11JSArenaPool($2, $3);
    if ((HEAP32[$this + 308 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $this + 100 | 0;
    var $9 = HEAP32[$8 >> 2];
    __ZN2js10Foreground7delete_INS_12ParseMapPoolEEEvPT_($9);
    HEAP32[$8 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13FreeOldArenasP9JSRuntimeP11JSArenaPool($rt, $pool) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    if (($2 | 0) == (HEAP32[$pool >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $9 = $2 + 4 | 0;
    if ((HEAP32[$2 + 12 >> 2] | 0) == (HEAP32[$9 >> 2] + 8 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $14 = _JS_Now();
    var $14$0 = $14[0];
    var $14$1 = $14[1];
    var $16 = HEAP32[$9 >> 2];
    var $17$0 = HEAP32[$16 >> 2];
    var $17$1 = HEAP32[$16 + 4 >> 2];
    var $18$0 = (i64Math.subtract($14$0, $14$1, $17$0, $17$1), i64Math.result[0]);
    var $18$1 = i64Math.result[1];
    var $21$0 = HEAP32[$rt + 160 >> 2];
    var $22$0 = (i64Math.multiply($21$0, 0, 1e3, 0), i64Math.result[0]);
    var $22$1 = i64Math.result[1];
    if (($18$1 | 0) > ($22$1 | 0) || ($18$1 | 0) == ($22$1 | 0) && $18$0 >>> 0 > $22$0 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    _JS_FreeArenaPool($pool);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ParseMapPoolD1Ev($this) {
  __ZN2js12ParseMapPoolD2Ev($this);
  return;
}

function _js_free816($p) {
  _free($p);
  return;
}

function __ZN2js12ParseMapPoolD2Ev($this) {
  __ZN2js12ParseMapPool8purgeAllEv($this);
  var $1 = $this + 140 | 0;
  __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEED1Ev($1);
  var $2 = $this | 0;
  __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEED1Ev($2);
  return;
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this >> 2];
    var $3 = __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js17SystemAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this >> 2];
    var $3 = __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js17SystemAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = $this + 12 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj8EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEEC2ES3_($this) {
  var $1 = $this | 0;
  var $2 = $this + 12 | 0;
  var $3 = __ZN7mozilla14AlignedStorageILj8EE4addrEv($2);
  HEAP32[$1 >> 2] = $3;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 2;
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES5_($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_($1);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_($this) {
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_($this);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $0 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j(16);
    HEAP32[$this + 20 >> 2] = $0;
    if (($0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, 4);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev($this_0_5_val) {
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev($this_0_5_val);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev($this_0_5_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_5_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($this_0_5_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN14DSTOffsetCacheC2Ev($this) {
  __ZN14DSTOffsetCache5purgeEv($this);
  return;
}

function __ZNK9JSContext15hasStrictOptionEv($this_0_6_val) {
  var $1 = __ZNK9JSContext12hasRunOptionEj($this_0_6_val, 1);
  return $1;
}

function __ZNK9JSContext15hasWErrorOptionEv($this_0_6_val) {
  var $1 = __ZNK9JSContext12hasRunOptionEj($this_0_6_val, 2);
  return $1;
}

function __ZN2js13FrameRegsIterC1EP9JSContextNS_9StackIter11SavedOptionE($this, $cx) {
  __ZN2js13FrameRegsIterC2EP9JSContextNS_9StackIter11SavedOptionE($this, $cx);
  return;
}

function __ZNK2js13FrameRegsIter4doneEv($this) {
  var $_idx_val = HEAP32[$this + 8 >> 2];
  var $2 = __ZNK2js9StackIter4doneEv($_idx_val);
  return $2;
}

function __ZNK2js13FrameRegsIter2fpEv($this) {
  var $_idx_val = HEAP32[$this + 12 >> 2];
  var $2 = __ZNK2js9StackIter2fpEv($_idx_val);
  return $2;
}

function __ZNK2js13FrameRegsIter2pcEv($this) {
  var $_idx_val = HEAP32[$this + 28 >> 2];
  var $1 = __ZNK2js9StackIter2pcEv($_idx_val);
  return $1;
}

function __ZN2js13FrameRegsIterppEv($this) {
  var $1 = $this;
  __ZN2js9StackIterppEv($1);
  __ZN2js13FrameRegsIter6settleEv($this);
  return;
}

function __ZN2js13FrameRegsIter6settleEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = $this + 8 | 0;
    __label__ = 2;
    break;
   case 2:
    var $_idx1_val = HEAP32[$2 >> 2];
    var $4 = __ZNK2js9StackIter4doneEv($_idx1_val);
    if ($4) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZNK2js9StackIter8isScriptEv($_idx1_val);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js9StackIterppEv($1);
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13FrameRegsIterC2EP9JSContextNS_9StackIter11SavedOptionE($this, $cx) {
  var $1 = $this;
  var $2 = $cx;
  __ZN2js9StackIterC2EP9JSContextNS0_11SavedOptionE($1, $2, 0);
  __ZN2js13FrameRegsIter6settleEv($this);
  return;
}

function __ZN2js8GSNCacheD2Ev($this) {
  var $1 = $this + 4 | 0;
  __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEED1Ev($1);
  return;
}

function __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev($this_0_5_val) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev($this_0_5_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev($this_0_5_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_5_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($this_0_5_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv($0);
  return;
}

function __ZN2js13PropertyCacheC2Ev($this) {
  __ZN2jsL7PodZeroINS_13PropertyCacheEEEvPT_($this);
  return;
}

function __ZN2jsL7PodZeroINS_13PropertyCacheEEEvPT_($t) {
  var $1 = $t;
  _memset($1, 0, 65540, 1);
  return;
}

function __ZN2js8GSNCacheC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEEC1ES4_($2);
  return;
}

function __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEEC1ES4_($this) {
  __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEEC2ES4_($this);
  return;
}

function __ZN13JSCompartment11thisForCtorEv($this) {
  return $this;
}

function __ZNK8JSObject15isStopIterationEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js18StopIterationClassE | 0);
}

function _JSID_IS_INT844($iden) {
  return $iden & 1;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5emptyEv($this_0_0_val, $this_0_1_val) {
  return ($this_0_0_val | 0) == ($this_0_1_val | 0);
}

function __ZN2jsL16CastAsPropertyOpEP8JSObject846($object) {
  return $object;
}

function __ZN2jsL22CastAsStrictPropertyOpEP8JSObject847($object) {
  return $object;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_($this) {
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5frontEv($this_0_0_val) {
  return $this_0_0_val + 8 | 0;
}

function __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEEC2ES4_($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_($this);
  return;
}

function __ZN13JSCompartmentC2EP9JSRuntime($this, $rt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = $rt;
  HEAP32[$this + 4 >> 2] = 0;
  var $4 = $this + 8 | 0;
  __ZN2js2gc10ArenaListsC1Ev($4);
  HEAP32[$this + 328 >> 2] = 0;
  HEAP32[$this + 332 >> 2] = 0;
  HEAP32[$this + 336 >> 2] = 0;
  HEAP8[$this + 340 | 0] = 0;
  HEAP32[$this + 708 >> 2] = 0;
  HEAP8[$this + 712 | 0] = 0;
  HEAP8[$this + 713 | 0] = 0;
  var $12 = $this + 716 | 0;
  __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEEC1ES4_($12);
  var $13 = $this + 744 | 0;
  var $14 = __ZN13JSCompartment11thisForCtorEv($this);
  __ZN2js12PropertyTreeC1EP13JSCompartment($13, $14);
  HEAP32[$this + 748 >> 2] = 0;
  HEAP32[$this + 752 >> 2] = 0;
  HEAP32[$this + 756 >> 2] = 0;
  HEAP32[$this + 760 >> 2] = 0;
  HEAP32[$this + 764 >> 2] = 0;
  HEAP32[$this + 768 >> 2] = 0;
  var $21 = $this + 772 | 0;
  __ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES5_($21);
  HEAP32[$this + 796 >> 2] = 0;
  HEAP32[$this + 800 >> 2] = 0;
  HEAP32[$this + 804 >> 2] = HEAP8[$rt + 144220 | 0] & 1 & 255;
  var $29 = $this + 808 | 0;
  __ZN2js15NativeIterCacheC1Ev($29);
  var $30 = $this + 1836 | 0;
  __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEEC1Ev($30);
  var $31 = $this + 1864 | 0;
  __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEEC1ES4_($31);
  var $32 = $this + 1888 | 0;
  __ZN2js9DtoaCacheC1Ev($32);
  HEAP32[$this + 1904 >> 2] = 0;
  var $34 = $this + 1908 | 0;
  __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC1ES4_($34);
  var $35 = $this + 1932 | 0;
  __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES5_($35);
  var $36 = $this + 1956 | 0;
  __ZN2js18RuntimeAllocPolicyC1EP9JSRuntime($1, $rt);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEEC1ES6_($36, $_0_val);
  HEAP32[$this + 1984 >> 2] = 0;
  var $38 = $this + 452 | 0;
  __ZN2jsL12PodArrayZeroIP8JSScriptLj64EEEvRAT0__T_($38);
  STACKTOP = __stackBase__;
  return;
}

__ZN13JSCompartmentC2EP9JSRuntime["X"] = 1;

function __ZN2js2gc10ArenaListsC1Ev($this) {
  __ZN2js2gc10ArenaListsC2Ev($this);
  return;
}

function __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEEC1ES4_($this) {
  __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEEC2ES4_($this);
  return;
}

function __ZN2js12PropertyTreeC1EP13JSCompartment($this, $comp) {
  __ZN2js12PropertyTreeC2EP13JSCompartment($this, $comp);
  return;
}

function __ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES5_($this) {
  __ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES5_($this);
  return;
}

function __ZN2js15NativeIterCacheC1Ev($this) {
  __ZN2js15NativeIterCacheC2Ev($this);
  return;
}

function __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEEC1Ev($this) {
  __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEEC2Ev($this);
  return;
}

function __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEEC1ES4_($this) {
  __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEEC2ES4_($this);
  return;
}

function __ZN2js9DtoaCacheC1Ev($this) {
  __ZN2js9DtoaCacheC2Ev($this);
  return;
}

function __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC1ES4_($this) {
  __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC2ES4_($this);
  return;
}

function __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEEC1ES6_($this, $a_01) {
  __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEEC2ES6_($this, $a_01);
  return;
}

function __ZN2js18RuntimeAllocPolicyC1EP9JSRuntime($this, $rt) {
  __ZN2js18RuntimeAllocPolicyC2EP9JSRuntime($this, $rt);
  return;
}

function __ZN2jsL12PodArrayZeroIP8JSScriptLj64EEEvRAT0__T_($t) {
  var $1 = $t;
  _memset($1, 0, 256, 1);
  return;
}

function __ZN13JSCompartmentD2Ev($this) {
  var $2 = HEAP32[$this + 1904 >> 2];
  __ZN2js10Foreground7delete_INS_9MathCacheEEEvPT_($2);
  var $4 = HEAP32[$this + 1984 >> 2];
  __ZN2js10Foreground7delete_INS_13WatchpointMapEEEvPT_($4);
  var $5 = $this + 1956 | 0;
  __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEED1Ev($5);
  var $6 = $this + 1932 | 0;
  __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev($6);
  var $7 = $this + 1908 | 0;
  __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED1Ev($7);
  var $8 = $this + 1864 | 0;
  __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEED1Ev($8);
  var $9 = $this + 1836 | 0;
  __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEED1Ev($9);
  var $10 = $this + 772 | 0;
  __ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev($10);
  var $11 = $this + 716 | 0;
  __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEED1Ev($11);
  var $12 = $this + 376 | 0;
  __ZN2js5types15TypeCompartmentD2Ev($12);
  var $13 = $this + 8 | 0;
  __ZN2js2gc10ArenaListsD1Ev($13);
  return;
}

function __ZN2js10Foreground7delete_INS_9MathCacheEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $p;
    _js_free864($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Foreground7delete_INS_13WatchpointMapEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js13WatchpointMapD1Ev($p);
    var $3 = $p;
    _js_free864($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEED1Ev($this) {
  __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEED2Ev($this);
  return;
}

function __ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js2gc10ArenaListsD1Ev($this) {
  __ZN2js2gc10ArenaListsD2Ev($this);
  return;
}

function __ZN13JSCompartment4initEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP8[$this + 373 | 0] = 0;
    HEAP8[$this + 372 | 0] = 0;
    var $3 = $this + 376 | 0;
    __ZN2js5types15TypeCompartment4initEP9JSContext($3, $cx);
    var $4 = $this + 344 | 0;
    _JS_InitArenaPool($4, 4056, 8);
    var $5 = $this + 716 | 0;
    var $6 = __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE4initEj($5);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $8 = $this + 1864 | 0;
    var $9 = __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE4initEj($8);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    var $12 = HEAP32[$this >> 2];
    var $13 = __ZN9JSRuntime4new_IN3WTF20BumpPointerAllocatorEEEPT_v($12);
    HEAP32[$this + 740 >> 2] = $13;
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = $this + 1908 | 0;
    var $18 = __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE4initEj($17);
    if ($18) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $20 = $this + 1932 | 0;
    var $21 = __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE4initEj($20);
    if ($21) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $23 = $this + 1956 | 0;
    var $24 = __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE4initEj($23);
    var $_0 = $24;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj($1);
  return $2;
}

function __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4initEj($1);
  return $2;
}

function __ZN9JSRuntime4new_IN3WTF20BumpPointerAllocatorEEEPT_v($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSRuntime7malloc_EjP9JSContext($this, 4, 0);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN3WTF20BumpPointerAllocatorC1Ev($4);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj($1);
  return $2;
}

function __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4initEj($1);
  return $2;
}

function __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($this, $cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $flags = __stackBase__;
    var $stackDummy_ = __stackBase__ + 4;
    var $global = __stackBase__ + 8;
    var $p = __stackBase__ + 12;
    var $1 = __stackBase__ + 16;
    var $orig = __stackBase__ + 24;
    var $proto = __stackBase__ + 32;
    HEAP32[$flags >> 2] = 0;
    if ($stackDummy_ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 38;
    break;
   case 3:
    var $vp_idx7 = $vp | 0;
    var $st$1$0 = $vp_idx7 | 0;
    var $vp_idx7_val$0 = HEAPU32[$st$1$0 >> 2];
    var $st$1$1 = $vp_idx7 + 4 | 0;
    var $vp_idx7_val$1 = HEAP32[$st$1$1 >> 2];
    var $8 = __ZNK2JS5Value10isMarkableEv($vp_idx7_val$0, $vp_idx7_val$1);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 38;
      break;
    }
   case 4:
    var $10 = __ZNK2JS5Value8isStringEv($vp_idx7_val$0, $vp_idx7_val$1);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $12 = __ZNK2JS5Value8toStringEv($vp_idx7_val$0, $vp_idx7_val$1);
    var $13 = $12;
    var $14 = __ZNK2js2gc4Cell11compartmentEv($13);
    if (($14 | 0) == ($this | 0)) {
      var $_0 = 1;
      __label__ = 38;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx14_val = HEAP32[$12 >> 2];
    var $17 = __ZNK8JSString6isAtomEv($_idx14_val);
    if ($17) {
      var $_0 = 1;
      __label__ = 38;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = __ZNK9JSContext5hasfpEv($cx);
    if ($19) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $21 = __ZNK9JSContext2fpEv($cx);
    var $22 = __ZNK2js10StackFrame10scopeChainEv($21);
    var $23 = $22;
    var $24 = __ZNK8JSObject9getGlobalEv($23);
    HEAP32[$global >> 2] = $24;
    __label__ = 10;
    break;
   case 9:
    var $28 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $28;
    var $29 = $cx;
    var $30 = $global;
    var $31 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($29, $30);
    if ($31) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 38;
      break;
    }
   case 10:
    var $st$0$0 = $vp_idx7 | 0;
    var $vp_idx1_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $vp_idx7 + 4 | 0;
    var $vp_idx1_val$1 = HEAP32[$st$0$1 >> 2];
    var $33 = __ZNK2JS5Value8isObjectEv($vp_idx1_val$0, $vp_idx1_val$1);
    if ($33) {
      __label__ = 11;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 11:
    var $35 = __ZNK2JS5Value8toObjectEv($vp_idx1_val$0, $vp_idx1_val$1);
    var $36 = $35;
    var $37 = __ZNK2js2gc4Cell11compartmentEv($36);
    if (($37 | 0) == ($this | 0)) {
      var $_0 = 1;
      __label__ = 38;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $_idx15_val = HEAP32[$35 + 4 >> 2];
    var $40 = __ZNK8JSObject15isStopIterationEv($_idx15_val);
    if ($40) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $42 = $cx;
    var $43 = __Z18js_FindClassObjectP9JSContextP8JSObject10JSProtoKeyPN2JS5ValueEPN2js5ClassE($42, 0, 23, $vp, 0);
    var $_0 = ($43 | 0) != 0;
    __label__ = 38;
    break;
   case 14:
    var $46 = __ZNK8JSObject8getClassEv($_idx15_val);
    if ((HEAP32[$46 + 76 >> 2] | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 15:
    var $51 = __ZN8JSObject6unwrapEPj($35, $flags);
    __ZN2JS5Value9setObjectER8JSObject($vp, $51);
    var $52 = __ZNK8JSObject14getCompartmentEv($51);
    if (($52 | 0) == ($this | 0)) {
      var $_0 = 1;
      __label__ = 38;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $58 = HEAP32[HEAP32[$cx + 52 >> 2] + 229024 >> 2];
    if (($58 | 0) == 0) {
      var $obj_0 = $51;
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $61 = HEAP32[$global >> 2];
    var $62 = HEAP32[$flags >> 2];
    var $63 = FUNCTION_TABLE[$58]($cx, $61, $51, $62);
    if (($63 | 0) == 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      var $obj_0 = $63;
      __label__ = 18;
      break;
    }
   case 18:
    var $obj_0;
    __ZN2JS5Value9setObjectER8JSObject($vp, $obj_0);
    var $66 = __ZNK8JSObject14getCompartmentEv($obj_0);
    if (($66 | 0) == ($this | 0)) {
      var $_0 = 1;
      __label__ = 38;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 19:
    var $72 = HEAP32[HEAP32[$cx + 52 >> 2] + 229024 >> 2];
    if (($72 | 0) == 0) {
      var $obj_1 = $35;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $75 = HEAP32[$global >> 2];
    var $76 = HEAP32[$flags >> 2];
    var $77 = FUNCTION_TABLE[$72]($cx, $75, $35, $76);
    if (($77 | 0) == 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      var $obj_1 = $77;
      __label__ = 21;
      break;
    }
   case 21:
    var $obj_1;
    __ZN2JS5Value9setObjectER8JSObject($vp, $obj_1);
    __label__ = 22;
    break;
   case 22:
    var $81 = $this + 716 | 0;
    __ZNK2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE6lookupERKS2_($p, $81, $vp);
    var $p_idx_val = HEAP32[$p >> 2];
    var $p_idx_val_idx_val = HEAP32[$p_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($1, $p_idx_val_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $86 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($p_idx_val);
    var $87 = $86 + 8 | 0;
    var $88$0 = HEAP32[$87 >> 2];
    var $88$1 = HEAP32[$87 + 4 >> 2];
    HEAP32[$vp_idx7 >> 2] = $88$0;
    HEAP32[$vp_idx7 + 4 >> 2] = $88$1;
    var $89 = __ZNK2JS5Value8isObjectEv($88$0, $88$1);
    if ($89) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 1;
      __label__ = 38;
      break;
    }
   case 24:
    var $91 = __ZNK2JS5Value8toObjectEv($88$0, $88$1);
    var $92 = HEAP32[$global >> 2];
    var $_idx17_val = HEAP32[$92 + 4 >> 2];
    var $93 = __ZNK8JSObject10getJSClassEv($_idx17_val);
    if (($93 | 0) == (_js_dummy_class | 0)) {
      var $_0 = 1;
      __label__ = 38;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $_idx_val = HEAP32[$91 + 20 >> 2];
    var $96 = __ZNK8JSObject9getParentEv($_idx_val);
    if (($96 | 0) == ($92 | 0)) {
      var $_0 = 1;
      __label__ = 38;
      break;
    } else {
      var $obj1_0 = $91;
      __label__ = 26;
      break;
    }
   case 26:
    var $obj1_0;
    __ZN8JSObject9setParentEPS_($obj1_0, $92);
    var $obj1_0_idx_val_idx_val = HEAP32[HEAP32[$obj1_0 + 36 >> 2] >> 2];
    var $98 = __ZNK8JSObject8getProtoEv($obj1_0_idx_val_idx_val);
    if (($98 | 0) == 0) {
      var $_0 = 1;
      __label__ = 38;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $101 = __ZL25IsCrossCompartmentWrapperP8JSObject($98);
    if ($101) {
      var $obj1_0 = $98;
      __label__ = 26;
      break;
    } else {
      var $_0 = 1;
      __label__ = 38;
      break;
    }
   case 28:
    var $st$0$0 = $vp_idx7 | 0;
    var $vp_idx12_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $vp_idx7 + 4 | 0;
    var $vp_idx12_val$1 = HEAP32[$st$0$1 >> 2];
    var $103 = __ZNK2JS5Value8isStringEv($vp_idx12_val$0, $vp_idx12_val$1);
    if ($103) {
      __label__ = 29;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 29:
    var $105 = $orig | 0;
    var $st$1$0 = $105 | 0;
    HEAP32[$st$1$0 >> 2] = $vp_idx12_val$0;
    var $st$1$1 = $105 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $vp_idx12_val$1;
    var $106 = __ZNK2JS5Value8toStringEv($vp_idx12_val$0, $vp_idx12_val$1);
    var $107 = __ZN8JSString8getCharsEP9JSContext($106, $cx);
    if (($107 | 0) == 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $_idx6_val = HEAP32[$106 >> 2];
    var $110 = __ZNK8JSString6lengthEv($_idx6_val);
    var $111 = $cx;
    var $112 = __Z17js_NewStringCopyNP9JSContextPKtj($111, $107, $110);
    if (($112 | 0) == 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $115 = $112 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $115);
    var $116 = __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3putERKS2_S7_($81, $orig, $vp);
    var $_0 = ($116 | 0) != 0;
    __label__ = 38;
    break;
   case 32:
    var $119 = __ZNK2JS5Value8toObjectEv($vp_idx12_val$0, $vp_idx12_val$1);
    var $_idx11_val_idx_val = HEAP32[HEAP32[$119 + 36 >> 2] >> 2];
    var $120 = __ZNK8JSObject8getProtoEv($_idx11_val_idx_val);
    HEAP32[$proto >> 2] = $120;
    var $121 = __ZN13JSCompartment4wrapEP9JSContextPP8JSObject($this, $cx, $proto);
    if ($121) {
      __label__ = 33;
      break;
    } else {
      var $_0 = 0;
      __label__ = 38;
      break;
    }
   case 33:
    var $126 = HEAP32[HEAP32[$cx + 52 >> 2] + 229020 >> 2];
    var $127 = HEAP32[$proto >> 2];
    var $128 = HEAP32[$global >> 2];
    var $129 = HEAP32[$flags >> 2];
    var $130 = FUNCTION_TABLE[$126]($cx, $119, $127, $128, $129);
    if (($130 | 0) == 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    __ZN2JS5Value9setObjectER8JSObject($vp, $130);
    var $_idx10_val_idx_val = HEAP32[HEAP32[$130 + 36 >> 2] >> 2];
    var $133 = __ZNK8JSObject8getProtoEv($_idx10_val_idx_val);
    if (($133 | 0) == ($127 | 0)) {
      __label__ = 36;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $136 = $cx;
    var $137 = $130;
    var $138 = $127;
    var $139 = __ZN2js8SetProtoEP9JSContextP8JSObjectS3_b($136, $137, $138, 0);
    if ($139) {
      __label__ = 36;
      break;
    } else {
      var $_0 = 0;
      __label__ = 38;
      break;
    }
   case 36:
    var $141 = __ZNK8JSObject15getProxyPrivateEv($130);
    var $142 = __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3putERKS2_S7_($81, $141, $vp);
    if (($142 | 0) == 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    __ZN8JSObject9setParentEPS_($130, $128);
    var $_0 = 1;
    __label__ = 38;
    break;
   case 38:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE["X"] = 1;

function __ZNK2JS5Value10isMarkableEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_IS_TRACEABLE_IMPL($this_0_0_0_val$0, $this_0_0_0_val$1);
  return ($1 | 0) != 0;
}

function __ZL25IsCrossCompartmentWrapperP8JSObject($wrapper) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject9isWrapperEv($wrapper);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $9 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN9JSWrapper14wrapperHandlerEPK8JSObject($wrapper);
    var $_idx_val = HEAP32[$3 + 8 >> 2];
    var $5 = __ZNK9JSWrapper5flagsEv($_idx_val);
    var $9 = ($5 & 1 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment4wrapEP9JSContextPP8JSObject($this, $cx, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __stackBase__ + 24;
    var $2 = HEAP32[$objp >> 2];
    if (($2 | 0) == 0) {
      var $_1 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL11ObjectValueER8JSObject841($1, $2);
    __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr, $cx, $1);
    var $5 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $6 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($this, $cx, $5);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $_idx = $8 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $9 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    HEAP32[$objp >> 2] = $9;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 5;
    break;
   case 5:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment4wrapEP9JSContextPP8JSString($this, $cx, $strp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __stackBase__ + 24;
    var $2 = HEAP32[$strp >> 2];
    __ZN2JSL11StringValueEP8JSString840($1, $2);
    __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr, $cx, $1);
    var $3 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $4 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($this, $cx, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $_idx = $6 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $7 = __ZNK2JS5Value8toStringEv($_idx_val$0, $_idx_val$1);
    HEAP32[$strp >> 2] = $7;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11StringValueEP8JSString840($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2JSL11ObjectValueER8JSObject841($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN13JSCompartment6wrapIdEP9JSContextPi($this, $cx, $idp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __stackBase__ + 24;
    var $2 = HEAP32[$idp >> 2];
    var $3 = _JSID_IS_INT844($2);
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 1;
      __label__ = 5;
      break;
    }
   case 2:
    __ZN2jsL9IdToValueEi845($1, $2);
    __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr, $cx, $1);
    var $6 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $7 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($this, $cx, $6);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $10 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($cx, $9, $idp);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 5;
    break;
   case 5:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9IdToValueEi845($agg_result, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_STRING869($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_STRING870($id);
    __ZN2JSL11StringValueEP8JSString840($agg_result, $4);
    __label__ = 8;
    break;
   case 3:
    var $6 = _JSID_IS_INT844($id);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _JSID_TO_INT872($id);
    __ZN2JSL10Int32ValueEi871($agg_result, $9);
    __label__ = 8;
    break;
   case 5:
    var $11 = _JSID_IS_OBJECT873($id);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = _JSID_TO_OBJECT874($id);
    __ZN2JSL11ObjectValueER8JSObject841($agg_result, $14);
    __label__ = 8;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv875($agg_result);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment4wrapEP9JSContextPPFiS1_P8JSObjectiPN2JS5ValueEE($this, $cx, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = HEAP32[$propp >> 2];
    __ZN2js17CastAsObjectJsvalEPFiP9JSContextP8JSObjectiPN2JS5ValueEE($v, $1);
    var $2 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($this, $cx, $v);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $4 = __ZNK2JS5Value14toObjectOrNullEv($v_idx_val$0, $v_idx_val$1);
    var $5 = __ZN2jsL16CastAsPropertyOpEP8JSObject846($4);
    HEAP32[$propp >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17CastAsObjectJsvalEPFiP9JSContextP8JSObjectiPN2JS5ValueEE($agg_result, $op) {
  var $1 = __ZN2js12CastAsObjectEPFiP9JSContextP8JSObjectiPN2JS5ValueEE($op);
  __ZN2JSL17ObjectOrNullValueEP8JSObject866($agg_result, $1);
  return;
}

function __ZN13JSCompartment4wrapEP9JSContextPPFiS1_P8JSObjectiiPN2JS5ValueEE($this, $cx, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = HEAP32[$propp >> 2];
    __ZN2js17CastAsObjectJsvalEPFiP9JSContextP8JSObjectiiPN2JS5ValueEE($v, $1);
    var $2 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($this, $cx, $v);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $4 = __ZNK2JS5Value14toObjectOrNullEv($v_idx_val$0, $v_idx_val$1);
    var $5 = __ZN2jsL22CastAsStrictPropertyOpEP8JSObject847($4);
    HEAP32[$propp >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17CastAsObjectJsvalEPFiP9JSContextP8JSObjectiiPN2JS5ValueEE($agg_result, $op) {
  var $1 = __ZN2js12CastAsObjectEPFiP9JSContextP8JSObjectiiPN2JS5ValueEE($op);
  __ZN2JSL17ObjectOrNullValueEP8JSObject866($agg_result, $1);
  return;
}

function __ZN13JSCompartment4wrapEP9JSContextP20JSPropertyDescriptor($this, $cx, $desc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $desc | 0;
    var $2 = __ZN13JSCompartment4wrapEP9JSContextPP8JSObject($this, $cx, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $22 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    var $4 = $desc + 4 | 0;
    var $5 = HEAP32[$4 >> 2];
    if (($5 & 16 | 0) == 0) {
      var $12 = $5;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $desc + 8 | 0;
    var $10 = __ZN13JSCompartment4wrapEP9JSContextPPFiS1_P8JSObjectiPN2JS5ValueEE($this, $cx, $9);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      var $22 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $12 = HEAP32[$4 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $12;
    if (($12 & 32 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = $desc + 12 | 0;
    var $17 = __ZN13JSCompartment4wrapEP9JSContextPPFiS1_P8JSObjectiiPN2JS5ValueEE($this, $cx, $16);
    if ($17) {
      __label__ = 7;
      break;
    } else {
      var $22 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $19 = $desc + 16 | 0;
    var $20 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($this, $cx, $19);
    var $22 = $20;
    __label__ = 8;
    break;
   case 8:
    var $22;
    return $22;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment4wrapEP9JSContextRN2js12AutoIdVectorE($this, $cx, $props) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $props | 0;
    var $2 = __ZN2js16AutoVectorRooterIiE5beginEv($1);
    var $3 = __ZNK2js16AutoVectorRooterIiE6lengthEv($1);
    var $n_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $n_0;
    if ($n_0 >>> 0 < $3 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 3:
    var $7 = $2 + ($n_0 << 2) | 0;
    var $8 = __ZN13JSCompartment6wrapIdEP9JSContextPi($this, $cx, $7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $n_0 = $n_0 + 1 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment28markCrossCompartmentWrappersEP8JSTracer($this, $trc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e = __stackBase__;
    var $1 = $this + 716 | 0;
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC1IS9_EERT_($e, $1);
    var $2 = $e | 0;
    var $_idx2 = $e | 0;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $_idx3 = $e + 4 | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5emptyEv($_idx2_val, $_idx3_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_idx4_val = $_idx2_val;
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD1Ev($e);
    STACKTOP = __stackBase__;
    return;
   case 3:
    var $_idx4_val;
    var $4 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5frontEv($_idx4_val);
    var $_idx5 = $4 | 0;
    var $_idx5_val$0 = HEAP32[$_idx5 >> 2];
    var $_idx5_val$1 = HEAP32[$_idx5 + 4 >> 2];
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $_idx5_val$0, $_idx5_val$1);
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range8popFrontEv($2);
    var $_idx_val = HEAP32[$_idx2 >> 2];
    var $_idx1_val = HEAP32[$_idx3 >> 2];
    var $5 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5emptyEv($_idx_val, $_idx1_val);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_idx4_val = $_idx_val;
      __label__ = 3;
      break;
    }
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC1IS9_EERT_($this, $map) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC2IS9_EERT_($this, $map);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 24 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$5 >> 2];
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isLiveEv($_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD2Ev($this);
  return;
}

function __ZNK2js2gc12CellIterImpl4doneEv($this_0_6_val) {
  return ($this_0_6_val | 0) == 0;
}

function __ZNK2js18ThreadContextRange5emptyEv($this_0_0_val, $this_0_1_val) {
  return ($this_0_0_val | 0) == ($this_0_1_val | 0);
}

function __ZNK2js2gc12CellIterImpl3getI8JSScriptEEPT_v($this_0_6_val) {
  return $this_0_6_val;
}

function __ZNK2js2gc12CellIterImpl3getI8JSObjectEEPT_v($this_0_6_val) {
  return $this_0_6_val;
}

function __ZNK2js2gc12CellIterImpl3getINS_5types10TypeObjectEEEPT_v($this_0_6_val) {
  return $this_0_6_val;
}

function __ZN8JSScript13clearAnalysisEv($this_0_32_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_32_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$this_0_32_val >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9DtoaCache5purgeEv($this) {
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZN2js18ThreadContextRange8popFrontEv($this) {
  var $1 = $this | 0;
  var $4 = HEAP32[HEAP32[$1 >> 2] >> 2];
  HEAP32[$1 >> 2] = $4;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrptEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN13JSCompartment9markTypesEP8JSTracer($this, $trc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 96;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $i1 = __stackBase__ + 32;
    var $i2 = __stackBase__ + 64;
    __ZN2js2gc15CellIterUnderGCC1EP13JSCompartmentNS0_9AllocKindE($i, $this, 13);
    var $1 = $i | 0;
    var $_idx5 = $i + 28 | 0;
    var $_idx5_val = HEAP32[$_idx5 >> 2];
    var $2 = __ZNK2js2gc12CellIterImpl4doneEv($_idx5_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_idx6_val = $_idx5_val;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $i1 | 0;
    var $_idx3 = $i1 + 28 | 0;
    var $thingKind_04 = 0;
    __label__ = 4;
    break;
   case 3:
    var $_idx6_val;
    var $4 = __ZNK2js2gc12CellIterImpl3getI8JSScriptEEPT_v($_idx6_val);
    __ZN2js2gc10MarkScriptEP8JSTracerP8JSScriptPKc($trc, $4);
    __ZN2js2gc12CellIterImpl4nextEv($1);
    var $_idx4_val = HEAP32[$_idx5 >> 2];
    var $5 = __ZNK2js2gc12CellIterImpl4doneEv($_idx4_val);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_idx6_val = $_idx4_val;
      __label__ = 3;
      break;
    }
   case 4:
    var $thingKind_04;
    __ZN2js2gc15CellIterUnderGCC1EP13JSCompartmentNS0_9AllocKindE($i1, $this, $thingKind_04);
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $7 = __ZNK2js2gc12CellIterImpl4doneEv($_idx3_val);
    if ($7) {
      __label__ = 9;
      break;
    } else {
      var $_idx7_val = $_idx3_val;
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx7_val;
    var $8 = __ZNK2js2gc12CellIterImpl3getI8JSObjectEEPT_v($_idx7_val);
    var $_idx8_val = HEAP32[$8 >> 2];
    var $9 = __ZNK8JSObject9isNewbornEv($_idx8_val);
    if ($9) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx9_val = HEAP32[$8 + 8 >> 2];
    var $11 = __ZNK8JSObject16hasSingletonTypeEv($_idx9_val);
    if ($11) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $8);
    __label__ = 8;
    break;
   case 8:
    __ZN2js2gc12CellIterImpl4nextEv($3);
    var $_idx2_val = HEAP32[$_idx3 >> 2];
    var $14 = __ZNK2js2gc12CellIterImpl4doneEv($_idx2_val);
    if ($14) {
      __label__ = 9;
      break;
    } else {
      var $_idx7_val = $_idx2_val;
      __label__ = 5;
      break;
    }
   case 9:
    var $15 = $thingKind_04 + 1 | 0;
    if (($15 | 0) == 13) {
      __label__ = 10;
      break;
    } else {
      var $thingKind_04 = $15;
      __label__ = 4;
      break;
    }
   case 10:
    __ZN2js2gc15CellIterUnderGCC1EP13JSCompartmentNS0_9AllocKindE($i2, $this, 15);
    var $17 = $i2 | 0;
    var $_idx1 = $i2 + 28 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $18 = __ZNK2js2gc12CellIterImpl4doneEv($_idx1_val);
    if ($18) {
      __label__ = 12;
      break;
    } else {
      var $_idx10_val = $_idx1_val;
      __label__ = 11;
      break;
    }
   case 11:
    var $_idx10_val;
    var $19 = __ZNK2js2gc12CellIterImpl3getINS_5types10TypeObjectEEEPT_v($_idx10_val);
    __ZN2js2gc14MarkTypeObjectEP8JSTracerPNS_5types10TypeObjectEPKc($trc, $19);
    __ZN2js2gc12CellIterImpl4nextEv($17);
    var $_idx_val = HEAP32[$_idx1 >> 2];
    var $20 = __ZNK2js2gc12CellIterImpl4doneEv($_idx_val);
    if ($20) {
      __label__ = 12;
      break;
    } else {
      var $_idx10_val = $_idx_val;
      __label__ = 11;
      break;
    }
   case 12:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN13JSCompartment9markTypesEP8JSTracer["X"] = 1;

function __ZN2js2gc15CellIterUnderGCC1EP13JSCompartmentNS0_9AllocKindE($this, $comp, $kind) {
  __ZN2js2gc15CellIterUnderGCC2EP13JSCompartmentNS0_9AllocKindE($this, $comp, $kind);
  return;
}

function __ZN2js2gc12CellIterImpl4nextEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = $this + 20 | 0;
    var $4 = $this + 8 | 0;
    var $5 = $this + 12 | 0;
    var $6 = $1;
    var $7 = $5;
    var $8 = $this | 0;
    var $11 = HEAP32[$2 >> 2];
    var $10 = HEAP32[$3 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $10;
    var $11;
    if (($11 | 0) == (HEAP32[$10 >> 2] | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    var $_idx1 = $10 + 4 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $16 = __ZNK2js2gc8FreeSpan7hasNextEv($_idx1_val);
    if ($16) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $19 = HEAP32[$this + 4 >> 2];
    var $20 = $19 + $_idx1_val | 0;
    HEAP32[$2 >> 2] = $20;
    var $_idx_val = HEAP32[$_idx1 >> 2];
    var $21 = __ZNK2js2gc8FreeSpan8nextSpanEv($_idx_val);
    HEAP32[$3 >> 2] = $21;
    var $36 = $20;
    var $35 = $19;
    __label__ = 9;
    break;
   case 5:
    var $23 = HEAP32[$4 >> 2];
    if (($23 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$this + 28 >> 2] = 0;
    __label__ = 10;
    break;
   case 7:
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($1, $23);
    var $28$0 = HEAP32[$6 >> 2];
    var $28$1 = HEAP32[$6 + 4 >> 2];
    HEAP32[$7 >> 2] = $28$0;
    HEAP32[$7 + 4 >> 2] = $28$1;
    HEAP32[$3 >> 2] = $5;
    var $29 = HEAP32[$4 >> 2];
    var $30 = __ZNK2js2gc11ArenaHeader12arenaAddressEv($29);
    var $32 = HEAP32[$8 >> 2] | $30;
    HEAP32[$2 >> 2] = $32;
    var $34 = HEAP32[$29 + 4 >> 2];
    HEAP32[$4 >> 2] = $34;
    var $11 = $32;
    var $10 = $5;
    __label__ = 2;
    break;
   case 8:
    var $36 = $11;
    var $35 = HEAP32[$this + 4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $35;
    var $36;
    HEAP32[$this + 28 >> 2] = $36;
    HEAP32[$2 >> 2] = $36 + $35 | 0;
    __label__ = 10;
    break;
   case 10:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc12CellIterImpl4nextEv["X"] = 1;

function __ZN13JSCompartment5sweepEP9JSContextj($this, $cx, $releaseInterval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 108;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e = __stackBase__;
    var $oldPool = __stackBase__ + 16;
    var $i = __stackBase__ + 44;
    var $i1 = __stackBase__ + 76;
    var $1 = $this + 716 | 0;
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC1IS9_EERT_($e, $1);
    var $2 = $e | 0;
    var $_idx2 = $e | 0;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $_idx3 = $e + 4 | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5emptyEv($_idx2_val, $_idx3_val);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $cx_idx16 = $cx + 52 | 0;
    var $_idx4_val = $_idx2_val;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD1Ev($e);
    var $4 = $this + 748 | 0;
    var $5 = HEAP32[$4 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $_idx4_val;
    var $7 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5frontEv($_idx4_val);
    var $_idx7 = $7 | 0;
    var $_idx7_val$0 = HEAP32[$_idx7 >> 2];
    var $_idx7_val$1 = HEAP32[$_idx7 + 4 >> 2];
    var $8 = __ZNK2JS5Value9toGCThingEv($_idx7_val$0, $_idx7_val$1);
    var $cx_idx16_val_idx_val = HEAP32[HEAP32[$cx_idx16 >> 2] + 144080 >> 2];
    var $9 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx_idx16_val_idx_val, $8);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx6 = $7 + 8 | 0;
    var $_idx6_val$0 = HEAP32[$_idx6 >> 2];
    var $_idx6_val$1 = HEAP32[$_idx6 + 4 >> 2];
    var $11 = __ZNK2JS5Value9toGCThingEv($_idx6_val$0, $_idx6_val$1);
    var $cx_idx15_val_idx_val = HEAP32[HEAP32[$cx_idx16 >> 2] + 144080 >> 2];
    var $12 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx_idx15_val_idx_val, $11);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4Enum11removeFrontEv($e);
    __label__ = 7;
    break;
   case 7:
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range8popFrontEv($2);
    var $_idx_val = HEAP32[$_idx2 >> 2];
    var $_idx1_val = HEAP32[$_idx3 >> 2];
    var $15 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5emptyEv($_idx_val, $_idx1_val);
    if ($15) {
      __label__ = 3;
      break;
    } else {
      var $_idx4_val = $_idx_val;
      __label__ = 4;
      break;
    }
   case 8:
    var $17 = $5;
    var $cx_idx14_val_idx_val = HEAP32[HEAP32[$cx + 52 >> 2] + 144080 >> 2];
    var $18 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx_idx14_val_idx_val, $17);
    if ($18) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    HEAP32[$4 >> 2] = 0;
    __label__ = 10;
    break;
   case 10:
    var $21 = $this + 752 | 0;
    var $22 = HEAP32[$21 >> 2];
    if (($22 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $25 = $22;
    var $cx_idx13_val_idx_val = HEAP32[HEAP32[$cx + 52 >> 2] + 144080 >> 2];
    var $26 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx_idx13_val_idx_val, $25);
    if ($26) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    HEAP32[$21 >> 2] = 0;
    __label__ = 13;
    break;
   case 13:
    var $29 = $this + 756 | 0;
    var $30 = HEAP32[$29 >> 2];
    if (($30 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $33 = $30;
    var $cx_idx12_val_idx_val = HEAP32[HEAP32[$cx + 52 >> 2] + 144080 >> 2];
    var $34 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx_idx12_val_idx_val, $33);
    if ($34) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    HEAP32[$29 >> 2] = 0;
    __label__ = 16;
    break;
   case 16:
    var $37 = $this + 760 | 0;
    var $38 = HEAP32[$37 >> 2];
    if (($38 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $41 = $38;
    var $cx_idx11_val_idx_val = HEAP32[HEAP32[$cx + 52 >> 2] + 144080 >> 2];
    var $42 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx_idx11_val_idx_val, $41);
    if ($42) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    HEAP32[$37 >> 2] = 0;
    __label__ = 19;
    break;
   case 19:
    var $45 = $this + 764 | 0;
    var $46 = HEAP32[$45 >> 2];
    if (($46 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $49 = $46;
    var $cx_idx10_val_idx_val = HEAP32[HEAP32[$cx + 52 >> 2] + 144080 >> 2];
    var $50 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx_idx10_val_idx_val, $49);
    if ($50) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    HEAP32[$45 >> 2] = 0;
    __label__ = 22;
    break;
   case 22:
    var $53 = $this + 768 | 0;
    var $54 = HEAP32[$53 >> 2];
    if (($54 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $57 = $54;
    var $cx_idx9_val_idx_val = HEAP32[HEAP32[$cx + 52 >> 2] + 144080 >> 2];
    var $58 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx_idx9_val_idx_val, $57);
    if ($58) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    HEAP32[$53 >> 2] = 0;
    __label__ = 25;
    break;
   case 25:
    var $61 = $this + 796 | 0;
    var $62 = HEAP32[$61 >> 2];
    if (($62 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $65 = $62;
    var $cx_idx8_val_idx_val = HEAP32[HEAP32[$cx + 52 >> 2] + 144080 >> 2];
    var $66 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx_idx8_val_idx_val, $65);
    if ($66) {
      __label__ = 27;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 27:
    HEAP32[$61 >> 2] = 0;
    __label__ = 28;
    break;
   case 28:
    var $69 = $this + 800 | 0;
    var $70 = HEAP32[$69 >> 2];
    if (($70 | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $73 = $70;
    var $cx_idx_val_idx_val = HEAP32[HEAP32[$cx + 52 >> 2] + 144080 >> 2];
    var $74 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx_idx_val_idx_val, $73);
    if ($74) {
      __label__ = 30;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    HEAP32[$69 >> 2] = 0;
    __label__ = 31;
    break;
   case 31:
    __ZN13JSCompartment16sweepBreakpointsEP9JSContext($this, $cx);
    var $77 = $this + 712 | 0;
    if ((HEAP8[$77] & 1) << 24 >> 24 == 0) {
      __label__ = 32;
      break;
    } else {
      var $89 = 0;
      __label__ = 34;
      break;
    }
   case 32:
    if (($releaseInterval | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      var $89 = 1;
      __label__ = 34;
      break;
    }
   case 33:
    var $89 = (HEAP8[$this + 713 | 0] & 1) << 24 >> 24 != 0;
    __label__ = 34;
    break;
   case 34:
    var $89;
    if ((HEAP8[$this + 372 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 35:
    var $95 = $this + 344 | 0;
    __ZN2js13MoveArenaPoolEP11JSArenaPoolS1_($95, $oldPool);
    var $96 = $this + 376 | 0;
    if ((HEAP8[$96 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    __ZN2js2gc15CellIterUnderGCC1EP13JSCompartmentNS0_9AllocKindE($i, $this, 13);
    var $102 = $i | 0;
    var $_idx20 = $i + 28 | 0;
    var $_idx20_val = HEAP32[$_idx20 >> 2];
    var $103 = __ZNK2js2gc12CellIterImpl4doneEv($_idx20_val);
    if ($103) {
      __label__ = 41;
      break;
    } else {
      var $_idx22_val = $_idx20_val;
      __label__ = 37;
      break;
    }
   case 37:
    var $_idx22_val;
    var $104 = __ZNK2js2gc12CellIterImpl3getI8JSScriptEEPT_v($_idx22_val);
    var $105 = $104 + 100 | 0;
    if ((HEAP32[$105 >> 2] | 0) == 0) {
      __label__ = 40;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    __ZN2js5types10TypeScript5SweepEP9JSContextP8JSScript($cx, $104);
    if ($89) {
      __label__ = 39;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 39:
    var $110 = HEAP32[$105 >> 2];
    __ZN2js5types10TypeScript7destroyEv($110);
    HEAP32[$105 >> 2] = 0;
    var $111 = $104 + 38 | 0;
    var $113 = HEAP8[$111] | 16;
    HEAP8[$111] = $113;
    __label__ = 40;
    break;
   case 40:
    __ZN2js2gc12CellIterImpl4nextEv($102);
    var $_idx19_val = HEAP32[$_idx20 >> 2];
    var $115 = __ZNK2js2gc12CellIterImpl4doneEv($_idx19_val);
    if ($115) {
      __label__ = 41;
      break;
    } else {
      var $_idx22_val = $_idx19_val;
      __label__ = 37;
      break;
    }
   case 41:
    __ZN2js5types15TypeCompartment5sweepEP9JSContext($96, $cx);
    __ZN2js2gc15CellIterUnderGCC1EP13JSCompartmentNS0_9AllocKindE($i1, $this, 13);
    var $116 = $i1 | 0;
    var $_idx18 = $i1 + 28 | 0;
    var $_idx18_val = HEAP32[$_idx18 >> 2];
    var $117 = __ZNK2js2gc12CellIterImpl4doneEv($_idx18_val);
    if ($117) {
      __label__ = 43;
      break;
    } else {
      var $_idx21_val = $_idx18_val;
      __label__ = 42;
      break;
    }
   case 42:
    var $_idx21_val;
    var $118 = __ZNK2js2gc12CellIterImpl3getI8JSScriptEEPT_v($_idx21_val);
    var $_idx23_val = HEAP32[$118 + 100 >> 2];
    __ZN8JSScript13clearAnalysisEv($_idx23_val);
    __ZN2js2gc12CellIterImpl4nextEv($116);
    var $_idx17_val = HEAP32[$_idx18 >> 2];
    var $119 = __ZNK2js2gc12CellIterImpl4doneEv($_idx17_val);
    if ($119) {
      __label__ = 43;
      break;
    } else {
      var $_idx21_val = $_idx17_val;
      __label__ = 42;
      break;
    }
   case 43:
    _JS_FinishArenaPool($oldPool);
    __label__ = 44;
    break;
   case 44:
    HEAP8[$77] = 0;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN13JSCompartment5sweepEP9JSContextj["X"] = 1;

function __ZNK2JS5Value9toGCThingEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_TO_GCTHING_IMPL($this_0_0_0_val$0, $this_0_0_0_val$1);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6removeERNS0_14HashTableEntryIS5_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZN13JSCompartment16sweepBreakpointsEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e = __stackBase__;
    var $1 = $this + 1956 | 0;
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumC1ISB_EERT_($e, $1);
    var $2 = $e | 0;
    var $_idx3 = $e | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $_idx4 = $e + 4 | 0;
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($_idx3_val, $_idx4_val);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $cx_idx1 = $cx + 52 | 0;
    var $_idx5_val = $_idx3_val;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumD1Ev($e);
    STACKTOP = __stackBase__;
    return;
   case 4:
    var $_idx5_val;
    var $4 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5frontEv($_idx5_val);
    var $6 = HEAP32[$4 + 4 >> 2];
    var $8 = HEAP32[$6 + 12 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = $8;
    var $cx_idx1_val_idx_val = HEAP32[HEAP32[$cx_idx1 >> 2] + 144080 >> 2];
    var $12 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx_idx1_val_idx_val, $11);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      var $16 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $_idx7_val = HEAP32[$6 + 28 >> 2];
    var $14 = __ZNK2js14BreakpointSite7hasTrapEv($_idx7_val);
    var $16 = $14;
    __label__ = 7;
    break;
   case 7:
    var $16;
    var $17 = __ZNK2js14BreakpointSite15firstBreakpointEv($6);
    if (($17 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $bp_01 = $17;
      __label__ = 8;
      break;
    }
   case 8:
    var $bp_01;
    var $bp_01_idx_val = HEAP32[$bp_01 + 4 >> 2];
    var $bp_01_idx8_val = HEAP32[$bp_01 + 20 >> 2];
    var $19 = __ZN2js10Breakpoint10nextInSiteEv($bp_01_idx_val, $bp_01_idx8_val);
    if ($12) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_idx6_val = HEAP32[HEAP32[$bp_01 >> 2] + 8 >> 2];
    var $23 = __ZNK2js8Debugger10toJSObjectEv($_idx6_val);
    var $24 = $23;
    var $cx_idx_val_idx_val = HEAP32[HEAP32[$cx_idx1 >> 2] + 144080 >> 2];
    var $25 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx_idx_val_idx_val, $24);
    if ($25) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if (($19 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $bp_01 = $19;
      __label__ = 8;
      break;
    }
   case 11:
    __ZN2js10Breakpoint7destroyEP9JSContextPNS_6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS6_S8_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESD_E4EnumE($bp_01, $e);
    __label__ = 10;
    break;
   case 12:
    if ($16) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    __ZN2js14BreakpointSite9clearTrapEP9JSContextPNS_6detail9HashTableINS_12HashMapEntryIPhPS0_EENS_7HashMapIS6_S7_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESC_E4EnumEPPF12JSTrapStatusS2_P8JSScriptS6_PN2JS5ValueESM_ESN_($6, $e);
    __label__ = 14;
    break;
   case 14:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range8popFrontEv($2);
    var $_idx_val = HEAP32[$_idx3 >> 2];
    var $_idx2_val = HEAP32[$_idx4 >> 2];
    var $30 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($_idx_val, $_idx2_val);
    if ($30) {
      __label__ = 3;
      break;
    } else {
      var $_idx5_val = $_idx_val;
      __label__ = 4;
      break;
    }
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN13JSCompartment16sweepBreakpointsEP9JSContext["X"] = 1;

function __ZN2js13MoveArenaPoolEP11JSArenaPoolS1_($oldPool, $newPool) {
  var $1 = $newPool;
  var $2 = $oldPool;
  HEAP32[$1 >> 2] = HEAP32[$2 >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[$2 + 4 >> 2];
  HEAP32[$1 + 8 >> 2] = HEAP32[$2 + 8 >> 2];
  HEAP32[$1 + 12 >> 2] = HEAP32[$2 + 12 >> 2];
  HEAP32[$1 + 16 >> 2] = HEAP32[$2 + 16 >> 2];
  HEAP32[$1 + 20 >> 2] = HEAP32[$2 + 20 >> 2];
  HEAP32[$1 + 24 >> 2] = HEAP32[$2 + 24 >> 2];
  var $4 = HEAP32[$newPool + 20 >> 2];
  var $7 = HEAP32[$newPool + 24 >> 2] + 1 | 0;
  _JS_InitArenaPool($oldPool, $4, $7);
  return;
}

function __ZN13JSCompartment5purgeEP9JSContext($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 8 | 0;
    __ZN2js2gc10ArenaLists5purgeEv($1);
    var $2 = $this + 1888 | 0;
    __ZN2js9DtoaCache5purgeEv($2);
    var $i_02 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_02;
    var $4 = $this + 452 + ($i_02 << 2) | 0;
    var $5 = HEAP32[$4 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $listHeadp_01 = $4;
      var $7 = $5;
      __label__ = 3;
      break;
    }
   case 3:
    var $7;
    var $listHeadp_01;
    HEAP32[$listHeadp_01 >> 2] = 0;
    var $9 = $7 + 84 | 0;
    var $10 = HEAP32[$9 >> 2];
    if (($10 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $listHeadp_01 = $9;
      var $7 = $10;
      __label__ = 3;
      break;
    }
   case 4:
    var $12 = $i_02 + 1 | 0;
    if (($12 | 0) == 64) {
      __label__ = 5;
      break;
    } else {
      var $i_02 = $12;
      __label__ = 2;
      break;
    }
   case 5:
    var $15 = $this + 808 | 0;
    __ZN2js15NativeIterCache5purgeEv($15);
    var $16 = $this + 1836 | 0;
    __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE20destroyIfConstructedEv($16);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc10ArenaLists5purgeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i_01 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_01;
    var $2 = $this + ($i_01 << 3) | 0;
    var $_idx_val = HEAP32[$2 >> 2];
    var $_idx1_val = HEAP32[$this + ($i_01 << 3) + 4 >> 2];
    var $3 = __ZNK2js2gc8FreeSpan7isEmptyEv($_idx_val, $_idx1_val);
    if ($3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK2js2gc8FreeSpan11arenaHeaderEv($_idx1_val);
    __ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE($5, $_idx_val, $_idx1_val);
    __ZN2js2gc8FreeSpan11initAsEmptyEj($2);
    __label__ = 4;
    break;
   case 4:
    var $7 = $i_01 + 1 | 0;
    if (($7 | 0) == 20) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = $7;
      __label__ = 2;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15NativeIterCache5purgeEv($this) {
  var $1 = $this | 0;
  __ZN2jsL12PodArrayZeroIP8JSObjectLj256EEEvRAT0__T_($1);
  HEAP32[$this + 1024 >> 2] = 0;
  return;
}

function __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE20destroyIfConstructedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP8[$this + 24 | 0];
    var $1 = __ZNK7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE5emptyEv($this_idx_val);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE7destroyEv($this);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment14allocMathCacheEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext4new_IN2js9MathCacheEEEPT_v($cx);
    var $2 = $this + 1904 | 0;
    HEAP32[$2 >> 2] = $1;
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $6 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $6 = HEAP32[$2 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext4new_IN2js9MathCacheEEEPT_v($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 81920);
    if (($1 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    var $5 = $1;
    __ZN2js9MathCacheC2Ev($5);
    var $7 = $4;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment17hasScriptsOnStackEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $_idx_val = HEAP32[$cx + 64 >> 2];
    var $1 = __ZNK2js12ContextStack5spaceEv($_idx_val);
    var $2 = $i;
    var $_idx1_val = HEAP32[$1 >> 2];
    __ZN2js13AllFramesIterC2ERNS_10StackSpaceE($2, $_idx1_val);
    var $i_idx = $i + 4 | 0;
    __label__ = 2;
    break;
   case 2:
    var $i_idx_val = HEAP32[$i_idx >> 2];
    var $4 = __ZNK2js13AllFramesIter4doneEv($i_idx_val);
    if ($4) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZNK2js13AllFramesIter2fpEv($i_idx_val);
    var $7 = __ZNK2js10StackFrame11maybeScriptEv($6);
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7;
    var $11 = __ZNK2js2gc4Cell11compartmentEv($10);
    if (($11 | 0) == ($this | 0)) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js13AllFramesIterppEv($2);
    __label__ = 2;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment17setDebugModeFromCEP9JSContextb($this, $cx, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx = $this + 804 | 0;
    var $this_idx_val = HEAPU32[$this_idx >> 2];
    var $1 = __ZNK13JSCompartment9debugModeEv($this_idx_val);
    if ($1 ^ ($this_idx_val >>> 0 > 1 | $b)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $6 = __ZN13JSCompartment17hasScriptsOnStackEP9JSContext($this, $cx);
    if ($6 & $b) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 4, 281, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    var $12 = HEAP32[$this_idx >> 2] & -2 | $b & 1;
    HEAP32[$this_idx >> 2] = $12;
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN13JSCompartment18updateForDebugModeEP9JSContext($cx_idx_val);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    HEAP32[$this_idx >> 2] = $this_idx_val & -2 | $b & 1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment18updateForDebugModeEP9JSContext($cx_0_11_val) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    __ZN2js18ThreadContextRangeC1EP9JSContext($r, $cx_0_11_val);
    var $r_idx2 = $r | 0;
    var $r_idx2_val = HEAP32[$r_idx2 >> 2];
    var $r_idx3 = $r + 4 | 0;
    var $r_idx3_val = HEAP32[$r_idx3 >> 2];
    var $1 = __ZNK2js18ThreadContextRange5emptyEv($r_idx2_val, $r_idx3_val);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js18ThreadContextRange8popFrontEv($r);
    var $r_idx_val = HEAP32[$r_idx2 >> 2];
    var $r_idx1_val = HEAP32[$r_idx3 >> 2];
    var $2 = __ZNK2js18ThreadContextRange5emptyEv($r_idx_val, $r_idx1_val);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18ThreadContextRangeC1EP9JSContext($this, $cx_0_11_val) {
  __ZN2js18ThreadContextRangeC2EP9JSContext($this, $cx_0_11_val);
  return;
}

function __ZN13JSCompartment11addDebuggeeEP9JSContextPN2js12GlobalObjectE($this, $cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $global;
    var $this_idx = $this + 804 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $2 = $this + 1932 | 0;
    var $3 = __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3putERKS2_($2, $1);
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZNK13JSCompartment9debugModeEv($this_idx_val);
    var $9 = HEAP32[$this_idx >> 2] | 2;
    HEAP32[$this_idx >> 2] = $9;
    if ($7) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN13JSCompartment18updateForDebugModeEP9JSContext($cx_idx_val);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment14removeDebuggeeEP9JSContextPN2js12GlobalObjectEPNS2_6detail9HashTableIKS4_NS2_7HashSetIS4_NS2_13DefaultHasherIS4_EENS2_17SystemAllocPolicyEE6SetOpsESB_E4EnumE($this, $cx, $global, $debuggeesEnum) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $global;
    var $this_idx1 = $this + 804 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $2 = __ZNK13JSCompartment9debugModeEv($this_idx1_val);
    if (($debuggeesEnum | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4Enum11removeFrontEv($debuggeesEnum);
    var $_pre_phi = $this + 1932 | 0;
    __label__ = 4;
    break;
   case 3:
    var $6 = $this + 1932 | 0;
    __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeERKS2_($6, $1);
    var $_pre_phi = $6;
    __label__ = 4;
    break;
   case 4:
    var $_pre_phi;
    var $8 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5emptyEv($_pre_phi);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $11 = HEAP32[$this_idx1 >> 2] & -3;
    HEAP32[$this_idx1 >> 2] = $11;
    if ($2) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $13 = __ZNK13JSCompartment9debugModeEv($11);
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN13JSCompartment18updateForDebugModeEP9JSContext($cx_idx_val);
    __label__ = 8;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment17getBreakpointSiteEPh($this, $pc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 8;
    HEAP32[$1 >> 2] = $pc;
    var $3 = $this + 1956 | 0;
    __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE6lookupERKS1_($p, $3, $1);
    var $p_idx_val = HEAP32[$p >> 2];
    var $p_idx_val_idx_val = HEAP32[$p_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrcvMSE_FvvEEv($2, $p_idx_val_idx_val);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      var $12 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrptEv($p_idx_val);
    var $12 = HEAP32[$8 + 4 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $12;
    STACKTOP = __stackBase__;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js14BreakpointSite7hasTrapEv($this_0_6_val) {
  return ($this_0_6_val | 0) != 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E10overloadedEv($this_0_2_val, $this_0_3_val, $this_0_5_val) {
  return ($this_0_5_val + $this_0_3_val | 0) >>> 0 >= ($this_0_2_val * 192 | 0) >>> 8 >>> 0;
}

function __ZNK7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE5emptyEv($this_0_1_val) {
  return ($this_0_1_val & 1) << 24 >> 24 == 0;
}

function __ZNK2js2gc8FreeSpan7isEmptyEv($this_0_0_val, $this_0_1_val) {
  return $this_0_0_val >>> 0 > $this_0_1_val >>> 0;
}

function __ZN2js2gc8FreeSpan13encodeOffsetsEjj($firstOffset, $lastOffset) {
  return $lastOffset << 16 | $firstOffset;
}

function __ZN7mozilla15AlignedStorage2IN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE4addrEv($this) {
  return $this;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej($this) {
  HEAP32[$this >> 2] = 28;
  HEAP32[$this + 4 >> 2] = 16;
  return;
}

function __ZN2js12HashMapEntryIPhjEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN3WTF20BumpPointerAllocatorC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_($this) {
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC2ES7_($this) {
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  return;
}

function __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEEC2Ev($this) {
  HEAP8[$this + 24 | 0] = 0;
  return;
}

function __ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_($this) {
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_($this) {
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_EC2ESA_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  return;
}

function __ZN2js18ThreadContextRangeC2EP9JSContext($this, $cx_0_11_val) {
  var $1 = $cx_0_11_val + 144140 | 0;
  HEAP32[$this + 4 >> 2] = $1;
  var $4 = HEAP32[$1 >> 2];
  HEAP32[$this >> 2] = $4;
  return;
}

function __ZN2js2gc8FreeSpan11initAsEmptyEj($this) {
  HEAP32[$this >> 2] = 4096;
  HEAP32[$this + 4 >> 2] = 4095;
  return;
}

function __ZN13JSCompartment25getOrCreateBreakpointSiteEP9JSContextP8JSScriptPhP8JSObject($this, $cx, $script, $pc, $scriptObject) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $site = __stackBase__ + 20;
    HEAP32[$1 >> 2] = $pc;
    var $3 = $this + 1956 | 0;
    __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS1_($p, $3, $1);
    var $_idx = $p | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $_idx_val_idx_val = HEAP32[$_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrcvMSE_FvvEEv($2, $_idx_val_idx_val);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_idx1_val = $_idx_val;
      __label__ = 6;
      break;
    }
   case 2:
    var $9 = HEAP32[$cx + 52 >> 2];
    var $10 = HEAP32[$1 >> 2];
    var $11 = __ZN9JSRuntime4new_IN2js14BreakpointSiteEP8JSScriptPhEEPT_T0_T1_($9, $script, $10);
    HEAP32[$site >> 2] = $11;
    if (($11 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S3_EENS7_13MapHashPolicyES6_E6AddPtrERKS1_RKS3_($3, $p, $1, $site);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx1_val = HEAP32[$_idx >> 2];
    __label__ = 6;
    break;
   case 5:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 6:
    var $_idx1_val;
    var $17 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrptEv($_idx1_val);
    var $19 = HEAP32[$17 + 4 >> 2];
    var $20 = $19 + 12 | 0;
    if ((HEAP32[$20 >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = $19;
      __label__ = 8;
      break;
    }
   case 7:
    HEAP32[$20 >> 2] = $scriptObject;
    var $_0 = $19;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E12lookupForAddERKS3_($agg_result, $1, $l);
  return;
}

function __ZN9JSRuntime4new_IN2js14BreakpointSiteEP8JSScriptPhEEPT_T0_T1_($this, $p1, $p2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSRuntime7malloc_EjP9JSContext($this, 40, 0);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js14BreakpointSiteC2EP8JSScriptPh($4, $p1, $p2);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S3_EENS7_13MapHashPolicyES6_E6AddPtrERKS1_RKS3_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrEPPS6_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $7 = HEAP32[$v >> 2];
    var $8 = $5 + 4 | 0;
    HEAP32[$8 >> 2] = $7;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment18clearBreakpointsInEP9JSContextPN2js8DebuggerEP8JSScriptP8JSObject($this, $dbg, $script, $handler) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e = __stackBase__;
    var $1 = $this + 1956 | 0;
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumC1ISB_EERT_($e, $1);
    var $2 = $e | 0;
    var $_idx2 = $e | 0;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $_idx3 = $e + 4 | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($_idx2_val, $_idx3_val);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = ($script | 0) == 0;
    var $5 = ($dbg | 0) == 0;
    var $6 = ($handler | 0) == 0;
    var $_idx4_val = $_idx2_val;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumD1Ev($e);
    STACKTOP = __stackBase__;
    return;
   case 4:
    var $_idx4_val;
    var $8 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5frontEv($_idx4_val);
    var $10 = HEAP32[$8 + 4 >> 2];
    if ($4) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$10 >> 2] | 0) == ($script | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 6:
    var $16 = __ZNK2js14BreakpointSite15firstBreakpointEv($10);
    if (($16 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $bp_01 = $16;
      __label__ = 7;
      break;
    }
   case 7:
    var $bp_01;
    var $bp_01_idx5_val = HEAP32[$bp_01 + 4 >> 2];
    var $bp_01_idx6_val = HEAP32[$bp_01 + 20 >> 2];
    var $18 = __ZN2js10Breakpoint10nextInSiteEv($bp_01_idx5_val, $bp_01_idx6_val);
    if ($5) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((HEAP32[$bp_01 >> 2] | 0) == ($dbg | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (($18 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $bp_01 = $18;
      __label__ = 7;
      break;
    }
   case 10:
    if ($6) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $bp_01_idx_val = HEAP32[$bp_01 + 8 >> 2];
    var $26 = __ZNK2js10Breakpoint10getHandlerEv($bp_01_idx_val);
    if (($26 | 0) == ($handler | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 12:
    __ZN2js10Breakpoint7destroyEP9JSContextPNS_6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS6_S8_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESD_E4EnumE($bp_01, $e);
    __label__ = 9;
    break;
   case 13:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range8popFrontEv($2);
    var $_idx_val = HEAP32[$_idx2 >> 2];
    var $_idx1_val = HEAP32[$_idx3 >> 2];
    var $29 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($_idx_val, $_idx1_val);
    if ($29) {
      __label__ = 3;
      break;
    } else {
      var $_idx4_val = $_idx_val;
      __label__ = 4;
      break;
    }
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN13JSCompartment18clearBreakpointsInEP9JSContextPN2js8DebuggerEP8JSScriptP8JSObject["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumC1ISB_EERT_($this, $map) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumC2ISB_EERT_($this, $map);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumD2Ev($this);
  return;
}

function __ZN13JSCompartment10clearTrapsEP9JSContextP8JSScript($this, $script) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e = __stackBase__;
    var $1 = $this + 1956 | 0;
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumC1ISB_EERT_($e, $1);
    var $2 = $e | 0;
    var $_idx2 = $e | 0;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $_idx3 = $e + 4 | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($_idx2_val, $_idx3_val);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = ($script | 0) == 0;
    var $_idx4_val = $_idx2_val;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumD1Ev($e);
    STACKTOP = __stackBase__;
    return;
   case 4:
    var $_idx4_val;
    var $6 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5frontEv($_idx4_val);
    var $8 = HEAP32[$6 + 4 >> 2];
    if ($4) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$8 >> 2] | 0) == ($script | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js14BreakpointSite9clearTrapEP9JSContextPNS_6detail9HashTableINS_12HashMapEntryIPhPS0_EENS_7HashMapIS6_S7_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESC_E4EnumEPPF12JSTrapStatusS2_P8JSScriptS6_PN2JS5ValueESM_ESN_($8, $e);
    __label__ = 7;
    break;
   case 7:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range8popFrontEv($2);
    var $_idx_val = HEAP32[$_idx2 >> 2];
    var $_idx1_val = HEAP32[$_idx3 >> 2];
    var $15 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($_idx_val, $_idx1_val);
    if ($15) {
      __label__ = 3;
      break;
    } else {
      var $_idx4_val = $_idx_val;
      __label__ = 4;
      break;
    }
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment27markTrapClosuresIterativelyEP8JSTracer($this, $trc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $2 = HEAP32[$trc >> 2];
    var $3 = $this + 1956 | 0;
    __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE3allEv($r, $3);
    var $r_idx6 = $r | 0;
    var $r_idx6_val = HEAP32[$r_idx6 >> 2];
    var $r_idx7 = $r + 4 | 0;
    var $r_idx7_val = HEAP32[$r_idx7 >> 2];
    var $4 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($r_idx6_val, $r_idx7_val);
    if ($4) {
      var $markedAny_0_lcssa = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx3 = $2 + 52 | 0;
    var $markedAny_01 = 0;
    var $r_idx8_val = $r_idx6_val;
    __label__ = 3;
    break;
   case 3:
    var $r_idx8_val;
    var $markedAny_01;
    var $5 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5frontEv($r_idx8_val);
    var $7 = HEAP32[$5 + 4 >> 2];
    if ((HEAP32[$7 + 28 >> 2] | 0) == 0) {
      var $markedAny_2 = $markedAny_01;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = HEAP32[$7 + 12 >> 2];
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = $13;
    var $_idx4_val_idx_val = HEAP32[HEAP32[$_idx3 >> 2] + 144080 >> 2];
    var $17 = __Z20IsAboutToBeFinalizedP9JSContextPKv($_idx4_val_idx_val, $16);
    if ($17) {
      var $markedAny_2 = $markedAny_01;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx = $7 + 32 | 0;
    var $st$1$0 = $_idx | 0;
    var $_idx_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAP32[$st$1$1 >> 2];
    var $19 = __ZNK2JS5Value10isMarkableEv($_idx_val$0, $_idx_val$1);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      var $markedAny_1 = $markedAny_01;
      __label__ = 9;
      break;
    }
   case 7:
    var $21 = __ZNK2JS5Value9toGCThingEv($_idx_val$0, $_idx_val$1);
    var $_idx3_val_idx_val = HEAP32[HEAP32[$_idx3 >> 2] + 144080 >> 2];
    var $22 = __Z20IsAboutToBeFinalizedP9JSContextPKv($_idx3_val_idx_val, $21);
    if ($22) {
      __label__ = 8;
      break;
    } else {
      var $markedAny_1 = $markedAny_01;
      __label__ = 9;
      break;
    }
   case 8:
    var $markedAny_1 = 1;
    __label__ = 9;
    break;
   case 9:
    var $markedAny_1;
    var $st$1$0 = $_idx | 0;
    var $_idx2_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$1$1 >> 2];
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $_idx2_val$0, $_idx2_val$1);
    var $markedAny_2 = $markedAny_1;
    __label__ = 10;
    break;
   case 10:
    var $markedAny_2;
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range8popFrontEv($r);
    var $r_idx_val = HEAP32[$r_idx6 >> 2];
    var $r_idx5_val = HEAP32[$r_idx7 >> 2];
    var $25 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($r_idx_val, $r_idx5_val);
    if ($25) {
      var $markedAny_0_lcssa = $markedAny_2;
      __label__ = 11;
      break;
    } else {
      var $markedAny_01 = $markedAny_2;
      var $r_idx8_val = $r_idx_val;
      __label__ = 3;
      break;
    }
   case 11:
    var $markedAny_0_lcssa;
    STACKTOP = __stackBase__;
    return ($markedAny_0_lcssa & 1) << 24 >> 24 != 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN13JSCompartment27markTrapClosuresIterativelyEP8JSTracer["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_free864($p) {
  _free($p);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumC2ISB_EERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE3allEv($1, $map);
  var $2 = $1;
  var $3 = $this;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  HEAP32[$this + 8 >> 2] = $map | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrEPPS6_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 12 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 8 >> 2];
    var $this_idx1 = $this + 12 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 20 >> 2];
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E12lookupForAddERKS3_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E11prepareHashERKS3_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6lookupERKS3_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6AddPtrC1ERNS0_14HashTableEntryIS6_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6AddPtrC1ERNS0_14HashTableEntryIS6_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6AddPtrC2ERNS0_14HashTableEntryIS6_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6AddPtrC2ERNS0_14HashTableEntryIS6_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrC2ERNS0_14HashTableEntryIS6_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js17SystemAllocPolicy7malloc_Ej(192);
    var $2 = $1;
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $1 + 192 | 0;
    var $e_01 = $2;
    __label__ = 3;
    break;
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $10 = $e_01 + 12 | 0;
    if (($10 | 0) == ($6 | 0)) {
      var $_0 = $2;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $10;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv($0);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPhjEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIPhjEC1Ev($this) {
  __ZN2js12HashMapEntryIPhjEC2Ev($this);
  return;
}

function __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE7destroyEv($this) {
  var $1 = __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE3refEv($this);
  __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev($1);
  HEAP8[$this + 24 | 0] = 0;
  return;
}

function __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE3refEv($this) {
  var $1 = __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE3asTEv($this);
  return $1;
}

function __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_ED1Ev($this_0_5_val) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_ED2Ev($this_0_5_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_ED2Ev($this_0_5_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_5_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($this_0_5_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv($0);
  return;
}

function __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE3asTEv($this) {
  var $1 = $this | 0;
  var $2 = __ZN7mozilla15AlignedStorage2IN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE4addrEv($1);
  return $2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC2IS9_EERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZNK2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3allEv($1, $map);
  var $2 = $1;
  var $3 = $this;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  HEAP32[$this + 8 >> 2] = $map | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3allEv($agg_result, $this) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $_idx1_val = HEAP32[$this + 20 >> 2];
  __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3allEv($agg_result, $_idx_val, $_idx1_val);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3allEv($agg_result, $this_0_1_val, $this_0_5_val) {
  var $1 = $this_0_5_val + $this_0_1_val * 24 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC1EPNS0_14HashTableEntryIS5_EESF_($agg_result, $this_0_5_val, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC1EPNS0_14HashTableEntryIS5_EESF_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC2EPNS0_14HashTableEntryIS5_EESF_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC2EPNS0_14HashTableEntryIS5_EESF_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$4 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isLiveEv($_idx_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 24 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this >> 2];
    var $0 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E11createTableERSA_j($_idx_val, 16);
    HEAP32[$this + 24 >> 2] = $0;
    if (($0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E16setTableSizeLog2Ej($this, 4);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $0 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j();
    HEAP32[$this + 20 >> 2] = $0;
    if (($0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej($this);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN3WTF20BumpPointerAllocatorC1Ev($this) {
  __ZN3WTF20BumpPointerAllocatorC2Ev($this);
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $0 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11createTableERS7_j(16);
    HEAP32[$this + 20 >> 2] = $0;
    if (($0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16setTableSizeLog2Ej($this, 4);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11createTableERS7_j($capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 3;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej($1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + ($capacity << 3) | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 8 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEC2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $0 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j(16);
    HEAP32[$this + 20 >> 2] = $0;
    if (($0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej($this, 4);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13WatchpointMapD1Ev($this) {
  __ZN2js13WatchpointMapD2Ev($this);
  return;
}

function __ZN2js13WatchpointMapD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED1Ev($1);
  return;
}

function __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev($this_0_5_val) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev($this_0_5_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev($this_0_5_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_5_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($this_0_5_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv($0);
  return;
}

function __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 24 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE3asTEv($this);
    __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev($6);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC2ES4_($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_($this);
  return;
}

function __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEEC2ES4_($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC1ES7_($1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC1ES7_($this) {
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC2ES7_($this);
  return;
}

function __ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES5_($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_($1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_($this) {
  __ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_($this);
  return;
}

function __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEEC2ES4_($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_($this);
  return;
}

function __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEEC2ES6_($this, $a_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_EC1ESA_($1, $a_0);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_EC1ESA_($this, $ap_01) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_EC2ESA_($this, $ap_01);
  return;
}

function __ZN2jsL12PodArrayZeroIP8JSObjectLj256EEEvRAT0__T_($t) {
  var $1 = $t;
  _memset($1, 0, 1024, 1);
  return;
}

function __ZNK2js2gc8FreeSpan11arenaHeaderEv($this_0_1_val) {
  var $1 = __ZNK2js2gc8FreeSpan12arenaAddressEv($this_0_1_val);
  return $1;
}

function __ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE($this, $span_0_0_val, $span_0_1_val) {
  var $1 = __ZNK2js2gc8FreeSpan15encodeAsOffsetsEv($span_0_0_val, $span_0_1_val);
  HEAP32[$this + 8 >> 2] = $1;
  return;
}

function __ZNK2js2gc8FreeSpan15encodeAsOffsetsEv($this_0_0_val, $this_0_1_val) {
  var $1 = __ZNK2js2gc8FreeSpan12arenaAddressEv($this_0_1_val);
  var $2 = $this_0_0_val - $1 | 0;
  var $3 = $this_0_1_val & 4095;
  var $4 = __ZN2js2gc8FreeSpan13encodeOffsetsEjj($2, $3);
  return $4;
}

function __ZNK2js2gc8FreeSpan12arenaAddressEv($this_0_1_val) {
  var $1 = __ZNK2js2gc8FreeSpan21arenaAddressUncheckedEv($this_0_1_val);
  return $1;
}

function __ZNK9JSWrapper5flagsEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js2gc8FreeSpan21arenaAddressUncheckedEv($this_0_1_val) {
  return $this_0_1_val & -4096;
}

function _JSVAL_TO_GCTHING_IMPL($l_0$0, $l_0$1) {
  return $l_0$0;
}

function __ZNK2js2gc8FreeSpan7hasNextEv($this_0_1_val) {
  return ($this_0_1_val & 1 | 0) == 0;
}

function __ZNK2js2gc8FreeSpan8nextSpanEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js2gc11ArenaHeader7addressEv($this) {
  return $this;
}

function _JSID_IS_STRING869($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_TO_STRING870($iden) {
  return $iden;
}

function _JSID_TO_INT872($iden) {
  return $iden >> 1;
}

function _JSID_IS_OBJECT873($iden) {
  return ($iden & 7 | 0) == 4 & ($iden | 0) != 4 & 1;
}

function _JSID_TO_OBJECT874($iden) {
  return $iden & -8;
}

function _JSVAL_IS_TRACEABLE_IMPL($l_0$0, $l_0$1) {
  var $2 = $l_0$1;
  return (($2 | 0) == -123 | ($2 | 0) == -121) & 1;
}

function __ZN2js2gc5Chunk11fromAddressEj($addr) {
  return $addr & -1048576;
}

function __ZN2js2gc8FreeSpanC2Ejj($this, $first, $last) {
  HEAP32[$this >> 2] = $first;
  HEAP32[$this + 4 >> 2] = $last;
  return;
}

function __ZN2js2gc5Arena16firstThingOffsetENS0_9AllocKindE($kind) {
  return HEAP32[__ZN2js2gc5Arena17FirstThingOffsetsE + ($kind << 2) >> 2];
}

function __ZNK2js2gc10ArenaLists13getFirstArenaENS0_9AllocKindE($this, $thingKind) {
  return HEAP32[$this + 160 + ($thingKind << 3) >> 2];
}

function __ZN2js18RuntimeAllocPolicyC2EP9JSRuntime($this, $rt) {
  HEAP32[$this >> 2] = $rt;
  return;
}

function __ZN2js9DtoaCacheC2Ev($this) {
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZN2js12PropertyTreeC2EP13JSCompartment($this, $comp) {
  HEAP32[$this >> 2] = $comp;
  return;
}

function __ZN2js2gc10ArenaLists9ArenaList5clearEv($this) {
  var $1 = $this | 0;
  HEAP32[$1 >> 2] = 0;
  HEAP32[$this + 4 >> 2] = $1;
  return;
}

function __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($agg_result, $this) {
  var $1 = __ZNK2js2gc11ArenaHeader12arenaAddressEv($this);
  var $3 = HEAP32[$this + 8 >> 2];
  __ZN2js2gc8FreeSpan13decodeOffsetsEjj($agg_result, $1, $3);
  return;
}

function __ZNK2js2gc11ArenaHeader12arenaAddressEv($this) {
  var $1 = __ZNK2js2gc11ArenaHeader7addressEv($this);
  return $1;
}

function __ZN2js2gc8FreeSpan13decodeOffsetsEjj($agg_result, $arenaAddr, $offsets) {
  var $3 = ($offsets & 65535) + $arenaAddr | 0;
  var $4 = $offsets >>> 16 | $arenaAddr;
  __ZN2js2gc8FreeSpanC1Ejj($agg_result, $3, $4);
  return;
}

function __ZN2js2gc8FreeSpanC1Ejj($this, $first, $last) {
  __ZN2js2gc8FreeSpanC2Ejj($this, $first, $last);
  return;
}

function __ZN2js2gc15CellIterUnderGCC2EP13JSCompartmentNS0_9AllocKindE($this, $comp, $kind) {
  var $1 = $this | 0;
  __ZN2js2gc12CellIterImpl4initEP13JSCompartmentNS0_9AllocKindE($1, $comp, $kind);
  return;
}

function __ZN2js2gc12CellIterImpl4initEP13JSCompartmentNS0_9AllocKindE($this, $comp, $kind) {
  var $1 = __ZN2js2gc5Arena16firstThingOffsetENS0_9AllocKindE($kind);
  HEAP32[$this >> 2] = $1;
  var $3 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($kind);
  HEAP32[$this + 4 >> 2] = $3;
  var $5 = $comp + 8 | 0;
  var $6 = __ZNK2js2gc10ArenaLists13getFirstArenaENS0_9AllocKindE($5, $kind);
  HEAP32[$this + 8 >> 2] = $6;
  var $8 = $this + 12 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($8);
  HEAP32[$this + 20 >> 2] = $8;
  var $11 = HEAP32[$8 >> 2];
  HEAP32[$this + 24 >> 2] = $11;
  __ZN2js2gc12CellIterImpl4nextEv($this);
  return;
}

function __ZN2JSL17ObjectOrNullValueEP8JSObject866($agg_result, $obj) {
  __ZN2JS5Value15setObjectOrNullEP8JSObject($agg_result, $obj);
  return;
}

function __ZN2JSL10Int32ValueEi871($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZN2JSL14UndefinedValueEv875($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2js2gc10ArenaListsD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i_01 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_01;
    var $2 = $this + 160 + ($i_01 << 3) | 0;
    var $3 = HEAP32[$2 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $5 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $5;
    var $7 = HEAP32[$5 + 4 >> 2];
    HEAP32[$2 >> 2] = $7;
    var $8 = __ZNK2js2gc11ArenaHeader5chunkEv($5);
    __ZN2js2gc5Chunk12releaseArenaEPNS0_11ArenaHeaderE($8, $5);
    var $9 = HEAP32[$2 >> 2];
    if (($9 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $5 = $9;
      __label__ = 3;
      break;
    }
   case 4:
    var $11 = $i_01 + 1 | 0;
    if (($11 | 0) == 20) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = $11;
      __label__ = 2;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js2gc11ArenaHeader5chunkEv($this) {
  var $1 = __ZNK2js2gc11ArenaHeader7addressEv($this);
  var $2 = __ZN2js2gc5Chunk11fromAddressEj($1);
  return $2;
}

function __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev($this_0_5_val) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev($this_0_5_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev($this_0_5_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_5_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj($this_0_5_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  __ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev($this_0_5_val) {
  __ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev($this_0_5_val);
  return;
}

function __ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev($this_0_5_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_5_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($this_0_5_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv($0);
  return;
}

function __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED1Ev($this_0_5_val) {
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED2Ev($this_0_5_val);
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED2Ev($this_0_5_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_5_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12destroyTableERS7_PNS0_14HashTableEntryIS4_EEj($this_0_5_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12destroyTableERS7_PNS0_14HashTableEntryIS4_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv($0);
  return;
}

function __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev($this_0_5_val) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev($this_0_5_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev($this_0_5_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_5_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($this_0_5_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 24 >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_ED1Ev($this_0_6_val) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_ED2Ev($this_0_6_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_ED2Ev($this_0_6_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_6_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E12destroyTableERSA_PNS0_14HashTableEntryIS6_EEj($this_0_6_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15NativeIterCacheC2Ev($this) {
  HEAP32[$this + 1024 >> 2] = 0;
  var $2 = $this | 0;
  __ZN2jsL12PodArrayZeroIP8JSObjectLj256EEEvRAT0__T_($2);
  return;
}

function __ZN2js2gc10ArenaListsC2Ev($this) {
  var $1 = $this + 160 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($1);
  var $2 = $this + 168 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($2);
  var $3 = $this + 176 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($3);
  var $4 = $this + 184 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($4);
  var $5 = $this + 192 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($5);
  var $6 = $this + 200 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($6);
  var $7 = $this + 208 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($7);
  var $8 = $this + 216 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($8);
  var $9 = $this + 224 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($9);
  var $10 = $this + 232 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($10);
  var $11 = $this + 240 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($11);
  var $12 = $this + 248 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($12);
  var $13 = $this + 256 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($13);
  var $14 = $this + 264 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($14);
  var $15 = $this + 272 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($15);
  var $16 = $this + 280 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($16);
  var $17 = $this + 288 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($17);
  var $18 = $this + 296 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($18);
  var $19 = $this + 304 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($19);
  var $20 = $this + 312 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($20);
  var $21 = $this | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($21);
  var $22 = $this + 8 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($22);
  var $23 = $this + 16 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($23);
  var $24 = $this + 24 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($24);
  var $25 = $this + 32 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($25);
  var $26 = $this + 40 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($26);
  var $27 = $this + 48 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($27);
  var $28 = $this + 56 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($28);
  var $29 = $this + 64 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($29);
  var $30 = $this + 72 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($30);
  var $31 = $this + 80 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($31);
  var $32 = $this + 88 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($32);
  var $33 = $this + 96 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($33);
  var $34 = $this + 104 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($34);
  var $35 = $this + 112 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($35);
  var $36 = $this + 120 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($36);
  var $37 = $this + 128 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($37);
  var $38 = $this + 136 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($38);
  var $39 = $this + 144 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($39);
  var $40 = $this + 152 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($40);
  return;
}

__ZN2js2gc10ArenaListsC2Ev["X"] = 1;

function __ZN2js2gc10ArenaLists9ArenaListC1Ev($this) {
  __ZN2js2gc10ArenaLists9ArenaListC2Ev($this);
  return;
}

function __ZN2js2gc10ArenaLists9ArenaListC2Ev($this) {
  __ZN2js2gc10ArenaLists9ArenaList5clearEv($this);
  return;
}

function __ZN2js5crash5StackC2Ey($this, $id$0, $id$1) {
  var $1 = $this | 0;
  __ZN2js5crash10CrashStackC2Ey($1, $id$0, $id$1);
  return;
}

function __ZN2js5crash10CrashStackC2Ey($this, $id$0, $id$1) {
  var $1 = $this | 0;
  __ZN2js5crash11CrashHeaderC1Ey($1, $id$0, $id$1);
  return;
}

function __ZN2js5crash4RingC2Ey($this, $id$0, $id$1) {
  var $1 = $this | 0;
  __ZN2js5crash9CrashRingC2Ey($1, $id$0, $id$1);
  return;
}

function __ZN2js5crash9CrashRingC2Ey($this, $id$0, $id$1) {
  var $1 = $this | 0;
  __ZN2js5crash11CrashHeaderC1Ey($1, $id$0, $id$1);
  var $3 = $this + 24 | 0;
  for (var $$dest = $3 >> 2, $$stop = $$dest + 8194; $$dest < $$stop; $$dest++) {
    HEAP32[$$dest] = 0;
  }
  return;
}

function ___cxx_global_var_init888() {
  __ZN2js5crash5StackC2Ey(__ZN2js5crashL8gGCStackE, 1024, 0);
  return;
}

function ___cxx_global_var_init1889() {
  __ZN2js5crash5StackC2Ey(__ZN2js5crashL11gErrorStackE, 1025, 0);
  return;
}

function ___cxx_global_var_init2890() {
  __ZN2js5crash4RingC2Ey(__ZN2js5crashL11gRingBufferE, 2048, 0);
  return;
}

function __ZN2js5crash11CrashHeaderC1Ey($this, $id$0, $id$1) {
  __ZN2js5crash11CrashHeaderC2Ey($this, $id$0, $id$1);
  return;
}

function __ZN2js5crash11CrashHeaderC2Ey($this, $id$0, $id$1) {
  var $1 = $this + 16 | 0;
  HEAP32[$1 >> 2] = $id$0;
  HEAP32[$1 + 4 >> 2] = $id$1;
  var $2 = $this | 0;
  for (var $$src = STRING_TABLE.__ZN2js5crashL12crash_cookieE | 0, $$dest = $2, $$stop = $$src + 16; $$src < $$stop; $$src++, $$dest++) {
    HEAP8[$$dest] = HEAP8[$$src];
  }
  return;
}

function __GLOBAL__I_a891() {
  ___cxx_global_var_init888();
  ___cxx_global_var_init1889();
  ___cxx_global_var_init2890();
  return;
}

function __ZL12date_convertP9JSContextP8JSObject6JSTypePN2JS5ValueE($cx, $obj, $hint, $vp) {
  var $2 = ($hint | 0) == 0 ? 3 : $hint;
  var $3 = $cx;
  var $4 = $obj;
  var $5 = __ZN2js12DefaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE($3, $4, $2, $vp);
  return $5;
}

function __ZL8date_UTCP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $msec_time = __stackBase__;
    var $1 = $vp + 16 | 0;
    var $2 = __ZL17date_msecFromArgsP9JSContextjPN2JS5ValueEPd($cx, $argc, $1, $msec_time);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = (tempDoubleI32[0] = HEAP32[$msec_time >> 2], tempDoubleI32[1] = HEAP32[$msec_time + 4 >> 2], tempDoubleF64[0]);
    var $6 = __ZL18JSDOUBLE_IS_FINITEd1004($5);
    if (($6 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($5 < 0) {
      __label__ = 4;
      break;
    } else {
      var $13 = $5;
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = -$5;
    __label__ = 5;
    break;
   case 5:
    var $13;
    if ($13 > 864e13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = $5;
    var $17 = __ZL18js_DoubleToIntegerd1005($16);
    var $21 = $17;
    __label__ = 8;
    break;
   case 7:
    var $19 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $21 = $19;
    __label__ = 8;
    break;
   case 8:
    var $21;
    tempDoubleF64[0] = $21, HEAP32[$msec_time >> 2] = tempDoubleI32[0], HEAP32[$msec_time + 4 >> 2] = tempDoubleI32[1];
    var $22 = __ZN2JS5Value9setNumberEd($vp, $21);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10date_parseP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $_idx = $5 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $7 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($6, $_idx_val$0, $_idx_val$1);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value9setStringEP8JSString($5, $7);
    var $10 = $cx;
    var $11 = __ZN8JSString12ensureLinearEP9JSContext($7, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = __ZL16date_parseStringP14JSLinearStringPdP9JSContext($11, $result, $cx);
    if (($14 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $17 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $17);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 7:
    var $19 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $20 = __ZL18JSDOUBLE_IS_FINITEd1004($19);
    if (($20 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($19 < 0) {
      __label__ = 9;
      break;
    } else {
      var $27 = $19;
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = -$19;
    __label__ = 10;
    break;
   case 10:
    var $27;
    if ($27 > 864e13) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $30 = $19;
    var $31 = __ZL18js_DoubleToIntegerd1005($30);
    var $35 = $31;
    __label__ = 13;
    break;
   case 12:
    var $33 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $35 = $33;
    __label__ = 13;
    break;
   case 13:
    var $35;
    tempDoubleF64[0] = $35, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $36 = __ZN2JS5Value9setNumberEd($vp, $35);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8date_nowP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL11NowAsMillisv();
  __ZN2JS5Value9setDoubleEd($vp, $1);
  return 1;
}

function __ZL12date_getTimeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $result);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZN2JS5Value9setNumberEd($vp, $3);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL22date_getTimezoneOffsetP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $utctime = __stackBase__;
    var $localtime = __stackBase__ + 8;
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZL10GetUTCTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $4, $vp, $utctime);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $4, 0, $localtime);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = (tempDoubleI32[0] = HEAP32[$utctime >> 2], tempDoubleI32[1] = HEAP32[$utctime + 4 >> 2], tempDoubleF64[0]);
    var $14 = (tempDoubleI32[0] = HEAP32[$localtime >> 2], tempDoubleI32[1] = HEAP32[$localtime + 4 >> 2], tempDoubleF64[0]);
    var $16 = ($13 - $14) / 6e4;
    var $17 = __ZN2JS5Value9setNumberEd($vp, $16);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12date_getYearP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $6, $vp, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK8JSObject7getSlotEj($3, 2);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = __ZNK2JS5Value7isInt32Ev($12$0, $12$1);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = __ZNK2JS5Value7toInt32Ev($12$0, $12$1);
    var $16 = $15 - 1900 | 0;
    __ZN2JS5Value8setInt32Ei($vp, $16);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $18 = $vp | 0;
    HEAP32[$18 >> 2] = $12$0;
    HEAP32[$18 + 4 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16date_getFullYearP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $6, $vp, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK8JSObject7getSlotEj($3, 2);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $vp | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19date_getUTCFullYearP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $result);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZL18JSDOUBLE_IS_FINITEd1004($3);
    if (($4 | 0) == 0) {
      var $10 = $3;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZL12YearFromTimed($3);
    var $8 = $7 | 0;
    tempDoubleF64[0] = $8, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    var $11 = __ZN2JS5Value9setNumberEd($vp, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13date_getMonthP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $6, $vp, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK8JSObject7getSlotEj($3, 3);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $vp | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16date_getUTCMonthP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $result);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZL18JSDOUBLE_IS_FINITEd1004($3);
    if (($4 | 0) == 0) {
      var $10 = $3;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZL13MonthFromTimed($3);
    var $8 = $7 | 0;
    tempDoubleF64[0] = $8, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    var $11 = __ZN2JS5Value9setNumberEd($vp, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12date_getDateP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $6, $vp, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK8JSObject7getSlotEj($3, 4);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $vp | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15date_getUTCDateP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $result);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZL18JSDOUBLE_IS_FINITEd1004($3);
    if (($4 | 0) == 0) {
      var $10 = $3;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZL12DateFromTimed($3);
    var $8 = $7 | 0;
    tempDoubleF64[0] = $8, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    var $11 = __ZN2JS5Value9setNumberEd($vp, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11date_getDayP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $6, $vp, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK8JSObject7getSlotEj($3, 5);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $vp | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14date_getUTCDayP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $result);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZL18JSDOUBLE_IS_FINITEd1004($3);
    if (($4 | 0) == 0) {
      var $10 = $3;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZL7WeekDayd($3);
    var $8 = $7 | 0;
    tempDoubleF64[0] = $8, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    var $11 = __ZN2JS5Value9setNumberEd($vp, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13date_getHoursP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $6, $vp, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK8JSObject7getSlotEj($3, 6);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $vp | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16date_getUTCHoursP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $result);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZL18JSDOUBLE_IS_FINITEd1004($3);
    if (($4 | 0) == 0) {
      var $10 = $3;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZL12HourFromTimed($3);
    var $8 = $7 | 0;
    tempDoubleF64[0] = $8, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    var $11 = __ZN2JS5Value9setNumberEd($vp, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15date_getMinutesP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $6, $vp, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK8JSObject7getSlotEj($3, 7);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $vp | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18date_getUTCMinutesP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $result);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZL18JSDOUBLE_IS_FINITEd1004($3);
    if (($4 | 0) == 0) {
      var $10 = $3;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZL11MinFromTimed($3);
    var $8 = $7 | 0;
    tempDoubleF64[0] = $8, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    var $11 = __ZN2JS5Value9setNumberEd($vp, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18JSDOUBLE_IS_FINITEd1004($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function __ZL18date_getUTCSecondsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $6, $vp, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK8JSObject7getSlotEj($3, 8);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $vp | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23date_getUTCMillisecondsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $result);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZL18JSDOUBLE_IS_FINITEd1004($3);
    if (($4 | 0) == 0) {
      var $10 = $3;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZL10msFromTimed($3);
    var $8 = $7 | 0;
    tempDoubleF64[0] = $8, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    var $11 = __ZN2JS5Value9setNumberEd($vp, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12date_setTimeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $7 = __ZNK8JSObject6isDateEv($_idx_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($2, $vp, __ZN2js9DateClassE);
    var $_0 = 0;
    __label__ = 14;
    break;
   case 4:
    if (($argc | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZL12SetDateToNaNP9JSContextP8JSObjectPN2JS5ValueE($cx_idx_val, $4, $vp);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 6:
    var $13 = $vp + 16 | 0;
    var $14 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($2, $13, $result);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 7:
    var $16 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $17 = __ZL18JSDOUBLE_IS_FINITEd1004($16);
    if (($17 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($16 < 0) {
      __label__ = 9;
      break;
    } else {
      var $24 = $16;
      __label__ = 10;
      break;
    }
   case 9:
    var $24 = -$16;
    __label__ = 10;
    break;
   case 10:
    var $24;
    if ($24 > 864e13) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $27 = $16;
    var $28 = __ZL18js_DoubleToIntegerd1005($27);
    var $32 = $28;
    __label__ = 13;
    break;
   case 12:
    var $30 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $32 = $30;
    __label__ = 13;
    break;
   case 13:
    var $32;
    __ZL10SetUTCTimeP9JSContextP8JSObjectdPN2JS5ValueE($4, $32, $vp);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12date_setYearP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $year = __stackBase__ + 8;
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZL10GetUTCTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $4, $vp, $result);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($argc | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $cx_idx1_val = HEAP32[$cx + 52 >> 2];
    __ZL12SetDateToNaNP9JSContextP8JSObjectPN2JS5ValueE($cx_idx1_val, $4, $vp);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 5:
    var $13 = $vp + 16 | 0;
    var $14 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($2, $13, $year);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 6:
    var $16 = (tempDoubleI32[0] = HEAP32[$year >> 2], tempDoubleI32[1] = HEAP32[$year + 4 >> 2], tempDoubleF64[0]);
    var $17 = __ZL18JSDOUBLE_IS_FINITEd1004($16);
    if (($17 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZL12SetDateToNaNP9JSContextP8JSObjectPN2JS5ValueE($cx_idx_val, $4, $vp);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 8:
    var $21 = __ZL18js_DoubleToIntegerd1005($16);
    if ($21 >= 0 & $21 <= 99) {
      __label__ = 9;
      break;
    } else {
      var $27 = $21;
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = $21 + 1900;
    __label__ = 10;
    break;
   case 10:
    var $27;
    tempDoubleF64[0] = $27, HEAP32[$year >> 2] = tempDoubleI32[0], HEAP32[$year + 4 >> 2] = tempDoubleI32[1];
    var $28 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $29 = __ZL18JSDOUBLE_IS_FINITEd1004($28);
    if (($29 | 0) == 0) {
      var $34 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $32 = __ZL9LocalTimedP9JSContext($28, $cx);
    var $34 = $32;
    __label__ = 12;
    break;
   case 12:
    var $34;
    var $35 = __ZL13MonthFromTimed($34);
    var $36 = $35 | 0;
    var $37 = __ZL12DateFromTimed($34);
    var $38 = $37 | 0;
    var $39 = __ZL7MakeDayddd($27, $36, $38);
    var $40 = $39 * 864e5;
    var $41 = __ZL13TimeWithinDayd($34);
    var $42 = $40 + $41;
    var $43 = __ZL3UTCdP9JSContext($42, $cx);
    tempDoubleF64[0] = $43, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $44 = __ZL18JSDOUBLE_IS_FINITEd1004($43);
    if (($44 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if ($43 < 0) {
      __label__ = 14;
      break;
    } else {
      var $51 = $43;
      __label__ = 15;
      break;
    }
   case 14:
    var $51 = -$43;
    __label__ = 15;
    break;
   case 15:
    var $51;
    if ($51 > 864e13) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $54 = $43;
    var $55 = __ZL18js_DoubleToIntegerd1005($54);
    var $59 = $55;
    __label__ = 18;
    break;
   case 17:
    var $57 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $59 = $57;
    __label__ = 18;
    break;
   case 18:
    var $59;
    __ZL10SetUTCTimeP9JSContextP8JSObjectdPN2JS5ValueE($4, $59, $vp);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12date_setYearP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL16date_setFullYearP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeDateP9JSContextjijPN2JS5ValueE($cx, 3, 1, $argc, $vp);
  return $1;
}

function __ZL19date_setUTCFullYearP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeDateP9JSContextjijPN2JS5ValueE($cx, 3, 0, $argc, $vp);
  return $1;
}

function __ZL13date_setMonthP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeDateP9JSContextjijPN2JS5ValueE($cx, 2, 1, $argc, $vp);
  return $1;
}

function __ZL16date_setUTCMonthP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeDateP9JSContextjijPN2JS5ValueE($cx, 2, 0, $argc, $vp);
  return $1;
}

function __ZL12date_setDateP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeDateP9JSContextjijPN2JS5ValueE($cx, 1, 1, $argc, $vp);
  return $1;
}

function __ZL15date_setUTCDateP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeDateP9JSContextjijPN2JS5ValueE($cx, 1, 0, $argc, $vp);
  return $1;
}

function __ZL13date_setHoursP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeTimeP9JSContextjijPN2JS5ValueE($cx, 4, 1, $argc, $vp);
  return $1;
}

function __ZL16date_setUTCHoursP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeTimeP9JSContextjijPN2JS5ValueE($cx, 4, 0, $argc, $vp);
  return $1;
}

function __ZL15date_setMinutesP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeTimeP9JSContextjijPN2JS5ValueE($cx, 3, 1, $argc, $vp);
  return $1;
}

function __ZL18date_setUTCMinutesP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeTimeP9JSContextjijPN2JS5ValueE($cx, 3, 0, $argc, $vp);
  return $1;
}

function __ZL15date_setSecondsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeTimeP9JSContextjijPN2JS5ValueE($cx, 2, 1, $argc, $vp);
  return $1;
}

function __ZL18date_setUTCSecondsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeTimeP9JSContextjijPN2JS5ValueE($cx, 2, 0, $argc, $vp);
  return $1;
}

function __ZL20date_setMillisecondsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeTimeP9JSContextjijPN2JS5ValueE($cx, 1, 1, $argc, $vp);
  return $1;
}

function __ZL23date_setUTCMillisecondsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeTimeP9JSContextjijPN2JS5ValueE($cx, 1, 0, $argc, $vp);
  return $1;
}

function __ZL16date_toGMTStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL15date_utc_formatP9JSContextPN2JS5ValueEPFvPcjdE($cx, $vp, 80);
  return $1;
}

function __ZL19date_toLocaleStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL19date_toLocaleHelperP9JSContextP8JSObjectPKcPN2JS5ValueE($cx, $6, STRING_TABLE.__str1462819 | 0, $vp);
    var $_0 = $7;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23date_toLocaleDateStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL19date_toLocaleHelperP9JSContextP8JSObjectPKcPN2JS5ValueE($cx, $6, STRING_TABLE.__str104998 | 0, $vp);
    var $_0 = $7;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23date_toLocaleTimeStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL19date_toLocaleHelperP9JSContextP8JSObjectPKcPN2JS5ValueE($cx, $6, STRING_TABLE.__str1061000 | 0, $vp);
    var $_0 = $7;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19date_toLocaleFormatP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fmtbytes = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZL19date_toLocaleStringP9JSContextjPN2JS5ValueE($cx, 0, $vp);
    var $_1 = $3;
    __label__ = 8;
    break;
   case 3:
    var $5 = $vp + 8 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($6, $5);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_1 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $vp + 16 | 0;
    var $12 = $cx;
    var $_idx = $11 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $13 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($12, $_idx_val$0, $_idx_val$1);
    if (($13 | 0) == 0) {
      var $_1 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JS5Value9setStringEP8JSString($11, $13);
    __ZN16JSAutoByteStringC1EP9JSContextP8JSString($fmtbytes, $cx, $13);
    var $fmtbytes_idx2_val = HEAP32[$fmtbytes >> 2];
    var $16 = __ZNK16JSAutoByteStringntEv($fmtbytes_idx2_val);
    if ($16) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = __ZNK16JSAutoByteString3ptrEv($fmtbytes_idx2_val);
    var $19 = __ZL19date_toLocaleHelperP9JSContextP8JSObjectPKcPN2JS5ValueE($cx, $8, $18, $vp);
    var $_0 = $19;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    __ZN16JSAutoByteStringD1Ev($fmtbytes_idx2_val);
    var $_1 = $_0;
    __label__ = 8;
    break;
   case 8:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17date_toDateStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $utctime = __stackBase__;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $utctime);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$utctime >> 2], tempDoubleI32[1] = HEAP32[$utctime + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZL11date_formatP9JSContextd10formatspecPN2JS5ValueE($cx, $3, 1, $vp);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17date_toTimeStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $utctime = __stackBase__;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $utctime);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$utctime >> 2], tempDoubleI32[1] = HEAP32[$utctime + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZL11date_formatP9JSContextd10formatspecPN2JS5ValueE($cx, $3, 2, $vp);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16date_toISOStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL15date_utc_formatP9JSContextPN2JS5ValueEPFvPcjdE($cx, $vp, 82);
  return $1;
}

function __ZL11date_toJSONP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tv = __stackBase__;
    var $args = __stackBase__ + 8;
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    __ZN2JSL11ObjectValueER8JSObject1038($tv, $6);
    var $7 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE($cx, $tv);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 0;
      __label__ = 13;
      break;
    }
   case 3:
    var $tv_idx = $tv | 0;
    var $st$1$0 = $tv_idx | 0;
    var $tv_idx_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $tv_idx + 4 | 0;
    var $tv_idx_val$1 = HEAP32[$st$1$1 >> 2];
    var $9 = __ZNK2JS5Value8isDoubleEv($tv_idx_val$0, $tv_idx_val$1);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $11 = __ZNK2JS5Value8toDoubleEv($tv);
    var $12 = __ZL18JSDOUBLE_IS_FINITEd1004($11);
    if (($12 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2JS5Value7setNullEv($vp);
    var $_1 = 1;
    __label__ = 13;
    break;
   case 6:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210240 >> 2];
    var $21 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($3, $2, $20, $vp);
    if (($21 | 0) == 0) {
      var $_1 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $vp_idx = $vp | 0;
    var $st$1$0 = $vp_idx | 0;
    var $vp_idx_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $vp_idx + 4 | 0;
    var $vp_idx_val$1 = HEAP32[$st$1$1 >> 2];
    var $24 = __ZL13js_IsCallableRKN2JS5ValueE1052($vp_idx_val$0, $vp_idx_val$1);
    if ($24) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $26 = _JS_ReportErrorFlagsAndNumber($2, 0, 253, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 13;
    break;
   case 9:
    var $28 = $args;
    __ZN2js15InvokeArgsGuardC1Ev($28);
    var $30 = $cx + 60 | 0;
    var $31 = $cx;
    var $32 = $args;
    var $33 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($30, $31, 0, $32);
    if ($33) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 10:
    var $_idx = $args | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $35 = __ZNK2js12CallReceiver7calleevEv($_idx_val);
    var $st$3$0 = $vp_idx | 0;
    var $36$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $vp_idx + 4 | 0;
    var $36$1 = HEAP32[$st$3$1 >> 2];
    var $37 = $35 | 0;
    var $st$8$0 = $37 | 0;
    HEAP32[$st$8$0 >> 2] = $36$0;
    var $st$8$1 = $37 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $36$1;
    var $_idx1_val = HEAP32[$_idx >> 2];
    var $38 = __ZNK2js12CallReceiver5thisvEv($_idx1_val);
    __ZN2JS5Value9setObjectER8JSObject($38, $3);
    var $39 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($2, $28, 0);
    if ($39) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 11:
    var $_idx2_val = HEAP32[$_idx >> 2];
    var $41 = __ZNK2js12CallReceiver4rvalEv($_idx2_val);
    var $42 = $41 | 0;
    var $st$3$0 = $42 | 0;
    var $43$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $42 + 4 | 0;
    var $43$1 = HEAP32[$st$3$1 >> 2];
    HEAP32[$vp_idx >> 2] = $43$0;
    HEAP32[$vp_idx + 4 >> 2] = $43$1;
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    __ZN2js15InvokeArgsGuardD1Ev($28);
    var $_1 = $_0;
    __label__ = 13;
    break;
   case 13:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11date_toJSONP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL13date_toSourceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $utctime = __stackBase__;
    var $cbuf = __stackBase__ + 8;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $utctime);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    __ZN2js12ToCStringBufC2Ev($cbuf);
    var $3 = (tempDoubleI32[0] = HEAP32[$utctime >> 2], tempDoubleI32[1] = HEAP32[$utctime + 4 >> 2], tempDoubleF64[0]);
    var $4 = $cx;
    var $5 = __ZN2js15NumberToCStringEP9JSContextPNS_12ToCStringBufEdi($4, $cbuf, $3);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportOutOfMemory($4);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 4:
    var $9 = _JS_smprintf(STRING_TABLE.__str122090 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = STRING_TABLE._js_Date_str | 0, HEAP32[tempInt + 4 >> 2] = $5, tempInt));
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    _JS_ReportOutOfMemory($4);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 6:
    var $13 = _JS_NewStringCopyZ($4, $9);
    __ZN9JSContext5free_EPv($9);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JS5Value9setStringEP8JSString($vp, $13);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    var $cbuf_idx_val = HEAP32[$cbuf + 36 >> 2];
    __ZN2js12ToCStringBufD2Ev($cbuf_idx_val);
    var $_1 = $_0;
    __label__ = 9;
    break;
   case 9:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13date_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $utctime = __stackBase__;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $utctime);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$utctime >> 2], tempDoubleI32[1] = HEAP32[$utctime + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZL11date_formatP9JSContextd10formatspecPN2JS5ValueE($cx, $3, 0, $vp);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12date_valueOfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZL12date_getTimeP9JSContextjPN2JS5ValueE($cx, 0, $vp);
    var $_0 = $3;
    __label__ = 9;
    break;
   case 3:
    var $5 = $vp + 8 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($6, $5);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $cx;
    var $_idx = $vp + 16 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $11 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($10, $_idx_val$0, $_idx_val$1);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = __ZN8JSString12ensureLinearEP9JSContext($11, $6);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = HEAP32[HEAP32[$cx + 52 >> 2] + 21e4 >> 2] | 0;
    var $22 = __ZN2js12EqualStringsEP14JSLinearStringS1_($14, $21);
    if ($22) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $24 = __ZL12date_getTimeP9JSContextjPN2JS5ValueE($cx, $argc, $vp);
    var $_0 = $24;
    __label__ = 9;
    break;
   case 8:
    var $26 = __ZL13date_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp);
    var $_0 = $26;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z7js_DateP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $msec_time = __stackBase__ + 8;
    var $1 = __ZN2jsL14IsConstructingEPKN2JS5ValueE1003($vp);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL11NowAsMillisv();
    var $4 = __ZL11date_formatP9JSContextd10formatspecPN2JS5ValueE($cx, $3, 0, $vp);
    var $_0 = $4;
    __label__ = 37;
    break;
   case 3:
    var $6 = $vp + 16 | 0;
    if (($argc | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($argc | 0) == 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 4:
    var $8 = __ZL11NowAsMillisv();
    tempDoubleF64[0] = $8, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $91 = $8;
    __label__ = 35;
    break;
   case 5:
    var $_idx = $6 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $10 = __ZNK2JS5Value8isStringEv($_idx_val$0, $_idx_val$1);
    if ($10) {
      __label__ = 14;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $12 = $cx;
    var $13 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($12, $6, $d);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 37;
      break;
    }
   case 7:
    var $15 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $16 = __ZL18JSDOUBLE_IS_FINITEd1004($15);
    if (($16 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($15 < 0) {
      __label__ = 9;
      break;
    } else {
      var $23 = $15;
      __label__ = 10;
      break;
    }
   case 9:
    var $23 = -$15;
    __label__ = 10;
    break;
   case 10:
    var $23;
    if ($23 > 864e13) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = $15;
    var $27 = __ZL18js_DoubleToIntegerd1005($26);
    var $31 = $27;
    __label__ = 13;
    break;
   case 12:
    var $29 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $31 = $29;
    __label__ = 13;
    break;
   case 13:
    var $31;
    tempDoubleF64[0] = $31, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $91 = $31;
    __label__ = 35;
    break;
   case 14:
    var $33 = $cx;
    var $34 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($33, $_idx_val$0, $_idx_val$1);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    __ZN2JS5Value9setStringEP8JSString($6, $34);
    var $37 = $cx;
    var $38 = __ZN8JSString12ensureLinearEP9JSContext($34, $37);
    if (($38 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $41 = __ZL16date_parseStringP14JSLinearStringPdP9JSContext($38, $d, $cx);
    if (($41 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $44 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $44, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $91 = $44;
    __label__ = 35;
    break;
   case 18:
    var $46 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $47 = __ZL18JSDOUBLE_IS_FINITEd1004($46);
    if (($47 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    if ($46 < 0) {
      __label__ = 20;
      break;
    } else {
      var $54 = $46;
      __label__ = 21;
      break;
    }
   case 20:
    var $54 = -$46;
    __label__ = 21;
    break;
   case 21:
    var $54;
    if ($54 > 864e13) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $57 = $46;
    var $58 = __ZL18js_DoubleToIntegerd1005($57);
    var $62 = $58;
    __label__ = 24;
    break;
   case 23:
    var $60 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $62 = $60;
    __label__ = 24;
    break;
   case 24:
    var $62;
    tempDoubleF64[0] = $62, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $91 = $62;
    __label__ = 35;
    break;
   case 25:
    var $64 = __ZL17date_msecFromArgsP9JSContextjPN2JS5ValueEPd($cx, $argc, $6, $msec_time);
    if (($64 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $67 = (tempDoubleI32[0] = HEAP32[$msec_time >> 2], tempDoubleI32[1] = HEAP32[$msec_time + 4 >> 2], tempDoubleF64[0]);
    var $68 = __ZL18JSDOUBLE_IS_FINITEd1004($67);
    if (($68 | 0) == 0) {
      var $89 = $67;
      __label__ = 34;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $71 = __ZL3UTCdP9JSContext($67, $cx);
    tempDoubleF64[0] = $71, HEAP32[$msec_time >> 2] = tempDoubleI32[0], HEAP32[$msec_time + 4 >> 2] = tempDoubleI32[1];
    var $72 = __ZL18JSDOUBLE_IS_FINITEd1004($71);
    if (($72 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    if ($71 < 0) {
      __label__ = 29;
      break;
    } else {
      var $79 = $71;
      __label__ = 30;
      break;
    }
   case 29:
    var $79 = -$71;
    __label__ = 30;
    break;
   case 30:
    var $79;
    if ($79 > 864e13) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $82 = $71;
    var $83 = __ZL18js_DoubleToIntegerd1005($82);
    var $87 = $83;
    __label__ = 33;
    break;
   case 32:
    var $85 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $87 = $85;
    __label__ = 33;
    break;
   case 33:
    var $87;
    tempDoubleF64[0] = $87, HEAP32[$msec_time >> 2] = tempDoubleI32[0], HEAP32[$msec_time + 4 >> 2] = tempDoubleI32[1];
    var $89 = $87;
    __label__ = 34;
    break;
   case 34:
    var $89;
    tempDoubleF64[0] = $89, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $91 = $89;
    __label__ = 35;
    break;
   case 35:
    var $91;
    var $92 = __Z20js_NewDateObjectMsecP9JSContextd($cx, $91);
    if (($92 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $95 = $92;
    __ZN2JS5Value9setObjectER8JSObject($vp, $95);
    var $_0 = 1;
    __label__ = 37;
    break;
   case 37:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z7js_DateP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2jsL14IsConstructingEPKN2JS5ValueE1003($vp) {
  var $_idx = $vp + 8 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $1 = __ZNK2JS5Value7isMagicEv($_idx_val$0, $_idx_val$1);
  return $1;
}

function __ZL11date_formatP9JSContextd10formatspecPN2JS5ValueE($cx, $date, $format, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 220;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $buf = __stackBase__;
    var $tzbuf = __stackBase__ + 100;
    var $split = __stackBase__ + 200;
    var $1 = __ZL18JSDOUBLE_IS_FINITEd1004($date);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $buf | 0;
    var $5 = _JS_snprintf($4, 100, STRING_TABLE.__ZL15js_NaN_date_str | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_pre_phi = $4;
    __label__ = 19;
    break;
   case 3:
    var $7 = __ZL9LocalTimedP9JSContext($date, $cx);
    var $8 = __ZL10AdjustTimedP9JSContext($date, $cx);
    var $9 = $8 / 6e4;
    var $10 = _floor($9);
    var $11 = $10 & -1;
    var $15 = (($11 | 0) / 60 & -1) * 100 + $11 % 60 | 0;
    __ZL11new_explodedP8PRMJTimeP9JSContext($date, $split, $cx);
    var $16 = $tzbuf | 0;
    var $17 = _PRMJ_FormatTime($16, STRING_TABLE.__str77971 | 0, $split);
    if (($17 | 0) == 0) {
      var $usetz_3 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $20 = _strlen($16);
    if ($20 >>> 0 > 100) {
      var $usetz_2 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($20 | 0) == 0) {
      var $usetz_2 = 1;
      __label__ = 11;
      break;
    } else {
      var $usetz_03 = 1;
      var $i_04 = 0;
      __label__ = 6;
      break;
    }
   case 6:
    var $i_04;
    var $usetz_03;
    var $26 = HEAP8[$tzbuf + $i_04 | 0] << 24 >> 24 & 65535;
    if ($26 >>> 0 > 127) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $29 = _isalpha($26);
    if (($29 | 0) != 0 | ($26 - 48 | 0) >>> 0 < 10) {
      var $usetz_1 = $usetz_03;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if (($26 | 0) == 41 || ($26 | 0) == 40 || ($26 | 0) == 32) {
      var $usetz_1 = $usetz_03;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $usetz_1 = 0;
    __label__ = 10;
    break;
   case 10:
    var $usetz_1;
    var $33 = $i_04 + 1 | 0;
    if (($33 | 0) == ($20 | 0)) {
      var $usetz_2 = $usetz_1;
      __label__ = 11;
      break;
    } else {
      var $usetz_03 = $usetz_1;
      var $i_04 = $33;
      __label__ = 6;
      break;
    }
   case 11:
    var $usetz_2;
    if (HEAP8[$16] << 24 >> 24 == 40) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    if (HEAP8[$tzbuf + 1 | 0] << 24 >> 24 == 41) {
      __label__ = 13;
      break;
    } else {
      var $usetz_3 = $usetz_2;
      __label__ = 14;
      break;
    }
   case 13:
    var $usetz_3 = 0;
    __label__ = 14;
    break;
   case 14:
    var $usetz_3;
    if (($format | 0) == 0) {
      __label__ = 16;
      break;
    } else if (($format | 0) == 1) {
      __label__ = 17;
      break;
    } else if (($format | 0) == 2) {
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $_pre_phi = $buf | 0;
    __label__ = 19;
    break;
   case 16:
    var $43 = $buf | 0;
    var $44 = __ZL7WeekDayd($7);
    var $46 = HEAP32[__ZL4days + ($44 << 2) >> 2];
    var $47 = __ZL13MonthFromTimed($7);
    var $49 = HEAP32[__ZL6months + ($47 << 2) >> 2];
    var $50 = __ZL12DateFromTimed($7);
    var $51 = __ZL12YearFromTimed($7);
    var $52 = __ZL12HourFromTimed($7);
    var $53 = __ZL11MinFromTimed($7);
    var $54 = __ZL11SecFromTimed($7);
    var $55 = ($usetz_3 | 0) != 0;
    var $56 = $55 ? STRING_TABLE.__str284577 | 0 : __str17668 | 0;
    var $57 = $55 ? $16 : __str17668 | 0;
    var $58 = _JS_snprintf($43, 100, STRING_TABLE.__str78972 | 0, (tempInt = STACKTOP, STACKTOP += 40, HEAP32[tempInt >> 2] = $46, HEAP32[tempInt + 4 >> 2] = $49, HEAP32[tempInt + 8 >> 2] = $50, HEAP32[tempInt + 12 >> 2] = $51, HEAP32[tempInt + 16 >> 2] = $52, HEAP32[tempInt + 20 >> 2] = $53, HEAP32[tempInt + 24 >> 2] = $54, HEAP32[tempInt + 28 >> 2] = $15, HEAP32[tempInt + 32 >> 2] = $56, HEAP32[tempInt + 36 >> 2] = $57, tempInt));
    var $_pre_phi = $43;
    __label__ = 19;
    break;
   case 17:
    var $60 = $buf | 0;
    var $61 = __ZL7WeekDayd($7);
    var $63 = HEAP32[__ZL4days + ($61 << 2) >> 2];
    var $64 = __ZL13MonthFromTimed($7);
    var $66 = HEAP32[__ZL6months + ($64 << 2) >> 2];
    var $67 = __ZL12DateFromTimed($7);
    var $68 = __ZL12YearFromTimed($7);
    var $69 = _JS_snprintf($60, 100, STRING_TABLE.__str81975 | 0, (tempInt = STACKTOP, STACKTOP += 16, HEAP32[tempInt >> 2] = $63, HEAP32[tempInt + 4 >> 2] = $66, HEAP32[tempInt + 8 >> 2] = $67, HEAP32[tempInt + 12 >> 2] = $68, tempInt));
    var $_pre_phi = $60;
    __label__ = 19;
    break;
   case 18:
    var $71 = $buf | 0;
    var $72 = __ZL12HourFromTimed($7);
    var $73 = __ZL11MinFromTimed($7);
    var $74 = __ZL11SecFromTimed($7);
    var $75 = ($usetz_3 | 0) != 0;
    var $76 = $75 ? STRING_TABLE.__str284577 | 0 : __str17668 | 0;
    var $77 = $75 ? $16 : __str17668 | 0;
    var $78 = _JS_snprintf($71, 100, STRING_TABLE.__str82976 | 0, (tempInt = STACKTOP, STACKTOP += 24, HEAP32[tempInt >> 2] = $72, HEAP32[tempInt + 4 >> 2] = $73, HEAP32[tempInt + 8 >> 2] = $74, HEAP32[tempInt + 12 >> 2] = $15, HEAP32[tempInt + 16 >> 2] = $76, HEAP32[tempInt + 20 >> 2] = $77, tempInt));
    var $_pre_phi = $71;
    __label__ = 19;
    break;
   case 19:
    var $_pre_phi;
    var $80 = $cx;
    var $81 = _JS_NewStringCopyZ($80, $_pre_phi);
    if (($81 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    __ZN2JS5Value9setStringEP8JSString($rval, $81);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11date_formatP9JSContextd10formatspecPN2JS5ValueE["X"] = 1;

function __ZL11NowAsMillisv() {
  var $1 = _PRMJ_Now();
  var $1$0 = $1[0];
  var $1$1 = $1[1];
  var $2$0 = (i64Math.divide($1$0, $1$1, 1e3, 0), i64Math.result[0]);
  var $2$1 = i64Math.result[1];
  return $2$0 + $2$1 * 4294967296;
}

function __ZL15JSDOUBLE_IS_NaNd1014($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZL18js_DoubleToIntegerd1005($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d == 0) {
      var $_0 = $d;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL18JSDOUBLE_IS_FINITEd1004($d);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZL15JSDOUBLE_IS_NaNd1014($d);
    var $d_ = ($6 | 0) == 0 ? $d : 0;
    var $_0 = $d_;
    __label__ = 7;
    break;
   case 4:
    if ($d < 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = _floor($d);
    var $_0 = $10;
    __label__ = 7;
    break;
   case 6:
    var $12 = -$d;
    var $13 = _floor($12);
    var $_0 = -$13;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16date_parseStringP14JSLinearStringPdP9JSContext($str, $result, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL19date_parseISOStringP14JSLinearStringPdP9JSContext($str, $result, $cx);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 79;
      break;
    }
   case 2:
    var $str_idx_val = HEAP32[$str + 4 >> 2];
    var $4 = __ZNK14JSLinearString5charsEv($str_idx_val);
    var $_idx_val = HEAP32[$str >> 2];
    var $5 = __ZNK8JSString6lengthEv($_idx_val);
    if (($5 | 0) == 0) {
      __label__ = 78;
      break;
    } else {
      var $seenmonthname_0 = 0;
      var $seenplusminus_0 = 0;
      var $i_0 = 0;
      var $year_0 = -1;
      var $mon_0 = -1;
      var $mday_0 = -1;
      var $hour_0 = -1;
      var $min_0 = -1;
      var $sec_0 = -1;
      var $tzoffset_0 = -1;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    }
   case 3:
    var $prevc_0;
    var $tzoffset_0;
    var $sec_0;
    var $min_0;
    var $hour_0;
    var $mday_0;
    var $mon_0;
    var $year_0;
    var $i_0;
    var $seenplusminus_0;
    var $seenmonthname_0;
    if ($i_0 >>> 0 < $5 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 4:
    var $10 = HEAPU16[$4 + ($i_0 << 1) >> 1];
    var $11 = $10 & 65535;
    var $12 = $i_0 + 1 | 0;
    if (($10 & 65535) < 33) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $12;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = $prevc_0;
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ($10 << 16 >> 16 == 44) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $12;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = $prevc_0;
      __label__ = 3;
      break;
    } else if ($10 << 16 >> 16 == 45) {
      __label__ = 6;
      break;
    } else if ($10 << 16 >> 16 == 40) {
      var $depth_0_ph = 1;
      var $i_1_ph = $12;
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 6:
    if ((HEAP16[$4 + ($12 << 1) >> 1] - 48 & 65535 & 65535) < 10) {
      __label__ = 7;
      break;
    } else {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $12;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = $prevc_0;
      __label__ = 3;
      break;
    }
   case 7:
    var $seenmonthname_0 = $seenmonthname_0;
    var $seenplusminus_0 = $seenplusminus_0;
    var $i_0 = $12;
    var $year_0 = $year_0;
    var $mon_0 = $mon_0;
    var $mday_0 = $mday_0;
    var $hour_0 = $hour_0;
    var $min_0 = $min_0;
    var $sec_0 = $sec_0;
    var $tzoffset_0 = $tzoffset_0;
    var $prevc_0 = $11;
    __label__ = 3;
    break;
   case 8:
    var $i_1;
    if ($i_1 >>> 0 < $5 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_1;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = $prevc_0;
      __label__ = 3;
      break;
    }
   case 9:
    var $23 = HEAP16[$4 + ($i_1 << 1) >> 1];
    var $24 = $i_1 + 1 | 0;
    if ($23 << 16 >> 16 == 40) {
      __label__ = 10;
      break;
    } else if ($23 << 16 >> 16 == 41) {
      __label__ = 12;
      break;
    } else {
      var $i_1 = $24;
      __label__ = 8;
      break;
    }
   case 10:
    var $depth_0_ph = $depth_0_ph + 1 | 0;
    var $i_1_ph = $24;
    __label__ = 11;
    break;
   case 11:
    var $i_1_ph;
    var $depth_0_ph;
    var $i_1 = $i_1_ph;
    __label__ = 8;
    break;
   case 12:
    var $28 = $depth_0_ph - 1 | 0;
    if (($28 | 0) < 1) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $24;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = $prevc_0;
      __label__ = 3;
      break;
    } else {
      var $depth_0_ph = $28;
      var $i_1_ph = $24;
      __label__ = 11;
      break;
    }
   case 13:
    if (($10 - 48 & 65535 & 65535) < 10) {
      var $i_2 = $12;
      var $c_0 = $11;
      var $n_0_in = $11;
      __label__ = 14;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 14:
    var $n_0_in;
    var $c_0;
    var $i_2;
    var $n_0 = $n_0_in - 48 | 0;
    var $32 = $i_2 >>> 0 < $5 >>> 0;
    if ($32) {
      __label__ = 15;
      break;
    } else {
      var $c_1 = $c_0;
      __label__ = 17;
      break;
    }
   case 15:
    var $35 = HEAPU16[$4 + ($i_2 << 1) >> 1];
    var $36 = $35 & 65535;
    if (($35 - 48 & 65535 & 65535) < 10) {
      __label__ = 16;
      break;
    } else {
      var $c_1 = $36;
      __label__ = 17;
      break;
    }
   case 16:
    var $40 = $36 + $n_0 * 10 | 0;
    var $i_2 = $i_2 + 1 | 0;
    var $c_0 = $36;
    var $n_0_in = $40;
    __label__ = 14;
    break;
   case 17:
    var $c_1;
    var $42 = ($prevc_0 | 0) == 43;
    if (($prevc_0 | 0) == 45 || ($prevc_0 | 0) == 43) {
      __label__ = 18;
      break;
    } else if (($prevc_0 | 0) == 47) {
      __label__ = 22;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 18:
    if (($n_0 | 0) < 24) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $n_1 = $n_0 * 60 | 0;
    __label__ = 21;
    break;
   case 20:
    var $n_1 = (($n_0 | 0) / 100 & -1) * 60 + $n_0 % 100 | 0;
    __label__ = 21;
    break;
   case 21:
    var $n_1;
    var $n_2 = $42 ? -$n_1 | 0 : $n_1;
    if (($tzoffset_0 | 0) == -1 || ($tzoffset_0 | 0) == 0) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = 1;
      var $i_0 = $i_2;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $n_2;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 22:
    if (($mon_0 | $mday_0 | 0) > -1 & ($year_0 | 0) < 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 23:
    if (($c_1 | 0) < 33) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $n_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    if (($c_1 | 0) == 47 || ($c_1 | 0) == 44) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $n_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    if ($32) {
      __label__ = 78;
      break;
    } else {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $n_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    }
   case 26:
    if (($c_1 | 0) == 58) {
      __label__ = 27;
      break;
    } else if (($c_1 | 0) == 47) {
      __label__ = 29;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 27:
    if (($hour_0 | 0) < 0) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $n_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    if (($min_0 | 0) < 0) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $n_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 29:
    if (($mon_0 | 0) < 0) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $year_0;
      var $mon_0 = $n_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    if (($mday_0 | 0) < 0) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $n_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 31:
    if ($32 & ($c_1 | 0) > 32) {
      __label__ = 32;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 32:
    if (($c_1 | 0) == 45 || ($c_1 | 0) == 44 || ($c_1 | 0) == 40) {
      __label__ = 33;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 33:
    if (($seenplusminus_0 | 0) != 0 & ($n_0 | 0) < 60) {
      __label__ = 34;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 34:
    if (($tzoffset_0 | 0) < 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 35:
    var $seenmonthname_0 = $seenmonthname_0;
    var $seenplusminus_0 = $seenplusminus_0;
    var $i_0 = $i_2;
    var $year_0 = $year_0;
    var $mon_0 = $mon_0;
    var $mday_0 = $mday_0;
    var $hour_0 = $hour_0;
    var $min_0 = $min_0;
    var $sec_0 = $sec_0;
    var $tzoffset_0 = $tzoffset_0 - $n_0 | 0;
    var $prevc_0 = 0;
    __label__ = 3;
    break;
   case 36:
    var $seenmonthname_0 = $seenmonthname_0;
    var $seenplusminus_0 = $seenplusminus_0;
    var $i_0 = $i_2;
    var $year_0 = $year_0;
    var $mon_0 = $mon_0;
    var $mday_0 = $mday_0;
    var $hour_0 = $hour_0;
    var $min_0 = $min_0;
    var $sec_0 = $sec_0;
    var $tzoffset_0 = $n_0 + $tzoffset_0 | 0;
    var $prevc_0 = 0;
    __label__ = 3;
    break;
   case 37:
    if (($hour_0 | 0) > -1 & ($min_0 | 0) < 0) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $n_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    if (($prevc_0 | 0) == 58 & ($min_0 | 0) > -1 & ($sec_0 | 0) < 0) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $n_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    if (($mon_0 | 0) < 0) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $year_0;
      var $mon_0 = $n_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    if (($mday_0 | 0) < 0) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $n_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    if (($year_0 | 0) < 0) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $n_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 42:
    if ($10 << 16 >> 16 == 58 || $10 << 16 >> 16 == 47 || $10 << 16 >> 16 == 45 || $10 << 16 >> 16 == 43) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $12;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = $11;
      __label__ = 3;
      break;
    } else {
      var $i_3 = $12;
      __label__ = 43;
      break;
    }
   case 43:
    var $i_3;
    if ($i_3 >>> 0 < $5 >>> 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 44:
    var $98 = HEAPU16[$4 + ($i_3 << 1) >> 1];
    if (($98 - 65 & 65535 & 65535) < 26 | ($98 - 97 & 65535 & 65535) < 26) {
      __label__ = 45;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 45:
    var $i_3 = $i_3 + 1 | 0;
    __label__ = 43;
    break;
   case 46:
    if ($i_3 >>> 0 > $12 >>> 0) {
      __label__ = 47;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 47:
    var $105 = $i_3 - $i_0 | 0;
    var $k_0 = 32;
    __label__ = 48;
    break;
   case 48:
    var $k_0;
    var $107 = $k_0 - 1 | 0;
    if (($k_0 | 0) > 0) {
      __label__ = 49;
      break;
    } else {
      var $seenmonthname_1 = $seenmonthname_0;
      var $year_2 = $year_0;
      var $mon_2 = $mon_0;
      var $mday_2 = $mday_0;
      var $hour_2 = $hour_0;
      var $tzoffset_2 = $tzoffset_0;
      __label__ = 62;
      break;
    }
   case 49:
    var $111 = HEAP32[__ZL3wtb + ($107 << 2) >> 2];
    var $112 = __ZL18date_regionMatchesPKciPKtiii($111, $4, $i_0, $105);
    if (($112 | 0) == 0) {
      var $k_0 = $107;
      __label__ = 48;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    var $116 = HEAPU32[__ZL3ttb + ($107 << 2) >> 2];
    if (($k_0 - 3 | 0) >>> 0 > 6) {
      __label__ = 51;
      break;
    } else {
      var $seenmonthname_1 = $seenmonthname_0;
      var $year_2 = $year_0;
      var $mon_2 = $mon_0;
      var $mday_2 = $mday_0;
      var $hour_2 = $hour_0;
      var $tzoffset_2 = $tzoffset_0;
      __label__ = 62;
      break;
    }
   case 51:
    if ($107 >>> 0 < 2) {
      __label__ = 52;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 52:
    if ($hour_0 >>> 0 > 12) {
      __label__ = 78;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    var $125 = ($hour_0 | 0) == 12;
    if (($107 | 0) == 0 & $125) {
      var $seenmonthname_1 = $seenmonthname_0;
      var $year_2 = $year_0;
      var $mon_2 = $mon_0;
      var $mday_2 = $mday_0;
      var $hour_2 = 0;
      var $tzoffset_2 = $tzoffset_0;
      __label__ = 62;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    if (($107 | 0) == 1) {
      __label__ = 55;
      break;
    } else {
      var $seenmonthname_1 = $seenmonthname_0;
      var $year_2 = $year_0;
      var $mon_2 = $mon_0;
      var $mday_2 = $mday_0;
      var $hour_2 = $hour_0;
      var $tzoffset_2 = $tzoffset_0;
      __label__ = 62;
      break;
    }
   case 55:
    var $hour_0_ = $125 ? 12 : $hour_0 + 12 | 0;
    var $seenmonthname_0 = $seenmonthname_0;
    var $seenplusminus_0 = $seenplusminus_0;
    var $i_0 = $i_3;
    var $year_0 = $year_0;
    var $mon_0 = $mon_0;
    var $mday_0 = $mday_0;
    var $hour_0 = $hour_0_;
    var $min_0 = $min_0;
    var $sec_0 = $sec_0;
    var $tzoffset_0 = $tzoffset_0;
    var $prevc_0 = 0;
    __label__ = 3;
    break;
   case 56:
    if ($107 >>> 0 < 21) {
      __label__ = 57;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 57:
    if (($seenmonthname_0 | 0) == 0) {
      __label__ = 58;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 58:
    var $134 = $116 - 1 | 0;
    if (($mon_0 | 0) < 0) {
      var $seenmonthname_1 = 1;
      var $year_2 = $year_0;
      var $mon_2 = $134;
      var $mday_2 = $mday_0;
      var $hour_2 = $hour_0;
      var $tzoffset_2 = $tzoffset_0;
      __label__ = 62;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 59:
    if (($mday_0 | 0) < 0) {
      var $seenmonthname_1 = 1;
      var $year_2 = $year_0;
      var $mon_2 = $134;
      var $mday_2 = $mon_0;
      var $hour_2 = $hour_0;
      var $tzoffset_2 = $tzoffset_0;
      __label__ = 62;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 60:
    if (($year_0 | 0) < 0) {
      var $seenmonthname_1 = 1;
      var $year_2 = $mon_0;
      var $mon_2 = $134;
      var $mday_2 = $mday_0;
      var $hour_2 = $hour_0;
      var $tzoffset_2 = $tzoffset_0;
      __label__ = 62;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 61:
    var $seenmonthname_1 = $seenmonthname_0;
    var $year_2 = $year_0;
    var $mon_2 = $mon_0;
    var $mday_2 = $mday_0;
    var $hour_2 = $hour_0;
    var $tzoffset_2 = $116 - 1e4 | 0;
    __label__ = 62;
    break;
   case 62:
    var $tzoffset_2;
    var $hour_2;
    var $mday_2;
    var $mon_2;
    var $year_2;
    var $seenmonthname_1;
    if (($107 | 0) < 0) {
      __label__ = 78;
      break;
    } else {
      var $seenmonthname_0 = $seenmonthname_1;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_3;
      var $year_0 = $year_2;
      var $mon_0 = $mon_2;
      var $mday_0 = $mday_2;
      var $hour_0 = $hour_2;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_2;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    }
   case 63:
    if (($mon_0 | $mday_0 | $year_0 | 0) < 0) {
      __label__ = 78;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    if (($seenmonthname_0 | 0) == 0) {
      __label__ = 68;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 65:
    if (($mday_0 | 0) > 69 & ($year_0 | 0) > 69) {
      __label__ = 78;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 66:
    if (($mday_0 | 0) < 70 & ($year_0 | 0) < 70) {
      __label__ = 78;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 67:
    var $156 = ($mday_0 | 0) > ($year_0 | 0);
    var $mday_3 = $156 ? $year_0 : $mday_0;
    var $year_3 = $156 ? $mday_0 : $year_0;
    var $_year_3 = ($year_3 - 70 | 0) >>> 0 < 30 ? $year_3 + 1900 | 0 : $year_3;
    var $year_4 = $_year_3;
    var $mon_3 = $mon_0;
    var $mday_4 = $mday_3;
    __label__ = 74;
    break;
   case 68:
    if (($mon_0 | 0) < 70) {
      __label__ = 69;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 69:
    var $_year_0 = ($year_0 | 0) < 100 ? $year_0 + 1900 | 0 : $year_0;
    var $year_4 = $_year_0;
    var $mon_3 = $mon_0;
    var $mday_4 = $mday_0;
    __label__ = 74;
    break;
   case 70:
    var $166 = ($mday_0 | 0) < 70;
    if (($mon_0 | 0) < 100) {
      __label__ = 71;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 71:
    if ($166) {
      __label__ = 72;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 72:
    var $year_4 = $mon_0 + 1900 | 0;
    var $mon_3 = $mday_0;
    var $mday_4 = $year_0;
    __label__ = 74;
    break;
   case 73:
    if ($166) {
      var $year_4 = $mon_0;
      var $mon_3 = $mday_0;
      var $mday_4 = $year_0;
      __label__ = 74;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 74:
    var $mday_4;
    var $mon_3;
    var $year_4;
    var $180 = ($hour_0 | 0) < 0 ? 0 : $hour_0 | 0;
    var $182 = ($min_0 | 0) < 0 ? 0 : $min_0 | 0;
    var $184 = ($sec_0 | 0) < 0 ? 0 : $sec_0 | 0;
    var $185 = __ZL17date_msecFromDateddddddd($year_4 | 0, $mon_3 - 1 | 0, $mday_4 | 0, $180, $182, $184, 0);
    if (($tzoffset_0 | 0) == -1) {
      __label__ = 75;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 75:
    var $188 = __ZL3UTCdP9JSContext($185, $cx);
    var $msec_0 = $188;
    __label__ = 77;
    break;
   case 76:
    var $msec_0 = $185 + ($tzoffset_0 | 0) * 6e4;
    __label__ = 77;
    break;
   case 77:
    var $msec_0;
    tempDoubleF64[0] = $msec_0, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 79;
    break;
   case 78:
    tempDoubleF64[0] = 0, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 0;
    __label__ = 79;
    break;
   case 79:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16date_parseStringP14JSLinearStringPdP9JSContext["X"] = 1;

function __ZL17date_msecFromArgsP9JSContextjPN2JS5ValueEPd($cx, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $d = __stackBase__ + 56;
    var $1 = $cx;
    var $loop_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $loop_0;
    if ($loop_0 >>> 0 < 7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 3:
    if ($loop_0 >>> 0 < $argc >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $7 = $argv + ($loop_0 << 3) | 0;
    var $8 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($1, $7, $d);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 5:
    var $10 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $11 = __ZL18JSDOUBLE_IS_FINITEd1004($10);
    if (($11 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $14 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $14, HEAP32[$rval >> 2] = tempDoubleI32[0], HEAP32[$rval + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 15;
    break;
   case 7:
    var $16 = __ZL18js_DoubleToIntegerd1005($10);
    var $17 = $array + ($loop_0 << 3) | 0;
    tempDoubleF64[0] = $16, HEAP32[$17 >> 2] = tempDoubleI32[0], HEAP32[$17 + 4 >> 2] = tempDoubleI32[1];
    __label__ = 11;
    break;
   case 8:
    var $20 = $array + ($loop_0 << 3) | 0;
    if (($loop_0 | 0) == 2) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    tempDoubleF64[0] = 1, HEAP32[$20 >> 2] = tempDoubleI32[0], HEAP32[$20 + 4 >> 2] = tempDoubleI32[1];
    __label__ = 11;
    break;
   case 10:
    tempDoubleF64[0] = 0, HEAP32[$20 >> 2] = tempDoubleI32[0], HEAP32[$20 + 4 >> 2] = tempDoubleI32[1];
    __label__ = 11;
    break;
   case 11:
    var $loop_0 = $loop_0 + 1 | 0;
    __label__ = 2;
    break;
   case 12:
    var $26 = $array | 0;
    var $27 = (tempDoubleI32[0] = HEAP32[$26 >> 2], tempDoubleI32[1] = HEAP32[$26 + 4 >> 2], tempDoubleF64[0]);
    if ($27 < 0 | $27 > 99) {
      var $32 = $27;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $31 = $27 + 1900;
    tempDoubleF64[0] = $31, HEAP32[$26 >> 2] = tempDoubleI32[0], HEAP32[$26 + 4 >> 2] = tempDoubleI32[1];
    var $32 = $31;
    __label__ = 14;
    break;
   case 14:
    var $32;
    var $33 = $array + 8 | 0;
    var $34 = (tempDoubleI32[0] = HEAP32[$33 >> 2], tempDoubleI32[1] = HEAP32[$33 + 4 >> 2], tempDoubleF64[0]);
    var $35 = $array + 16 | 0;
    var $36 = (tempDoubleI32[0] = HEAP32[$35 >> 2], tempDoubleI32[1] = HEAP32[$35 + 4 >> 2], tempDoubleF64[0]);
    var $37 = $array + 24 | 0;
    var $38 = (tempDoubleI32[0] = HEAP32[$37 >> 2], tempDoubleI32[1] = HEAP32[$37 + 4 >> 2], tempDoubleF64[0]);
    var $39 = $array + 32 | 0;
    var $40 = (tempDoubleI32[0] = HEAP32[$39 >> 2], tempDoubleI32[1] = HEAP32[$39 + 4 >> 2], tempDoubleF64[0]);
    var $41 = $array + 40 | 0;
    var $42 = (tempDoubleI32[0] = HEAP32[$41 >> 2], tempDoubleI32[1] = HEAP32[$41 + 4 >> 2], tempDoubleF64[0]);
    var $43 = $array + 48 | 0;
    var $44 = (tempDoubleI32[0] = HEAP32[$43 >> 2], tempDoubleI32[1] = HEAP32[$43 + 4 >> 2], tempDoubleF64[0]);
    var $45 = __ZL17date_msecFromDateddddddd($32, $34, $36, $38, $40, $42, $44);
    tempDoubleF64[0] = $45, HEAP32[$rval >> 2] = tempDoubleI32[0], HEAP32[$rval + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17date_msecFromArgsP9JSContextjPN2JS5ValueEPd["X"] = 1;

function __ZL3UTCdP9JSContext($t, $cx) {
  var $1 = (tempDoubleI32[0] = HEAP32[__ZL8LocalTZA >> 2], tempDoubleI32[1] = HEAP32[__ZL8LocalTZA + 4 >> 2], tempDoubleF64[0]);
  var $2 = $t - $1;
  var $3 = __ZL10AdjustTimedP9JSContext($2, $cx);
  return $t - $3;
}

function __Z20js_NewDateObjectMsecP9JSContextd($cx, $msec_time) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE1011($cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    var $5 = $cx;
    var $6 = __ZN8JSObject11ensureSlotsEP9JSContextj($4, $5, 9);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZL10SetUTCTimeP9JSContextP8JSObjectdPN2JS5ValueE($1, $msec_time, 0);
    var $_0 = $1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_InitDateClassP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $toUTCStringFun = __stackBase__;
    var $1 = _PRMJ_LocalGMTDifference();
    tempDoubleF64[0] = -(($1 | 0) * 1e3), HEAP32[__ZL8LocalTZA >> 2] = tempDoubleI32[0], HEAP32[__ZL8LocalTZA + 4 >> 2] = tempDoubleI32[1];
    var $5 = $obj;
    var $6 = __ZN8JSObject8asGlobalEv($5);
    var $7 = $cx;
    var $8 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($6, $7, __ZN2js9DateClassE);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $cx_idx = $cx + 52 | 0;
    var $cx_idx_val = HEAP32[$cx_idx >> 2];
    __ZL12SetDateToNaNP9JSContextP8JSObjectPN2JS5ValueE($cx_idx_val, $9, 0);
    var $15 = HEAP32[HEAP32[$cx_idx >> 2] + 210044 >> 2];
    var $16 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($6, $7, 84, __ZN2js9DateClassE, $15, 7);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $19 = $16 | 0;
    var $20 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($7, $19, $8);
    if ($20) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 4:
    var $22 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($7, $19, 0, __ZL19date_static_methods);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $24 = $cx;
    var $25 = $8;
    var $26 = _JS_DefineFunctions($24, $25, __ZL12date_methods);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $29 = HEAP32[$cx_idx >> 2];
    var $32 = HEAP32[$29 + 210328 >> 2] | 0;
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom1010($32);
    var $35 = HEAP32[$29 + 210312 >> 2];
    var $36 = __Z14js_GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($24, $25, $33, $toUTCStringFun);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $39 = $35 | 0;
    var $40 = __ZL12ATOM_TO_JSIDP6JSAtom1010($39);
    var $41 = $cx;
    var $42 = $8;
    var $43 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($41, $42, $40, $toUTCStringFun, 10, 12, 0);
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx_val = HEAP8[$cx + 232 | 0];
    var $47 = __ZN9JSContext20typeInferenceEnabledEv($_idx_val);
    if ($47) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $49 = __ZN8JSObject5brandEP9JSContext($8, $7);
    __label__ = 10;
    break;
   case 10:
    var $51 = $6;
    var $52 = $16;
    var $53 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($24, $51, 6, $52, $25);
    var $_ = $53 ? $9 : 0;
    var $_0 = $_;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z16js_InitDateClassP9JSContextP8JSObject["X"] = 1;

function __ZL12SetDateToNaNP9JSContextP8JSObjectPN2JS5ValueE($cx_0_11_val, $obj, $vp) {
  var $1 = $cx_0_11_val + 144112 | 0;
  var $2 = __ZN2JS5Value12getDoubleRefEv($1);
  var $3 = (tempDoubleI32[0] = HEAP32[$2 >> 2], tempDoubleI32[1] = HEAP32[$2 + 4 >> 2], tempDoubleF64[0]);
  __ZL10SetUTCTimeP9JSContextP8JSObjectdPN2JS5ValueE($obj, $3, $vp);
  return;
}

function __ZL12ATOM_TO_JSIDP6JSAtom1010($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj1046($1);
  return $2;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE1011($cx) {
  var $3 = HEAPU32[__ZN2js9DateClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb1026($3);
  var $5 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1027($cx, $4);
  return $5;
}

function __ZL10SetUTCTimeP9JSContextP8JSObjectdPN2JS5ValueE($obj, $t, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $obj;
    var $_idx_val = HEAP32[$obj + 28 >> 2];
    var $5 = __ZNK8JSObject8numSlotsEv($_idx_val);
    if ($5 >>> 0 > 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = $5 >>> 0 < 9 ? $5 : 9;
    var $_idx1 = $1 | 0;
    var $ind_01 = 1;
    __label__ = 3;
    break;
   case 3:
    var $ind_01;
    __ZN2JSL14UndefinedValueEv1024($1);
    var $st$2$0 = $_idx1 | 0;
    var $_idx1_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx1 + 4 | 0;
    var $_idx1_val$1 = HEAP32[$st$2$1 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($3, $ind_01, $_idx1_val$0, $_idx1_val$1);
    var $10 = $ind_01 + 1 | 0;
    if (($10 | 0) == ($8 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $ind_01 = $10;
      __label__ = 3;
      break;
    }
   case 4:
    __ZN2JSL11DoubleValueEd1017($2, $t);
    var $_idx2 = $2 | 0;
    var $st$2$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$2$1 >> 2];
    __ZN8JSObject14setDateUTCTimeERKN2JS5ValueE($obj, $_idx2_val$0, $_idx2_val$1);
    if (($vp | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JS5Value9setDoubleEd($vp, $t);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17date_msecFromDateddddddd($year, $mon, $mday, $hour, $min, $sec, $msec) {
  var $1 = __ZL7MakeDayddd($year, $mon, $mday);
  return $1 * 864e5 + ((($hour * 60 + $min) * 60 + $sec) * 1e3 + $msec);
}

function __ZL10GetUTCTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $obj, $vp, $dp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$obj + 4 >> 2];
    var $2 = __ZNK8JSObject6isDateEv($_idx_val);
    if ($2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($vp | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = $cx;
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($6, $vp, __ZN2js9DateClassE);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $8 = __ZNK8JSObject14getDateUTCTimeEv($obj);
    var $9 = __ZNK2JS5Value8toNumberEv($8);
    tempDoubleF64[0] = $9, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z14js_DateGetYearP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $localtime = __stackBase__;
    var $1 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $obj, 0, $localtime);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = (tempDoubleI32[0] = HEAP32[$localtime >> 2], tempDoubleI32[1] = HEAP32[$localtime + 4 >> 2], tempDoubleF64[0]);
    var $5 = __ZL15JSDOUBLE_IS_NaNd1014($4);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZL12YearFromTimed($4);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $obj, $vp, $time) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($obj | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $obj;
    var $_idx1_val = HEAP32[$obj + 4 >> 2];
    var $5 = __ZNK8JSObject6isDateEv($_idx1_val);
    if ($5) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($vp | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $cx;
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($9, $vp, __ZN2js9DateClassE);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 5:
    var $11 = __ZNK8JSObject7getSlotEj($3, 1);
    var $_idx = $11 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $12 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $14 = __ZL14FillLocalTimesP9JSContextP8JSObject($cx, $obj);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    if (($time | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $18 = __ZNK8JSObject7getSlotEj($3, 1);
    var $19 = __ZNK2JS5Value8toDoubleEv($18);
    tempDoubleF64[0] = $19, HEAP32[$time >> 2] = tempDoubleI32[0], HEAP32[$time + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12YearFromTimed($t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $t / 31556952e3;
    var $2 = _floor($1);
    var $3 = $2 & -1;
    var $4 = $3 + 1970 | 0;
    var $6 = $3 * 365 | 0;
    var $9 = ($3 + 1 | 0) * .25;
    var $10 = _floor($9);
    var $11 = $6 + $10;
    var $14 = ($3 + 69 | 0) / 100;
    var $15 = _floor($14);
    var $16 = $11 - $15;
    var $19 = ($3 + 369 | 0) / 400;
    var $20 = _floor($19);
    var $22 = ($16 + $20) * 864e5;
    if ($22 > $t) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $y_0 = $3 + 1969 | 0;
    __label__ = 5;
    break;
   case 3:
    var $27 = __ZL10DaysInYeari($4);
    if ($22 + ($27 | 0) * 864e5 > $t) {
      var $y_0 = $4;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $y_0 = $3 + 1971 | 0;
    __label__ = 5;
    break;
   case 5:
    var $y_0;
    return $y_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13MonthFromTimed($t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL12YearFromTimed($t);
    var $2 = $t / 864e5;
    var $3 = _floor($2);
    var $6 = $1 * 365 - 719050 | 0;
    var $9 = ($1 - 1969 | 0) * .25;
    var $10 = _floor($9);
    var $11 = $6 + $10;
    var $14 = ($1 - 1901 | 0) / 100;
    var $15 = _floor($14);
    var $16 = $11 - $15;
    var $19 = ($1 - 1601 | 0) / 400;
    var $20 = _floor($19);
    var $23 = $3 - ($16 + $20) & -1;
    if (($23 | 0) < 31) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $26 = __ZL14DaysInFebruaryi($1);
    if (($23 | 0) < ($26 + 31 | 0)) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($23 | 0) < ($26 + 62 | 0)) {
      var $_0 = 2;
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($23 | 0) < ($26 + 92 | 0)) {
      var $_0 = 3;
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($23 | 0) < ($26 + 123 | 0)) {
      var $_0 = 4;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($23 | 0) < ($26 + 153 | 0)) {
      var $_0 = 5;
      __label__ = 12;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($23 | 0) < ($26 + 184 | 0)) {
      var $_0 = 6;
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if (($23 | 0) < ($26 + 215 | 0)) {
      var $_0 = 7;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (($23 | 0) < ($26 + 245 | 0)) {
      var $_0 = 8;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if (($23 | 0) < ($26 + 276 | 0)) {
      var $_0 = 9;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_ = ($23 | 0) < ($26 + 306 | 0) ? 10 : 11;
    var $_0 = $_;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13MonthFromTimed["X"] = 1;

function __ZL14JSID_FROM_BITSj1046($bits) {
  return $bits;
}

function __ZL10IsLeapYeari($year) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($year & 3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $10 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    if (($year % 100 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $10 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = ($year % 400 | 0) == 0;
    __label__ = 4;
    break;
   case 4:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL15GetGCObjectKindEjb1026($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12DateFromTimed($t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL12YearFromTimed($t);
    var $2 = $t / 864e5;
    var $3 = _floor($2);
    var $6 = $1 * 365 - 719050 | 0;
    var $9 = ($1 - 1969 | 0) * .25;
    var $10 = _floor($9);
    var $11 = $6 + $10;
    var $14 = ($1 - 1901 | 0) / 100;
    var $15 = _floor($14);
    var $16 = $11 - $15;
    var $19 = ($1 - 1601 | 0) / 400;
    var $20 = _floor($19);
    var $23 = $3 - ($16 + $20) & -1;
    if (($23 | 0) < 31) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $23 + 1 | 0;
    __label__ = 24;
    break;
   case 3:
    var $28 = __ZL14DaysInFebruaryi($1);
    var $29 = $28 + 30 | 0;
    if (($23 | 0) > ($29 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = $23 - 30 | 0;
    __label__ = 24;
    break;
   case 5:
    var $34 = $28 + 61 | 0;
    if (($23 | 0) > ($34 | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_0 = $23 - $29 | 0;
    __label__ = 24;
    break;
   case 7:
    var $39 = $28 + 91 | 0;
    if (($23 | 0) > ($39 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = $23 - $34 | 0;
    __label__ = 24;
    break;
   case 9:
    var $44 = $28 + 122 | 0;
    if (($23 | 0) > ($44 | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = $23 - $39 | 0;
    __label__ = 24;
    break;
   case 11:
    var $49 = $28 + 152 | 0;
    if (($23 | 0) > ($49 | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $_0 = $23 - $44 | 0;
    __label__ = 24;
    break;
   case 13:
    var $54 = $28 + 183 | 0;
    if (($23 | 0) > ($54 | 0)) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $_0 = $23 - $49 | 0;
    __label__ = 24;
    break;
   case 15:
    var $59 = $28 + 214 | 0;
    if (($23 | 0) > ($59 | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $_0 = $23 - $54 | 0;
    __label__ = 24;
    break;
   case 17:
    var $64 = $28 + 244 | 0;
    if (($23 | 0) > ($64 | 0)) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $_0 = $23 - $59 | 0;
    __label__ = 24;
    break;
   case 19:
    var $69 = $28 + 275 | 0;
    if (($23 | 0) > ($69 | 0)) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $_0 = $23 - $64 | 0;
    __label__ = 24;
    break;
   case 21:
    var $74 = $28 + 305 | 0;
    if (($23 | 0) > ($74 | 0)) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $_0 = $23 - $69 | 0;
    __label__ = 24;
    break;
   case 23:
    var $_0 = $23 - $74 | 0;
    __label__ = 24;
    break;
   case 24:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12DateFromTimed["X"] = 1;

function __ZL12HourFromTimed($t) {
  var $1 = $t / 36e5;
  var $2 = _floor($1);
  var $3 = _fmod($2, 24);
  var $4 = $3 & -1;
  var $_ = ($4 | 0) < 0 ? $4 + 24 | 0 : $4;
  return $_;
}

function __ZL11MinFromTimed($t) {
  var $1 = $t / 6e4;
  var $2 = _floor($1);
  var $3 = _fmod($2, 60);
  var $4 = $3 & -1;
  var $_ = ($4 | 0) < 0 ? $4 + 60 | 0 : $4;
  return $_;
}

function __ZL11SecFromTimed($t) {
  var $1 = $t / 1e3;
  var $2 = _floor($1);
  var $3 = _fmod($2, 60);
  var $4 = $3 & -1;
  var $_ = ($4 | 0) < 0 ? $4 + 60 | 0 : $4;
  return $_;
}

function __Z24js_DateGetMsecSinceEpochP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $utctime = __stackBase__;
  var $1 = __ZL10GetUTCTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $obj, 0, $utctime);
  var $2 = ($1 | 0) == 0;
  var $3 = (tempDoubleI32[0] = HEAP32[$utctime >> 2], tempDoubleI32[1] = HEAP32[$utctime + 4 >> 2], tempDoubleF64[0]);
  var $_0 = $2 ? 0 : $3;
  STACKTOP = __stackBase__;
  return $_0;
}

function __Z14js_IntervalNowv() {
  var $1 = _PRMJ_Now();
  var $1$0 = $1[0];
  var $1$1 = $1[1];
  var $2$0 = (i64Math.divide($1$0, $1$1, 1e3, 0), i64Math.result[0]);
  var $2$1 = i64Math.result[1];
  return $2$0;
}

function __ZL14DaysInFebruaryi($year) {
  var $1 = __ZL10IsLeapYeari($year);
  var $2 = $1 ? 29 : 28;
  return $2;
}

function __ZL10DaysInYeari($year) {
  var $1 = __ZL10IsLeapYeari($year);
  var $2 = $1 ? 366 : 365;
  return $2;
}

function __ZL14FillLocalTimesP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __stackBase__ + 40;
    var $7 = __stackBase__ + 48;
    var $8 = __stackBase__ + 56;
    var $9 = __stackBase__ + 64;
    var $10 = __ZNK8JSObject14getDateUTCTimeEv($obj);
    var $11 = __ZNK2JS5Value8toNumberEv($10);
    var $12 = $obj;
    var $_idx_val = HEAP32[$obj + 28 >> 2];
    var $14 = __ZNK8JSObject8numSlotsEv($_idx_val);
    if ($14 >>> 0 < 9) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = $obj;
    var $18 = $cx;
    var $19 = __ZN8JSObject9growSlotsEP9JSContextj($17, $18, 9);
    if ($19) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 3:
    var $21 = __ZL18JSDOUBLE_IS_FINITEd1004($11);
    if (($21 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JSL11DoubleValueEd1017($1, $11);
    var $_idx16 = $1 | 0;
    var $_idx16_val$0 = HEAP32[$_idx16 >> 2];
    var $_idx16_val$1 = HEAP32[$_idx16 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 1, $_idx16_val$0, $_idx16_val$1);
    __ZN2JSL11DoubleValueEd1017($1, $11);
    var $_idx15_val$0 = HEAP32[$_idx16 >> 2];
    var $_idx15_val$1 = HEAP32[$_idx16 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 2, $_idx15_val$0, $_idx15_val$1);
    __ZN2JSL11DoubleValueEd1017($1, $11);
    var $_idx14_val$0 = HEAP32[$_idx16 >> 2];
    var $_idx14_val$1 = HEAP32[$_idx16 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 3, $_idx14_val$0, $_idx14_val$1);
    __ZN2JSL11DoubleValueEd1017($1, $11);
    var $st$20$0 = $_idx16 | 0;
    var $_idx13_val$0 = HEAP32[$st$20$0 >> 2];
    var $st$20$1 = $_idx16 + 4 | 0;
    var $_idx13_val$1 = HEAP32[$st$20$1 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 4, $_idx13_val$0, $_idx13_val$1);
    __ZN2JSL11DoubleValueEd1017($1, $11);
    var $_idx12_val$0 = HEAP32[$_idx16 >> 2];
    var $_idx12_val$1 = HEAP32[$_idx16 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 5, $_idx12_val$0, $_idx12_val$1);
    __ZN2JSL11DoubleValueEd1017($1, $11);
    var $_idx11_val$0 = HEAP32[$_idx16 >> 2];
    var $_idx11_val$1 = HEAP32[$_idx16 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 6, $_idx11_val$0, $_idx11_val$1);
    __ZN2JSL11DoubleValueEd1017($1, $11);
    var $_idx10_val$0 = HEAP32[$_idx16 >> 2];
    var $_idx10_val$1 = HEAP32[$_idx16 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 7, $_idx10_val$0, $_idx10_val$1);
    __ZN2JSL11DoubleValueEd1017($1, $11);
    var $_idx9_val$0 = HEAP32[$_idx16 >> 2];
    var $_idx9_val$1 = HEAP32[$_idx16 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 8, $_idx9_val$0, $_idx9_val$1);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 5:
    var $24 = __ZL9LocalTimedP9JSContext($11, $cx);
    __ZN2JSL11DoubleValueEd1017($2, $24);
    var $_idx8 = $2 | 0;
    var $_idx8_val$0 = HEAP32[$_idx8 >> 2];
    var $_idx8_val$1 = HEAP32[$_idx8 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 1, $_idx8_val$0, $_idx8_val$1);
    var $25 = $24 / 31556952e3;
    var $26 = _floor($25);
    var $27 = $26 & -1;
    var $28 = $27 + 1970 | 0;
    var $30 = $27 * 365 | 0;
    var $33 = ($27 + 1 | 0) * .25;
    var $34 = _floor($33);
    var $35 = $30 + $34;
    var $38 = ($27 + 69 | 0) / 100;
    var $39 = _floor($38);
    var $40 = $35 - $39;
    var $43 = ($27 + 369 | 0) / 400;
    var $44 = _floor($43);
    var $46 = ($40 + $44) * 864e5;
    if ($46 > $24) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $49 = $27 + 1969 | 0;
    var $50 = __ZL10DaysInYeari($49);
    var $yearDays_0 = $50;
    var $year_0 = $49;
    var $yearStartTime_0 = $46 - ($50 | 0) * 864e5;
    __label__ = 9;
    break;
   case 7:
    var $55 = __ZL10DaysInYeari($28);
    var $58 = $46 + ($55 | 0) * 864e5;
    if ($58 > $24) {
      var $yearDays_0 = $55;
      var $year_0 = $28;
      var $yearStartTime_0 = $46;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $61 = $27 + 1971 | 0;
    var $62 = __ZL10DaysInYeari($61);
    var $yearDays_0 = $62;
    var $year_0 = $61;
    var $yearStartTime_0 = $58;
    __label__ = 9;
    break;
   case 9:
    var $yearStartTime_0;
    var $year_0;
    var $yearDays_0;
    __ZN2JSL10Int32ValueEi1018($3, $year_0);
    var $_idx7 = $3 | 0;
    var $_idx7_val$0 = HEAP32[$_idx7 >> 2];
    var $_idx7_val$1 = HEAP32[$_idx7 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 2, $_idx7_val$0, $_idx7_val$1);
    var $64 = $24 - $yearStartTime_0;
    var $65$0 = $64 >>> 0;
    var $65$1 = Math.min(Math.floor($64 / 4294967296), 4294967295);
    var $66$0 = (i64Math.divide($65$0, $65$1, 1e3, 0, true), i64Math.result[0]);
    var $66$1 = i64Math.result[1];
    var $67 = $66$0;
    var $68 = ($67 | 0) / 86400 & -1;
    if (($67 | 0) < 2678400) {
      var $month_0 = 0;
      var $step_0 = -1;
      __label__ = 20;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $72 = ($yearDays_0 | 0) == 366 ? 59 : 58;
    if (($68 | 0) > ($72 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $month_0 = 1;
      var $step_0 = 30;
      __label__ = 20;
      break;
    }
   case 11:
    var $75 = $72 + 31 | 0;
    if (($68 | 0) > ($75 | 0)) {
      __label__ = 12;
      break;
    } else {
      var $month_0 = 2;
      var $step_0 = $72;
      __label__ = 20;
      break;
    }
   case 12:
    var $78 = $72 + 61 | 0;
    if (($68 | 0) > ($78 | 0)) {
      __label__ = 13;
      break;
    } else {
      var $month_0 = 3;
      var $step_0 = $75;
      __label__ = 20;
      break;
    }
   case 13:
    var $81 = $72 + 92 | 0;
    if (($68 | 0) > ($81 | 0)) {
      __label__ = 14;
      break;
    } else {
      var $month_0 = 4;
      var $step_0 = $78;
      __label__ = 20;
      break;
    }
   case 14:
    var $84 = $72 + 122 | 0;
    if (($68 | 0) > ($84 | 0)) {
      __label__ = 15;
      break;
    } else {
      var $month_0 = 5;
      var $step_0 = $81;
      __label__ = 20;
      break;
    }
   case 15:
    var $87 = $72 + 153 | 0;
    if (($68 | 0) > ($87 | 0)) {
      __label__ = 16;
      break;
    } else {
      var $month_0 = 6;
      var $step_0 = $84;
      __label__ = 20;
      break;
    }
   case 16:
    var $90 = $72 + 184 | 0;
    if (($68 | 0) > ($90 | 0)) {
      __label__ = 17;
      break;
    } else {
      var $month_0 = 7;
      var $step_0 = $87;
      __label__ = 20;
      break;
    }
   case 17:
    var $93 = $72 + 214 | 0;
    if (($68 | 0) > ($93 | 0)) {
      __label__ = 18;
      break;
    } else {
      var $month_0 = 8;
      var $step_0 = $90;
      __label__ = 20;
      break;
    }
   case 18:
    var $96 = $72 + 245 | 0;
    if (($68 | 0) > ($96 | 0)) {
      __label__ = 19;
      break;
    } else {
      var $month_0 = 9;
      var $step_0 = $93;
      __label__ = 20;
      break;
    }
   case 19:
    var $99 = $72 + 275 | 0;
    var $100 = ($68 | 0) > ($99 | 0);
    var $_ = $100 ? $99 : $96;
    var $_1 = $100 ? 11 : 10;
    var $month_0 = $_1;
    var $step_0 = $_;
    __label__ = 20;
    break;
   case 20:
    var $step_0;
    var $month_0;
    __ZN2JSL10Int32ValueEi1018($4, $month_0);
    var $_idx6 = $4 | 0;
    var $_idx6_val$0 = HEAP32[$_idx6 >> 2];
    var $_idx6_val$1 = HEAP32[$_idx6 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 3, $_idx6_val$0, $_idx6_val$1);
    var $102 = $68 - $step_0 | 0;
    __ZN2JSL10Int32ValueEi1018($5, $102);
    var $_idx5 = $5 | 0;
    var $_idx5_val$0 = HEAP32[$_idx5 >> 2];
    var $_idx5_val$1 = HEAP32[$_idx5 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 4, $_idx5_val$0, $_idx5_val$1);
    var $103 = __ZL7WeekDayd($24);
    __ZN2JSL10Int32ValueEi1018($6, $103);
    var $_idx4 = $6 | 0;
    var $st$20$0 = $_idx4 | 0;
    var $_idx4_val$0 = HEAP32[$st$20$0 >> 2];
    var $st$20$1 = $_idx4 + 4 | 0;
    var $_idx4_val$1 = HEAP32[$st$20$1 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 5, $_idx4_val$0, $_idx4_val$1);
    var $104 = ($67 | 0) % 60;
    __ZN2JSL10Int32ValueEi1018($7, $104);
    var $_idx3 = $7 | 0;
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 8, $_idx3_val$0, $_idx3_val$1);
    var $106 = (($67 | 0) / 60 & -1 | 0) % 60;
    __ZN2JSL10Int32ValueEi1018($8, $106);
    var $_idx2 = $8 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 7, $_idx2_val$0, $_idx2_val$1);
    var $108 = (($67 | 0) / 3600 & -1 | 0) % 24;
    __ZN2JSL10Int32ValueEi1018($9, $108);
    var $_idx1 = $9 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 6, $_idx1_val$0, $_idx1_val$1);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14FillLocalTimesP9JSContextP8JSObject["X"] = 1;

function __ZNK8JSObject14getDateUTCTimeEv($this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject12getFixedSlotEj($1, 0);
  return $2;
}

function __ZN2JSL11DoubleValueEd1017($agg_result, $dbl) {
  __ZN2JS5Value9setDoubleEd($agg_result, $dbl);
  return;
}

function __ZL9LocalTimedP9JSContext($t, $cx) {
  var $1 = __ZL10AdjustTimedP9JSContext($t, $cx);
  return $1 + $t;
}

function __ZN2JSL10Int32ValueEi1018($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZL7WeekDayd($t) {
  var $1 = $t / 864e5;
  var $2 = _floor($1);
  var $5 = (($2 & -1) + 4 | 0) % 7;
  var $_ = ($5 | 0) < 0 ? $5 + 7 | 0 : $5;
  return $_;
}

function __ZL10AdjustTimedP9JSContext($date, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL16DaylightSavingTAdP9JSContext($date, $cx);
    var $2 = (tempDoubleI32[0] = HEAP32[__ZL8LocalTZA >> 2], tempDoubleI32[1] = HEAP32[__ZL8LocalTZA + 4 >> 2], tempDoubleF64[0]);
    var $3 = $1 + $2;
    if ($2 < 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = _fmod($3, 864e5);
    var $12 = $6;
    __label__ = 4;
    break;
   case 3:
    var $8 = 864e5 - $3;
    var $9 = _fmod($8, 864e5);
    var $12 = -$9;
    __label__ = 4;
    break;
   case 4:
    var $12;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16DaylightSavingTAdP9JSContext($t, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL15JSDOUBLE_IS_NaNd1014($t);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $t;
      __label__ = 5;
      break;
    }
   case 2:
    if ($t < 0 | $t > 21459168e5) {
      __label__ = 3;
      break;
    } else {
      var $_02 = $t;
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZL12YearFromTimed($t);
    var $8 = __ZL20EquivalentYearForDSTi($7);
    var $9 = $8 | 0;
    var $10 = __ZL13MonthFromTimed($t);
    var $11 = $10 | 0;
    var $12 = __ZL12DateFromTimed($t);
    var $13 = $12 | 0;
    var $14 = __ZL7MakeDayddd($9, $11, $13);
    var $15 = $14 * 864e5;
    var $16 = __ZL13TimeWithinDayd($t);
    var $_02 = $15 + $16;
    __label__ = 4;
    break;
   case 4:
    var $_02;
    var $19$0 = $_02 >>> 0;
    var $19$1 = Math.min(Math.floor($_02 / 4294967296), 4294967295);
    var $20 = $cx + 236 | 0;
    var $21 = __ZN14DSTOffsetCache24getDSTOffsetMillisecondsExP9JSContext($20, $19$0, $19$1);
    var $_0 = $21[0] + $21[1] * 4294967296;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20EquivalentYearForDSTi($year) {
  var $3 = $year * 365 - 719050 | 0;
  var $6 = ($year - 1969 | 0) * .25;
  var $7 = _floor($6);
  var $8 = $3 + $7;
  var $11 = ($year - 1901 | 0) / 100;
  var $12 = _floor($11);
  var $13 = $8 - $12;
  var $16 = ($year - 1601 | 0) / 400;
  var $17 = _floor($16);
  var $21 = (($13 + $17 & -1) + 4 | 0) % 7;
  var $_ = ($21 | 0) < 0 ? $21 + 7 | 0 : $21;
  var $24 = __ZL10IsLeapYeari($year);
  return HEAP32[__ZL16yearStartingWith + ($24 & 1) * 28 + ($_ << 2) >> 2];
}

function __ZL7MakeDayddd($year, $month, $date) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $month / 12;
    var $2 = _floor($1);
    var $3 = $2 + $year;
    var $4 = _fmod($month, 12);
    if ($4 < 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $4;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $4 + 12;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    var $9 = $3 & -1;
    var $10 = __ZL10IsLeapYeari($9);
    var $11 = $10 & 1;
    var $13 = ($3 - 1970) * 365;
    var $15 = ($3 - 1969) * .25;
    var $16 = _floor($15);
    var $17 = $13 + $16;
    var $19 = ($3 - 1901) / 100;
    var $20 = _floor($19);
    var $21 = $17 - $20;
    var $23 = ($3 - 1601) / 400;
    var $24 = _floor($23);
    var $27 = ($21 + $24) * 864e5 / 864e5;
    var $28 = _floor($27);
    var $30 = __ZL15firstDayOfMonth + $11 * 104 + (($_0 & -1) << 3) | 0;
    var $31 = (tempDoubleI32[0] = HEAP32[$30 >> 2], tempDoubleI32[1] = HEAP32[$30 + 4 >> 2], tempDoubleF64[0]);
    return $28 + $31 + $date - 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13TimeWithinDayd($t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _fmod($t, 864e5);
    if ($1 < 0) {
      __label__ = 2;
      break;
    } else {
      var $result_0 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    var $result_0 = $1 + 864e5;
    __label__ = 3;
    break;
   case 3:
    var $result_0;
    return $result_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL14UndefinedValueEv1024($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN8JSObject14setDateUTCTimeERKN2JS5ValueE($this, $time_0_0_0_val$0, $time_0_0_0_val$1) {
  var $1 = $this;
  __ZN8JSObject12setFixedSlotEjRKN2JS5ValueE($1, 0, $time_0_0_0_val$0, $time_0_0_0_val$1);
  return;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1027($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js9DateClassE + 4 >> 2] >>> 24;
    var $4 = $cx;
    var $5 = __ZNK9JSContext5hasfpEv($4);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $8;
    var $9 = $cx;
    var $10 = $global;
    var $11 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($9, $10);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $19 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $13 = __ZNK9JSContext2fpEv($4);
    var $14 = __ZNK2js10StackFrame10scopeChainEv($13);
    var $15 = $14;
    var $16 = __ZNK8JSObject9getGlobalEv($15);
    var $17 = $16;
    HEAP32[$global >> 2] = $17;
    var $19 = $17;
    __label__ = 5;
    break;
   case 5:
    var $19;
    var $20 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $19, $20);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $22 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $24 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $25 = $24;
    HEAP32[$proto >> 2] = $25;
    var $32 = $25;
    __label__ = 9;
    break;
   case 7:
    var $27 = $cx;
    var $29 = $proto;
    var $30 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($27, $19, $3, $29, __ZN2js9DateClassE);
    if ($30) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $32 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $32;
    var $33 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1028($cx, $32, $19, $kind);
    var $_0 = $33;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1027["X"] = 1;

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1028($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $proto;
    var $2 = $cx;
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($1, $2, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($2, $kind);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_0 = $7;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $parent;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, __ZN2js9DateClassE, $3, $10, 0, (__ZN2js9DateClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $11 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($3, $2, __ZN2js9DateClassE, $kind);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $11 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($6, $14);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11ObjectValueER8JSObject1038($agg_result, $obj) {
  var $1 = $obj;
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $1);
  return;
}

function __ZNK16JSAutoByteStringntEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js7unicode8CharInfoEt($code) {
  var $1 = $code & 65535;
  return __ZN2js7unicode11js_charinfoE + (HEAPU16[__ZN2js7unicode6index2E + (((HEAPU16[__ZN2js7unicode6index1E + ($1 >>> 6 << 1) >> 1] & 65535) << 6 | $1 & 63) << 1) >> 1] & 65535) * 6 | 0;
}

function __ZL10fractionalPdPKtPjj($result, $s, $i, $limit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$i >> 2];
    tempDoubleF64[0] = 0, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $factor_0 = .1;
    var $3 = HEAP32[$i >> 2];
    __label__ = 2;
    break;
   case 2:
    var $3;
    var $factor_0;
    if ($3 >>> 0 < $limit >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $7 = HEAPU16[$s + ($3 << 1) >> 1];
    if (($7 & 65535) > 47 & ($7 & 65535) < 58) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = (($7 & 65535) - 48 | 0) * $factor_0;
    var $15 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $16 = $15 + $14;
    tempDoubleF64[0] = $16, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $19 = HEAP32[$i >> 2] + 1 | 0;
    HEAP32[$i >> 2] = $19;
    var $factor_0 = $factor_0 * .1;
    var $3 = $19;
    __label__ = 2;
    break;
   case 5:
    return ($3 | 0) != ($1 | 0) & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL6digitsPjPKtS_j($result, $s, $i, $limit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$i >> 2];
    HEAP32[$result >> 2] = 0;
    var $3 = HEAP32[$i >> 2];
    __label__ = 2;
    break;
   case 2:
    var $3;
    if ($3 >>> 0 < $limit >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    if ((HEAP16[$s + ($3 << 1) >> 1] - 48 & 65535 & 65535) < 10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = HEAP32[$result >> 2] * 10 | 0;
    HEAP32[$result >> 2] = $11;
    var $17 = $11 - 48 + (HEAPU16[$s + (HEAP32[$i >> 2] << 1) >> 1] & 65535) | 0;
    HEAP32[$result >> 2] = $17;
    var $19 = HEAP32[$i >> 2] + 1 | 0;
    HEAP32[$i >> 2] = $19;
    var $3 = $19;
    __label__ = 2;
    break;
   case 5:
    return ($3 | 0) != ($1 | 0) & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19date_parseISOStringP14JSLinearStringPdP9JSContext($str, $result, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $year = __stackBase__ + 4;
    var $month = __stackBase__ + 8;
    var $day = __stackBase__ + 12;
    var $hour = __stackBase__ + 16;
    var $min = __stackBase__ + 20;
    var $sec = __stackBase__ + 24;
    var $frac = __stackBase__ + 28;
    var $tzHour = __stackBase__ + 36;
    var $tzMin = __stackBase__ + 40;
    HEAP32[$i >> 2] = 0;
    HEAP32[$year >> 2] = 1970;
    HEAP32[$month >> 2] = 1;
    HEAP32[$day >> 2] = 1;
    HEAP32[$hour >> 2] = 0;
    HEAP32[$min >> 2] = 0;
    HEAP32[$sec >> 2] = 0;
    tempDoubleF64[0] = 0, HEAP32[$frac >> 2] = tempDoubleI32[0], HEAP32[$frac + 4 >> 2] = tempDoubleI32[1];
    HEAP32[$tzHour >> 2] = 0;
    HEAP32[$tzMin >> 2] = 0;
    var $str_idx_val = HEAP32[$str + 4 >> 2];
    var $1 = __ZNK14JSLinearString5charsEv($str_idx_val);
    var $_idx_val = HEAP32[$str >> 2];
    var $2 = __ZNK8JSString6lengthEv($_idx_val);
    if (($2 | 0) != 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    if (HEAP16[$1 >> 1] << 16 >> 16 == 43) {
      var $dateMul_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (HEAP16[$1 >> 1] << 16 >> 16 == 45) {
      var $dateMul_0 = -1;
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $dateMul_0;
    HEAP32[$i >> 2] = 1;
    var $10 = __ZL7ndigitsjPjPKtS_j(6, $year, $1, $i, $2);
    if (($10 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      var $dateMul_1 = $dateMul_0;
      __label__ = 7;
      break;
    }
   case 5:
    if (HEAP16[$1 >> 1] << 16 >> 16 == 84) {
      var $dateMul_1 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = __ZL7ndigitsjPjPKtS_j(4, $year, $1, $i, $2);
    if (($16 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      var $dateMul_1 = 1;
      __label__ = 7;
      break;
    }
   case 7:
    var $dateMul_1;
    var $18 = HEAPU32[$i >> 2];
    if ($18 >>> 0 < $2 >>> 0) {
      __label__ = 8;
      break;
    } else {
      var $40 = $18;
      __label__ = 14;
      break;
    }
   case 8:
    if (HEAP16[$1 + ($18 << 1) >> 1] << 16 >> 16 == 45) {
      __label__ = 9;
      break;
    } else {
      var $40 = $18;
      __label__ = 14;
      break;
    }
   case 9:
    HEAP32[$i >> 2] = $18 + 1 | 0;
    var $26 = __ZL7ndigitsjPjPKtS_j(2, $month, $1, $i, $2);
    if (($26 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $29 = HEAPU32[$i >> 2];
    if ($29 >>> 0 < $2 >>> 0) {
      __label__ = 11;
      break;
    } else {
      var $40 = $29;
      __label__ = 14;
      break;
    }
   case 11:
    if (HEAP16[$1 + ($29 << 1) >> 1] << 16 >> 16 == 45) {
      __label__ = 12;
      break;
    } else {
      var $40 = $29;
      __label__ = 14;
      break;
    }
   case 12:
    HEAP32[$i >> 2] = $29 + 1 | 0;
    var $37 = __ZL7ndigitsjPjPKtS_j(2, $day, $1, $i, $2);
    if (($37 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $40 = HEAP32[$i >> 2];
    __label__ = 14;
    break;
   case 14:
    var $40;
    if ($40 >>> 0 < $2 >>> 0) {
      __label__ = 15;
      break;
    } else {
      var $isLocalTime_0 = 0;
      var $tzMul_1 = 1;
      __label__ = 36;
      break;
    }
   case 15:
    if (HEAP16[$1 + ($40 << 1) >> 1] << 16 >> 16 == 84) {
      __label__ = 16;
      break;
    } else {
      var $isLocalTime_0 = 0;
      var $tzMul_1 = 1;
      __label__ = 36;
      break;
    }
   case 16:
    HEAP32[$i >> 2] = $40 + 1 | 0;
    var $48 = __ZL7ndigitsjPjPKtS_j(2, $hour, $1, $i, $2);
    if (($48 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $51 = HEAPU32[$i >> 2];
    if ($51 >>> 0 < $2 >>> 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 18:
    if (HEAP16[$1 + ($51 << 1) >> 1] << 16 >> 16 == 58) {
      __label__ = 19;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 19:
    HEAP32[$i >> 2] = $51 + 1 | 0;
    var $59 = __ZL7ndigitsjPjPKtS_j(2, $min, $1, $i, $2);
    if (($59 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $62 = HEAPU32[$i >> 2];
    if ($62 >>> 0 < $2 >>> 0) {
      __label__ = 21;
      break;
    } else {
      var $84 = $62;
      __label__ = 27;
      break;
    }
   case 21:
    if (HEAP16[$1 + ($62 << 1) >> 1] << 16 >> 16 == 58) {
      __label__ = 22;
      break;
    } else {
      var $84 = $62;
      __label__ = 27;
      break;
    }
   case 22:
    HEAP32[$i >> 2] = $62 + 1 | 0;
    var $70 = __ZL7ndigitsjPjPKtS_j(2, $sec, $1, $i, $2);
    if (($70 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $73 = HEAPU32[$i >> 2];
    if ($73 >>> 0 < $2 >>> 0) {
      __label__ = 24;
      break;
    } else {
      var $84 = $73;
      __label__ = 27;
      break;
    }
   case 24:
    if (HEAP16[$1 + ($73 << 1) >> 1] << 16 >> 16 == 46) {
      __label__ = 25;
      break;
    } else {
      var $84 = $73;
      __label__ = 27;
      break;
    }
   case 25:
    HEAP32[$i >> 2] = $73 + 1 | 0;
    var $81 = __ZL10fractionalPdPKtPjj($frac, $1, $i, $2);
    if (($81 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $84 = HEAP32[$i >> 2];
    __label__ = 27;
    break;
   case 27:
    var $84;
    if ($84 >>> 0 < $2 >>> 0) {
      __label__ = 28;
      break;
    } else {
      var $isLocalTime_0 = 1;
      var $tzMul_1 = 1;
      __label__ = 36;
      break;
    }
   case 28:
    if (HEAP16[$1 + ($84 << 1) >> 1] << 16 >> 16 == 90) {
      __label__ = 29;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 29:
    HEAP32[$i >> 2] = $84 + 1 | 0;
    var $isLocalTime_0 = 0;
    var $tzMul_1 = 1;
    __label__ = 36;
    break;
   case 30:
    if (HEAP16[$1 + ($84 << 1) >> 1] << 16 >> 16 == 43) {
      var $tzMul_0 = 1;
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    if (HEAP16[$1 + ($84 << 1) >> 1] << 16 >> 16 == 45) {
      var $tzMul_0 = -1;
      __label__ = 32;
      break;
    } else {
      var $isLocalTime_0 = 1;
      var $tzMul_1 = 1;
      __label__ = 36;
      break;
    }
   case 32:
    var $tzMul_0;
    HEAP32[$i >> 2] = $84 + 1 | 0;
    var $101 = __ZL7ndigitsjPjPKtS_j(2, $tzHour, $1, $i, $2);
    if (($101 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $104 = HEAPU32[$i >> 2];
    if ($104 >>> 0 < $2 >>> 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 34:
    if (HEAP16[$1 + ($104 << 1) >> 1] << 16 >> 16 == 58) {
      __label__ = 35;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 35:
    HEAP32[$i >> 2] = $104 + 1 | 0;
    var $112 = __ZL7ndigitsjPjPKtS_j(2, $tzMin, $1, $i, $2);
    if (($112 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      var $isLocalTime_0 = 0;
      var $tzMul_1 = $tzMul_0;
      __label__ = 36;
      break;
    }
   case 36:
    var $tzMul_1;
    var $isLocalTime_0;
    var $114 = HEAPU32[$year >> 2];
    if ($114 >>> 0 > 275943) {
      __label__ = 53;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $117 = HEAPU32[$month >> 2];
    if (($117 | 0) == 0 | $117 >>> 0 > 12) {
      __label__ = 53;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $121 = HEAPU32[$day >> 2];
    if (($121 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $124 = __ZL11DaysInMonthii($114, $117);
    if ($121 >>> 0 > $124 >>> 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $127 = HEAPU32[$hour >> 2];
    if ($127 >>> 0 > 24) {
      __label__ = 53;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    var $131 = HEAPU32[$min >> 2];
    if (($127 | 0) == 24) {
      __label__ = 42;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 42:
    if (($131 | 0) == 0) {
      __label__ = 43;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 43:
    var $135 = HEAPU32[$sec >> 2];
    if (($135 | 0) == 0) {
      var $141 = $135;
      var $140 = $131;
      __label__ = 46;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 44:
    if ($131 >>> 0 > 59) {
      __label__ = 53;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $_pr = HEAPU32[$sec >> 2];
    if ($_pr >>> 0 > 59) {
      __label__ = 53;
      break;
    } else {
      var $141 = $_pr;
      var $140 = $131;
      __label__ = 46;
      break;
    }
   case 46:
    var $140;
    var $141;
    var $142 = HEAPU32[$tzHour >> 2];
    if ($142 >>> 0 > 23) {
      __label__ = 53;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $145 = HEAPU32[$tzMin >> 2];
    if ($145 >>> 0 > 59) {
      __label__ = 53;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    if ((HEAP32[$i >> 2] | 0) == ($2 | 0)) {
      __label__ = 49;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 49:
    var $151 = $117 - 1 | 0;
    HEAP32[$month >> 2] = $151;
    var $154 = ($dateMul_1 | 0) * ($114 >>> 0);
    var $155 = $151 >>> 0;
    var $156 = $121 >>> 0;
    var $157 = $127 >>> 0;
    var $160 = (tempDoubleI32[0] = HEAP32[$frac >> 2], tempDoubleI32[1] = HEAP32[$frac + 4 >> 2], tempDoubleF64[0]);
    var $161 = $160 * 1e3;
    var $162 = __ZL17date_msecFromDateddddddd($154, $155, $156, $157, $140 >>> 0, $141 >>> 0, $161);
    if ($isLocalTime_0) {
      __label__ = 50;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 50:
    var $164 = __ZL3UTCdP9JSContext($162, $cx);
    var $msec_0 = $164;
    __label__ = 52;
    break;
   case 51:
    var $msec_0 = $162 - ($tzMul_1 | 0) * (($142 >>> 0) * 36e5 + ($145 >>> 0) * 6e4);
    __label__ = 52;
    break;
   case 52:
    var $msec_0;
    if ($msec_0 < -864e13 | $msec_0 > 864e13) {
      __label__ = 53;
      break;
    } else {
      var $_0 = 1;
      var $storemerge = $msec_0;
      __label__ = 54;
      break;
    }
   case 53:
    var $_0 = 0;
    var $storemerge = 0;
    __label__ = 54;
    break;
   case 54:
    var $storemerge;
    var $_0;
    tempDoubleF64[0] = $storemerge, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19date_parseISOStringP14JSLinearStringPdP9JSContext["X"] = 1;

function __ZL18date_regionMatchesPKciPKtiii($s1, $s2, $s2off, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_0 = 0;
    var $_02 = $count;
    var $_03 = $s2off;
    __label__ = 2;
    break;
   case 2:
    var $_03;
    var $_02;
    var $_0;
    if (($_02 | 0) > 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    var $5 = HEAP8[$s1 + $_0 | 0];
    if ($5 << 24 >> 24 == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = HEAP16[$s2 + ($_03 << 1) >> 1];
    if ($9 << 16 >> 16 == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $5 << 24 >> 24;
    var $13 = __ZN2js7unicode11ToLowerCaseEt($12);
    var $14 = __ZN2js7unicode11ToLowerCaseEt($9);
    if ($13 << 16 >> 16 == $14 << 16 >> 16) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $_0 = $_0 + 1 | 0;
    var $_02 = $_02 - 1 | 0;
    var $_03 = $_03 + 1 | 0;
    __label__ = 2;
    break;
   case 7:
    return ($_02 | 0) == 0 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7unicode11ToLowerCaseEt($ch) {
  var $1 = __ZN2js7unicode8CharInfoEt($ch);
  var $8 = (HEAP8[$1 + 4 | 0] & 8) << 24 >> 24 == 0 ? $ch : 0;
  return $8 + HEAP16[$1 + 2 >> 1] & 65535;
}

function __ZL7ndigitsjPjPKtS_j($n, $result, $s, $i, $limit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[$i >> 2];
    var $2 = $1 + $n | 0;
    var $limit_ = $2 >>> 0 > $limit >>> 0 ? $limit : $2;
    var $4 = __ZL6digitsPjPKtS_j($result, $s, $i, $limit_);
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP32[$i >> 2] - $1 | 0) == ($n | 0) & 1;
    __label__ = 4;
    break;
   case 3:
    HEAP32[$i >> 2] = $1;
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11DaysInMonthii($year, $month) {
  var $1 = __ZL10IsLeapYeari($year);
  var $2 = $1 & 1;
  var $3 = __ZL15firstDayOfMonth + $2 * 104 + ($month << 3) | 0;
  var $4 = (tempDoubleI32[0] = HEAP32[$3 >> 2], tempDoubleI32[1] = HEAP32[$3 + 4 >> 2], tempDoubleF64[0]);
  var $6 = __ZL15firstDayOfMonth + $2 * 104 + ($month - 1 << 3) | 0;
  var $7 = (tempDoubleI32[0] = HEAP32[$6 >> 2], tempDoubleI32[1] = HEAP32[$6 + 4 >> 2], tempDoubleF64[0]);
  return $4 - $7 & -1;
}

function __ZL11new_explodedP8PRMJTimeP9JSContext($timeval, $split, $cx) {
  var $1 = __ZL12YearFromTimed($timeval);
  var $2 = __ZL10msFromTimed($timeval);
  HEAP32[$split >> 2] = $2 * 1e3 | 0;
  var $5 = __ZL11SecFromTimed($timeval);
  HEAP8[$split + 4 | 0] = $5 & 255;
  var $8 = __ZL11MinFromTimed($timeval);
  HEAP8[$split + 5 | 0] = $8 & 255;
  var $11 = __ZL12HourFromTimed($timeval);
  HEAP8[$split + 6 | 0] = $11 & 255;
  var $14 = __ZL12DateFromTimed($timeval);
  HEAP8[$split + 7 | 0] = $14 & 255;
  var $17 = __ZL13MonthFromTimed($timeval);
  HEAP8[$split + 8 | 0] = $17 & 255;
  var $20 = __ZL7WeekDayd($timeval);
  HEAP8[$split + 9 | 0] = $20 & 255;
  HEAP32[$split + 12 >> 2] = $1;
  var $24 = $timeval / 864e5;
  var $25 = _floor($24);
  var $28 = $1 * 365 - 719050 | 0;
  var $31 = ($1 - 1969 | 0) * .25;
  var $32 = _floor($31);
  var $33 = $28 + $32;
  var $36 = ($1 - 1901 | 0) / 100;
  var $37 = _floor($36);
  var $38 = $33 - $37;
  var $41 = ($1 - 1601 | 0) / 400;
  var $42 = _floor($41);
  HEAP16[$split + 16 >> 1] = $25 - ($38 + $42) & -1 & 65535;
  var $48 = __ZL16DaylightSavingTAdP9JSContext($timeval, $cx);
  HEAP8[$split + 18 | 0] = $48 != 0 & 1;
  return;
}

__ZL11new_explodedP8PRMJTimeP9JSContext["X"] = 1;

function __ZL10msFromTimed($t) {
  var $1 = _fmod($t, 1e3);
  var $2 = $1 & -1;
  var $_ = ($2 | 0) < 0 ? $2 + 1e3 | 0 : $2;
  return $_;
}

function __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $dp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL10GetUTCTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $6, $vp, $dp);
    var $_0 = ($7 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $vp_idx1 = $vp | 0;
    var $vp_idx1_val$0 = HEAP32[$vp_idx1 >> 2];
    var $vp_idx1_val$1 = HEAP32[$vp_idx1 + 4 >> 2];
    var $1 = __ZNK2JS5Value11isPrimitiveEv($vp_idx1_val$0, $vp_idx1_val$1);
    if ($1) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($vp_idx1_val$0, $vp_idx1_val$1);
    var $4 = $3;
    var $5 = __ZN8JSObject12defaultValueEP9JSContext6JSTypePN2JS5ValueE($4, $cx, 4, $vp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13js_IsCallableRKN2JS5ValueE1052($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZN8JSObject10isCallableEv($_idx_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject12defaultValueEP9JSContext6JSTypePN2JS5ValueE($this, $cx, $hint, $vp) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $2 = __ZNK8JSObject8getClassEv($_idx_val);
  var $4 = HEAP32[$2 + 32 >> 2];
  var $7 = ($4 | 0) == 86 ? 88 : $4;
  var $8 = FUNCTION_TABLE[$7]($cx, $this, $hint, $vp);
  return ($8 | 0) != 0;
}

function __ZL15date_utc_formatP9JSContextPN2JS5ValueEPFvPcjdE($cx, $vp, $printFunc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 108;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $utctime = __stackBase__;
    var $buf = __stackBase__ + 8;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $utctime);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$utctime >> 2], tempDoubleI32[1] = HEAP32[$utctime + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZL18JSDOUBLE_IS_FINITEd1004($3);
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    if (($printFunc | 0) == 82) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = $cx;
    _JS_ReportErrorNumber($9, 4, 24, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 5:
    var $11 = $buf | 0;
    var $12 = _JS_snprintf($11, 100, STRING_TABLE.__ZL15js_NaN_date_str | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 7;
    break;
   case 6:
    var $14 = $buf | 0;
    FUNCTION_TABLE[$printFunc]($14, 100, $3);
    __label__ = 7;
    break;
   case 7:
    var $16 = $buf | 0;
    var $17 = $cx;
    var $18 = _JS_NewStringCopyZ($17, $16);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2JS5Value9setStringEP8JSString($vp, $18);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16print_iso_stringPcjd($buf, $size, $utctime) {
  var __stackBase__ = STACKTOP;
  var $1 = __ZL12YearFromTimed($utctime);
  var $2 = __ZL13MonthFromTimed($utctime);
  var $3 = $2 + 1 | 0;
  var $4 = __ZL12DateFromTimed($utctime);
  var $5 = __ZL12HourFromTimed($utctime);
  var $6 = __ZL11MinFromTimed($utctime);
  var $7 = __ZL11SecFromTimed($utctime);
  var $8 = __ZL10msFromTimed($utctime);
  var $9 = _JS_snprintf($buf, $size, STRING_TABLE.__str103997 | 0, (tempInt = STACKTOP, STACKTOP += 28, HEAP32[tempInt >> 2] = $1, HEAP32[tempInt + 4 >> 2] = $3, HEAP32[tempInt + 8 >> 2] = $4, HEAP32[tempInt + 12 >> 2] = $5, HEAP32[tempInt + 16 >> 2] = $6, HEAP32[tempInt + 20 >> 2] = $7, HEAP32[tempInt + 24 >> 2] = $8, tempInt));
  STACKTOP = __stackBase__;
  return;
}

function __ZN16JSAutoByteStringC1EP9JSContextP8JSString($this, $cx, $str) {
  __ZN16JSAutoByteStringC2EP9JSContextP8JSString($this, $cx, $str);
  return;
}

function __ZL19date_toLocaleHelperP9JSContextP8JSObjectPKcPN2JS5ValueE($cx, $obj, $format, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 128;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $buf = __stackBase__;
    var $split = __stackBase__ + 100;
    var $utctime = __stackBase__ + 120;
    var $1 = __ZL10GetUTCTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $obj, $vp, $utctime);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = (tempDoubleI32[0] = HEAP32[$utctime >> 2], tempDoubleI32[1] = HEAP32[$utctime + 4 >> 2], tempDoubleF64[0]);
    var $5 = __ZL18JSDOUBLE_IS_FINITEd1004($4);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = $buf | 0;
    var $9 = _JS_snprintf($8, 100, STRING_TABLE.__ZL15js_NaN_date_str | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 15;
    break;
   case 4:
    var $11 = __ZL9LocalTimedP9JSContext($4, $cx);
    __ZL11new_explodedP8PRMJTimeP9JSContext($11, $split, $cx);
    var $12 = $buf | 0;
    var $13 = _PRMJ_FormatTime($12, $format, $split);
    if (($13 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = __ZL11date_formatP9JSContextd10formatspecPN2JS5ValueE($cx, $4, 0, $vp);
    var $_0 = $16;
    __label__ = 20;
    break;
   case 6:
    var $18 = _strcmp($format, STRING_TABLE.__str104998 | 0);
    if (($18 | 0) == 0 & ($13 | 0) > 5) {
      __label__ = 7;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 7:
    if (((HEAP8[$buf + ($13 - 3) | 0] << 24 >> 24) - 48 | 0) >>> 0 < 10) {
      __label__ = 15;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $28 = $buf + ($13 - 2) | 0;
    if (((HEAP8[$28] << 24 >> 24) - 48 | 0) >>> 0 < 10) {
      __label__ = 9;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 9:
    if (((HEAP8[$buf + ($13 - 1) | 0] << 24 >> 24) - 48 | 0) >>> 0 < 10) {
      __label__ = 10;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 10:
    if (((HEAP8[$12] << 24 >> 24) - 48 | 0) >>> 0 < 10) {
      __label__ = 11;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 11:
    if (((HEAP8[$buf + 1 | 0] << 24 >> 24) - 48 | 0) >>> 0 < 10) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    if (((HEAP8[$buf + 2 | 0] << 24 >> 24) - 48 | 0) >>> 0 < 10) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    if (((HEAP8[$buf + 3 | 0] << 24 >> 24) - 48 | 0) >>> 0 < 10) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $52 = 102 - $13 | 0;
    var $53 = __Z14js_DateGetYearP9JSContextP8JSObject($cx, $obj);
    var $54 = _JS_snprintf($28, $52, STRING_TABLE.__str4498 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $53, tempInt));
    __label__ = 15;
    break;
   case 15:
    var $57 = HEAP32[$cx + 36 >> 2];
    if (($57 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $61 = HEAP32[$57 + 12 >> 2];
    if (($61 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $64 = $buf | 0;
    var $65 = FUNCTION_TABLE[$61]($cx, $64, $vp);
    var $_0 = $65;
    __label__ = 20;
    break;
   case 18:
    var $67 = $buf | 0;
    var $68 = $cx;
    var $69 = _JS_NewStringCopyZ($68, $67);
    if (($69 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    __ZN2JS5Value9setStringEP8JSString($vp, $69);
    var $_0 = 1;
    __label__ = 20;
    break;
   case 20:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19date_toLocaleHelperP9JSContextP8JSObjectPKcPN2JS5ValueE["X"] = 1;

function __ZN16JSAutoByteStringC2EP9JSContextP8JSString($this, $cx, $str) {
  var $1 = $this | 0;
  var $2 = $cx;
  var $3 = _JS_EncodeString($2, $str);
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZL16print_gmt_stringPcjd($buf, $size, $utctime) {
  var __stackBase__ = STACKTOP;
  var $1 = __ZL7WeekDayd($utctime);
  var $3 = HEAP32[__ZL4days + ($1 << 2) >> 2];
  var $4 = __ZL12DateFromTimed($utctime);
  var $5 = __ZL13MonthFromTimed($utctime);
  var $7 = HEAP32[__ZL6months + ($5 << 2) >> 2];
  var $8 = __ZL12YearFromTimed($utctime);
  var $9 = __ZL12HourFromTimed($utctime);
  var $10 = __ZL11MinFromTimed($utctime);
  var $11 = __ZL11SecFromTimed($utctime);
  var $12 = _JS_snprintf($buf, $size, STRING_TABLE.__str1081002 | 0, (tempInt = STACKTOP, STACKTOP += 28, HEAP32[tempInt >> 2] = $3, HEAP32[tempInt + 4 >> 2] = $4, HEAP32[tempInt + 8 >> 2] = $7, HEAP32[tempInt + 12 >> 2] = $8, HEAP32[tempInt + 16 >> 2] = $9, HEAP32[tempInt + 20 >> 2] = $10, HEAP32[tempInt + 24 >> 2] = $11, tempInt));
  STACKTOP = __stackBase__;
  return;
}

function _JSID_IS_INT1059($iden) {
  return $iden & 1;
}

function __ZN2jsL8JsvalifyEPNS_10StackFrameE($fp) {
  return $fp;
}

function _JS_SetRuntimeDebugMode($rt) {
  HEAP8[$rt + 144220 | 0] = 1;
  return;
}

function __ZN2js10StackFrame11setHookDataEPv($this, $v) {
  HEAP32[$this + 44 >> 2] = $v;
  var $2 = $this | 0;
  var $4 = HEAP32[$2 >> 2] | 65536;
  HEAP32[$2 >> 2] = $4;
  return;
}

function __ZN2js11GetGSNCacheEP9JSContext($cx_0_11_val) {
  return $cx_0_11_val + 144308 | 0;
}

function __ZN2js15AutoValueRooter3setEN2JS5ValueE($this, $_0_0_0_val$0, $_0_0_0_val$1) {
  var $_03 = $this + 16 | 0;
  HEAP32[$_03 >> 2] = $_0_0_0_val$0;
  HEAP32[$_03 + 4 >> 2] = $_0_0_0_val$1;
  return;
}

function __ZL13date_makeTimeP9JSContextjijPN2JS5ValueE($cx, $maxargs, $local, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $result = __stackBase__ + 32;
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZL10GetUTCTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $4, $vp, $result);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $11 = __ZL18JSDOUBLE_IS_FINITEd1004($10);
    if (($11 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = __ZN2JS5Value9setNumberEd($vp, $10);
    var $_0 = 1;
    __label__ = 36;
    break;
   case 5:
    if (($argc | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $cx_idx1_val = HEAP32[$cx + 52 >> 2];
    __ZL12SetDateToNaNP9JSContextP8JSObjectPN2JS5ValueE($cx_idx1_val, $4, $vp);
    var $_0 = 1;
    __label__ = 36;
    break;
   case 7:
    var $_01 = $argc >>> 0 > $maxargs >>> 0 ? $maxargs : $argc;
    var $i_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $i_0;
    if ($i_0 >>> 0 < $_01 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 9:
    var $23 = $vp + ($i_0 + 2 << 3) | 0;
    var $24 = $args + ($i_0 << 3) | 0;
    var $25 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($2, $23, $24);
    if ($25) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 36;
      break;
    }
   case 10:
    var $27 = (tempDoubleI32[0] = HEAP32[$24 >> 2], tempDoubleI32[1] = HEAP32[$24 + 4 >> 2], tempDoubleF64[0]);
    var $28 = __ZL18JSDOUBLE_IS_FINITEd1004($27);
    if (($28 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZL12SetDateToNaNP9JSContextP8JSObjectPN2JS5ValueE($cx_idx_val, $4, $vp);
    var $_0 = 1;
    __label__ = 36;
    break;
   case 12:
    var $32 = __ZL18js_DoubleToIntegerd1005($27);
    tempDoubleF64[0] = $32, HEAP32[$24 >> 2] = tempDoubleI32[0], HEAP32[$24 + 4 >> 2] = tempDoubleI32[1];
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 8;
    break;
   case 13:
    var $35 = ($local | 0) != 0;
    if ($35) {
      __label__ = 14;
      break;
    } else {
      var $lorutime_0 = $10;
      __label__ = 15;
      break;
    }
   case 14:
    var $37 = __ZL9LocalTimedP9JSContext($10, $cx);
    var $lorutime_0 = $37;
    __label__ = 15;
    break;
   case 15:
    var $lorutime_0;
    var $39 = $args | 0;
    var $40 = $args + ($_01 << 3) | 0;
    if ($maxargs >>> 0 > 3 & ($_01 | 0) > 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $44 = $args + 8 | 0;
    var $45 = (tempDoubleI32[0] = HEAP32[$39 >> 2], tempDoubleI32[1] = HEAP32[$39 + 4 >> 2], tempDoubleF64[0]);
    var $hour_0 = $45;
    var $argp_0 = $44;
    __label__ = 18;
    break;
   case 17:
    var $47 = __ZL12HourFromTimed($lorutime_0);
    var $hour_0 = $47 | 0;
    var $argp_0 = $39;
    __label__ = 18;
    break;
   case 18:
    var $argp_0;
    var $hour_0;
    if ($maxargs >>> 0 > 2 & $argp_0 >>> 0 < $40 >>> 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $54 = (tempDoubleI32[0] = HEAP32[$argp_0 >> 2], tempDoubleI32[1] = HEAP32[$argp_0 + 4 >> 2], tempDoubleF64[0]);
    var $min_0 = $54;
    var $argp_1 = $argp_0 + 8 | 0;
    __label__ = 21;
    break;
   case 20:
    var $56 = __ZL11MinFromTimed($lorutime_0);
    var $min_0 = $56 | 0;
    var $argp_1 = $argp_0;
    __label__ = 21;
    break;
   case 21:
    var $argp_1;
    var $min_0;
    if ($maxargs >>> 0 > 1 & $argp_1 >>> 0 < $40 >>> 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    var $63 = (tempDoubleI32[0] = HEAP32[$argp_1 >> 2], tempDoubleI32[1] = HEAP32[$argp_1 + 4 >> 2], tempDoubleF64[0]);
    var $sec_0 = $63;
    var $argp_2 = $argp_1 + 8 | 0;
    __label__ = 24;
    break;
   case 23:
    var $65 = __ZL11SecFromTimed($lorutime_0);
    var $sec_0 = $65 | 0;
    var $argp_2 = $argp_1;
    __label__ = 24;
    break;
   case 24:
    var $argp_2;
    var $sec_0;
    if (($maxargs | 0) != 0 & $argp_2 >>> 0 < $40 >>> 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    var $71 = (tempDoubleI32[0] = HEAP32[$argp_2 >> 2], tempDoubleI32[1] = HEAP32[$argp_2 + 4 >> 2], tempDoubleF64[0]);
    var $msec_0 = $71;
    __label__ = 27;
    break;
   case 26:
    var $73 = __ZL10msFromTimed($lorutime_0);
    var $msec_0 = $73 | 0;
    __label__ = 27;
    break;
   case 27:
    var $msec_0;
    var $81 = (($hour_0 * 60 + $min_0) * 60 + $sec_0) * 1e3 + $msec_0;
    var $83 = _floor($lorutime_0 / 864e5);
    var $85 = $83 * 864e5 + $81;
    tempDoubleF64[0] = $85, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    if ($35) {
      __label__ = 28;
      break;
    } else {
      var $89 = $85;
      __label__ = 29;
      break;
    }
   case 28:
    var $87 = __ZL3UTCdP9JSContext($85, $cx);
    tempDoubleF64[0] = $87, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $89 = $87;
    __label__ = 29;
    break;
   case 29:
    var $89;
    var $90 = __ZL18JSDOUBLE_IS_FINITEd1004($89);
    if (($90 | 0) == 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    if ($89 < 0) {
      __label__ = 31;
      break;
    } else {
      var $97 = $89;
      __label__ = 32;
      break;
    }
   case 31:
    var $97 = -$89;
    __label__ = 32;
    break;
   case 32:
    var $97;
    if ($97 > 864e13) {
      __label__ = 34;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $101 = __ZL18js_DoubleToIntegerd1005($89);
    var $105 = $101;
    __label__ = 35;
    break;
   case 34:
    var $103 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $105 = $103;
    __label__ = 35;
    break;
   case 35:
    var $105;
    __ZL10SetUTCTimeP9JSContextP8JSObjectdPN2JS5ValueE($4, $105, $vp);
    var $_0 = 1;
    __label__ = 36;
    break;
   case 36:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13date_makeTimeP9JSContextjijPN2JS5ValueE["X"] = 1;

function __ZL13date_makeDateP9JSContextjijPN2JS5ValueE($cx, $maxargs, $local, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $result = __stackBase__ + 24;
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZL10GetUTCTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $4, $vp, $result);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($argc | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $cx_idx1_val = HEAP32[$cx + 52 >> 2];
    __ZL12SetDateToNaNP9JSContextP8JSObjectPN2JS5ValueE($cx_idx1_val, $4, $vp);
    var $_0 = 1;
    __label__ = 34;
    break;
   case 5:
    var $_01 = $argc >>> 0 > $maxargs >>> 0 ? $maxargs : $argc;
    var $i_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $i_0;
    if ($i_0 >>> 0 < $_01 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 7:
    var $17 = $vp + ($i_0 + 2 << 3) | 0;
    var $18 = $args + ($i_0 << 3) | 0;
    var $19 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($2, $17, $18);
    if ($19) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 34;
      break;
    }
   case 8:
    var $21 = (tempDoubleI32[0] = HEAP32[$18 >> 2], tempDoubleI32[1] = HEAP32[$18 + 4 >> 2], tempDoubleF64[0]);
    var $22 = __ZL18JSDOUBLE_IS_FINITEd1004($21);
    if (($22 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZL12SetDateToNaNP9JSContextP8JSObjectPN2JS5ValueE($cx_idx_val, $4, $vp);
    var $_0 = 1;
    __label__ = 34;
    break;
   case 10:
    var $26 = __ZL18js_DoubleToIntegerd1005($21);
    tempDoubleF64[0] = $26, HEAP32[$18 >> 2] = tempDoubleI32[0], HEAP32[$18 + 4 >> 2] = tempDoubleI32[1];
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 6;
    break;
   case 11:
    var $29 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $30 = __ZL18JSDOUBLE_IS_FINITEd1004($29);
    if (($30 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    if ($maxargs >>> 0 < 3) {
      __label__ = 13;
      break;
    } else {
      var $lorutime_0 = 0;
      __label__ = 16;
      break;
    }
   case 13:
    __ZN2JS5Value9setDoubleEd($vp, $29);
    var $_0 = 1;
    __label__ = 34;
    break;
   case 14:
    if (($local | 0) == 0) {
      var $lorutime_0 = $29;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $38 = __ZL9LocalTimedP9JSContext($29, $cx);
    var $lorutime_0 = $38;
    __label__ = 16;
    break;
   case 16:
    var $lorutime_0;
    var $40 = $args | 0;
    var $41 = $args + ($_01 << 3) | 0;
    if ($maxargs >>> 0 > 2 & ($_01 | 0) > 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $45 = $args + 8 | 0;
    var $46 = (tempDoubleI32[0] = HEAP32[$40 >> 2], tempDoubleI32[1] = HEAP32[$40 + 4 >> 2], tempDoubleF64[0]);
    var $year_0 = $46;
    var $argp_0 = $45;
    __label__ = 19;
    break;
   case 18:
    var $48 = __ZL12YearFromTimed($lorutime_0);
    var $year_0 = $48 | 0;
    var $argp_0 = $40;
    __label__ = 19;
    break;
   case 19:
    var $argp_0;
    var $year_0;
    if ($maxargs >>> 0 > 1 & $argp_0 >>> 0 < $41 >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $55 = (tempDoubleI32[0] = HEAP32[$argp_0 >> 2], tempDoubleI32[1] = HEAP32[$argp_0 + 4 >> 2], tempDoubleF64[0]);
    var $month_0 = $55;
    var $argp_1 = $argp_0 + 8 | 0;
    __label__ = 22;
    break;
   case 21:
    var $57 = __ZL13MonthFromTimed($lorutime_0);
    var $month_0 = $57 | 0;
    var $argp_1 = $argp_0;
    __label__ = 22;
    break;
   case 22:
    var $argp_1;
    var $month_0;
    if (($maxargs | 0) != 0 & $argp_1 >>> 0 < $41 >>> 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $63 = (tempDoubleI32[0] = HEAP32[$argp_1 >> 2], tempDoubleI32[1] = HEAP32[$argp_1 + 4 >> 2], tempDoubleF64[0]);
    var $day_0 = $63;
    __label__ = 25;
    break;
   case 24:
    var $65 = __ZL12DateFromTimed($lorutime_0);
    var $day_0 = $65 | 0;
    __label__ = 25;
    break;
   case 25:
    var $day_0;
    var $68 = __ZL7MakeDayddd($year_0, $month_0, $day_0);
    var $69 = $68 * 864e5;
    var $70 = __ZL13TimeWithinDayd($lorutime_0);
    var $71 = $69 + $70;
    tempDoubleF64[0] = $71, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    if (($local | 0) == 0) {
      var $76 = $71;
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $74 = __ZL3UTCdP9JSContext($71, $cx);
    tempDoubleF64[0] = $74, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $76 = $74;
    __label__ = 27;
    break;
   case 27:
    var $76;
    var $77 = __ZL18JSDOUBLE_IS_FINITEd1004($76);
    if (($77 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    if ($76 < 0) {
      __label__ = 29;
      break;
    } else {
      var $84 = $76;
      __label__ = 30;
      break;
    }
   case 29:
    var $84 = -$76;
    __label__ = 30;
    break;
   case 30:
    var $84;
    if ($84 > 864e13) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $88 = __ZL18js_DoubleToIntegerd1005($76);
    var $92 = $88;
    __label__ = 33;
    break;
   case 32:
    var $90 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $92 = $90;
    __label__ = 33;
    break;
   case 33:
    var $92;
    __ZL10SetUTCTimeP9JSContextP8JSObjectdPN2JS5ValueE($4, $92, $vp);
    var $_0 = 1;
    __label__ = 34;
    break;
   case 34:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13date_makeDateP9JSContextjijPN2JS5ValueE["X"] = 1;

function _JS_GetDebugMode($cx_0_12_val) {
  var $_idx_val = HEAP32[$cx_0_12_val + 804 >> 2];
  var $2 = __ZNK13JSCompartment9debugModeEv($_idx_val);
  return $2 & 1;
}

function _JS_SetDebugMode($cx, $debug) {
  var $2 = HEAP32[$cx + 56 >> 2];
  var $3 = _JS_SetDebugModeForCompartment($cx, $2, $debug);
  return $3;
}

function _JS_SetDebugModeForCompartment($cx, $comp, $debug) {
  var $1 = ($debug | 0) != 0;
  var $2 = $comp;
  var $3 = $cx;
  var $4 = __ZN13JSCompartment17setDebugModeFromCEP9JSContextb($2, $3, $1);
  return $4 & 1;
}

function __ZN2js19ScriptDebugPrologueEP9JSContextPNS_10StackFrameE($cx, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$fp >> 2];
    var $1 = __ZNK2js10StackFrame22isFramePushedByExecuteEv($_idx_val);
    var $3 = HEAP32[$cx + 200 >> 2];
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = HEAP32[$3 + 40 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZN2jsL8JsvalifyEPNS_10StackFrameE($fp);
    var $11 = HEAP32[$3 + 44 >> 2];
    var $12 = FUNCTION_TABLE[$6]($cx, $9, 1, 0, $11);
    __ZN2js10StackFrame11setHookDataEPv($fp, $12);
    __label__ = 6;
    break;
   case 4:
    var $15 = HEAP32[$3 + 48 >> 2];
    if (($15 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = __ZN2jsL8JsvalifyEPNS_10StackFrameE($fp);
    var $20 = HEAP32[$3 + 52 >> 2];
    var $21 = FUNCTION_TABLE[$15]($cx, $18, 1, 0, $20);
    __ZN2js10StackFrame11setHookDataEPv($fp, $21);
    __label__ = 6;
    break;
   case 6:
    __ZN2js8Debugger12onEnterFrameEP9JSContext($cx);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger12onEnterFrameEP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$cx + 56 >> 2];
    var $4 = __ZN13JSCompartment12getDebuggeesEv($3);
    var $5 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5emptyEv($4);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $cx;
    __ZN2js8Debugger20slowPathOnEnterFrameEP9JSContext($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js19ScriptDebugEpilogueEP9JSContextPNS_10StackFrameEb($cx, $fp, $okArg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ok = __stackBase__;
    HEAP32[$ok >> 2] = $okArg & 1;
    var $2 = __ZNK2js10StackFrame13maybeHookDataEv($fp);
    if (($2 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$fp >> 2];
    var $5 = __ZNK2js10StackFrame22isFramePushedByExecuteEv($_idx_val);
    var $7 = HEAPU32[$cx + 200 >> 2];
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = HEAP32[$7 + 40 >> 2];
    if (($10 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = __ZN2jsL8JsvalifyEPNS_10StackFrameE($fp);
    var $14 = FUNCTION_TABLE[$10]($cx, $13, 0, $ok, $2);
    __label__ = 7;
    break;
   case 5:
    var $17 = HEAP32[$7 + 48 >> 2];
    if (($17 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = __ZN2jsL8JsvalifyEPNS_10StackFrameE($fp);
    var $21 = FUNCTION_TABLE[$17]($cx, $20, 0, $ok, $2);
    __label__ = 7;
    break;
   case 7:
    __ZN2js8Debugger12onLeaveFrameEP9JSContext($cx);
    var $24 = (HEAP32[$ok >> 2] | 0) != 0;
    STACKTOP = __stackBase__;
    return $24;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame13maybeHookDataEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK2js10StackFrame11hasHookDataEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = HEAP32[$this + 44 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger12onLeaveFrameEP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 56 >> 2];
    var $3 = $2;
    var $4 = __ZN13JSCompartment12getDebuggeesEv($3);
    var $5 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5emptyEv($4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $2 + 1956 | 0;
    var $8 = __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE5emptyEv($7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $cx;
    __ZN2js8Debugger20slowPathOnLeaveFrameEP9JSContext($10);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14CheckDebugModeP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cx_idx_val = HEAP32[$cx + 56 >> 2];
    var $1 = _JS_GetDebugMode($cx_idx_val);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = _JS_ReportErrorFlagsAndNumber($4, 0, 257, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 3;
    break;
   case 3:
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_UntrapScriptCode($cx, $script) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $script | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $script;
    var $4 = __ZNK2js2gc4Cell11compartmentEv($3);
    var $5 = $4 + 1956 | 0;
    __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE3allEv($r, $5);
    var $6 = $script + 8 | 0;
    var $7 = $cx;
    var $r_idx = $r | 0;
    var $r_idx2 = $r + 4 | 0;
    var $cx_idx = $cx + 52 | 0;
    var $code_0 = $2;
    __label__ = 2;
    break;
   case 2:
    var $code_0;
    var $r_idx_val = HEAP32[$r_idx >> 2];
    var $r_idx2_val = HEAP32[$r_idx2 >> 2];
    var $9 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($r_idx_val, $r_idx2_val);
    if ($9) {
      var $code_3 = $code_0;
      __label__ = 16;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5frontEv($r_idx_val);
    var $13 = HEAPU32[$11 + 4 >> 2];
    if ((HEAP32[$13 >> 2] | 0) == ($script | 0)) {
      __label__ = 4;
      break;
    } else {
      var $code_2 = $code_0;
      __label__ = 15;
      break;
    }
   case 4:
    var $18 = $13 + 4 | 0;
    var $19 = HEAPU32[$18 >> 2];
    var $20 = HEAPU32[$1 >> 2];
    var $24 = HEAPU32[$6 >> 2];
    if (($19 - $20 | 0) >>> 0 < $24 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $code_2 = $code_0;
      __label__ = 15;
      break;
    }
   case 5:
    if (($code_0 | 0) == ($20 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $code_1 = $code_0;
      var $62 = $19;
      var $61 = $20;
      __label__ = 14;
      break;
    }
   case 6:
    var $29 = __ZN8JSScript5notesEv($20, $24);
    var $30 = HEAP8[$29];
    if ($30 << 24 >> 24 == 0) {
      var $sn_0_lcssa = $29;
      __label__ = 12;
      break;
    } else {
      var $sn_01 = $29;
      var $32 = $30;
      __label__ = 7;
      break;
    }
   case 7:
    var $32;
    var $sn_01;
    if (($32 & 255) > 191) {
      var $38 = 24;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $38 = ($32 & 255) >>> 3;
    __label__ = 9;
    break;
   case 9:
    var $38;
    if (HEAP8[_js_SrcNoteSpec + ($38 << 3) + 4 | 0] << 24 >> 24 == 0) {
      var $45 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $43 = _js_SrcNoteLength($sn_01);
    var $45 = $43;
    __label__ = 11;
    break;
   case 11:
    var $45;
    var $46 = $sn_01 + $45 | 0;
    var $47 = HEAPU8[$46];
    if ($47 << 24 >> 24 == 0) {
      var $sn_0_lcssa = $46;
      __label__ = 12;
      break;
    } else {
      var $sn_01 = $46;
      var $32 = $47;
      __label__ = 7;
      break;
    }
   case 12:
    var $sn_0_lcssa;
    var $53 = $24 + 1 - $29 + $sn_0_lcssa | 0;
    var $54 = __ZN9JSContext7malloc_Ej($7, $53);
    if (($54 | 0) == 0) {
      var $code_3 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $57 = HEAP32[$1 >> 2];
    _memcpy($54, $57, $53, 1);
    var $cx_idx_val = HEAP32[$cx_idx >> 2];
    var $58 = __ZN2js11GetGSNCacheEP9JSContext($cx_idx_val);
    var $59 = $58;
    __ZN2js8GSNCache5purgeEv($59);
    var $code_1 = $54;
    var $62 = HEAP32[$18 >> 2];
    var $61 = HEAP32[$1 >> 2];
    __label__ = 14;
    break;
   case 14:
    var $61;
    var $62;
    var $code_1;
    HEAP8[$code_1 + ($62 - $61) | 0] = HEAP32[$13 + 8 >> 2] & 255;
    var $code_2 = $code_1;
    __label__ = 15;
    break;
   case 15:
    var $code_2;
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range8popFrontEv($r);
    var $code_0 = $code_2;
    __label__ = 2;
    break;
   case 16:
    var $code_3;
    STACKTOP = __stackBase__;
    return $code_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_UntrapScriptCode["X"] = 1;

function _JS_SetTrap($cx, $script, $pc, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $closure = __stackBase__;
    var $1 = $closure | 0;
    HEAP32[$1 >> 2] = $_0_0_0_val$0;
    HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
    var $2 = __ZL14CheckDebugModeP9JSContext($cx);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $script;
    var $6 = __ZNK2js2gc4Cell11compartmentEv($5);
    var $7 = $cx;
    var $8 = $script;
    var $9 = __ZN13JSCompartment25getOrCreateBreakpointSiteEP9JSContextP8JSScriptPhP8JSObject($6, $7, $8, $pc, 0);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js14BreakpointSite7setTrapEP9JSContextPF12JSTrapStatusS2_P8JSScriptPhPN2JS5ValueES8_ERKS8_($9, $closure);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetTrapOpcode($script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $script;
    var $2 = __ZNK2js2gc4Cell11compartmentEv($1);
    var $3 = __ZN13JSCompartment17getBreakpointSiteEPh($2, $pc);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = HEAP32[$3 + 8 >> 2];
    __label__ = 4;
    break;
   case 3:
    var $12 = HEAPU8[$pc] & 255;
    __label__ = 4;
    break;
   case 4:
    var $12;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ClearTrap($cx, $script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $script;
    var $2 = __ZNK2js2gc4Cell11compartmentEv($1);
    var $3 = __ZN13JSCompartment17getBreakpointSiteEPh($2, $pc);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js14BreakpointSite9clearTrapEP9JSContextPNS_6detail9HashTableINS_12HashMapEntryIPhPS0_EENS_7HashMapIS6_S7_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESC_E4EnumEPPF12JSTrapStatusS2_P8JSScriptS6_PN2JS5ValueESM_ESN_($3, 0);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ClearScriptTraps($cx, $script) {
  var $1 = $script;
  var $2 = __ZNK2js2gc4Cell11compartmentEv($1);
  var $3 = $script;
  __ZN13JSCompartment10clearTrapsEP9JSContextP8JSScript($2, $3);
  return;
}

function _JS_SetWatchPoint($cx, $obj, $id, $closure) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $v = __stackBase__ + 4;
    var $attrs = __stackBase__ + 12;
    var $propid = __stackBase__ + 16;
    var $idroot = __stackBase__ + 20;
    var $2 = __stackBase__ + 44;
    var $3 = __stackBase__ + 52;
    HEAP32[$1 >> 2] = $obj;
    var $4 = $cx;
    var $5 = __Z22js_CheckForStringIndexi($id);
    var $6 = $1;
    __Z19OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($4, $6);
    var $7 = HEAP32[$1 >> 2];
    if (($7 | 0) == 0) {
      var $_1 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $idroot;
    __ZN2js15AutoValueRooterC1EP9JSContext($10, $4);
    var $11 = _JSID_IS_INT1059($5);
    if (($11 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$propid >> 2] = $5;
    var $20 = $5;
    __label__ = 6;
    break;
   case 4:
    __ZN2jsL9IdToValueEi1060($2, $5);
    var $_idx2 = $2 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    var $15 = __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($4, $_idx2_val$0, $_idx2_val$1, $propid);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 5:
    var $17 = HEAP32[$propid >> 2];
    var $18 = __Z22js_CheckForStringIndexi($17);
    HEAP32[$propid >> 2] = $18;
    __ZN2jsL9IdToValueEi1060($3, $18);
    var $_idx3 = $3 | 0;
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    __ZN2js15AutoValueRooter3setEN2JS5ValueE($idroot, $_idx3_val$0, $_idx3_val$1);
    var $20 = $18;
    __label__ = 6;
    break;
   case 6:
    var $20;
    if (($7 | 0) == ($obj | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = $cx;
    var $24 = $7;
    var $25 = __ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj($23, $24, $20, 3, $v, $attrs);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx1_val = HEAP32[$7 >> 2];
    var $28 = __ZNK8JSObject8isNativeEv($_idx1_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_idx_val = HEAP32[$7 + 4 >> 2];
    var $31 = __ZNK8JSObject8getClassEv($_idx_val);
    var $33 = HEAP32[$31 >> 2];
    _JS_ReportErrorNumber($4, 4, 15, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $33, tempInt));
    var $_0 = 0;
    __label__ = 16;
    break;
   case 10:
    var $35 = $7;
    __ZN2js5types26MarkTypePropertyConfiguredEP9JSContextP8JSObjecti($4, $35, $20);
    var $36 = $cx + 56 | 0;
    var $39 = HEAP32[HEAP32[$36 >> 2] + 1984 >> 2];
    if (($39 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $wpmap_0 = $39;
      __label__ = 15;
      break;
    }
   case 11:
    var $43 = HEAP32[$cx + 52 >> 2];
    var $44 = __ZN9JSRuntime4new_IN2js13WatchpointMapEEEPT_v($43);
    if (($44 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $47 = $44;
    var $48 = __ZN2js13WatchpointMap4initEv($47);
    if ($48) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    __Z20js_ReportOutOfMemoryP9JSContext($4);
    var $_0 = 0;
    __label__ = 16;
    break;
   case 14:
    var $52 = HEAP32[$36 >> 2] + 1984 | 0;
    HEAP32[$52 >> 2] = $44;
    var $wpmap_0 = $44;
    __label__ = 15;
    break;
   case 15:
    var $wpmap_0;
    var $55 = $closure;
    var $56 = __ZN2js13WatchpointMap5watchEP9JSContextP8JSObjectiPFiS2_S4_iN2JS5ValueEPS6_PvES4_($wpmap_0, $4, $35, $5, $55);
    var $_0 = $56 & 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($10);
    var $_1 = $_0;
    __label__ = 17;
    break;
   case 17:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_SetWatchPoint["X"] = 1;

function __ZN2jsL9IdToValueEi1060($agg_result, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_STRING1077($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_STRING1080($id);
    __ZN2JSL11StringValueEP8JSString1079($agg_result, $4);
    __label__ = 8;
    break;
   case 3:
    var $6 = _JSID_IS_INT1059($id);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _JSID_TO_INT1082($id);
    __ZN2JSL10Int32ValueEi1081($agg_result, $9);
    __label__ = 8;
    break;
   case 5:
    var $11 = _JSID_IS_OBJECT1083($id);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = _JSID_TO_OBJECT1085($id);
    __ZN2JSL11ObjectValueER8JSObject1084($agg_result, $14);
    __label__ = 8;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv1068($agg_result);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime4new_IN2js13WatchpointMapEEEPT_v($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZN9JSRuntime7malloc_EjP9JSContext($1, 24, 0);
    if (($2 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    HEAP32[$2 >> 2] = 0;
    HEAP32[$2 + 4 >> 2] = 0;
    HEAP32[$2 + 8 >> 2] = 0;
    HEAP32[$2 + 12 >> 2] = 0;
    HEAP32[$2 + 16 >> 2] = 0;
    HEAP32[$2 + 20 >> 2] = 0;
    __ZN2js13WatchpointMapC1Ev($5);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ClearWatchPoint($cx_0_12_val_0_37_val, $obj, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($cx_0_12_val_0_37_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __Z22js_CheckForStringIndexi($id);
    var $4 = $obj;
    var $5 = $cx_0_12_val_0_37_val;
    __ZN2js13WatchpointMap7unwatchEP8JSObjectiPPFiP9JSContextS2_iN2JS5ValueEPS6_PvEPS2_($5, $4, $3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ClearAllWatchPoints($cx_0_12_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($cx_0_12_val | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$cx_0_12_val + 1984 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $4;
    __ZN2js13WatchpointMap5clearEv($7);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK10JSFunction6nativeEv($this_0_3_0_0_val) {
  return $this_0_3_0_0_val;
}

function _JS_DHashFinalizeStub($table) {
  return;
}

function __ZNK2js5Shape8writableEv($this_0_7_val) {
  return ($this_0_7_val & 2) << 24 >> 24 == 0;
}

function __ZNK2js5Shape12configurableEv($this_0_7_val) {
  return ($this_0_7_val & 4) << 24 >> 24 == 0;
}

function __ZNK2js5Shape5Range5emptyEv($this_0_0_val_0_10_val) {
  return ($this_0_0_val_0_10_val | 0) == 0;
}

function __ZNK2js8Bindings15countLocalNamesEv($this_0_1_val, $this_0_2_val, $this_0_3_val) {
  return ($this_0_2_val & 65535) + ($this_0_1_val & 65535) + ($this_0_3_val & 65535) | 0;
}

function _JSID_IS_STRING1077($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_TO_STRING1080($iden) {
  return $iden;
}

function _JSID_TO_INT1082($iden) {
  return $iden >> 1;
}

function _JSID_IS_OBJECT1083($iden) {
  return ($iden & 7 | 0) == 4 & ($iden | 0) != 4 & 1;
}

function _JSID_TO_OBJECT1085($iden) {
  return $iden & -8;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5emptyEv($this_0_3_val) {
  return ($this_0_3_val | 0) == 0;
}

function __ZNK2js10StackFrame11hasHookDataEv($this_0_0_val) {
  return ($this_0_0_val & 65536 | 0) != 0;
}

function _JS_DHashVoidPtrKeyStub($table, $key) {
  return $key >>> 2;
}

function _JS_SetDebuggerHandler($rt, $closure) {
  HEAP32[$rt + 144172 >> 2] = 90;
  HEAP32[$rt + 144176 >> 2] = $closure;
  return;
}

function _JS_SetThrowHook($rt, $closure) {
  HEAP32[$rt + 144204 >> 2] = 90;
  HEAP32[$rt + 144208 >> 2] = $closure;
  return;
}

function __ZN8JSScript7regexpsEv($this_0_1_val, $this_0_7_val) {
  return $this_0_1_val + ($this_0_7_val & 255) | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this) {
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  return;
}

function __ZN2js10StackFrame15markReturnValueEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 262144;
  HEAP32[$1 >> 2] = $3;
  return;
}

function _JS_DHashMatchEntryStub($table, $entry, $key) {
  return (HEAP32[$entry + 4 >> 2] | 0) == ($key | 0) & 1;
}

function _JS_PCToLineNumber($cx, $script, $pc) {
  var $1 = $cx;
  var $2 = $script;
  var $3 = __Z17js_PCToLineNumberP9JSContextP8JSScriptPh($1, $2, $pc);
  return $3;
}

function _JS_LineNumberToPC($script, $lineno) {
  var $1 = $script;
  var $2 = __Z17js_LineNumberToPCP8JSScriptj($1, $lineno);
  return $2;
}

function __ZNK2js8Bindings13hasLocalNamesEv($this_0_1_val, $this_0_2_val, $this_0_3_val) {
  var $1 = __ZNK2js8Bindings15countLocalNamesEv($this_0_1_val, $this_0_2_val, $this_0_3_val);
  return ($1 | 0) != 0;
}

function __ZNK10JSFunction11maybeScriptEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP16[$this + 58 >> 1];
    var $2 = __ZNK10JSFunction13isInterpretedEv($_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this;
    var $5 = __ZNK10JSFunction6scriptEv($4);
    var $8 = $5;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK10JSFunction11maybeNativeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP16[$this + 58 >> 1];
    var $2 = __ZNK10JSFunction13isInterpretedEv($_idx_val);
    if ($2) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 60 >> 2];
    var $4 = __ZNK10JSFunction6nativeEv($this_idx_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetFrameScript($fp) {
  var $1 = $fp;
  var $2 = __ZN2js8ValueifyEP12JSStackFrame($1);
  var $3 = __ZNK2js10StackFrame11maybeScriptEv($2);
  return $3;
}

function _JS_GetFramePC($cx, $fp) {
  var $1 = $fp;
  var $2 = __ZN2js8ValueifyEP12JSStackFrame($1);
  var $4 = $2;
  var $5 = $cx + 60 | 0;
  var $6 = __ZN2js10StackFrame11pcQuadraticERKNS_12ContextStackEPS0_PPNS_13JSInlinedSiteE($4, $5, 0);
  return $6;
}

function _JS_GetScriptedCaller($cx) {
  var $1 = __ZN2js8ValueifyEP12JSStackFrame(0);
  var $2 = $cx;
  var $3 = __Z20js_GetScriptedCallerP9JSContextPN2js10StackFrameE($2, $1);
  var $4 = $3;
  var $5 = __ZN2jsL8JsvalifyEPNS_10StackFrameE($4);
  return $5;
}

function _JS_GetFrameScopeChain($cx, $fpArg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ac = __stackBase__;
    var $1 = $fpArg;
    var $2 = __ZN2js8ValueifyEP12JSStackFrame($1);
    var $3 = __ZNK2js10StackFrame10scopeChainEv($2);
    var $4 = $cx;
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $4, $3);
    var $5 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $2;
    var $8 = __ZN2jsL8JsvalifyEPNS_10StackFrameE($7);
    _JS_GetFrameCallObject($cx, $8);
    var $9 = __ZN2js13GetScopeChainEP9JSContextPNS_10StackFrameE($4, $2);
    var $_0 = $9;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($ac);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetFrameCallObject($cx, $fpArg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ac = __stackBase__;
    var $1 = $fpArg;
    var $2 = __ZN2js8ValueifyEP12JSStackFrame($1);
    var $_idx1 = $2 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $3 = __ZNK2js10StackFrame15isFunctionFrameEv($_idx1_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $5 = __ZNK2js10StackFrame10scopeChainEv($2);
    var $6 = $cx;
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $6, $5);
    var $7 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    var $_idx2_val = HEAP32[$_idx1 >> 2];
    var $9 = __ZNK2js10StackFrame10hasCallObjEv($_idx2_val);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($_idx2_val);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $13 = __ZN2js19CreateFunCallObjectEP9JSContextPNS_10StackFrameE($6, $2);
    __label__ = 7;
    break;
   case 6:
    var $15 = $2;
    var $16 = __ZNK2js10StackFrame7callObjEv($15);
    __label__ = 7;
    break;
   case 7:
    __ZN2js15AutoCompartmentD2Ev($ac);
    __label__ = 8;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame8maybeFunEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK2js10StackFrame15isFunctionFrameEv($_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this;
    var $4 = __ZNK2js10StackFrame3funEv($3);
    var $7 = $4;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame11returnValueEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = $this + 24 | 0;
    if ((HEAP32[$this >> 2] & 262144 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($5);
    __label__ = 3;
    break;
   case 3:
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame14setReturnValueERKN2JS5ValueE($this, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  var $1 = $this + 24 | 0;
  HEAP32[$1 >> 2] = $v_0_0_0_val$0;
  HEAP32[$1 + 4 >> 2] = $v_0_0_0_val$1;
  __ZN2js10StackFrame15markReturnValueEv($this);
  return;
}

function _JS_EvaluateUCInStackFrame($cx, $fpArg, $chars, $length, $filename, $lineno, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ac = __stackBase__;
    var $1 = __ZL14CheckDebugModeP9JSContext($cx);
    if (($1 | 0) == 0) {
      var $_1 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JS_GetFrameScopeChain($cx, $fpArg);
    if (($4 | 0) == 0) {
      var $_1 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $cx;
    var $8 = $4;
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $7, $8);
    var $9 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = $fpArg;
    var $12 = __ZN2js8ValueifyEP12JSStackFrame($11);
    var $13 = __ZN2js15EvaluateInScopeEP9JSContextP8JSObjectPNS_10StackFrameEPKtjPKcjPN2JS5ValueE($7, $8, $12, $chars, $length, $filename, $lineno, $rval);
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_1 = $_0;
    __label__ = 6;
    break;
   case 6:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetPropertyDesc($cx, $obj, $sprop, $pd) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $lastException = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $r = __stackBase__ + 24;
    var $3 = __stackBase__ + 32;
    var $4 = $cx;
    var $5 = $obj;
    var $6 = $sprop;
    var $7 = $6 + 12 | 0;
    var $8 = HEAP32[$7 >> 2];
    __ZN2jsL9IdToJsvalEi1067($1, $8);
    var $9 = $1 | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $pd | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = $cx + 20 | 0;
    var $_idx3_val = HEAP32[$12 >> 2];
    var $13 = __ZN9JSContext18isExceptionPendingEv($_idx3_val);
    __ZN2JSL14UndefinedValueEv1068($lastException);
    if ($13) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $15 = $cx + 24 | 0;
    var $st$1$0 = $15 | 0;
    var $_idx5_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $15 + 4 | 0;
    var $_idx5_val$1 = HEAP32[$st$1$1 >> 2];
    __ZN9JSContext19getPendingExceptionEv($lastException, $_idx5_val$0, $_idx5_val$1);
    __label__ = 3;
    break;
   case 3:
    __ZN9JSContext21clearPendingExceptionEv($4);
    var $17 = HEAP32[$7 >> 2];
    var $18 = $pd + 8 | 0;
    var $19 = __Z14js_GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($4, $5, $17, $18);
    if (($19 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $_idx2_val = HEAP32[$12 >> 2];
    var $22 = __ZN9JSContext18isExceptionPendingEv($_idx2_val);
    var $23 = $pd + 16 | 0;
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP8[$23] = -128;
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$2$0 = $$emscripten$temp$0 | 0;
    var $25$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $$emscripten$temp$0 + 4 | 0;
    var $25$1 = HEAP32[$st$2$1 >> 2];
    var $26 = $18 | 0;
    HEAP32[$26 >> 2] = $25$0;
    HEAP32[$26 + 4 >> 2] = $25$1;
    __label__ = 8;
    break;
   case 6:
    HEAP8[$23] = 64;
    var $28 = $cx + 24 | 0;
    var $st$2$0 = $28 | 0;
    var $_idx4_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $28 + 4 | 0;
    var $_idx4_val$1 = HEAP32[$st$2$1 >> 2];
    __ZN9JSContext19getPendingExceptionEv($2, $_idx4_val$0, $_idx4_val$1);
    var $29 = $2 | 0;
    var $st$8$0 = $29 | 0;
    var $30$0 = HEAP32[$st$8$0 >> 2];
    var $st$8$1 = $29 + 4 | 0;
    var $30$1 = HEAP32[$st$8$1 >> 2];
    var $31 = $18 | 0;
    HEAP32[$31 >> 2] = $30$0;
    HEAP32[$31 + 4 >> 2] = $30$1;
    __label__ = 8;
    break;
   case 7:
    HEAP8[$pd + 16 | 0] = 0;
    __label__ = 8;
    break;
   case 8:
    if ($13) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $36 = $lastException | 0;
    var $st$1$0 = $36 | 0;
    var $37$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $36 + 4 | 0;
    var $37$1 = HEAP32[$st$1$1 >> 2];
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($4, $37$0, $37$1);
    __label__ = 10;
    break;
   case 10:
    var $38 = $sprop;
    var $_idx11_val = HEAPU8[$38 + 28 | 0];
    var $39 = __ZNK2js5Shape10enumerableEv($_idx11_val);
    var $40 = $39 & 1;
    var $41 = __ZNK2js5Shape8writableEv($_idx11_val);
    var $42 = $41 ? 0 : 2;
    var $43 = __ZNK2js5Shape12configurableEv($_idx11_val);
    var $44 = $43 ? 0 : 4;
    var $45 = $pd + 16 | 0;
    var $49 = $42 | $40 | HEAP8[$45] | $44;
    HEAP8[$45] = $49;
    HEAP8[$pd + 17 | 0] = 0;
    var $_idx1_val = HEAP32[$38 + 16 >> 2];
    var $51 = __ZNK2js5Shape6getterEv($_idx1_val);
    if (($51 | 0) == 92) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $55 = HEAP16[$6 + 30 >> 1];
    HEAP16[$pd + 18 >> 1] = $55;
    var $57 = $49 | 16;
    HEAP8[$45] = $57;
    __label__ = 15;
    break;
   case 12:
    if (($51 | 0) == 94) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $62 = HEAP16[$6 + 30 >> 1];
    HEAP16[$pd + 18 >> 1] = $62;
    var $64 = $49 | 32;
    HEAP8[$45] = $64;
    __label__ = 15;
    break;
   case 14:
    HEAP16[$pd + 18 >> 1] = 0;
    __label__ = 15;
    break;
   case 15:
    var $$emscripten$temp$1 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$1 | 0;
    var $68$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$1 + 4 | 0;
    var $68$1 = HEAP32[$st$1$1 >> 2];
    var $69 = $pd + 24 | 0;
    HEAP32[$69 >> 2] = $68$0;
    HEAP32[$69 + 4 >> 2] = $68$1;
    var $70 = $6 + 24 | 0;
    var $71 = HEAP32[$70 >> 2];
    var $_idx7_val = HEAP32[$obj >> 2];
    var $_idx7_val_idx_val = HEAP32[$_idx7_val + 4 >> 2];
    var $72 = __ZNK8JSObject12containsSlotEj($_idx7_val_idx_val, $71);
    if ($72) {
      __label__ = 16;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 16:
    var $74 = __ZNK8JSObject12lastPropertyEv($_idx7_val);
    var $75 = $74;
    __ZNK2js5Shape3allEv($r, $75);
    var $76 = $r;
    var $r_idx = $r | 0;
    __label__ = 17;
    break;
   case 17:
    var $r_idx_val = HEAP32[$r_idx >> 2];
    var $r_idx_val_idx_val = HEAP32[$r_idx_val + 32 >> 2];
    var $78 = __ZNK2js5Shape5Range5emptyEv($r_idx_val_idx_val);
    if ($78) {
      __label__ = 22;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $80 = $r_idx_val;
    var $81 = __ZNK2js5Shape5Range5frontEv($80);
    if (($81 | 0) == ($38 | 0)) {
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    if ((HEAP32[$81 + 24 >> 2] | 0) == (HEAP32[$70 >> 2] | 0)) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $90 = HEAP32[$81 + 12 >> 2];
    __ZN2jsL9IdToJsvalEi1067($3, $90);
    var $91 = $3 | 0;
    var $92$0 = HEAP32[$91 >> 2];
    var $92$1 = HEAP32[$91 + 4 >> 2];
    var $st$8$0 = $69 | 0;
    HEAP32[$st$8$0 >> 2] = $92$0;
    var $st$8$1 = $69 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $92$1;
    __label__ = 22;
    break;
   case 21:
    __ZN2js5Shape5Range8popFrontEv($76);
    __label__ = 17;
    break;
   case 22:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_GetPropertyDesc["X"] = 1;

function __ZN2jsL9IdToJsvalEi1067($agg_result, $id) {
  __ZN2jsL9IdToValueEi1060($agg_result, $id);
  return;
}

function __ZN2JSL14UndefinedValueEv1068($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZNK2js5Shape3allEv($agg_result, $this) {
  var $1 = $agg_result;
  var $2 = $this;
  __ZN2js5Shape5RangeC1EPKS0_($1, $2);
  return;
}

function _JS_GetPropertyDescArray($cx, $obj, $pda) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $cx;
    var $_idx1_val = HEAP32[$obj + 4 >> 2];
    var $3 = __ZNK8JSObject8getClassEv($_idx1_val);
    var $_idx2 = $obj;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $4 = __ZNK8JSObject8isNativeEv($_idx2_val);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    if ((HEAP32[$3 + 4 >> 2] & 2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAP32[$3 >> 2];
    _JS_ReportErrorNumber($1, 4, 153, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $12, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 4:
    var $16 = HEAP32[$3 + 24 >> 2];
    var $17 = FUNCTION_TABLE[$16]($cx, $obj);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx4_val = HEAP32[$_idx2 >> 2];
    var $20 = __ZNK8JSObject11nativeEmptyEv($_idx4_val);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$pda >> 2] = 0;
    HEAP32[$pda + 4 >> 2] = 0;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 7:
    var $25 = __ZNK8JSObject13propertyCountEv($obj);
    var $26 = $25 << 5;
    var $27 = __ZN9JSContext7malloc_Ej($1, $26);
    var $28 = $27;
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx_val = HEAP32[$_idx2 >> 2];
    var $31 = __ZNK8JSObject12lastPropertyEv($_idx_val);
    var $32 = $31;
    __ZNK2js5Shape3allEv($r, $32);
    var $33 = $r;
    var $r_idx = $r | 0;
    var $i_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $i_0;
    var $r_idx_val = HEAP32[$r_idx >> 2];
    var $r_idx_val_idx_val = HEAP32[$r_idx_val + 32 >> 2];
    var $35 = __ZNK2js5Shape5Range5emptyEv($r_idx_val_idx_val);
    var $36 = $r_idx_val;
    if ($35) {
      var $i_1 = $i_0;
      __label__ = 16;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = $28 + ($i_0 << 5) | 0;
    var $39 = $38 | 0;
    var $40 = __Z10js_AddRootP9JSContextPN2JS5ValueEPKc($1, $39, 0);
    if (($40 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $43 = $28 + ($i_0 << 5) + 8 | 0;
    var $44 = __Z10js_AddRootP9JSContextPN2JS5ValueEPKc($1, $43, 0);
    if (($44 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $47 = __ZNK2js5Shape5Range5frontEv($36);
    var $48 = $47;
    _JS_GetPropertyDesc($cx, $obj, $48, $38);
    if ((HEAP8[$28 + ($i_0 << 5) + 16 | 0] & 8) << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $54 = $28 + ($i_0 << 5) + 24 | 0;
    var $55 = __Z10js_AddRootP9JSContextPN2JS5ValueEPKc($1, $54, 0);
    if (($55 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $58 = $i_0 + 1 | 0;
    if (($58 | 0) == ($25 | 0)) {
      var $i_1 = $58;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    __ZN2js5Shape5Range8popFrontEv($33);
    var $i_0 = $58;
    __label__ = 9;
    break;
   case 16:
    var $i_1;
    HEAP32[$pda >> 2] = $i_1;
    HEAP32[$pda + 4 >> 2] = $28;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 17:
    HEAP32[$pda >> 2] = $i_0 + 1 | 0;
    HEAP32[$pda + 4 >> 2] = $28;
    _JS_PutPropertyDescArray($cx, $pda);
    var $_0 = 0;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_GetPropertyDescArray["X"] = 1;

function __ZNK8JSObject13propertyCountEv($this) {
  var $_idx_val = HEAP32[$this >> 2];
  var $1 = __ZNK8JSObject12lastPropertyEv($_idx_val);
  var $2 = $1;
  var $3 = __ZNK2js5Shape10entryCountEv($2);
  return $3;
}

function _JS_PutPropertyDescArray($cx, $pda) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$pda + 4 >> 2];
    var $3 = $pda | 0;
    if ((HEAP32[$3 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx + 52 | 0;
    var $i_01 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_01;
    var $10 = $2 + ($i_01 << 5) | 0;
    var $11 = HEAP32[$6 >> 2];
    _js_RemoveRoot($11, $10);
    var $14 = $2 + ($i_01 << 5) + 8 | 0;
    var $15 = HEAP32[$6 >> 2];
    _js_RemoveRoot($15, $14);
    if ((HEAP8[$2 + ($i_01 << 5) + 16 | 0] & 8) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $23 = $2 + ($i_01 << 5) + 24 | 0;
    var $24 = HEAP32[$6 >> 2];
    _js_RemoveRoot($24, $23);
    __label__ = 5;
    break;
   case 5:
    var $26 = $i_01 + 1 | 0;
    if ($26 >>> 0 < HEAPU32[$3 >> 2] >>> 0) {
      var $i_01 = $26;
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $29 = $2;
    __ZN9JSContext5free_EPv($29);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_RevertVersion($cx) {
  var $1 = $cx;
  __ZN9JSContext20clearVersionOverrideEv($1);
  return;
}

function _JS_DumpCompartmentBytecode($cx) {
  var $3 = $cx;
  var $4 = HEAP32[$cx + 56 >> 2];
  __ZN2js12IterateCellsEP9JSContextP13JSCompartmentNS_2gc9AllocKindEPvPFvS1_S6_S6_13JSGCTraceKindjE($3, $4);
  return;
}

function __ZN2js13WatchpointMapC1Ev($this) {
  __ZN2js13WatchpointMapC2Ev($this);
  return;
}

function __ZN2js13WatchpointMapC2Ev($this) {
  var $1 = $this | 0;
  __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC1ES5_($1);
  return;
}

function __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC1ES5_($this) {
  __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC2ES5_($this);
  return;
}

function __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC2ES5_($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this);
  return;
}

function __ZNK8JSObject10structSizeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx2_val = HEAP32[$this + 4 >> 2];
    var $2 = __ZNK8JSObject10isFunctionEv($_idx2_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this + 24 >> 2];
    var $5 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($5 | 0) == 0) {
      var $13 = 80;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx1_val = HEAP32[$this + 8 >> 2];
    var $9 = __ZNK8JSObject13numFixedSlotsEv($_idx1_val);
    var $13 = ($9 << 3) + 40 | 0;
    __label__ = 4;
    break;
   case 4:
    var $13;
    return $13;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5Shape10entryCountEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $_idx_val = HEAP32[$this + 8 >> 2];
    var $2 = __ZNK2js5Shape8hasTableEv($_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this;
    var $5 = __ZNK2js5Shape8getTableEv($4);
    var $_0 = HEAP32[$5 + 4 >> 2];
    __label__ = 6;
    break;
   case 3:
    __ZNK2js5Shape3allEv($r, $this);
    var $r_idx1 = $r | 0;
    var $r_idx1_val_idx_val = HEAP32[HEAP32[$r_idx1 >> 2] + 32 >> 2];
    var $9 = __ZNK2js5Shape5Range5emptyEv($r_idx1_val_idx_val);
    if ($9) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $r;
    var $count_01 = 0;
    __label__ = 5;
    break;
   case 5:
    var $count_01;
    var $12 = $count_01 + 1 | 0;
    __ZN2js5Shape5Range8popFrontEv($10);
    var $r_idx_val_idx_val = HEAP32[HEAP32[$r_idx1 >> 2] + 32 >> 2];
    var $13 = __ZNK2js5Shape5Range5emptyEv($r_idx_val_idx_val);
    if ($13) {
      var $_0 = $12;
      __label__ = 6;
      break;
    } else {
      var $count_01 = $12;
      __label__ = 5;
      break;
    }
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11StringValueEP8JSString1079($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2JSL10Int32ValueEi1081($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZN2JSL11ObjectValueER8JSObject1084($agg_result, $obj) {
  var $1 = $obj;
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $1);
  return;
}

function __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE5emptyEv($this) {
  var $_idx_val = HEAP32[$this + 12 >> 2];
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5emptyEv($_idx_val);
  return $1;
}

function _JS_DHashAllocTable($table, $nbytes) {
  var $1 = __ZN2js11OffTheBooks7malloc_Ej($nbytes);
  return $1;
}

function _JS_DHashFreeTable($table, $ptr) {
  __ZN2js10Foreground5free_EPv($ptr);
  return;
}

function _JS_DHashMoveEntryStub($table, $from, $to) {
  var $1 = $to;
  var $2 = $from;
  var $4 = HEAP32[$table + 12 >> 2];
  _memcpy($1, $2, $4, 1);
  return;
}

function _JS_DHashClearEntryStub($table, $entry) {
  var $1 = $entry;
  var $3 = HEAP32[$table + 12 >> 2];
  _memset($1, 0, $3, 1);
  return;
}

function _JS_NewDHashTable($capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11OffTheBooks7malloc_Ej(32);
    var $2 = $1;
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = _JS_DHashTableInit($2, 12, $capacity);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $2;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js10Foreground5free_EPv($1);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DHashTableInit($table, $entrySize, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$table >> 2] = __ZL8stub_ops;
    HEAP32[$table + 4 >> 2] = 0;
    var $_01 = $capacity >>> 0 < 16 ? 16 : $capacity;
    if ($_01 >>> 0 < 2) {
      var $10 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $_01 - 1 | 0;
    var $7 = _llvm_ctlz_i32($6);
    var $10 = 32 - $7 | 0;
    __label__ = 3;
    break;
   case 3:
    var $10;
    if (1 << $10 >>> 0 > 16777215) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP16[$table + 8 >> 1] = 32 - $10 & 65535;
    HEAP8[$table + 10 | 0] = -64;
    HEAP8[$table + 11 | 0] = 64;
    HEAP32[$table + 12 >> 2] = $entrySize;
    HEAP32[$table + 20 >> 2] = 0;
    HEAP32[$table + 16 >> 2] = 0;
    HEAP32[$table + 24 >> 2] = 0;
    var $23 = $entrySize << $10;
    var $24 = _JS_DHashAllocTable($table, $23);
    HEAP32[$table + 28 >> 2] = $24;
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _memset($24, 0, $23, 1);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DHashTableDestroy($table) {
  _JS_DHashTableFinish($table);
  var $1 = $table;
  __ZN2js10Foreground5free_EPv($1);
  return;
}

function _JS_DHashTableFinish($table) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $table | 0;
    var $4 = HEAP32[HEAP32[$1 >> 2] + 24 >> 2];
    FUNCTION_TABLE[$4]($table);
    var $5 = $table + 28 | 0;
    var $6 = HEAPU32[$5 >> 2];
    var $8 = HEAPU32[$table + 12 >> 2];
    var $13 = $8 << 32 - (HEAP16[$table + 8 >> 1] << 16 >> 16);
    var $14 = $6 + $13 | 0;
    if (($13 | 0) > 0) {
      var $entryAddr_01 = $6;
      __label__ = 2;
      break;
    } else {
      var $27 = $6;
      __label__ = 6;
      break;
    }
   case 2:
    var $entryAddr_01;
    if (HEAPU32[$entryAddr_01 >> 2] >>> 0 > 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $23 = HEAP32[HEAP32[$1 >> 2] + 20 >> 2];
    FUNCTION_TABLE[$23]($table, $entryAddr_01);
    __label__ = 4;
    break;
   case 4:
    var $25 = $entryAddr_01 + $8 | 0;
    if ($25 >>> 0 < $14 >>> 0) {
      var $entryAddr_01 = $25;
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $27 = HEAP32[$5 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $27;
    var $30 = HEAP32[HEAP32[$1 >> 2] + 4 >> 2];
    FUNCTION_TABLE[$30]($table, $27);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13FindFreeEntryP12JSDHashTablej($table, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP16[$table + 8 >> 1] << 16 >> 16;
    var $4 = $keyHash >>> ($3 >>> 0);
    var $5 = $table + 28 | 0;
    var $7 = $table + 12 | 0;
    var $10 = HEAP32[$5 >> 2] + $4 * HEAP32[$7 >> 2] | 0;
    var $11 = $10;
    if ((HEAP32[$10 >> 2] | 0) == 0) {
      var $_0 = $11;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $16 = 32 - $3 | 0;
    var $19 = $keyHash << $16 >>> ($3 >>> 0) | 1;
    var $21 = (1 << $16) - 1 | 0;
    var $entry_0 = $11;
    var $hash1_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $hash1_0;
    var $entry_0;
    var $23 = $entry_0 | 0;
    var $25 = HEAP32[$23 >> 2] | 1;
    HEAP32[$23 >> 2] = $25;
    var $27 = $hash1_0 - $19 & $21;
    var $31 = HEAP32[$5 >> 2] + HEAP32[$7 >> 2] * $27 | 0;
    var $32 = $31;
    if ((HEAP32[$31 >> 2] | 0) == 0) {
      var $_0 = $32;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $32;
      var $hash1_0 = $27;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DHashTableOperate($table, $key, $op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $table | 0;
    var $4 = HEAP32[HEAP32[$1 >> 2] + 8 >> 2];
    var $5 = FUNCTION_TABLE[$4]($table, $key);
    var $6 = $5 * -1640531527 | 0;
    var $_ = $6 >>> 0 < 2 ? $6 - 2 | 0 : $6;
    var $9 = $_ & -2;
    if (($op | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($op | 0) == 1) {
      __label__ = 3;
      break;
    } else if (($op | 0) == 2) {
      __label__ = 13;
      break;
    } else {
      var $entry_0 = 0;
      __label__ = 17;
      break;
    }
   case 2:
    var $11 = __ZL11SearchTableP12JSDHashTablePKvj15JSDHashOperator($table, $key, $9, 0);
    var $entry_0 = $11;
    __label__ = 17;
    break;
   case 3:
    var $16 = 32 - (HEAP16[$table + 8 >> 1] << 16 >> 16) | 0;
    var $17 = 1 << $16;
    var $18 = $table + 16 | 0;
    var $20 = $table + 20 | 0;
    var $21 = HEAPU32[$20 >> 2];
    if (($21 + HEAP32[$18 >> 2] | 0) >>> 0 < (HEAPU8[$table + 10 | 0] & 255) << $16 >>> 8 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_1 = $21 >>> 0 < $17 >>> 2 >>> 0 & 1;
    var $32 = __ZL11ChangeTableP12JSDHashTablei($table, $_1);
    if (($32 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    if ((HEAP32[$20 >> 2] + HEAP32[$18 >> 2] | 0) == ($17 - 1 | 0)) {
      var $entry_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $41 = __ZL11SearchTableP12JSDHashTablePKvj15JSDHashOperator($table, $key, $9, 1);
    var $42 = $41 | 0;
    var $43 = HEAPU32[$42 >> 2];
    if ($43 >>> 0 > 1) {
      var $entry_0 = $41;
      __label__ = 17;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($43 | 0) == 1) {
      __label__ = 8;
      break;
    } else {
      var $keyHash_1 = $9;
      __label__ = 9;
      break;
    }
   case 8:
    var $49 = HEAP32[$20 >> 2] - 1 | 0;
    HEAP32[$20 >> 2] = $49;
    var $keyHash_1 = $_ | 1;
    __label__ = 9;
    break;
   case 9:
    var $keyHash_1;
    var $54 = HEAP32[HEAP32[$1 >> 2] + 28 >> 2];
    if (($54 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $57 = FUNCTION_TABLE[$54]($table, $41, $key);
    if (($57 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $61 = $41 + 4 | 0;
    var $64 = HEAP32[$table + 12 >> 2] - 4 | 0;
    _memset($61, 0, $64, 1);
    var $entry_0 = 0;
    __label__ = 17;
    break;
   case 12:
    HEAP32[$42 >> 2] = $keyHash_1;
    var $67 = HEAP32[$18 >> 2] + 1 | 0;
    HEAP32[$18 >> 2] = $67;
    var $entry_0 = $41;
    __label__ = 17;
    break;
   case 13:
    var $69 = __ZL11SearchTableP12JSDHashTablePKvj15JSDHashOperator($table, $key, $9, 2);
    if (HEAPU32[$69 >> 2] >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      var $entry_0 = 0;
      __label__ = 17;
      break;
    }
   case 14:
    _JS_DHashTableRawRemove($table, $69);
    var $77 = 32 - (HEAP16[$table + 8 >> 1] << 16 >> 16) | 0;
    if (1 << $77 >>> 0 > 16) {
      __label__ = 15;
      break;
    } else {
      var $entry_0 = 0;
      __label__ = 17;
      break;
    }
   case 15:
    if (HEAPU32[$table + 16 >> 2] >>> 0 > (HEAPU8[$table + 11 | 0] & 255) << $77 >>> 8 >>> 0) {
      var $entry_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $90 = __ZL11ChangeTableP12JSDHashTablei($table, -1);
    var $entry_0 = 0;
    __label__ = 17;
    break;
   case 17:
    var $entry_0;
    return $entry_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_DHashTableOperate["X"] = 1;

function __ZL11SearchTableP12JSDHashTablePKvj15JSDHashOperator($table, $key, $keyHash, $op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $table + 8 | 0;
    var $2 = HEAPU16[$1 >> 1];
    var $3 = $2 << 16 >> 16;
    var $4 = $keyHash >>> ($3 >>> 0);
    var $5 = $table + 28 | 0;
    var $7 = $table + 12 | 0;
    var $10 = HEAP32[$5 >> 2] + $4 * HEAP32[$7 >> 2] | 0;
    var $11 = $10;
    var $13 = HEAP32[$10 >> 2];
    if (($13 | 0) == 0) {
      var $_0 = $11;
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $19 = HEAPU32[HEAP32[$table >> 2] + 12 >> 2];
    if (($13 & -2 | 0) == ($keyHash | 0)) {
      __label__ = 3;
      break;
    } else {
      var $26 = $2;
      __label__ = 5;
      break;
    }
   case 3:
    var $23 = FUNCTION_TABLE[$19]($table, $11, $key);
    if (($23 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $11;
      __label__ = 16;
      break;
    }
   case 4:
    var $26 = HEAP16[$1 >> 1];
    __label__ = 5;
    break;
   case 5:
    var $26;
    var $28 = 32 - ($26 << 16 >> 16) | 0;
    var $31 = $keyHash << $28 >>> ($3 >>> 0) | 1;
    var $33 = (1 << $28) - 1 | 0;
    var $34 = ($op | 0) == 1;
    var $firstRemoved_0 = 0;
    var $entry_0 = $11;
    var $hash1_0 = $4;
    __label__ = 6;
    break;
   case 6:
    var $hash1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $35 = $entry_0 | 0;
    var $36 = HEAP32[$35 >> 2];
    if (($36 | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      __label__ = 11;
      break;
    }
   case 8:
    var $firstRemoved_1 = $entry_0;
    __label__ = 11;
    break;
   case 9:
    if ($34) {
      __label__ = 10;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      __label__ = 11;
      break;
    }
   case 10:
    var $43 = $36 | 1;
    HEAP32[$35 >> 2] = $43;
    var $firstRemoved_1 = $firstRemoved_0;
    __label__ = 11;
    break;
   case 11:
    var $firstRemoved_1;
    var $45 = $hash1_0 - $31 & $33;
    var $49 = HEAP32[$5 >> 2] + HEAP32[$7 >> 2] * $45 | 0;
    var $50 = $49;
    var $52 = HEAP32[$49 >> 2];
    if (($52 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    if (($firstRemoved_1 | 0) == 0) {
      var $_0 = $50;
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $phitmp = $34 ? $firstRemoved_1 : $50;
    var $_0 = $phitmp;
    __label__ = 16;
    break;
   case 14:
    if (($52 & -2 | 0) == ($keyHash | 0)) {
      __label__ = 15;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $50;
      var $hash1_0 = $45;
      __label__ = 6;
      break;
    }
   case 15:
    var $61 = FUNCTION_TABLE[$19]($table, $50, $key);
    if (($61 | 0) == 0) {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $50;
      var $hash1_0 = $45;
      __label__ = 6;
      break;
    } else {
      var $_0 = $50;
      __label__ = 16;
      break;
    }
   case 16:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11SearchTableP12JSDHashTablePKvj15JSDHashOperator["X"] = 1;

function __ZL11ChangeTableP12JSDHashTablei($table, $deltaLog2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $table + 8 | 0;
    var $4 = 32 - (HEAP16[$1 >> 1] << 16 >> 16) | 0;
    var $5 = $4 + $deltaLog2 | 0;
    var $6 = 1 << $4;
    if (1 << $5 >>> 0 > 16777215) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = HEAPU32[$table + 12 >> 2];
    var $12 = $11 << $5;
    var $13 = $table | 0;
    var $16 = HEAP32[HEAP32[$13 >> 2] >> 2];
    var $17 = FUNCTION_TABLE[$16]($table, $12);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $21 = 32 - $5 & 65535;
    HEAP16[$1 >> 1] = $21;
    HEAP32[$table + 20 >> 2] = 0;
    var $23 = $table + 24 | 0;
    var $25 = HEAP32[$23 >> 2] + 1 | 0;
    HEAP32[$23 >> 2] = $25;
    _memset($17, 0, $12, 1);
    var $26 = $table + 28 | 0;
    var $27 = HEAPU32[$26 >> 2];
    HEAP32[$26 >> 2] = $17;
    var $30 = HEAP32[HEAP32[$13 >> 2] + 16 >> 2];
    var $oldEntryAddr_01 = $27;
    var $i_02 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_02;
    var $oldEntryAddr_01;
    var $32 = $oldEntryAddr_01;
    var $33 = HEAPU32[$32 >> 2];
    if ($33 >>> 0 > 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $36 = $oldEntryAddr_01;
    var $37 = $33 & -2;
    HEAP32[$32 >> 2] = $37;
    var $38 = __ZL13FindFreeEntryP12JSDHashTablej($table, $37);
    FUNCTION_TABLE[$30]($table, $36, $38);
    var $39 = HEAP32[$32 >> 2];
    HEAP32[$38 >> 2] = $39;
    __label__ = 6;
    break;
   case 6:
    var $43 = $i_02 + 1 | 0;
    if ($43 >>> 0 < $6 >>> 0) {
      var $oldEntryAddr_01 = $oldEntryAddr_01 + $11 | 0;
      var $i_02 = $43;
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $48 = HEAP32[HEAP32[$13 >> 2] + 4 >> 2];
    FUNCTION_TABLE[$48]($table, $27);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11ChangeTableP12JSDHashTablei["X"] = 1;

function _JS_DHashTableRawRemove($table, $entry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $entry | 0;
    var $2 = HEAP32[$1 >> 2];
    var $6 = HEAP32[HEAP32[$table >> 2] + 20 >> 2];
    FUNCTION_TABLE[$6]($table, $entry);
    if (($2 & 1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = 1;
    var $10 = $table + 20 | 0;
    var $12 = HEAP32[$10 >> 2] + 1 | 0;
    HEAP32[$10 >> 2] = $12;
    __label__ = 4;
    break;
   case 3:
    HEAP32[$1 >> 2] = 0;
    __label__ = 4;
    break;
   case 4:
    var $15 = $table + 16 | 0;
    var $17 = HEAP32[$15 >> 2] - 1 | 0;
    HEAP32[$15 >> 2] = $17;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_strtod_harder($state, $s00, $se, $err) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($err | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$err >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    var $4 = __strtod($state, $s00, $se);
    return $4;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __strtod($state, $s00, $se) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $bbe = __stackBase__;
    var $bbbits = __stackBase__ + 4;
    var $s_0 = $s00;
    __label__ = 2;
    break;
   case 2:
    var $s_0;
    var $2 = HEAP8[$s_0];
    var $3 = $2 << 24 >> 24;
    if (($3 | 0) == 45) {
      __label__ = 3;
      break;
    } else if (($3 | 0) == 43) {
      var $sign_0 = 0;
      __label__ = 4;
      break;
    } else if (($3 | 0) == 9 || ($3 | 0) == 10 || ($3 | 0) == 11 || ($3 | 0) == 12 || ($3 | 0) == 13 || ($3 | 0) == 32) {
      __label__ = 5;
      break;
    } else if (($3 | 0) == 0) {
      var $_1 = $s00;
      __label__ = 50;
      break;
    } else {
      var $sign_1 = 0;
      var $s_1 = $s_0;
      var $9 = $2;
      __label__ = 6;
      break;
    }
   case 3:
    var $sign_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $sign_0;
    var $4 = $s_0 + 1 | 0;
    var $5 = HEAP8[$4];
    if ($5 << 24 >> 24 == 0) {
      var $_1 = $s00;
      __label__ = 50;
      break;
    } else {
      var $sign_1 = $sign_0;
      var $s_1 = $4;
      var $9 = $5;
      __label__ = 6;
      break;
    }
   case 5:
    var $s_0 = $s_0 + 1 | 0;
    __label__ = 2;
    break;
   case 6:
    var $9;
    var $s_1;
    var $sign_1;
    if ($9 << 24 >> 24 == 48) {
      var $s_2 = $s_1;
      __label__ = 7;
      break;
    } else {
      var $nz0_0 = 0;
      var $s_3 = $s_1;
      var $13 = $9;
      __label__ = 8;
      break;
    }
   case 7:
    var $s_2;
    var $11 = $s_2 + 1 | 0;
    var $12 = HEAP8[$11];
    if ($12 << 24 >> 24 == 48) {
      var $s_2 = $11;
      __label__ = 7;
      break;
    } else if ($12 << 24 >> 24 == 0) {
      var $sign_2 = $sign_1;
      var $s_13 = $11;
      var $rv_16$1 = 0;
      var $rv_16$0 = 0;
      __label__ = 165;
      break;
    } else {
      var $nz0_0 = 1;
      var $s_3 = $11;
      var $13 = $12;
      __label__ = 8;
      break;
    }
   case 8:
    var $13;
    var $s_3;
    var $nz0_0;
    var $14 = $13 << 24 >> 24;
    if (($13 - 48 & 255 & 255) < 10) {
      var $z_0202 = 0;
      var $y_0203 = 0;
      var $s_4204 = $s_3;
      var $nd_0205 = 0;
      var $16 = $14;
      __label__ = 9;
      break;
    } else {
      var $z_0_lcssa = 0;
      var $y_0_lcssa = 0;
      var $s_4_lcssa = $s_3;
      var $nd_0_lcssa = 0;
      var $_lcssa199 = $13;
      var $_lcssa200 = $14;
      __label__ = 14;
      break;
    }
   case 9:
    var $16;
    var $nd_0205;
    var $s_4204;
    var $y_0203;
    var $z_0202;
    if (($nd_0205 | 0) < 9) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $y_1 = $y_0203 * 10 - 48 + $16 | 0;
    var $z_1 = $z_0202;
    __label__ = 13;
    break;
   case 11:
    if (($nd_0205 | 0) < 16) {
      __label__ = 12;
      break;
    } else {
      var $y_1 = $y_0203;
      var $z_1 = $z_0202;
      __label__ = 13;
      break;
    }
   case 12:
    var $y_1 = $y_0203;
    var $z_1 = $z_0202 * 10 - 48 + $16 | 0;
    __label__ = 13;
    break;
   case 13:
    var $z_1;
    var $y_1;
    var $29 = $nd_0205 + 1 | 0;
    var $30 = $s_4204 + 1 | 0;
    var $31 = HEAPU8[$30];
    var $32 = $31 << 24 >> 24;
    if (($31 - 48 & 255 & 255) < 10) {
      var $z_0202 = $z_1;
      var $y_0203 = $y_1;
      var $s_4204 = $30;
      var $nd_0205 = $29;
      var $16 = $32;
      __label__ = 9;
      break;
    } else {
      var $z_0_lcssa = $z_1;
      var $y_0_lcssa = $y_1;
      var $s_4_lcssa = $30;
      var $nd_0_lcssa = $29;
      var $_lcssa199 = $31;
      var $_lcssa200 = $32;
      __label__ = 14;
      break;
    }
   case 14:
    var $_lcssa200;
    var $_lcssa199;
    var $nd_0_lcssa;
    var $s_4_lcssa;
    var $y_0_lcssa;
    var $z_0_lcssa;
    if ($_lcssa199 << 24 >> 24 == 46) {
      __label__ = 15;
      break;
    } else {
      var $c_3 = $_lcssa200;
      var $nd_5 = $nd_0_lcssa;
      var $nf_3 = 0;
      var $nz_4 = 0;
      var $s_8 = $s_4_lcssa;
      var $s0_2 = $s_3;
      var $y_8 = $y_0_lcssa;
      var $z_8 = $z_0_lcssa;
      __label__ = 35;
      break;
    }
   case 15:
    var $36 = $s_4_lcssa + 1 | 0;
    var $37 = HEAP8[$36];
    var $38 = $37 << 24 >> 24;
    if (($nd_0_lcssa | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      var $c_1 = $38;
      var $nd_1 = $nd_0_lcssa;
      var $nf_0 = 0;
      var $nz_1 = 0;
      var $s_6 = $36;
      var $s0_0 = $s_3;
      var $y_2 = $y_0_lcssa;
      var $z_2 = $z_0_lcssa;
      __label__ = 20;
      break;
    }
   case 16:
    if ($37 << 24 >> 24 == 48) {
      var $s_5192 = $36;
      var $nz_0193 = 0;
      __label__ = 17;
      break;
    } else {
      var $s_5_lcssa = $36;
      var $nz_0_lcssa = 0;
      var $c_0_lcssa = $38;
      __label__ = 19;
      break;
    }
   case 17:
    var $nz_0193;
    var $s_5192;
    var $41 = $nz_0193 + 1 | 0;
    var $42 = $s_5192 + 1 | 0;
    var $43 = HEAP8[$42];
    if ($43 << 24 >> 24 == 48) {
      var $s_5192 = $42;
      var $nz_0193 = $41;
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $s_5_lcssa = $42;
    var $nz_0_lcssa = $41;
    var $c_0_lcssa = $43 << 24 >> 24;
    __label__ = 19;
    break;
   case 19:
    var $c_0_lcssa;
    var $nz_0_lcssa;
    var $s_5_lcssa;
    if (($c_0_lcssa - 49 | 0) >>> 0 < 9) {
      var $c_2 = $c_0_lcssa;
      var $nd_2 = $nd_0_lcssa;
      var $nf_1 = $nz_0_lcssa;
      var $nz_2 = 0;
      var $s_7 = $s_5_lcssa;
      var $s0_1 = $s_5_lcssa;
      var $y_3 = $y_0_lcssa;
      var $z_3 = $z_0_lcssa;
      __label__ = 21;
      break;
    } else {
      var $c_3 = $c_0_lcssa;
      var $nd_5 = $nd_0_lcssa;
      var $nf_3 = 0;
      var $nz_4 = $nz_0_lcssa;
      var $s_8 = $s_5_lcssa;
      var $s0_2 = $s_3;
      var $y_8 = $y_0_lcssa;
      var $z_8 = $z_0_lcssa;
      __label__ = 35;
      break;
    }
   case 20:
    var $z_2;
    var $y_2;
    var $s0_0;
    var $s_6;
    var $nz_1;
    var $nf_0;
    var $nd_1;
    var $c_1;
    if (($c_1 - 48 | 0) >>> 0 < 10) {
      var $c_2 = $c_1;
      var $nd_2 = $nd_1;
      var $nf_1 = $nf_0;
      var $nz_2 = $nz_1;
      var $s_7 = $s_6;
      var $s0_1 = $s0_0;
      var $y_3 = $y_2;
      var $z_3 = $z_2;
      __label__ = 21;
      break;
    } else {
      var $c_3 = $c_1;
      var $nd_5 = $nd_1;
      var $nf_3 = $nf_0;
      var $nz_4 = $nz_1;
      var $s_8 = $s_6;
      var $s0_2 = $s0_0;
      var $y_8 = $y_2;
      var $z_8 = $z_2;
      __label__ = 35;
      break;
    }
   case 21:
    var $z_3;
    var $y_3;
    var $s0_1;
    var $s_7;
    var $nz_2;
    var $nf_1;
    var $nd_2;
    var $c_2;
    var $51 = $nz_2 + 1 | 0;
    var $52 = $c_2 - 48 | 0;
    if (($52 | 0) == 0) {
      var $nd_4 = $nd_2;
      var $nf_2 = $nf_1;
      var $nz_3 = $51;
      var $y_7 = $y_3;
      var $z_7 = $z_3;
      __label__ = 34;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $55 = $nf_1 + $51 | 0;
    var $57 = $nd_2 + 1 | 0;
    var $58 = ($nd_2 | 0) < 9;
    if (($nz_2 | 0) > 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 23:
    var $smax = ($51 | 0) > 2 ? $51 : 2;
    var $z_4117 = $z_3;
    var $y_4118 = $y_3;
    var $i_0119 = 1;
    var $62 = $57;
    var $61 = $58;
    __label__ = 24;
    break;
   case 24:
    var $61;
    var $62;
    var $i_0119;
    var $y_4118;
    var $z_4117;
    if ($61) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    var $y_5 = $y_4118 * 10 | 0;
    var $z_5 = $z_4117;
    __label__ = 28;
    break;
   case 26:
    if (($62 | 0) < 17) {
      __label__ = 27;
      break;
    } else {
      var $y_5 = $y_4118;
      var $z_5 = $z_4117;
      __label__ = 28;
      break;
    }
   case 27:
    var $y_5 = $y_4118;
    var $z_5 = $z_4117 * 10 | 0;
    __label__ = 28;
    break;
   case 28:
    var $z_5;
    var $y_5;
    var $70 = $i_0119 + 1 | 0;
    var $73 = ($62 | 0) < 9;
    if (($70 | 0) < ($51 | 0)) {
      var $z_4117 = $z_5;
      var $y_4118 = $y_5;
      var $i_0119 = $70;
      var $62 = $62 + 1 | 0;
      var $61 = $73;
      __label__ = 24;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $74 = $nd_2 + $smax | 0;
    if ($73) {
      var $_lcssa287 = $74;
      var $y_4_lcssa288 = $y_5;
      var $z_4_lcssa291 = $z_5;
      __label__ = 31;
      break;
    } else {
      var $_lcssa286 = $74;
      var $y_4_lcssa289 = $y_5;
      var $z_4_lcssa290 = $z_5;
      __label__ = 32;
      break;
    }
   case 30:
    if ($58) {
      var $_lcssa287 = $57;
      var $y_4_lcssa288 = $y_3;
      var $z_4_lcssa291 = $z_3;
      __label__ = 31;
      break;
    } else {
      var $_lcssa286 = $57;
      var $y_4_lcssa289 = $y_3;
      var $z_4_lcssa290 = $z_3;
      __label__ = 32;
      break;
    }
   case 31:
    var $z_4_lcssa291;
    var $y_4_lcssa288;
    var $_lcssa287;
    var $nd_4 = $_lcssa287;
    var $nf_2 = $55;
    var $nz_3 = 0;
    var $y_7 = $y_4_lcssa288 * 10 + $52 | 0;
    var $z_7 = $z_4_lcssa291;
    __label__ = 34;
    break;
   case 32:
    var $z_4_lcssa290;
    var $y_4_lcssa289;
    var $_lcssa286;
    if (($_lcssa286 | 0) < 17) {
      __label__ = 33;
      break;
    } else {
      var $nd_4 = $_lcssa286;
      var $nf_2 = $55;
      var $nz_3 = 0;
      var $y_7 = $y_4_lcssa289;
      var $z_7 = $z_4_lcssa290;
      __label__ = 34;
      break;
    }
   case 33:
    var $nd_4 = $_lcssa286;
    var $nf_2 = $55;
    var $nz_3 = 0;
    var $y_7 = $y_4_lcssa289;
    var $z_7 = $z_4_lcssa290 * 10 + $52 | 0;
    __label__ = 34;
    break;
   case 34:
    var $z_7;
    var $y_7;
    var $nz_3;
    var $nf_2;
    var $nd_4;
    var $85 = $s_7 + 1 | 0;
    var $c_1 = HEAP8[$85] << 24 >> 24;
    var $nd_1 = $nd_4;
    var $nf_0 = $nf_2;
    var $nz_1 = $nz_3;
    var $s_6 = $85;
    var $s0_0 = $s0_1;
    var $y_2 = $y_7;
    var $z_2 = $z_7;
    __label__ = 20;
    break;
   case 35:
    var $z_8;
    var $y_8;
    var $s0_2;
    var $s_8;
    var $nz_4;
    var $nf_3;
    var $nd_5;
    var $c_3;
    if (($c_3 | 0) == 101 || ($c_3 | 0) == 69) {
      __label__ = 36;
      break;
    } else {
      var $_0 = $s00;
      var $e_1 = 0;
      var $s_12 = $s_8;
      __label__ = 48;
      break;
    }
   case 36:
    if (($nz_4 | $nz0_0 | $nd_5 | 0) == 0) {
      var $_1 = $s00;
      __label__ = 50;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $93 = $s_8 + 1 | 0;
    var $95 = HEAP8[$93] << 24 >> 24;
    if (($95 | 0) == 45) {
      __label__ = 38;
      break;
    } else if (($95 | 0) == 43) {
      var $esign_0 = 0;
      __label__ = 39;
      break;
    } else {
      var $c_4 = $95;
      var $esign_1 = 0;
      var $s_9 = $93;
      __label__ = 40;
      break;
    }
   case 38:
    var $esign_0 = 1;
    __label__ = 39;
    break;
   case 39:
    var $esign_0;
    var $98 = $s_8 + 2 | 0;
    var $c_4 = HEAP8[$98] << 24 >> 24;
    var $esign_1 = $esign_0;
    var $s_9 = $98;
    __label__ = 40;
    break;
   case 40:
    var $s_9;
    var $esign_1;
    var $c_4;
    if (($c_4 - 48 | 0) >>> 0 < 10) {
      __label__ = 41;
      break;
    } else {
      var $_0 = $s_8;
      var $e_1 = 0;
      var $s_12 = $s_8;
      __label__ = 48;
      break;
    }
   case 41:
    if (($c_4 | 0) == 48) {
      var $s_10131 = $s_9;
      __label__ = 42;
      break;
    } else {
      var $s_10_lcssa = $s_9;
      var $c_5_lcssa = $c_4;
      __label__ = 44;
      break;
    }
   case 42:
    var $s_10131;
    var $104 = $s_10131 + 1 | 0;
    var $105 = HEAP8[$104];
    if ($105 << 24 >> 24 == 48) {
      var $s_10131 = $104;
      __label__ = 42;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    var $s_10_lcssa = $104;
    var $c_5_lcssa = $105 << 24 >> 24;
    __label__ = 44;
    break;
   case 44:
    var $c_5_lcssa;
    var $s_10_lcssa;
    if (($c_5_lcssa - 49 | 0) >>> 0 < 9) {
      __label__ = 45;
      break;
    } else {
      var $_0 = $s_8;
      var $e_1 = 0;
      var $s_12 = $s_10_lcssa;
      __label__ = 48;
      break;
    }
   case 45:
    var $L_0124 = $c_5_lcssa - 48 | 0;
    var $110 = $s_10_lcssa + 1 | 0;
    var $111 = HEAPU8[$110];
    if (($111 - 48 & 255 & 255) < 10) {
      var $L_0126 = $L_0124;
      var $114 = $110;
      var $113 = $111;
      __label__ = 46;
      break;
    } else {
      var $L_0_lcssa = $L_0124;
      var $_lcssa123 = $110;
      __label__ = 47;
      break;
    }
   case 46:
    var $113;
    var $114;
    var $L_0126;
    var $L_0 = ($113 << 24 >> 24) + $L_0126 * 10 - 48 | 0;
    var $118 = $114 + 1 | 0;
    var $119 = HEAPU8[$118];
    if (($119 - 48 & 255 & 255) < 10) {
      var $L_0126 = $L_0;
      var $114 = $118;
      var $113 = $119;
      __label__ = 46;
      break;
    } else {
      var $L_0_lcssa = $L_0;
      var $_lcssa123 = $118;
      __label__ = 47;
      break;
    }
   case 47:
    var $_lcssa123;
    var $L_0_lcssa;
    var $e_0 = ($_lcssa123 - $s_10_lcssa | 0) > 8 | ($L_0_lcssa | 0) > 19999 ? 19999 : $L_0_lcssa;
    var $e_0_ = ($esign_1 | 0) == 0 ? $e_0 : -$e_0 | 0;
    var $_0 = $s_8;
    var $e_1 = $e_0_;
    var $s_12 = $_lcssa123;
    __label__ = 48;
    break;
   case 48:
    var $s_12;
    var $e_1;
    var $_0;
    if (($nd_5 | 0) == 0) {
      __label__ = 49;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 49:
    if (($nz_4 | $nz0_0 | 0) == 0) {
      var $_1 = $_0;
      __label__ = 50;
      break;
    } else {
      var $sign_2 = $sign_1;
      var $s_13 = $s_12;
      var $rv_16$1 = 0;
      var $rv_16$0 = 0;
      __label__ = 165;
      break;
    }
   case 50:
    var $_1;
    var $sign_2 = 0;
    var $s_13 = $_1;
    var $rv_16$1 = 0;
    var $rv_16$0 = 0;
    __label__ = 165;
    break;
   case 51:
    var $134 = $e_1 - $nf_3 | 0;
    var $nd0_0 = ($nd_0_lcssa | 0) == 0 ? $nd_5 : $nd_0_lcssa;
    var $136 = ($nd_5 | 0) < 16;
    var $137 = $136 ? $nd_5 : 16;
    var $138 = $y_8 >>> 0;
    if (($137 | 0) > 9) {
      __label__ = 52;
      break;
    } else {
      var $rv_0_in = $138;
      __label__ = 53;
      break;
    }
   case 52:
    var $142 = _tens + ($137 - 9 << 3) | 0;
    var $143 = (tempDoubleI32[0] = HEAP32[$142 >> 2], tempDoubleI32[1] = HEAP32[$142 + 4 >> 2], tempDoubleF64[0]);
    var $rv_0_in = $143 * $138 + ($z_8 >>> 0);
    __label__ = 53;
    break;
   case 53:
    var $rv_0_in;
    tempDoubleF64[0] = $rv_0_in;
    var $rv_0$0 = tempDoubleI32[0];
    var $rv_0$1 = tempDoubleI32[1];
    if ($136) {
      __label__ = 54;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 54:
    if (($e_1 | 0) == ($nf_3 | 0)) {
      var $sign_2 = $sign_1;
      var $s_13 = $s_12;
      var $rv_16$1 = $rv_0$1;
      var $rv_16$0 = $rv_0$0;
      __label__ = 165;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    if (($134 | 0) > 0) {
      __label__ = 56;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 56:
    if (($134 | 0) < 23) {
      __label__ = 57;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 57:
    var $155 = _tens + ($134 << 3) | 0;
    var $156 = (tempDoubleI32[0] = HEAP32[$155 >> 2], tempDoubleI32[1] = HEAP32[$155 + 4 >> 2], tempDoubleF64[0]);
    var $157 = $rv_0_in * $156;
    tempDoubleF64[0] = $157;
    var $sign_2 = $sign_1;
    var $s_13 = $s_12;
    var $rv_16$1 = tempDoubleI32[1];
    var $rv_16$0 = tempDoubleI32[0];
    __label__ = 165;
    break;
   case 58:
    var $160 = 15 - $nd_5 | 0;
    if (($134 | 0) > ($160 + 22 | 0)) {
      __label__ = 62;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 59:
    var $165 = _tens + ($160 << 3) | 0;
    var $166 = (tempDoubleI32[0] = HEAP32[$165 >> 2], tempDoubleI32[1] = HEAP32[$165 + 4 >> 2], tempDoubleF64[0]);
    var $167 = $rv_0_in * $166;
    var $168 = _tens + ($134 - $160 << 3) | 0;
    var $169 = (tempDoubleI32[0] = HEAP32[$168 >> 2], tempDoubleI32[1] = HEAP32[$168 + 4 >> 2], tempDoubleF64[0]);
    var $170 = $167 * $169;
    tempDoubleF64[0] = $170;
    var $sign_2 = $sign_1;
    var $s_13 = $s_12;
    var $rv_16$1 = tempDoubleI32[1];
    var $rv_16$0 = tempDoubleI32[0];
    __label__ = 165;
    break;
   case 60:
    if (($134 | 0) > -23) {
      __label__ = 61;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 61:
    var $176 = _tens + (-$134 << 3) | 0;
    var $177 = (tempDoubleI32[0] = HEAP32[$176 >> 2], tempDoubleI32[1] = HEAP32[$176 + 4 >> 2], tempDoubleF64[0]);
    var $178 = $rv_0_in / $177;
    tempDoubleF64[0] = $178;
    var $sign_2 = $sign_1;
    var $s_13 = $s_12;
    var $rv_16$1 = tempDoubleI32[1];
    var $rv_16$0 = tempDoubleI32[0];
    __label__ = 165;
    break;
   case 62:
    var $182 = $134 + ($nd_5 - $137) | 0;
    if (($182 | 0) > 0) {
      __label__ = 63;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 63:
    var $185 = $182 & 15;
    if (($185 | 0) == 0) {
      var $rv_1$1 = $rv_0$1;
      var $rv_1$0 = $rv_0$0;
      __label__ = 65;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    var $188 = _tens + ($185 << 3) | 0;
    var $189 = (tempDoubleI32[0] = HEAP32[$188 >> 2], tempDoubleI32[1] = HEAP32[$188 + 4 >> 2], tempDoubleF64[0]);
    var $190 = $rv_0_in * $189;
    tempDoubleF64[0] = $190;
    var $rv_1$1 = tempDoubleI32[1];
    var $rv_1$0 = tempDoubleI32[0];
    __label__ = 65;
    break;
   case 65:
    var $rv_1$0;
    var $rv_1$1;
    var $193 = $182 & -16;
    if (($193 | 0) == 0) {
      var $scale_1 = 0;
      var $rv_9$1 = $rv_1$1;
      var $rv_9$0 = $rv_1$0;
      __label__ = 94;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 66:
    if (($193 | 0) > 308) {
      __label__ = 67;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 67:
    var $197 = ___errno();
    HEAP32[$197 >> 2] = 34;
    var $sign_2 = $sign_1;
    var $s_13 = $s_12;
    var $rv_16$1 = 2146435072;
    var $rv_16$0 = 0;
    __label__ = 165;
    break;
   case 68:
    var $199 = ___errno();
    HEAP32[$199 >> 2] = 34;
    if (($298 | 0) == 0) {
      var $sign_2 = $sign_1;
      var $s_13 = $s_12;
      var $rv_16$1 = 2146435072;
      var $rv_16$0 = 0;
      __label__ = 165;
      break;
    } else {
      var $delta_4 = $361;
      var $rv_15$1 = 2146435072;
      var $rv_15$0 = 0;
      __label__ = 164;
      break;
    }
   case 69:
    var $202 = $182 >> 4;
    if (($202 | 0) > 1) {
      var $rv_3143$1 = $rv_1$1;
      var $rv_3143$0 = $rv_1$0;
      var $j_0144 = 0;
      var $e1_0145 = $202;
      __label__ = 70;
      break;
    } else {
      var $rv_3_lcssa$1 = $rv_1$1;
      var $rv_3_lcssa$0 = $rv_1$0;
      var $j_0_lcssa = 0;
      __label__ = 73;
      break;
    }
   case 70:
    var $e1_0145;
    var $j_0144;
    var $rv_3143$0;
    var $rv_3143$1;
    if (($e1_0145 & 1 | 0) == 0) {
      var $rv_4$1 = $rv_3143$1;
      var $rv_4$0 = $rv_3143$0;
      __label__ = 72;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 71:
    var $207 = _bigtens + ($j_0144 << 3) | 0;
    var $208 = (tempDoubleI32[0] = HEAP32[$207 >> 2], tempDoubleI32[1] = HEAP32[$207 + 4 >> 2], tempDoubleF64[0]);
    var $209 = (tempDoubleI32[0] = $rv_3143$0, tempDoubleI32[1] = $rv_3143$1, tempDoubleF64[0]);
    var $210 = $209 * $208;
    tempDoubleF64[0] = $210;
    var $rv_4$1 = tempDoubleI32[1];
    var $rv_4$0 = tempDoubleI32[0];
    __label__ = 72;
    break;
   case 72:
    var $rv_4$0;
    var $rv_4$1;
    var $213 = $j_0144 + 1 | 0;
    var $214 = $e1_0145 >> 1;
    if (($214 | 0) > 1) {
      var $rv_3143$1 = $rv_4$1;
      var $rv_3143$0 = $rv_4$0;
      var $j_0144 = $213;
      var $e1_0145 = $214;
      __label__ = 70;
      break;
    } else {
      var $rv_3_lcssa$1 = $rv_4$1;
      var $rv_3_lcssa$0 = $rv_4$0;
      var $j_0_lcssa = $213;
      __label__ = 73;
      break;
    }
   case 73:
    var $j_0_lcssa;
    var $rv_3_lcssa$0;
    var $rv_3_lcssa$1;
    var $221 = _bigtens + ($j_0_lcssa << 3) | 0;
    var $222 = (tempDoubleI32[0] = HEAP32[$221 >> 2], tempDoubleI32[1] = HEAP32[$221 + 4 >> 2], tempDoubleF64[0]);
    var $223 = (tempDoubleI32[0] = 0 | $rv_3_lcssa$0 & -1, tempDoubleI32[1] = $rv_3_lcssa$1 - 55574528 | $rv_3_lcssa$1 & 0, tempDoubleF64[0]);
    var $224 = $223 * $222;
    tempDoubleF64[0] = $224;
    var $225$0 = tempDoubleI32[0];
    var $225$1 = tempDoubleI32[1];
    var $227 = $225$1;
    var $228 = $227 & 2146435072;
    if ($228 >>> 0 > 2090860544) {
      __label__ = 67;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 74:
    if ($228 >>> 0 > 2089811968) {
      var $scale_1 = 0;
      var $rv_9$1 = 2146435071;
      var $rv_9$0 = -1;
      __label__ = 94;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 75:
    var $scale_1 = 0;
    var $rv_9$1 = $227 + 55574528 | $225$1 & 0;
    var $rv_9$0 = 0 | $225$0 & -1;
    __label__ = 94;
    break;
   case 76:
    if (($182 | 0) < 0) {
      __label__ = 77;
      break;
    } else {
      var $scale_1 = 0;
      var $rv_9$1 = $rv_0$1;
      var $rv_9$0 = $rv_0$0;
      __label__ = 94;
      break;
    }
   case 77:
    var $239 = -$182 | 0;
    var $240 = $239 & 15;
    if (($240 | 0) == 0) {
      var $rv_5$1 = $rv_0$1;
      var $rv_5$0 = $rv_0$0;
      __label__ = 79;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 78:
    var $243 = _tens + ($240 << 3) | 0;
    var $244 = (tempDoubleI32[0] = HEAP32[$243 >> 2], tempDoubleI32[1] = HEAP32[$243 + 4 >> 2], tempDoubleF64[0]);
    var $245 = $rv_0_in / $244;
    tempDoubleF64[0] = $245;
    var $rv_5$1 = tempDoubleI32[1];
    var $rv_5$0 = tempDoubleI32[0];
    __label__ = 79;
    break;
   case 79:
    var $rv_5$0;
    var $rv_5$1;
    var $248 = $239 >> 4;
    if (($248 | 0) == 0) {
      var $scale_1 = 0;
      var $rv_9$1 = $rv_5$1;
      var $rv_9$0 = $rv_5$0;
      __label__ = 94;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 80:
    if (($248 | 0) > 31) {
      __label__ = 92;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 81:
    var $254 = ($248 & 16 | 0) == 0;
    var $scale_0 = $254 ? 0 : 106;
    if (($248 | 0) > 0) {
      var $rv_6136$1 = $rv_5$1;
      var $rv_6136$0 = $rv_5$0;
      var $j_1137 = 0;
      var $e1_1138 = $248;
      __label__ = 82;
      break;
    } else {
      var $rv_6_lcssa$1 = $rv_5$1;
      var $rv_6_lcssa$0 = $rv_5$0;
      __label__ = 85;
      break;
    }
   case 82:
    var $e1_1138;
    var $j_1137;
    var $rv_6136$0;
    var $rv_6136$1;
    if (($e1_1138 & 1 | 0) == 0) {
      var $rv_7$1 = $rv_6136$1;
      var $rv_7$0 = $rv_6136$0;
      __label__ = 84;
      break;
    } else {
      __label__ = 83;
      break;
    }
   case 83:
    var $259 = _tinytens + ($j_1137 << 3) | 0;
    var $260 = (tempDoubleI32[0] = HEAP32[$259 >> 2], tempDoubleI32[1] = HEAP32[$259 + 4 >> 2], tempDoubleF64[0]);
    var $261 = (tempDoubleI32[0] = $rv_6136$0, tempDoubleI32[1] = $rv_6136$1, tempDoubleF64[0]);
    var $262 = $261 * $260;
    tempDoubleF64[0] = $262;
    var $rv_7$1 = tempDoubleI32[1];
    var $rv_7$0 = tempDoubleI32[0];
    __label__ = 84;
    break;
   case 84:
    var $rv_7$0;
    var $rv_7$1;
    var $266 = $e1_1138 >> 1;
    if (($266 | 0) > 0) {
      var $rv_6136$1 = $rv_7$1;
      var $rv_6136$0 = $rv_7$0;
      var $j_1137 = $j_1137 + 1 | 0;
      var $e1_1138 = $266;
      __label__ = 82;
      break;
    } else {
      var $rv_6_lcssa$1 = $rv_7$1;
      var $rv_6_lcssa$0 = $rv_7$0;
      __label__ = 85;
      break;
    }
   case 85:
    var $rv_6_lcssa$0;
    var $rv_6_lcssa$1;
    if ($254) {
      var $rv_8$1 = $rv_6_lcssa$1;
      var $rv_8$0 = $rv_6_lcssa$0;
      __label__ = 91;
      break;
    } else {
      __label__ = 86;
      break;
    }
   case 86:
    var $272 = 107 - (($rv_6_lcssa$1 >>> 20 | 0 << 12) & 2047) | 0;
    if (($272 | 0) > 0) {
      __label__ = 87;
      break;
    } else {
      var $rv_8$1 = $rv_6_lcssa$1;
      var $rv_8$0 = $rv_6_lcssa$0;
      __label__ = 91;
      break;
    }
   case 87:
    if (($272 | 0) > 31) {
      __label__ = 88;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 88:
    if (($272 | 0) > 52) {
      var $rv_8$1 = 57671680;
      var $rv_8$0 = 0;
      __label__ = 91;
      break;
    } else {
      __label__ = 89;
      break;
    }
   case 89:
    var $rv_8$1 = -1 << $272 - 32 & $rv_6_lcssa$1;
    var $rv_8$0 = 0;
    __label__ = 91;
    break;
   case 90:
    var $rv_8$1 = 0 | $rv_6_lcssa$1 & -1;
    var $rv_8$0 = -1 << $272 & $rv_6_lcssa$0 | $rv_6_lcssa$0 & 0;
    __label__ = 91;
    break;
   case 91:
    var $rv_8$0;
    var $rv_8$1;
    var $292 = (tempDoubleI32[0] = $rv_8$0, tempDoubleI32[1] = $rv_8$1, tempDoubleF64[0]);
    if ($292 != 0) {
      var $scale_1 = $scale_0;
      var $rv_9$1 = $rv_8$1;
      var $rv_9$0 = $rv_8$0;
      __label__ = 94;
      break;
    } else {
      __label__ = 92;
      break;
    }
   case 92:
    var $294 = ___errno();
    HEAP32[$294 >> 2] = 34;
    var $sign_2 = $sign_1;
    var $s_13 = $s_12;
    var $rv_16$1 = 0;
    var $rv_16$0 = 0;
    __label__ = 165;
    break;
   case 93:
    var $delta_1;
    var $295 = ___errno();
    HEAP32[$295 >> 2] = 34;
    if (($298 | 0) == 0) {
      var $sign_2 = $sign_1;
      var $s_13 = $s_12;
      var $rv_16$1 = 0;
      var $rv_16$0 = 0;
      __label__ = 165;
      break;
    } else {
      var $delta_4 = $delta_1;
      var $rv_15$1 = 0;
      var $rv_15$0 = 0;
      __label__ = 164;
      break;
    }
   case 94:
    var $rv_9$0;
    var $rv_9$1;
    var $scale_1;
    var $298 = _s2b($state, $s0_2, $nd0_0, $nd_5, $y_8);
    var $299 = $298 + 4 | 0;
    var $301 = $298 + 12 | 0;
    var $302 = $298 + 16 | 0;
    var $303 = ($134 | 0) > -1;
    var $bd5_0 = $303 ? $134 : 0;
    var $bb5_0 = $303 ? 0 : -$134 | 0;
    var $bd2_1 = $scale_1 + $bd5_0 | 0;
    var $305 = ($bb5_0 | 0) > 0;
    var $306 = ($bd5_0 | 0) > 0;
    var $307 = ($scale_1 | 0) == 0;
    var $308 = ($scale_1 | 0) != 0;
    var $rv_10$1 = $rv_9$1;
    var $rv_10$0 = $rv_9$0;
    __label__ = 95;
    break;
   case 95:
    var $rv_10$0;
    var $rv_10$1;
    var $310 = HEAP32[$299 >> 2];
    var $311 = _Balloc($state, $310);
    var $313 = $311 + 12 | 0;
    var $316 = (HEAP32[$302 >> 2] << 2) + 8 | 0;
    _memcpy($313, $301, $316, 1);
    var $317 = (tempDoubleI32[0] = $rv_10$0, tempDoubleI32[1] = $rv_10$1, tempDoubleF64[0]);
    var $318 = _d2b($state, $317, $bbe, $bbbits);
    var $319 = _i2b($state, 1);
    var $320 = HEAP32[$bbe >> 2];
    var $321 = ($320 | 0) > -1;
    var $_neg = $321 ? 0 : -$320 | 0;
    var $322 = $321 ? $320 : 0;
    var $bb2_1 = $322 + $bb5_0 | 0;
    var $323 = $320 - $scale_1 | 0;
    var $324 = HEAP32[$bbbits >> 2];
    var $j_2 = ($324 - 1 + $323 | 0) < -1022 ? $323 + 1075 | 0 : 54 - $324 | 0;
    var $330 = $j_2 + $bb2_1 | 0;
    var $332 = $bd2_1 + $_neg + $j_2 | 0;
    var $334 = ($330 | 0) < ($332 | 0) ? $330 : $332;
    var $i_1 = ($334 | 0) > ($bb2_1 | 0) ? $bb2_1 : $334;
    if (($i_1 | 0) > 0) {
      __label__ = 96;
      break;
    } else {
      var $bb2_2 = $330;
      var $bd2_2 = $332;
      var $bs2_0 = $bb2_1;
      __label__ = 97;
      break;
    }
   case 96:
    var $bb2_2 = $330 - $i_1 | 0;
    var $bd2_2 = $332 - $i_1 | 0;
    var $bs2_0 = $bb2_1 - $i_1 | 0;
    __label__ = 97;
    break;
   case 97:
    var $bs2_0;
    var $bd2_2;
    var $bb2_2;
    if ($305) {
      __label__ = 98;
      break;
    } else {
      var $bs_2 = $319;
      var $bb_2 = $318;
      __label__ = 99;
      break;
    }
   case 98:
    var $343 = _pow5mult($state, $319, $bb5_0);
    var $344 = _mult($state, $343, $318);
    _Bfree($state, $318);
    var $bs_2 = $343;
    var $bb_2 = $344;
    __label__ = 99;
    break;
   case 99:
    var $bb_2;
    var $bs_2;
    if (($bb2_2 | 0) > 0) {
      __label__ = 100;
      break;
    } else {
      var $bb_3 = $bb_2;
      __label__ = 101;
      break;
    }
   case 100:
    var $348 = _lshift($state, $bb_2, $bb2_2);
    var $bb_3 = $348;
    __label__ = 101;
    break;
   case 101:
    var $bb_3;
    if ($306) {
      __label__ = 102;
      break;
    } else {
      var $bd_2 = $311;
      __label__ = 103;
      break;
    }
   case 102:
    var $351 = _pow5mult($state, $311, $bd5_0);
    var $bd_2 = $351;
    __label__ = 103;
    break;
   case 103:
    var $bd_2;
    if (($bd2_2 | 0) > 0) {
      __label__ = 104;
      break;
    } else {
      var $bd_3 = $bd_2;
      __label__ = 105;
      break;
    }
   case 104:
    var $355 = _lshift($state, $bd_2, $bd2_2);
    var $bd_3 = $355;
    __label__ = 105;
    break;
   case 105:
    var $bd_3;
    if (($bs2_0 | 0) > 0) {
      __label__ = 106;
      break;
    } else {
      var $bs_3 = $bs_2;
      __label__ = 107;
      break;
    }
   case 106:
    var $359 = _lshift($state, $bs_2, $bs2_0);
    var $bs_3 = $359;
    __label__ = 107;
    break;
   case 107:
    var $bs_3;
    var $361 = _diff($state, $bb_3, $bd_3);
    var $362 = $361 + 12 | 0;
    var $363 = HEAPU32[$362 >> 2];
    HEAP32[$362 >> 2] = 0;
    var $364 = _cmp($361, $bs_3);
    if (($364 | 0) < 0) {
      __label__ = 108;
      break;
    } else {
      __label__ = 114;
      break;
    }
   case 108:
    if (($363 | 0) == 0) {
      __label__ = 109;
      break;
    } else {
      var $delta_3 = $361;
      var $rv_14$1 = $rv_10$1;
      var $rv_14$0 = $rv_10$0;
      __label__ = 161;
      break;
    }
   case 109:
    if (($rv_10$0 | 0) == 0) {
      __label__ = 110;
      break;
    } else {
      var $delta_3 = $361;
      var $rv_14$1 = $rv_10$1;
      var $rv_14$0 = $rv_10$0;
      __label__ = 161;
      break;
    }
   case 110:
    var $373 = $rv_10$1;
    if (($373 & 1048575 | 0) != 0 | ($373 & 2146435072) >>> 0 < 112197633) {
      var $delta_3 = $361;
      var $rv_14$1 = $rv_10$1;
      var $rv_14$0 = $rv_10$0;
      __label__ = 161;
      break;
    } else {
      __label__ = 111;
      break;
    }
   case 111:
    if ((HEAP32[$361 + 20 >> 2] | 0) == 0) {
      __label__ = 112;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 112:
    if ((HEAP32[$361 + 16 >> 2] | 0) < 2) {
      var $delta_3 = $361;
      var $rv_14$1 = $rv_10$1;
      var $rv_14$0 = $rv_10$0;
      __label__ = 161;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 113:
    var $387 = _lshift($state, $361, 1);
    var $388 = _cmp($387, $bs_3);
    if (($388 | 0) > 0) {
      var $delta_2 = $387;
      __label__ = 124;
      break;
    } else {
      var $delta_3 = $387;
      var $rv_14$1 = $rv_10$1;
      var $rv_14$0 = $rv_10$0;
      __label__ = 161;
      break;
    }
   case 114:
    if (($364 | 0) == 0) {
      __label__ = 115;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 115:
    var $393 = ($363 | 0) != 0;
    var $395 = $rv_10$1;
    var $396 = $395 & 1048575;
    if ($393) {
      __label__ = 116;
      break;
    } else {
      __label__ = 122;
      break;
    }
   case 116:
    if (($396 | 0) == 1048575) {
      __label__ = 117;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 117:
    var $400 = $rv_10$0;
    if ($307) {
      var $409 = -1;
      __label__ = 120;
      break;
    } else {
      __label__ = 118;
      break;
    }
   case 118:
    var $402 = $395 & 2146435072;
    if ($402 >>> 0 < 111149057) {
      __label__ = 119;
      break;
    } else {
      var $409 = -1;
      __label__ = 120;
      break;
    }
   case 119:
    var $409 = -1 << 107 - ($402 >>> 20);
    __label__ = 120;
    break;
   case 120:
    var $409;
    if (($400 | 0) == ($409 | 0)) {
      __label__ = 121;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 121:
    var $delta_3 = $361;
    var $rv_14$1 = ($395 & 2146435072) + 1048576 | 0;
    var $rv_14$0 = 0;
    __label__ = 161;
    break;
   case 122:
    if (($396 | 0) == 0) {
      __label__ = 123;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 123:
    if (($rv_10$0 | 0) == 0) {
      var $delta_2 = $361;
      __label__ = 124;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 124:
    var $delta_2;
    var $_pre18 = $rv_10$1 & 2146435072;
    if (($307 ^ 1) & $_pre18 >>> 0 < 112197633) {
      __label__ = 125;
      break;
    } else {
      __label__ = 126;
      break;
    }
   case 125:
    if ($_pre18 >>> 0 > 57671680) {
      var $rv_147$1 = $rv_10$1;
      var $rv_147$0 = $rv_10$0;
      var $delta_38 = $delta_2;
      __label__ = 162;
      break;
    } else {
      var $delta_1 = $delta_2;
      __label__ = 93;
      break;
    }
   case 126:
    var $delta_3 = $delta_2;
    var $rv_14$1 = $_pre18 - 1048576 | 1048575 | 0;
    var $rv_14$0 = 0 | -1;
    __label__ = 161;
    break;
   case 127:
    if (($rv_10$0 & 1) == 0 && ($rv_10$1 & 0) == 0) {
      var $delta_3 = $361;
      var $rv_14$1 = $rv_10$1;
      var $rv_14$0 = $rv_10$0;
      __label__ = 161;
      break;
    } else {
      __label__ = 128;
      break;
    }
   case 128:
    var $433 = _ulp($317);
    if ($393) {
      __label__ = 129;
      break;
    } else {
      __label__ = 130;
      break;
    }
   case 129:
    var $rv_11_in = $317 + $433;
    __label__ = 131;
    break;
   case 130:
    var $437 = $317 - $433;
    if ($437 != 0) {
      var $rv_11_in = $437;
      __label__ = 131;
      break;
    } else {
      var $delta_1 = $361;
      __label__ = 93;
      break;
    }
   case 131:
    var $rv_11_in;
    tempDoubleF64[0] = $rv_11_in;
    var $delta_3 = $361;
    var $rv_14$1 = tempDoubleI32[1];
    var $rv_14$0 = tempDoubleI32[0];
    __label__ = 161;
    break;
   case 132:
    var $441 = _ratio($361, $bs_3);
    if ($441 > 2) {
      __label__ = 139;
      break;
    } else {
      __label__ = 133;
      break;
    }
   case 133:
    if (($363 | 0) == 0) {
      __label__ = 134;
      break;
    } else {
      var $aadj_1 = 1;
      var $aadj1_0$1 = 1072693248;
      var $aadj1_0$0 = 0;
      __label__ = 142;
      break;
    }
   case 134:
    if (($rv_10$0 & -1) == 0 && ($rv_10$1 & 1048575) == 0) {
      __label__ = 136;
      break;
    } else {
      __label__ = 135;
      break;
    }
   case 135:
    var $$emscripten$temp$8$1 = 0;
    if (($rv_10$0 | 0) != 1 | ($rv_10$1 >>> 0 > $$emscripten$temp$8$1 >>> 0 || $rv_10$1 >>> 0 == $$emscripten$temp$8$1 >>> 0 && $rv_10$0 >>> 0 > -1 >>> 0)) {
      var $aadj_1 = 1;
      var $aadj1_0$1 = -1074790400;
      var $aadj1_0$0 = 0;
      __label__ = 142;
      break;
    } else {
      var $delta_1 = $361;
      __label__ = 93;
      break;
    }
   case 136:
    if ($441 < 1) {
      var $aadj_0 = .5;
      __label__ = 138;
      break;
    } else {
      __label__ = 137;
      break;
    }
   case 137:
    var $aadj_0 = $441 * .5;
    __label__ = 138;
    break;
   case 138:
    var $aadj_0;
    tempDoubleF64[0] = -$aadj_0;
    var $aadj_1 = $aadj_0;
    var $aadj1_0$1 = tempDoubleI32[1];
    var $aadj1_0$0 = tempDoubleI32[0];
    __label__ = 142;
    break;
   case 139:
    var $460 = $441 * .5;
    if (($363 | 0) == 0) {
      __label__ = 140;
      break;
    } else {
      var $465 = $460;
      __label__ = 141;
      break;
    }
   case 140:
    var $465 = -$460;
    __label__ = 141;
    break;
   case 141:
    var $465;
    tempDoubleF64[0] = $465;
    var $aadj_1 = $460;
    var $aadj1_0$1 = tempDoubleI32[1];
    var $aadj1_0$0 = tempDoubleI32[0];
    __label__ = 142;
    break;
   case 142:
    var $aadj1_0$0;
    var $aadj1_0$1;
    var $aadj_1;
    var $469 = $rv_10$1;
    var $470 = $469 & 2146435072;
    if (($470 | 0) == 2145386496) {
      __label__ = 143;
      break;
    } else {
      __label__ = 146;
      break;
    }
   case 143:
    var $476 = (tempDoubleI32[0] = $aadj1_0$0, tempDoubleI32[1] = $aadj1_0$1, tempDoubleF64[0]);
    var $477 = (tempDoubleI32[0] = 0 | $rv_10$0 & -1, tempDoubleI32[1] = $469 - 55574528 | $rv_10$1 & 0, tempDoubleF64[0]);
    var $478 = _ulp($477);
    var $480 = $477 + $476 * $478;
    tempDoubleF64[0] = $480;
    var $481$0 = tempDoubleI32[0];
    var $481$1 = tempDoubleI32[1];
    var $483 = $481$1;
    if (($483 & 2145386496) >>> 0 > 2090860543) {
      __label__ = 144;
      break;
    } else {
      __label__ = 145;
      break;
    }
   case 144:
    if ($rv_10$0 == -1 && $rv_10$1 == 2146435071) {
      __label__ = 68;
      break;
    } else {
      var $rv_13$1 = 2146435071;
      var $rv_13$0 = -1;
      __label__ = 160;
      break;
    }
   case 145:
    var $aadj_4 = $aadj_1;
    var $rv_12$1 = $483 + 55574528 | $481$1 & 0;
    var $rv_12$0 = 0 | $481$0 & -1;
    __label__ = 153;
    break;
   case 146:
    if ($308 & $470 >>> 0 < 111149057) {
      __label__ = 147;
      break;
    } else {
      var $aadj_3 = $aadj_1;
      var $aadj1_2$1 = $aadj1_0$1;
      var $aadj1_2$0 = $aadj1_0$0;
      __label__ = 152;
      break;
    }
   case 147:
    if ($aadj_1 > 2147483647) {
      var $aadj_2 = $aadj_1;
      var $aadj1_1$1 = $aadj1_0$1;
      var $aadj1_1$0 = $aadj1_0$0;
      __label__ = 151;
      break;
    } else {
      __label__ = 148;
      break;
    }
   case 148:
    var $497 = $aadj_1 >= 0 ? Math.floor($aadj_1) : Math.ceil($aadj_1);
    var $500 = ($497 | 0) == 0 ? 1 : $497 >>> 0;
    if (($363 | 0) == 0) {
      __label__ = 149;
      break;
    } else {
      var $505 = $500;
      __label__ = 150;
      break;
    }
   case 149:
    var $505 = -$500;
    __label__ = 150;
    break;
   case 150:
    var $505;
    tempDoubleF64[0] = $505;
    var $aadj_2 = $500;
    var $aadj1_1$1 = tempDoubleI32[1];
    var $aadj1_1$0 = tempDoubleI32[0];
    __label__ = 151;
    break;
   case 151:
    var $aadj1_1$0;
    var $aadj1_1$1;
    var $aadj_2;
    var $aadj_3 = $aadj_2;
    var $aadj1_2$1 = 112197632 - $470 + $aadj1_1$1 | $aadj1_1$1 & 0;
    var $aadj1_2$0 = 0 | $aadj1_1$0 & -1;
    __label__ = 152;
    break;
   case 152:
    var $aadj1_2$0;
    var $aadj1_2$1;
    var $aadj_3;
    var $515 = (tempDoubleI32[0] = $aadj1_2$0, tempDoubleI32[1] = $aadj1_2$1, tempDoubleF64[0]);
    var $516 = _ulp($317);
    var $518 = $317 + $515 * $516;
    tempDoubleF64[0] = $518;
    var $aadj_4 = $aadj_3;
    var $rv_12$1 = tempDoubleI32[1];
    var $rv_12$0 = tempDoubleI32[0];
    __label__ = 153;
    break;
   case 153:
    var $rv_12$0;
    var $rv_12$1;
    var $aadj_4;
    var $522 = $rv_12$1;
    if ($307) {
      __label__ = 154;
      break;
    } else {
      var $rv_13$1 = $rv_12$1;
      var $rv_13$0 = $rv_12$0;
      __label__ = 160;
      break;
    }
   case 154:
    if (($470 | 0) == ($522 & 2146435072 | 0)) {
      __label__ = 155;
      break;
    } else {
      var $rv_13$1 = $rv_12$1;
      var $rv_13$0 = $rv_12$0;
      __label__ = 160;
      break;
    }
   case 155:
    var $529 = $aadj_4 - ($aadj_4 & -1 | 0);
    if (($363 | 0) == 0) {
      __label__ = 156;
      break;
    } else {
      __label__ = 158;
      break;
    }
   case 156:
    if (($rv_12$0 | 0) == 0) {
      __label__ = 157;
      break;
    } else {
      __label__ = 158;
      break;
    }
   case 157:
    if (($522 & 1048575 | 0) == 0) {
      __label__ = 159;
      break;
    } else {
      __label__ = 158;
      break;
    }
   case 158:
    if ($529 < .4999999 | $529 > .5000001) {
      var $delta_3 = $361;
      var $rv_14$1 = $rv_12$1;
      var $rv_14$0 = $rv_12$0;
      __label__ = 161;
      break;
    } else {
      var $rv_13$1 = $rv_12$1;
      var $rv_13$0 = $rv_12$0;
      __label__ = 160;
      break;
    }
   case 159:
    if ($529 < .24999995) {
      var $delta_4 = $361;
      var $rv_15$1 = $rv_12$1;
      var $rv_15$0 = $rv_12$0;
      __label__ = 164;
      break;
    } else {
      var $rv_13$1 = $rv_12$1;
      var $rv_13$0 = $rv_12$0;
      __label__ = 160;
      break;
    }
   case 160:
    var $rv_13$0;
    var $rv_13$1;
    _Bfree($state, $bb_3);
    _Bfree($state, $bd_3);
    _Bfree($state, $bs_3);
    _Bfree($state, $361);
    var $rv_10$1 = $rv_13$1;
    var $rv_10$0 = $rv_13$0;
    __label__ = 95;
    break;
   case 161:
    var $rv_14$0;
    var $rv_14$1;
    var $delta_3;
    if ($307) {
      var $delta_4 = $delta_3;
      var $rv_15$1 = $rv_14$1;
      var $rv_15$0 = $rv_14$0;
      __label__ = 164;
      break;
    } else {
      var $rv_147$1 = $rv_14$1;
      var $rv_147$0 = $rv_14$0;
      var $delta_38 = $delta_3;
      __label__ = 162;
      break;
    }
   case 162:
    var $delta_38;
    var $rv_147$0;
    var $rv_147$1;
    var $543 = (tempDoubleI32[0] = $rv_147$0, tempDoubleI32[1] = $rv_147$1, tempDoubleF64[0]);
    var $544 = $543 * 1.232595164407831e-32;
    tempDoubleF64[0] = $544;
    var $545$0 = tempDoubleI32[0];
    var $545$1 = tempDoubleI32[1];
    var $$emscripten$temp$13$1 = 1;
    if (($545$1 >>> 0 < $$emscripten$temp$13$1 >>> 0 || $545$1 >>> 0 == $$emscripten$temp$13$1 >>> 0 && $545$0 >>> 0 < 0 >>> 0) & ($545$0 | 0) == 0) {
      __label__ = 163;
      break;
    } else {
      var $delta_4 = $delta_38;
      var $rv_15$1 = $545$1;
      var $rv_15$0 = $545$0;
      __label__ = 164;
      break;
    }
   case 163:
    var $550 = ___errno();
    HEAP32[$550 >> 2] = 34;
    var $delta_4 = $delta_38;
    var $rv_15$1 = $545$1;
    var $rv_15$0 = $545$0;
    __label__ = 164;
    break;
   case 164:
    var $rv_15$0;
    var $rv_15$1;
    var $delta_4;
    _Bfree($state, $bb_3);
    _Bfree($state, $bd_3);
    _Bfree($state, $bs_3);
    _Bfree($state, $298);
    _Bfree($state, $delta_4);
    var $sign_2 = $sign_1;
    var $s_13 = $s_12;
    var $rv_16$1 = $rv_15$1;
    var $rv_16$0 = $rv_15$0;
    __label__ = 165;
    break;
   case 165:
    var $rv_16$0;
    var $rv_16$1;
    var $s_13;
    var $sign_2;
    if (($se | 0) == 0) {
      __label__ = 167;
      break;
    } else {
      __label__ = 166;
      break;
    }
   case 166:
    HEAP32[$se >> 2] = $s_13;
    __label__ = 167;
    break;
   case 167:
    var $555 = (tempDoubleI32[0] = $rv_16$0, tempDoubleI32[1] = $rv_16$1, tempDoubleF64[0]);
    if (($sign_2 | 0) == 0) {
      var $559 = $555;
      __label__ = 169;
      break;
    } else {
      __label__ = 168;
      break;
    }
   case 168:
    var $559 = -$555;
    __label__ = 169;
    break;
   case 169:
    var $559;
    STACKTOP = __stackBase__;
    return $559;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__strtod["X"] = 1;

function _js_dtostr($state, $buffer, $bufferSize, $mode, $precision, $dinput) {
  var __stackBase__ = STACKTOP;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $buffer;
    var $decPt = STACKTOP;
    STACKTOP += 4;
    var $sign = STACKTOP;
    STACKTOP += 4;
    var $numEnd = STACKTOP;
    STACKTOP += 4;
    HEAP32[$numEnd >> 2] = 0;
    if (($mode | 0) == 2) {
      __label__ = 2;
      break;
    } else {
      var $_04 = $mode;
      __label__ = 4;
      break;
    }
   case 2:
    if ($dinput >= 1e+21 | $dinput <= -1e+21) {
      __label__ = 3;
      break;
    } else {
      var $_04 = 2;
      __label__ = 4;
      break;
    }
   case 3:
    var $_04 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_04;
    tempDoubleF64[0] = $dinput;
    var $8$0 = tempDoubleI32[0];
    var $8$1 = tempDoubleI32[1];
    var $9 = STRING_TABLE.__ZL9dtoaModes + $_04 | 0;
    var $11 = HEAPU8[$9] & 255;
    var $12 = _dtoa($state, $dinput, $11, $precision, $decPt, $sign, $numEnd);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = HEAP32[$numEnd >> 2] - $12 | 0;
    if ($18 >>> 0 > ($bufferSize - 2 | 0) >>> 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = $buffer + 2 | 0;
    _memcpy($22, $12, $18, 1);
    _freedtoa($state, $12);
    var $23 = $18 + ($buffer + 2) | 0;
    HEAP32[$numEnd >> 2] = $23;
    HEAP8[$23] = 0;
    var $24 = HEAPU32[$decPt >> 2];
    if (($24 | 0) == 9999) {
      var $numBegin_1 = $22;
      __label__ = 32;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($_04 | 0) == 0) {
      __label__ = 8;
      break;
    } else if (($_04 | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($_04 | 0) == 3) {
      __label__ = 10;
      break;
    } else if (($_04 | 0) == 1) {
      var $minNDigits_0 = 0;
      __label__ = 11;
      break;
    } else if (($_04 | 0) == 4) {
      __label__ = 12;
      break;
    } else {
      var $minNDigits_1 = 0;
      var $exponentialNotation_0 = 0;
      __label__ = 14;
      break;
    }
   case 8:
    var $28 = ($24 + 5 | 0) >>> 0 > 26;
    var $_6 = $28 ? 0 : $24;
    var $minNDigits_1 = $_6;
    var $exponentialNotation_0 = $28 & 1;
    __label__ = 14;
    break;
   case 9:
    var $31 = ($precision | 0) < 0 ? 0 : $precision;
    var $minNDigits_1 = $24 + $31 | 0;
    var $exponentialNotation_0 = 0;
    __label__ = 14;
    break;
   case 10:
    var $minNDigits_0 = $precision;
    __label__ = 11;
    break;
   case 11:
    var $minNDigits_0;
    var $minNDigits_1 = $minNDigits_0;
    var $exponentialNotation_0 = 1;
    __label__ = 14;
    break;
   case 12:
    if (($24 | 0) < -5 | ($24 | 0) > ($precision | 0)) {
      __label__ = 13;
      break;
    } else {
      var $minNDigits_1 = $precision;
      var $exponentialNotation_0 = 0;
      __label__ = 14;
      break;
    }
   case 13:
    var $minNDigits_1 = $precision;
    var $exponentialNotation_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $exponentialNotation_0;
    var $minNDigits_1;
    if (($18 | 0) < ($minNDigits_1 | 0)) {
      __label__ = 15;
      break;
    } else {
      var $nDigits_0 = $18;
      __label__ = 18;
      break;
    }
   case 15:
    var $41 = $minNDigits_1 + ($buffer + 2) | 0;
    var $43 = $23;
    __label__ = 16;
    break;
   case 16:
    var $43;
    HEAP32[$numEnd >> 2] = $43 + 1 | 0;
    HEAP8[$43] = 48;
    var $45 = HEAP32[$numEnd >> 2];
    if (($45 | 0) == ($41 | 0)) {
      __label__ = 17;
      break;
    } else {
      var $43 = $45;
      __label__ = 16;
      break;
    }
   case 17:
    HEAP8[$45] = 0;
    var $nDigits_0 = $minNDigits_1;
    __label__ = 18;
    break;
   case 18:
    var $nDigits_0;
    if (($exponentialNotation_0 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    if (($nDigits_0 | 0) == 1) {
      var $numBegin_0 = $22;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $53 = $buffer + 1 | 0;
    var $54 = HEAP8[$22];
    HEAP8[$53] = $54;
    HEAP8[$22] = 46;
    var $numBegin_0 = $53;
    __label__ = 21;
    break;
   case 21:
    var $numBegin_0;
    var $55 = HEAP32[$numEnd >> 2];
    var $58 = $1 + $bufferSize - $55 | 0;
    var $59 = $24 - 1 | 0;
    var $60 = _JS_snprintf($55, $58, STRING_TABLE.__str1096 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $59, tempInt));
    var $numBegin_1 = $numBegin_0;
    __label__ = 32;
    break;
   case 22:
    if (($24 | 0) == ($nDigits_0 | 0)) {
      var $numBegin_1 = $22;
      __label__ = 32;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    if (($24 | 0) > 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $66 = $buffer + 1 | 0;
    var $p_0 = $66;
    __label__ = 25;
    break;
   case 25:
    var $p_0;
    var $68 = $p_0 + 1 | 0;
    var $69 = HEAP8[$68];
    HEAP8[$p_0] = $69;
    var $71 = HEAP32[$decPt >> 2] - 1 | 0;
    HEAP32[$decPt >> 2] = $71;
    if (($71 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      var $p_0 = $68;
      __label__ = 25;
      break;
    }
   case 26:
    HEAP8[$68] = 46;
    var $numBegin_1 = $66;
    __label__ = 32;
    break;
   case 27:
    var $75 = HEAP32[$numEnd >> 2];
    var $77 = $75 + (1 - $24) | 0;
    HEAP32[$numEnd >> 2] = $77;
    HEAP8[$77] = 0;
    if (($75 | 0) == ($22 | 0)) {
      var $q_0_lcssa = $77;
      __label__ = 29;
      break;
    } else {
      var $p_112 = $75;
      var $q_013 = $77;
      __label__ = 28;
      break;
    }
   case 28:
    var $q_013;
    var $p_112;
    var $79 = $p_112 - 1 | 0;
    var $80 = HEAP8[$79];
    var $81 = $q_013 - 1 | 0;
    HEAP8[$81] = $80;
    if (($79 | 0) == ($22 | 0)) {
      var $q_0_lcssa = $81;
      __label__ = 29;
      break;
    } else {
      var $p_112 = $79;
      var $q_013 = $81;
      __label__ = 28;
      break;
    }
   case 29:
    var $q_0_lcssa;
    var $83 = $buffer + 3 | 0;
    if (($83 | 0) == ($q_0_lcssa | 0)) {
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $scevgep1819 = $q_0_lcssa + (-3 - $1) | 0;
    _memset($83, 48, $scevgep1819, 1);
    __label__ = 31;
    break;
   case 31:
    HEAP8[$22] = 46;
    var $87 = $buffer + 1 | 0;
    HEAP8[$87] = 48;
    var $numBegin_1 = $87;
    __label__ = 32;
    break;
   case 32:
    var $numBegin_1;
    if ((HEAP32[$sign >> 2] | 0) == 0) {
      var $_0 = $numBegin_1;
      __label__ = 38;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $93 = $8$1;
    var $96 = ($8$0 | 0) == 0;
    if (($93 | 0) == -2147483648 & $96) {
      var $_0 = $numBegin_1;
      __label__ = 38;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    if (($93 & 2146435072 | 0) == 2146435072) {
      __label__ = 35;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 35:
    if ($96) {
      __label__ = 36;
      break;
    } else {
      var $_0 = $numBegin_1;
      __label__ = 38;
      break;
    }
   case 36:
    if (($93 & 1048575 | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      var $_0 = $numBegin_1;
      __label__ = 38;
      break;
    }
   case 37:
    var $105 = $numBegin_1 - 1 | 0;
    HEAP8[$105] = 45;
    var $_0 = $105;
    __label__ = 38;
    break;
   case 38:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_dtostr["X"] = 1;

function _dtoa($state, $d_0, $mode, $ndigits, $decpt, $sign, $rve) {
  var __stackBase__ = STACKTOP;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    tempDoubleF64[0] = $d_0;
    var $1$0 = tempDoubleI32[0];
    var $1$1 = tempDoubleI32[1];
    var $bbits = STACKTOP;
    STACKTOP += 4;
    var $be = STACKTOP;
    STACKTOP += 4;
    if (($1$1 | 0) < 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$sign >> 2] = 1;
    var $d_020$1 = $1$1 & 2147483647;
    var $d_020$0 = $1$0 & -1;
    __label__ = 4;
    break;
   case 3:
    HEAP32[$sign >> 2] = 0;
    var $d_020$1 = $1$1;
    var $d_020$0 = $1$0;
    __label__ = 4;
    break;
   case 4:
    var $d_020$0;
    var $d_020$1;
    var $9 = $d_020$1;
    if (($9 & 2146435072 | 0) == 2146435072) {
      __label__ = 5;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 5:
    HEAP32[$decpt >> 2] = 9999;
    if (($d_020$0 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($9 & 1048575 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $19 = _nrv_alloc($state, STRING_TABLE.__str11097 | 0, $rve, 8);
    var $_0 = $19;
    __label__ = 164;
    break;
   case 8:
    var $21 = _nrv_alloc($state, STRING_TABLE.__str21098 | 0, $rve, 3);
    var $_0 = $21;
    __label__ = 164;
    break;
   case 9:
    var $23 = (tempDoubleI32[0] = $d_020$0, tempDoubleI32[1] = $d_020$1, tempDoubleF64[0]);
    if ($23 != 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    HEAP32[$decpt >> 2] = 1;
    var $26 = _nrv_alloc($state, STRING_TABLE.__str225518 | 0, $rve, 1);
    var $_0 = $26;
    __label__ = 164;
    break;
   case 11:
    var $28 = _d2b($state, $23, $be, $bbits);
    var $31 = ($d_020$1 >>> 20 | 0 << 12) & 2047;
    if (($31 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $i_0 = $31 - 1023 | 0;
    var $denorm_0 = 0;
    var $d2_0$1 = $d_020$1 & 1048575 | 1072693248 | $d_020$1 & 0;
    var $d2_0$0 = 0 | $d_020$0 & -1;
    __label__ = 17;
    break;
   case 13:
    var $42 = HEAP32[$be >> 2] + HEAP32[$bbits >> 2] | 0;
    if (($42 + 1074 | 0) > 32) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $57 = $d_020$0 >>> (($42 + 1042 | 0) >>> 0) | $9 << -1010 - $42;
    __label__ = 16;
    break;
   case 15:
    var $57 = $d_020$0 << -1042 - $42;
    __label__ = 16;
    break;
   case 16:
    var $57;
    tempDoubleF64[0] = $57 >>> 0;
    var $59$1 = tempDoubleI32[1];
    var $i_0 = $42 - 1 | 0;
    var $denorm_0 = 1;
    var $d2_0$1 = $59$1 - 32505856 | $59$1 & 0;
    var $d2_0$0 = 0 | tempDoubleI32[0] & -1;
    __label__ = 17;
    break;
   case 17:
    var $d2_0$0;
    var $d2_0$1;
    var $denorm_0;
    var $i_0;
    var $67 = (tempDoubleI32[0] = $d2_0$0, tempDoubleI32[1] = $d2_0$1, tempDoubleF64[0]);
    var $73 = ($67 - 1.5) * .289529654602168 + .1760912590558 + ($i_0 | 0) * .301029995663981;
    var $74 = $73 & -1;
    if ($73 < 0) {
      __label__ = 18;
      break;
    } else {
      var $k_0 = $74;
      __label__ = 20;
      break;
    }
   case 18:
    if ($73 != ($74 | 0)) {
      __label__ = 19;
      break;
    } else {
      var $k_0 = $74;
      __label__ = 20;
      break;
    }
   case 19:
    var $k_0 = $74 - 1 | 0;
    __label__ = 20;
    break;
   case 20:
    var $k_0;
    if ($k_0 >>> 0 < 23) {
      __label__ = 21;
      break;
    } else {
      var $k_2 = $k_0;
      var $k_check_0 = 1;
      __label__ = 22;
      break;
    }
   case 21:
    var $84 = _tens + ($k_0 << 3) | 0;
    var $85 = (tempDoubleI32[0] = HEAP32[$84 >> 2], tempDoubleI32[1] = HEAP32[$84 + 4 >> 2], tempDoubleF64[0]);
    var $k_2 = (($23 < $85) << 31 >> 31) + $k_0 | 0;
    var $k_check_0 = 0;
    __label__ = 22;
    break;
   case 22:
    var $k_check_0;
    var $k_2;
    var $89 = HEAP32[$bbits >> 2] - $i_0 | 0;
    var $90 = ($89 | 0) > 0;
    var $s2_0 = $90 ? $89 - 1 | 0 : 0;
    var $b2_0 = $90 ? 0 : 1 - $89 | 0;
    if (($k_2 | 0) > -1) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $b2_1 = $b2_0;
    var $b5_0 = 0;
    var $s2_1 = $s2_0 + $k_2 | 0;
    var $s5_0 = $k_2;
    __label__ = 25;
    break;
   case 24:
    var $b2_1 = $b2_0 - $k_2 | 0;
    var $b5_0 = -$k_2 | 0;
    var $s2_1 = $s2_0;
    var $s5_0 = 0;
    __label__ = 25;
    break;
   case 25:
    var $s5_0;
    var $s2_1;
    var $b5_0;
    var $b2_1;
    var $_08 = $mode >>> 0 > 9 ? 0 : $mode;
    var $102 = ($_08 | 0) > 5;
    var $__08 = $102 ? $_08 - 4 | 0 : $_08;
    if (($__08 | 0) == 0 || ($__08 | 0) == 1) {
      __label__ = 26;
      break;
    } else if (($__08 | 0) == 2) {
      __label__ = 27;
      break;
    } else if (($__08 | 0) == 4) {
      var $leftright_0 = 1;
      __label__ = 28;
      break;
    } else if (($__08 | 0) == 3) {
      __label__ = 29;
      break;
    } else if (($__08 | 0) == 5) {
      var $leftright_1 = 1;
      __label__ = 30;
      break;
    } else {
      var $_110 = $ndigits;
      var $i_1 = $i_0;
      var $ilim_0 = 0;
      var $ilim1_0 = 0;
      var $leftright_2 = 1;
      __label__ = 32;
      break;
    }
   case 26:
    var $103 = _rv_alloc($state, 18);
    var $leftright_237 = 1;
    var $ilim1_038 = -1;
    var $ilim_039 = -1;
    var $_11040 = 0;
    var $260 = $103;
    __label__ = 64;
    break;
   case 27:
    var $leftright_0 = 0;
    __label__ = 28;
    break;
   case 28:
    var $leftright_0;
    var $_09 = ($ndigits | 0) < 1 ? 1 : $ndigits;
    var $_110 = $_09;
    var $i_1 = $_09;
    var $ilim_0 = $_09;
    var $ilim1_0 = $_09;
    var $leftright_2 = $leftright_0;
    __label__ = 32;
    break;
   case 29:
    var $leftright_1 = 0;
    __label__ = 30;
    break;
   case 30:
    var $leftright_1;
    var $109 = $k_2 + $ndigits | 0;
    var $110 = $109 + 1 | 0;
    if (($109 | 0) < 0) {
      __label__ = 31;
      break;
    } else {
      var $_110 = $ndigits;
      var $i_1 = $110;
      var $ilim_0 = $110;
      var $ilim1_0 = $109;
      var $leftright_2 = $leftright_1;
      __label__ = 32;
      break;
    }
   case 31:
    var $_110 = $ndigits;
    var $i_1 = 1;
    var $ilim_0 = $110;
    var $ilim1_0 = $109;
    var $leftright_2 = $leftright_1;
    __label__ = 32;
    break;
   case 32:
    var $leftright_2;
    var $ilim1_0;
    var $ilim_0;
    var $i_1;
    var $_110;
    var $114 = _rv_alloc($state, $i_1);
    if ($ilim_0 >>> 0 > 14 | $102) {
      var $leftright_237 = $leftright_2;
      var $ilim1_038 = $ilim1_0;
      var $ilim_039 = $ilim_0;
      var $_11040 = $_110;
      var $260 = $114;
      __label__ = 64;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    if (($k_2 | 0) > 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 34:
    var $120 = _tens + (($k_2 & 15) << 3) | 0;
    var $121 = (tempDoubleI32[0] = HEAP32[$120 >> 2], tempDoubleI32[1] = HEAP32[$120 + 4 >> 2], tempDoubleF64[0]);
    var $122 = $k_2 >> 4;
    if (($122 & 16 | 0) == 0) {
      var $ieps_0_ph = 2;
      var $j_0_ph = $122;
      var $d_1$1 = $d_020$1;
      var $d_1$0 = $d_020$0;
      __label__ = 36;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $127 = $23 / 1e+256;
    tempDoubleF64[0] = $127;
    var $ieps_0_ph = 3;
    var $j_0_ph = $122 & 15;
    var $d_1$1 = tempDoubleI32[1];
    var $d_1$0 = tempDoubleI32[0];
    __label__ = 36;
    break;
   case 36:
    var $d_1$0;
    var $d_1$1;
    var $j_0_ph;
    var $ieps_0_ph;
    if (($j_0_ph | 0) == 0) {
      var $ieps_0_lcssa = $ieps_0_ph;
      var $ds_0_lcssa = $121;
      __label__ = 40;
      break;
    } else {
      var $j_058 = $j_0_ph;
      var $ieps_059 = $ieps_0_ph;
      var $i_260 = 0;
      var $ds_061 = $121;
      __label__ = 37;
      break;
    }
   case 37:
    var $ds_061;
    var $i_260;
    var $ieps_059;
    var $j_058;
    if (($j_058 & 1 | 0) == 0) {
      var $ds_1 = $ds_061;
      var $ieps_1 = $ieps_059;
      __label__ = 39;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $134 = _bigtens + ($i_260 << 3) | 0;
    var $135 = (tempDoubleI32[0] = HEAP32[$134 >> 2], tempDoubleI32[1] = HEAP32[$134 + 4 >> 2], tempDoubleF64[0]);
    var $ds_1 = $ds_061 * $135;
    var $ieps_1 = $ieps_059 + 1 | 0;
    __label__ = 39;
    break;
   case 39:
    var $ieps_1;
    var $ds_1;
    var $138 = $j_058 >> 1;
    if (($138 | 0) == 0) {
      var $ieps_0_lcssa = $ieps_1;
      var $ds_0_lcssa = $ds_1;
      __label__ = 40;
      break;
    } else {
      var $j_058 = $138;
      var $ieps_059 = $ieps_1;
      var $i_260 = $i_260 + 1 | 0;
      var $ds_061 = $ds_1;
      __label__ = 37;
      break;
    }
   case 40:
    var $ds_0_lcssa;
    var $ieps_0_lcssa;
    var $141 = (tempDoubleI32[0] = $d_1$0, tempDoubleI32[1] = $d_1$1, tempDoubleF64[0]);
    var $142 = $141 / $ds_0_lcssa;
    tempDoubleF64[0] = $142;
    var $ieps_4 = $ieps_0_lcssa;
    var $d_4$1 = tempDoubleI32[1];
    var $d_4$0 = tempDoubleI32[0];
    __label__ = 46;
    break;
   case 41:
    var $145 = -$k_2 | 0;
    if (($k_2 | 0) == 0) {
      var $ieps_4 = 2;
      var $d_4$1 = $d_020$1;
      var $d_4$0 = $d_020$0;
      __label__ = 46;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $149 = _tens + (($145 & 15) << 3) | 0;
    var $150 = (tempDoubleI32[0] = HEAP32[$149 >> 2], tempDoubleI32[1] = HEAP32[$149 + 4 >> 2], tempDoubleF64[0]);
    var $151 = $23 * $150;
    tempDoubleF64[0] = $151;
    var $152$0 = tempDoubleI32[0];
    var $152$1 = tempDoubleI32[1];
    var $153 = $145 >> 4;
    if (($153 | 0) == 0) {
      var $ieps_4 = 2;
      var $d_4$1 = $152$1;
      var $d_4$0 = $152$0;
      __label__ = 46;
      break;
    } else {
      var $j_142 = $153;
      var $ieps_243 = 2;
      var $i_344 = 0;
      var $d_2$1 = $152$1;
      var $d_2$0 = $152$0;
      __label__ = 43;
      break;
    }
   case 43:
    var $d_2$0;
    var $d_2$1;
    var $i_344;
    var $ieps_243;
    var $j_142;
    if (($j_142 & 1 | 0) == 0) {
      var $ieps_3 = $ieps_243;
      var $d_3$1 = $d_2$1;
      var $d_3$0 = $d_2$0;
      __label__ = 45;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $159 = _bigtens + ($i_344 << 3) | 0;
    var $160 = (tempDoubleI32[0] = HEAP32[$159 >> 2], tempDoubleI32[1] = HEAP32[$159 + 4 >> 2], tempDoubleF64[0]);
    var $161 = (tempDoubleI32[0] = $d_2$0, tempDoubleI32[1] = $d_2$1, tempDoubleF64[0]);
    var $162 = $161 * $160;
    tempDoubleF64[0] = $162;
    var $ieps_3 = $ieps_243 + 1 | 0;
    var $d_3$1 = tempDoubleI32[1];
    var $d_3$0 = tempDoubleI32[0];
    __label__ = 45;
    break;
   case 45:
    var $d_3$0;
    var $d_3$1;
    var $ieps_3;
    var $165 = $j_142 >> 1;
    if (($165 | 0) == 0) {
      var $ieps_4 = $ieps_3;
      var $d_4$1 = $d_3$1;
      var $d_4$0 = $d_3$0;
      __label__ = 46;
      break;
    } else {
      var $j_142 = $165;
      var $ieps_243 = $ieps_3;
      var $i_344 = $i_344 + 1 | 0;
      var $d_2$1 = $d_3$1;
      var $d_2$0 = $d_3$0;
      __label__ = 43;
      break;
    }
   case 46:
    var $d_4$0;
    var $d_4$1;
    var $ieps_4;
    if (($k_check_0 | 0) == 0) {
      var $ieps_5 = $ieps_4;
      var $ilim_1 = $ilim_0;
      var $k_3 = $k_2;
      var $d_5$1 = $d_4$1;
      var $d_5$0 = $d_4$0;
      __label__ = 50;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $170 = (tempDoubleI32[0] = $d_4$0, tempDoubleI32[1] = $d_4$1, tempDoubleF64[0]);
    if ($170 < 1 & ($ilim_0 | 0) > 0) {
      __label__ = 48;
      break;
    } else {
      var $ieps_5 = $ieps_4;
      var $ilim_1 = $ilim_0;
      var $k_3 = $k_2;
      var $d_5$1 = $d_4$1;
      var $d_5$0 = $d_4$0;
      __label__ = 50;
      break;
    }
   case 48:
    if (($ilim1_0 | 0) < 1) {
      var $leftright_237 = $leftright_2;
      var $ilim1_038 = $ilim1_0;
      var $ilim_039 = $ilim_0;
      var $_11040 = $_110;
      var $260 = $114;
      __label__ = 64;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $177 = $170 * 10;
    tempDoubleF64[0] = $177;
    var $ieps_5 = $ieps_4 + 1 | 0;
    var $ilim_1 = $ilim1_0;
    var $k_3 = $k_2 - 1 | 0;
    var $d_5$1 = tempDoubleI32[1];
    var $d_5$0 = tempDoubleI32[0];
    __label__ = 50;
    break;
   case 50:
    var $d_5$0;
    var $d_5$1;
    var $k_3;
    var $ilim_1;
    var $ieps_5;
    var $182 = (tempDoubleI32[0] = $d_5$0, tempDoubleI32[1] = $d_5$1, tempDoubleF64[0]);
    var $184 = ($ieps_5 | 0) * $182 + 7;
    tempDoubleF64[0] = $184;
    var $185$1 = tempDoubleI32[1];
    var $ins$0 = 0 | tempDoubleI32[0] & -1;
    var $ins$1 = $185$1 - 54525952 | $185$1 & 0;
    if (($ilim_1 | 0) == 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 51:
    var $193 = $182 - 5;
    var $194 = (tempDoubleI32[0] = $ins$0, tempDoubleI32[1] = $ins$1, tempDoubleF64[0]);
    if ($193 > $194) {
      var $S_3 = 0;
      var $mhi_6 = 0;
      var $k_8 = $k_3;
      var $b_5 = $28;
      var $419 = $114;
      __label__ = 116;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 52:
    if ($193 < -$194) {
      var $S_2 = 0;
      var $mhi_5 = 0;
      var $b_4 = $28;
      var $416 = $114;
      __label__ = 115;
      break;
    } else {
      var $leftright_237 = $leftright_2;
      var $ilim1_038 = $ilim1_0;
      var $ilim_039 = $ilim_0;
      var $_11040 = $_110;
      var $260 = $114;
      __label__ = 64;
      break;
    }
   case 53:
    var $202 = _tens + ($ilim_1 - 1 << 3) | 0;
    var $203 = (tempDoubleI32[0] = HEAP32[$202 >> 2], tempDoubleI32[1] = HEAP32[$202 + 4 >> 2], tempDoubleF64[0]);
    if (($leftright_2 | 0) == 0) {
      __label__ = 59;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    var $205 = .5 / $203;
    var $206 = (tempDoubleI32[0] = $ins$0, tempDoubleI32[1] = $ins$1, tempDoubleF64[0]);
    var $s_0 = $114;
    var $i_4 = 1;
    var $eps_0_in = $205 - $206;
    var $d_6$1 = $d_5$1;
    var $d_6$0 = $d_5$0;
    __label__ = 55;
    break;
   case 55:
    var $d_6$0;
    var $d_6$1;
    var $eps_0_in;
    var $i_4;
    var $s_0;
    var $209 = (tempDoubleI32[0] = $d_6$0, tempDoubleI32[1] = $d_6$1, tempDoubleF64[0]);
    var $210 = $209 >= 0 ? Math.floor($209) : Math.ceil($209);
    var $212 = $209 - ($210 | 0);
    var $215 = $s_0 + 1 | 0;
    HEAP8[$s_0] = $210 + 48 & 255;
    if ($212 < $eps_0_in) {
      var $s_14 = $215;
      var $k_10 = $k_3;
      var $b_13 = $28;
      var $556 = $114;
      __label__ = 162;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    if (1 - $212 < $eps_0_in) {
      var $s_5_ph = $215;
      var $k_5_ph = $k_3;
      var $_ph = $114;
      __label__ = 73;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    if (($i_4 | 0) < ($ilim_1 | 0)) {
      __label__ = 58;
      break;
    } else {
      var $leftright_237 = $leftright_2;
      var $ilim1_038 = $ilim1_0;
      var $ilim_039 = $ilim_0;
      var $_11040 = $_110;
      var $260 = $114;
      __label__ = 64;
      break;
    }
   case 58:
    var $224 = $212 * 10;
    tempDoubleF64[0] = $224;
    var $s_0 = $215;
    var $i_4 = $i_4 + 1 | 0;
    var $eps_0_in = $eps_0_in * 10;
    var $d_6$1 = tempDoubleI32[1];
    var $d_6$0 = tempDoubleI32[0];
    __label__ = 55;
    break;
   case 59:
    var $227 = (tempDoubleI32[0] = $ins$0, tempDoubleI32[1] = $ins$1, tempDoubleF64[0]);
    var $228 = $227 * $203;
    var $229 = $182 & -1;
    var $231 = $182 - ($229 | 0);
    tempDoubleF64[0] = $231;
    var $232$0 = tempDoubleI32[0];
    var $232$1 = tempDoubleI32[1];
    var $ilim_352 = $231 != 0 ? $ilim_1 : 1;
    var $236 = $114 + 1 | 0;
    HEAP8[$114] = $229 + 48 & 255;
    if (($ilim_352 | 0) == 1) {
      var $_lcssa51 = $236;
      var $d_7$1 = $232$1;
      var $d_7$0 = $232$0;
      __label__ = 60;
      break;
    } else {
      var $i_553 = 1;
      var $ilim_354 = $ilim_352;
      var $247 = $236;
      var $d_8$1 = $232$1;
      var $d_8$0 = $232$0;
      __label__ = 63;
      break;
    }
   case 60:
    var $d_7$0;
    var $d_7$1;
    var $_lcssa51;
    var $238 = (tempDoubleI32[0] = $d_7$0, tempDoubleI32[1] = $d_7$1, tempDoubleF64[0]);
    if ($238 > $228 + .5) {
      var $s_5_ph = $_lcssa51;
      var $k_5_ph = $k_3;
      var $_ph = $114;
      __label__ = 73;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    if ($238 < .5 - $228) {
      var $s_2 = $_lcssa51;
      __label__ = 62;
      break;
    } else {
      var $leftright_237 = $leftright_2;
      var $ilim1_038 = $ilim1_0;
      var $ilim_039 = $ilim_0;
      var $_11040 = $_110;
      var $260 = $114;
      __label__ = 64;
      break;
    }
   case 62:
    var $s_2;
    var $244 = $s_2 - 1 | 0;
    if (HEAP8[$244] << 24 >> 24 == 48) {
      var $s_2 = $244;
      __label__ = 62;
      break;
    } else {
      var $s_14 = $s_2;
      var $k_10 = $k_3;
      var $b_13 = $28;
      var $556 = $114;
      __label__ = 162;
      break;
    }
   case 63:
    var $d_8$0;
    var $d_8$1;
    var $247;
    var $ilim_354;
    var $i_553;
    var $248 = $i_553 + 1 | 0;
    var $249 = (tempDoubleI32[0] = $d_8$0, tempDoubleI32[1] = $d_8$1, tempDoubleF64[0]);
    var $250 = $249 * 10;
    var $251 = $250 & -1;
    var $253 = $250 - ($251 | 0);
    tempDoubleF64[0] = $253;
    var $254$0 = tempDoubleI32[0];
    var $254$1 = tempDoubleI32[1];
    var $ilim_3 = $253 != 0 ? $ilim_354 : $248;
    var $258 = $247 + 1 | 0;
    HEAP8[$247] = $251 + 48 & 255;
    if (($248 | 0) == ($ilim_3 | 0)) {
      var $_lcssa51 = $258;
      var $d_7$1 = $254$1;
      var $d_7$0 = $254$0;
      __label__ = 60;
      break;
    } else {
      var $i_553 = $248;
      var $ilim_354 = $ilim_3;
      var $247 = $258;
      var $d_8$1 = $254$1;
      var $d_8$0 = $254$0;
      __label__ = 63;
      break;
    }
   case 64:
    var $260;
    var $_11040;
    var $ilim_039;
    var $ilim1_038;
    var $leftright_237;
    var $261 = HEAPU32[$be >> 2];
    if (($261 | 0) > -1 & ($k_2 | 0) < 15) {
      __label__ = 65;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 65:
    var $265 = _tens + ($k_2 << 3) | 0;
    var $266 = (tempDoubleI32[0] = HEAP32[$265 >> 2], tempDoubleI32[1] = HEAP32[$265 + 4 >> 2], tempDoubleF64[0]);
    if (($_11040 | 0) < 0 & ($ilim_039 | 0) < 1) {
      __label__ = 66;
      break;
    } else {
      var $s_4 = $260;
      var $i_6 = 1;
      var $d_10$1 = $d_020$1;
      var $d_10$0 = $d_020$0;
      __label__ = 68;
      break;
    }
   case 66:
    if (($ilim_039 | 0) < 0) {
      var $S_2 = 0;
      var $mhi_5 = 0;
      var $b_4 = $28;
      var $416 = $260;
      __label__ = 115;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 67:
    var $272 = (tempDoubleI32[0] = $d_020$0, tempDoubleI32[1] = $d_020$1, tempDoubleF64[0]);
    if ($272 < $266 * 5) {
      var $S_2 = 0;
      var $mhi_5 = 0;
      var $b_4 = $28;
      var $416 = $260;
      __label__ = 115;
      break;
    } else {
      var $S_3 = 0;
      var $mhi_6 = 0;
      var $k_8 = $k_2;
      var $b_5 = $28;
      var $419 = $260;
      __label__ = 116;
      break;
    }
   case 68:
    var $d_10$0;
    var $d_10$1;
    var $i_6;
    var $s_4;
    var $275 = (tempDoubleI32[0] = $d_10$0, tempDoubleI32[1] = $d_10$1, tempDoubleF64[0]);
    var $277 = $275 / $266 & -1;
    var $280 = $275 - ($277 | 0) * $266;
    var $283 = $s_4 + 1 | 0;
    HEAP8[$s_4] = $277 + 48 & 255;
    if ($280 != 0) {
      __label__ = 69;
      break;
    } else {
      var $s_14 = $283;
      var $k_10 = $k_2;
      var $b_13 = $28;
      var $556 = $260;
      __label__ = 162;
      break;
    }
   case 69:
    if (($i_6 | 0) == ($ilim_039 | 0)) {
      __label__ = 70;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 70:
    var $288 = $280 + $280;
    if ($288 > $266) {
      var $s_5_ph = $283;
      var $k_5_ph = $k_2;
      var $_ph = $260;
      __label__ = 73;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 71:
    if ($288 == $266) {
      __label__ = 72;
      break;
    } else {
      var $s_14 = $283;
      var $k_10 = $k_2;
      var $b_13 = $28;
      var $556 = $260;
      __label__ = 162;
      break;
    }
   case 72:
    if (($277 & 1 | 0) == 0) {
      var $s_14 = $283;
      var $k_10 = $k_2;
      var $b_13 = $28;
      var $556 = $260;
      __label__ = 162;
      break;
    } else {
      var $s_5_ph = $283;
      var $k_5_ph = $k_2;
      var $_ph = $260;
      __label__ = 73;
      break;
    }
   case 73:
    var $_ph;
    var $k_5_ph;
    var $s_5_ph;
    var $s_5 = $s_5_ph;
    __label__ = 74;
    break;
   case 74:
    var $s_5;
    var $296 = $s_5 - 1 | 0;
    var $297 = HEAP8[$296];
    if ($297 << 24 >> 24 == 57) {
      __label__ = 75;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 75:
    if (($296 | 0) == ($_ph | 0)) {
      __label__ = 76;
      break;
    } else {
      var $s_5 = $296;
      __label__ = 74;
      break;
    }
   case 76:
    HEAP8[$296] = 48;
    var $k_6 = $k_5_ph + 1 | 0;
    var $303 = 49;
    __label__ = 78;
    break;
   case 77:
    var $k_6 = $k_5_ph;
    var $303 = $297 + 1 & 255;
    __label__ = 78;
    break;
   case 78:
    var $303;
    var $k_6;
    HEAP8[$296] = $303;
    var $s_14 = $s_5;
    var $k_10 = $k_6;
    var $b_13 = $28;
    var $556 = $_ph;
    __label__ = 162;
    break;
   case 79:
    var $306 = $280 * 10;
    tempDoubleF64[0] = $306;
    var $s_4 = $283;
    var $i_6 = $i_6 + 1 | 0;
    var $d_10$1 = tempDoubleI32[1];
    var $d_10$0 = tempDoubleI32[0];
    __label__ = 68;
    break;
   case 80:
    var $309 = ($leftright_237 | 0) != 0;
    if ($309) {
      __label__ = 81;
      break;
    } else {
      var $mhi_0 = 0;
      var $b2_2 = $b2_1;
      var $s2_2 = $s2_1;
      __label__ = 85;
      break;
    }
   case 81:
    if (($denorm_0 | 0) == 0) {
      __label__ = 83;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 82:
    var $318 = $261 + 1075 | 0;
    __label__ = 84;
    break;
   case 83:
    var $318 = 54 - HEAP32[$bbits >> 2] | 0;
    __label__ = 84;
    break;
   case 84:
    var $318;
    var $319 = $318 + $b2_1 | 0;
    var $320 = $318 + $s2_1 | 0;
    var $321 = _i2b($state, 1);
    var $mhi_0 = $321;
    var $b2_2 = $319;
    var $s2_2 = $320;
    __label__ = 85;
    break;
   case 85:
    var $s2_2;
    var $b2_2;
    var $mhi_0;
    if (($b2_1 | 0) > 0 & ($s2_2 | 0) > 0) {
      __label__ = 86;
      break;
    } else {
      var $b2_3 = $b2_2;
      var $m2_0 = $b2_1;
      var $s2_3 = $s2_2;
      __label__ = 87;
      break;
    }
   case 86:
    var $327 = ($b2_1 | 0) < ($s2_2 | 0) ? $b2_1 : $s2_2;
    var $b2_3 = $b2_2 - $327 | 0;
    var $m2_0 = $b2_1 - $327 | 0;
    var $s2_3 = $s2_2 - $327 | 0;
    __label__ = 87;
    break;
   case 87:
    var $s2_3;
    var $m2_0;
    var $b2_3;
    if (($b5_0 | 0) > 0) {
      __label__ = 88;
      break;
    } else {
      var $mhi_2 = $mhi_0;
      var $b_1 = $28;
      __label__ = 91;
      break;
    }
   case 88:
    if ($309) {
      __label__ = 89;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 89:
    var $335 = _pow5mult($state, $mhi_0, $b5_0);
    var $336 = _mult($state, $335, $28);
    _Bfree($state, $28);
    var $mhi_2 = $335;
    var $b_1 = $336;
    __label__ = 91;
    break;
   case 90:
    var $338 = _pow5mult($state, $28, $b5_0);
    var $mhi_2 = $mhi_0;
    var $b_1 = $338;
    __label__ = 91;
    break;
   case 91:
    var $b_1;
    var $mhi_2;
    var $340 = _i2b($state, 1);
    if (($s5_0 | 0) > 0) {
      __label__ = 92;
      break;
    } else {
      var $S_0 = $340;
      __label__ = 93;
      break;
    }
   case 92:
    var $343 = _pow5mult($state, $340, $s5_0);
    var $S_0 = $343;
    __label__ = 93;
    break;
   case 93:
    var $S_0;
    if (($__08 | 0) < 2 | $309) {
      __label__ = 94;
      break;
    } else {
      var $b2_4 = $b2_3;
      var $s2_4 = $s2_3;
      var $spec_case_0 = 0;
      __label__ = 97;
      break;
    }
   case 94:
    if (($d_020$0 | 0) == 0) {
      __label__ = 95;
      break;
    } else {
      var $b2_4 = $b2_3;
      var $s2_4 = $s2_3;
      var $spec_case_0 = 0;
      __label__ = 97;
      break;
    }
   case 95:
    var $351 = $d_020$1;
    if (($351 & 1048575 | 0) != 0 | ($351 & 2145386496 | 0) == 0) {
      var $b2_4 = $b2_3;
      var $s2_4 = $s2_3;
      var $spec_case_0 = 0;
      __label__ = 97;
      break;
    } else {
      __label__ = 96;
      break;
    }
   case 96:
    var $b2_4 = $b2_3 + 1 | 0;
    var $s2_4 = $s2_3 + 1 | 0;
    var $spec_case_0 = 1;
    __label__ = 97;
    break;
   case 97:
    var $spec_case_0;
    var $s2_4;
    var $b2_4;
    if (($s5_0 | 0) == 0) {
      var $370 = 1;
      __label__ = 99;
      break;
    } else {
      __label__ = 98;
      break;
    }
   case 98:
    var $366 = HEAP32[$S_0 + 20 + (HEAP32[$S_0 + 16 >> 2] - 1 << 2) >> 2];
    var $367 = _hi0bits($366);
    var $370 = 32 - $367 | 0;
    __label__ = 99;
    break;
   case 99:
    var $370;
    var $372 = $370 + $s2_4 & 31;
    var $_ = ($372 | 0) == 0 ? 0 : 32 - $372 | 0;
    if ($_ >>> 0 > 4) {
      __label__ = 100;
      break;
    } else {
      __label__ = 101;
      break;
    }
   case 100:
    var $377 = $_ - 4 | 0;
    var $b2_5 = $377 + $b2_4 | 0;
    var $m2_1 = $377 + $m2_0 | 0;
    var $s2_5 = $377 + $s2_4 | 0;
    __label__ = 103;
    break;
   case 101:
    if ($_ >>> 0 < 4) {
      __label__ = 102;
      break;
    } else {
      var $b2_5 = $b2_4;
      var $m2_1 = $m2_0;
      var $s2_5 = $s2_4;
      __label__ = 103;
      break;
    }
   case 102:
    var $384 = $_ + 28 | 0;
    var $b2_5 = $384 + $b2_4 | 0;
    var $m2_1 = $384 + $m2_0 | 0;
    var $s2_5 = $384 + $s2_4 | 0;
    __label__ = 103;
    break;
   case 103:
    var $s2_5;
    var $m2_1;
    var $b2_5;
    if (($b2_5 | 0) > 0) {
      __label__ = 104;
      break;
    } else {
      var $b_2 = $b_1;
      __label__ = 105;
      break;
    }
   case 104:
    var $391 = _lshift($state, $b_1, $b2_5);
    var $b_2 = $391;
    __label__ = 105;
    break;
   case 105:
    var $b_2;
    if (($s2_5 | 0) > 0) {
      __label__ = 106;
      break;
    } else {
      var $S_1 = $S_0;
      __label__ = 107;
      break;
    }
   case 106:
    var $395 = _lshift($state, $S_0, $s2_5);
    var $S_1 = $395;
    __label__ = 107;
    break;
   case 107:
    var $S_1;
    if (($k_check_0 | 0) == 0) {
      var $mhi_4 = $mhi_2;
      var $ilim_5 = $ilim_039;
      var $k_7 = $k_2;
      var $b_3 = $b_2;
      __label__ = 111;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 108:
    var $399 = _cmp($b_2, $S_1);
    if (($399 | 0) < 0) {
      __label__ = 109;
      break;
    } else {
      var $mhi_4 = $mhi_2;
      var $ilim_5 = $ilim_039;
      var $k_7 = $k_2;
      var $b_3 = $b_2;
      __label__ = 111;
      break;
    }
   case 109:
    var $402 = $k_2 - 1 | 0;
    var $403 = _multadd($state, $b_2, 10, 0);
    if ($309) {
      __label__ = 110;
      break;
    } else {
      var $mhi_4 = $mhi_2;
      var $ilim_5 = $ilim1_038;
      var $k_7 = $402;
      var $b_3 = $403;
      __label__ = 111;
      break;
    }
   case 110:
    var $405 = _multadd($state, $mhi_2, 10, 0);
    var $mhi_4 = $405;
    var $ilim_5 = $ilim1_038;
    var $k_7 = $402;
    var $b_3 = $403;
    __label__ = 111;
    break;
   case 111:
    var $b_3;
    var $k_7;
    var $ilim_5;
    var $mhi_4;
    if (($ilim_5 | 0) < 1) {
      __label__ = 112;
      break;
    } else {
      __label__ = 117;
      break;
    }
   case 112:
    if (($__08 | 0) == 5 || ($__08 | 0) == 3) {
      __label__ = 113;
      break;
    } else {
      __label__ = 117;
      break;
    }
   case 113:
    if (($ilim_5 | 0) < 0) {
      var $S_2 = $S_1;
      var $mhi_5 = $mhi_4;
      var $b_4 = $b_3;
      var $416 = $260;
      __label__ = 115;
      break;
    } else {
      __label__ = 114;
      break;
    }
   case 114:
    var $412 = _multadd($state, $S_1, 5, 0);
    var $413 = _cmp($b_3, $412);
    if (($413 | 0) < 0) {
      var $S_2 = $412;
      var $mhi_5 = $mhi_4;
      var $b_4 = $b_3;
      var $416 = $260;
      __label__ = 115;
      break;
    } else {
      var $S_3 = $412;
      var $mhi_6 = $mhi_4;
      var $k_8 = $k_7;
      var $b_5 = $b_3;
      var $419 = $260;
      __label__ = 116;
      break;
    }
   case 115:
    var $416;
    var $b_4;
    var $mhi_5;
    var $S_2;
    HEAP8[$416] = 48;
    var $s_13 = $416 + 1 | 0;
    var $S_4 = $S_2;
    var $mhi_13 = $mhi_5;
    var $mlo_6 = 0;
    var $k_9 = 0;
    var $b_12 = $b_4;
    var $549 = $416;
    __label__ = 158;
    break;
   case 116:
    var $419;
    var $b_5;
    var $k_8;
    var $mhi_6;
    var $S_3;
    HEAP8[$419] = 49;
    var $s_13 = $419 + 1 | 0;
    var $S_4 = $S_3;
    var $mhi_13 = $mhi_6;
    var $mlo_6 = 0;
    var $k_9 = $k_8 + 1 | 0;
    var $b_12 = $b_5;
    var $549 = $419;
    __label__ = 158;
    break;
   case 117:
    if ($309) {
      __label__ = 118;
      break;
    } else {
      var $s_9 = $260;
      var $i_9 = 1;
      var $b_9 = $b_3;
      __label__ = 148;
      break;
    }
   case 118:
    if (($m2_1 | 0) > 0) {
      __label__ = 119;
      break;
    } else {
      var $mhi_7 = $mhi_4;
      __label__ = 120;
      break;
    }
   case 119:
    var $426 = _lshift($state, $mhi_4, $m2_1);
    var $mhi_7 = $426;
    __label__ = 120;
    break;
   case 120:
    var $mhi_7;
    if (($spec_case_0 | 0) == 0) {
      var $mhi_9_ph = $mhi_7;
      __label__ = 122;
      break;
    } else {
      __label__ = 121;
      break;
    }
   case 121:
    var $431 = HEAP32[$mhi_7 + 4 >> 2];
    var $432 = _Balloc($state, $431);
    var $434 = $432 + 12 | 0;
    var $440 = (HEAP32[$mhi_7 + 16 >> 2] << 2) + 8 | 0;
    _memcpy($434, $mhi_7 + 12 | 0, $440, 1);
    var $441 = _lshift($state, $432, 1);
    var $mhi_9_ph = $441;
    __label__ = 122;
    break;
   case 122:
    var $mhi_9_ph;
    var $442 = ($__08 | 0) == 1;
    var $444 = ($d_020$0 & 1) == 0 && ($d_020$1 & 0) == 0;
    var $s_8 = $260;
    var $mhi_9 = $mhi_9_ph;
    var $i_8 = 1;
    var $mlo_2 = $mhi_7;
    var $b_6 = $b_3;
    __label__ = 123;
    break;
   case 123:
    var $b_6;
    var $mlo_2;
    var $i_8;
    var $mhi_9;
    var $s_8;
    var $446 = _quorem($b_6, $S_1);
    var $447 = $446 + 48 | 0;
    var $448 = _cmp($b_6, $mlo_2);
    var $449 = _diff($state, $S_1, $mhi_9);
    if ((HEAP32[$449 + 12 >> 2] | 0) == 0) {
      __label__ = 125;
      break;
    } else {
      __label__ = 124;
      break;
    }
   case 124:
    _Bfree($state, $449);
    var $464 = 1;
    __label__ = 128;
    break;
   case 125:
    var $454 = _cmp($b_6, $449);
    _Bfree($state, $449);
    if (($454 | 0) != 0 | $442 | $444 ^ 1) {
      var $464 = $454;
      __label__ = 128;
      break;
    } else {
      __label__ = 126;
      break;
    }
   case 126:
    if (($447 | 0) == 57) {
      var $b_8 = $b_6;
      __label__ = 140;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 127:
    var $_31 = ($448 | 0) > 0 ? $446 + 49 | 0 : $447;
    HEAP8[$s_8] = $_31 & 255;
    var $s_13 = $s_8 + 1 | 0;
    var $S_4 = $S_1;
    var $mhi_13 = $mhi_9;
    var $mlo_6 = $mlo_2;
    var $k_9 = $k_7;
    var $b_12 = $b_6;
    var $549 = $260;
    __label__ = 158;
    break;
   case 128:
    var $464;
    if (($448 | 0) < 0) {
      __label__ = 130;
      break;
    } else {
      __label__ = 129;
      break;
    }
   case 129:
    if (($448 | 0) != 0 | $442 | $444 ^ 1) {
      __label__ = 138;
      break;
    } else {
      __label__ = 130;
      break;
    }
   case 130:
    if ((HEAP32[$b_6 + 20 >> 2] | 0) == 0) {
      __label__ = 131;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 131:
    if ((HEAP32[$b_6 + 16 >> 2] | 0) > 1 & ($464 | 0) > 0) {
      __label__ = 133;
      break;
    } else {
      var $dig_1 = $447;
      var $b_7 = $b_6;
      __label__ = 137;
      break;
    }
   case 132:
    if (($464 | 0) > 0) {
      __label__ = 133;
      break;
    } else {
      var $dig_1 = $447;
      var $b_7 = $b_6;
      __label__ = 137;
      break;
    }
   case 133:
    var $479 = _lshift($state, $b_6, 1);
    var $480 = _cmp($479, $S_1);
    if (($480 | 0) > 0) {
      __label__ = 136;
      break;
    } else {
      __label__ = 134;
      break;
    }
   case 134:
    if (($480 | 0) == 0) {
      __label__ = 135;
      break;
    } else {
      var $dig_1 = $447;
      var $b_7 = $479;
      __label__ = 137;
      break;
    }
   case 135:
    if (($447 & 1 | 0) == 0) {
      var $dig_1 = $447;
      var $b_7 = $479;
      __label__ = 137;
      break;
    } else {
      __label__ = 136;
      break;
    }
   case 136:
    var $488 = $446 + 49 | 0;
    if (($447 | 0) == 57) {
      var $b_8 = $479;
      __label__ = 140;
      break;
    } else {
      var $dig_1 = $488;
      var $b_7 = $479;
      __label__ = 137;
      break;
    }
   case 137:
    var $b_7;
    var $dig_1;
    HEAP8[$s_8] = $dig_1 & 255;
    var $s_13 = $s_8 + 1 | 0;
    var $S_4 = $S_1;
    var $mhi_13 = $mhi_9;
    var $mlo_6 = $mlo_2;
    var $k_9 = $k_7;
    var $b_12 = $b_7;
    var $549 = $260;
    __label__ = 158;
    break;
   case 138:
    if (($464 | 0) > 0) {
      __label__ = 139;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 139:
    if (($447 | 0) == 57) {
      var $b_8 = $b_6;
      __label__ = 140;
      break;
    } else {
      __label__ = 142;
      break;
    }
   case 140:
    var $b_8;
    HEAP8[$s_8] = 57;
    var $s_11_ph = $s_8 + 1 | 0;
    var $mhi_12_ph = $mhi_9;
    var $mlo_5_ph = $mlo_2;
    var $b_11_ph = $b_8;
    __label__ = 141;
    break;
   case 141:
    var $b_11_ph;
    var $mlo_5_ph;
    var $mhi_12_ph;
    var $s_11_ph;
    var $s_11 = $s_11_ph;
    __label__ = 153;
    break;
   case 142:
    HEAP8[$s_8] = $446 + 49 & 255;
    var $s_13 = $s_8 + 1 | 0;
    var $S_4 = $S_1;
    var $mhi_13 = $mhi_9;
    var $mlo_6 = $mlo_2;
    var $k_9 = $k_7;
    var $b_12 = $b_6;
    var $549 = $260;
    __label__ = 158;
    break;
   case 143:
    var $505 = $s_8 + 1 | 0;
    HEAP8[$s_8] = $447 & 255;
    if (($i_8 | 0) == ($ilim_5 | 0)) {
      var $s_10 = $505;
      var $mhi_11 = $mhi_9;
      var $mlo_4 = $mlo_2;
      var $b_10 = $b_6;
      __label__ = 152;
      break;
    } else {
      __label__ = 144;
      break;
    }
   case 144:
    var $508 = _multadd($state, $b_6, 10, 0);
    if (($mlo_2 | 0) == ($mhi_9 | 0)) {
      __label__ = 145;
      break;
    } else {
      __label__ = 146;
      break;
    }
   case 145:
    var $511 = _multadd($state, $mhi_9, 10, 0);
    var $mhi_10 = $511;
    var $mlo_3 = $511;
    __label__ = 147;
    break;
   case 146:
    var $513 = _multadd($state, $mlo_2, 10, 0);
    var $514 = _multadd($state, $mhi_9, 10, 0);
    var $mhi_10 = $514;
    var $mlo_3 = $513;
    __label__ = 147;
    break;
   case 147:
    var $mlo_3;
    var $mhi_10;
    var $s_8 = $505;
    var $mhi_9 = $mhi_10;
    var $i_8 = $i_8 + 1 | 0;
    var $mlo_2 = $mlo_3;
    var $b_6 = $508;
    __label__ = 123;
    break;
   case 148:
    var $b_9;
    var $i_9;
    var $s_9;
    var $517 = _quorem($b_9, $S_1);
    var $520 = $s_9 + 1 | 0;
    HEAP8[$s_9] = $517 + 48 & 255;
    if ((HEAP32[$b_9 + 20 >> 2] | 0) == 0) {
      __label__ = 149;
      break;
    } else {
      __label__ = 150;
      break;
    }
   case 149:
    if ((HEAP32[$b_9 + 16 >> 2] | 0) < 2) {
      var $s_13 = $520;
      var $S_4 = $S_1;
      var $mhi_13 = $mhi_4;
      var $mlo_6 = 0;
      var $k_9 = $k_7;
      var $b_12 = $b_9;
      var $549 = $260;
      __label__ = 158;
      break;
    } else {
      __label__ = 150;
      break;
    }
   case 150:
    if (($i_9 | 0) < ($ilim_5 | 0)) {
      __label__ = 151;
      break;
    } else {
      var $s_10 = $520;
      var $mhi_11 = $mhi_4;
      var $mlo_4 = 0;
      var $b_10 = $b_9;
      __label__ = 152;
      break;
    }
   case 151:
    var $531 = _multadd($state, $b_9, 10, 0);
    var $s_9 = $520;
    var $i_9 = $i_9 + 1 | 0;
    var $b_9 = $531;
    __label__ = 148;
    break;
   case 152:
    var $b_10;
    var $mlo_4;
    var $mhi_11;
    var $s_10;
    var $533 = _lshift($state, $b_10, 1);
    var $534 = _cmp($533, $S_1);
    if (($534 | 0) > -1) {
      var $s_11_ph = $s_10;
      var $mhi_12_ph = $mhi_11;
      var $mlo_5_ph = $mlo_4;
      var $b_11_ph = $533;
      __label__ = 141;
      break;
    } else {
      var $s_12 = $s_10;
      __label__ = 157;
      break;
    }
   case 153:
    var $s_11;
    var $537 = $s_11 - 1 | 0;
    var $538 = HEAP8[$537];
    if ($538 << 24 >> 24 == 57) {
      __label__ = 154;
      break;
    } else {
      __label__ = 156;
      break;
    }
   case 154:
    if (($537 | 0) == ($260 | 0)) {
      __label__ = 155;
      break;
    } else {
      var $s_11 = $537;
      __label__ = 153;
      break;
    }
   case 155:
    HEAP8[$537] = 49;
    var $s_13 = $s_11;
    var $S_4 = $S_1;
    var $mhi_13 = $mhi_12_ph;
    var $mlo_6 = $mlo_5_ph;
    var $k_9 = $k_7 + 1 | 0;
    var $b_12 = $b_11_ph;
    var $549 = $260;
    __label__ = 158;
    break;
   case 156:
    var $545 = $538 + 1 & 255;
    HEAP8[$537] = $545;
    var $s_13 = $s_11;
    var $S_4 = $S_1;
    var $mhi_13 = $mhi_12_ph;
    var $mlo_6 = $mlo_5_ph;
    var $k_9 = $k_7;
    var $b_12 = $b_11_ph;
    var $549 = $260;
    __label__ = 158;
    break;
   case 157:
    var $s_12;
    var $546 = $s_12 - 1 | 0;
    if (HEAP8[$546] << 24 >> 24 == 48) {
      var $s_12 = $546;
      __label__ = 157;
      break;
    } else {
      var $s_13 = $s_12;
      var $S_4 = $S_1;
      var $mhi_13 = $mhi_11;
      var $mlo_6 = $mlo_4;
      var $k_9 = $k_7;
      var $b_12 = $533;
      var $549 = $260;
      __label__ = 158;
      break;
    }
   case 158:
    var $549;
    var $b_12;
    var $k_9;
    var $mlo_6;
    var $mhi_13;
    var $S_4;
    var $s_13;
    _Bfree($state, $S_4);
    if (($mhi_13 | 0) == 0) {
      var $s_14 = $s_13;
      var $k_10 = $k_9;
      var $b_13 = $b_12;
      var $556 = $549;
      __label__ = 162;
      break;
    } else {
      __label__ = 159;
      break;
    }
   case 159:
    if (($mlo_6 | 0) == 0 | ($mlo_6 | 0) == ($mhi_13 | 0)) {
      __label__ = 161;
      break;
    } else {
      __label__ = 160;
      break;
    }
   case 160:
    _Bfree($state, $mlo_6);
    __label__ = 161;
    break;
   case 161:
    _Bfree($state, $mhi_13);
    var $s_14 = $s_13;
    var $k_10 = $k_9;
    var $b_13 = $b_12;
    var $556 = $549;
    __label__ = 162;
    break;
   case 162:
    var $556;
    var $b_13;
    var $k_10;
    var $s_14;
    _Bfree($state, $b_13);
    HEAP8[$s_14] = 0;
    HEAP32[$decpt >> 2] = $k_10 + 1 | 0;
    if (($rve | 0) == 0) {
      var $_0 = $556;
      __label__ = 164;
      break;
    } else {
      __label__ = 163;
      break;
    }
   case 163:
    HEAP32[$rve >> 2] = $s_14;
    var $_0 = $556;
    __label__ = 164;
    break;
   case 164:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_dtoa["X"] = 1;

function __ZL6divremP6Bigintj($b, $divisor) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $b + 16 | 0;
    var $2 = HEAPU32[$1 >> 2];
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $b + 20 | 0;
    var $bp_0 = $b + 20 + ($2 << 2) | 0;
    var $remainder_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $remainder_0;
    var $bp_0;
    var $8 = $bp_0 - 4 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = $9 >>> 16;
    var $12 = $11 | $remainder_0 << 16;
    var $13 = Math.floor(($12 >>> 0) / ($divisor >>> 0));
    var $18 = $11 - $13 * $divisor << 16 | $9 & 65535;
    var $19 = Math.floor(($18 >>> 0) / ($divisor >>> 0));
    var $21 = $18 - $19 * $divisor | 0;
    HEAP32[$8 >> 2] = $13 << 16 | $19;
    if (($8 | 0) == ($5 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $bp_0 = $8;
      var $remainder_0 = $21;
      __label__ = 3;
      break;
    }
   case 4:
    if ((HEAP32[$b + 20 + ($2 - 1 << 2) >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $21;
      __label__ = 6;
      break;
    }
   case 5:
    var $32 = HEAP32[$1 >> 2] - 1 | 0;
    HEAP32[$1 >> 2] = $32;
    var $_0 = $21;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL7quorem2P6Biginti($b, $k) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $k >> 5;
    var $2 = $k & 31;
    var $3 = $b + 16 | 0;
    var $5 = HEAP32[$3 >> 2] - $1 | 0;
    if (($5 | 0) < 1) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $b + 20 | 0;
    var $11 = $b + 20 + ($1 << 2) | 0;
    var $12 = HEAPU32[$11 >> 2];
    var $13 = $12 >>> ($2 >>> 0);
    var $14 = $12 & (1 << $2) - 1;
    HEAP32[$11 >> 2] = $14;
    var $_pre = $1 + 1 | 0;
    if (($5 | 0) != 2 | ($2 | 0) == 0) {
      var $result_0 = $13;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $result_0 = HEAP32[$b + 20 + ($_pre << 2) >> 2] << 32 - $2 | $13;
    __label__ = 4;
    break;
   case 4:
    var $result_0;
    if (($14 | 0) == 0 & ($1 | 0) != 0) {
      var $bxe_01 = $11;
      var $n_02 = $_pre;
      __label__ = 5;
      break;
    } else {
      var $n_0_lcssa = $_pre;
      __label__ = 6;
      break;
    }
   case 5:
    var $n_02;
    var $bxe_01;
    var $26 = $n_02 - 1 | 0;
    var $27 = $bxe_01 - 4 | 0;
    if ((HEAP32[$27 >> 2] | 0) == 0 & ($27 | 0) != ($10 | 0)) {
      var $bxe_01 = $27;
      var $n_02 = $26;
      __label__ = 5;
      break;
    } else {
      var $n_0_lcssa = $26;
      __label__ = 6;
      break;
    }
   case 6:
    var $n_0_lcssa;
    HEAP32[$3 >> 2] = $n_0_lcssa;
    var $_0 = $result_0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _cmp($a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$a + 16 >> 2];
    var $4 = HEAP32[$b + 16 >> 2];
    if (($2 | 0) == ($4 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = $2 - $4 | 0;
    __label__ = 7;
    break;
   case 3:
    var $9 = $a + 20 | 0;
    var $xb_0 = $b + 20 + ($4 << 2) | 0;
    var $xa_0 = $a + 20 + ($4 << 2) | 0;
    __label__ = 4;
    break;
   case 4:
    var $xa_0;
    var $xb_0;
    var $13 = $xa_0 - 4 | 0;
    var $14 = HEAPU32[$13 >> 2];
    var $15 = $xb_0 - 4 | 0;
    var $16 = HEAPU32[$15 >> 2];
    if (($14 | 0) == ($16 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = $14 >>> 0 < $16 >>> 0 ? -1 : 1;
    var $_0 = $20;
    __label__ = 7;
    break;
   case 6:
    if ($13 >>> 0 > $9 >>> 0) {
      var $xb_0 = $15;
      var $xa_0 = $13;
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _freedtoa($state, $s) {
  var $1 = $s - 4 | 0;
  var $2 = $1;
  var $4 = HEAP32[$1 >> 2];
  HEAP32[$s >> 2] = $4;
  var $6 = 1 << $4;
  HEAP32[$s + 4 >> 2] = $6;
  _Bfree($state, $2);
  return;
}

function _js_dtobasestr($state, $base, $dinput) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e = __stackBase__;
    var $bits = __stackBase__ + 4;
    var $e1 = __stackBase__ + 8;
    var $bbits = __stackBase__ + 12;
    var $1 = __ZN2js11OffTheBooks7malloc_Ej(1078);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($dinput < 0) {
      __label__ = 3;
      break;
    } else {
      var $p_0 = $1;
      var $d_0_in = $dinput;
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = $1 + 1 | 0;
    HEAP8[$1] = 45;
    var $p_0 = $6;
    var $d_0_in = -$dinput;
    __label__ = 4;
    break;
   case 4:
    var $d_0_in;
    var $p_0;
    tempDoubleF64[0] = $d_0_in;
    var $d_0$0 = tempDoubleI32[0];
    var $d_0$1 = tempDoubleI32[1];
    var $10 = $d_0$1;
    if (($10 & 2146435072 | 0) == 2146435072) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    if (($d_0$0 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $20 = STRING_TABLE.__str21098 | 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $phitmp = ($10 & 1048575 | 0) == 0 ? STRING_TABLE.__str11097 | 0 : STRING_TABLE.__str21098 | 0;
    var $20 = $phitmp;
    __label__ = 7;
    break;
   case 7:
    var $20;
    var $21 = _strcpy($p_0, $20);
    var $_0 = $1;
    __label__ = 54;
    break;
   case 8:
    var $23 = _floor($d_0_in);
    if ($23 > 4294967295) {
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $26 = $23 >= 0 ? Math.floor($23) : Math.ceil($23);
    if (($26 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $p_1 = $p_0;
      var $n_0 = $26;
      __label__ = 10;
      break;
    }
   case 10:
    var $n_0;
    var $p_1;
    var $28 = Math.floor(($n_0 >>> 0) / ($base >>> 0));
    var $30 = $n_0 - $28 * $base | 0;
    var $_v5 = $30 >>> 0 > 9 ? 87 : 48;
    var $34 = $p_1 + 1 | 0;
    HEAP8[$p_1] = $_v5 + $30 & 255;
    if (($28 | 0) == 0) {
      var $p_3 = $34;
      __label__ = 18;
      break;
    } else {
      var $p_1 = $34;
      var $n_0 = $28;
      __label__ = 10;
      break;
    }
   case 11:
    HEAP8[$p_0] = 48;
    var $p_3 = $p_0 + 1 | 0;
    __label__ = 18;
    break;
   case 12:
    var $39 = _d2b($state, $23, $e, $bits);
    if (($39 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $42 = HEAP32[$e >> 2];
    var $43 = _lshift($state, $39, $42);
    if (($43 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $45 = $43 + 16 | 0;
    var $p_2 = $p_0;
    __label__ = 16;
    break;
   case 15:
    _Bfree($state, 0);
    __ZN2js10Foreground5free_EPv($1);
    var $_0 = 0;
    __label__ = 54;
    break;
   case 16:
    var $p_2;
    var $48 = __ZL6divremP6Bigintj($43, $base);
    var $_v = $48 >>> 0 > 9 ? 87 : 48;
    var $52 = $p_2 + 1 | 0;
    HEAP8[$p_2] = $_v + $48 & 255;
    if ((HEAP32[$45 >> 2] | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $p_2 = $52;
      __label__ = 16;
      break;
    }
   case 17:
    _Bfree($state, $43);
    var $p_3 = $52;
    __label__ = 18;
    break;
   case 18:
    var $p_3;
    var $q_013 = $p_3 - 1 | 0;
    if ($q_013 >>> 0 > $p_0 >>> 0) {
      var $pInt_014 = $p_0;
      var $q_015 = $q_013;
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $q_015;
    var $pInt_014;
    var $57 = HEAP8[$pInt_014];
    var $58 = HEAP8[$q_015];
    var $59 = $pInt_014 + 1 | 0;
    HEAP8[$pInt_014] = $58;
    HEAP8[$q_015] = $57;
    var $q_0 = $q_015 - 1 | 0;
    if ($q_0 >>> 0 > $59 >>> 0) {
      var $pInt_014 = $59;
      var $q_015 = $q_0;
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $61 = $d_0_in - $23;
    if ($61 != 0) {
      __label__ = 21;
      break;
    } else {
      var $p_5 = $p_3;
      __label__ = 53;
      break;
    }
   case 21:
    HEAP8[$p_3] = 46;
    var $64 = _d2b($state, $61, $e1, $bbits);
    if (($64 | 0) == 0) {
      var $mhi_0 = 0;
      var $mlo_0 = 0;
      var $s_0 = 0;
      var $b2_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 22:
    var $b2_0;
    var $s_0;
    var $mlo_0;
    var $mhi_0;
    _Bfree($state, $b2_0);
    _Bfree($state, $s_0);
    if (($mlo_0 | 0) == ($mhi_0 | 0)) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    _Bfree($state, $mlo_0);
    __label__ = 24;
    break;
   case 24:
    _Bfree($state, $mhi_0);
    __ZN2js10Foreground5free_EPv($1);
    var $_0 = 0;
    __label__ = 54;
    break;
   case 25:
    var $72 = ($d_0$1 >>> 20 | 0 << 12) & 2047;
    var $s2_0 = ($72 | 0) == 0 ? -1 : -$72 | 0;
    var $75 = $s2_0 + 1076 | 0;
    var $76 = _i2b($state, 1);
    if (($76 | 0) == 0) {
      var $mhi_0 = 0;
      var $mlo_0 = 0;
      var $s_0 = 0;
      var $b2_0 = $64;
      __label__ = 22;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $79 = $d_0$0;
    if (($79 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $mhi_1 = $76;
      var $s2_1 = $75;
      __label__ = 29;
      break;
    }
   case 27:
    if (($10 & 1048575 | 0) != 0 | ($10 & 2145386496 | 0) == 0) {
      var $mhi_1 = $76;
      var $s2_1 = $75;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $87 = $s2_0 + 1077 | 0;
    var $88 = _i2b($state, 2);
    if (($88 | 0) == 0) {
      var $mhi_0 = 0;
      var $mlo_0 = $76;
      var $s_0 = 0;
      var $b2_0 = $64;
      __label__ = 22;
      break;
    } else {
      var $mhi_1 = $88;
      var $s2_1 = $87;
      __label__ = 29;
      break;
    }
   case 29:
    var $s2_1;
    var $mhi_1;
    var $92 = HEAP32[$e1 >> 2] + $s2_1 | 0;
    var $93 = _lshift($state, $64, $92);
    if (($93 | 0) == 0) {
      var $mhi_0 = $mhi_1;
      var $mlo_0 = $76;
      var $s_0 = 0;
      var $b2_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $96 = _i2b($state, 1);
    if (($96 | 0) == 0) {
      var $mhi_0 = $mhi_1;
      var $mlo_0 = $76;
      var $s_0 = 0;
      var $b2_0 = $93;
      __label__ = 22;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $99 = _lshift($state, $96, $s2_1);
    if (($99 | 0) == 0) {
      var $mhi_0 = $mhi_1;
      var $mlo_0 = $76;
      var $s_0 = 0;
      var $b2_0 = $93;
      __label__ = 22;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $101 = $79 & 1;
    var $mhi_2 = $mhi_1;
    var $mlo_1 = $76;
    var $p_4_pn = $p_3;
    var $b2_1 = $93;
    __label__ = 33;
    break;
   case 33:
    var $b2_1;
    var $p_4_pn;
    var $mlo_1;
    var $mhi_2;
    var $p_4 = $p_4_pn + 1 | 0;
    var $103 = _multadd($state, $b2_1, $base, 0);
    if (($103 | 0) == 0) {
      var $mhi_0 = $mhi_2;
      var $mlo_0 = $mlo_1;
      var $s_0 = $99;
      var $b2_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $106 = __ZL7quorem2P6Biginti($103, $s2_1);
    var $107 = ($mlo_1 | 0) == ($mhi_2 | 0);
    var $108 = _multadd($state, $mlo_1, $base, 0);
    var $109 = ($108 | 0) == 0;
    if ($107) {
      __label__ = 35;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 35:
    if ($109) {
      var $mhi_0 = 0;
      var $mlo_0 = 0;
      var $s_0 = $99;
      var $b2_0 = $103;
      __label__ = 22;
      break;
    } else {
      var $mhi_3 = $108;
      __label__ = 38;
      break;
    }
   case 36:
    if ($109) {
      var $mhi_0 = $mhi_2;
      var $mlo_0 = 0;
      var $s_0 = $99;
      var $b2_0 = $103;
      __label__ = 22;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $113 = _multadd($state, $mhi_2, $base, 0);
    if (($113 | 0) == 0) {
      var $mhi_0 = 0;
      var $mlo_0 = $108;
      var $s_0 = $99;
      var $b2_0 = $103;
      __label__ = 22;
      break;
    } else {
      var $mhi_3 = $113;
      __label__ = 38;
      break;
    }
   case 38:
    var $mhi_3;
    var $116 = _cmp($103, $108);
    var $117 = _diff($state, $99, $mhi_3);
    if (($117 | 0) == 0) {
      var $mhi_0 = $mhi_3;
      var $mlo_0 = $108;
      var $s_0 = $99;
      var $b2_0 = $103;
      __label__ = 22;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    if ((HEAP32[$117 + 12 >> 2] | 0) == 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    _Bfree($state, $117);
    var $131 = 1;
    __label__ = 43;
    break;
   case 41:
    var $124 = _cmp($103, $117);
    _Bfree($state, $117);
    if (($124 | $101 | 0) == 0) {
      __label__ = 42;
      break;
    } else {
      var $131 = $124;
      __label__ = 43;
      break;
    }
   case 42:
    var $digit_2_ph = (($116 | 0) > 0 & 1) + $106 | 0;
    var $b2_3_ph = $103;
    __label__ = 50;
    break;
   case 43:
    var $131;
    if (($116 | 0) < 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    if (($116 | $101 | 0) == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 45:
    if (($131 | 0) > 0) {
      __label__ = 46;
      break;
    } else {
      var $digit_2_ph = $106;
      var $b2_3_ph = $103;
      __label__ = 50;
      break;
    }
   case 46:
    var $139 = _lshift($state, $103, 1);
    if (($139 | 0) == 0) {
      var $mhi_0 = $mhi_3;
      var $mlo_0 = $108;
      var $s_0 = $99;
      var $b2_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $142 = _cmp($139, $99);
    var $digit_2_ph = (($142 | 0) > 0 & 1) + $106 | 0;
    var $b2_3_ph = $139;
    __label__ = 50;
    break;
   case 48:
    var $146 = ($131 | 0) > 0;
    var $_8 = ($146 & 1) + $106 | 0;
    if ($146) {
      var $digit_2_ph = $_8;
      var $b2_3_ph = $103;
      __label__ = 50;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $_v4 = $_8 >>> 0 > 9 ? 87 : 48;
    HEAP8[$p_4] = $_v4 + $_8 & 255;
    var $mhi_2 = $mhi_3;
    var $mlo_1 = $108;
    var $p_4_pn = $p_4;
    var $b2_1 = $103;
    __label__ = 33;
    break;
   case 50:
    var $b2_3_ph;
    var $digit_2_ph;
    var $_v422 = $digit_2_ph >>> 0 > 9 ? 87 : 48;
    var $155 = $p_4_pn + 2 | 0;
    HEAP8[$p_4] = $_v422 + $digit_2_ph & 255;
    _Bfree($state, $b2_3_ph);
    _Bfree($state, $99);
    if (($108 | 0) == ($mhi_3 | 0)) {
      __label__ = 52;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    _Bfree($state, $108);
    __label__ = 52;
    break;
   case 52:
    _Bfree($state, $mhi_3);
    var $p_5 = $155;
    __label__ = 53;
    break;
   case 53:
    var $p_5;
    HEAP8[$p_5] = 0;
    var $_0 = $1;
    __label__ = 54;
    break;
   case 54:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_dtobasestr["X"] = 1;

function _d2b($state, $d_0, $e, $bits) {
  var __stackBase__ = STACKTOP;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    tempDoubleF64[0] = $d_0;
    var $1$0 = tempDoubleI32[0];
    var $1$1 = tempDoubleI32[1];
    var $y = STACKTOP;
    STACKTOP += 4;
    var $z = STACKTOP;
    STACKTOP += 4;
    var $2 = _Balloc($state, 1);
    var $3 = $2 + 20 | 0;
    var $6 = $1$1 & 1048575;
    var $9 = ($1$1 >>> 20 | 0 << 12) & 2047;
    var $10 = ($9 | 0) != 0;
    var $storemerge2 = $10 ? $6 | 1048576 : $6;
    HEAP32[$z >> 2] = $storemerge2;
    var $12 = $1$0;
    HEAP32[$y >> 2] = $12;
    if (($12 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $15 = _lo0bits($y);
    var $17 = HEAPU32[$y >> 2];
    if (($15 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$3 >> 2] = $storemerge2 << 32 - $15 | $17;
    var $22 = $storemerge2 >>> ($15 >>> 0);
    HEAP32[$z >> 2] = $22;
    var $25 = $22;
    __label__ = 5;
    break;
   case 4:
    HEAP32[$3 >> 2] = $17;
    var $25 = $storemerge2;
    __label__ = 5;
    break;
   case 5:
    var $25;
    HEAP32[$2 + 24 >> 2] = $25;
    var $28 = ($25 | 0) != 0 ? 2 : 1;
    HEAP32[$2 + 16 >> 2] = $28;
    var $i_0 = $28;
    var $k_0 = $15;
    __label__ = 7;
    break;
   case 6:
    var $31 = _lo0bits($z);
    var $32 = HEAP32[$z >> 2];
    HEAP32[$3 >> 2] = $32;
    HEAP32[$2 + 16 >> 2] = 1;
    var $i_0 = 1;
    var $k_0 = $31 + 32 | 0;
    __label__ = 7;
    break;
   case 7:
    var $k_0;
    var $i_0;
    if ($10) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    HEAP32[$e >> 2] = $9 - 1075 + $k_0 | 0;
    var $storemerge = 53 - $k_0 | 0;
    __label__ = 10;
    break;
   case 9:
    HEAP32[$e >> 2] = $k_0 - 1074 | 0;
    var $42 = $i_0 << 5;
    var $45 = HEAP32[$2 + 20 + ($i_0 - 1 << 2) >> 2];
    var $46 = _hi0bits($45);
    var $storemerge = $42 - $46 | 0;
    __label__ = 10;
    break;
   case 10:
    var $storemerge;
    HEAP32[$bits >> 2] = $storemerge;
    STACKTOP = __stackBase__;
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_d2b["X"] = 1;

function _lshift($state, $b, $k) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $k >> 5;
    var $3 = HEAP32[$b + 4 >> 2];
    var $4 = $b + 16 | 0;
    var $6 = HEAP32[$4 >> 2] + $1 | 0;
    var $7 = $6 + 1 | 0;
    var $9 = HEAP32[$b + 8 >> 2];
    if (($7 | 0) > ($9 | 0)) {
      var $k1_04 = $3;
      var $i_05 = $9;
      __label__ = 2;
      break;
    } else {
      var $k1_0_lcssa = $3;
      __label__ = 3;
      break;
    }
   case 2:
    var $i_05;
    var $k1_04;
    var $11 = $k1_04 + 1 | 0;
    var $12 = $i_05 << 1;
    if (($7 | 0) > ($12 | 0)) {
      var $k1_04 = $11;
      var $i_05 = $12;
      __label__ = 2;
      break;
    } else {
      var $k1_0_lcssa = $11;
      __label__ = 3;
      break;
    }
   case 3:
    var $k1_0_lcssa;
    var $14 = _Balloc($state, $k1_0_lcssa);
    var $15 = $14 + 20 | 0;
    if (($1 | 0) > 0) {
      __label__ = 4;
      break;
    } else {
      var $x1_0_lcssa = $15;
      __label__ = 5;
      break;
    }
   case 4:
    var $18 = $k >> 3 & -4;
    var $scevgep13 = $15;
    _memset($scevgep13, 0, $18, 4);
    var $x1_0_lcssa = $18 + ($14 + 20) | 0;
    __label__ = 5;
    break;
   case 5:
    var $x1_0_lcssa;
    var $22 = $b + 20 | 0;
    var $24 = $b + 20 + (HEAP32[$4 >> 2] << 2) | 0;
    var $25 = $k & 31;
    if (($25 | 0) == 0) {
      var $x1_2 = $x1_0_lcssa;
      var $x_1 = $22;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $28 = 32 - $25 | 0;
    var $z_0 = 0;
    var $x1_1 = $x1_0_lcssa;
    var $x_0 = $22;
    __label__ = 7;
    break;
   case 7:
    var $x_0;
    var $x1_1;
    var $z_0;
    var $32 = HEAP32[$x_0 >> 2] << $25 | $z_0;
    var $33 = $x1_1 + 4 | 0;
    HEAP32[$x1_1 >> 2] = $32;
    var $34 = $x_0 + 4 | 0;
    var $36 = HEAPU32[$x_0 >> 2] >>> ($28 >>> 0);
    if ($34 >>> 0 < $24 >>> 0) {
      var $z_0 = $36;
      var $x1_1 = $33;
      var $x_0 = $34;
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP32[$33 >> 2] = $36;
    var $_ = ($36 | 0) == 0 ? $7 : $6 + 2 | 0;
    var $n1_0 = $_;
    __label__ = 10;
    break;
   case 9:
    var $x_1;
    var $x1_2;
    var $41 = $x_1 + 4 | 0;
    var $42 = HEAP32[$x_1 >> 2];
    HEAP32[$x1_2 >> 2] = $42;
    if ($41 >>> 0 < $24 >>> 0) {
      var $x1_2 = $x1_2 + 4 | 0;
      var $x_1 = $41;
      __label__ = 9;
      break;
    } else {
      var $n1_0 = $7;
      __label__ = 10;
      break;
    }
   case 10:
    var $n1_0;
    HEAP32[$14 + 16 >> 2] = $n1_0 - 1 | 0;
    _Bfree($state, $b);
    return $14;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_lshift["X"] = 1;

function _Bfree($state, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($v | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$v + 4 >> 2];
    if (($4 | 0) > 7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = $v;
    __Z9dtoa_freePv($7);
    __label__ = 5;
    break;
   case 4:
    var $9 = $state + ($4 << 2) | 0;
    var $10 = HEAP32[$9 >> 2];
    HEAP32[$v >> 2] = $10;
    HEAP32[$9 >> 2] = $v;
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _i2b($state, $i) {
  var $1 = _Balloc($state, 1);
  HEAP32[$1 + 20 >> 2] = $i;
  HEAP32[$1 + 16 >> 2] = 1;
  return $1;
}

function _multadd($state, $b, $m, $a) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $b + 16 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $4$1 = ($a | 0) < 0 ? -1 : 0;
    var $5$0 = $m;
    var $5$1 = ($m | 0) < 0 ? -1 : 0;
    var $carry_0$1 = $4$1;
    var $carry_0$0 = $a;
    var $x_0 = $b + 20 | 0;
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    var $x_0;
    var $carry_0$0;
    var $carry_0$1;
    var $8$0 = HEAP32[$x_0 >> 2];
    var $9$0 = (i64Math.multiply($8$0, 0, $5$0, $5$1), i64Math.result[0]);
    var $9$1 = i64Math.result[1];
    var $10$0 = (i64Math.add($9$0, $9$1, $carry_0$0, $carry_0$1), i64Math.result[0]);
    var $10$1 = i64Math.result[1];
    var $11$0 = $10$1;
    var $11$1 = 0;
    var $12 = $10$0;
    HEAP32[$x_0 >> 2] = $12;
    var $14 = $i_0 + 1 | 0;
    if (($14 | 0) < ($2 | 0)) {
      var $carry_0$1 = $11$1;
      var $carry_0$0 = $11$0;
      var $x_0 = $x_0 + 4 | 0;
      var $i_0 = $14;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($11$0 == 0 && $11$1 == 0) {
      var $_1 = $b;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($2 | 0) < (HEAP32[$b + 8 >> 2] | 0)) {
      var $_0 = $b;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $25 = HEAP32[$b + 4 >> 2] + 1 | 0;
    var $26 = _Balloc($state, $25);
    var $28 = $26 + 12 | 0;
    var $30 = $b + 12 | 0;
    var $33 = (HEAP32[$1 >> 2] << 2) + 8 | 0;
    _memcpy($28, $30, $33, 1);
    _Bfree($state, $b);
    var $_0 = $26;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    var $36 = $2 + 1 | 0;
    var $37 = $_0 + 20 + ($2 << 2) | 0;
    HEAP32[$37 >> 2] = $11$0;
    HEAP32[$_0 + 16 >> 2] = $36;
    var $_1 = $_0;
    __label__ = 7;
    break;
   case 7:
    var $_1;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_multadd["X"] = 1;

function _diff($state, $a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _cmp($a, $b);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = _Balloc($state, 0);
    HEAP32[$4 + 16 >> 2] = 1;
    HEAP32[$4 + 20 >> 2] = 0;
    var $_0 = $4;
    __label__ = 10;
    break;
   case 3:
    var $8 = ($1 | 0) < 0;
    var $_lobit = $1 >>> 31;
    var $a_b = $8 ? $a : $b;
    var $b_a = $8 ? $b : $a;
    var $10 = HEAP32[$b_a + 4 >> 2];
    var $11 = _Balloc($state, $10);
    var $12 = $11 + 12 | 0;
    HEAP32[$12 >> 2] = $_lobit;
    var $14 = HEAPU32[$b_a + 16 >> 2];
    var $19 = $a_b + 20 + (HEAP32[$a_b + 16 >> 2] << 2) | 0;
    var $borrow_0$1 = 0;
    var $borrow_0$0 = 0;
    var $xa_0 = $b_a + 20 | 0;
    var $xc_0 = $11 + 20 | 0;
    var $xb_0 = $a_b + 20 | 0;
    __label__ = 4;
    break;
   case 4:
    var $xb_0;
    var $xc_0;
    var $xa_0;
    var $borrow_0$0;
    var $borrow_0$1;
    var $22 = $xa_0 + 4 | 0;
    var $24$0 = HEAP32[$xa_0 >> 2];
    var $25 = $xb_0 + 4 | 0;
    var $27$0 = HEAP32[$xb_0 >> 2];
    var $28$0 = (i64Math.subtract($24$0, 0, $27$0, 0), i64Math.result[0]);
    var $28$1 = i64Math.result[1];
    var $29$0 = (i64Math.subtract($28$0, $28$1, $borrow_0$0, $borrow_0$1), i64Math.result[0]);
    var $29$1 = i64Math.result[1];
    var $31$0 = $29$1 & 1;
    var $31$1 = 0 & 0;
    var $32 = $29$0;
    var $33 = $xc_0 + 4 | 0;
    HEAP32[$xc_0 >> 2] = $32;
    if ($25 >>> 0 < $19 >>> 0) {
      var $borrow_0$1 = $31$1;
      var $borrow_0$0 = $31$0;
      var $xa_0 = $22;
      var $xc_0 = $33;
      var $xb_0 = $25;
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $35 = $b_a + 20 + ($14 << 2) | 0;
    if ($22 >>> 0 < $35 >>> 0) {
      var $xc_15 = $33;
      var $xa_16 = $22;
      var $borrow_17$1 = $31$1;
      var $borrow_17$0 = $31$0;
      __label__ = 7;
      break;
    } else {
      var $xc_1_lcssa = $33;
      __label__ = 6;
      break;
    }
   case 6:
    var $xc_1_lcssa;
    var $37 = $xc_1_lcssa - 4 | 0;
    if ((HEAP32[$37 >> 2] | 0) == 0) {
      var $wa_03 = $14;
      var $49 = $37;
      __label__ = 8;
      break;
    } else {
      var $wa_0_lcssa = $14;
      __label__ = 9;
      break;
    }
   case 7:
    var $borrow_17$0;
    var $borrow_17$1;
    var $xa_16;
    var $xc_15;
    var $40 = $xa_16 + 4 | 0;
    var $42$0 = HEAP32[$xa_16 >> 2];
    var $43$0 = (i64Math.subtract($42$0, 0, $borrow_17$0, $borrow_17$1), i64Math.result[0]);
    var $43$1 = i64Math.result[1];
    var $45$0 = $43$1 & 1;
    var $46 = $43$0;
    var $47 = $xc_15 + 4 | 0;
    HEAP32[$xc_15 >> 2] = $46;
    if ($40 >>> 0 < $35 >>> 0) {
      var $xc_15 = $47;
      var $xa_16 = $40;
      var $borrow_17$1 = 0 & 0;
      var $borrow_17$0 = $45$0;
      __label__ = 7;
      break;
    } else {
      var $xc_1_lcssa = $47;
      __label__ = 6;
      break;
    }
   case 8:
    var $49;
    var $wa_03;
    var $50 = $wa_03 - 1 | 0;
    var $51 = $49 - 4 | 0;
    if ((HEAP32[$51 >> 2] | 0) == 0) {
      var $wa_03 = $50;
      var $49 = $51;
      __label__ = 8;
      break;
    } else {
      var $wa_0_lcssa = $50;
      __label__ = 9;
      break;
    }
   case 9:
    var $wa_0_lcssa;
    var $54 = $11 + 16 | 0;
    HEAP32[$54 >> 2] = $wa_0_lcssa;
    var $_0 = $11;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_diff["X"] = 1;

function _js_NewDtoaState() {
  var $1 = _newdtoa();
  return $1;
}

function _newdtoa() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z11dtoa_mallocj(2344);
    var $2 = $1;
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _memset($1, 0, 2344, 1);
    HEAP32[$1 + 2340 >> 2] = $1 + 36 | 0;
    __label__ = 3;
    break;
   case 3:
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_DestroyDtoaState($state) {
  _destroydtoa($state);
  return;
}

function _destroydtoa($state) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $state + 36 | 0;
    var $2 = $state + 2340 | 0;
    var $i_03 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_03;
    var $5 = HEAP32[$state + ($i_03 << 2) >> 2];
    if (($5 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $v_02 = $5;
      __label__ = 3;
      break;
    }
   case 3:
    var $v_02;
    var $8 = HEAPU32[$v_02 >> 2];
    var $9 = $v_02;
    if ($9 >>> 0 >= $1 >>> 0 & $9 >>> 0 < $2 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    if (($8 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $v_02 = $8;
      __label__ = 3;
      break;
    }
   case 5:
    __Z9dtoa_freePv($v_02);
    __label__ = 4;
    break;
   case 6:
    var $15 = $i_03 + 1 | 0;
    if (($15 | 0) == 8) {
      __label__ = 7;
      break;
    } else {
      var $i_03 = $15;
      __label__ = 2;
      break;
    }
   case 7:
    var $17 = $state;
    __Z9dtoa_freePv($17);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z9dtoa_freePv($p) {
  __ZN2js10Foreground5free_EPv($p);
  return;
}

function __Z11dtoa_mallocj($size) {
  var $1 = __ZN2js11OffTheBooks7malloc_Ej($size);
  return $1;
}

function _lo0bits($y) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[$y >> 2];
    if (($1 & 7 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($1 & 1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 3:
    if (($1 & 2 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$y >> 2] = $1 >>> 1;
    var $_0 = 1;
    __label__ = 15;
    break;
   case 5:
    HEAP32[$y >> 2] = $1 >>> 2;
    var $_0 = 2;
    __label__ = 15;
    break;
   case 6:
    var $17 = ($1 & 65535 | 0) == 0;
    var $_ = $17 ? $1 >>> 16 : $1;
    var $k_0 = $17 ? 16 : 0;
    if (($_ & 255 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $x_1 = $_;
      var $k_1 = $k_0;
      __label__ = 8;
      break;
    }
   case 7:
    var $x_1 = $_ >>> 8;
    var $k_1 = $k_0 | 8;
    __label__ = 8;
    break;
   case 8:
    var $k_1;
    var $x_1;
    if (($x_1 & 15 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $x_2 = $x_1;
      var $k_2 = $k_1;
      __label__ = 10;
      break;
    }
   case 9:
    var $x_2 = $x_1 >>> 4;
    var $k_2 = $k_1 + 4 | 0;
    __label__ = 10;
    break;
   case 10:
    var $k_2;
    var $x_2;
    if (($x_2 & 3 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $x_3 = $x_2;
      var $k_3 = $k_2;
      __label__ = 12;
      break;
    }
   case 11:
    var $x_3 = $x_2 >>> 2;
    var $k_3 = $k_2 + 2 | 0;
    __label__ = 12;
    break;
   case 12:
    var $k_3;
    var $x_3;
    if (($x_3 & 1 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $x_4 = $x_3;
      var $k_4 = $k_3;
      __label__ = 14;
      break;
    }
   case 13:
    var $40 = $x_3 >>> 1;
    if (($40 | 0) == 0) {
      var $_0 = 32;
      __label__ = 15;
      break;
    } else {
      var $x_4 = $40;
      var $k_4 = $k_3 + 1 | 0;
      __label__ = 14;
      break;
    }
   case 14:
    var $k_4;
    var $x_4;
    HEAP32[$y >> 2] = $x_4;
    var $_0 = $k_4;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_lo0bits["X"] = 1;

function _hi0bits($x) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $x >>> 0 > 65535;
    var $x_ = $2 ? $x : $x << 16;
    var $k_0 = $2 ? 0 : 16;
    if ($x_ >>> 0 > 16777215) {
      var $_1 = $x_;
      var $k_1 = $k_0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_1 = $x_ << 8;
    var $k_1 = $k_0 | 8;
    __label__ = 3;
    break;
   case 3:
    var $k_1;
    var $_1;
    if ($_1 >>> 0 > 268435455) {
      var $_2 = $_1;
      var $k_2 = $k_1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_2 = $_1 << 4;
    var $k_2 = $k_1 + 4 | 0;
    __label__ = 5;
    break;
   case 5:
    var $k_2;
    var $_2;
    if ($_2 >>> 0 > 1073741823) {
      var $_3 = $_2;
      var $k_3 = $k_2;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_3 = $_2 << 2;
    var $k_3 = $k_2 + 2 | 0;
    __label__ = 7;
    break;
   case 7:
    var $k_3;
    var $_3;
    if (($_3 | 0) < 0) {
      var $k_4 = $k_3;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if (($_3 & 1073741824 | 0) == 0) {
      var $_0 = 32;
      __label__ = 10;
      break;
    } else {
      var $k_4 = $k_3 + 1 | 0;
      __label__ = 9;
      break;
    }
   case 9:
    var $k_4;
    var $_0 = $k_4;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _ulp($x_0) {
  tempDoubleF64[0] = $x_0;
  var $7$1 = (tempDoubleI32[1] & 2146435072) - 54525952 | 0;
  var $8 = (tempDoubleI32[0] = 0, tempDoubleI32[1] = $7$1, tempDoubleF64[0]);
  return $8;
}

function _Balloc($state, $k) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($k | 0) < 8) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $state + ($k << 2) | 0;
    var $4 = HEAPU32[$3 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = HEAP32[$4 >> 2];
    HEAP32[$3 >> 2] = $8;
    var $rv_1 = $4;
    __label__ = 9;
    break;
   case 4:
    var $10 = 1 << $k;
    var $32 = $10;
    var $31 = ($10 << 2) + 27 | 0;
    __label__ = 7;
    break;
   case 5:
    var $14 = 1 << $k;
    var $16 = ($14 << 2) + 27 | 0;
    var $17 = $16 >>> 3;
    var $18 = $state + 2340 | 0;
    var $19 = HEAPU32[$18 >> 2];
    if ((($19 - ($state + 36) >> 3) + $17 | 0) >>> 0 < 289) {
      __label__ = 6;
      break;
    } else {
      var $32 = $14;
      var $31 = $16;
      __label__ = 7;
      break;
    }
   case 6:
    var $28 = $19;
    HEAP32[$18 >> 2] = $19 + ($17 << 3) | 0;
    var $rv_0 = $28;
    var $37 = $14;
    __label__ = 8;
    break;
   case 7:
    var $31;
    var $32;
    var $34 = __Z11dtoa_mallocj($31 & -8);
    var $rv_0 = $34;
    var $37 = $32;
    __label__ = 8;
    break;
   case 8:
    var $37;
    var $rv_0;
    HEAP32[$rv_0 + 4 >> 2] = $k;
    HEAP32[$rv_0 + 8 >> 2] = $37;
    var $rv_1 = $rv_0;
    __label__ = 9;
    break;
   case 9:
    var $rv_1;
    HEAP32[$rv_1 + 16 >> 2] = 0;
    HEAP32[$rv_1 + 12 >> 2] = 0;
    return $rv_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_Balloc["X"] = 1;

function _nrv_alloc($state, $s, $rve, $n) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _rv_alloc($state, $n);
    var $2 = HEAP8[$s];
    HEAP8[$1] = $2;
    if ($2 << 24 >> 24 == 0) {
      var $t_0_lcssa = $1;
      __label__ = 3;
      break;
    } else {
      var $_01 = $s;
      var $t_02 = $1;
      __label__ = 2;
      break;
    }
   case 2:
    var $t_02;
    var $_01;
    var $4 = $_01 + 1 | 0;
    var $5 = $t_02 + 1 | 0;
    var $6 = HEAP8[$4];
    HEAP8[$5] = $6;
    if ($6 << 24 >> 24 == 0) {
      var $t_0_lcssa = $5;
      __label__ = 3;
      break;
    } else {
      var $_01 = $4;
      var $t_02 = $5;
      __label__ = 2;
      break;
    }
   case 3:
    var $t_0_lcssa;
    if (($rve | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$rve >> 2] = $t_0_lcssa;
    __label__ = 5;
    break;
   case 5:
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _rv_alloc($state, $i) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($i >>> 0 < 20) {
      var $k_0_lcssa = 0;
      __label__ = 3;
      break;
    } else {
      var $j_01 = 4;
      var $k_02 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $k_02;
    var $j_01;
    var $2 = $k_02 + 1 | 0;
    var $3 = $j_01 << 1;
    if (($3 + 16 | 0) >>> 0 > $i >>> 0) {
      var $k_0_lcssa = $2;
      __label__ = 3;
      break;
    } else {
      var $j_01 = $3;
      var $k_02 = $2;
      __label__ = 2;
      break;
    }
   case 3:
    var $k_0_lcssa;
    var $6 = _Balloc($state, $k_0_lcssa);
    HEAP32[$6 >> 2] = $k_0_lcssa;
    return $6 + 4 | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _pow5mult($state, $b, $k) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $k & 3;
    if (($1 | 0) == 0) {
      var $_01 = $b;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[_p05 + ($1 - 1 << 2) >> 2];
    var $7 = _multadd($state, $b, $6, 0);
    var $_01 = $7;
    __label__ = 3;
    break;
   case 3:
    var $_01;
    var $9 = $k >> 2;
    if (($9 | 0) == 0) {
      var $_0 = $_01;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $state + 32 | 0;
    var $13 = HEAP32[$12 >> 2];
    if (($13 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_1 = $_01;
      var $_02 = $9;
      var $p5_0 = $13;
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = _i2b($state, 625);
    HEAP32[$12 >> 2] = $16;
    HEAP32[$16 >> 2] = 0;
    var $_1 = $_01;
    var $_02 = $9;
    var $p5_0 = $16;
    __label__ = 6;
    break;
   case 6:
    var $p5_0;
    var $_02;
    var $_1;
    if (($_02 & 1 | 0) == 0) {
      var $_2 = $_1;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $21 = _mult($state, $_1, $p5_0);
    _Bfree($state, $_1);
    var $_2 = $21;
    __label__ = 8;
    break;
   case 8:
    var $_2;
    var $23 = $_02 >> 1;
    if (($23 | 0) == 0) {
      var $_0 = $_2;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $26 = $p5_0 | 0;
    var $27 = HEAP32[$26 >> 2];
    if (($27 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_1 = $_2;
      var $_02 = $23;
      var $p5_0 = $27;
      __label__ = 6;
      break;
    }
   case 10:
    var $30 = _mult($state, $p5_0, $p5_0);
    HEAP32[$26 >> 2] = $30;
    HEAP32[$30 >> 2] = 0;
    var $_1 = $_2;
    var $_02 = $23;
    var $p5_0 = $30;
    __label__ = 6;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _mult($state, $a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = (HEAP32[$a + 16 >> 2] | 0) < (HEAP32[$b + 16 >> 2] | 0);
    var $_01 = $5 ? $a : $b;
    var $_0 = $5 ? $b : $a;
    var $9 = HEAPU32[$_0 + 16 >> 2];
    var $11 = HEAPU32[$_01 + 16 >> 2];
    var $12 = $11 + $9 | 0;
    var $k_0 = (($12 | 0) > (HEAP32[$_0 + 8 >> 2] | 0) & 1) + HEAP32[$_0 + 4 >> 2] | 0;
    var $17 = _Balloc($state, $k_0);
    var $18 = $17 + 20 | 0;
    var $19 = $17 + 20 + ($12 << 2) | 0;
    if (($12 | 0) > 0) {
      var $x_06 = $18;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $x_06;
    HEAP32[$x_06 >> 2] = 0;
    var $21 = $x_06 + 4 | 0;
    if ($21 >>> 0 < $19 >>> 0) {
      var $x_06 = $21;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $23 = $_0 + 20 | 0;
    var $24 = $_0 + 20 + ($9 << 2) | 0;
    var $25 = $_01 + 20 + ($11 << 2) | 0;
    if (($11 | 0) > 0) {
      __label__ = 4;
      break;
    } else {
      var $xc_1 = $19;
      var $wc_0 = $12;
      __label__ = 10;
      break;
    }
   case 4:
    var $xb_04 = $_01 + 20 | 0;
    var $xc0_05 = $18;
    __label__ = 5;
    break;
   case 5:
    var $xc0_05;
    var $xb_04;
    var $29 = $xb_04 + 4 | 0;
    var $30 = HEAP32[$xb_04 >> 2];
    if (($30 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $32$0 = $30;
    var $32$1 = 0;
    var $carry_0$1 = 0;
    var $carry_0$0 = 0;
    var $xc_0 = $xc0_05;
    var $x_1 = $23;
    __label__ = 7;
    break;
   case 7:
    var $x_1;
    var $xc_0;
    var $carry_0$0;
    var $carry_0$1;
    var $34 = $x_1 + 4 | 0;
    var $36$0 = HEAP32[$x_1 >> 2];
    var $37$0 = (i64Math.multiply($36$0, 0, $32$0, $32$1), i64Math.result[0]);
    var $37$1 = i64Math.result[1];
    var $39$0 = HEAP32[$xc_0 >> 2];
    var $40$0 = (i64Math.add($39$0, 0, $carry_0$0, $carry_0$1), i64Math.result[0]);
    var $40$1 = i64Math.result[1];
    var $41$0 = (i64Math.add($40$0, $40$1, $37$0, $37$1), i64Math.result[0]);
    var $41$1 = i64Math.result[1];
    var $42$0 = $41$1;
    var $43 = $41$0;
    var $44 = $xc_0 + 4 | 0;
    HEAP32[$xc_0 >> 2] = $43;
    if ($34 >>> 0 < $24 >>> 0) {
      var $carry_0$1 = 0;
      var $carry_0$0 = $42$0;
      var $xc_0 = $44;
      var $x_1 = $34;
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP32[$44 >> 2] = $42$0;
    __label__ = 9;
    break;
   case 9:
    if ($29 >>> 0 < $25 >>> 0) {
      var $xb_04 = $29;
      var $xc0_05 = $xc0_05 + 4 | 0;
      __label__ = 5;
      break;
    } else {
      var $xc_1 = $19;
      var $wc_0 = $12;
      __label__ = 10;
      break;
    }
   case 10:
    var $wc_0;
    var $xc_1;
    if (($wc_0 | 0) > 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $53 = $xc_1 - 4 | 0;
    if ((HEAP32[$53 >> 2] | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $xc_1 = $53;
    var $wc_0 = $wc_0 - 1 | 0;
    __label__ = 10;
    break;
   case 13:
    var $58 = $17 + 16 | 0;
    HEAP32[$58 >> 2] = $wc_0;
    return $17;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_mult["X"] = 1;

function _quorem($b, $S) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$S + 16 >> 2];
    var $3 = $b + 16 | 0;
    if ((HEAP32[$3 >> 2] | 0) < ($2 | 0)) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $S + 20 | 0;
    var $8 = $2 - 1 | 0;
    var $9 = $S + 20 + ($8 << 2) | 0;
    var $10 = $b + 20 | 0;
    var $11 = $b + 20 + ($8 << 2) | 0;
    var $12 = HEAPU32[$11 >> 2];
    var $14 = HEAP32[$9 >> 2] + 1 | 0;
    var $15 = Math.floor(($12 >>> 0) / ($14 >>> 0));
    if (($15 | 0) == 0) {
      var $n_1 = $8;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17$0 = $15;
    var $17$1 = 0;
    var $bx_0 = $10;
    var $sx_0 = $7;
    var $carry_0$1 = 0;
    var $carry_0$0 = 0;
    var $borrow_0$1 = 0;
    var $borrow_0$0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $borrow_0$0;
    var $borrow_0$1;
    var $carry_0$0;
    var $carry_0$1;
    var $sx_0;
    var $bx_0;
    var $19 = $sx_0 + 4 | 0;
    var $21$0 = HEAP32[$sx_0 >> 2];
    var $22$0 = (i64Math.multiply($21$0, 0, $17$0, $17$1), i64Math.result[0]);
    var $22$1 = i64Math.result[1];
    var $23$0 = (i64Math.add($22$0, $22$1, $carry_0$0, $carry_0$1), i64Math.result[0]);
    var $23$1 = i64Math.result[1];
    var $24$0 = $23$1;
    var $24$1 = 0;
    var $26$0 = HEAP32[$bx_0 >> 2];
    var $27$0 = $23$0 & -1;
    var $27$1 = $23$1 & 0;
    var $28$0 = (i64Math.subtract($26$0, 0, $27$0, $27$1), i64Math.result[0]);
    var $28$1 = i64Math.result[1];
    var $29$0 = (i64Math.subtract($28$0, $28$1, $borrow_0$0, $borrow_0$1), i64Math.result[0]);
    var $29$1 = i64Math.result[1];
    var $31$0 = $29$1 & 1;
    var $32 = $29$0;
    HEAP32[$bx_0 >> 2] = $32;
    if ($19 >>> 0 > $9 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $bx_0 = $bx_0 + 4 | 0;
      var $sx_0 = $19;
      var $carry_0$1 = $24$1;
      var $carry_0$0 = $24$0;
      var $borrow_0$1 = 0 & 0;
      var $borrow_0$0 = $31$0;
      __label__ = 4;
      break;
    }
   case 5:
    if ((HEAP32[$11 >> 2] | 0) == 0) {
      var $n_0 = $8;
      var $bxe_0 = $11;
      __label__ = 6;
      break;
    } else {
      var $n_1 = $8;
      __label__ = 10;
      break;
    }
   case 6:
    var $bxe_0;
    var $n_0;
    var $38 = $bxe_0 - 4 | 0;
    if ($38 >>> 0 > $10 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    if ((HEAP32[$38 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $n_0 = $n_0 - 1 | 0;
    var $bxe_0 = $38;
    __label__ = 6;
    break;
   case 9:
    HEAP32[$3 >> 2] = $n_0;
    var $n_1 = $n_0;
    __label__ = 10;
    break;
   case 10:
    var $n_1;
    var $46 = _cmp($b, $S);
    if (($46 | 0) > -1) {
      var $bx_1 = $10;
      var $sx_1 = $7;
      var $carry_1$1 = 0;
      var $carry_1$0 = 0;
      var $borrow_1$1 = 0;
      var $borrow_1$0 = 0;
      __label__ = 11;
      break;
    } else {
      var $_0 = $15;
      __label__ = 17;
      break;
    }
   case 11:
    var $borrow_1$0;
    var $borrow_1$1;
    var $carry_1$0;
    var $carry_1$1;
    var $sx_1;
    var $bx_1;
    var $48 = $sx_1 + 4 | 0;
    var $50$0 = HEAP32[$sx_1 >> 2];
    var $51$0 = (i64Math.add($50$0, 0, $carry_1$0, $carry_1$1), i64Math.result[0]);
    var $51$1 = i64Math.result[1];
    var $52$0 = $51$1;
    var $52$1 = 0;
    var $54$0 = HEAP32[$bx_1 >> 2];
    var $55$0 = $51$0 & -1;
    var $55$1 = $51$1 & 0;
    var $56$0 = (i64Math.subtract($54$0, 0, $55$0, $55$1), i64Math.result[0]);
    var $56$1 = i64Math.result[1];
    var $57$0 = (i64Math.subtract($56$0, $56$1, $borrow_1$0, $borrow_1$1), i64Math.result[0]);
    var $57$1 = i64Math.result[1];
    var $59$0 = $57$1 & 1;
    var $60 = $57$0;
    HEAP32[$bx_1 >> 2] = $60;
    if ($48 >>> 0 > $9 >>> 0) {
      __label__ = 12;
      break;
    } else {
      var $bx_1 = $bx_1 + 4 | 0;
      var $sx_1 = $48;
      var $carry_1$1 = $52$1;
      var $carry_1$0 = $52$0;
      var $borrow_1$1 = 0 & 0;
      var $borrow_1$0 = $59$0;
      __label__ = 11;
      break;
    }
   case 12:
    var $64 = $15 + 1 | 0;
    var $65 = $b + 20 + ($n_1 << 2) | 0;
    if ((HEAP32[$65 >> 2] | 0) == 0) {
      var $n_2 = $n_1;
      var $bxe_1 = $65;
      __label__ = 13;
      break;
    } else {
      var $_0 = $64;
      __label__ = 17;
      break;
    }
   case 13:
    var $bxe_1;
    var $n_2;
    var $68 = $bxe_1 - 4 | 0;
    if ($68 >>> 0 > $10 >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    if ((HEAP32[$68 >> 2] | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $n_2 = $n_2 - 1 | 0;
    var $bxe_1 = $68;
    __label__ = 13;
    break;
   case 16:
    HEAP32[$3 >> 2] = $n_2;
    var $_0 = $64;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_quorem["X"] = 1;

function _s2b($state, $s, $nd0, $nd, $y9) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $nd + 8 | 0;
    var $2 = ($1 | 0) / 9 & -1;
    if (($1 | 0) > 17) {
      var $k_05 = 0;
      var $y_06 = 1;
      __label__ = 2;
      break;
    } else {
      var $k_0_lcssa = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $y_06;
    var $k_05;
    var $4 = $y_06 << 1;
    var $5 = $k_05 + 1 | 0;
    if (($2 | 0) > ($4 | 0)) {
      var $k_05 = $5;
      var $y_06 = $4;
      __label__ = 2;
      break;
    } else {
      var $k_0_lcssa = $5;
      __label__ = 3;
      break;
    }
   case 3:
    var $k_0_lcssa;
    var $7 = _Balloc($state, $k_0_lcssa);
    HEAP32[$7 + 20 >> 2] = $y9;
    HEAP32[$7 + 16 >> 2] = 1;
    if (($nd0 | 0) > 9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $lftr_limit13 = $s + $nd0 | 0;
    var $_0 = $s + 9 | 0;
    var $b_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $b_0;
    var $_0;
    var $14 = $_0 + 1 | 0;
    var $17 = (HEAP8[$_0] << 24 >> 24) - 48 | 0;
    var $18 = _multadd($state, $b_0, 10, $17);
    if (($14 | 0) == ($lftr_limit13 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $14;
      var $b_0 = $18;
      __label__ = 5;
      break;
    }
   case 6:
    var $_1_ph = $nd0 + ($s + 1) | 0;
    var $i_1_ph = $nd0;
    var $b_1_ph = $18;
    __label__ = 8;
    break;
   case 7:
    var $_1_ph = $s + 10 | 0;
    var $i_1_ph = 9;
    var $b_1_ph = $7;
    __label__ = 8;
    break;
   case 8:
    var $b_1_ph;
    var $i_1_ph;
    var $_1_ph;
    if (($i_1_ph | 0) < ($nd | 0)) {
      __label__ = 9;
      break;
    } else {
      var $b_1_lcssa = $b_1_ph;
      __label__ = 11;
      break;
    }
   case 9:
    var $lftr_limit = $_1_ph + ($nd - $i_1_ph) | 0;
    var $b_11 = $b_1_ph;
    var $_13 = $_1_ph;
    __label__ = 10;
    break;
   case 10:
    var $_13;
    var $b_11;
    var $26 = $_13 + 1 | 0;
    var $29 = (HEAP8[$_13] << 24 >> 24) - 48 | 0;
    var $30 = _multadd($state, $b_11, 10, $29);
    if (($26 | 0) == ($lftr_limit | 0)) {
      var $b_1_lcssa = $30;
      __label__ = 11;
      break;
    } else {
      var $b_11 = $30;
      var $_13 = $26;
      __label__ = 10;
      break;
    }
   case 11:
    var $b_1_lcssa;
    return $b_1_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_s2b["X"] = 1;

function _ratio($a, $b) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ka = __stackBase__;
    var $kb = __stackBase__ + 4;
    var $1 = _b2d($a, $ka);
    tempDoubleF64[0] = $1;
    var $2$0 = tempDoubleI32[0];
    var $2$1 = tempDoubleI32[1];
    var $3 = _b2d($b, $kb);
    tempDoubleF64[0] = $3;
    var $4$0 = tempDoubleI32[0];
    var $4$1 = tempDoubleI32[1];
    var $14 = (HEAP32[$a + 16 >> 2] - HEAP32[$b + 16 >> 2] << 5) + (HEAP32[$ka >> 2] - HEAP32[$kb >> 2]) | 0;
    if (($14 | 0) > 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $da_0$1 = ($14 << 20) + $2$1 | $2$1 & 0;
    var $da_0$0 = 0 | $2$0 & -1;
    var $db_0$1 = $4$1;
    var $db_0$0 = $4$0;
    __label__ = 4;
    break;
   case 3:
    var $da_0$1 = $2$1;
    var $da_0$0 = $2$0;
    var $db_0$1 = $14 * -1048576 + $4$1 | $4$1 & 0;
    var $db_0$0 = 0 | $4$0 & -1;
    __label__ = 4;
    break;
   case 4:
    var $db_0$0;
    var $db_0$1;
    var $da_0$0;
    var $da_0$1;
    var $31 = (tempDoubleI32[0] = $da_0$0, tempDoubleI32[1] = $da_0$1, tempDoubleF64[0]);
    var $32 = (tempDoubleI32[0] = $db_0$0, tempDoubleI32[1] = $db_0$1, tempDoubleF64[0]);
    var $33 = $31 / $32;
    STACKTOP = __stackBase__;
    return $33;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_ratio["X"] = 1;

function _b2d($a, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $a + 20 | 0;
    var $3 = HEAPU32[$a + 16 >> 2];
    var $_sum = $3 - 1 | 0;
    var $4 = $a + 20 + ($_sum << 2) | 0;
    var $5 = HEAPU32[$4 >> 2];
    var $6 = _hi0bits($5);
    HEAP32[$e >> 2] = 32 - $6 | 0;
    if (($6 | 0) < 11) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $10 = 11 - $6 | 0;
    var $14$0 = 0;
    var $14$1 = $5 >>> ($10 >>> 0) | 1072693248;
    if (($_sum | 0) > 0) {
      __label__ = 3;
      break;
    } else {
      var $20 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $20 = HEAP32[$a + 20 + ($3 - 2 << 2) >> 2];
    __label__ = 4;
    break;
   case 4:
    var $20;
    var $d_0$1 = 0 | $14$1;
    var $d_0$0 = $20 >>> ($10 >>> 0) | $5 << $6 + 21 | $14$0;
    __label__ = 12;
    break;
   case 5:
    if (($_sum | 0) > 0) {
      __label__ = 6;
      break;
    } else {
      var $32 = 0;
      var $xa_0 = $4;
      __label__ = 7;
      break;
    }
   case 6:
    var $29 = $a + 20 + ($3 - 2 << 2) | 0;
    var $32 = HEAP32[$29 >> 2];
    var $xa_0 = $29;
    __label__ = 7;
    break;
   case 7:
    var $xa_0;
    var $32;
    var $33 = $6 - 11 | 0;
    if (($33 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $37 = 43 - $6 | 0;
    var $42$0 = 0;
    var $42$1 = $5 << $33 | $32 >>> ($37 >>> 0) | 1072693248;
    if ($xa_0 >>> 0 > $1 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $48 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    var $48 = HEAP32[$xa_0 - 4 >> 2];
    __label__ = 10;
    break;
   case 10:
    var $48;
    var $d_0$1 = 0 | $42$1;
    var $d_0$0 = $48 >>> ($37 >>> 0) | $32 << $33 | $42$0;
    __label__ = 12;
    break;
   case 11:
    var $d_0$1 = 0 | ($5 | 1072693248);
    var $d_0$0 = $32 | 0;
    __label__ = 12;
    break;
   case 12:
    var $d_0$0;
    var $d_0$1;
    var $59 = (tempDoubleI32[0] = $d_0$0, tempDoubleI32[1] = $d_0$1, tempDoubleF64[0]);
    return $59;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_b2d["X"] = 1;

function __ZN13JSTreeContext5traceEP8JSTracer($this, $trc) {
  var $2 = $trc;
  var $_idx_val = HEAP32[$this + 92 >> 2];
  __ZN2js8Bindings5traceEP8JSTracer($_idx_val, $2);
  return;
}

function __ZN15JSCodeGeneratorC2EPN2js6ParserEj($this, $parser, $lineno) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __stackBase__ + 8;
  var $4 = __stackBase__ + 12;
  var $5 = __stackBase__ + 16;
  var $6 = $this | 0;
  __ZN13JSTreeContextC2EPN2js6ParserE($6, $parser);
  var $7 = $this + 176 | 0;
  var $8 = $parser + 12 | 0;
  var $9 = HEAP32[$8 >> 2];
  __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEEC1EP9JSContext($7, $9);
  var $11 = $this + 240 | 0;
  var $12 = $this + 192 | 0;
  for (var $$dest = $12 >> 2, $$stop = $$dest + 12; $$dest < $$stop; $$dest++) {
    HEAP32[$$dest] = 0;
  }
  var $13 = HEAP32[$8 >> 2];
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $13);
  var $_02_val = HEAP32[$1 >> 2];
  __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES7_($11, $_02_val);
  var $14 = $this + 268 | 0;
  var $15 = HEAP32[$8 >> 2];
  __ZN13JSGCConstListC1EP9JSContext($14, $15);
  var $16 = $this + 292 | 0;
  __ZN14JSCGObjectListC1Ev($16);
  var $17 = $this + 300 | 0;
  __ZN14JSCGObjectListC1Ev($17);
  var $18 = $this + 308 | 0;
  var $19 = HEAP32[$8 >> 2];
  __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEEC1EP9JSContext($18, $19);
  var $20 = $this + 316 | 0;
  var $21 = HEAP32[$8 >> 2];
  __ZN2js15TempAllocPolicyC1EP9JSContext($2, $21);
  var $_03_val = HEAP32[$2 >> 2];
  __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEEC1ES2_($20, $_03_val);
  var $22 = $this + 364 | 0;
  var $23 = HEAP32[$8 >> 2];
  __ZN2js15TempAllocPolicyC1EP9JSContext($3, $23);
  var $_04_val = HEAP32[$3 >> 2];
  __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEEC1ES3_($22, $_04_val);
  var $24 = $this + 508 | 0;
  var $25 = HEAP32[$8 >> 2];
  __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEEC1EP9JSContext($24, $25);
  var $26 = $this + 516 | 0;
  var $27 = HEAP32[$8 >> 2];
  __ZN2js15TempAllocPolicyC1EP9JSContext($4, $27);
  var $_01_val = HEAP32[$4 >> 2];
  __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEC1ES1_($26, $_01_val);
  var $28 = $this + 564 | 0;
  var $29 = HEAP32[$8 >> 2];
  __ZN2js15TempAllocPolicyC1EP9JSContext($5, $29);
  var $_0_val = HEAP32[$5 >> 2];
  __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEC1ES1_($28, $_0_val);
  HEAP16[$this + 612 >> 1] = 0;
  HEAP16[$this + 614 >> 1] = 0;
  HEAP32[$this >> 2] = 1;
  var $34 = $this + 140 | 0;
  var $35 = $this + 172 | 0;
  var $36 = $this + 108 | 0;
  _memset($36, 0, 64, 1);
  HEAP32[$35 >> 2] = $34;
  HEAP32[$this + 168 >> 2] = $lineno;
  HEAP32[$this + 136 >> 2] = $lineno;
  HEAP32[$this + 188 >> 2] = $lineno;
  STACKTOP = __stackBase__;
  return;
}

__ZN15JSCodeGeneratorC2EPN2js6ParserEj["X"] = 1;

function __ZN13JSTreeContextC2EPN2js6ParserE($this, $prs) {
  var $1 = $this + 40 | 0;
  var $2 = $prs + 12 | 0;
  var $3 = $this;
  for (var $$dest = $3 >> 2, $$stop = $$dest + 10; $$dest < $$stop; $$dest++) {
    HEAP32[$$dest] = 0;
  }
  var $4 = HEAP32[$2 >> 2];
  __ZN2js9AtomDeclsC1EP9JSContext($1, $4);
  HEAP32[$this + 48 >> 2] = $prs;
  HEAP32[$this + 52 >> 2] = 0;
  HEAP32[$this + 56 >> 2] = 0;
  HEAP32[$this + 60 >> 2] = 0;
  var $9 = $this + 64 | 0;
  var $10 = HEAP32[$2 >> 2];
  __ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEEC1EP9JSContext($9, $10);
  var $12 = $prs + 980 | 0;
  var $13 = HEAP32[$12 >> 2];
  HEAP32[$this + 72 >> 2] = $13;
  HEAP32[$this + 76 >> 2] = 0;
  HEAP32[$this + 80 >> 2] = 0;
  HEAP32[$this + 84 >> 2] = 0;
  HEAP32[$this + 88 >> 2] = 0;
  var $18 = $this + 92 | 0;
  __ZN2js8BindingsC1EP9JSContext($18);
  HEAP32[$this + 104 >> 2] = -1;
  HEAP32[$12 >> 2] = $this;
  return;
}

function __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEEC1EP9JSContext($this, $cx) {
  __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEEC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES7_($this, $a_01) {
  __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES7_($this, $a_01);
  return;
}

function __ZN13JSGCConstListC1EP9JSContext($this, $cx) {
  __ZN13JSGCConstListC2EP9JSContext($this, $cx);
  return;
}

function __ZN14JSCGObjectListC1Ev($this) {
  __ZN14JSCGObjectListC2Ev($this);
  return;
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEEC1ES2_($this, $ap_01) {
  __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEEC2ES2_($this, $ap_01);
  return;
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEEC1ES3_($this, $ap_01) {
  __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEEC2ES3_($this, $ap_01);
  return;
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEC1ES1_($this, $ap_01) {
  __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEC2ES1_($this, $ap_01);
  return;
}

function __ZN15JSCodeGenerator4initEP9JSContextN13JSTreeContext12InitBehaviorE($this, $cx, $ib) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 184 | 0;
    __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE4initEv($1);
    var $2 = $this | 0;
    var $3 = __ZN13JSTreeContext4initEP9JSContextNS_12InitBehaviorE($2, $cx, $ib);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this + 240 | 0;
    var $6 = __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($5);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $11 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = $this + 176 | 0;
    var $9 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE9ensureMapEP9JSContext($8, $cx);
    var $11 = $9;
    __label__ = 4;
    break;
   case 4:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE4initEv($this) {
  __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE8clearMapEv($this);
  return;
}

function __ZN13JSTreeContext4initEP9JSContextNS_12InitBehaviorE($this, $cx, $ib) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($ib | 0) == 1) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $this + 40 | 0;
    var $4 = __ZN2js9AtomDecls4initEv($3);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = $this + 64 | 0;
    var $7 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE9ensureMapEP9JSContext($6, $cx);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E4initEj($1);
  return $2;
}

function __ZNK2js8Bindings9countVarsEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZNK13JSTreeContext10inFunctionEv($this_0_0_val) {
  return ($this_0_0_val & 2 | 0) != 0;
}

function __ZL10GetSpanDepP15JSCodeGeneratorPh($cg, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $8 = (HEAPU8[$pc + 1 | 0] & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255;
    if (($8 | 0) == 65535) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[$cg + 208 >> 2] + ($8 << 4) | 0;
    __label__ = 11;
    break;
   case 3:
    var $21 = $pc - HEAP32[HEAP32[$cg + 172 >> 2] >> 2] | 0;
    var $25 = $cg + 208 | 0;
    var $hi_0_ph = HEAP32[$cg + 220 >> 2] - 1 | 0;
    var $lo_0_ph = 0;
    __label__ = 4;
    break;
   case 4:
    var $lo_0_ph;
    var $hi_0_ph;
    var $hi_0 = $hi_0_ph;
    __label__ = 5;
    break;
   case 5:
    var $hi_0;
    if (($lo_0_ph | 0) > ($hi_0 | 0)) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $30 = ($hi_0 + $lo_0_ph | 0) / 2 & -1;
    var $31 = HEAP32[$25 >> 2];
    var $33 = HEAP32[$31 + ($30 << 4) + 8 >> 2];
    if (($33 | 0) == ($21 | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $_0 = $31 + ($30 << 4) | 0;
    __label__ = 11;
    break;
   case 8:
    if (($33 | 0) < ($21 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $hi_0_ph = $hi_0;
    var $lo_0_ph = $30 + 1 | 0;
    __label__ = 4;
    break;
   case 10:
    var $hi_0 = $30 - 1 | 0;
    __label__ = 5;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSTreeContext11inStatementE10JSStmtType($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmt_0_in = $this + 24 | 0;
    __label__ = 2;
    break;
   case 2:
    var $stmt_0_in;
    var $stmt_0 = HEAP32[$stmt_0_in >> 2];
    if (($stmt_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (HEAP16[$stmt_0 >> 1] << 16 >> 16 == 6) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $stmt_0_in = $stmt_0 + 24 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSTreeContext7blockidEv($this) {
  var $2 = HEAP32[$this + 24 >> 2];
  var $_in = ($2 | 0) == 0 ? $this + 4 | 0 : $2 + 4 | 0;
  return HEAP32[$_in >> 2];
}

function __ZN13JSTreeContext10blockChainEv($this_0_8_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_8_val | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$this_0_8_val + 8 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_PopStatement($tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $tc + 24 | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $4 = HEAP32[$2 + 24 >> 2];
    HEAP32[$1 >> 2] = $4;
    var $_pre = $2 + 2 | 0;
    if (((HEAPU16[$2 >> 1] & 65535) - 6 | 0) >>> 0 < 2) {
      var $_pre_phi = $_pre;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP16[$_pre >> 1] & 1) << 16 >> 16 == 0) {
      __label__ = 5;
      break;
    } else {
      var $_pre_phi = $_pre;
      __label__ = 3;
      break;
    }
   case 3:
    var $_pre_phi;
    var $15 = HEAP32[$2 + 28 >> 2];
    HEAP32[$tc + 28 >> 2] = $15;
    if ((HEAP16[$_pre_phi >> 1] & 1) << 16 >> 16 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $25 = HEAP32[HEAP32[$2 + 20 >> 2] + 12 >> 2];
    HEAP32[$tc + 32 >> 2] = $25;
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE9ensureMapEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $cx_idx_val = HEAP32[$cx + 100 >> 2];
    var $5 = __ZN9JSContext12parseMapPoolEv($cx_idx_val);
    var $6 = __ZN2js12ParseMapPool7acquireINS_9InlineMapIP6JSAtomjLj24EEEEEPT_v($5);
    HEAP32[$1 >> 2] = $6;
    var $_0 = ($6 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN15JSCodeGeneratorD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $3 = HEAP32[$this + 108 >> 2];
    __ZN9JSContext5free_EPv($3);
    var $5 = HEAP32[$this + 120 >> 2];
    __ZN9JSContext5free_EPv($5);
    var $7 = HEAP32[$this + 140 >> 2];
    __ZN9JSContext5free_EPv($7);
    var $9 = HEAP32[$this + 152 >> 2];
    __ZN9JSContext5free_EPv($9);
    var $11 = HEAP32[$this + 208 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = $11;
    __ZN9JSContext5free_EPv($14);
    __label__ = 3;
    break;
   case 3:
    var $16 = $this + 564 | 0;
    __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEED1Ev($16);
    var $17 = $this + 516 | 0;
    __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEED1Ev($17);
    var $18 = $this + 508 | 0;
    __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEED1Ev($18);
    var $19 = $this + 364 | 0;
    __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEED1Ev($19);
    var $20 = $this + 316 | 0;
    __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEED1Ev($20);
    var $21 = $this + 308 | 0;
    __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEED1Ev($21);
    var $22 = $this + 268 | 0;
    __ZN13JSGCConstListD1Ev($22);
    var $23 = $this + 240 | 0;
    __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev($23);
    var $24 = $this + 176 | 0;
    __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEED1Ev($24);
    __ZN13JSTreeContextD2Ev($1);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEED1Ev($this) {
  __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEED2Ev($this);
  return;
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN13JSGCConstListD1Ev($this) {
  __ZN13JSGCConstListD2Ev($this);
  return;
}

function __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN13JSTreeContextD2Ev($this) {
  var $2 = HEAP32[$this + 72 >> 2];
  var $5 = HEAP32[$this + 48 >> 2] + 980 | 0;
  HEAP32[$5 >> 2] = $2;
  var $6 = $this + 64 | 0;
  __ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEED1Ev($6);
  var $7 = $this + 40 | 0;
  __ZN2js9AtomDeclsD1Ev($7);
  return;
}

function _js_Emit1($cx, $cg, $op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL9EmitCheckP9JSContextP15JSCodeGeneratori($cx, $cg, 1);
    if (($1 | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $op & 255;
    var $7 = HEAP32[$cg + 172 >> 2] + 8 | 0;
    var $8 = HEAP32[$7 >> 2];
    var $9 = $8 + 1 | 0;
    HEAP32[$7 >> 2] = $9;
    HEAP8[$8] = $4;
    __ZL11UpdateDepthP9JSContextP15JSCodeGeneratori($cx, $cg, $1);
    __label__ = 3;
    break;
   case 3:
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9EmitCheckP9JSContextP15JSCodeGeneratori($cx, $cg, $delta) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg + 172 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $4 = HEAPU32[$2 >> 2];
    var $6 = HEAP32[$2 + 8 >> 2];
    var $8 = HEAPU32[$2 + 4 >> 2];
    var $10 = $4;
    var $11 = $6 - $10 | 0;
    var $12 = $11 + $delta | 0;
    if (($6 + $delta | 0) >>> 0 > $8 >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $11;
      __label__ = 12;
      break;
    }
   case 2:
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    if ($12 >>> 0 > 1024) {
      __label__ = 4;
      break;
    } else {
      var $newlength_0 = 1024;
      __label__ = 5;
      break;
    }
   case 4:
    var $20 = __ZN2js11RoundUpPow2Ej($12);
    var $newlength_0 = $20;
    __label__ = 5;
    break;
   case 5:
    var $newlength_0;
    var $22 = __ZN9JSContext7malloc_Ej($cx, $newlength_0);
    var $newlength_2 = $newlength_0;
    var $newbase_0 = $22;
    __label__ = 9;
    break;
   case 6:
    var $26 = $8 - $10 << 1;
    if ($26 >>> 0 < $12 >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $newlength_1 = $26;
      __label__ = 8;
      break;
    }
   case 7:
    var $29 = __ZN2js11RoundUpPow2Ej($12);
    var $newlength_1 = $29;
    __label__ = 8;
    break;
   case 8:
    var $newlength_1;
    var $31 = __ZN9JSContext8realloc_EPvj($cx, $4, $newlength_1);
    var $newlength_2 = $newlength_1;
    var $newbase_0 = $31;
    __label__ = 9;
    break;
   case 9:
    var $newbase_0;
    var $newlength_2;
    if (($newbase_0 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = -1;
    __label__ = 12;
    break;
   case 11:
    var $37 = HEAP32[$1 >> 2] | 0;
    HEAP32[$37 >> 2] = $newbase_0;
    var $40 = HEAP32[$1 >> 2] + 4 | 0;
    HEAP32[$40 >> 2] = $newbase_0 + $newlength_2 | 0;
    var $41 = $newbase_0 + $11 | 0;
    var $43 = HEAP32[$1 >> 2] + 8 | 0;
    HEAP32[$43 >> 2] = $41;
    var $_0 = $11;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9EmitCheckP9JSContextP15JSCodeGeneratori["X"] = 1;

function __ZL11UpdateDepthP9JSContextP15JSCodeGeneratori($cx, $cg, $target) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $numBuf = __stackBase__;
    var $1 = __stackBase__ + 12;
    var $6 = HEAP32[HEAP32[$cg + 172 >> 2] >> 2] + $target | 0;
    var $8 = HEAPU8[$6] & 255;
    var $10 = HEAPU32[_js_CodeSpec + ($8 << 3) + 4 >> 2];
    var $_pre = HEAPU32[$cg + 192 >> 2];
    if (($10 & 12582912 | 0) == 0) {
      var $21 = $_pre;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $16 = $_pre + ($10 >>> 22 & 3) | 0;
    var $17 = $cg + 196 | 0;
    if ($16 >>> 0 > HEAPU32[$17 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $21 = $_pre;
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[$17 >> 2] = $16;
    var $21 = $_pre;
    __label__ = 4;
    break;
   case 4:
    var $21;
    var $_idx1_val = HEAP8[_js_CodeSpec + ($8 << 3) + 1 | 0];
    var $22 = _js_GetStackUses($_idx1_val, $8, $6);
    var $23 = $cg + 192 | 0;
    var $24 = $21 - $22 | 0;
    HEAP32[$23 >> 2] = $24;
    if (($24 | 0) < 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $27 = $numBuf | 0;
    var $28 = _JS_snprintf($27, 12, STRING_TABLE.__str4498 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $target, tempInt));
    var $_idx2_val = HEAP32[HEAP32[$cg + 48 >> 2] + 212 >> 2];
    var $31 = __ZNK2js11TokenStream11getFilenameEv($_idx2_val);
    var $33 = ($31 | 0) == 0 ? STRING_TABLE.__str401148 | 0 : $31;
    var $34 = _JS_ReportErrorFlagsAndNumber($cx, 1, 16, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $33, HEAP32[tempInt + 4 >> 2] = $27, tempInt));
    __label__ = 6;
    break;
   case 6:
    var $37 = HEAP8[_js_CodeSpec + ($8 << 3) + 2 | 0];
    if ($37 << 24 >> 24 < 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $ndefs_0 = $37 << 24 >> 24;
    __label__ = 9;
    break;
   case 8:
    var $44 = HEAP32[HEAP32[$cg + 296 >> 2] + 8 >> 2];
    var $45 = HEAP32[$23 >> 2];
    __ZN2JSL10Int32ValueEi1190($1, $45);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject12setFixedSlotEjRKN2JS5ValueE($44, 0, $_idx_val$0, $_idx_val$1);
    var $46 = $44;
    var $47 = __ZNK8JSObject13propertyCountEv($46);
    var $ndefs_0 = $47;
    __label__ = 9;
    break;
   case 9:
    var $ndefs_0;
    var $50 = HEAP32[$23 >> 2] + $ndefs_0 | 0;
    HEAP32[$23 >> 2] = $50;
    var $51 = $cg + 196 | 0;
    if ($50 >>> 0 > HEAPU32[$51 >> 2] >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    HEAP32[$51 >> 2] = $50;
    __label__ = 11;
    break;
   case 11:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11UpdateDepthP9JSContextP15JSCodeGeneratori["X"] = 1;

function _js_Emit2($cx, $cg, $op, $op1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL9EmitCheckP9JSContextP15JSCodeGeneratori($cx, $cg, 2);
    if (($1 | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $cg + 172 | 0;
    var $7 = HEAP32[HEAP32[$4 >> 2] + 8 >> 2];
    HEAP8[$7] = $op & 255;
    HEAP8[$7 + 1 | 0] = $op1;
    var $10 = $7 + 2 | 0;
    var $12 = HEAP32[$4 >> 2] + 8 | 0;
    HEAP32[$12 >> 2] = $10;
    __ZL11UpdateDepthP9JSContextP15JSCodeGeneratori($cx, $cg, $1);
    __label__ = 3;
    break;
   case 3:
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_Emit3($cx, $cg, $op, $op1, $op2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL9EmitCheckP9JSContextP15JSCodeGeneratori($cx, $cg, 3);
    if (($1 | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $cg + 172 | 0;
    var $7 = HEAP32[HEAP32[$4 >> 2] + 8 >> 2];
    HEAP8[$7] = $op & 255;
    HEAP8[$7 + 1 | 0] = $op1;
    HEAP8[$7 + 2 | 0] = $op2;
    var $11 = $7 + 3 | 0;
    var $13 = HEAP32[$4 >> 2] + 8 | 0;
    HEAP32[$13 >> 2] = $11;
    __ZL11UpdateDepthP9JSContextP15JSCodeGeneratori($cx, $cg, $1);
    __label__ = 3;
    break;
   case 3:
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_Emit5($cx, $cg, $op, $op1, $op2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL9EmitCheckP9JSContextP15JSCodeGeneratori($cx, $cg, 5);
    if (($1 | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $cg + 172 | 0;
    var $7 = HEAPU32[HEAP32[$4 >> 2] + 8 >> 2];
    HEAP8[$7] = $op & 255;
    HEAP8[$7 + 1 | 0] = ($op1 & 65535) >>> 8 & 255;
    HEAP8[$7 + 2 | 0] = $op1 & 255;
    HEAP8[$7 + 3 | 0] = ($op2 & 65535) >>> 8 & 255;
    HEAP8[$7 + 4 | 0] = $op2 & 255;
    var $19 = $7 + 5 | 0;
    var $21 = HEAP32[$4 >> 2] + 8 | 0;
    HEAP32[$21 >> 2] = $19;
    __ZL11UpdateDepthP9JSContextP15JSCodeGeneratori($cx, $cg, $1);
    __label__ = 3;
    break;
   case 3:
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_EmitN($cx, $cg, $op, $extra) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $extra + 1 | 0;
    var $2 = __ZL9EmitCheckP9JSContextP15JSCodeGeneratori($cx, $cg, $1);
    if (($2 | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $cg + 172 | 0;
    var $8 = HEAP32[HEAP32[$5 >> 2] + 8 >> 2];
    HEAP8[$8] = $op & 255;
    var $10 = $8 + 1 | 0;
    _memset($10, 0, $extra, 1);
    var $11 = $8 + $1 | 0;
    var $13 = HEAP32[$5 >> 2] + 8 | 0;
    HEAP32[$13 >> 2] = $11;
    if (HEAP8[_js_CodeSpec + ($op << 3) + 1 | 0] << 24 >> 24 > -1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZL11UpdateDepthP9JSContextP15JSCodeGeneratori($cx, $cg, $2);
    __label__ = 4;
    break;
   case 4:
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_SetJumpOffset($cx, $cg, $pc, $off) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$cg + 208 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    if (($off + 32768 | 0) >>> 0 < 65536) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP8[$pc + 1 | 0] = $off >>> 8 & 255;
    HEAP8[$pc + 2 | 0] = $off & 255;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 4:
    var $13 = __ZL17BuildSpanDepTableP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = __ZL10GetSpanDepP15JSCodeGeneratorPh($cg, $pc);
    var $17 = __ZL16SetSpanDepTargetP9JSContextP15JSCodeGeneratorP9JSSpanDepi($cx, $cg, $16, $off);
    var $_0 = $17;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17BuildSpanDepTableP9JSContextP15JSCodeGenerator($cx, $cg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cg + 172 >> 2];
    var $9 = HEAP32[$2 + 8 >> 2];
    var $pc_0 = HEAP32[$2 >> 2] + HEAP32[$cg + 228 >> 2] | 0;
    __label__ = 2;
    break;
   case 2:
    var $pc_0;
    if (($pc_0 | 0) == ($9 | 0)) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = HEAPU8[$pc_0] & 255;
    var $16 = HEAP32[_js_CodeSpec + ($13 << 3) + 4 >> 2] & 31;
    if (($16 | 0) == 4 || ($16 | 0) == 5) {
      __label__ = 4;
      break;
    } else if (($16 | 0) == 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $18 = __ZL17AddSwitchSpanDepsP9JSContextP15JSCodeGeneratorPh($cx, $cg, $pc_0);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      var $pc_0 = $18;
      __label__ = 2;
      break;
    }
   case 5:
    var $29 = ((HEAPU8[$pc_0 + 1 | 0] & 255) << 8 | HEAPU8[$pc_0 + 2 | 0] & 255) << 16 >> 16;
    var $30 = __ZL10AddSpanDepP9JSContextP15JSCodeGeneratorPhS3_i($cx, $cg, $pc_0, $pc_0, $29);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $pc_0 = $pc_0 + (HEAP8[_js_CodeSpec + ($13 << 3) | 0] << 24 >> 24) | 0;
    __label__ = 2;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16SetSpanDepTargetP9JSContextP15JSCodeGeneratorP9JSSpanDepi($cx, $cg, $sd, $off) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    HEAP32[$args >> 2] = $cx;
    HEAP32[$args + 4 >> 2] = $cg;
    var $5 = HEAP32[$sd >> 2] + $off | 0;
    HEAP32[$args + 8 >> 2] = $5;
    var $7 = $args + 12 | 0;
    HEAP32[$7 >> 2] = 0;
    var $8 = $cg + 212 | 0;
    var $9 = __ZL13AddJumpTargetP17AddJumpTargetArgsPP12JSJumpTarget($args, $8);
    var $10 = HEAP32[$7 >> 2];
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $15 = $10 | 1;
    HEAP32[$sd + 12 >> 2] = $15;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSTreeContext16ensureSharpSlotsEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 104 | 0;
    if ((HEAP32[$1 >> 2] | 0) > -1) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx = $this | 0;
    var $this_idx_val = HEAPU32[$this_idx >> 2];
    var $5 = __ZNK13JSTreeContext10inFunctionEv($this_idx_val);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    var $10 = HEAPU32[HEAP32[$this + 48 >> 2] + 12 >> 2];
    var $11 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($10, STRING_TABLE.__str3667 | 0, 6, 0);
    var $12 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($10, STRING_TABLE.__str11107 | 0, 6, 0);
    if (($11 | 0) == 0 | ($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = $this + 92 | 0;
    var $_idx_val = HEAP16[$this + 98 >> 1];
    var $17 = __ZNK2js8Bindings9countVarsEv($_idx_val);
    HEAP32[$1 >> 2] = $17 & 65535;
    var $19 = __ZN2js8Bindings11addVariableEP9JSContextP6JSAtom($16, $10, $11);
    if ($19) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $21 = __ZN2js8Bindings11addVariableEP9JSContextP6JSAtom($16, $10, $12);
    if ($21) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $24 = HEAP32[$this_idx >> 2];
    __label__ = 8;
    break;
   case 7:
    HEAP32[$1 >> 2] = 0;
    var $24 = $this_idx_val;
    __label__ = 8;
    break;
   case 8:
    var $24;
    HEAP32[$this_idx >> 2] = $24 | 32768;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Bindings11addVariableEP9JSContextP6JSAtom($this, $cx, $name) {
  var $1 = $this;
  var $2 = $cx;
  var $3 = __ZN2js8Bindings3addEP9JSContextP6JSAtomNS_11BindingKindE($1, $2, $name, 2);
  return $3;
}

function _js_PushStatement($tc, $stmt, $type, $top) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $stmt | 0;
    HEAP16[$2 >> 1] = $type & 65535;
    var $3 = $stmt + 2 | 0;
    HEAP16[$3 >> 1] = 0;
    var $4 = __ZN13JSTreeContext7blockidEv($tc);
    HEAP32[$stmt + 4 >> 2] = $4;
    HEAP32[$stmt + 8 >> 2] = $top;
    HEAP32[$stmt + 16 >> 2] = -1;
    HEAP32[$stmt + 12 >> 2] = -1;
    HEAP32[$stmt + 20 >> 2] = 0;
    var $10 = $tc + 24 | 0;
    var $11 = HEAP32[$10 >> 2];
    HEAP32[$stmt + 24 >> 2] = $11;
    HEAP32[$10 >> 2] = $stmt;
    if (((HEAPU16[$2 >> 1] & 65535) - 6 | 0) >>> 0 < 2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP16[$3 >> 1] & 1) << 16 >> 16 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $22 = $tc + 28 | 0;
    var $23 = HEAP32[$22 >> 2];
    HEAP32[$stmt + 28 >> 2] = $23;
    HEAP32[$22 >> 2] = $stmt;
    __label__ = 5;
    break;
   case 4:
    HEAP32[$stmt + 28 >> 2] = 0;
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_PushBlockScope($tc, $stmt, $blockBox, $top) {
  _js_PushStatement($tc, $stmt, 4, $top);
  var $1 = $stmt + 2 | 0;
  var $3 = HEAP16[$1 >> 1] | 1;
  HEAP16[$1 >> 1] = $3;
  var $4 = $tc + 32 | 0;
  var $5 = HEAP32[$4 >> 2];
  HEAP32[$blockBox + 12 >> 2] = $5;
  var $8 = HEAP32[$blockBox + 8 >> 2];
  var $tc_idx_val = HEAP32[$4 >> 2];
  var $9 = __ZN13JSTreeContext10blockChainEv($tc_idx_val);
  __ZN8JSObject9setParentEPS_($8, $9);
  var $10 = $tc + 28 | 0;
  var $11 = HEAP32[$10 >> 2];
  HEAP32[$stmt + 28 >> 2] = $11;
  HEAP32[$10 >> 2] = $stmt;
  HEAP32[$4 >> 2] = $blockBox;
  HEAP32[$stmt + 20 >> 2] = $blockBox;
  return;
}

function _js_PopStatementCG($cx, $cg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg | 0;
    var $3 = HEAPU32[$cg + 24 >> 2];
    if (((HEAPU16[$3 >> 1] & 65535) - 8 | 0) >>> 0 < 3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = HEAP32[$3 + 12 >> 2];
    var $12 = $cg + 172 | 0;
    var $15 = HEAP32[HEAP32[$12 >> 2] + 8 >> 2];
    var $16 = __ZL9BackPatchP9JSContextP15JSCodeGeneratoriPhh($cx, $cg, $11, $15, 6);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $20 = HEAP32[$3 + 16 >> 2];
    var $26 = HEAP32[HEAP32[$12 >> 2] >> 2] + HEAP32[$3 + 8 >> 2] | 0;
    var $27 = __ZL9BackPatchP9JSContextP15JSCodeGeneratoriPhh($cx, $cg, $20, $26, 6);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _js_PopStatement($1);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9BackPatchP9JSContextP15JSCodeGeneratoriPhh($cx, $cg, $last, $target, $op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAP32[HEAP32[$cg + 172 >> 2] >> 2];
    var $6 = $4 - 1 | 0;
    var $7 = $target;
    var $pc_0 = $4 + $last | 0;
    __label__ = 2;
    break;
   case 2:
    var $pc_0;
    if (($pc_0 | 0) == ($6 | 0)) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZL13GetJumpOffsetP15JSCodeGeneratorPh($cg, $pc_0);
    var $13 = $7 - $pc_0 | 0;
    var $14 = _js_SetJumpOffset($cx, $cg, $pc_0, $13);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP8[$pc_0] = $op;
    var $pc_0 = $pc_0 + -$11 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_DefineCompileTimeConstant($cg, $atom, $pn) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $atom;
    var $3 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 30);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $cg + 240 | 0;
    var $7 = $pn + 32 | 0;
    var $8 = (tempDoubleI32[0] = HEAP32[$7 >> 2], tempDoubleI32[1] = HEAP32[$7 + 4 >> 2], tempDoubleF64[0]);
    __ZN2JSL11NumberValueEd1149($2, $8);
    var $9 = __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3putERKS2_RKS4_($5, $1, $2);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK11JSParseNode6isKindEN2js9TokenKindE($this, $kind) {
  var $1 = __ZNK11JSParseNode7getKindEv($this);
  return ($1 | 0) == ($kind | 0);
}

function __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3putERKS2_RKS4_($this, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZNK2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($p, $this, $k);
    var $_idx = $p | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $_idx_val_idx_val = HEAP32[$_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($1, $_idx_val_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($_idx_val);
    var $7 = $v | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $6 + 8 | 0;
    var $st$7$0 = $9 | 0;
    HEAP32[$st$7$0 >> 2] = $8$0;
    var $st$7$1 = $9 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $8$1;
    var $10 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv($_idx_val);
    var $_0 = $10;
    __label__ = 5;
    break;
   case 3:
    var $12 = __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($this, $p, $k, $v);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx2_val = HEAP32[$_idx >> 2];
    var $14 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv($_idx2_val);
    var $_0 = $14;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11NumberValueEd1149($agg_result, $dbl) {
  var $1 = __ZN2JS5Value9setNumberEd($agg_result, $dbl);
  return;
}

function __ZN15JSCodeGenerator7contextEv($this_0_0_11_val_0_1_val) {
  return $this_0_0_11_val_0_1_val;
}

function __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE6lengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZNK13JSTreeContext9callsEvalEv($this_0_0_val) {
  return ($this_0_0_val & 8388608 | 0) != 0;
}

function __ZNK11JSParseNode6isDefnEv($this) {
  return (HEAP32[$this >> 2] | 0) < 0;
}

function __ZN2js11UpvarCookie3setEtt($this, $newLevel, $newSlot) {
  HEAP32[$this >> 2] = ($newLevel & 65535) << 16 | $newSlot & 65535;
  return;
}

function _js_LexicalLookup($tc, $atom, $stmt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($stmt | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_01_ph = $stmt;
      __label__ = 3;
      break;
    }
   case 2:
    var $_01_ph = HEAP32[$tc + 28 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_01_ph;
    var $5 = $tc + 48 | 0;
    var $_01 = $_01_ph;
    __label__ = 4;
    break;
   case 4:
    var $_01;
    if (($_01 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (HEAP16[$_01 >> 1] << 16 >> 16 == 6) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP16[$_01 + 2 >> 1] & 1) << 16 >> 16 == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = HEAP32[HEAP32[$_01 + 20 >> 2] + 8 >> 2];
    var $25 = HEAP32[HEAP32[$5 >> 2] + 12 >> 2];
    var $26 = __ZL12ATOM_TO_JSIDP6JSAtom1150($atom);
    var $27 = __ZN8JSObject12nativeLookupEP9JSContexti($22, $25, $26);
    if (($27 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $_01 = HEAP32[$_01 + 28 >> 2];
    __label__ = 4;
    break;
   case 9:
    return $_01;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12ATOM_TO_JSIDP6JSAtom1150($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj1189($1);
  return $2;
}

function __ZN15JSCodeGenerator20shouldNoteClosedNameEP11JSParseNode($this, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK13JSTreeContext9callsEvalEv($_idx_val);
    if ($1) {
      var $7 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK11JSParseNode6isDefnEv($pn);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $7 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = __ZNK11JSParseNode8isClosedEv($pn);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK11JSParseNode8isClosedEv($this) {
  var $1 = __ZNK11JSParseNode4testEj($this, 2048);
  return $1;
}

function __ZN15JSCodeGenerator12addGlobalUseEP6JSAtomjPN2js11UpvarCookieE($this, $atom, $slot, $cookie) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $allAtomIndex = __stackBase__ + 20;
    var $globalUseIndex = __stackBase__ + 24;
    HEAP32[$1 >> 2] = $atom;
    var $2 = $this + 508 | 0;
    var $this_idx_val_idx_val = HEAP32[HEAP32[$this + 48 >> 2] + 12 >> 2];
    var $3 = __ZN15JSCodeGenerator7contextEv($this_idx_val_idx_val);
    var $4 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE9ensureMapEP9JSContext($2, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    var $_idx1 = $2 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $6 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($_idx1_val);
    __ZN2js9InlineMapIP6JSAtomjLj24EE12lookupForAddERKS2_($p, $6, $1);
    var $7 = __ZNK2js9InlineMapIP6JSAtomjLj24EE6AddPtrcvPPPPPPPS4_Ev($p);
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtr5valueEv($p);
    var $12 = HEAP32[$10 >> 2] & 65535;
    __ZN2js11UpvarCookie3setEtt($cookie, 0, $12);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 4:
    var $14 = $this + 364 | 0;
    var $_idx3 = $this + 372 | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $15 = __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE6lengthEv($_idx3_val);
    if ($15 >>> 0 > 65535) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js11UpvarCookie8makeFreeEv($cookie);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 6:
    var $19 = HEAP32[$1 >> 2];
    var $20 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($this, $19, $allAtomIndex);
    if ($20) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $_idx2_val = HEAP32[$_idx3 >> 2];
    var $22 = __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE6lengthEv($_idx2_val);
    HEAP32[$globalUseIndex >> 2] = $22;
    var $23 = $22 & 65535;
    __ZN2js11UpvarCookie3setEtt($cookie, 0, $23);
    var $24 = HEAP32[$allAtomIndex >> 2];
    var $25 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE6appendIS2_EEbT_($14, $24, $slot);
    if ($25) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $_idx_val = HEAP32[$_idx1 >> 2];
    var $27 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($_idx_val);
    var $28 = __ZN2js9InlineMapIP6JSAtomjLj24EE3addERNS3_6AddPtrERKS2_RKj($27, $p, $1, $globalUseIndex);
    var $_0 = $28;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN15JSCodeGenerator12addGlobalUseEP6JSAtomjPN2js11UpvarCookieE["X"] = 1;

function __ZN2js9InlineMapIP6JSAtomjLj24EE12lookupForAddERKS2_($agg_result, $this, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $_idx_val = HEAP32[$this >> 2];
    var $2 = __ZNK2js9InlineMapIP6JSAtomjLj24EE8usingMapEv($_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this + 200 | 0;
    __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($1, $4, $key);
    __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC1ERKNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E6AddPtrE($agg_result, $1);
    __label__ = 9;
    break;
   case 3:
    var $7 = $this + 8 + ($_idx_val << 3) | 0;
    var $it_0 = $this + 8 | 0;
    __label__ = 4;
    break;
   case 4:
    var $it_0;
    if (($it_0 | 0) == ($7 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$it_0 >> 2] | 0) == (HEAP32[$key >> 2] | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC1EPNS3_10InlineElemEb($agg_result, $it_0, 1);
    __label__ = 9;
    break;
   case 7:
    var $it_0 = $it_0 + 8 | 0;
    __label__ = 4;
    break;
   case 8:
    __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC1EPNS3_10InlineElemEb($agg_result, $7, 0);
    __label__ = 9;
    break;
   case 9:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js9InlineMapIP6JSAtomjLj24EE6AddPtrcvPPPPPPPS4_Ev($this) {
  var $1 = __ZNK2js9InlineMapIP6JSAtomjLj24EE6AddPtr5foundEv($this);
  var $2 = $1 ? 1 : 0;
  return $2;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtr5valueEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[$this + 8 >> 2] + 4 | 0;
    __label__ = 4;
    break;
   case 3:
    var $_idx_val = HEAP32[$this >> 2];
    var $10 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($_idx_val);
    var $_0 = $10 + 4 | 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11UpvarCookie8makeFreeEv($this) {
  __ZN2js11UpvarCookie3setEtt($this, -1, -1);
  return;
}

function __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($this, $atom, $indexp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $index = __stackBase__ + 20;
    HEAP32[$1 >> 2] = $atom;
    var $_idx2 = $this + 176 | 0;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $2 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($_idx2_val);
    __ZN2js9InlineMapIP6JSAtomjLj24EE12lookupForAddERKS2_($p, $2, $1);
    var $3 = __ZNK2js9InlineMapIP6JSAtomjLj24EE6AddPtrcvPPPPPPPS4_Ev($p);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtr5valueEv($p);
    var $7 = HEAP32[$6 >> 2];
    HEAP32[$indexp >> 2] = $7;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $_idx1_val = HEAP32[$_idx2 >> 2];
    var $9 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($_idx1_val);
    var $10 = __ZN2js9InlineMapIP6JSAtomjLj24EE5countEv($9);
    HEAP32[$index >> 2] = $10;
    var $11 = __ZN2js9InlineMapIP6JSAtomjLj24EE3addERNS3_6AddPtrERKS2_RKj($9, $p, $1, $index);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = HEAP32[$index >> 2];
    HEAP32[$indexp >> 2] = $13;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE6appendIS2_EEbT_($this, $t_0, $t_1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE13growStorageByEj($this);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t_0, $t_1);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE3addERNS3_6AddPtrERKS2_RKj($this, $p, $key, $value) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$p + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $p + 8 | 0;
    var $7 = HEAP32[$6 >> 2];
    if (($7 | 0) == ($this + 200 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js9InlineMapIP6JSAtomjLj24EE12switchAndAddERKS2_RKj($this, $key, $value);
    var $_0 = $11;
    __label__ = 6;
    break;
   case 4:
    var $13 = HEAP32[$key >> 2];
    var $14 = $7 | 0;
    HEAP32[$14 >> 2] = $13;
    var $15 = HEAP32[$value >> 2];
    var $17 = HEAP32[$6 >> 2] + 4 | 0;
    HEAP32[$17 >> 2] = $15;
    var $18 = $this + 4 | 0;
    var $20 = HEAP32[$18 >> 2] + 1 | 0;
    HEAP32[$18 >> 2] = $20;
    var $21 = $this | 0;
    var $23 = HEAP32[$21 >> 2] + 1 | 0;
    HEAP32[$21 >> 2] = $23;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $25 = $this + 200 | 0;
    var $26 = $p | 0;
    var $27 = __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKj($25, $26, $key, $value);
    var $_0 = $27;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_EmitFunctionScript($cx, $cg, $body) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 & 512 | 0) == 0) {
      var $_idx_val = $2;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $cg + 172 | 0;
    HEAP32[$7 >> 2] = $cg + 108 | 0;
    var $8 = _js_Emit1($cx, $cg, 205);
    if (($8 | 0) < 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$7 >> 2] = $cg + 140 | 0;
    var $_idx_val = HEAP32[$1 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $_idx_val;
    var $13 = __ZNK13JSTreeContext19needsEagerArgumentsEv($_idx_val);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      var $25 = $_idx_val;
      __label__ = 8;
      break;
    }
   case 5:
    var $16 = $cg + 172 | 0;
    HEAP32[$16 >> 2] = $cg + 108 | 0;
    var $17 = _js_Emit1($cx, $cg, 9);
    if (($17 | 0) < 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = _js_Emit1($cx, $cg, 81);
    if (($20 | 0) < 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$16 >> 2] = $cg + 140 | 0;
    var $25 = HEAP32[$1 >> 2];
    __label__ = 8;
    break;
   case 8:
    var $25;
    if (($25 & 1048576 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $30 = $cg + 172 | 0;
    HEAP32[$30 >> 2] = $cg + 108 | 0;
    var $31 = _js_Emit1($cx, $cg, 229);
    if (($31 | 0) < 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    HEAP32[$30 >> 2] = $cg + 140 | 0;
    __label__ = 11;
    break;
   case 11:
    var $36 = _js_EmitTree($cx, $cg, $body);
    if (($36 | 0) == 0) {
      var $47 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $39 = _js_Emit1($cx, $cg, 197);
    if (($39 | 0) > -1) {
      __label__ = 13;
      break;
    } else {
      var $47 = 0;
      __label__ = 14;
      break;
    }
   case 13:
    var $42 = $cx;
    var $43 = $cg;
    var $44 = __ZN8JSScript15NewScriptFromCGEP9JSContextP15JSCodeGenerator($42, $43);
    var $47 = ($44 | 0) != 0;
    __label__ = 14;
    break;
   case 14:
    var $47;
    var $_0 = $47 & 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_EmitFunctionScript["X"] = 1;

function __ZNK13JSTreeContext19needsEagerArgumentsEv($this_0_0_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK13JSTreeContext12inStrictModeEv($this_0_0_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $9 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = __ZNK13JSTreeContext13usesArgumentsEv($this_0_0_val);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = __ZNK13JSTreeContext16mutatesParameterEv($this_0_0_val);
    if ($5) {
      var $9 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZNK13JSTreeContext9callsEvalEv($this_0_0_val);
    var $9 = $7;
    __label__ = 5;
    break;
   case 5:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_EmitTree($cx, $cg, $pn) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 124;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $useful = __stackBase__;
    var $stmtInfo = __stackBase__ + 4;
    var $noteIndex = __stackBase__ + 36;
    var $op = __stackBase__ + 40;
    var $elm = __stackBase__ + 44;
    var $stackDummy_ = __stackBase__ + 48;
    var $slot = __stackBase__ + 52;
    var $tps = __stackBase__ + 56;
    var $labelIndex = __stackBase__ + 68;
    var $labelIndex2 = __stackBase__ + 72;
    var $catchJump = __stackBase__ + 76;
    var $index4 = __stackBase__ + 80;
    var $tps7 = __stackBase__ + 84;
    var $index11 = __stackBase__ + 96;
    var $1 = __stackBase__ + 100;
    var $index16 = __stackBase__ + 108;
    var $index17 = __stackBase__ + 112;
    var $index19 = __stackBase__ + 116;
    var $index21 = __stackBase__ + 120;
    __ZN16EmitLevelManagerC1EP15JSCodeGenerator($elm, $cg);
    if ($stackDummy_ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_1 = 0;
    __label__ = 614;
    break;
   case 3:
    var $8 = $cg + 172 | 0;
    var $9 = HEAP32[$8 >> 2];
    var $16 = HEAP32[$9 + 8 >> 2] - HEAP32[$9 >> 2] | 0;
    HEAP32[$pn + 20 >> 2] = $16;
    var $18 = $pn + 8 | 0;
    var $19 = HEAPU32[$18 >> 2];
    var $21 = HEAP32[$8 >> 2] + 28 | 0;
    var $22 = HEAP32[$21 >> 2];
    var $23 = $19 - $22 | 0;
    if (($19 | 0) == ($22 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$21 >> 2] = $19;
    if ($23 >>> 0 < ((($19 >>> 0 > 127 & 1) << 1) + 2 | 0) >>> 0) {
      var $delta__0 = $23;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $32 = _js_NewSrcNote2($cx, $cg, 23, $19);
    if (($32 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $delta__0;
    var $34 = _js_NewSrcNote($cx, $cg, 22);
    if (($34 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $37 = $delta__0 - 1 | 0;
    if (($37 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $delta__0 = $37;
      __label__ = 6;
      break;
    }
   case 8:
    var $39 = __ZNK11JSParseNode7getKindEv($pn);
    if (($39 | 0) == 34) {
      __label__ = 9;
      break;
    } else if (($39 | 0) == 84) {
      __label__ = 38;
      break;
    } else if (($39 | 0) == 85) {
      __label__ = 47;
      break;
    } else if (($39 | 0) == 35) {
      __label__ = 48;
      break;
    } else if (($39 | 0) == 37) {
      __label__ = 65;
      break;
    } else if (($39 | 0) == 40) {
      __label__ = 66;
      break;
    } else if (($39 | 0) == 41) {
      __label__ = 77;
      break;
    } else if (($39 | 0) == 42) {
      __label__ = 90;
      break;
    } else if (($39 | 0) == 43) {
      __label__ = 164;
      break;
    } else if (($39 | 0) == 44) {
      __label__ = 174;
      break;
    } else if (($39 | 0) == 47) {
      __label__ = 183;
      break;
    } else if (($39 | 0) == 53) {
      __label__ = 189;
      break;
    } else if (($39 | 0) == 54) {
      __label__ = 234;
      break;
    } else if (($39 | 0) == 46) {
      __label__ = 249;
      break;
    } else if (($39 | 0) == 48) {
      __label__ = 250;
      break;
    } else if (($39 | 0) == 77) {
      __label__ = 258;
      break;
    } else if (($39 | 0) == 25) {
      __label__ = 264;
      break;
    } else if (($39 | 0) == 82) {
      __label__ = 286;
      break;
    } else if (($39 | 0) == 2) {
      __label__ = 291;
      break;
    } else if (($39 | 0) == 6) {
      __label__ = 315;
      break;
    } else if (($39 | 0) == 3) {
      __label__ = 326;
      break;
    } else if (($39 | 0) == 4) {
      __label__ = 333;
      break;
    } else if (($39 | 0) == 5) {
      __label__ = 334;
      break;
    } else if (($39 | 0) == 7 || ($39 | 0) == 8) {
      __label__ = 343;
      break;
    } else if (($39 | 0) == 15 || ($39 | 0) == 9 || ($39 | 0) == 10 || ($39 | 0) == 11 || ($39 | 0) == 12 || ($39 | 0) == 13 || ($39 | 0) == 45 || ($39 | 0) == 57 || ($39 | 0) == 14 || ($39 | 0) == 16 || ($39 | 0) == 17 || ($39 | 0) == 18) {
      __label__ = 360;
      break;
    } else if (($39 | 0) == 71) {
      __label__ = 366;
      break;
    } else if (($39 | 0) == 56 || ($39 | 0) == 70 || ($39 | 0) == 39 || ($39 | 0) == 19) {
      __label__ = 372;
      break;
    } else if (($39 | 0) == 20 || ($39 | 0) == 21) {
      __label__ = 378;
      break;
    } else if (($39 | 0) == 50) {
      __label__ = 403;
      break;
    } else if (($39 | 0) == 74) {
      __label__ = 420;
      break;
    } else if (($39 | 0) == 22) {
      __label__ = 427;
      break;
    } else if (($39 | 0) == 23 || ($39 | 0) == 73) {
      __label__ = 428;
      break;
    } else if (($39 | 0) == 49 || ($39 | 0) == 27) {
      __label__ = 429;
      break;
    } else if (($39 | 0) == 80) {
      __label__ = 448;
      break;
    } else if (($39 | 0) == 81) {
      __label__ = 461;
      break;
    } else if (($39 | 0) == 79) {
      __label__ = 473;
      break;
    } else if (($39 | 0) == 24 || ($39 | 0) == 78) {
      var $_3 = $pn;
      var $sharpnum_0 = -1;
      __label__ = 477;
      break;
    } else if (($39 | 0) == 26) {
      var $_4 = $pn;
      var $sharpnum_1 = -1;
      __label__ = 503;
      break;
    } else if (($39 | 0) == 51) {
      __label__ = 542;
      break;
    } else if (($39 | 0) == 52) {
      __label__ = 548;
      break;
    } else if (($39 | 0) == 29) {
      __label__ = 550;
      break;
    } else if (($39 | 0) == 64 || ($39 | 0) == 65 || ($39 | 0) == 66 || ($39 | 0) == 68 || ($39 | 0) == 67 || ($39 | 0) == 31) {
      __label__ = 552;
      break;
    } else if (($39 | 0) == 30) {
      __label__ = 553;
      break;
    } else if (($39 | 0) == 32) {
      __label__ = 554;
      break;
    } else if (($39 | 0) == 72 || ($39 | 0) == 33) {
      __label__ = 555;
      break;
    } else if (($39 | 0) == 58) {
      __label__ = 556;
      break;
    } else if (($39 | 0) == 75 || ($39 | 0) == 76) {
      __label__ = 557;
      break;
    } else if (($39 | 0) == 61 || ($39 | 0) == 59 || ($39 | 0) == 60) {
      __label__ = 572;
      break;
    } else if (($39 | 0) == 63) {
      __label__ = 593;
      break;
    } else if (($39 | 0) == 69) {
      __label__ = 605;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 9:
    var $41 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 0);
    if ($41) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $43 = _js_Emit1($cx, $cg, 208);
    if (($43 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 11:
    var $47 = $pn + 32 | 0;
    var $_idx8_val = HEAP32[HEAP32[$47 >> 2] + 8 >> 2];
    var $49 = __ZNK13JSFunctionBox8functionEv($_idx8_val);
    var $50 = __ZNK10JSFunction6scriptEv($49);
    if (($50 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $56 = HEAPU32[$pn + 44 >> 2] >>> 12;
    var $57 = __ZL18EmitFunctionDefNopP9JSContextP15JSCodeGeneratorj($cx, $cg, $56);
    if (($57 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 13:
    var $60 = $cg | 0;
    var $62 = HEAP32[$cg + 48 >> 2];
    var $63 = HEAP32[$18 >> 2];
    var $64 = __ZN9JSContext4new_I15JSCodeGeneratorPN2js6ParserEjEEPT_T0_T1_($cx, $62, $63);
    if (($64 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_1 = 0;
    __label__ = 614;
    break;
   case 15:
    var $68 = __ZN15JSCodeGenerator4initEP9JSContextN13JSTreeContext12InitBehaviorE($64, $cx, 1);
    if ($68) {
      __label__ = 16;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 16:
    var $73 = $cg | 0;
    var $77 = HEAP32[HEAP32[$47 >> 2] + 60 >> 2] | HEAP32[$73 >> 2] & 67108864 | 3;
    var $78 = $64 | 0;
    var $79 = $64 | 0;
    HEAP32[$79 >> 2] = $77;
    var $80 = $64 + 92 | 0;
    var $82 = HEAP32[$47 >> 2] + 44 | 0;
    __ZN2js8Bindings8transferEP9JSContextPS0_($80, $82);
    if ((HEAP32[$79 >> 2] & 32768 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $87 = $80;
    var $88 = $cx;
    var $89 = __ZN2js8Bindings13sharpSlotBaseEP9JSContext($87, $88);
    var $90 = $64 + 104 | 0;
    HEAP32[$90 >> 2] = $89;
    if (($89 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZN13JSTreeContext11setFunctionEP10JSFunction($78, $49);
    var $93 = HEAP32[$47 >> 2];
    var $94 = $64 + 80 | 0;
    HEAP32[$94 >> 2] = $93;
    var $95 = $64 + 72 | 0;
    HEAP32[$95 >> 2] = $60;
    var $98 = HEAP32[$cg + 76 >> 2] + 1 | 0;
    var $99 = $64 + 76 | 0;
    HEAP32[$99 >> 2] = $98;
    var $102 = HEAP32[$pn + 36 >> 2];
    var $103 = _js_EmitFunctionScript($cx, $64, $102);
    var $_010 = ($103 | 0) == 0 ? 0 : $pn;
    __ZN9JSContext7delete_I15JSCodeGeneratorEEvPT_($64);
    if (($_010 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $107 = $cg + 292 | 0;
    var $109 = $_010 + 32 | 0;
    var $111 = HEAP32[$109 >> 2] | 0;
    var $112 = __ZN14JSCGObjectList5indexEP11JSObjectBox($107, $111);
    var $113 = __ZNK11JSParseNode5getOpEv($_010);
    HEAP32[$op >> 2] = $113;
    if (($113 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    if ((HEAP32[HEAP32[$109 >> 2] + 60 >> 2] & 4096 | 0) == 0) {
      var $125 = $113;
      __label__ = 23;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $122 = _js_NewSrcNote($cx, $cg, 1);
    if (($122 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $125 = HEAP32[$op >> 2];
    __label__ = 23;
    break;
   case 23:
    var $125;
    var $126 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $125, $112, $cg, 0);
    if ($126) {
      __label__ = 24;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 24:
    var $128 = __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($128 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $_010;
      __label__ = 609;
      break;
    }
   case 25:
    var $_idx6_val = HEAP32[$73 >> 2];
    var $131 = __ZNK13JSTreeContext10inFunctionEv($_idx6_val);
    if ($131) {
      __label__ = 32;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $134 = HEAP32[$49 + 72 >> 2];
    var $135 = __ZL10BindGlobalP9JSContextP15JSCodeGeneratorP11JSParseNodeP6JSAtom($cg, $_010, $134);
    if ($135) {
      __label__ = 27;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 27:
    var $_idx10_val = HEAP32[$_010 + 40 >> 2];
    var $138 = __ZNK2js11UpvarCookie6isFreeEv($_idx10_val);
    if ($138) {
      __label__ = 28;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 28:
    HEAP32[$8 >> 2] = $cg + 108 | 0;
    var $_idx19_val = HEAP16[$49 + 58 >> 1];
    var $141 = __ZNK10JSFunction13isFlatClosureEv($_idx19_val);
    var $142 = $141 ? 222 : 127;
    HEAP32[$op >> 2] = $142;
    var $143 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $142, $112, $cg, 0);
    if ($143) {
      __label__ = 29;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 29:
    var $145 = __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($145 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    HEAP32[$8 >> 2] = $cg + 140 | 0;
    __label__ = 31;
    break;
   case 31:
    var $150 = __ZL18EmitFunctionDefNopP9JSContextP15JSCodeGeneratorj($cx, $cg, $112);
    if (($150 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $_010;
      __label__ = 609;
      break;
    }
   case 32:
    var $155 = HEAP32[$49 + 72 >> 2];
    var $156 = $cg + 92 | 0;
    var $157 = $cx;
    var $158 = __ZNK2js8Bindings6lookupEP9JSContextP6JSAtomPj($156, $157, $155, $slot);
    var $160 = $_010 + 44 | 0;
    var $164 = HEAP32[$160 >> 2] & 4095 | $112 << 12;
    HEAP32[$160 >> 2] = $164;
    var $_idx18_val = HEAP16[$49 + 58 >> 1];
    var $165 = __ZNK10JSFunction13isFlatClosureEv($_idx18_val);
    var $166 = $165 ? 223 : 140;
    HEAP32[$op >> 2] = $166;
    var $167 = __ZNK11JSParseNode8isClosedEv($_010);
    if ($167) {
      __label__ = 33;
      break;
    } else {
      var $176 = $166;
      __label__ = 36;
      break;
    }
   case 33:
    var $_idx12_val = HEAP32[$73 >> 2];
    var $169 = __ZNK13JSTreeContext9callsEvalEv($_idx12_val);
    if ($169) {
      var $176 = $166;
      __label__ = 36;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $171 = $cg + 564 | 0;
    var $_idx1_val = HEAP32[$_010 + 40 >> 2];
    var $173 = __ZNK2js11UpvarCookie4slotEv($_idx1_val);
    var $174 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE6appendItEEbT_($171, $173);
    if ($174) {
      __label__ = 35;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 35:
    var $176 = HEAP32[$op >> 2];
    __label__ = 36;
    break;
   case 36:
    var $176;
    var $177 = HEAP32[$slot >> 2];
    var $178 = __ZL15EmitSlotIndexOpP9JSContext4JSOpjjP15JSCodeGenerator($cx, $176, $177, $112, $cg);
    if (($178 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $181 = __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($181 | 0) > -1) {
      var $ok_059 = 1;
      var $_560 = $_010;
      __label__ = 609;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 38:
    var $pn_idx11_val = HEAP32[$pn + 36 >> 2];
    var $183 = __ZNK11JSParseNode4lastEv($pn_idx11_val);
    var $185 = $cg + 516 | 0;
    var $pn21_0_in = $pn + 32 | 0;
    __label__ = 39;
    break;
   case 39:
    var $pn21_0_in;
    var $pn21_0 = HEAP32[$pn21_0_in >> 2];
    if (($pn21_0 | 0) == ($183 | 0)) {
      __label__ = 46;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $189 = __ZNK11JSParseNode6isDefnEv($pn21_0);
    if ($189) {
      __label__ = 41;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 41:
    var $191 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn21_0);
    if (($191 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $194 = __ZNK11JSParseNode5getOpEv($pn21_0);
    if ((HEAP32[_js_CodeSpec + ($194 << 3) + 4 >> 2] & 31 | 0) == 6) {
      __label__ = 43;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 43:
    var $200 = __ZN15JSCodeGenerator20shouldNoteClosedNameEP11JSParseNode($cg, $pn21_0);
    if ($200) {
      __label__ = 44;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 44:
    var $_idx_val = HEAP32[$pn21_0 + 40 >> 2];
    var $203 = __ZNK2js11UpvarCookie4slotEv($_idx_val);
    var $204 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE6appendItEEbT_($185, $203);
    if ($204) {
      __label__ = 45;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 45:
    var $pn21_0_in = $pn21_0 + 24 | 0;
    __label__ = 39;
    break;
   case 46:
    var $208 = _js_EmitTree($cx, $cg, $183);
    var $_5 = $pn;
    var $ok_0 = $208;
    __label__ = 608;
    break;
   case 47:
    var $210 = $cg + 184 | 0;
    var $211 = $pn + 32 | 0;
    var $213 = HEAP32[$211 >> 2];
    HEAP32[$210 >> 2] = $213;
    var $217 = HEAP32[$pn + 36 >> 2];
    var $218 = _js_EmitTree($cx, $cg, $217);
    var $219 = $210 | 0;
    __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE8clearMapEv($219);
    var $220 = $211;
    __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE10releaseMapEP9JSContext($220, $cx);
    var $_5 = $pn;
    var $ok_0 = $218;
    __label__ = 608;
    break;
   case 48:
    var $222 = $stmtInfo | 0;
    HEAP16[$222 >> 1] = 1;
    HEAP32[$noteIndex >> 2] = -1;
    var $223 = $cg | 0;
    var $224 = $stmtInfo + 12 | 0;
    var $225 = $stmtInfo + 8 | 0;
    var $_111 = $pn;
    var $beq_0 = -1;
    var $jmp_0 = -1;
    __label__ = 49;
    break;
   case 49:
    var $jmp_0;
    var $beq_0;
    var $_111;
    var $228 = HEAP32[$_111 + 32 >> 2];
    var $229 = _js_EmitTree($cx, $cg, $228);
    if (($229 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    var $232 = HEAP32[$8 >> 2];
    var $239 = HEAP32[$232 + 8 >> 2] - HEAP32[$232 >> 2] | 0;
    if (HEAP16[$222 >> 1] << 16 >> 16 == 1) {
      __label__ = 51;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 51:
    _js_PushStatement($223, $stmtInfo, 1, $239);
    __label__ = 54;
    break;
   case 52:
    HEAP16[$222 >> 1] = 1;
    HEAP32[$225 >> 2] = $239;
    var $244 = HEAP32[$noteIndex >> 2];
    var $246 = _js_SetSrcNoteOffset($cx, $cg, $244, 0, $jmp_0 - $beq_0 | 0);
    if (($246 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    var $249 = HEAP32[$noteIndex >> 2];
    var $250 = $239 - $beq_0 | 0;
    var $251 = _js_SetSrcNoteOffset($cx, $cg, $249, 1, $250);
    if (($251 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    var $256 = HEAP32[$_111 + 40 >> 2];
    var $257 = ($256 | 0) != 0;
    var $258 = $257 ? 2 : 1;
    var $259 = _js_NewSrcNote($cx, $cg, $258);
    HEAP32[$noteIndex >> 2] = $259;
    if (($259 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    var $262 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 7, 0);
    if (($262 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    var $267 = HEAP32[$_111 + 36 >> 2];
    var $268 = _js_EmitTree($cx, $cg, $267);
    if (($268 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    if ($257) {
      __label__ = 58;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 58:
    HEAP16[$222 >> 1] = 2;
    var $272 = __ZL8EmitGotoP9JSContextP15JSCodeGeneratorP10JSStmtInfoPij13JSSrcNoteType($cx, $cg, $stmtInfo, $224, -1, 0);
    if (($272 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 59:
    var $275 = HEAP32[$8 >> 2];
    var $277 = HEAP32[$275 >> 2];
    var $278 = $277 + $262 | 0;
    var $283 = HEAP32[$275 + 8 >> 2] - ($277 + $262) | 0;
    var $284 = _js_SetJumpOffset($cx, $cg, $278, $283);
    if (($284 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 60:
    var $287 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($256, 35);
    if ($287) {
      var $_111 = $256;
      var $beq_0 = $262;
      var $jmp_0 = $272;
      __label__ = 49;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    var $289 = _js_EmitTree($cx, $cg, $256);
    if (($289 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 62:
    var $292 = HEAP32[$noteIndex >> 2];
    var $293 = $272 - $262 | 0;
    var $294 = _js_SetSrcNoteOffset($cx, $cg, $292, 0, $293);
    if (($294 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 63:
    var $297 = HEAP32[$8 >> 2];
    var $299 = HEAP32[$297 >> 2];
    var $300 = $299 + $262 | 0;
    var $305 = HEAP32[$297 + 8 >> 2] - ($299 + $262) | 0;
    var $306 = _js_SetJumpOffset($cx, $cg, $300, $305);
    if (($306 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    var $309 = _js_PopStatementCG($cx, $cg);
    var $_5 = $_111;
    var $ok_0 = $309;
    __label__ = 608;
    break;
   case 65:
    var $311 = __ZL10EmitSwitchP9JSContextP15JSCodeGeneratorP11JSParseNodeP10JSStmtInfo($cx, $cg, $pn, $stmtInfo);
    var $_5 = $pn;
    var $ok_0 = $311;
    __label__ = 608;
    break;
   case 66:
    var $313 = $cg | 0;
    _js_PushStatement($313, $stmtInfo, 14, $16);
    var $314 = _js_NewSrcNote($cx, $cg, 4);
    HEAP32[$noteIndex >> 2] = $314;
    if (($314 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 67:
    var $317 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 6, 0);
    if (($317 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 68:
    var $320 = _js_NewSrcNote($cx, $cg, 4);
    if (($320 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 69:
    var $323 = $pn + 36 | 0;
    var $325 = HEAP32[$323 >> 2];
    var $326 = __ZL11EmitTraceOpP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $325);
    if (($326 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    var $330 = HEAP32[$323 >> 2];
    var $331 = _js_EmitTree($cx, $cg, $330);
    if (($331 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 71:
    var $334 = HEAP32[$8 >> 2];
    var $336 = HEAP32[$334 >> 2];
    var $337 = $336 + $317 | 0;
    var $342 = HEAP32[$334 + 8 >> 2] - ($336 + $317) | 0;
    var $343 = _js_SetJumpOffset($cx, $cg, $337, $342);
    if (($343 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 72;
      break;
    }
   case 72:
    var $347 = HEAP32[$pn + 32 >> 2];
    var $348 = _js_EmitTree($cx, $cg, $347);
    if (($348 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    var $351 = HEAP32[$8 >> 2];
    var $359 = $326 - HEAP32[$351 + 8 >> 2] + HEAP32[$351 >> 2] | 0;
    var $360 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 8, $359);
    if (($360 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 74:
    var $363 = $360 - $326 | 0;
    var $364 = _js_SetSrcNoteOffset($cx, $cg, $320, 0, $363);
    if (($364 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 75:
    var $367 = HEAP32[$noteIndex >> 2];
    var $368 = $360 - $317 | 0;
    var $369 = _js_SetSrcNoteOffset($cx, $cg, $367, 0, $368);
    if (($369 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 76:
    var $372 = _js_PopStatementCG($cx, $cg);
    var $_5 = $pn;
    var $ok_0 = $372;
    __label__ = 608;
    break;
   case 77:
    var $374 = _js_NewSrcNote($cx, $cg, 4);
    HEAP32[$noteIndex >> 2] = $374;
    if (($374 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 78:
    var $377 = _js_Emit1($cx, $cg, 0);
    if (($377 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 79:
    var $380 = _js_NewSrcNote($cx, $cg, 4);
    if (($380 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 80:
    var $383 = $pn + 32 | 0;
    var $384 = HEAP32[$383 >> 2];
    var $385 = __ZL11EmitTraceOpP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $384);
    if (($385 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 81:
    var $388 = $cg | 0;
    _js_PushStatement($388, $stmtInfo, 11, $385);
    var $389 = HEAP32[$383 >> 2];
    var $390 = _js_EmitTree($cx, $cg, $389);
    if (($390 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 82:
    var $393 = HEAP32[$8 >> 2];
    var $400 = HEAP32[$393 + 8 >> 2] - HEAP32[$393 >> 2] | 0;
    var $stmt_0 = $stmtInfo;
    __label__ = 83;
    break;
   case 83:
    var $stmt_0;
    HEAP32[$stmt_0 + 8 >> 2] = $400;
    var $404 = HEAP32[$stmt_0 + 24 >> 2];
    if (($404 | 0) == 0) {
      __label__ = 85;
      break;
    } else {
      __label__ = 84;
      break;
    }
   case 84:
    if (HEAP16[$404 >> 1] << 16 >> 16 == 0) {
      var $stmt_0 = $404;
      __label__ = 83;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 85:
    var $412 = HEAP32[$pn + 36 >> 2];
    var $413 = _js_EmitTree($cx, $cg, $412);
    if (($413 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 86;
      break;
    }
   case 86:
    var $416 = HEAP32[$8 >> 2];
    var $424 = $385 - HEAP32[$416 + 8 >> 2] + HEAP32[$416 >> 2] | 0;
    var $425 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 8, $424);
    if (($425 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 87;
      break;
    }
   case 87:
    var $428 = $425 - $385 | 0;
    var $429 = _js_SetSrcNoteOffset($cx, $cg, $380, 0, $428);
    if (($429 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 88;
      break;
    }
   case 88:
    var $432 = HEAP32[$noteIndex >> 2];
    var $434 = 1 - $385 + $400 | 0;
    var $435 = _js_SetSrcNoteOffset($cx, $cg, $432, 0, $434);
    if (($435 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 89;
      break;
    }
   case 89:
    var $438 = _js_PopStatementCG($cx, $cg);
    var $_5 = $pn;
    var $ok_0 = $438;
    __label__ = 608;
    break;
   case 90:
    var $441 = HEAP32[$pn + 32 >> 2];
    var $442 = $cg | 0;
    _js_PushStatement($442, $stmtInfo, 12, $16);
    var $443 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($441, 45);
    if ($443) {
      __label__ = 91;
      break;
    } else {
      __label__ = 117;
      break;
    }
   case 91:
    HEAP16[$stmtInfo >> 1] = 13;
    var $446 = $441 + 32 | 0;
    var $447 = HEAP32[$446 >> 2];
    if (($447 | 0) == 0) {
      __label__ = 92;
      break;
    } else {
      __label__ = 93;
      break;
    }
   case 92:
    __ZN12TempPopScopeC1Ev($tps);
    var $forLet_033 = 0;
    __label__ = 96;
    break;
   case 93:
    var $450 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($447, 81);
    var $451 = $cg | 0;
    var $453 = HEAP32[$451 >> 2] | 16;
    HEAP32[$451 >> 2] = $453;
    var $454 = _js_EmitTree($cx, $cg, $447);
    if (($454 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 94;
      break;
    }
   case 94:
    var $458 = HEAP32[$451 >> 2] & -17;
    HEAP32[$451 >> 2] = $458;
    __ZN12TempPopScopeC1Ev($tps);
    if ($450) {
      __label__ = 95;
      break;
    } else {
      var $forLet_033 = 0;
      __label__ = 96;
      break;
    }
   case 95:
    var $460 = __ZN12TempPopScope8popBlockEP9JSContextP15JSCodeGenerator($tps, $cx, $cg);
    if ($460) {
      var $forLet_033 = 1;
      __label__ = 96;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 96:
    var $forLet_033;
    var $464 = HEAP32[$441 + 40 >> 2];
    var $465 = _js_EmitTree($cx, $cg, $464);
    if (($465 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 97;
      break;
    }
   case 97:
    if ($forLet_033) {
      __label__ = 98;
      break;
    } else {
      __label__ = 99;
      break;
    }
   case 98:
    var $469 = __ZN12TempPopScope11repushBlockEP9JSContextP15JSCodeGenerator($tps, $cx, $cg);
    if ($469) {
      __label__ = 99;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 99:
    var $474 = HEAP32[$pn + 44 >> 2] & 255;
    var $475 = _js_Emit2($cx, $cg, 75, $474);
    if (($475 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 100;
      break;
    }
   case 100:
    var $478 = _js_NewSrcNote($cx, $cg, 2);
    HEAP32[$noteIndex >> 2] = $478;
    if (($478 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 101;
      break;
    }
   case 101:
    var $481 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 6, 0);
    if (($481 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 102:
    var $484 = _js_NewSrcNote($cx, $cg, 4);
    if (($484 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 103;
      break;
    }
   case 103:
    var $487 = HEAP32[$8 >> 2];
    var $494 = HEAP32[$487 + 8 >> 2] - HEAP32[$487 >> 2] | 0;
    HEAP32[$stmtInfo + 8 >> 2] = $494;
    HEAP32[$stmtInfo + 16 >> 2] = -1;
    HEAP32[$stmtInfo + 12 >> 2] = -1;
    var $498 = __ZL11EmitTraceOpP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, 0);
    if (($498 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 104;
      break;
    }
   case 104:
    var $503 = HEAP32[$441 + 36 >> 2];
    var $504 = __ZL14EmitAssignmentP9JSContextP15JSCodeGeneratorP11JSParseNode4JSOpS4_($cx, $cg, $503, 0, 0);
    if ($504) {
      __label__ = 105;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 105:
    var $506 = HEAP32[$8 >> 2];
    var $511 = HEAP32[$506 + 8 >> 2];
    var $512 = HEAP32[$506 >> 2];
    var $513 = HEAP32[$446 >> 2];
    if (($513 | 0) == 0) {
      __label__ = 107;
      break;
    } else {
      __label__ = 106;
      break;
    }
   case 106:
    var $516 = __ZNK11JSParseNode4isOpE4JSOp($513, 129);
    var $517 = $516 ? 0 : 2;
    var $518 = _js_NewSrcNote2($cx, $cg, 6, $517);
    if (($518 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 107;
      break;
    }
   case 107:
    var $521 = _js_Emit1($cx, $cg, 81);
    if (($521 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 108:
    var $526 = HEAP32[$pn + 36 >> 2];
    var $527 = _js_EmitTree($cx, $cg, $526);
    if (($527 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $stmt_1 = $stmtInfo;
      __label__ = 109;
      break;
    }
   case 109:
    var $stmt_1;
    var $529 = HEAP32[$8 >> 2];
    var $536 = HEAP32[$529 + 8 >> 2] - HEAP32[$529 >> 2] | 0;
    HEAP32[$stmt_1 + 8 >> 2] = $536;
    var $539 = HEAP32[$stmt_1 + 24 >> 2];
    if (($539 | 0) == 0) {
      __label__ = 111;
      break;
    } else {
      __label__ = 110;
      break;
    }
   case 110:
    if (HEAP16[$539 >> 1] << 16 >> 16 == 0) {
      var $stmt_1 = $539;
      __label__ = 109;
      break;
    } else {
      __label__ = 111;
      break;
    }
   case 111:
    var $545 = HEAP32[$8 >> 2];
    var $547 = HEAP32[$545 >> 2];
    var $548 = $547 + $481 | 0;
    var $553 = HEAP32[$545 + 8 >> 2] - ($547 + $481) | 0;
    var $554 = _js_SetJumpOffset($cx, $cg, $548, $553);
    if (($554 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 112;
      break;
    }
   case 112:
    var $557 = _js_Emit1($cx, $cg, 76);
    if (($557 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 113:
    var $560 = HEAP32[$8 >> 2];
    var $568 = $494 - HEAP32[$560 + 8 >> 2] + HEAP32[$560 >> 2] | 0;
    var $569 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 8, $568);
    if (($569 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 114;
      break;
    }
   case 114:
    var $572 = $569 - $494 | 0;
    var $573 = _js_SetSrcNoteOffset($cx, $cg, $484, 0, $572);
    if (($573 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 115;
      break;
    }
   case 115:
    var $576 = HEAP32[$noteIndex >> 2];
    var $578 = $511 - $481 - $512 | 0;
    var $579 = _js_SetSrcNoteOffset($cx, $cg, $576, 0, $578);
    if (($579 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 116;
      break;
    }
   case 116:
    var $582 = HEAP32[$noteIndex >> 2];
    var $583 = $569 - $481 | 0;
    var $584 = _js_SetSrcNoteOffset($cx, $cg, $582, 1, $583);
    if (($584 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $top_0 = $494;
      __label__ = 160;
      break;
    }
   case 117:
    HEAP32[$op >> 2] = 81;
    var $588 = HEAP32[$441 + 32 >> 2];
    if (($588 | 0) == 0) {
      __label__ = 118;
      break;
    } else {
      __label__ = 119;
      break;
    }
   case 118:
    HEAP32[$op >> 2] = 0;
    __label__ = 127;
    break;
   case 119:
    var $592 = $cg | 0;
    var $594 = HEAP32[$592 >> 2] | 16;
    HEAP32[$592 >> 2] = $594;
    var $595 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($588, 4);
    if ($595) {
      __label__ = 120;
      break;
    } else {
      __label__ = 122;
      break;
    }
   case 120:
    var $_idx27_val = HEAP32[$588 + 32 >> 2];
    var $_idx28_val = HEAP32[$588 + 36 >> 2];
    var $597 = __ZL24MaybeEmitGroupAssignmentP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodePS3_($cx, $cg, 81, $_idx27_val, $_idx28_val, $op);
    if (($597 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 121;
      break;
    }
   case 121:
    if ((HEAP32[$op >> 2] | 0) == 81) {
      __label__ = 122;
      break;
    } else {
      __label__ = 126;
      break;
    }
   case 122:
    var $600 = _js_EmitTree($cx, $cg, $588);
    if (($600 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 123;
      break;
    }
   case 123:
    var $603 = __ZNK11JSParseNode7getKindEv($588);
    var $604 = __ZN2jsL15TokenKindIsDeclENS_9TokenKindE($603);
    if ($604) {
      __label__ = 124;
      break;
    } else {
      __label__ = 126;
      break;
    }
   case 124:
    if ((HEAP32[$588 + 44 >> 2] & 64 | 0) == 0) {
      __label__ = 126;
      break;
    } else {
      __label__ = 125;
      break;
    }
   case 125:
    HEAP32[$op >> 2] = 0;
    __label__ = 126;
    break;
   case 126:
    var $613 = HEAP32[$592 >> 2] & -17;
    HEAP32[$592 >> 2] = $613;
    __label__ = 127;
    break;
   case 127:
    var $615 = _js_NewSrcNote($cx, $cg, 3);
    HEAP32[$noteIndex >> 2] = $615;
    if (($615 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 128;
      break;
    }
   case 128:
    var $618 = HEAP32[$op >> 2];
    var $619 = _js_Emit1($cx, $cg, $618);
    if (($619 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 129;
      break;
    }
   case 129:
    var $622 = HEAP32[$8 >> 2];
    var $624 = HEAP32[$622 + 8 >> 2];
    var $626 = HEAP32[$622 >> 2];
    var $629 = $624 - $626 | 0;
    var $630 = $441 + 36 | 0;
    if ((HEAP32[$630 >> 2] | 0) == 0) {
      var $jmp_1 = -1;
      var $638 = $624;
      var $637 = $626;
      __label__ = 132;
      break;
    } else {
      __label__ = 130;
      break;
    }
   case 130:
    var $634 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 6, 0);
    if (($634 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 131;
      break;
    }
   case 131:
    var $_pre73 = HEAP32[$8 >> 2];
    var $jmp_1 = $634;
    var $638 = HEAP32[$_pre73 + 8 >> 2];
    var $637 = HEAP32[$_pre73 >> 2];
    __label__ = 132;
    break;
   case 132:
    var $637;
    var $638;
    var $jmp_1;
    var $641 = $638 - $637 | 0;
    HEAP32[$stmtInfo + 8 >> 2] = $641;
    HEAP32[$stmtInfo + 16 >> 2] = -1;
    HEAP32[$stmtInfo + 12 >> 2] = -1;
    var $645 = _js_NewSrcNote($cx, $cg, 4);
    if (($645 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 133;
      break;
    }
   case 133:
    var $648 = $pn + 36 | 0;
    var $650 = HEAP32[$648 >> 2];
    var $651 = __ZL11EmitTraceOpP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $650);
    if (($651 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 134;
      break;
    }
   case 134:
    var $655 = HEAP32[$648 >> 2];
    var $656 = _js_EmitTree($cx, $cg, $655);
    if (($656 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 135;
      break;
    }
   case 135:
    var $659 = HEAP32[$8 >> 2];
    var $661 = HEAP32[$659 + 8 >> 2];
    var $663 = HEAP32[$659 >> 2];
    var $664 = $661;
    var $665 = $663;
    var $stmt_2 = $stmtInfo;
    var $668 = $661;
    var $667 = $663;
    __label__ = 136;
    break;
   case 136:
    var $667;
    var $668;
    var $stmt_2;
    HEAP32[$stmt_2 + 8 >> 2] = $668 - $667 | 0;
    var $674 = HEAP32[$stmt_2 + 24 >> 2];
    if (($674 | 0) == 0) {
      __label__ = 139;
      break;
    } else {
      __label__ = 137;
      break;
    }
   case 137:
    if (HEAP16[$674 >> 1] << 16 >> 16 == 0) {
      __label__ = 138;
      break;
    } else {
      __label__ = 139;
      break;
    }
   case 138:
    var $_pre77 = HEAP32[$8 >> 2];
    var $stmt_2 = $674;
    var $668 = HEAP32[$_pre77 + 8 >> 2];
    var $667 = HEAP32[$_pre77 >> 2];
    __label__ = 136;
    break;
   case 139:
    var $682 = HEAP32[$441 + 40 >> 2];
    if (($682 | 0) == 0) {
      __label__ = 149;
      break;
    } else {
      __label__ = 140;
      break;
    }
   case 140:
    HEAP32[$op >> 2] = 81;
    var $685 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($682, 4);
    if ($685) {
      __label__ = 141;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 141:
    var $_idx25_val = HEAP32[$682 + 32 >> 2];
    var $_idx26_val = HEAP32[$682 + 36 >> 2];
    var $687 = __ZL24MaybeEmitGroupAssignmentP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodePS3_($cx, $cg, 81, $_idx25_val, $_idx26_val, $op);
    if (($687 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 142;
      break;
    }
   case 142:
    var $_pr = HEAP32[$op >> 2];
    if (($_pr | 0) == 81) {
      __label__ = 143;
      break;
    } else {
      var $694 = $_pr;
      __label__ = 145;
      break;
    }
   case 143:
    var $691 = _js_EmitTree($cx, $cg, $682);
    if (($691 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 144;
      break;
    }
   case 144:
    var $694 = HEAP32[$op >> 2];
    __label__ = 145;
    break;
   case 145:
    var $694;
    var $695 = _js_Emit1($cx, $cg, $694);
    if (($695 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 146;
      break;
    }
   case 146:
    var $699 = HEAP32[$pn + 16 >> 2];
    if ((HEAP32[HEAP32[$8 >> 2] + 28 >> 2] | 0) == ($699 | 0)) {
      __label__ = 149;
      break;
    } else {
      __label__ = 147;
      break;
    }
   case 147:
    var $705 = _js_NewSrcNote2($cx, $cg, 23, $699);
    if (($705 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 148;
      break;
    }
   case 148:
    var $709 = HEAP32[$8 >> 2] + 28 | 0;
    HEAP32[$709 >> 2] = $699;
    __label__ = 149;
    break;
   case 149:
    var $710 = HEAP32[$8 >> 2];
    var $712 = HEAP32[$710 + 8 >> 2];
    var $714 = HEAP32[$710 >> 2];
    var $717 = $712 - $714 | 0;
    if ((HEAP32[$630 >> 2] | 0) == 0) {
      var $732 = $712;
      var $731 = $714;
      __label__ = 153;
      break;
    } else {
      __label__ = 150;
      break;
    }
   case 150:
    var $721 = $714 + $jmp_1 | 0;
    var $722 = $717 - $jmp_1 | 0;
    var $723 = _js_SetJumpOffset($cx, $cg, $721, $722);
    if (($723 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 151;
      break;
    }
   case 151:
    var $727 = HEAP32[$630 >> 2];
    var $728 = _js_EmitTree($cx, $cg, $727);
    if (($728 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 152;
      break;
    }
   case 152:
    var $_pre82 = HEAP32[$8 >> 2];
    var $732 = HEAP32[$_pre82 + 8 >> 2];
    var $731 = HEAP32[$_pre82 >> 2];
    __label__ = 153;
    break;
   case 153:
    var $731;
    var $732;
    var $737 = _js_SetSrcNoteOffset($cx, $cg, $645, 0, $732 - $641 - $731 | 0);
    if (($737 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 154;
      break;
    }
   case 154:
    var $740 = HEAP32[$noteIndex >> 2];
    var $741 = $717 - $629 | 0;
    var $742 = _js_SetSrcNoteOffset($cx, $cg, $740, 0, $741);
    if (($742 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 155;
      break;
    }
   case 155:
    var $745 = HEAP32[$noteIndex >> 2];
    var $747 = $664 - $629 - $665 | 0;
    var $748 = _js_SetSrcNoteOffset($cx, $cg, $745, 1, $747);
    if (($748 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 156;
      break;
    }
   case 156:
    var $751 = HEAP32[$noteIndex >> 2];
    var $752 = HEAP32[$8 >> 2];
    var $760 = HEAP32[$752 + 8 >> 2] - $629 - HEAP32[$752 >> 2] | 0;
    var $761 = _js_SetSrcNoteOffset($cx, $cg, $751, 2, $760);
    if (($761 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 157;
      break;
    }
   case 157:
    var $766 = HEAP32[$8 >> 2];
    var $774 = HEAP32[$766 >> 2] - HEAP32[$766 + 8 >> 2] + $641 | 0;
    if ((HEAP32[$630 >> 2] | 0) == 0) {
      __label__ = 159;
      break;
    } else {
      __label__ = 158;
      break;
    }
   case 158:
    var $776 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 8, $774);
    if (($776 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $top_0 = $641;
      __label__ = 160;
      break;
    }
   case 159:
    var $779 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 6, $774);
    if (($779 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $top_0 = $641;
      __label__ = 160;
      break;
    }
   case 160:
    var $top_0;
    var $782 = _js_PopStatementCG($cx, $cg);
    if (($782 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 161;
      break;
    }
   case 161:
    var $785 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($441, 45);
    if ($785) {
      __label__ = 162;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 162:
    var $788 = HEAP32[$cg + 192 >> 2];
    var $789 = HEAP32[$8 >> 2];
    var $796 = HEAP32[$789 + 8 >> 2] - HEAP32[$789 >> 2] | 0;
    var $797 = __ZL10NewTryNoteP9JSContextP15JSCodeGenerator13JSTryNoteKindjjj($cx, $cg, 2, $788, $top_0, $796);
    if (($797 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 163;
      break;
    }
   case 163:
    var $800 = _js_Emit1($cx, $cg, 78);
    if (($800 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 164:
    var $804 = HEAPU32[$cg + 24 >> 2];
    var $807 = HEAP32[$pn + 32 >> 2];
    if (($807 | 0) == 0) {
      __label__ = 169;
      break;
    } else {
      __label__ = 165;
      break;
    }
   case 165:
    var $810 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $807, $labelIndex);
    if ($810) {
      var $stmt_3 = $804;
      __label__ = 166;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 166:
    var $stmt_3;
    if (HEAP16[$stmt_3 >> 1] << 16 >> 16 == 0) {
      __label__ = 167;
      break;
    } else {
      __label__ = 168;
      break;
    }
   case 167:
    if ((HEAP32[$stmt_3 + 20 >> 2] | 0) == ($807 | 0)) {
      __label__ = 172;
      break;
    } else {
      __label__ = 168;
      break;
    }
   case 168:
    var $stmt_3 = HEAP32[$stmt_3 + 24 >> 2];
    __label__ = 166;
    break;
   case 169:
    HEAP32[$labelIndex >> 2] = -1;
    var $822 = HEAPU16[$804 >> 1];
    if ($822 << 16 >> 16 != 5 & ($822 & 65535) < 11) {
      var $stmt_4141 = $804;
      __label__ = 170;
      break;
    } else {
      var $stmt_4_lcssa = $804;
      var $_lcssa139 = $822;
      __label__ = 171;
      break;
    }
   case 170:
    var $stmt_4141;
    var $826 = HEAPU32[$stmt_4141 + 24 >> 2];
    var $828 = HEAPU16[$826 >> 1];
    if ($828 << 16 >> 16 != 5 & ($828 & 65535) < 11) {
      var $stmt_4141 = $826;
      __label__ = 170;
      break;
    } else {
      var $stmt_4_lcssa = $826;
      var $_lcssa139 = $828;
      __label__ = 171;
      break;
    }
   case 171:
    var $_lcssa139;
    var $stmt_4_lcssa;
    var $832 = $_lcssa139 << 16 >> 16 == 5 ? 18 : 1;
    var $stmt_5 = $stmt_4_lcssa;
    var $noteType_0 = $832;
    var $833 = -1;
    __label__ = 173;
    break;
   case 172:
    var $stmt_5 = $stmt_3;
    var $noteType_0 = 16;
    var $833 = HEAP32[$labelIndex >> 2];
    __label__ = 173;
    break;
   case 173:
    var $833;
    var $noteType_0;
    var $stmt_5;
    var $835 = __ZL8EmitGotoP9JSContextP15JSCodeGeneratorP10JSStmtInfoPij13JSSrcNoteType($cx, $cg, $stmt_5, $stmt_5 + 12 | 0, $833, $noteType_0);
    if (($835 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 174:
    var $839 = HEAPU32[$cg + 24 >> 2];
    var $842 = HEAP32[$pn + 32 >> 2];
    if (($842 | 0) == 0) {
      __label__ = 179;
      break;
    } else {
      __label__ = 175;
      break;
    }
   case 175:
    var $845 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $842, $labelIndex2);
    if ($845) {
      var $stmt_6 = $839;
      var $loop_0 = 0;
      __label__ = 176;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 176:
    var $loop_0;
    var $stmt_6;
    var $847 = HEAPU16[$stmt_6 >> 1];
    if ($847 << 16 >> 16 == 0) {
      __label__ = 177;
      break;
    } else {
      __label__ = 178;
      break;
    }
   case 177:
    if ((HEAP32[$stmt_6 + 20 >> 2] | 0) == ($842 | 0)) {
      __label__ = 181;
      break;
    } else {
      __label__ = 178;
      break;
    }
   case 178:
    var $loop_1 = ($847 & 65535) > 10 ? $stmt_6 : $loop_0;
    var $stmt_6 = HEAPU32[$stmt_6 + 24 >> 2];
    var $loop_0 = $loop_1;
    __label__ = 176;
    break;
   case 179:
    HEAP32[$labelIndex2 >> 2] = -1;
    if ((HEAPU16[$839 >> 1] & 65535) < 11) {
      var $stmt_7136 = $839;
      __label__ = 180;
      break;
    } else {
      var $stmt_8 = $839;
      var $noteType_1 = 5;
      var $865 = -1;
      __label__ = 182;
      break;
    }
   case 180:
    var $stmt_7136;
    var $861 = HEAPU32[$stmt_7136 + 24 >> 2];
    if ((HEAPU16[$861 >> 1] & 65535) < 11) {
      var $stmt_7136 = $861;
      __label__ = 180;
      break;
    } else {
      var $stmt_8 = $861;
      var $noteType_1 = 5;
      var $865 = -1;
      __label__ = 182;
      break;
    }
   case 181:
    var $stmt_8 = $loop_0;
    var $noteType_1 = 17;
    var $865 = HEAP32[$labelIndex2 >> 2];
    __label__ = 182;
    break;
   case 182:
    var $865;
    var $noteType_1;
    var $stmt_8;
    var $867 = __ZL8EmitGotoP9JSContextP15JSCodeGeneratorP10JSStmtInfoPij13JSSrcNoteType($cx, $cg, $stmt_8, $stmt_8 + 16 | 0, $865, $noteType_1);
    if (($867 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 183:
    var $871 = HEAP32[$pn + 32 >> 2];
    var $872 = _js_EmitTree($cx, $cg, $871);
    if (($872 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 184;
      break;
    }
   case 184:
    var $875 = $cg | 0;
    var $876 = HEAP32[$8 >> 2];
    var $883 = HEAP32[$876 + 8 >> 2] - HEAP32[$876 >> 2] | 0;
    _js_PushStatement($875, $stmtInfo, 6, $883);
    var $884 = _js_Emit1($cx, $cg, 3);
    if (($884 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 185;
      break;
    }
   case 185:
    var $887 = __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($887 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 186;
      break;
    }
   case 186:
    var $892 = HEAP32[$pn + 36 >> 2];
    var $893 = _js_EmitTree($cx, $cg, $892);
    if (($893 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 187;
      break;
    }
   case 187:
    var $896 = _js_Emit1($cx, $cg, 4);
    if (($896 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 188;
      break;
    }
   case 188:
    var $899 = _js_PopStatementCG($cx, $cg);
    var $_5 = $pn;
    var $ok_0 = $899;
    __label__ = 608;
    break;
   case 189:
    HEAP32[$catchJump >> 2] = -1;
    var $901 = $cg | 0;
    var $903 = $pn + 40 | 0;
    var $906 = (HEAP32[$903 >> 2] | 0) != 0 ? 9 : 8;
    var $907 = HEAP32[$8 >> 2];
    var $914 = HEAP32[$907 + 8 >> 2] - HEAP32[$907 >> 2] | 0;
    _js_PushStatement($901, $stmtInfo, $906, $914);
    var $915 = $cg + 192 | 0;
    var $916 = HEAPU32[$915 >> 2];
    var $917 = _js_Emit1($cx, $cg, 134);
    if (($917 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 190;
      break;
    }
   case 190:
    var $920 = HEAP32[$8 >> 2];
    var $927 = HEAP32[$920 + 8 >> 2] - HEAP32[$920 >> 2] | 0;
    var $929 = HEAP32[$pn + 32 >> 2];
    var $930 = _js_EmitTree($cx, $cg, $929);
    if (($930 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 191;
      break;
    }
   case 191:
    if ((HEAP32[$903 >> 2] | 0) == 0) {
      __label__ = 194;
      break;
    } else {
      __label__ = 192;
      break;
    }
   case 192:
    var $936 = _js_NewSrcNote($cx, $cg, 11);
    if (($936 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 193;
      break;
    }
   case 193:
    var $939 = $stmtInfo + 12 | 0;
    var $940 = __ZL15EmitBackPatchOpP9JSContextP15JSCodeGenerator4JSOpPi($cx, $cg, $939);
    if (($940 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 194;
      break;
    }
   case 194:
    var $943 = _js_NewSrcNote($cx, $cg, 11);
    if (($943 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 195;
      break;
    }
   case 195:
    var $946 = __ZL15EmitBackPatchOpP9JSContextP15JSCodeGenerator4JSOpPi($cx, $cg, $catchJump);
    if (($946 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 196;
      break;
    }
   case 196:
    var $949 = HEAP32[$8 >> 2];
    var $956 = HEAP32[$949 + 8 >> 2] - HEAP32[$949 >> 2] | 0;
    var $957 = $pn + 36 | 0;
    var $958 = HEAP32[$957 >> 2];
    if (($958 | 0) == 0) {
      __label__ = 220;
      break;
    } else {
      __label__ = 197;
      break;
    }
   case 197:
    var $962 = $stmtInfo + 16 | 0;
    var $963 = $stmtInfo + 8 | 0;
    var $964 = $stmtInfo + 12 | 0;
    var $965 = $916 + 1 | 0;
    var $pn3_0_in = $958 + 32 | 0;
    var $count_0 = 0;
    var $prevBox_0 = 0;
    var $lastCatch_0 = 0;
    __label__ = 198;
    break;
   case 198:
    var $lastCatch_0;
    var $prevBox_0;
    var $count_0;
    var $pn3_0_in;
    var $pn3_0 = HEAP32[$pn3_0_in >> 2];
    if (($pn3_0 | 0) == 0) {
      __label__ = 213;
      break;
    } else {
      __label__ = 199;
      break;
    }
   case 199:
    var $969 = HEAP32[$962 >> 2];
    if (($969 | 0) == -1) {
      __label__ = 206;
      break;
    } else {
      __label__ = 200;
      break;
    }
   case 200:
    var $972 = __ZL19EmitKnownBlockChainP9JSContextP15JSCodeGeneratorP11JSObjectBox($cx, $cg, $prevBox_0);
    if (($972 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 201;
      break;
    }
   case 201:
    var $975 = HEAP32[$8 >> 2];
    var $977 = HEAP32[$975 >> 2];
    var $978 = $977 + $969 | 0;
    var $983 = HEAP32[$975 + 8 >> 2] - ($977 + $969) | 0;
    var $984 = _js_SetJumpOffset($cx, $cg, $978, $983);
    if (($984 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 202;
      break;
    }
   case 202:
    HEAP32[$915 >> 2] = $965 + $count_0 | 0;
    var $988 = _js_NewSrcNote($cx, $cg, 11);
    if (($988 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 203;
      break;
    }
   case 203:
    var $991 = _js_Emit1($cx, $cg, 153);
    if (($991 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 204;
      break;
    }
   case 204:
    var $994 = _js_NewSrcNote($cx, $cg, 11);
    if (($994 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 205;
      break;
    }
   case 205:
    var $997 = __ZL14EmitLeaveBlockP9JSContextP15JSCodeGenerator4JSOpP11JSObjectBox($cx, $cg, 202, $prevBox_0);
    if (($997 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 206;
      break;
    }
   case 206:
    var $1000 = _js_NewSrcNote2($cx, $cg, 20, 0);
    if (($1000 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 207;
      break;
    }
   case 207:
    HEAP32[$963 >> 2] = $1000;
    var $1004 = $pn3_0 + 32 | 0;
    var $1008 = HEAP32[HEAP32[$1004 >> 2] + 8 >> 2];
    var $1009 = __ZNK8JSObject13propertyCountEv($1008);
    var $1010 = HEAP32[$1004 >> 2];
    var $1011 = _js_EmitTree($cx, $cg, $pn3_0);
    if (($1011 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 208;
      break;
    }
   case 208:
    if ((HEAP32[$903 >> 2] | 0) == 0) {
      __label__ = 210;
      break;
    } else {
      __label__ = 209;
      break;
    }
   case 209:
    var $1017 = __ZL15EmitBackPatchOpP9JSContextP15JSCodeGenerator4JSOpPi($cx, $cg, $964);
    if (($1017 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 210;
      break;
    }
   case 210:
    var $1020 = _js_NewSrcNote($cx, $cg, 11);
    if (($1020 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 211;
      break;
    }
   case 211:
    var $1023 = __ZL15EmitBackPatchOpP9JSContextP15JSCodeGenerator4JSOpPi($cx, $cg, $catchJump);
    if (($1023 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 212;
      break;
    }
   case 212:
    var $pn3_0_idx_val = HEAP32[$pn3_0 + 36 >> 2];
    var $1026 = __ZNK11JSParseNode4exprEv($pn3_0_idx_val);
    var $pn3_0_in = $pn3_0 + 24 | 0;
    var $count_0 = $1009;
    var $prevBox_0 = $1010;
    var $lastCatch_0 = $1026;
    __label__ = 198;
    break;
   case 213:
    if (($lastCatch_0 | 0) == 0) {
      __label__ = 220;
      break;
    } else {
      __label__ = 214;
      break;
    }
   case 214:
    if ((HEAP32[$lastCatch_0 + 36 >> 2] | 0) == 0) {
      __label__ = 220;
      break;
    } else {
      __label__ = 215;
      break;
    }
   case 215:
    var $1035 = __ZL19EmitKnownBlockChainP9JSContextP15JSCodeGeneratorP11JSObjectBox($cx, $cg, $prevBox_0);
    if (($1035 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 216;
      break;
    }
   case 216:
    var $1038 = HEAP32[$8 >> 2];
    var $1040 = HEAP32[$1038 >> 2];
    var $1041 = HEAP32[$962 >> 2];
    var $1042 = $1040 + $1041 | 0;
    var $1047 = HEAP32[$1038 + 8 >> 2] - ($1040 + $1041) | 0;
    var $1048 = _js_SetJumpOffset($cx, $cg, $1042, $1047);
    if (($1048 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 217;
      break;
    }
   case 217:
    HEAP32[$915 >> 2] = $965;
    var $1051 = _js_NewSrcNote($cx, $cg, 11);
    if (($1051 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 218;
      break;
    }
   case 218:
    var $1054 = _js_Emit1($cx, $cg, 112);
    if (($1054 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 219;
      break;
    }
   case 219:
    var $1057 = __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($1057 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 220;
      break;
    }
   case 220:
    if ((HEAP32[$903 >> 2] | 0) == 0) {
      var $finallyStart_0 = 0;
      __label__ = 226;
      break;
    } else {
      __label__ = 221;
      break;
    }
   case 221:
    var $1063 = HEAP32[$stmtInfo + 12 >> 2];
    var $1066 = HEAP32[HEAP32[$8 >> 2] + 8 >> 2];
    var $1067 = __ZL9BackPatchP9JSContextP15JSCodeGeneratoriPhh($cx, $cg, $1063, $1066, 116);
    if (($1067 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 222;
      break;
    }
   case 222:
    var $1070 = HEAP32[$8 >> 2];
    var $1077 = HEAP32[$1070 + 8 >> 2] - HEAP32[$1070 >> 2] | 0;
    HEAP16[$stmtInfo >> 1] = 10;
    var $1081 = HEAP32[HEAP32[$903 >> 2] + 8 >> 2];
    var $1082 = __ZL21UpdateLineNumberNotesP9JSContextP15JSCodeGeneratorj($cx, $cg, $1081);
    if (($1082 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 223;
      break;
    }
   case 223:
    var $1085 = _js_Emit1($cx, $cg, 135);
    if (($1085 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 224;
      break;
    }
   case 224:
    var $1088 = HEAP32[$903 >> 2];
    var $1089 = _js_EmitTree($cx, $cg, $1088);
    if (($1089 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 225;
      break;
    }
   case 225:
    var $1092 = _js_Emit1($cx, $cg, 117);
    if (($1092 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $finallyStart_0 = $1077;
      __label__ = 226;
      break;
    }
   case 226:
    var $finallyStart_0;
    var $1095 = _js_PopStatementCG($cx, $cg);
    if (($1095 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 227;
      break;
    }
   case 227:
    var $1098 = _js_NewSrcNote($cx, $cg, 15);
    if (($1098 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 228;
      break;
    }
   case 228:
    var $1101 = _js_Emit1($cx, $cg, 0);
    if (($1101 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 229;
      break;
    }
   case 229:
    var $1104 = HEAP32[$catchJump >> 2];
    var $1107 = HEAP32[HEAP32[$8 >> 2] + 8 >> 2];
    var $1108 = __ZL9BackPatchP9JSContextP15JSCodeGeneratoriPhh($cx, $cg, $1104, $1107, 6);
    if (($1108 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 230;
      break;
    }
   case 230:
    if ((HEAP32[$957 >> 2] | 0) == 0) {
      __label__ = 232;
      break;
    } else {
      __label__ = 231;
      break;
    }
   case 231:
    var $1114 = __ZL10NewTryNoteP9JSContextP15JSCodeGenerator13JSTryNoteKindjjj($cx, $cg, 0, $916, $927, $956);
    if (($1114 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 232;
      break;
    }
   case 232:
    if ((HEAP32[$903 >> 2] | 0) == 0) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    } else {
      __label__ = 233;
      break;
    }
   case 233:
    var $1120 = __ZL10NewTryNoteP9JSContextP15JSCodeGenerator13JSTryNoteKindjjj($cx, $cg, 1, $916, $927, $finallyStart_0);
    if (($1120 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 234:
    var $1124 = HEAP32[$cg + 24 >> 2];
    HEAP16[$1124 >> 1] = 7;
    var $1127 = HEAP32[$1124 + 8 >> 2];
    var $1129 = HEAP32[$1124 + 24 >> 2];
    var $1130 = _js_Emit1($cx, $cg, 118);
    if (($1130 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 235;
      break;
    }
   case 235:
    var $1133 = $pn + 36 | 0;
    if ((HEAP32[$1133 >> 2] | 0) == 0) {
      __label__ = 237;
      break;
    } else {
      __label__ = 236;
      break;
    }
   case 236:
    var $1137 = _js_Emit1($cx, $cg, 12);
    if (($1137 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 237;
      break;
    }
   case 237:
    var $1141 = HEAP32[$pn + 32 >> 2];
    var $1142 = __ZNK11JSParseNode7getKindEv($1141);
    if (($1142 | 0) == 24 || ($1142 | 0) == 26) {
      __label__ = 238;
      break;
    } else if (($1142 | 0) == 29) {
      __label__ = 240;
      break;
    } else {
      __label__ = 242;
      break;
    }
   case 238:
    var $1144 = __ZL20EmitDestructuringOpsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode($cx, $cg, 0, $1141);
    if (($1144 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 239;
      break;
    }
   case 239:
    var $1147 = _js_Emit1($cx, $cg, 81);
    if (($1147 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 242;
      break;
    }
   case 240:
    var $_idx17_val = HEAP32[$1141 + 40 >> 2];
    var $1151 = __ZNK2js11UpvarCookie9asIntegerEv($_idx17_val);
    var $1153 = $1151 >>> 8 & 255;
    var $1154 = $1151 & 255;
    var $1155 = _js_Emit3($cx, $cg, 132, $1153, $1154);
    if (($1155 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 241;
      break;
    }
   case 241:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, 132);
    __label__ = 242;
    break;
   case 242:
    var $1158 = HEAP32[$1133 >> 2];
    if (($1158 | 0) == 0) {
      __label__ = 247;
      break;
    } else {
      __label__ = 243;
      break;
    }
   case 243:
    var $1161 = $1158;
    var $1162 = _js_EmitTree($cx, $cg, $1161);
    if (($1162 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 244;
      break;
    }
   case 244:
    var $1166 = HEAP32[$1129 + 8 >> 2];
    var $1167 = HEAP32[$8 >> 2];
    var $1175 = HEAP32[$1167 + 8 >> 2] - $1127 - HEAP32[$1167 >> 2] | 0;
    var $1176 = _js_SetSrcNoteOffset($cx, $cg, $1166, 0, $1175);
    if (($1176 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 245;
      break;
    }
   case 245:
    var $1179 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 7, 0);
    if (($1179 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 246;
      break;
    }
   case 246:
    var $1182 = $1129 + 16 | 0;
    HEAP32[$1182 >> 2] = $1179;
    var $1183 = _js_Emit1($cx, $cg, 81);
    if (($1183 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 247;
      break;
    }
   case 247:
    var $1188 = HEAP32[$pn + 40 >> 2];
    var $1189 = _js_EmitTree($cx, $cg, $1188);
    if (($1189 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 248;
      break;
    }
   case 248:
    var $1193 = HEAP32[$cg + 192 >> 2];
    var $1194 = _js_NewSrcNote2($cx, $cg, 20, $1193);
    if (($1194 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 249:
    var $1197 = __ZL13EmitVariablesP9JSContextP15JSCodeGeneratorP11JSParseNodeiPi($cx, $cg, $pn, 0, $noteIndex);
    if (($1197 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 250:
    var $1201 = HEAP32[$pn + 32 >> 2];
    if (($1201 | 0) == 0) {
      __label__ = 252;
      break;
    } else {
      __label__ = 251;
      break;
    }
   case 251:
    var $1204 = _js_EmitTree($cx, $cg, $1201);
    if (($1204 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 253;
      break;
    }
   case 252:
    var $1207 = _js_Emit1($cx, $cg, 1);
    if (($1207 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 253;
      break;
    }
   case 253:
    var $1210 = HEAP32[$8 >> 2];
    var $1217 = HEAP32[$1210 + 8 >> 2] - HEAP32[$1210 >> 2] | 0;
    var $1218 = _js_Emit1($cx, $cg, 5);
    if (($1218 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 254;
      break;
    }
   case 254:
    var $1221 = __ZL21EmitNonLocalJumpFixupP9JSContextP15JSCodeGeneratorP10JSStmtInfo($cx, $cg, 0);
    if (($1221 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 255;
      break;
    }
   case 255:
    var $1225 = HEAP32[$8 >> 2];
    var $1229 = HEAP32[$1225 >> 2];
    if (($1217 + 1 | 0) == (HEAP32[$1225 + 8 >> 2] - $1229 | 0)) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    } else {
      __label__ = 256;
      break;
    }
   case 256:
    HEAP8[$1229 + $1217 | 0] = -102;
    var $1236 = _js_Emit1($cx, $cg, 155);
    if (($1236 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 257;
      break;
    }
   case 257:
    var $1239 = __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($1239 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 258:
    var $1243 = HEAP32[$pn + 32 >> 2];
    if (($1243 | 0) == 0) {
      __label__ = 260;
      break;
    } else {
      __label__ = 259;
      break;
    }
   case 259:
    var $1246 = _js_EmitTree($cx, $cg, $1243);
    if (($1246 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 261;
      break;
    }
   case 260:
    var $1249 = _js_Emit1($cx, $cg, 1);
    if (($1249 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 261;
      break;
    }
   case 261:
    if ((HEAP32[$pn + 40 >> 2] | 0) == 0) {
      __label__ = 263;
      break;
    } else {
      __label__ = 262;
      break;
    }
   case 262:
    var $1256 = _js_NewSrcNote($cx, $cg, 11);
    if (($1256 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 263;
      break;
    }
   case 263:
    var $1259 = _js_Emit1($cx, $cg, 206);
    if (($1259 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 264:
    var $1262 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 1);
    if ($1262) {
      __label__ = 265;
      break;
    } else {
      __label__ = 267;
      break;
    }
   case 265:
    var $1265 = HEAP32[$pn + 32 >> 2];
    var $1266 = _js_EmitTree($cx, $cg, $1265);
    if (($1266 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 266;
      break;
    }
   case 266:
    var $1269 = __ZNK11JSParseNode5getOpEv($pn);
    var $1270 = _js_Emit1($cx, $cg, $1269);
    if (($1270 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 267:
    HEAP32[$noteIndex >> 2] = -1;
    var $1273 = HEAP32[$8 >> 2];
    var $1278 = HEAP32[$1273 + 8 >> 2];
    var $1279 = HEAP32[$1273 >> 2];
    var $1281 = $pn + 44 | 0;
    if ((HEAP32[$1281 >> 2] & 128 | 0) == 0) {
      __label__ = 270;
      break;
    } else {
      __label__ = 268;
      break;
    }
   case 268:
    var $1286 = _js_NewSrcNote2($cx, $cg, 10, 0);
    HEAP32[$noteIndex >> 2] = $1286;
    if (($1286 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 269;
      break;
    }
   case 269:
    var $1289 = _js_Emit1($cx, $cg, 0);
    if (($1289 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 270;
      break;
    }
   case 270:
    var $1292 = $cg | 0;
    _js_PushStatement($1292, $stmtInfo, 4, $16);
    var $1294 = HEAP32[$pn + 32 >> 2];
    var $1295 = HEAP32[$1281 >> 2];
    if (($1295 & 256 | 0) == 0) {
      var $pn2_1 = $1294;
      __label__ = 280;
      break;
    } else {
      __label__ = 271;
      break;
    }
   case 271:
    if (($1295 & 512 | 0) == 0) {
      var $pnchild_0 = $1294;
      __label__ = 274;
      break;
    } else {
      __label__ = 272;
      break;
    }
   case 272:
    var $1302 = _js_EmitTree($cx, $cg, $1294);
    if (($1302 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 273;
      break;
    }
   case 273:
    var $pnchild_0 = HEAP32[$1294 + 24 >> 2];
    __label__ = 274;
    break;
   case 274:
    var $pnchild_0;
    var $pn2_0 = $pnchild_0;
    __label__ = 275;
    break;
   case 275:
    var $pn2_0;
    if (($pn2_0 | 0) == 0) {
      var $pn2_1 = $pnchild_0;
      __label__ = 280;
      break;
    } else {
      __label__ = 276;
      break;
    }
   case 276:
    var $1311 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_0, 34);
    if ($1311) {
      __label__ = 277;
      break;
    } else {
      __label__ = 279;
      break;
    }
   case 277:
    var $1313 = __ZNK11JSParseNode4isOpE4JSOp($pn2_0, 0);
    if ($1313) {
      __label__ = 278;
      break;
    } else {
      __label__ = 279;
      break;
    }
   case 278:
    var $1315 = _js_EmitTree($cx, $cg, $pn2_0);
    if (($1315 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 279;
      break;
    }
   case 279:
    var $pn2_0 = HEAP32[$pn2_0 + 24 >> 2];
    __label__ = 275;
    break;
   case 280:
    var $pn2_1;
    if (($pn2_1 | 0) == 0) {
      __label__ = 283;
      break;
    } else {
      __label__ = 281;
      break;
    }
   case 281:
    var $1322 = _js_EmitTree($cx, $cg, $pn2_1);
    if (($1322 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 282;
      break;
    }
   case 282:
    var $pn2_1 = HEAP32[$pn2_1 + 24 >> 2];
    __label__ = 280;
    break;
   case 283:
    var $1328 = HEAP32[$noteIndex >> 2];
    if (($1328 | 0) > -1) {
      __label__ = 284;
      break;
    } else {
      __label__ = 285;
      break;
    }
   case 284:
    var $1331 = HEAP32[$8 >> 2];
    var $1340 = $1279 - $1278 + HEAP32[$1331 + 8 >> 2] - HEAP32[$1331 >> 2] | 0;
    var $1341 = _js_SetSrcNoteOffset($cx, $cg, $1328, 0, $1340);
    if (($1341 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 285;
      break;
    }
   case 285:
    var $1344 = _js_PopStatementCG($cx, $cg);
    var $_5 = $pn;
    var $ok_0 = $1344;
    __label__ = 608;
    break;
   case 286:
    var $1346 = $cg | 0;
    _js_PushStatement($1346, $stmtInfo, 3, $16);
    var $pn2_2_in = $pn + 32 | 0;
    __label__ = 287;
    break;
   case 287:
    var $pn2_2_in;
    var $pn2_2 = HEAP32[$pn2_2_in >> 2];
    if (($pn2_2 | 0) == 0) {
      __label__ = 290;
      break;
    } else {
      __label__ = 288;
      break;
    }
   case 288:
    var $1351 = _js_EmitTree($cx, $cg, $pn2_2);
    if (($1351 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 289;
      break;
    }
   case 289:
    var $pn2_2_in = $pn2_2 + 24 | 0;
    __label__ = 287;
    break;
   case 290:
    var $1356 = _js_PopStatementCG($cx, $cg);
    var $_5 = $pn;
    var $ok_0 = $1356;
    __label__ = 608;
    break;
   case 291:
    var $1359 = HEAPU32[$pn + 32 >> 2];
    if (($1359 | 0) == 0) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    } else {
      __label__ = 292;
      break;
    }
   case 292:
    var $1365 = (HEAP32[$cg >> 2] & 16386 | 0) == 0;
    var $1366 = $1365 & 1;
    HEAP32[$useful >> 2] = $1366;
    if ($1365) {
      var $_pr38 = $1366;
      __label__ = 295;
      break;
    } else {
      __label__ = 293;
      break;
    }
   case 293:
    var $1368 = __ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi($cx, $cg, $1359, $useful);
    if (($1368 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 294;
      break;
    }
   case 294:
    var $_pr38 = HEAP32[$useful >> 2];
    __label__ = 295;
    break;
   case 295:
    var $_pr38;
    var $1371 = ($_pr38 | 0) == 0;
    if ($1371) {
      __label__ = 296;
      break;
    } else {
      __label__ = 303;
      break;
    }
   case 296:
    var $1374 = HEAP32[$cg + 24 >> 2];
    if (($1374 | 0) == 0) {
      __label__ = 301;
      break;
    } else {
      __label__ = 297;
      break;
    }
   case 297:
    if (HEAP16[$1374 >> 1] << 16 >> 16 == 0) {
      __label__ = 298;
      break;
    } else {
      __label__ = 300;
      break;
    }
   case 298:
    var $1383 = HEAP32[$8 >> 2];
    if ((HEAP32[$1374 + 8 >> 2] | 0) < (HEAP32[$1383 + 8 >> 2] - HEAP32[$1383 >> 2] | 0)) {
      __label__ = 300;
      break;
    } else {
      __label__ = 299;
      break;
    }
   case 299:
    HEAP32[$useful >> 2] = 1;
    __label__ = 303;
    break;
   case 300:
    if ($1371) {
      __label__ = 301;
      break;
    } else {
      __label__ = 303;
      break;
    }
   case 301:
    var $pn_idx20_val = HEAP32[$pn + 40 >> 2];
    var $1393 = __ZNK11JSParseNode25isDirectivePrologueMemberEv($pn_idx20_val);
    if ($1393) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    } else {
      __label__ = 302;
      break;
    }
   case 302:
    var $1396 = HEAP32[$1359 + 8 >> 2];
    var $1398 = HEAP32[$8 >> 2] + 28 | 0;
    HEAP32[$1398 >> 2] = $1396;
    var $1401 = HEAP32[$cg + 48 >> 2] + 40 | 0;
    var $1402 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($1401, $1359, 5, 163, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    if ($1402) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 303:
    var $1403 = $1365 ? 2 : 81;
    HEAP32[$op >> 2] = $1403;
    if ($1365) {
      __label__ = 313;
      break;
    } else {
      __label__ = 304;
      break;
    }
   case 304:
    var $1405 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($1359, 4);
    if ($1405) {
      __label__ = 305;
      break;
    } else {
      __label__ = 307;
      break;
    }
   case 305:
    var $_idx23_val = HEAP32[$1359 + 32 >> 2];
    var $_idx24_val = HEAP32[$1359 + 36 >> 2];
    var $1407 = __ZL24MaybeEmitGroupAssignmentP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodePS3_($cx, $cg, $1403, $_idx23_val, $_idx24_val, $op);
    if (($1407 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 306;
      break;
    }
   case 306:
    if ((HEAP32[$op >> 2] | 0) == 0) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    } else {
      __label__ = 307;
      break;
    }
   case 307:
    var $1411 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($1359, 4);
    if ($1411) {
      __label__ = 308;
      break;
    } else {
      __label__ = 313;
      break;
    }
   case 308:
    var $1413 = __ZNK11JSParseNode4isOpE4JSOp($1359, 0);
    if ($1413) {
      __label__ = 309;
      break;
    } else {
      __label__ = 313;
      break;
    }
   case 309:
    var $1416 = HEAP32[$1359 + 32 >> 2];
    var $1417 = __ZNK11JSParseNode4isOpE4JSOp($1416, 54);
    if ($1417) {
      __label__ = 310;
      break;
    } else {
      __label__ = 313;
      break;
    }
   case 310:
    var $1420 = HEAP32[$1359 + 36 >> 2];
    var $1421 = $1420;
    var $1422 = __ZNK11JSParseNode4isOpE4JSOp($1421, 130);
    if ($1422) {
      __label__ = 311;
      break;
    } else {
      __label__ = 313;
      break;
    }
   case 311:
    var $1426 = HEAP32[$1420 + 32 >> 2];
    var $1427 = __ZNK13JSFunctionBox8joinableEv($1426);
    if ($1427) {
      __label__ = 312;
      break;
    } else {
      __label__ = 313;
      break;
    }
   case 312:
    __ZN11JSParseNode5setOpE4JSOp($1416, 226);
    __label__ = 313;
    break;
   case 313:
    var $1429 = _js_EmitTree($cx, $cg, $1359);
    if (($1429 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 314;
      break;
    }
   case 314:
    var $1432 = HEAP32[$op >> 2];
    var $1433 = _js_Emit1($cx, $cg, $1432);
    if (($1433 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 315:
    var $1438 = HEAP32[$pn + 32 >> 2];
    var $1439 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $1438, $index4);
    if ($1439) {
      __label__ = 316;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 316:
    var $pn_idx4_val = HEAP32[$pn + 36 >> 2];
    var $1441 = __ZNK11JSParseNode4exprEv($pn_idx4_val);
    var $1442 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($1441, 25);
    if ($1442) {
      var $1449 = 1;
      __label__ = 319;
      break;
    } else {
      __label__ = 317;
      break;
    }
   case 317:
    var $1444 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($1441, 80);
    if ($1444) {
      __label__ = 318;
      break;
    } else {
      var $1449 = 0;
      __label__ = 319;
      break;
    }
   case 318:
    var $_idx3_val = HEAP32[$1441 + 36 >> 2];
    var $1446 = __ZNK11JSParseNode4exprEv($_idx3_val);
    var $1447 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($1446, 25);
    var $1449 = $1447;
    __label__ = 319;
    break;
   case 319:
    var $1449;
    var $1450 = $1449 ? 14 : 13;
    var $1451 = HEAP32[$index4 >> 2];
    var $1452 = _js_NewSrcNote2($cx, $cg, $1450, $1451);
    HEAP32[$noteIndex >> 2] = $1452;
    if (($1452 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 320;
      break;
    }
   case 320:
    var $1455 = _js_Emit1($cx, $cg, 0);
    if (($1455 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 321;
      break;
    }
   case 321:
    var $1458 = $cg | 0;
    var $1459 = HEAP32[$8 >> 2];
    var $1466 = HEAP32[$1459 + 8 >> 2] - HEAP32[$1459 >> 2] | 0;
    _js_PushStatement($1458, $stmtInfo, 0, $1466);
    HEAP32[$stmtInfo + 20 >> 2] = $1438;
    var $1468 = _js_EmitTree($cx, $cg, $1441);
    if (($1468 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 322;
      break;
    }
   case 322:
    var $1471 = _js_PopStatementCG($cx, $cg);
    if (($1471 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 323;
      break;
    }
   case 323:
    if ($1449) {
      __label__ = 324;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 324:
    var $1475 = _js_NewSrcNote($cx, $cg, 15);
    if (($1475 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 325;
      break;
    }
   case 325:
    var $1478 = _js_Emit1($cx, $cg, 0);
    if (($1478 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 326:
    HEAP32[$noteIndex >> 2] = -1;
    var $off_0 = -1;
    var $pn2_3_in = $pn + 32 | 0;
    __label__ = 327;
    break;
   case 327:
    var $pn2_3_in;
    var $off_0;
    var $pn2_3 = HEAP32[$pn2_3_in >> 2];
    var $1483 = _js_EmitTree($cx, $cg, $pn2_3);
    if (($1483 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 328;
      break;
    }
   case 328:
    var $1486 = HEAP32[$8 >> 2];
    var $1493 = HEAP32[$1486 + 8 >> 2] - HEAP32[$1486 >> 2] | 0;
    var $1494 = HEAP32[$noteIndex >> 2];
    if (($1494 | 0) > -1) {
      __label__ = 329;
      break;
    } else {
      __label__ = 330;
      break;
    }
   case 329:
    var $1497 = $1493 - $off_0 | 0;
    var $1498 = _js_SetSrcNoteOffset($cx, $cg, $1494, 0, $1497);
    if (($1498 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 330;
      break;
    }
   case 330:
    var $1501 = $pn2_3 + 24 | 0;
    if ((HEAP32[$1501 >> 2] | 0) == 0) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    } else {
      __label__ = 331;
      break;
    }
   case 331:
    var $1505 = _js_NewSrcNote2($cx, $cg, 7, 0);
    HEAP32[$noteIndex >> 2] = $1505;
    if (($1505 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 332;
      break;
    }
   case 332:
    var $1508 = _js_Emit1($cx, $cg, 81);
    if (($1508 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $off_0 = $1493;
      var $pn2_3_in = $1501;
      __label__ = 327;
      break;
    }
   case 333:
    var $1512 = HEAP32[$pn + 32 >> 2];
    var $1513 = __ZNK11JSParseNode5getOpEv($pn);
    var $1516 = HEAP32[$pn + 36 >> 2];
    var $1517 = __ZL14EmitAssignmentP9JSContextP15JSCodeGeneratorP11JSParseNode4JSOpS4_($cx, $cg, $1512, $1513, $1516);
    if ($1517) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 334:
    var $1520 = HEAP32[$pn + 32 >> 2];
    var $1521 = _js_EmitTree($cx, $cg, $1520);
    if (($1521 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 335;
      break;
    }
   case 335:
    var $1524 = _js_NewSrcNote($cx, $cg, 9);
    HEAP32[$noteIndex >> 2] = $1524;
    if (($1524 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 336;
      break;
    }
   case 336:
    var $1527 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 7, 0);
    if (($1527 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 337;
      break;
    }
   case 337:
    var $1532 = HEAP32[$pn + 36 >> 2];
    var $1533 = _js_EmitTree($cx, $cg, $1532);
    if (($1533 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 338;
      break;
    }
   case 338:
    var $1536 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 6, 0);
    if (($1536 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 339;
      break;
    }
   case 339:
    var $1539 = HEAP32[$8 >> 2];
    var $1541 = HEAP32[$1539 >> 2];
    var $1542 = $1541 + $1527 | 0;
    var $1547 = HEAP32[$1539 + 8 >> 2] - ($1541 + $1527) | 0;
    var $1548 = _js_SetJumpOffset($cx, $cg, $1542, $1547);
    if (($1548 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 340;
      break;
    }
   case 340:
    var $1551 = $cg + 192 | 0;
    var $1553 = HEAP32[$1551 >> 2] - 1 | 0;
    HEAP32[$1551 >> 2] = $1553;
    var $1556 = HEAP32[$pn + 40 >> 2];
    var $1557 = _js_EmitTree($cx, $cg, $1556);
    if (($1557 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 341;
      break;
    }
   case 341:
    var $1560 = HEAP32[$8 >> 2];
    var $1562 = HEAP32[$1560 >> 2];
    var $1563 = $1562 + $1536 | 0;
    var $1568 = HEAP32[$1560 + 8 >> 2] - ($1562 + $1536) | 0;
    var $1569 = _js_SetJumpOffset($cx, $cg, $1563, $1568);
    if (($1569 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 342;
      break;
    }
   case 342:
    var $1572 = HEAP32[$noteIndex >> 2];
    var $1573 = $1536 - $1527 | 0;
    var $1574 = _js_SetSrcNoteOffset($cx, $cg, $1572, 0, $1573);
    if (($1574 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 343:
    var $1577 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 2);
    var $1578 = $pn + 32 | 0;
    var $1579 = HEAP32[$1578 >> 2];
    var $1580 = _js_EmitTree($cx, $cg, $1579);
    var $1581 = ($1580 | 0) == 0;
    if ($1577) {
      __label__ = 344;
      break;
    } else {
      __label__ = 349;
      break;
    }
   case 344:
    if ($1581) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 345;
      break;
    }
   case 345:
    var $1584 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 152, 0);
    if (($1584 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 346;
      break;
    }
   case 346:
    var $1589 = HEAP32[$pn + 36 >> 2];
    var $1590 = _js_EmitTree($cx, $cg, $1589);
    if (($1590 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 347;
      break;
    }
   case 347:
    var $1593 = HEAP32[$8 >> 2];
    var $1597 = HEAP32[$1593 >> 2];
    var $1600 = $1597 + $1584 | 0;
    var $1602 = HEAP32[$1593 + 8 >> 2] - $1584 - $1597 | 0;
    var $1603 = _js_SetJumpOffset($cx, $cg, $1600, $1602);
    if (($1603 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 348;
      break;
    }
   case 348:
    var $1606 = __ZNK11JSParseNode5getOpEv($pn);
    HEAP8[$1600] = $1606 & 255;
    var $ok_059 = 1;
    var $_560 = $pn;
    __label__ = 609;
    break;
   case 349:
    if ($1581) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 350;
      break;
    }
   case 350:
    var $1610 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 152, 0);
    if (($1610 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $jmp_2 = $1610;
      var $pn2_4 = $1579;
      __label__ = 351;
      break;
    }
   case 351:
    var $pn2_4;
    var $jmp_2;
    var $1613 = HEAP32[$pn2_4 + 24 >> 2];
    var $1616 = (HEAP32[$1613 + 24 >> 2] | 0) == 0;
    var $1617 = _js_EmitTree($cx, $cg, $1613);
    var $1618 = ($1617 | 0) != 0;
    if ($1616) {
      __label__ = 355;
      break;
    } else {
      __label__ = 352;
      break;
    }
   case 352:
    if ($1618) {
      __label__ = 353;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 353:
    var $1621 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 152, 0);
    if (($1621 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 354;
      break;
    }
   case 354:
    var $1627 = HEAP32[HEAP32[$8 >> 2] >> 2] + $jmp_2 | 0;
    var $1628 = $1621 - $jmp_2 | 0;
    var $1629 = __ZL17SetBackPatchDeltaP9JSContextP15JSCodeGeneratorPhi($cx, $cg, $1627, $1628);
    if (($1629 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $jmp_2 = $1621;
      var $pn2_4 = $1613;
      __label__ = 351;
      break;
    }
   case 355:
    if ($1618) {
      __label__ = 356;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 356:
    var $1634 = HEAP32[$8 >> 2];
    var $1638 = HEAP32[$1634 >> 2];
    var $1641 = HEAP32[$1634 + 8 >> 2] - $1638 | 0;
    var $top_1 = $1610;
    var $pn2_5 = HEAP32[$1578 >> 2];
    var $1643 = $1638;
    __label__ = 357;
    break;
   case 357:
    var $1643;
    var $pn2_5;
    var $top_1;
    var $1644 = $1643 + $top_1 | 0;
    var $1645 = __ZL13GetJumpOffsetP15JSCodeGeneratorPh($cg, $1644);
    var $1646 = $1641 - $top_1 | 0;
    var $1647 = _js_SetJumpOffset($cx, $cg, $1644, $1646);
    if (($1647 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 358;
      break;
    }
   case 358:
    var $1650 = __ZNK11JSParseNode5getOpEv($pn);
    HEAP8[$1644] = $1650 & 255;
    var $1653 = HEAP32[$pn2_5 + 24 >> 2];
    if ((HEAP32[$1653 + 24 >> 2] | 0) == 0) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    } else {
      __label__ = 359;
      break;
    }
   case 359:
    var $top_1 = $1645 + $top_1 | 0;
    var $pn2_5 = $1653;
    var $1643 = HEAP32[HEAP32[$8 >> 2] >> 2];
    __label__ = 357;
    break;
   case 360:
    var $1659 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 5);
    if ($1659) {
      __label__ = 361;
      break;
    } else {
      __label__ = 366;
      break;
    }
   case 361:
    var $1662 = HEAP32[$pn + 32 >> 2];
    var $1663 = _js_EmitTree($cx, $cg, $1662);
    if (($1663 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 362;
      break;
    }
   case 362:
    var $1666 = __ZNK11JSParseNode5getOpEv($pn);
    HEAP32[$op >> 2] = $1666;
    var $pn2_6 = $1662;
    __label__ = 363;
    break;
   case 363:
    var $pn2_6;
    var $1669 = HEAP32[$pn2_6 + 24 >> 2];
    if (($1669 | 0) == 0) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    } else {
      __label__ = 364;
      break;
    }
   case 364:
    var $1672 = _js_EmitTree($cx, $cg, $1669);
    if (($1672 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 365;
      break;
    }
   case 365:
    var $1675 = HEAP32[$op >> 2];
    var $1676 = _js_Emit1($cx, $cg, $1675);
    if (($1676 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $pn2_6 = $1669;
      __label__ = 363;
      break;
    }
   case 366:
    var $1679 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 6);
    if ($1679) {
      __label__ = 367;
      break;
    } else {
      __label__ = 369;
      break;
    }
   case 367:
    var $pn_idx2_val = HEAP32[$pn + 36 >> 2];
    var $1681 = __ZNK11JSParseNode4exprEv($pn_idx2_val);
    var $1682 = _js_EmitTree($cx, $cg, $1681);
    if (($1682 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 368;
      break;
    }
   case 368:
    var $1685 = __ZNK11JSParseNode5getOpEv($pn);
    var $1686 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, $1685, $cg, 0);
    if ($1686) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 369:
    var $1688 = $cg | 0;
    var $1689 = HEAP32[$1688 >> 2];
    var $1690 = $1689 & -17;
    HEAP32[$1688 >> 2] = $1690;
    var $1692 = HEAP32[$pn + 32 >> 2];
    var $1693 = _js_EmitTree($cx, $cg, $1692);
    if (($1693 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 370;
      break;
    }
   case 370:
    var $1698 = HEAP32[$pn + 36 >> 2];
    var $1699 = _js_EmitTree($cx, $cg, $1698);
    if (($1699 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 371;
      break;
    }
   case 371:
    var $1704 = HEAP32[$1688 >> 2] | $1689 & 16;
    HEAP32[$1688 >> 2] = $1704;
    var $1705 = __ZNK11JSParseNode5getOpEv($pn);
    var $1706 = _js_Emit1($cx, $cg, $1705);
    if (($1706 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 372:
    var $1709 = __ZNK11JSParseNode5getOpEv($pn);
    HEAP32[$op >> 2] = $1709;
    var $pn_idx22_val = HEAP32[$pn + 32 >> 2];
    if (($1709 | 0) == 174) {
      __label__ = 373;
      break;
    } else if (($1709 | 0) == 39) {
      __label__ = 374;
      break;
    } else {
      __label__ = 376;
      break;
    }
   case 373:
    var $1711 = __ZL11EmitXMLNameP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn_idx22_val, 174, $cg);
    if (($1711 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 374:
    var $1714 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_idx22_val, 29);
    if ($1714) {
      __label__ = 376;
      break;
    } else {
      __label__ = 375;
      break;
    }
   case 375:
    HEAP32[$op >> 2] = 200;
    __label__ = 376;
    break;
   case 376:
    var $1717 = $cg | 0;
    var $1718 = HEAP32[$1717 >> 2];
    var $1719 = $1718 & -17;
    HEAP32[$1717 >> 2] = $1719;
    var $1720 = _js_EmitTree($cx, $cg, $pn_idx22_val);
    if (($1720 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 377;
      break;
    }
   case 377:
    var $1725 = HEAP32[$1717 >> 2] | $1718 & 16;
    HEAP32[$1717 >> 2] = $1725;
    var $1726 = HEAP32[$op >> 2];
    var $1727 = _js_Emit1($cx, $cg, $1726);
    if (($1727 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 378:
    var $1731 = HEAPU32[$pn + 32 >> 2];
    var $1732 = __ZNK11JSParseNode5getOpEv($pn);
    HEAP32[$op >> 2] = $1732;
    var $1733 = __ZNK11JSParseNode7getKindEv($1731);
    if (($1733 | 0) == 22) {
      __label__ = 393;
      break;
    } else if (($1733 | 0) == 23) {
      __label__ = 394;
      break;
    } else if (($1733 | 0) == 27) {
      __label__ = 395;
      break;
    } else if (($1733 | 0) == 19) {
      __label__ = 400;
      break;
    } else {
      __label__ = 379;
      break;
    }
   case 379:
    __ZN11JSParseNode5setOpE4JSOp($1731, $1732);
    var $1735 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $1731);
    if (($1735 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 380;
      break;
    }
   case 380:
    var $1738 = __ZNK11JSParseNode5getOpEv($1731);
    HEAP32[$op >> 2] = $1738;
    if (($1738 | 0) == 131) {
      __label__ = 381;
      break;
    } else {
      __label__ = 382;
      break;
    }
   case 381:
    var $1741 = _js_Emit1($cx, $cg, 131);
    if (($1741 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 388;
      break;
    }
   case 382:
    var $_idx9_val = HEAP32[$1731 + 40 >> 2];
    var $1745 = __ZNK2js11UpvarCookie6isFreeEv($_idx9_val);
    if ($1745) {
      __label__ = 385;
      break;
    } else {
      __label__ = 383;
      break;
    }
   case 383:
    var $1747 = __ZNK2js11UpvarCookie9asIntegerEv($_idx9_val);
    var $1749 = $1747 >>> 8 & 255;
    var $1750 = $1747 & 255;
    var $1751 = _js_Emit3($cx, $cg, $1738, $1749, $1750);
    if (($1751 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 384;
      break;
    }
   case 384:
    var $1754 = HEAP32[$op >> 2];
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, $1754);
    __label__ = 388;
    break;
   case 385:
    if ((HEAP32[_js_CodeSpec + ($1738 << 3) + 4 >> 2] & 3072 | 0) == 0) {
      __label__ = 387;
      break;
    } else {
      __label__ = 386;
      break;
    }
   case 386:
    var $1761 = __ZL14EmitNameIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $1731, $1738, $cg);
    if ($1761) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 387:
    var $1763 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $1731, $1738, $cg, 0);
    if ($1763) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 388:
    var $1765 = __ZNK11JSParseNode7isConstEv($1731);
    if ($1765) {
      __label__ = 389;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 389:
    var $1767 = _js_Emit1($cx, $cg, 35);
    if (($1767 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 390;
      break;
    }
   case 390:
    var $1770 = __ZNK11JSParseNode5getOpEv($pn);
    HEAP32[$op >> 2] = $1770;
    if ((HEAP32[_js_CodeSpec + ($1770 << 3) + 4 >> 2] & 4096 | 0) == 0) {
      __label__ = 391;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 391:
    var $1776 = _js_Emit1($cx, $cg, 63);
    if (($1776 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 392;
      break;
    }
   case 392:
    var $1785 = (HEAPU32[_js_CodeSpec + (HEAP32[$op >> 2] << 3) + 4 >> 2] >>> 11 & 1 ^ 1) + 27 | 0;
    HEAP32[$op >> 2] = $1785;
    var $1786 = _js_Emit1($cx, $cg, $1785);
    if (($1786 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 393:
    var $1789 = __ZL14EmitPropIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $1731, $1732, $cg);
    if ($1789) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 394:
    var $1791 = __ZL14EmitElemIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $1731, $1732, $cg);
    if ($1791) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 395:
    var $1793 = _js_EmitTree($cx, $cg, $1731);
    if (($1793 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 396;
      break;
    }
   case 396:
    var $1796 = HEAP32[$8 >> 2];
    var $1806 = HEAP32[$1796 + 8 >> 2] - HEAP32[$1731 + 20 >> 2] - HEAP32[$1796 >> 2] | 0;
    var $1807 = _js_NewSrcNote2($cx, $cg, 12, $1806);
    if (($1807 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 397;
      break;
    }
   case 397:
    var $1810 = HEAP32[$op >> 2];
    var $1811 = _js_Emit1($cx, $cg, $1810);
    if (($1811 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 398;
      break;
    }
   case 398:
    var $1814 = _js_Emit1($cx, $cg, 1);
    if (($1814 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 399;
      break;
    }
   case 399:
    var $1817 = _js_Emit1($cx, $cg, 81);
    if (($1817 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 400:
    var $1821 = HEAP32[$1731 + 32 >> 2];
    var $1822 = _js_EmitTree($cx, $cg, $1821);
    if (($1822 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 401;
      break;
    }
   case 401:
    var $1825 = _js_Emit1($cx, $cg, 172);
    if (($1825 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 402;
      break;
    }
   case 402:
    var $1828 = HEAP32[$op >> 2];
    var $1829 = __ZL14EmitElemIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, 0, $1828, $cg);
    if ($1829) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 403:
    var $1832 = HEAP32[$pn + 32 >> 2];
    var $1833 = __ZNK11JSParseNode7getKindEv($1832);
    if (($1833 | 0) == 29) {
      __label__ = 404;
      break;
    } else if (($1833 | 0) == 22) {
      __label__ = 408;
      break;
    } else if (($1833 | 0) == 73) {
      __label__ = 409;
      break;
    } else if (($1833 | 0) == 23) {
      __label__ = 410;
      break;
    } else {
      __label__ = 411;
      break;
    }
   case 404:
    var $1835 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $1832);
    if (($1835 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 405;
      break;
    }
   case 405:
    var $1838 = __ZNK11JSParseNode5getOpEv($1832);
    HEAP32[$op >> 2] = $1838;
    if (($1838 | 0) == 66) {
      __label__ = 406;
      break;
    } else {
      __label__ = 407;
      break;
    }
   case 406:
    var $1841 = _js_Emit1($cx, $cg, 66);
    if (($1841 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 407:
    var $1844 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $1832, $1838, $cg, 0);
    if ($1844) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 408:
    var $1846 = __ZL10EmitPropOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratoriPS3_($cx, $1832, 37, $cg, 0, 0);
    if (($1846 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 409:
    var $1849 = __ZL10EmitElemOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $1832, 186, $cg);
    if (($1849 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 410:
    var $1852 = __ZL10EmitElemOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $1832, 38, $cg);
    if (($1852 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 411:
    HEAP32[$useful >> 2] = 0;
    var $1855 = __ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi($cx, $cg, $1832, $useful);
    if (($1855 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 412;
      break;
    }
   case 412:
    if ((HEAP32[$useful >> 2] | 0) == 0) {
      __label__ = 413;
      break;
    } else {
      __label__ = 414;
      break;
    }
   case 413:
    HEAP32[$noteIndex >> 2] = -1;
    var $off_1 = -1;
    __label__ = 417;
    break;
   case 414:
    var $1862 = _js_EmitTree($cx, $cg, $1832);
    if (($1862 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 415;
      break;
    }
   case 415:
    var $1865 = HEAP32[$8 >> 2];
    var $1867 = HEAP32[$1865 + 8 >> 2];
    var $1869 = HEAP32[$1865 >> 2];
    var $1870 = _js_NewSrcNote2($cx, $cg, 7, 0);
    HEAP32[$noteIndex >> 2] = $1870;
    if (($1870 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 416;
      break;
    }
   case 416:
    var $1875 = $1867 - $1869 | 0;
    var $1876 = _js_Emit1($cx, $cg, 81);
    if (($1876 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $off_1 = $1875;
      __label__ = 417;
      break;
    }
   case 417:
    var $off_1;
    var $1879 = _js_Emit1($cx, $cg, 67);
    if (($1879 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 418;
      break;
    }
   case 418:
    var $1882 = HEAP32[$noteIndex >> 2];
    if (($1882 | 0) > -1) {
      __label__ = 419;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 419:
    var $1885 = HEAP32[$8 >> 2];
    var $1893 = HEAP32[$1885 + 8 >> 2] - $off_1 - HEAP32[$1885 >> 2] | 0;
    var $1894 = _js_SetSrcNoteOffset($cx, $cg, $1882, 0, $1893);
    if (($1894 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 420:
    var $1898 = HEAP32[$pn + 32 >> 2];
    var $1899 = _js_EmitTree($cx, $cg, $1898);
    if (($1899 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 421;
      break;
    }
   case 421:
    var $1902 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 176, 0);
    if (($1902 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 422;
      break;
    }
   case 422:
    var $1905 = $pn + 36 | 0;
    var $1907 = HEAP32[$1905 >> 2];
    var $1908 = __ZL11EmitTraceOpP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $1907);
    if (($1908 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 423;
      break;
    }
   case 423:
    var $1912 = HEAP32[$1905 >> 2];
    var $1913 = _js_EmitTree($cx, $cg, $1912);
    if (($1913 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 424;
      break;
    }
   case 424:
    var $1916 = HEAP32[$8 >> 2];
    var $1918 = HEAP32[$1916 >> 2];
    var $1919 = $1918 + $1902 | 0;
    var $1924 = HEAP32[$1916 + 8 >> 2] - ($1918 + $1902) | 0;
    var $1925 = _js_SetJumpOffset($cx, $cg, $1919, $1924);
    if (($1925 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 425;
      break;
    }
   case 425:
    var $1928 = HEAP32[$8 >> 2];
    var $1936 = $1908 - HEAP32[$1928 + 8 >> 2] + HEAP32[$1928 >> 2] | 0;
    var $1937 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 177, $1936);
    if (($1937 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 426;
      break;
    }
   case 426:
    var $1940 = __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($1940 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 427:
    var $1943 = __ZNK11JSParseNode5getOpEv($pn);
    var $1944 = __ZL10EmitPropOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratoriPS3_($cx, $pn, $1943, $cg, 0, 0);
    var $_5 = $pn;
    var $ok_0 = $1944;
    __label__ = 608;
    break;
   case 428:
    var $1946 = __ZNK11JSParseNode5getOpEv($pn);
    var $1947 = __ZL10EmitElemOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn, $1946, $cg);
    var $_5 = $pn;
    var $ok_0 = $1947;
    __label__ = 608;
    break;
   case 429:
    var $1949 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 27);
    var $1951 = HEAPU32[$pn + 32 >> 2];
    var $1952 = __ZNK11JSParseNode7getKindEv($1951);
    if (($1952 | 0) == 29) {
      __label__ = 430;
      break;
    } else if (($1952 | 0) == 22) {
      __label__ = 431;
      break;
    } else if (($1952 | 0) == 23) {
      __label__ = 432;
      break;
    } else if (($1952 | 0) == 19) {
      __label__ = 433;
      break;
    } else {
      __label__ = 435;
      break;
    }
   case 430:
    var $1954 = $1949 & 1;
    var $1955 = __ZL10EmitNameOpP9JSContextP15JSCodeGeneratorP11JSParseNodei($cx, $cg, $1951, $1954);
    if (($1955 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 436;
      break;
    }
   case 431:
    var $1958 = __ZNK11JSParseNode5getOpEv($1951);
    var $1959 = $1949 & 1;
    var $1960 = __ZL10EmitPropOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratoriPS3_($cx, $1951, $1958, $cg, $1959, 0);
    if (($1960 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 436;
      break;
    }
   case 432:
    var $1963 = $1949 ? 196 : 55;
    var $1964 = __ZL10EmitElemOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $1951, $1963, $cg);
    if (($1964 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 436;
      break;
    }
   case 433:
    var $1967 = __ZNK11JSParseNode4isOpE4JSOp($1951, 174);
    if ($1967) {
      __label__ = 434;
      break;
    } else {
      __label__ = 435;
      break;
    }
   case 434:
    var $_idx21_val = HEAP32[$1951 + 32 >> 2];
    var $1969 = __ZL11EmitXMLNameP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $_idx21_val, 199, $cg);
    if (($1969 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 438;
      break;
    }
   case 435:
    var $1972 = _js_EmitTree($cx, $cg, $1951);
    if (($1972 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 437;
      break;
    }
   case 436:
    if ($1949) {
      __label__ = 438;
      break;
    } else {
      __label__ = 437;
      break;
    }
   case 437:
    var $1975 = _js_Emit1($cx, $cg, 1);
    if (($1975 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 438;
      break;
    }
   case 438:
    var $1977 = $cg | 0;
    var $1978 = HEAP32[$1977 >> 2];
    var $1979 = $1978 & -17;
    HEAP32[$1977 >> 2] = $1979;
    var $_pn28 = $1951;
    __label__ = 439;
    break;
   case 439:
    var $_pn28;
    var $pn3_1 = HEAP32[$_pn28 + 24 >> 2];
    if (($pn3_1 | 0) == 0) {
      __label__ = 441;
      break;
    } else {
      __label__ = 440;
      break;
    }
   case 440:
    var $1983 = _js_EmitTree($cx, $cg, $pn3_1);
    if (($1983 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $_pn28 = $pn3_1;
      __label__ = 439;
      break;
    }
   case 441:
    var $1988 = HEAP32[$1977 >> 2] | $1978 & 16;
    HEAP32[$1977 >> 2] = $1988;
    var $1989 = HEAP32[$8 >> 2];
    var $1997 = HEAP32[$1989 + 8 >> 2] - $16 - HEAP32[$1989 >> 2] | 0;
    var $1998 = _js_NewSrcNote2($cx, $cg, 12, $1997);
    if (($1998 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 442;
      break;
    }
   case 442:
    var $2003 = HEAP32[$pn + 40 >> 2] - 1 | 0;
    var $2004 = __ZNK11JSParseNode5getOpEv($pn);
    var $2006 = $2003 >>> 8 & 255;
    var $2007 = $2003 & 255;
    var $2008 = _js_Emit3($cx, $cg, $2004, $2006, $2007);
    if (($2008 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 443;
      break;
    }
   case 443:
    var $2011 = __ZNK11JSParseNode5getOpEv($pn);
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, $2011);
    var $2012 = __ZNK11JSParseNode4isOpE4JSOp($pn, 123);
    if ($2012) {
      __label__ = 444;
      break;
    } else {
      __label__ = 446;
      break;
    }
   case 444:
    var $2014 = HEAPU32[$18 >> 2];
    var $2016 = $2014 >>> 8 & 255;
    var $2017 = $2014 & 255;
    var $2018 = _js_Emit3($cx, $cg, 119, $2016, $2017);
    if (($2018 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 445;
      break;
    }
   case 445:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, 119);
    var $2021 = __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($2021 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 446;
      break;
    }
   case 446:
    if ((HEAP32[$pn + 44 >> 2] & 256 | 0) == 0) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    } else {
      __label__ = 447;
      break;
    }
   case 447:
    var $2030 = _js_Emit1($cx, $cg, 74);
    if (($2030 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 448:
    var $2035 = HEAPU32[$pn + 32 >> 2];
    var $2036 = $cg | 0;
    var $2037 = HEAP32[$8 >> 2];
    var $2044 = HEAP32[$2037 + 8 >> 2] - HEAP32[$2037 >> 2] | 0;
    _js_PushBlockScope($2036, $stmtInfo, $2035, $2044);
    HEAP32[$noteIndex >> 2] = -1;
    var $pn_idx = $pn + 36 | 0;
    var $pn_idx_val = HEAP32[$pn_idx >> 2];
    var $2045 = __ZNK11JSParseNode4exprEv($pn_idx_val);
    var $2046 = __ZNK11JSParseNode7getKindEv($2045);
    if (($2046 | 0) == 81 || ($2046 | 0) == 54 || ($2046 | 0) == 42) {
      __label__ = 453;
      break;
    } else {
      __label__ = 449;
      break;
    }
   case 449:
    var $2049 = HEAP32[$stmtInfo + 24 >> 2];
    if (($2049 | 0) == 0) {
      __label__ = 450;
      break;
    } else {
      __label__ = 451;
      break;
    }
   case 450:
    var $_idx5_val = HEAP32[$cg >> 2];
    var $2052 = __ZNK13JSTreeContext10inFunctionEv($_idx5_val);
    if ($2052) {
      __label__ = 453;
      break;
    } else {
      __label__ = 452;
      break;
    }
   case 451:
    if (HEAP16[$2049 >> 1] << 16 >> 16 == 4) {
      __label__ = 452;
      break;
    } else {
      __label__ = 453;
      break;
    }
   case 452:
    var $2058 = _js_NewSrcNote2($cx, $cg, 10, 0);
    HEAP32[$noteIndex >> 2] = $2058;
    if (($2058 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 453;
      break;
    }
   case 453:
    var $2061 = __ZL14EmitEnterBlockP9JSContextP11JSParseNodeP15JSCodeGenerator($cx, $pn, $cg);
    if ($2061) {
      __label__ = 454;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 454:
    var $2064 = HEAP32[$pn_idx >> 2];
    var $2065 = _js_EmitTree($cx, $cg, $2064);
    if (($2065 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 455;
      break;
    }
   case 455:
    var $2068 = __ZNK11JSParseNode5getOpEv($pn);
    HEAP32[$op >> 2] = $2068;
    if (($2068 | 0) == 210) {
      __label__ = 456;
      break;
    } else {
      __label__ = 457;
      break;
    }
   case 456:
    var $2071 = HEAP32[$8 >> 2];
    var $2079 = HEAP32[$2071 + 8 >> 2] - $16 - HEAP32[$2071 >> 2] | 0;
    var $2080 = _js_NewSrcNote2($cx, $cg, 12, $2079);
    if (($2080 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 459;
      break;
    }
   case 457:
    var $2083 = HEAP32[$noteIndex >> 2];
    if (($2083 | 0) > -1) {
      __label__ = 458;
      break;
    } else {
      __label__ = 459;
      break;
    }
   case 458:
    var $2086 = HEAP32[$8 >> 2];
    var $2094 = HEAP32[$2086 + 8 >> 2] - $16 - HEAP32[$2086 >> 2] | 0;
    var $2095 = _js_SetSrcNoteOffset($cx, $cg, $2083, 0, $2094);
    if (($2095 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 459;
      break;
    }
   case 459:
    var $2097 = HEAP32[$op >> 2];
    var $2098 = __ZL14EmitLeaveBlockP9JSContextP15JSCodeGenerator4JSOpP11JSObjectBox($cx, $cg, $2097, $2035);
    if (($2098 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 460;
      break;
    }
   case 460:
    var $2101 = _js_PopStatementCG($cx, $cg);
    var $_5 = $pn;
    var $ok_0 = $2101;
    __label__ = 608;
    break;
   case 461:
    var $2103 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 2);
    if ($2103) {
      __label__ = 463;
      break;
    } else {
      __label__ = 462;
      break;
    }
   case 462:
    __ZN12TempPopScopeC1Ev($tps7);
    var $_249 = $pn;
    __label__ = 464;
    break;
   case 463:
    var $2106 = HEAP32[$pn + 36 >> 2];
    var $2107 = $2106;
    var $2109 = HEAP32[$pn + 32 >> 2];
    __ZN12TempPopScopeC1Ev($tps7);
    if (($2106 | 0) == 0) {
      var $_249 = $2109;
      __label__ = 464;
      break;
    } else {
      var $2116 = 1;
      var $_25053 = $2109;
      var $pn2_74855 = $2107;
      __label__ = 465;
      break;
    }
   case 464:
    var $_249;
    if ((HEAP32[$cg >> 2] & 16 | 0) == 0) {
      var $2120 = 0;
      var $_25052 = $_249;
      var $pn2_74854 = 0;
      var $2119 = 0;
      __label__ = 466;
      break;
    } else {
      var $2116 = 0;
      var $_25053 = $_249;
      var $pn2_74855 = 0;
      __label__ = 465;
      break;
    }
   case 465:
    var $pn2_74855;
    var $_25053;
    var $2116;
    var $2117 = __ZN12TempPopScope8popBlockEP9JSContextP15JSCodeGenerator($tps7, $cx, $cg);
    if ($2117) {
      var $2120 = $2116;
      var $_25052 = $_25053;
      var $pn2_74854 = $pn2_74855;
      var $2119 = 1;
      __label__ = 466;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 466:
    var $2119;
    var $pn2_74854;
    var $_25052;
    var $2120;
    var $2122 = __ZL13EmitVariablesP9JSContextP15JSCodeGeneratorP11JSParseNodeiPi($cx, $cg, $_25052, $2120 & 1, $noteIndex);
    if (($2122 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 467;
      break;
    }
   case 467:
    var $2125 = HEAP32[$8 >> 2];
    var $2130 = HEAP32[$2125 + 8 >> 2];
    var $2131 = HEAP32[$2125 >> 2];
    if ($2119) {
      __label__ = 468;
      break;
    } else {
      __label__ = 469;
      break;
    }
   case 468:
    var $2133 = __ZN12TempPopScope11repushBlockEP9JSContextP15JSCodeGenerator($tps7, $cx, $cg);
    if ($2133) {
      __label__ = 469;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 469:
    if ($2120) {
      __label__ = 470;
      break;
    } else {
      __label__ = 471;
      break;
    }
   case 470:
    var $2136 = _js_EmitTree($cx, $cg, $pn2_74854);
    if (($2136 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 471;
      break;
    }
   case 471:
    var $2139 = HEAP32[$noteIndex >> 2];
    if (($2139 | 0) > -1) {
      __label__ = 472;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $_25052;
      __label__ = 609;
      break;
    }
   case 472:
    var $2142 = HEAP32[$8 >> 2];
    var $2151 = $2131 - $2130 + HEAP32[$2142 + 8 >> 2] - HEAP32[$2142 >> 2] | 0;
    var $2152 = _js_SetSrcNoteOffset($cx, $cg, $2139, 0, $2151);
    if (($2152 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $_25052;
      __label__ = 609;
      break;
    }
   case 473:
    var $2156 = HEAP32[$pn + 32 >> 2];
    var $2157 = _js_EmitTree($cx, $cg, $2156);
    if (($2157 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 474;
      break;
    }
   case 474:
    var $2161 = HEAP32[$cg + 232 >> 2];
    var $2162 = __ZL15AdjustBlockSlotP9JSContextP15JSCodeGeneratori($cg, $2161);
    if (($2162 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 475;
      break;
    }
   case 475:
    var $2165 = __ZNK11JSParseNode5getOpEv($pn);
    var $2167 = $2162 >>> 8 & 255;
    var $2168 = $2162 & 255;
    var $2169 = _js_Emit3($cx, $cg, $2165, $2167, $2168);
    if (($2169 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 476;
      break;
    }
   case 476:
    var $2172 = __ZNK11JSParseNode5getOpEv($pn);
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, $2172);
    var $ok_059 = 1;
    var $_560 = $pn;
    __label__ = 609;
    break;
   case 477:
    var $sharpnum_0;
    var $_3;
    var $2174 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($_3, 78);
    if ($2174) {
      __label__ = 478;
      break;
    } else {
      __label__ = 481;
      break;
    }
   case 478:
    var $2176 = __ZL11EmitNewInitP9JSContextP15JSCodeGenerator10JSProtoKeyP11JSParseNodei($cx, $cg, 3, $_3, $sharpnum_0);
    if ($2176) {
      __label__ = 479;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 479:
    var $2178 = $cg + 232 | 0;
    var $2179 = HEAP32[$2178 >> 2];
    var $2182 = HEAP32[$cg + 192 >> 2] - 1 | 0;
    HEAP32[$2178 >> 2] = $2182;
    var $2184 = HEAP32[$_3 + 32 >> 2];
    var $2185 = _js_EmitTree($cx, $cg, $2184);
    if (($2185 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 480;
      break;
    }
   case 480:
    HEAP32[$2178 >> 2] = $2179;
    var $2188 = __ZL11EmitEndInitP9JSContextP15JSCodeGeneratorj($cx, $cg, 1);
    if ($2188) {
      var $ok_059 = 1;
      var $_560 = $_3;
      __label__ = 609;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 481:
    var $cg_idx15 = $cg | 0;
    var $cg_idx15_val = HEAP32[$cg_idx15 >> 2];
    var $2190 = __ZNK15JSCodeGenerator9hasSharpsEv($cg_idx15_val);
    if ($2190) {
      var $cg_idx14_val = $cg_idx15_val;
      __label__ = 487;
      break;
    } else {
      __label__ = 482;
      break;
    }
   case 482:
    if ((HEAP32[$_3 + 44 >> 2] & 2048 | 0) == 0) {
      __label__ = 483;
      break;
    } else {
      var $cg_idx14_val = $cg_idx15_val;
      __label__ = 487;
      break;
    }
   case 483:
    if ((HEAP32[$_3 + 32 >> 2] | 0) == 0) {
      var $cg_idx14_val = $cg_idx15_val;
      __label__ = 487;
      break;
    } else {
      __label__ = 484;
      break;
    }
   case 484:
    var $2202 = __ZN15JSCodeGenerator21checkSingletonContextEv($cg);
    if ($2202) {
      __label__ = 486;
      break;
    } else {
      __label__ = 485;
      break;
    }
   case 485:
    var $cg_idx14_val = HEAP32[$cg_idx15 >> 2];
    __label__ = 487;
    break;
   case 486:
    var $2204 = __ZL24EmitSingletonInitialiserP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $_3);
    if ($2204) {
      var $ok_059 = 1;
      var $_560 = $_3;
      __label__ = 609;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 487:
    var $cg_idx14_val;
    var $2206 = __ZNK15JSCodeGenerator9hasSharpsEv($cg_idx14_val);
    if ($2206) {
      __label__ = 488;
      break;
    } else {
      __label__ = 489;
      break;
    }
   case 488:
    var $2208 = __ZL11EmitNewInitP9JSContextP15JSCodeGenerator10JSProtoKeyP11JSParseNodei($cx, $cg, 3, $_3, $sharpnum_0);
    if ($2208) {
      __label__ = 491;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 489:
    var $2210 = _js_EmitN($cx, $cg, 90, 3);
    if (($2210 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 490;
      break;
    }
   case 490:
    var $2215 = HEAPU32[HEAP32[$8 >> 2] >> 2];
    var $2216 = $_3 + 40 | 0;
    HEAP8[$2210 + ($2215 + 1) | 0] = HEAPU32[$2216 >> 2] >>> 16 & 255;
    HEAP8[$2210 + ($2215 + 2) | 0] = HEAPU32[$2216 >> 2] >>> 8 & 255;
    HEAP8[$2210 + ($2215 + 3) | 0] = HEAP32[$2216 >> 2] & 255;
    __label__ = 491;
    break;
   case 491:
    var $pn2_8_in = $_3 + 32 | 0;
    var $atomIndex_0 = 0;
    __label__ = 492;
    break;
   case 492:
    var $atomIndex_0;
    var $pn2_8_in;
    var $pn2_8 = HEAPU32[$pn2_8_in >> 2];
    if (($pn2_8 | 0) == 0) {
      __label__ = 500;
      break;
    } else {
      __label__ = 493;
      break;
    }
   case 493:
    var $2234 = __ZL12EmitNumberOpP9JSContextdP15JSCodeGenerator($cx, $atomIndex_0 >>> 0, $cg);
    if (($2234 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 494;
      break;
    }
   case 494:
    var $2237 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_8, 3);
    if ($2237) {
      __label__ = 495;
      break;
    } else {
      __label__ = 497;
      break;
    }
   case 495:
    var $2239 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn2_8, 0);
    if ($2239) {
      __label__ = 496;
      break;
    } else {
      __label__ = 497;
      break;
    }
   case 496:
    var $2241 = _js_Emit1($cx, $cg, 221);
    if (($2241 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 498;
      break;
    }
   case 497:
    var $2244 = _js_EmitTree($cx, $cg, $pn2_8);
    if (($2244 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 498;
      break;
    }
   case 498:
    var $2247 = _js_Emit1($cx, $cg, 94);
    if (($2247 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 499;
      break;
    }
   case 499:
    var $pn2_8_in = $pn2_8 + 24 | 0;
    var $atomIndex_0 = $atomIndex_0 + 1 | 0;
    __label__ = 492;
    break;
   case 500:
    if ((HEAP32[$_3 + 44 >> 2] & 16 | 0) == 0) {
      __label__ = 502;
      break;
    } else {
      __label__ = 501;
      break;
    }
   case 501:
    var $2259 = _js_NewSrcNote($cx, $cg, 5);
    if (($2259 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 502;
      break;
    }
   case 502:
    var $2262 = __ZL11EmitEndInitP9JSContextP15JSCodeGeneratorj($cx, $cg, $atomIndex_0);
    if ($2262) {
      var $ok_059 = 1;
      var $_560 = $_3;
      __label__ = 609;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 503:
    var $sharpnum_1;
    var $_4;
    var $2264 = $_4 + 32 | 0;
    var $2267 = HEAP32[$_4 + 44 >> 2];
    if (($2267 & 512 | 0) == 0) {
      __label__ = 505;
      break;
    } else {
      __label__ = 504;
      break;
    }
   case 504:
    var $2273 = HEAP32[$cg + 48 >> 2] + 40 | 0;
    var $2274 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($2273, $_4, 0, 224, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 614;
    break;
   case 505:
    var $cg_idx13 = $cg | 0;
    var $cg_idx13_val = HEAP32[$cg_idx13 >> 2];
    var $2276 = __ZNK15JSCodeGenerator9hasSharpsEv($cg_idx13_val);
    if ($2276) {
      __label__ = 510;
      break;
    } else {
      __label__ = 506;
      break;
    }
   case 506:
    if (($2267 & 2048 | 0) == 0) {
      __label__ = 507;
      break;
    } else {
      __label__ = 510;
      break;
    }
   case 507:
    if ((HEAP32[$2264 >> 2] | 0) == 0) {
      __label__ = 510;
      break;
    } else {
      __label__ = 508;
      break;
    }
   case 508:
    var $2285 = __ZN15JSCodeGenerator21checkSingletonContextEv($cg);
    if ($2285) {
      __label__ = 509;
      break;
    } else {
      __label__ = 510;
      break;
    }
   case 509:
    var $2287 = __ZL24EmitSingletonInitialiserP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $_4);
    if ($2287) {
      var $ok_059 = 1;
      var $_560 = $_4;
      __label__ = 609;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 510:
    var $2288 = HEAP32[$8 >> 2];
    var $2295 = HEAP32[$2288 + 8 >> 2] - HEAP32[$2288 >> 2] | 0;
    var $2296 = __ZL11EmitNewInitP9JSContextP15JSCodeGenerator10JSProtoKeyP11JSParseNodei($cx, $cg, 1, $_4, $sharpnum_1);
    if ($2296) {
      __label__ = 511;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 511:
    var $cg_idx_val = HEAP32[$cg_idx13 >> 2];
    var $2298 = __ZNK15JSCodeGenerator9hasSharpsEv($cg_idx_val);
    if ($2298) {
      var $obj_0 = 0;
      __label__ = 514;
      break;
    } else {
      __label__ = 512;
      break;
    }
   case 512:
    var $2300 = __ZNK13JSTreeContext12compileAndGoEv($cg_idx_val);
    if ($2300) {
      __label__ = 513;
      break;
    } else {
      var $obj_0 = 0;
      __label__ = 514;
      break;
    }
   case 513:
    var $2303 = HEAP32[$_4 + 40 >> 2];
    var $2304 = __ZN2jsL17GuessObjectGCKindEjb1152($2303);
    var $2305 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1153($cx, $2304);
    if (($2305 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $obj_0 = $2305;
      __label__ = 514;
      break;
    }
   case 514:
    var $obj_0;
    var $2309 = $cx + 52 | 0;
    var $2310 = $cx;
    var $slowMethodInits_0 = 0;
    var $obj_1 = $obj_0;
    var $pn2_9_in = $2264 | 0;
    __label__ = 515;
    break;
   case 515:
    var $pn2_9_in;
    var $obj_1;
    var $slowMethodInits_0;
    var $pn2_9 = HEAPU32[$pn2_9_in >> 2];
    if (($pn2_9 | 0) == 0) {
      __label__ = 534;
      break;
    } else {
      __label__ = 516;
      break;
    }
   case 516:
    var $2315 = HEAPU32[$pn2_9 + 32 >> 2];
    var $2316 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($2315, 30);
    if ($2316) {
      __label__ = 517;
      break;
    } else {
      __label__ = 518;
      break;
    }
   case 517:
    var $2319 = $2315 + 32 | 0;
    var $2320 = (tempDoubleI32[0] = HEAP32[$2319 >> 2], tempDoubleI32[1] = HEAP32[$2319 + 4 >> 2], tempDoubleF64[0]);
    var $2321 = __ZL12EmitNumberOpP9JSContextdP15JSCodeGenerator($cx, $2320, $cg);
    if (($2321 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 518;
      break;
    }
   case 518:
    var $2324 = $pn2_9 + 36 | 0;
    var $2326 = HEAP32[$2324 >> 2];
    var $2327 = _js_EmitTree($cx, $cg, $2326);
    if (($2327 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 519;
      break;
    }
   case 519:
    var $2330 = __ZNK11JSParseNode5getOpEv($pn2_9);
    HEAP32[$op >> 2] = $2330;
    if (($2330 - 125 | 0) >>> 0 < 2) {
      __label__ = 520;
      break;
    } else {
      var $obj_2 = $obj_1;
      __label__ = 521;
      break;
    }
   case 520:
    var $2333 = _js_Emit1($cx, $cg, $2330);
    if (($2333 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $obj_2 = 0;
      __label__ = 521;
      break;
    }
   case 521:
    var $obj_2;
    var $2336 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($2315, 30);
    if ($2336) {
      __label__ = 522;
      break;
    } else {
      __label__ = 524;
      break;
    }
   case 522:
    var $2338 = _js_NewSrcNote($cx, $cg, 1);
    if (($2338 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 523;
      break;
    }
   case 523:
    var $2341 = _js_Emit1($cx, $cg, 94);
    if (($2341 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $slowMethodInits_2 = $slowMethodInits_0;
      var $obj_6 = 0;
      __label__ = 533;
      break;
    }
   case 524:
    var $2345 = $2315 + 32 | 0;
    var $2346 = HEAP32[$2345 >> 2];
    var $2347 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $2346, $index11);
    if ($2347) {
      __label__ = 525;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 525:
    var $2349 = HEAP32[$2324 >> 2];
    var $2350 = $2349;
    var $2351 = __ZNK11JSParseNode4isOpE4JSOp($2350, 130);
    if ((HEAP32[$op >> 2] | 0) != 93 | $2351 ^ 1) {
      __label__ = 528;
      break;
    } else {
      __label__ = 526;
      break;
    }
   case 526:
    var $2356 = HEAP32[$2349 + 32 >> 2];
    var $2357 = __ZNK13JSFunctionBox8joinableEv($2356);
    if ($2357) {
      __label__ = 527;
      break;
    } else {
      __label__ = 528;
      break;
    }
   case 527:
    HEAP32[$op >> 2] = 227;
    __ZN11JSParseNode5setOpE4JSOp($pn2_9, 227);
    var $obj_5 = 0;
    var $slowMethodInits_157 = $slowMethodInits_0;
    __label__ = 532;
    break;
   case 528:
    var $obj_3 = (HEAP32[$2345 >> 2] | 0) == (HEAP32[HEAP32[$2309 >> 2] + 210292 >> 2] | 0) ? 0 : $obj_2;
    HEAP32[$op >> 2] = 93;
    var $_slowMethodInits_0 = ($2351 & 1) + $slowMethodInits_0 | 0;
    if (($obj_3 | 0) == 0) {
      var $obj_5 = 0;
      var $slowMethodInits_157 = $_slowMethodInits_0;
      __label__ = 532;
      break;
    } else {
      __label__ = 529;
      break;
    }
   case 529:
    var $2368 = HEAP32[$2345 >> 2];
    var $2369 = __ZL12ATOM_TO_JSIDP6JSAtom1150($2368);
    __ZN2JSL14UndefinedValueEv1154($1);
    var $2370 = $obj_3;
    var $2371 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($2310, $2370, $2369, $1, 0, 0, 1, 0, 0, 0);
    if (($2371 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 530;
      break;
    }
   case 530:
    var $obj_3_idx_val = HEAP32[$obj_3 >> 2];
    var $2374 = __ZNK8JSObject16inDictionaryModeEv($obj_3_idx_val);
    if ($2374) {
      __label__ = 531;
      break;
    } else {
      var $obj_5 = $obj_3;
      var $slowMethodInits_157 = $_slowMethodInits_0;
      __label__ = 532;
      break;
    }
   case 531:
    var $obj_5 = 0;
    var $slowMethodInits_157 = $_slowMethodInits_0;
    __label__ = 532;
    break;
   case 532:
    var $slowMethodInits_157;
    var $obj_5;
    var $2376 = HEAP32[$op >> 2];
    var $2377 = HEAP32[$index11 >> 2];
    var $2378 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $2376, $2377, $cg, 0);
    if ($2378) {
      var $slowMethodInits_2 = $slowMethodInits_157;
      var $obj_6 = $obj_5;
      __label__ = 533;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 533:
    var $obj_6;
    var $slowMethodInits_2;
    var $slowMethodInits_0 = $slowMethodInits_2;
    var $obj_1 = $obj_6;
    var $pn2_9_in = $pn2_9 + 24 | 0;
    __label__ = 515;
    break;
   case 534:
    var $2383 = HEAP32[$cg + 80 >> 2];
    if (($2383 | 0) == 0) {
      var $obj_7 = $obj_1;
      __label__ = 537;
      break;
    } else {
      __label__ = 535;
      break;
    }
   case 535:
    var $2386 = __ZNK13JSFunctionBox13shouldUnbrandEjj($2383, $slowMethodInits_0);
    if ($2386) {
      __label__ = 536;
      break;
    } else {
      var $obj_7 = $obj_1;
      __label__ = 537;
      break;
    }
   case 536:
    var $2388 = _js_Emit1($cx, $cg, 228);
    if (($2388 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $obj_7 = 0;
      __label__ = 537;
      break;
    }
   case 537:
    var $obj_7;
    var $2392 = HEAP32[$_4 + 40 >> 2];
    var $2393 = __ZL11EmitEndInitP9JSContextP15JSCodeGeneratorj($cx, $cg, $2392);
    if ($2393) {
      __label__ = 538;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 538:
    if (($obj_7 | 0) == 0) {
      var $ok_059 = 1;
      var $_560 = $_4;
      __label__ = 609;
      break;
    } else {
      __label__ = 539;
      break;
    }
   case 539:
    var $2399 = HEAP32[$cg + 48 >> 2];
    var $2400 = __ZN2js6Parser12newObjectBoxEP8JSObject($2399, $obj_7);
    if (($2400 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 540;
      break;
    }
   case 540:
    var $2403 = $cg + 292 | 0;
    var $2404 = __ZN14JSCGObjectList5indexEP11JSObjectBox($2403, $2400);
    var $2405 = __ZL19FitsWithoutBigIndexj($2404);
    if ($2405) {
      __label__ = 541;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $_4;
      __label__ = 609;
      break;
    }
   case 541:
    HEAP8[HEAP32[HEAP32[$8 >> 2] >> 2] + $2295 | 0] = 91;
    HEAP8[HEAP32[HEAP32[$8 >> 2] >> 2] + ($2295 + 1) | 0] = $2404 >>> 8 & 255;
    HEAP8[HEAP32[HEAP32[$8 >> 2] >> 2] + ($2295 + 2) | 0] = $2404 & 255;
    var $ok_059 = 1;
    var $_560 = $_4;
    __label__ = 609;
    break;
   case 542:
    var $2425 = HEAPU32[$pn + 36 >> 2];
    var $2427 = HEAPU32[$pn + 32 >> 2];
    var $2428 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($2427, 24);
    if ($2428) {
      var $_3 = $2427;
      var $sharpnum_0 = $2425;
      __label__ = 477;
      break;
    } else {
      __label__ = 543;
      break;
    }
   case 543:
    var $2430 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($2427, 78);
    if ($2430) {
      var $_3 = $2427;
      var $sharpnum_0 = $2425;
      __label__ = 477;
      break;
    } else {
      __label__ = 544;
      break;
    }
   case 544:
    var $2432 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($2427, 26);
    if ($2432) {
      var $_4 = $2427;
      var $sharpnum_1 = $2425;
      __label__ = 503;
      break;
    } else {
      __label__ = 545;
      break;
    }
   case 545:
    var $2434 = _js_EmitTree($cx, $cg, $2427);
    if (($2434 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 546;
      break;
    }
   case 546:
    var $2437 = _js_EmitN($cx, $cg, 95, 4);
    if (($2437 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 547;
      break;
    }
   case 547:
    var $2442 = HEAPU32[HEAP32[$8 >> 2] >> 2];
    var $2443 = $cg + 104 | 0;
    HEAP8[$2437 + ($2442 + 1) | 0] = HEAPU32[$2443 >> 2] >>> 8 & 255;
    HEAP8[$2437 + ($2442 + 2) | 0] = HEAP32[$2443 >> 2] & 255;
    HEAP8[$2437 + ($2442 + 3) | 0] = $2425 >>> 8 & 255;
    HEAP8[$2437 + ($2442 + 4) | 0] = $2425 & 255;
    var $ok_059 = 1;
    var $_560 = $2427;
    __label__ = 609;
    break;
   case 548:
    var $2457 = _js_EmitN($cx, $cg, 96, 4);
    if (($2457 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 549;
      break;
    }
   case 549:
    var $2462 = HEAPU32[HEAP32[$8 >> 2] >> 2];
    var $2463 = $cg + 104 | 0;
    HEAP8[$2457 + ($2462 + 1) | 0] = HEAPU32[$2463 >> 2] >>> 8 & 255;
    HEAP8[$2457 + ($2462 + 2) | 0] = HEAP32[$2463 >> 2] & 255;
    var $2472 = $pn + 36 | 0;
    HEAP8[$2457 + ($2462 + 3) | 0] = HEAPU32[$2472 >> 2] >>> 8 & 255;
    HEAP8[$2457 + ($2462 + 4) | 0] = HEAP32[$2472 >> 2] & 255;
    var $ok_059 = 1;
    var $_560 = $pn;
    __label__ = 609;
    break;
   case 550:
    var $2481 = __ZNK11JSParseNode4isOpE4JSOp($pn, 0);
    if ($2481) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    } else {
      __label__ = 551;
      break;
    }
   case 551:
    var $2483 = __ZL10EmitNameOpP9JSContextP15JSCodeGeneratorP11JSParseNodei($cx, $cg, $pn, 0);
    if (($2483 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 552:
    var $2486 = __ZNK11JSParseNode5getOpEv($pn);
    var $2487 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, $2486, $cg, 0);
    var $_5 = $pn;
    var $ok_0 = $2487 & 1;
    __label__ = 608;
    break;
   case 553:
    var $2491 = $pn + 32 | 0;
    var $2492 = (tempDoubleI32[0] = HEAP32[$2491 >> 2], tempDoubleI32[1] = HEAP32[$2491 + 4 >> 2], tempDoubleF64[0]);
    var $2493 = __ZL12EmitNumberOpP9JSContextdP15JSCodeGenerator($cx, $2492, $cg);
    var $_5 = $pn;
    var $ok_0 = $2493;
    __label__ = 608;
    break;
   case 554:
    var $2495 = $cg + 300 | 0;
    var $2498 = HEAP32[$pn + 32 >> 2];
    var $2499 = __ZN14JSCGObjectList5indexEP11JSObjectBox($2495, $2498);
    var $2500 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 162, $2499, $cg, 0);
    var $_5 = $pn;
    var $ok_0 = $2500 & 1;
    __label__ = 608;
    break;
   case 555:
    var $2503 = __ZNK11JSParseNode5getOpEv($pn);
    var $2504 = _js_Emit1($cx, $cg, $2503);
    if (($2504 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 556:
    var $2507 = _js_Emit1($cx, $cg, 115);
    if (($2507 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 557:
    var $2510 = $pn + 32 | 0;
    var $2511 = HEAP32[$2510 >> 2];
    if (($2511 | 0) == 0) {
      __label__ = 559;
      break;
    } else {
      __label__ = 558;
      break;
    }
   case 558:
    var $2514 = __ZNK11JSParseNode7getKindEv($2511);
    if (($2514 - 59 | 0) >>> 0 < 3) {
      var $pn2_10_in = $2510;
      __label__ = 560;
      break;
    } else {
      __label__ = 559;
      break;
    }
   case 559:
    var $2515 = _js_Emit1($cx, $cg, 194);
    if (($2515 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $pn2_10_in = $2510;
      __label__ = 560;
      break;
    }
   case 560:
    var $pn2_10_in;
    var $pn2_10 = HEAPU32[$pn2_10_in >> 2];
    if (($pn2_10 | 0) == 0) {
      __label__ = 567;
      break;
    } else {
      __label__ = 561;
      break;
    }
   case 561:
    var $2519 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_10, 25);
    if ($2519) {
      __label__ = 562;
      break;
    } else {
      __label__ = 563;
      break;
    }
   case 562:
    var $2521 = _js_Emit1($cx, $cg, 195);
    if (($2521 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 563;
      break;
    }
   case 563:
    var $2524 = _js_EmitTree($cx, $cg, $pn2_10);
    if (($2524 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 564;
      break;
    }
   case 564:
    if (($pn2_10 | 0) == (HEAP32[$2510 >> 2] | 0)) {
      __label__ = 566;
      break;
    } else {
      __label__ = 565;
      break;
    }
   case 565:
    var $2530 = _js_Emit1($cx, $cg, 27);
    if (($2530 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 566;
      break;
    }
   case 566:
    var $pn2_10_in = $pn2_10 + 24 | 0;
    __label__ = 560;
    break;
   case 567:
    if ((HEAP32[$pn + 44 >> 2] & 32 | 0) == 0) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    } else {
      __label__ = 568;
      break;
    }
   case 568:
    if ((HEAP32[$pn + 40 >> 2] | 0) == 0) {
      __label__ = 569;
      break;
    } else {
      __label__ = 571;
      break;
    }
   case 569:
    var $2549 = HEAP32[HEAP32[$cx + 52 >> 2] + 209972 >> 2] | 0;
    var $2550 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $2549, $index16);
    if ($2550) {
      __label__ = 570;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 570:
    var $2552 = HEAP32[$index16 >> 2];
    var $2553 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 61, $2552, $cg, 0);
    if ($2553) {
      __label__ = 571;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 571:
    var $2555 = __ZNK11JSParseNode5getOpEv($pn);
    var $2556 = _js_Emit1($cx, $cg, $2555);
    if (($2556 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 572:
    var $2559 = _js_Emit1($cx, $cg, 194);
    if (($2559 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 573;
      break;
    }
   case 573:
    var $2562 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 60);
    var $2563 = $cx + 52 | 0;
    var $2564 = HEAP32[$2563 >> 2];
    var $_in = $2562 ? $2564 + 210388 | 0 : $2564 + 210408 | 0;
    var $2568 = HEAP32[$_in >> 2] | 0;
    var $2569 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $2568, $index17);
    if ($2569) {
      __label__ = 574;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 574:
    var $2571 = HEAP32[$index17 >> 2];
    var $2572 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 61, $2571, $cg, 0);
    if ($2572) {
      __label__ = 575;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 575:
    var $2575 = HEAP32[$pn + 32 >> 2];
    var $2576 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($2575, 25);
    if ($2576) {
      __label__ = 576;
      break;
    } else {
      __label__ = 577;
      break;
    }
   case 576:
    var $2578 = _js_Emit1($cx, $cg, 195);
    if (($2578 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 577;
      break;
    }
   case 577:
    var $2581 = _js_EmitTree($cx, $cg, $2575);
    if (($2581 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 578;
      break;
    }
   case 578:
    var $2584 = _js_Emit1($cx, $cg, 27);
    if (($2584 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $i_0 = 0;
      var $_pn = $2575;
      __label__ = 579;
      break;
    }
   case 579:
    var $_pn;
    var $i_0;
    var $pn2_11 = HEAP32[$_pn + 24 >> 2];
    if (($pn2_11 | 0) == 0) {
      __label__ = 588;
      break;
    } else {
      __label__ = 580;
      break;
    }
   case 580:
    var $2588 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_11, 25);
    if ($2588) {
      __label__ = 581;
      break;
    } else {
      __label__ = 582;
      break;
    }
   case 581:
    var $2590 = _js_Emit1($cx, $cg, 195);
    if (($2590 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 582;
      break;
    }
   case 582:
    var $2593 = _js_EmitTree($cx, $cg, $pn2_11);
    if (($2593 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 583;
      break;
    }
   case 583:
    var $2596 = $i_0 & 1;
    if (($2596 | 0) == 0) {
      __label__ = 586;
      break;
    } else {
      __label__ = 584;
      break;
    }
   case 584:
    var $2599 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_11, 25);
    if ($2599) {
      __label__ = 585;
      break;
    } else {
      __label__ = 586;
      break;
    }
   case 585:
    var $2601 = _js_Emit1($cx, $cg, 169);
    if (($2601 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 586;
      break;
    }
   case 586:
    var $2605 = _js_Emit1($cx, $cg, $2596 | 170);
    if (($2605 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 587;
      break;
    }
   case 587:
    var $i_0 = $i_0 + 1 | 0;
    var $_pn = $pn2_11;
    __label__ = 579;
    break;
   case 588:
    var $2610 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 61);
    var $2611 = HEAP32[$2563 >> 2];
    var $_in13 = $2610 ? $2611 + 210396 | 0 : $2611 + 210420 | 0;
    var $2615 = HEAP32[$_in13 >> 2] | 0;
    var $2616 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $2615, $index19);
    if ($2616) {
      __label__ = 589;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 589:
    var $2618 = HEAP32[$index19 >> 2];
    var $2619 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 61, $2618, $cg, 0);
    if ($2619) {
      __label__ = 590;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 590:
    var $2621 = _js_Emit1($cx, $cg, 27);
    if (($2621 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 591;
      break;
    }
   case 591:
    if ((HEAP32[$pn + 44 >> 2] & 32 | 0) == 0) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    } else {
      __label__ = 592;
      break;
    }
   case 592:
    var $2630 = __ZNK11JSParseNode5getOpEv($pn);
    var $2631 = _js_Emit1($cx, $cg, $2630);
    if (($2631 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    }
   case 593:
    var $2634 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 5);
    if ($2634) {
      __label__ = 594;
      break;
    } else {
      __label__ = 602;
      break;
    }
   case 594:
    var $2636 = $pn + 32 | 0;
    var $pn2_12_in = $2636;
    __label__ = 595;
    break;
   case 595:
    var $pn2_12_in;
    var $pn2_12 = HEAP32[$pn2_12_in >> 2];
    if (($pn2_12 | 0) == 0) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    } else {
      __label__ = 596;
      break;
    }
   case 596:
    var $2640 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_12, 25);
    if ($2640) {
      __label__ = 597;
      break;
    } else {
      __label__ = 598;
      break;
    }
   case 597:
    var $2642 = _js_Emit1($cx, $cg, 195);
    if (($2642 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 598;
      break;
    }
   case 598:
    var $2645 = _js_EmitTree($cx, $cg, $pn2_12);
    if (($2645 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 599;
      break;
    }
   case 599:
    if (($pn2_12 | 0) == (HEAP32[$2636 >> 2] | 0)) {
      __label__ = 601;
      break;
    } else {
      __label__ = 600;
      break;
    }
   case 600:
    var $2651 = _js_Emit1($cx, $cg, 27);
    if (($2651 | 0) < 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      __label__ = 601;
      break;
    }
   case 601:
    var $pn2_12_in = $pn2_12 + 24 | 0;
    __label__ = 595;
    break;
   case 602:
    var $2656 = __ZNK11JSParseNode4isOpE4JSOp($pn, 80);
    if ($2656) {
      __label__ = 603;
      break;
    } else {
      __label__ = 604;
      break;
    }
   case 603:
    var $2660 = HEAP32[$pn + 32 >> 2];
    var $2661 = __ZNK11JSParseNode5getOpEv($pn);
    var $2662 = __ZL12EmitObjectOpP9JSContextP11JSObjectBox4JSOpP15JSCodeGenerator($cx, $2660, $2661, $cg);
    var $_5 = $pn;
    var $ok_0 = $2662;
    __label__ = 608;
    break;
   case 604:
    var $2664 = __ZNK11JSParseNode5getOpEv($pn);
    var $2665 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, $2664, $cg, 0);
    var $_5 = $pn;
    var $ok_0 = $2665 & 1;
    __label__ = 608;
    break;
   case 605:
    var $2670 = HEAP32[$pn + 36 >> 2];
    var $2671 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $2670, $index21);
    if ($2671) {
      __label__ = 606;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 606:
    var $2673 = HEAP32[$index21 >> 2];
    var $2674 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 165, $2673, $cg, 0);
    if ($2674) {
      __label__ = 607;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 607:
    var $2676 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, 185, $cg, 0);
    if ($2676) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 609;
      break;
    } else {
      var $_1 = 0;
      __label__ = 614;
      break;
    }
   case 608:
    var $ok_0;
    var $_5;
    if (($ok_0 | 0) == 0) {
      var $ok_2 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = $ok_0;
      var $_560 = $_5;
      __label__ = 609;
      break;
    }
   case 609:
    var $_560;
    var $ok_059;
    if ((HEAP32[$cg + 236 >> 2] | 0) == 1) {
      __label__ = 610;
      break;
    } else {
      var $ok_2 = $ok_059;
      __label__ = 613;
      break;
    }
   case 610:
    if ((HEAP32[$cg + 208 >> 2] | 0) == 0) {
      var $ok_1 = $ok_059;
      __label__ = 612;
      break;
    } else {
      __label__ = 611;
      break;
    }
   case 611:
    var $2687 = __ZL16OptimizeSpanDepsP9JSContextP15JSCodeGenerator($cx, $cg);
    var $ok_1 = $2687;
    __label__ = 612;
    break;
   case 612:
    var $ok_1;
    var $2690 = HEAP32[$_560 + 16 >> 2];
    var $2691 = __ZL21UpdateLineNumberNotesP9JSContextP15JSCodeGeneratorj($cx, $cg, $2690);
    if (($2691 | 0) == 0) {
      var $_1 = 0;
      __label__ = 614;
      break;
    } else {
      var $ok_2 = $ok_1;
      __label__ = 613;
      break;
    }
   case 613:
    var $ok_2;
    var $_1 = $ok_2;
    __label__ = 614;
    break;
   case 614:
    var $_1;
    var $elm_idx_val = HEAP32[$elm >> 2];
    __ZN16EmitLevelManagerD1Ev($elm_idx_val);
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_EmitTree["X"] = 1;

function _INT_TO_JSID1151($i) {
  return $i << 1 | 1;
}

function _INT_FITS_IN_JSID($i) {
  return ($i + 1073741824 | 0) >>> 31 ^ 1;
}

function __ZNK2js11UpvarCookie6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == -1;
}

function __ZNK2js11UpvarCookie4slotEv($this_0_0_val) {
  return $this_0_0_val & 65535;
}

function __ZNK11JSParseNode4lastEv($this_0_7_0_1_val) {
  return $this_0_7_0_1_val - 24 | 0;
}

function __ZNK11JSParseNode7getKindEv($this) {
  return HEAP32[$this >> 2] & 65535;
}

function __ZNK11JSParseNode5getOpEv($this) {
  return HEAPU32[$this >> 2] >>> 16 & 255;
}

function __ZNK13JSFunctionBox8functionEv($this_0_0_2_val) {
  return $this_0_0_2_val;
}

function __ZN13JSTreeContext11setFunctionEP10JSFunction($this, $fun) {
  HEAP32[$this + 60 >> 2] = $fun;
  return;
}

function __ZN14JSCGObjectList5indexEP11JSObjectBox($this, $objbox) {
  var $1 = $this + 4 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$objbox + 4 >> 2] = $2;
  HEAP32[$1 >> 2] = $objbox;
  var $4 = $this | 0;
  var $5 = HEAP32[$4 >> 2];
  var $6 = $5 + 1 | 0;
  HEAP32[$4 >> 2] = $6;
  HEAP32[$objbox + 16 >> 2] = $5;
  return $5;
}

function __ZN11JSParseNode16getConstantValueEP9JSContextbPN2JS5ValueE($this, $cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $value = __stackBase__;
    var $value3 = __stackBase__ + 8;
    var $idvalue = __stackBase__ + 16;
    var $id = __stackBase__ + 24;
    var $1 = __ZNK11JSParseNode7getKindEv($this);
    if (($1 | 0) == 30) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 31) {
      __label__ = 3;
      break;
    } else if (($1 | 0) == 33) {
      __label__ = 4;
      break;
    } else if (($1 | 0) == 24) {
      __label__ = 8;
      break;
    } else if (($1 | 0) == 26) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 2:
    var $4 = $this + 32 | 0;
    var $5 = (tempDoubleI32[0] = HEAP32[$4 >> 2], tempDoubleI32[1] = HEAP32[$4 + 4 >> 2], tempDoubleF64[0]);
    var $6 = __ZN2JS5Value9setNumberEd($vp, $5);
    var $_0 = 1;
    __label__ = 29;
    break;
   case 3:
    var $11 = HEAP32[$this + 32 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $11);
    var $_0 = 1;
    __label__ = 29;
    break;
   case 4:
    var $13 = __ZNK11JSParseNode5getOpEv($this);
    if (($13 | 0) == 64) {
      __label__ = 5;
      break;
    } else if (($13 | 0) == 66) {
      __label__ = 6;
      break;
    } else if (($13 | 0) == 67) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 5:
    __ZN2JS5Value7setNullEv($vp);
    var $_0 = 1;
    __label__ = 29;
    break;
   case 6:
    __ZN2JS5Value10setBooleanEb($vp, 0);
    var $_0 = 1;
    __label__ = 29;
    break;
   case 7:
    __ZN2JS5Value10setBooleanEb($vp, 1);
    var $_0 = 1;
    __label__ = 29;
    break;
   case 8:
    var $19 = HEAP32[$this + 40 >> 2];
    var $20 = __ZN2js22NewDenseAllocatedArrayEP9JSContextjP8JSObject($cx, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $pn_0_in = $this + 32 | 0;
    var $idx_0 = 0;
    __label__ = 10;
    break;
   case 10:
    var $idx_0;
    var $pn_0_in;
    var $pn_0 = HEAP32[$pn_0_in >> 2];
    if (($pn_0 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $27 = __ZN11JSParseNode16getConstantValueEP9JSContextbPN2JS5ValueE($pn_0, $cx, $value);
    if ($27) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 12:
    var $29 = _INT_TO_JSID1151($idx_0);
    var $30 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($20, $cx, $29, $value, 0, 0, 1);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $pn_0_in = $pn_0 + 24 | 0;
    var $idx_0 = $idx_0 + 1 | 0;
    __label__ = 10;
    break;
   case 14:
    __ZN2js5types12FixArrayTypeEP9JSContextP8JSObject($cx, $20);
    __ZN2JS5Value9setObjectER8JSObject($vp, $20);
    var $_0 = 1;
    __label__ = 29;
    break;
   case 15:
    var $38 = HEAP32[$this + 40 >> 2];
    var $39 = __ZN2jsL17GuessObjectGCKindEjb1152($38);
    var $40 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1153($cx, $39);
    if (($40 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $44 = $cx;
    var $45 = $40;
    var $idvalue_idx1 = $idvalue | 0;
    var $pn2_0_in = $this + 32 | 0;
    __label__ = 17;
    break;
   case 17:
    var $pn2_0_in;
    var $pn2_0 = HEAP32[$pn2_0_in >> 2];
    if (($pn2_0 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $51 = HEAP32[$pn2_0 + 36 >> 2];
    var $52 = __ZN11JSParseNode16getConstantValueEP9JSContextbPN2JS5ValueE($51, $cx, $value3);
    if ($52) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 19:
    var $55 = HEAP32[$pn2_0 + 32 >> 2];
    var $56 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($55, 30);
    var $57 = $55 + 32 | 0;
    if ($56) {
      __label__ = 20;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 20:
    var $59 = $57;
    var $60 = (tempDoubleI32[0] = HEAP32[$59 >> 2], tempDoubleI32[1] = HEAP32[$59 + 4 >> 2], tempDoubleF64[0]);
    __ZN2JSL11NumberValueEd1149($idvalue, $60);
    var $idvalue_idx1_val$0 = HEAP32[$idvalue_idx1 >> 2];
    var $idvalue_idx1_val$1 = HEAP32[$idvalue_idx1 + 4 >> 2];
    var $61 = __ZNK2JS5Value7isInt32Ev($idvalue_idx1_val$0, $idvalue_idx1_val$1);
    if ($61) {
      __label__ = 21;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 21:
    var $63 = __ZNK2JS5Value7toInt32Ev($idvalue_idx1_val$0, $idvalue_idx1_val$1);
    var $64 = _INT_FITS_IN_JSID($63);
    if (($64 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $67 = _INT_TO_JSID1151($63);
    HEAP32[$id >> 2] = $67;
    var $71 = $67;
    __label__ = 25;
    break;
   case 23:
    var $69 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPi($cx, $40, $idvalue, $id);
    if ($69) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 24:
    var $71 = HEAP32[$id >> 2];
    __label__ = 25;
    break;
   case 25:
    var $71;
    var $72 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($40, $cx, $71, $value3, 0, 0, 1);
    if (($72 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $76 = HEAP32[$57 >> 2];
    var $77 = __ZL12ATOM_TO_JSIDP6JSAtom1150($76);
    var $78 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($44, $45, $77, $value3, 0, 0, 1, 0, 0, 0);
    if (($78 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $pn2_0_in = $pn2_0 + 24 | 0;
    __label__ = 17;
    break;
   case 28:
    __ZN2js5types13FixObjectTypeEP9JSContextP8JSObject($cx, $40);
    __ZN2JS5Value9setObjectER8JSObject($vp, $40);
    var $_0 = 1;
    __label__ = 29;
    break;
   case 29:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN11JSParseNode16getConstantValueEP9JSContextbPN2JS5ValueE["X"] = 1;

function __ZN2js5types12FixArrayTypeEP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment12fixArrayTypeEP9JSContextP8JSObject($5, $cx, $obj);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL17GuessObjectGCKindEjb1152($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($numSlots | 0) == 0) {
      var $_0 = 4;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2js2gcL15GetGCObjectKindEjb1183($numSlots);
    var $_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1153($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 24;
    var $4 = __ZNK9JSContext5hasfpEv($cx);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $7;
    var $8 = $cx;
    var $9 = $global;
    var $10 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($8, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $18 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZNK9JSContext2fpEv($cx);
    var $13 = __ZNK2js10StackFrame10scopeChainEv($12);
    var $14 = $13;
    var $15 = __ZNK8JSObject9getGlobalEv($14);
    var $16 = $15;
    HEAP32[$global >> 2] = $16;
    var $18 = $16;
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $18, $19);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $20 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    HEAP32[$proto >> 2] = $22;
    var $29 = $22;
    __label__ = 9;
    break;
   case 7:
    var $24 = $cx;
    var $26 = $proto;
    var $27 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($24, $18, $3, $26, __ZN2js11ObjectClassE);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $29 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $29;
    var $30 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1177($cx, $29, $18, $kind);
    var $_0 = $30;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPi($cx, $obj, $idval, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $idval_idx = $idval | 0;
    var $idval_idx_val$0 = HEAP32[$idval_idx >> 2];
    var $idval_idx_val$1 = HEAP32[$idval_idx + 4 >> 2];
    var $1 = __ZNK2JS5Value8isObjectEv($idval_idx_val$0, $idval_idx_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $3 = __Z28js_InternNonIntElementIdSlowP9JSContextP8JSObjectRKN2JS5ValueEPi($cx, $obj_idx_val, $idval, $idp);
    var $_0 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($cx, $idval_idx_val$0, $idval_idx_val$1, $idp);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types13FixObjectTypeEP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment13fixObjectTypeEP9JSContextP8JSObject($5, $cx, $obj);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN16EmitLevelManagerC1EP15JSCodeGenerator($this, $cg) {
  __ZN16EmitLevelManagerC2EP15JSCodeGenerator($this, $cg);
  return;
}

function _js_NewSrcNote2($cx, $cg, $type, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_NewSrcNote($cx, $cg, $type);
    if (($1 | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = _js_SetSrcNoteOffset($cx, $cg, $1, 0, $offset);
    if (($4 | 0) == 0) {
      var $_0 = -1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_0 = $1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_NewSrcNote($cx, $cg, $type) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL12AllocSrcNoteP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($1 | 0) < 0) {
      var $_0 = -1;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cg + 172 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $8 = HEAP32[$5 + 12 >> 2] + $1 | 0;
    var $15 = HEAP32[$5 + 8 >> 2] - HEAP32[$5 >> 2] | 0;
    var $16 = $5 + 24 | 0;
    var $18 = $15 - HEAP32[$16 >> 2] | 0;
    HEAP32[$16 >> 2] = $15;
    if (($18 | 0) > 7) {
      var $delta_0 = $18;
      var $sn_0 = $8;
      __label__ = 3;
      break;
    } else {
      var $delta_1 = $18;
      var $sn_1 = $8;
      var $index_0 = $1;
      __label__ = 5;
      break;
    }
   case 3:
    var $sn_0;
    var $delta_0;
    var $21 = ($delta_0 | 0) < 63 ? $delta_0 : 63;
    HEAP8[$sn_0] = ($21 | 192) & 255;
    var $24 = $delta_0 - $21 | 0;
    var $25 = __ZL12AllocSrcNoteP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($25 | 0) < 0) {
      var $_0 = -1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $31 = HEAP32[HEAP32[$4 >> 2] + 12 >> 2] + $25 | 0;
    if (($24 | 0) > 7) {
      var $delta_0 = $24;
      var $sn_0 = $31;
      __label__ = 3;
      break;
    } else {
      var $delta_1 = $24;
      var $sn_1 = $31;
      var $index_0 = $25;
      __label__ = 5;
      break;
    }
   case 5:
    var $index_0;
    var $sn_1;
    var $delta_1;
    HEAP8[$sn_1] = ($delta_1 & 7 | $type << 3) & 255;
    var $n_0 = HEAP8[_js_SrcNoteSpec + ($type << 3) + 4 | 0] << 24 >> 24;
    __label__ = 6;
    break;
   case 6:
    var $n_0;
    if (($n_0 | 0) > 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = $index_0;
      __label__ = 9;
      break;
    }
   case 7:
    var $43 = _js_NewSrcNote($cx, $cg, 0);
    if (($43 | 0) < 0) {
      var $_0 = -1;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $n_0 = $n_0 - 1 | 0;
    __label__ = 6;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_NewSrcNote["X"] = 1;

function __ZNK11JSParseNode7isArityE16JSParseNodeArity($this, $a) {
  var $1 = __ZNK11JSParseNode8getArityEv($this);
  return ($1 | 0) == ($a | 0);
}

function __ZL18EmitFunctionDefNopP9JSContextP15JSCodeGeneratorj($cx, $cg, $index) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_NewSrcNote2($cx, $cg, 19, $index);
    if (($1 | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = _js_Emit1($cx, $cg, 0);
    var $7 = ($4 | 0) > -1;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext4new_I15JSCodeGeneratorPN2js6ParserEjEEPT_T0_T1_($this, $p1, $p2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 616);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN15JSCodeGeneratorC2EPN2js6ParserEj($4, $p1, $p2);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Bindings8transferEP9JSContextPS0_($this, $bindings) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = $bindings;
    HEAP32[$1 >> 2] = HEAP32[$2 >> 2];
    HEAP32[$1 + 4 >> 2] = HEAP32[$2 + 4 >> 2];
    HEAP32[$1 + 8 >> 2] = HEAP32[$2 + 8 >> 2];
    var $4 = HEAP32[$this >> 2];
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP8[$4 + 29 | 0];
    var $7 = __ZNK2js5Shape12inDictionaryEv($_idx_val);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = $4 + 36 | 0;
    HEAP32[$9 >> 2] = $this;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext7delete_I15JSCodeGeneratorEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN15JSCodeGeneratorD2Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $op, $index, $cg, $psuffix) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL18EmitBigIndexPrefixP9JSContextP15JSCodeGeneratorj($cx, $cg, $index);
    if (($1 | 0) == 66) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $index >>> 8 & 255;
    var $6 = $index & 255;
    var $7 = _js_Emit3($cx, $cg, $op, $5, $6);
    if (($7 | 0) < 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, $op);
    if (($psuffix | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$psuffix >> 2] = $1;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 5:
    if (($1 | 0) == 0) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = _js_Emit1($cx, $cg, $1);
    var $_0 = ($15 | 0) > -1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg) {
  var $2 = HEAP32[$cg + 32 >> 2];
  var $3 = __ZL19EmitKnownBlockChainP9JSContextP15JSCodeGeneratorP11JSObjectBox($cx, $cg, $2);
  return $3;
}

function __ZL10BindGlobalP9JSContextP15JSCodeGeneratorP11JSParseNodeP6JSAtom($cg, $pn, $atom) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $pn + 40 | 0;
    __ZN2js11UpvarCookie8makeFreeEv($2);
    var $3 = __ZNK11JSParseNode6isUsedEv($pn);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $dn_0 = HEAP32[$pn + 36 >> 2];
    __label__ = 5;
    break;
   case 3:
    var $9 = __ZNK11JSParseNode6isDefnEv($pn);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 4:
    var $dn_0 = $pn;
    __label__ = 5;
    break;
   case 5:
    var $dn_0;
    var $13 = __ZNK12JSDefinition8isGlobalEv($dn_0);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 6:
    var $16 = __ZL15BindKnownGlobalP9JSContextP15JSCodeGeneratorP11JSParseNodeS4_P6JSAtom($cg, $dn_0 | 0, $pn, $atom);
    var $_0 = $16;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE6appendItEEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE13growStorageByEj($this);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE14internalAppendItEEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15EmitSlotIndexOpP9JSContext4JSOpjjP15JSCodeGenerator($cx, $op, $slot, $index, $cg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL18EmitBigIndexPrefixP9JSContextP15JSCodeGeneratorj($cx, $cg, $index);
    if (($1 | 0) == 66) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _js_EmitN($cx, $cg, $op, 4);
    if (($4 | 0) < 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = HEAPU32[HEAP32[$cg + 172 >> 2] >> 2];
    HEAP8[$4 + ($10 + 1) | 0] = $slot >>> 8 & 255;
    HEAP8[$4 + ($10 + 2) | 0] = $slot & 255;
    HEAP8[$4 + ($10 + 3) | 0] = $index >>> 8 & 255;
    HEAP8[$4 + ($10 + 4) | 0] = $index & 255;
    if (($1 | 0) == 0) {
      var $26 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $23 = _js_Emit1($cx, $cg, $1);
    var $26 = ($23 | 0) > -1;
    __label__ = 5;
    break;
   case 5:
    var $26;
    var $_0 = $26 & 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE8clearMapEv($this) {
  HEAP32[$this >> 2] = 0;
  return;
}

function __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $op = __stackBase__;
    var $atom = __stackBase__ + 4;
    var $cookie = __stackBase__ + 8;
    var $name = __stackBase__ + 12;
    var $_ = __stackBase__ + 16;
    var $_1 = __stackBase__ + 20;
    var $p = __stackBase__ + 20;
    var $index = __stackBase__ + 36;
    var $1 = $pn + 32 | 0;
    var $3 = $pn + 44 | 0;
    var $4 = HEAP32[$3 >> 2];
    if (($4 & 512 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 1;
      __label__ = 90;
      break;
    }
   case 2:
    var $8 = __ZNK11JSParseNode6isUsedEv($pn);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $11 = HEAP32[$pn + 36 >> 2];
    var $12 = __ZNK11JSParseNode13isDeoptimizedEv($pn);
    if ($12) {
      var $_1 = 1;
      __label__ = 90;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $11;
    var $19 = HEAP32[$11 + 44 >> 2] & 2 | $4;
    HEAP32[$3 >> 2] = $19;
    var $dn_0 = $14;
    var $25 = $19;
    __label__ = 7;
    break;
   case 5:
    var $21 = __ZNK11JSParseNode6isDefnEv($pn);
    if ($21) {
      __label__ = 6;
      break;
    } else {
      var $_1 = 1;
      __label__ = 90;
      break;
    }
   case 6:
    var $dn_0 = $pn;
    var $25 = $4;
    __label__ = 7;
    break;
   case 7:
    var $25;
    var $dn_0;
    var $26 = __ZNK11JSParseNode5getOpEv($pn);
    HEAP32[$op >> 2] = $26;
    if (($26 | 0) == 0) {
      var $_1 = 1;
      __label__ = 90;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $30 = HEAP32[$1 >> 2];
    HEAP32[$atom >> 2] = $30;
    var $31 = $dn_0 | 0;
    var $33 = HEAP32[$dn_0 + 40 >> 2];
    var $34 = $cookie | 0;
    HEAP32[$34 >> 2] = $33;
    var $35 = __ZN12JSDefinition4kindEv($dn_0);
    if (($26 | 0) == 36) {
      __label__ = 9;
      break;
    } else if (($26 | 0) == 59 || ($26 | 0) == 14) {
      __label__ = 22;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 9:
    if (($35 | 0) == 5) {
      __label__ = 22;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ((HEAP32[HEAP32[$cg + 48 >> 2] + 960 >> 2] | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $45 = __ZNK11JSParseNode10isTopLevelEv($31);
    if ($45) {
      var $48 = $25;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN11JSParseNode5setOpE4JSOp($pn, 66);
    var $48 = HEAP32[$3 >> 2];
    __label__ = 13;
    break;
   case 13:
    var $48;
    HEAP32[$3 >> 2] = $48 | 512;
    var $_1 = 1;
    __label__ = 90;
    break;
   case 14:
    var $51 = __ZNK11JSParseNode7isConstEv($pn);
    if ($51) {
      __label__ = 15;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 15:
    var $53 = $cg | 0;
    var $54 = __ZN13JSTreeContext16needStrictChecksEv($53);
    if ($54) {
      __label__ = 16;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 16:
    __ZN16JSAutoByteStringC1Ev($name);
    var $56 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $30, $name);
    if (($56 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $name_idx1_val = HEAP32[$name >> 2];
    __label__ = 19;
    break;
   case 18:
    var $61 = HEAP32[$cg + 48 >> 2] + 40 | 0;
    var $name_idx3_val = HEAP32[$name >> 2];
    var $62 = __ZNK16JSAutoByteString3ptrEv($name_idx3_val);
    var $63 = __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($cx, $61, $53, $pn, 19, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $62, tempInt));
    if ($63) {
      __label__ = 20;
      break;
    } else {
      var $name_idx1_val = $name_idx3_val;
      __label__ = 19;
      break;
    }
   case 19:
    var $name_idx1_val;
    __ZN16JSAutoByteStringD1Ev($name_idx1_val);
    var $_1 = 0;
    __label__ = 90;
    break;
   case 20:
    __ZN16JSAutoByteStringD1Ev($name_idx3_val);
    __label__ = 21;
    break;
   case 21:
    HEAP32[$op >> 2] = 59;
    __ZN11JSParseNode5setOpE4JSOp($pn, 59);
    __label__ = 22;
    break;
   case 22:
    var $67 = __ZNK12JSDefinition8isGlobalEv($dn_0);
    if ($67) {
      __label__ = 23;
      break;
    } else {
      var $cookie_idx2_val = $33;
      __label__ = 27;
      break;
    }
   case 23:
    if ((HEAP32[$op >> 2] | 0) == 59) {
      __label__ = 24;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 24:
    var $_idx11_val = HEAP32[$pn + 40 >> 2];
    var $73 = __ZNK2js11UpvarCookie6isFreeEv($_idx11_val);
    if ($73) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    __ZN11JSParseNode5setOpE4JSOp($pn, 156);
    var $76 = HEAP32[$3 >> 2] | 512;
    HEAP32[$3 >> 2] = $76;
    var $_1 = 1;
    __label__ = 90;
    break;
   case 26:
    __ZN2js11UpvarCookie8makeFreeEv($cookie);
    var $cookie_idx2_val = HEAP32[$34 >> 2];
    __label__ = 27;
    break;
   case 27:
    var $cookie_idx2_val;
    var $79 = __ZNK2js11UpvarCookie6isFreeEv($cookie_idx2_val);
    if ($79) {
      __label__ = 28;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 28:
    var $84 = HEAP32[HEAP32[$cg + 48 >> 2] + 960 >> 2];
    var $_idx13_val = HEAP32[$cg >> 2];
    if (($84 | 0) == 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    if (($_idx13_val & 16 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      var $_1 = 1;
      __label__ = 90;
      break;
    }
   case 30:
    var $_idx15_val = HEAP32[$84 >> 2];
    var $90 = __ZNK2js10StackFrame13isGlobalFrameEv($_idx15_val);
    if ($90) {
      __label__ = 31;
      break;
    } else {
      var $_1 = 1;
      __label__ = 90;
      break;
    }
   case 31:
    var $92 = __ZL17TryConvertToGnameP15JSCodeGeneratorP11JSParseNodeP4JSOp($cg, $pn, $op);
    if ($92) {
      __label__ = 32;
      break;
    } else {
      var $_1 = 1;
      __label__ = 90;
      break;
    }
   case 32:
    var $94 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $30, $_);
    if ($94) {
      __label__ = 33;
      break;
    } else {
      var $_1 = 0;
      __label__ = 90;
      break;
    }
   case 33:
    var $96 = HEAP32[$op >> 2];
    __ZN11JSParseNode5setOpE4JSOp($pn, $96);
    var $98 = HEAP32[$3 >> 2] | 512;
    HEAP32[$3 >> 2] = $98;
    var $_1 = 1;
    __label__ = 90;
    break;
   case 34:
    var $100 = __ZNK13JSTreeContext16mightAliasLocalsEv($_idx13_val);
    if ($100) {
      __label__ = 36;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $102 = __ZL17TryConvertToGnameP15JSCodeGeneratorP11JSParseNodeP4JSOp($cg, $pn, $op);
    if ($102) {
      __label__ = 36;
      break;
    } else {
      var $_1 = 1;
      __label__ = 90;
      break;
    }
   case 36:
    var $104 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $30, $_1);
    if ($104) {
      __label__ = 37;
      break;
    } else {
      var $_1 = 0;
      __label__ = 90;
      break;
    }
   case 37:
    var $106 = HEAP32[$op >> 2];
    __ZN11JSParseNode5setOpE4JSOp($pn, $106);
    var $108 = HEAP32[$3 >> 2] | 512;
    HEAP32[$3 >> 2] = $108;
    var $_1 = 1;
    __label__ = 90;
    break;
   case 38:
    var $110 = __ZNK2js11UpvarCookie5levelEv($cookie_idx2_val);
    var $111 = $cg | 0;
    var $113 = HEAP32[$cg + 76 >> 2];
    var $114 = $110 & 65535;
    var $115 = $113 - $114 | 0;
    if (($113 | 0) == ($114 | 0)) {
      __label__ = 61;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    if ((HEAP32[$op >> 2] | 0) != 59 | $115 >>> 0 > 15) {
      var $_1 = 1;
      __label__ = 90;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    if ((HEAP32[$cg >> 2] & 256 | 0) == 0) {
      __label__ = 41;
      break;
    } else {
      var $_1 = 1;
      __label__ = 90;
      break;
    }
   case 41:
    var $_idx9_val = HEAP32[$cg + 60 >> 2];
    var $127 = __ZNK13JSTreeContext3funEv($_idx9_val);
    var $_idx14_val = HEAP16[$127 + 58 >> 1];
    var $128 = __ZNK10JSFunction13isFlatClosureEv($_idx14_val);
    if ($128) {
      __label__ = 42;
      break;
    } else {
      var $_1 = 1;
      __label__ = 90;
      break;
    }
   case 42:
    var $130 = $cg + 308 | 0;
    var $131 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE9ensureMapEP9JSContext($130, $cx);
    if ($131) {
      __label__ = 43;
      break;
    } else {
      var $_1 = 0;
      __label__ = 90;
      break;
    }
   case 43:
    var $_idx5 = $130 | 0;
    var $_idx5_val = HEAP32[$_idx5 >> 2];
    var $133 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($_idx5_val);
    __ZN2js9InlineMapIP6JSAtomjLj24EE12lookupForAddERKS2_($p, $133, $atom);
    var $134 = __ZNK2js9InlineMapIP6JSAtomjLj24EE6AddPtrcvPPPPPPPS4_Ev($p);
    if (($134 | 0) == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $137 = __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtr5valueEv($p);
    var $138 = HEAPU32[$137 >> 2];
    HEAP32[$index >> 2] = $138;
    var $185 = $138;
    __label__ = 60;
    break;
   case 45:
    var $140 = $cg + 92 | 0;
    var $141 = HEAP32[$atom >> 2];
    var $142 = __ZN2js8Bindings8addUpvarEP9JSContextP6JSAtom($140, $cx, $141);
    if ($142) {
      __label__ = 46;
      break;
    } else {
      var $_1 = 0;
      __label__ = 90;
      break;
    }
   case 46:
    var $_idx4_val = HEAP32[$_idx5 >> 2];
    var $144 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($_idx4_val);
    var $145 = __ZN2js9InlineMapIP6JSAtomjLj24EE5countEv($144);
    HEAP32[$index >> 2] = $145;
    var $146 = __ZN2js9InlineMapIP6JSAtomjLj24EE3addERNS3_6AddPtrERKS2_RKj($144, $p, $atom, $index);
    if ($146) {
      __label__ = 47;
      break;
    } else {
      var $_1 = 0;
      __label__ = 90;
      break;
    }
   case 47:
    var $148 = $cg + 316 | 0;
    var $_idx6_val = HEAP32[$cg + 184 >> 2];
    var $149 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($_idx6_val);
    var $150 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5countEv($149);
    var $_idx16_val = HEAP32[$cg + 324 >> 2];
    var $151 = __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE5emptyEv($_idx16_val);
    if ($151) {
      __label__ = 48;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 48:
    if ($150 >>> 0 < 9) {
      __label__ = 49;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 49:
    __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE19growByUninitializedEj($148, $150);
    __label__ = 52;
    break;
   case 50:
    var $156 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE11allocPolicyEv($148);
    var $157 = $150 << 2;
    var $158 = __ZN2js15TempAllocPolicy7malloc_Ej($156, $157);
    if (($158 | 0) == 0) {
      var $_1 = 0;
      __label__ = 90;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $161 = $158;
    __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE16replaceRawBufferEPS1_j($148, $161, $150);
    __label__ = 52;
    break;
   case 52:
    if (($150 | 0) == 0) {
      __label__ = 55;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    var $_idx18 = $cg + 320 | 0;
    var $i_05 = 0;
    __label__ = 54;
    break;
   case 54:
    var $i_05;
    var $_idx18_val = HEAP32[$_idx18 >> 2];
    var $163 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEEixEj($_idx18_val, $i_05);
    var $_02 = $163 | 0;
    HEAP32[$_02 >> 2] = 0;
    var $164 = $i_05 + 1 | 0;
    if (($164 | 0) == ($150 | 0)) {
      __label__ = 55;
      break;
    } else {
      var $i_05 = $164;
      __label__ = 54;
      break;
    }
   case 55:
    var $165 = __ZNK2js11UpvarCookie4slotEv($cookie_idx2_val);
    if ($165 << 16 >> 16 == -1 | ($35 | 0) == 4) {
      var $slot_0 = $165;
      __label__ = 59;
      break;
    } else {
      var $tc_0 = $111;
      __label__ = 56;
      break;
    }
   case 56:
    var $tc_0;
    var $169 = HEAP32[$tc_0 + 72 >> 2];
    if ((HEAP32[$169 + 76 >> 2] | 0) == ($114 | 0)) {
      __label__ = 57;
      break;
    } else {
      var $tc_0 = $169;
      __label__ = 56;
      break;
    }
   case 57:
    var $_idx7_val = HEAP32[$169 >> 2];
    var $174 = __ZNK13JSTreeContext10inFunctionEv($_idx7_val);
    if ($174) {
      __label__ = 58;
      break;
    } else {
      var $slot_0 = $165;
      __label__ = 59;
      break;
    }
   case 58:
    var $_idx8_val = HEAP32[$169 + 60 >> 2];
    var $176 = __ZNK13JSTreeContext3funEv($_idx8_val);
    var $slot_0 = HEAP16[$176 + 56 >> 1] + $165 & 65535;
    __label__ = 59;
    break;
   case 59:
    var $slot_0;
    var $181 = HEAP32[$index >> 2];
    var $_idx17_val = HEAP32[$cg + 320 >> 2];
    var $182 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEEixEj($_idx17_val, $181);
    var $183 = $115 & 65535;
    __ZN2js11UpvarCookie3setEtt($182, $183, $slot_0);
    var $185 = $181;
    __label__ = 60;
    break;
   case 60:
    var $185;
    __ZN11JSParseNode5setOpE4JSOp($pn, 136);
    var $187 = $pn + 40 | 0;
    __ZN2js11UpvarCookie3setEtt($187, 0, $185 & 65535);
    var $190 = HEAP32[$3 >> 2] | 512;
    HEAP32[$3 >> 2] = $190;
    var $_1 = 1;
    __label__ = 90;
    break;
   case 61:
    if (($35 | 0) == 2) {
      __label__ = 62;
      break;
    } else if (($35 | 0) == 4) {
      __label__ = 69;
      break;
    } else if (($35 | 0) == 0) {
      __label__ = 76;
      break;
    } else if (($35 | 0) == 5) {
      var $_1 = 1;
      __label__ = 90;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 62:
    var $193 = HEAP32[$op >> 2];
    if (($193 | 0) == 59) {
      __label__ = 63;
      break;
    } else if (($193 | 0) == 111) {
      __label__ = 64;
      break;
    } else if (($193 | 0) == 41) {
      __label__ = 65;
      break;
    } else if (($193 | 0) == 47) {
      __label__ = 66;
      break;
    } else if (($193 | 0) == 44) {
      __label__ = 67;
      break;
    } else if (($193 | 0) == 50) {
      __label__ = 68;
      break;
    } else {
      var $231 = $193;
      __label__ = 89;
      break;
    }
   case 63:
    HEAP32[$op >> 2] = 86;
    var $231 = 86;
    __label__ = 89;
    break;
   case 64:
    HEAP32[$op >> 2] = 87;
    var $231 = 87;
    __label__ = 89;
    break;
   case 65:
    HEAP32[$op >> 2] = 101;
    var $231 = 101;
    __label__ = 89;
    break;
   case 66:
    HEAP32[$op >> 2] = 103;
    var $231 = 103;
    __label__ = 89;
    break;
   case 67:
    HEAP32[$op >> 2] = 102;
    var $231 = 102;
    __label__ = 89;
    break;
   case 68:
    HEAP32[$op >> 2] = 104;
    var $231 = 104;
    __label__ = 89;
    break;
   case 69:
    var $201 = HEAP32[$op >> 2];
    if (($201 | 0) == 59) {
      __label__ = 70;
      break;
    } else if (($201 | 0) == 111) {
      __label__ = 71;
      break;
    } else if (($201 | 0) == 41) {
      __label__ = 72;
      break;
    } else if (($201 | 0) == 47) {
      __label__ = 73;
      break;
    } else if (($201 | 0) == 44) {
      __label__ = 74;
      break;
    } else if (($201 | 0) == 50) {
      __label__ = 75;
      break;
    } else {
      var $231 = $201;
      __label__ = 89;
      break;
    }
   case 70:
    HEAP32[$op >> 2] = 84;
    var $231 = 84;
    __label__ = 89;
    break;
   case 71:
    HEAP32[$op >> 2] = 85;
    var $231 = 85;
    __label__ = 89;
    break;
   case 72:
    HEAP32[$op >> 2] = 97;
    var $231 = 97;
    __label__ = 89;
    break;
   case 73:
    HEAP32[$op >> 2] = 99;
    var $231 = 99;
    __label__ = 89;
    break;
   case 74:
    HEAP32[$op >> 2] = 98;
    var $231 = 98;
    __label__ = 89;
    break;
   case 75:
    HEAP32[$op >> 2] = 100;
    var $231 = 100;
    __label__ = 89;
    break;
   case 76:
    var $209 = __ZNK11JSParseNode4isOpE4JSOp($31, 131);
    if ($209) {
      __label__ = 77;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 77:
    if ((HEAP32[$cg >> 2] & 256 | 0) == 0) {
      __label__ = 79;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 78:
    var $219 = HEAP32[$op >> 2];
    __label__ = 80;
    break;
   case 79:
    HEAP32[$op >> 2] = 131;
    var $217 = HEAP32[$3 >> 2] | 2;
    HEAP32[$3 >> 2] = $217;
    var $219 = 131;
    __label__ = 80;
    break;
   case 80:
    var $219;
    __ZN11JSParseNode5setOpE4JSOp($pn, $219);
    var $221 = HEAP32[$3 >> 2] | 512;
    HEAP32[$3 >> 2] = $221;
    var $_1 = 1;
    __label__ = 90;
    break;
   case 81:
    var $222 = HEAP32[$op >> 2];
    if (($222 | 0) == 59) {
      __label__ = 82;
      break;
    } else if (($222 | 0) == 111) {
      __label__ = 83;
      break;
    } else if (($222 | 0) == 14) {
      __label__ = 84;
      break;
    } else if (($222 | 0) == 41) {
      __label__ = 85;
      break;
    } else if (($222 | 0) == 47) {
      __label__ = 86;
      break;
    } else if (($222 | 0) == 44) {
      __label__ = 87;
      break;
    } else if (($222 | 0) == 50) {
      __label__ = 88;
      break;
    } else {
      var $231 = $222;
      __label__ = 89;
      break;
    }
   case 82:
    HEAP32[$op >> 2] = 86;
    var $231 = 86;
    __label__ = 89;
    break;
   case 83:
    HEAP32[$op >> 2] = 87;
    var $231 = 87;
    __label__ = 89;
    break;
   case 84:
    HEAP32[$op >> 2] = 87;
    var $231 = 87;
    __label__ = 89;
    break;
   case 85:
    HEAP32[$op >> 2] = 101;
    var $231 = 101;
    __label__ = 89;
    break;
   case 86:
    HEAP32[$op >> 2] = 103;
    var $231 = 103;
    __label__ = 89;
    break;
   case 87:
    HEAP32[$op >> 2] = 102;
    var $231 = 102;
    __label__ = 89;
    break;
   case 88:
    HEAP32[$op >> 2] = 104;
    var $231 = 104;
    __label__ = 89;
    break;
   case 89:
    var $231;
    __ZN11JSParseNode5setOpE4JSOp($pn, $231);
    var $233 = $pn + 40 | 0;
    var $234 = __ZNK2js11UpvarCookie4slotEv($cookie_idx2_val);
    __ZN2js11UpvarCookie3setEtt($233, 0, $234);
    var $236 = HEAP32[$3 >> 2] | 512;
    HEAP32[$3 >> 2] = $236;
    var $_1 = 1;
    __label__ = 90;
    break;
   case 90:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode["X"] = 1;

function __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE10releaseMapEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $cx_idx_val = HEAP32[$cx + 100 >> 2];
    var $5 = __ZN9JSContext12parseMapPoolEv($cx_idx_val);
    __ZN2js12ParseMapPool7releaseEPNS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEE($5, $2);
    HEAP32[$1 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_SetSrcNoteOffset($cx, $cg, $index, $which, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($offset >>> 0 > 8388607) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $cg_idx_val = HEAP32[$cg + 24 >> 2];
    __ZL23ReportStatementTooLargeP9JSContextP15JSCodeGenerator($cx, $cg_idx_val);
    var $_0 = 0;
    __label__ = 14;
    break;
   case 3:
    var $4 = $cg + 172 | 0;
    var $5 = HEAPU32[$4 >> 2];
    var $7 = HEAPU32[$5 + 12 >> 2];
    var $8 = $index + ($7 + 1) | 0;
    if (($which | 0) == 0) {
      var $sn_0_lcssa = $8;
      __label__ = 5;
      break;
    } else {
      var $_013 = $which;
      var $sn_04 = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $sn_04;
    var $_013;
    var $sn_1 = HEAP8[$sn_04] << 24 >> 24 < 0 ? $sn_04 + 2 | 0 : $sn_04;
    var $13 = $sn_1 + 1 | 0;
    var $14 = $_013 - 1 | 0;
    if (($14 | 0) == 0) {
      var $sn_0_lcssa = $13;
      __label__ = 5;
      break;
    } else {
      var $_013 = $14;
      var $sn_04 = $13;
      __label__ = 4;
      break;
    }
   case 5:
    var $sn_0_lcssa;
    if (($offset | 0) > 127) {
      __label__ = 6;
      break;
    } else {
      var $sn_4 = $sn_0_lcssa;
      __label__ = 13;
      break;
    }
   case 6:
    if (HEAP8[$sn_0_lcssa] << 24 >> 24 < 0) {
      var $sn_3 = $sn_0_lcssa;
      __label__ = 12;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = $sn_0_lcssa - $7 | 0;
    var $25 = HEAPU32[$5 + 16 >> 2];
    if (($25 + 1 | 0) >>> 0 < HEAPU32[$5 + 20 >> 2] >>> 0) {
      var $sn_2 = $sn_0_lcssa;
      var $40 = $5;
      var $39 = $25;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = __ZL12GrowSrcNotesP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $34 = HEAPU32[$4 >> 2];
    var $sn_2 = HEAP32[$34 + 12 >> 2] + $23 | 0;
    var $40 = $34;
    var $39 = HEAP32[$34 + 16 >> 2];
    __label__ = 10;
    break;
   case 10:
    var $39;
    var $40;
    var $sn_2;
    HEAP32[$40 + 16 >> 2] = $39 + 2 | 0;
    var $46 = -3 - $23 + HEAP32[HEAP32[$4 >> 2] + 16 >> 2] | 0;
    if (($46 | 0) > 0) {
      __label__ = 11;
      break;
    } else {
      var $sn_3 = $sn_2;
      __label__ = 12;
      break;
    }
   case 11:
    _llvm_memmove_p0i8_p0i8_i32($sn_2 + 3 | 0, $sn_2 + 1 | 0, $46, 1, 0);
    var $sn_3 = $sn_2;
    __label__ = 12;
    break;
   case 12:
    var $sn_3;
    HEAP8[$sn_3] = ($offset >>> 16 | 128) & 255;
    HEAP8[$sn_3 + 1 | 0] = $offset >>> 8 & 255;
    var $sn_4 = $sn_3 + 2 | 0;
    __label__ = 13;
    break;
   case 13:
    var $sn_4;
    HEAP8[$sn_4] = $offset & 255;
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_SetSrcNoteOffset["X"] = 1;

function __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, $op, $off) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($off + 32768 | 0) >>> 0 > 65535;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    if ((HEAP32[$cg + 208 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZL17BuildSpanDepTableP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($7 | 0) == 0) {
      var $_0 = -1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $off >>> 8 & 255;
    var $12 = $off & 255;
    var $13 = _js_Emit3($cx, $cg, $op, $11, $12);
    if (($13 | 0) > -1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    if ($1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$cg + 208 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = HEAP32[HEAP32[$cg + 172 >> 2] >> 2] + $13 | 0;
    var $26 = __ZL10AddSpanDepP9JSContextP15JSCodeGeneratorPhS3_i($cx, $cg, $25, $25, $off);
    if (($26 | 0) == 0) {
      var $_0 = -1;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = $13;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8EmitGotoP9JSContextP15JSCodeGeneratorP10JSStmtInfoPij13JSSrcNoteType($cx, $cg, $toStmt, $lastp, $labelIndex, $noteType) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL21EmitNonLocalJumpFixupP9JSContextP15JSCodeGeneratorP10JSStmtInfo($cx, $cg, $toStmt);
    if (($1 | 0) == 0) {
      var $_0 = -1;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($labelIndex | 0) == -1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = _js_NewSrcNote2($cx, $cg, $noteType, $labelIndex);
    var $index_0 = $6;
    __label__ = 6;
    break;
   case 4:
    if (($noteType | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = _js_NewSrcNote($cx, $cg, $noteType);
    var $index_0 = $10;
    __label__ = 6;
    break;
   case 6:
    var $index_0;
    if (($index_0 | 0) < 0) {
      var $_0 = -1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $13 = __ZL15EmitBackPatchOpP9JSContextP15JSCodeGenerator4JSOpPi($cx, $cg, $lastp);
    if (($13 | 0) < 0) {
      var $_0 = $13;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $16 = __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg);
    var $_ = ($16 | 0) == 0 ? -1 : $13;
    var $_0 = $_;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10EmitSwitchP9JSContextP15JSCodeGeneratorP11JSParseNodeP10JSStmtInfo($cx, $cg, $pn, $stmtInfo) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 1052;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tps = __stackBase__;
    var $intmap_space = __stackBase__ + 12;
    var $constVal = __stackBase__ + 1036;
    var $index = __stackBase__ + 1044;
    var $index1 = __stackBase__ + 1048;
    var $1 = $pn + 36 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $2;
    __ZN12TempPopScopeC1Ev($tps);
    var $4 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($3, 80);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $box_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = HEAP32[$2 + 32 >> 2];
    var $9 = $cg | 0;
    _js_PushBlockScope($9, $stmtInfo, $8, -1);
    HEAP16[$stmtInfo >> 1] = 5;
    var $11 = __ZL14EmitEnterBlockP9JSContextP11JSParseNodeP15JSCodeGenerator($cx, $3, $cg);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 137;
      break;
    }
   case 3:
    var $13 = __ZN12TempPopScope8popBlockEP9JSContextP15JSCodeGenerator($tps, $cx, $cg);
    if ($13) {
      var $box_0 = $8;
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 137;
      break;
    }
   case 4:
    var $box_0;
    var $16 = HEAP32[$pn + 32 >> 2];
    var $17 = _js_EmitTree($cx, $cg, $16);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = $cg + 172 | 0;
    var $21 = HEAP32[$20 >> 2];
    var $28 = HEAP32[$21 + 8 >> 2] - HEAP32[$21 >> 2] | 0;
    var $29 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($3, 25);
    if ($29) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $31 = $cg | 0;
    _js_PushStatement($31, $stmtInfo, 5, $28);
    var $top_0 = $28;
    var $pn2_0 = $3;
    __label__ = 9;
    break;
   case 7:
    var $33 = __ZN12TempPopScope11repushBlockEP9JSContextP15JSCodeGenerator($tps, $cx, $cg);
    if ($33) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 137;
      break;
    }
   case 8:
    var $35 = HEAP32[$20 >> 2];
    var $42 = HEAP32[$35 + 8 >> 2] - HEAP32[$35 >> 2] | 0;
    HEAP32[$stmtInfo + 8 >> 2] = $42;
    var $_idx4_val = HEAP32[$2 + 36 >> 2];
    var $45 = __ZNK11JSParseNode4exprEv($_idx4_val);
    var $top_0 = $42;
    var $pn2_0 = $45;
    __label__ = 9;
    break;
   case 9:
    var $pn2_0;
    var $top_0;
    var $47 = $pn2_0 + 32 | 0;
    var $49 = HEAPU32[$pn2_0 + 40 >> 2];
    if (($49 | 0) == 1) {
      __label__ = 11;
      break;
    } else if (($49 | 0) == 0) {
      var $switchOp_2 = 70;
      var $hasDefault_4 = 0;
      var $constPropagated_4 = 0;
      var $caseCount_2 = 0;
      var $tableLength_0 = 0;
      var $low_3 = 0;
      var $high_3 = -1;
      __label__ = 51;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $hasDefault_1 = 0;
    var $_pre_phi = $47 | 0;
    __label__ = 12;
    break;
   case 11:
    var $51 = $47 | 0;
    var $52 = HEAP32[$51 >> 2];
    var $53 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($52, 39);
    var $54 = $53 & 1;
    if ($53) {
      var $switchOp_2 = 70;
      var $hasDefault_4 = $54;
      var $constPropagated_4 = 0;
      var $caseCount_2 = 0;
      var $tableLength_0 = 0;
      var $low_3 = 0;
      var $high_3 = -1;
      __label__ = 51;
      break;
    } else {
      var $hasDefault_1 = $54;
      var $_pre_phi = $51;
      __label__ = 12;
      break;
    }
   case 12:
    var $_pre_phi;
    var $hasDefault_1;
    var $56 = $constVal | 0;
    var $57 = $intmap_space | 0;
    var $intmap_bitlen_0 = 0;
    var $intmap_0 = 0;
    var $switchOp_0 = 70;
    var $hasDefault_2 = $hasDefault_1;
    var $constPropagated_0 = 0;
    var $pn3_0_in = $_pre_phi;
    var $caseCount_0 = $49;
    var $low_0 = 2147483647;
    var $high_0 = -2147483648;
    __label__ = 13;
    break;
   case 13:
    var $high_0;
    var $low_0;
    var $caseCount_0;
    var $pn3_0_in;
    var $constPropagated_0;
    var $hasDefault_2;
    var $switchOp_0;
    var $intmap_0;
    var $intmap_bitlen_0;
    var $pn3_0 = HEAPU32[$pn3_0_in >> 2];
    if (($pn3_0 | 0) == 0) {
      var $ok_5 = 1;
      var $constPropagated_3 = $constPropagated_0;
      __label__ = 42;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $61 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn3_0, 39);
    if ($61) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $intmap_bitlen_3 = $intmap_bitlen_0;
    var $intmap_3 = $intmap_0;
    var $switchOp_1 = $switchOp_0;
    var $hasDefault_3 = 1;
    var $constPropagated_2 = $constPropagated_0;
    var $caseCount_1 = $caseCount_0 - 1 | 0;
    var $low_2 = $low_0;
    var $high_2 = $high_0;
    __label__ = 41;
    break;
   case 16:
    if (($switchOp_0 | 0) == 120) {
      var $intmap_bitlen_3 = $intmap_bitlen_0;
      var $intmap_3 = $intmap_0;
      var $switchOp_1 = 120;
      var $hasDefault_3 = $hasDefault_2;
      var $constPropagated_2 = $constPropagated_0;
      var $caseCount_1 = $caseCount_0;
      var $low_2 = $low_0;
      var $high_2 = $high_0;
      __label__ = 41;
      break;
    } else {
      var $pn3_0_pn = $pn3_0;
      __label__ = 17;
      break;
    }
   case 17:
    var $pn3_0_pn;
    var $pn4_0 = HEAPU32[$pn3_0_pn + 32 >> 2];
    var $66 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn4_0, 28);
    if ($66) {
      var $pn3_0_pn = $pn4_0;
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $68 = __ZNK11JSParseNode7getKindEv($pn4_0);
    if (($68 | 0) == 30) {
      __label__ = 19;
      break;
    } else if (($68 | 0) == 31) {
      __label__ = 20;
      break;
    } else if (($68 | 0) == 29) {
      __label__ = 21;
      break;
    } else if (($68 | 0) == 33) {
      __label__ = 24;
      break;
    } else {
      var $intmap_bitlen_3 = $intmap_bitlen_0;
      var $intmap_3 = $intmap_0;
      var $switchOp_1 = 120;
      var $hasDefault_3 = $hasDefault_2;
      var $constPropagated_2 = $constPropagated_0;
      var $caseCount_1 = $caseCount_0;
      var $low_2 = $low_0;
      var $high_2 = $high_0;
      __label__ = 41;
      break;
    }
   case 19:
    var $71 = $pn4_0 + 32 | 0;
    var $72 = (tempDoubleI32[0] = HEAP32[$71 >> 2], tempDoubleI32[1] = HEAP32[$71 + 4 >> 2], tempDoubleF64[0]);
    var $73 = __ZN2JS5Value9setNumberEd($constVal, $72);
    var $constPropagated_1 = $constPropagated_0;
    __label__ = 30;
    break;
   case 20:
    var $78 = HEAP32[$pn4_0 + 32 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($constVal, $78);
    var $constPropagated_1 = $constPropagated_0;
    __label__ = 30;
    break;
   case 21:
    var $80 = __ZN11JSParseNode9maybeExprEv($pn4_0);
    if (($80 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 22:
    var $85 = HEAP32[$pn4_0 + 32 >> 2];
    __ZL25LookupCompileTimeConstantP9JSContextP15JSCodeGeneratorP6JSAtomPN2JS5ValueE($cx, $cg, $85, $constVal);
    var $st$4$0 = $56 | 0;
    var $constVal_idx3_val$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $56 + 4 | 0;
    var $constVal_idx3_val$1 = HEAP32[$st$4$1 >> 2];
    var $86 = __ZNK2JS5Value7isMagicE10JSWhyMagic($constVal_idx3_val$0, $constVal_idx3_val$1);
    if ($86) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $88 = __ZNK2JS5Value8isObjectEv($constVal_idx3_val$0, $constVal_idx3_val$1);
    if ($88) {
      var $intmap_bitlen_3 = $intmap_bitlen_0;
      var $intmap_3 = $intmap_0;
      var $switchOp_1 = 120;
      var $hasDefault_3 = $hasDefault_2;
      var $constPropagated_2 = $constPropagated_0;
      var $caseCount_1 = $caseCount_0;
      var $low_2 = $low_0;
      var $high_2 = $high_0;
      __label__ = 41;
      break;
    } else {
      var $constPropagated_1 = 1;
      __label__ = 30;
      break;
    }
   case 24:
    var $90 = __ZNK11JSParseNode4isOpE4JSOp($pn4_0, 67);
    if ($90) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    __ZN2JS5Value10setBooleanEb($constVal, 1);
    var $constPropagated_1 = $constPropagated_0;
    __label__ = 30;
    break;
   case 26:
    var $93 = __ZNK11JSParseNode4isOpE4JSOp($pn4_0, 66);
    if ($93) {
      __label__ = 27;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 27:
    __ZN2JS5Value10setBooleanEb($constVal, 0);
    var $constPropagated_1 = $constPropagated_0;
    __label__ = 30;
    break;
   case 28:
    var $96 = __ZNK11JSParseNode4isOpE4JSOp($pn4_0, 64);
    if ($96) {
      __label__ = 29;
      break;
    } else {
      var $intmap_bitlen_3 = $intmap_bitlen_0;
      var $intmap_3 = $intmap_0;
      var $switchOp_1 = 120;
      var $hasDefault_3 = $hasDefault_2;
      var $constPropagated_2 = $constPropagated_0;
      var $caseCount_1 = $caseCount_0;
      var $low_2 = $low_0;
      var $high_2 = $high_0;
      __label__ = 41;
      break;
    }
   case 29:
    __ZN2JS5Value7setNullEv($constVal);
    var $constPropagated_1 = $constPropagated_0;
    __label__ = 30;
    break;
   case 30:
    var $constPropagated_1;
    var $99 = __ZL22AllocateSwitchConstantP9JSContext($cx);
    var $100 = $pn3_0 + 40 | 0;
    var $101 = $100;
    HEAP32[$100 >> 2] = $99;
    if (($99 | 0) == 0) {
      var $ok_5 = 0;
      var $constPropagated_3 = $constPropagated_1;
      __label__ = 42;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $104$0 = HEAP32[$56 >> 2];
    var $104$1 = HEAP32[$56 + 4 >> 2];
    var $105 = $99 | 0;
    HEAP32[$105 >> 2] = $104$0;
    HEAP32[$105 + 4 >> 2] = $104$1;
    if (($switchOp_0 | 0) == 70) {
      __label__ = 32;
      break;
    } else {
      var $intmap_bitlen_3 = $intmap_bitlen_0;
      var $intmap_3 = $intmap_0;
      var $switchOp_1 = $switchOp_0;
      var $hasDefault_3 = $hasDefault_2;
      var $constPropagated_2 = $constPropagated_1;
      var $caseCount_1 = $caseCount_0;
      var $low_2 = $low_0;
      var $high_2 = $high_0;
      __label__ = 41;
      break;
    }
   case 32:
    var $_idx2 = HEAP32[$101 >> 2] | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    var $109 = __ZNK2JS5Value7isInt32Ev($_idx2_val$0, $_idx2_val$1);
    if ($109) {
      __label__ = 33;
      break;
    } else {
      var $intmap_bitlen_3 = $intmap_bitlen_0;
      var $intmap_3 = $intmap_0;
      var $switchOp_1 = 71;
      var $hasDefault_3 = $hasDefault_2;
      var $constPropagated_2 = $constPropagated_1;
      var $caseCount_1 = $caseCount_0;
      var $low_2 = $low_0;
      var $high_2 = $high_0;
      __label__ = 41;
      break;
    }
   case 33:
    var $111 = __ZNK2JS5Value7toInt32Ev($_idx2_val$0, $_idx2_val$1);
    if (($111 + 32768 | 0) >>> 0 > 65535) {
      var $intmap_bitlen_3 = $intmap_bitlen_0;
      var $intmap_3 = $intmap_0;
      var $switchOp_1 = 71;
      var $hasDefault_3 = $hasDefault_2;
      var $constPropagated_2 = $constPropagated_1;
      var $caseCount_1 = $caseCount_0;
      var $low_2 = $low_0;
      var $high_2 = $high_0;
      __label__ = 41;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $low_1 = ($111 | 0) < ($low_0 | 0) ? $111 : $low_0;
    var $high_1 = ($high_0 | 0) < ($111 | 0) ? $111 : $high_0;
    var $_ = ($111 | 0) < 0 ? $111 + 65536 | 0 : $111;
    if (($_ | 0) < ($intmap_bitlen_0 | 0)) {
      var $intmap_bitlen_2 = $intmap_bitlen_0;
      var $intmap_2 = $intmap_0;
      __label__ = 39;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    if (($intmap_0 | 0) == 0 & ($_ | 0) < 8192) {
      var $intmap_bitlen_1 = 8192;
      var $intmap_1 = $57;
      __label__ = 38;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $124 = __ZN9JSContext7malloc_Ej($cx, 8192);
    var $125 = $124;
    if (($124 | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      var $intmap_bitlen_1 = 65536;
      var $intmap_1 = $125;
      __label__ = 38;
      break;
    }
   case 37:
    _JS_ReportOutOfMemory($cx);
    var $_0 = 0;
    __label__ = 137;
    break;
   case 38:
    var $intmap_1;
    var $intmap_bitlen_1;
    _memset($intmap_1, 0, $intmap_bitlen_1 >>> 3, 1);
    var $intmap_bitlen_2 = $intmap_bitlen_1;
    var $intmap_2 = $intmap_1;
    __label__ = 39;
    break;
   case 39:
    var $intmap_2;
    var $intmap_bitlen_2;
    var $133 = $intmap_2 + ($_ >> 5 << 2) | 0;
    var $134 = HEAP32[$133 >> 2];
    var $136 = 1 << ($_ & 31);
    if (($134 & $136 | 0) == 0) {
      __label__ = 40;
      break;
    } else {
      var $intmap_bitlen_3 = $intmap_bitlen_2;
      var $intmap_3 = $intmap_2;
      var $switchOp_1 = 71;
      var $hasDefault_3 = $hasDefault_2;
      var $constPropagated_2 = $constPropagated_1;
      var $caseCount_1 = $caseCount_0;
      var $low_2 = $low_1;
      var $high_2 = $high_1;
      __label__ = 41;
      break;
    }
   case 40:
    var $140 = $134 | $136;
    HEAP32[$133 >> 2] = $140;
    var $intmap_bitlen_3 = $intmap_bitlen_2;
    var $intmap_3 = $intmap_2;
    var $switchOp_1 = $switchOp_0;
    var $hasDefault_3 = $hasDefault_2;
    var $constPropagated_2 = $constPropagated_1;
    var $caseCount_1 = $caseCount_0;
    var $low_2 = $low_1;
    var $high_2 = $high_1;
    __label__ = 41;
    break;
   case 41:
    var $high_2;
    var $low_2;
    var $caseCount_1;
    var $constPropagated_2;
    var $hasDefault_3;
    var $switchOp_1;
    var $intmap_3;
    var $intmap_bitlen_3;
    var $intmap_bitlen_0 = $intmap_bitlen_3;
    var $intmap_0 = $intmap_3;
    var $switchOp_0 = $switchOp_1;
    var $hasDefault_2 = $hasDefault_3;
    var $constPropagated_0 = $constPropagated_2;
    var $pn3_0_in = $pn3_0 + 24 | 0;
    var $caseCount_0 = $caseCount_1;
    var $low_0 = $low_2;
    var $high_0 = $high_2;
    __label__ = 13;
    break;
   case 42:
    var $constPropagated_3;
    var $ok_5;
    if (($intmap_0 | 0) == 0 | ($intmap_0 | 0) == ($57 | 0)) {
      __label__ = 44;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    __ZN9JSContext5free_EPv($intmap_0);
    __label__ = 44;
    break;
   case 44:
    if (($ok_5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    if (($switchOp_0 | 0) == 70) {
      __label__ = 46;
      break;
    } else if (($switchOp_0 | 0) == 71) {
      __label__ = 49;
      break;
    } else {
      var $switchOp_2 = $switchOp_0;
      var $hasDefault_4 = $hasDefault_2;
      var $constPropagated_4 = $constPropagated_3;
      var $caseCount_2 = $caseCount_0;
      var $tableLength_0 = 0;
      var $low_3 = $low_0;
      var $high_3 = $high_0;
      __label__ = 51;
      break;
    }
   case 46:
    var $153 = $high_0 - $low_0 + 1 | 0;
    if ($153 >>> 0 > 65535) {
      __label__ = 48;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    if ($153 >>> 0 > $caseCount_0 << 1 >>> 0) {
      __label__ = 48;
      break;
    } else {
      var $switchOp_2 = $switchOp_0;
      var $hasDefault_4 = $hasDefault_2;
      var $constPropagated_4 = $constPropagated_3;
      var $caseCount_2 = $caseCount_0;
      var $tableLength_0 = $153;
      var $low_3 = $low_0;
      var $high_3 = $high_0;
      __label__ = 51;
      break;
    }
   case 48:
    var $switchOp_2 = 71;
    var $hasDefault_4 = $hasDefault_2;
    var $constPropagated_4 = $constPropagated_3;
    var $caseCount_2 = $caseCount_0;
    var $tableLength_0 = $153;
    var $low_3 = $low_0;
    var $high_3 = $high_0;
    __label__ = 51;
    break;
   case 49:
    var $160 = $cg + 268 | 0;
    var $161 = __ZNK13JSGCConstList6lengthEv($160);
    if (($161 + $caseCount_0 | 0) >>> 0 > 65536) {
      __label__ = 50;
      break;
    } else {
      var $switchOp_2 = 71;
      var $hasDefault_4 = $hasDefault_2;
      var $constPropagated_4 = $constPropagated_3;
      var $caseCount_2 = $caseCount_0;
      var $tableLength_0 = 0;
      var $low_3 = $low_0;
      var $high_3 = $high_0;
      __label__ = 51;
      break;
    }
   case 50:
    var $switchOp_2 = 120;
    var $hasDefault_4 = $hasDefault_2;
    var $constPropagated_4 = $constPropagated_3;
    var $caseCount_2 = $caseCount_0;
    var $tableLength_0 = 0;
    var $low_3 = $low_0;
    var $high_3 = $high_0;
    __label__ = 51;
    break;
   case 51:
    var $high_3;
    var $low_3;
    var $tableLength_0;
    var $caseCount_2;
    var $constPropagated_4;
    var $hasDefault_4;
    var $switchOp_2;
    var $166 = _js_NewSrcNote3($cx, $cg);
    if (($166 | 0) < 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 52:
    var $169 = ($switchOp_2 | 0) == 120;
    if ($169) {
      var $switchSize_0 = 0;
      __label__ = 56;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    if (($switchOp_2 | 0) == 70) {
      __label__ = 54;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 54:
    var $switchSize_0 = ($tableLength_0 << 1) + 6 | 0;
    __label__ = 56;
    break;
   case 55:
    var $switchSize_0 = ($caseCount_2 << 2) + 4 | 0;
    __label__ = 56;
    break;
   case 56:
    var $switchSize_0;
    var $179 = _js_EmitN($cx, $cg, $switchOp_2, $switchSize_0);
    if (($179 | 0) < 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    if ($169) {
      __label__ = 58;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 58:
    var $beforeCases_0 = 1;
    var $caseNoteIndex_0 = -1;
    var $off_0 = -1;
    var $pn3_1_in = $47 | 0;
    __label__ = 59;
    break;
   case 59:
    var $pn3_1_in;
    var $off_0;
    var $caseNoteIndex_0;
    var $beforeCases_0;
    var $pn3_1 = HEAPU32[$pn3_1_in >> 2];
    if (($pn3_1 | 0) == 0) {
      __label__ = 72;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 60:
    var $188 = HEAP32[$pn3_1 + 32 >> 2];
    var $189 = ($188 | 0) != 0;
    if ($189) {
      __label__ = 61;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 61:
    var $191 = _js_EmitTree($cx, $cg, $188);
    if (($191 | 0) == 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 62:
    if (($caseNoteIndex_0 | 0) > -1) {
      __label__ = 63;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 63:
    var $196 = HEAP32[$20 >> 2];
    var $204 = HEAP32[$196 + 8 >> 2] - $off_0 - HEAP32[$196 >> 2] | 0;
    var $205 = _js_SetSrcNoteOffset($cx, $cg, $caseNoteIndex_0, 0, $204);
    if (($205 | 0) == 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    if ($189) {
      __label__ = 65;
      break;
    } else {
      var $beforeCases_1 = $beforeCases_0;
      var $caseNoteIndex_2 = $caseNoteIndex_0;
      var $off_1 = $off_0;
      __label__ = 71;
      break;
    }
   case 65:
    var $209 = _js_NewSrcNote2($cx, $cg, 7, 0);
    if (($209 | 0) < 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 66:
    var $212 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 121, 0);
    if (($212 | 0) < 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 67:
    HEAP32[$pn3_1 + 20 >> 2] = $212;
    if (($beforeCases_0 | 0) == 0) {
      var $beforeCases_1 = 0;
      var $caseNoteIndex_2 = $209;
      var $off_1 = $212;
      __label__ = 71;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 68:
    var $220 = HEAP32[HEAP32[$20 >> 2] + 16 >> 2];
    var $221 = $212 - $top_0 | 0;
    var $222 = _js_SetSrcNoteOffset($cx, $cg, $166, 1, $221);
    if (($222 | 0) == 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 69:
    var $227 = HEAP32[HEAP32[$20 >> 2] + 16 >> 2];
    if (($227 | 0) == ($220 | 0)) {
      var $beforeCases_1 = 0;
      var $caseNoteIndex_2 = $209;
      var $off_1 = $212;
      __label__ = 71;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    var $beforeCases_1 = 0;
    var $caseNoteIndex_2 = $209 - $220 + $227 | 0;
    var $off_1 = $212;
    __label__ = 71;
    break;
   case 71:
    var $off_1;
    var $caseNoteIndex_2;
    var $beforeCases_1;
    var $beforeCases_0 = $beforeCases_1;
    var $caseNoteIndex_0 = $caseNoteIndex_2;
    var $off_0 = $off_1;
    var $pn3_1_in = $pn3_1 + 24 | 0;
    __label__ = 59;
    break;
   case 72:
    if (($hasDefault_4 | 0) == 0 & ($caseNoteIndex_0 | 0) > -1) {
      __label__ = 73;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 73:
    var $238 = HEAP32[$20 >> 2];
    var $246 = HEAP32[$238 + 8 >> 2] - $off_0 - HEAP32[$238 >> 2] | 0;
    var $247 = _js_SetSrcNoteOffset($cx, $cg, $caseNoteIndex_0, 0, $246);
    if (($247 | 0) == 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 74:
    var $250 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 122, 0);
    if (($250 | 0) < 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      var $off_2 = $off_0;
      var $defaultOffset_0 = $250;
      var $table_1 = 0;
      __label__ = 102;
      break;
    }
   case 75:
    var $255 = HEAPU32[HEAP32[$20 >> 2] >> 2];
    var $256 = ($switchOp_2 | 0) == 70;
    if ($256) {
      __label__ = 76;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 76:
    HEAP8[$top_0 + ($255 + 3) | 0] = $low_3 >>> 8 & 255;
    HEAP8[$top_0 + ($255 + 4) | 0] = $low_3 & 255;
    HEAP8[$top_0 + ($255 + 5) | 0] = $high_3 >>> 8 & 255;
    var $267 = $top_0 + ($255 + 6) | 0;
    HEAP8[$267] = $high_3 & 255;
    if (($tableLength_0 | 0) == 0) {
      var $table_0 = 0;
      var $pc_0 = $267;
      __label__ = 83;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 77:
    var $270 = $tableLength_0 << 2;
    var $271 = __ZN9JSContext7malloc_Ej($cx, $270);
    var $272 = $271;
    if (($271 | 0) == 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 78:
    _memset($271, 0, $270, 1);
    var $pn3_214 = HEAP32[$47 >> 2];
    if (($pn3_214 | 0) == 0) {
      var $table_0 = $272;
      var $pc_0 = $267;
      __label__ = 83;
      break;
    } else {
      var $pn3_215 = $pn3_214;
      __label__ = 79;
      break;
    }
   case 79:
    var $pn3_215;
    var $277 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn3_215, 39);
    if ($277) {
      __label__ = 81;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 80:
    var $_idx = HEAP32[$pn3_215 + 40 >> 2] | 0;
    var $st$4$0 = $_idx | 0;
    var $_idx_val$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAP32[$st$4$1 >> 2];
    var $282 = __ZNK2JS5Value7toInt32Ev($_idx_val$0, $_idx_val$1);
    var $284 = $272 + ($282 - $low_3 << 2) | 0;
    HEAP32[$284 >> 2] = $pn3_215;
    __label__ = 81;
    break;
   case 81:
    var $pn3_2 = HEAPU32[$pn3_215 + 24 >> 2];
    if (($pn3_2 | 0) == 0) {
      var $table_0 = $272;
      var $pc_0 = $267;
      __label__ = 83;
      break;
    } else {
      var $pn3_215 = $pn3_2;
      __label__ = 79;
      break;
    }
   case 82:
    HEAP8[$top_0 + ($255 + 3) | 0] = $caseCount_2 >>> 8 & 255;
    var $293 = $top_0 + ($255 + 4) | 0;
    HEAP8[$293] = $caseCount_2 & 255;
    var $table_0 = 0;
    var $pc_0 = $293;
    __label__ = 83;
    break;
   case 83:
    var $pc_0;
    var $table_0;
    if ((HEAP32[$cg + 208 >> 2] | 0) == 0) {
      __label__ = 85;
      break;
    } else {
      __label__ = 84;
      break;
    }
   case 84:
    var $301 = HEAP32[HEAP32[$20 >> 2] >> 2] + $top_0 | 0;
    var $302 = __ZL17AddSwitchSpanDepsP9JSContextP15JSCodeGeneratorPh($cx, $cg, $301);
    if (($302 | 0) == 0) {
      var $ok_9 = 0;
      var $table_2 = $table_0;
      __label__ = 131;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 85:
    if (($constPropagated_4 | 0) == 0) {
      var $off_2 = -1;
      var $defaultOffset_0 = -1;
      var $table_1 = $table_0;
      __label__ = 102;
      break;
    } else {
      __label__ = 86;
      break;
    }
   case 86:
    var $308 = HEAP32[$20 >> 2] + 8 | 0;
    var $309 = HEAP32[$308 >> 2];
    HEAP32[$308 >> 2] = $pc_0 + 1 | 0;
    if ($256) {
      var $i_1 = 0;
      var $pc_1 = $pc_0;
      __label__ = 87;
      break;
    } else {
      __label__ = 94;
      break;
    }
   case 87:
    var $pc_1;
    var $i_1;
    if (($i_1 | 0) < ($tableLength_0 | 0)) {
      __label__ = 88;
      break;
    } else {
      __label__ = 101;
      break;
    }
   case 88:
    var $314 = HEAP32[$table_0 + ($i_1 << 2) >> 2];
    if (($314 | 0) == 0) {
      __label__ = 93;
      break;
    } else {
      __label__ = 89;
      break;
    }
   case 89:
    var $318 = HEAP32[$314 + 32 >> 2];
    if (($318 | 0) == 0) {
      __label__ = 93;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 90:
    var $321 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($318, 29);
    if ($321) {
      __label__ = 91;
      break;
    } else {
      __label__ = 93;
      break;
    }
   case 91:
    var $325 = HEAP32[$318 + 32 >> 2];
    var $326 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $325, $index);
    if ($326) {
      __label__ = 92;
      break;
    } else {
      var $table_26 = $table_0;
      var $ok_97 = 0;
      __label__ = 132;
      break;
    }
   case 92:
    var $329 = HEAP32[$20 >> 2] + 8 | 0;
    HEAP32[$329 >> 2] = $pc_1;
    var $330 = HEAP32[$index >> 2];
    var $331 = _js_NewSrcNote2($cx, $cg, 13, $330);
    if (($331 | 0) < 0) {
      var $ok_9 = 0;
      var $table_2 = $table_0;
      __label__ = 131;
      break;
    } else {
      __label__ = 93;
      break;
    }
   case 93:
    var $i_1 = $i_1 + 1 | 0;
    var $pc_1 = $pc_1 + 2 | 0;
    __label__ = 87;
    break;
   case 94:
    var $pn3_3_in = $47 | 0;
    var $pc_2 = $pc_0;
    __label__ = 95;
    break;
   case 95:
    var $pc_2;
    var $pn3_3_in;
    var $pn3_3 = HEAP32[$pn3_3_in >> 2];
    if (($pn3_3 | 0) == 0) {
      __label__ = 101;
      break;
    } else {
      __label__ = 96;
      break;
    }
   case 96:
    var $342 = HEAP32[$pn3_3 + 32 >> 2];
    if (($342 | 0) == 0) {
      __label__ = 100;
      break;
    } else {
      __label__ = 97;
      break;
    }
   case 97:
    var $345 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($342, 29);
    if ($345) {
      __label__ = 98;
      break;
    } else {
      __label__ = 100;
      break;
    }
   case 98:
    var $349 = HEAP32[$342 + 32 >> 2];
    var $350 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $349, $index1);
    if ($350) {
      __label__ = 99;
      break;
    } else {
      var $ok_9 = 0;
      var $table_2 = $table_0;
      __label__ = 131;
      break;
    }
   case 99:
    var $353 = HEAP32[$20 >> 2] + 8 | 0;
    HEAP32[$353 >> 2] = $pc_2;
    var $354 = HEAP32[$index1 >> 2];
    var $355 = _js_NewSrcNote2($cx, $cg, 13, $354);
    if (($355 | 0) < 0) {
      var $ok_9 = 0;
      var $table_2 = $table_0;
      __label__ = 131;
      break;
    } else {
      __label__ = 100;
      break;
    }
   case 100:
    var $pn3_3_in = $pn3_3 + 24 | 0;
    var $pc_2 = $pc_2 + 4 | 0;
    __label__ = 95;
    break;
   case 101:
    var $361 = HEAP32[$20 >> 2] + 8 | 0;
    HEAP32[$361 >> 2] = $309;
    var $off_2 = -1;
    var $defaultOffset_0 = -1;
    var $table_1 = $table_0;
    __label__ = 102;
    break;
   case 102:
    var $table_1;
    var $defaultOffset_0;
    var $off_2;
    var $363 = $47 | 0;
    var $off_3 = $off_2;
    var $pn3_4_in = $363;
    __label__ = 103;
    break;
   case 103:
    var $pn3_4_in;
    var $off_3;
    var $pn3_4 = HEAP32[$pn3_4_in >> 2];
    if (($pn3_4 | 0) == 0) {
      __label__ = 109;
      break;
    } else {
      __label__ = 104;
      break;
    }
   case 104:
    if ($169) {
      __label__ = 105;
      break;
    } else {
      __label__ = 107;
      break;
    }
   case 105:
    var $368 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn3_4, 39);
    if ($368) {
      __label__ = 107;
      break;
    } else {
      __label__ = 106;
      break;
    }
   case 106:
    var $370 = HEAP32[$20 >> 2];
    var $372 = HEAP32[$370 >> 2];
    var $374 = HEAP32[$pn3_4 + 20 >> 2];
    var $375 = $372 + $374 | 0;
    var $380 = HEAP32[$370 + 8 >> 2] - ($372 + $374) | 0;
    var $381 = _js_SetJumpOffset($cx, $cg, $375, $380);
    if (($381 | 0) == 0) {
      var $ok_9 = 0;
      var $table_2 = $table_1;
      __label__ = 131;
      break;
    } else {
      __label__ = 107;
      break;
    }
   case 107:
    var $385 = HEAP32[$pn3_4 + 36 >> 2];
    var $386 = $385;
    var $387 = _js_EmitTree($cx, $cg, $386);
    if (($387 | 0) == 0) {
      var $ok_9 = 0;
      var $table_2 = $table_1;
      __label__ = 131;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 108:
    var $392 = HEAP32[$385 + 20 >> 2];
    var $393 = $pn3_4 + 20 | 0;
    HEAP32[$393 >> 2] = $392;
    var $394 = $392 - $top_0 | 0;
    var $395 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn3_4, 39);
    var $_off_3 = $395 ? $394 : $off_3;
    var $off_3 = $_off_3;
    var $pn3_4_in = $pn3_4 + 24 | 0;
    __label__ = 103;
    break;
   case 109:
    var $399 = HEAP32[$20 >> 2];
    if (($hasDefault_4 | 0) == 0) {
      __label__ = 111;
      break;
    } else {
      __label__ = 110;
      break;
    }
   case 110:
    var $off_5 = $off_3;
    var $410 = HEAP32[$399 >> 2];
    __label__ = 112;
    break;
   case 111:
    var $404 = HEAP32[$399 >> 2];
    var $off_5 = HEAP32[$399 + 8 >> 2] - $top_0 - $404 | 0;
    var $410 = $404;
    __label__ = 112;
    break;
   case 112:
    var $410;
    var $off_5;
    if ($169) {
      __label__ = 113;
      break;
    } else {
      __label__ = 114;
      break;
    }
   case 113:
    var $415 = _js_SetJumpOffset($cx, $cg, $410 + $defaultOffset_0 | 0, $top_0 - $defaultOffset_0 + $off_5 | 0);
    if (($415 | 0) == 0) {
      var $ok_9 = 0;
      var $table_2 = $table_1;
      __label__ = 131;
      break;
    } else {
      var $pc_3 = 0;
      __label__ = 116;
      break;
    }
   case 114:
    var $419 = _js_SetJumpOffset($cx, $cg, $410 + $top_0 | 0, $off_5);
    if (($419 | 0) == 0) {
      var $ok_9 = 0;
      var $table_2 = $table_1;
      __label__ = 131;
      break;
    } else {
      __label__ = 115;
      break;
    }
   case 115:
    var $pc_3 = $top_0 + ($410 + 2) | 0;
    __label__ = 116;
    break;
   case 116:
    var $pc_3;
    var $424 = HEAP32[$20 >> 2];
    var $432 = HEAP32[$424 + 8 >> 2] - $top_0 - HEAP32[$424 >> 2] | 0;
    var $433 = _js_SetSrcNoteOffset($cx, $cg, $166, 0, $432);
    if (($433 | 0) == 0) {
      var $ok_9 = 0;
      var $table_2 = $table_1;
      __label__ = 131;
      break;
    } else {
      __label__ = 117;
      break;
    }
   case 117:
    if (($switchOp_2 | 0) == 70) {
      __label__ = 118;
      break;
    } else if (($switchOp_2 | 0) == 71) {
      __label__ = 124;
      break;
    } else {
      var $ok_9 = $433;
      var $table_2 = $table_1;
      __label__ = 131;
      break;
    }
   case 118:
    var $ok_6 = $433;
    var $i_2 = 0;
    var $pc_4 = $pc_3 + 4 | 0;
    __label__ = 119;
    break;
   case 119:
    var $pc_4;
    var $i_2;
    var $ok_6;
    if (($i_2 | 0) < ($tableLength_0 | 0)) {
      __label__ = 120;
      break;
    } else {
      var $ok_9 = $ok_6;
      var $table_2 = $table_1;
      __label__ = 131;
      break;
    }
   case 120:
    var $442 = HEAP32[$table_1 + ($i_2 << 2) >> 2];
    if (($442 | 0) == 0) {
      var $449 = 0;
      __label__ = 122;
      break;
    } else {
      __label__ = 121;
      break;
    }
   case 121:
    var $449 = HEAP32[$442 + 20 >> 2] - $top_0 | 0;
    __label__ = 122;
    break;
   case 122:
    var $449;
    var $450 = _js_SetJumpOffset($cx, $cg, $pc_4, $449);
    if (($450 | 0) == 0) {
      var $ok_9 = 0;
      var $table_2 = $table_1;
      __label__ = 131;
      break;
    } else {
      __label__ = 123;
      break;
    }
   case 123:
    var $ok_6 = $450;
    var $i_2 = $i_2 + 1 | 0;
    var $pc_4 = $pc_4 + 2 | 0;
    __label__ = 119;
    break;
   case 124:
    var $457 = $cg + 268 | 0;
    var $ok_7 = $433;
    var $pn3_5_in = $363;
    var $pc_5 = $pc_3 + 2 | 0;
    __label__ = 125;
    break;
   case 125:
    var $pc_5;
    var $pn3_5_in;
    var $ok_7;
    var $pn3_5 = HEAPU32[$pn3_5_in >> 2];
    if (($pn3_5 | 0) == 0) {
      var $ok_9 = $ok_7;
      var $table_2 = $table_1;
      __label__ = 131;
      break;
    } else {
      __label__ = 126;
      break;
    }
   case 126:
    var $461 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn3_5, 39);
    if ($461) {
      var $ok_8 = $ok_7;
      var $pc_6 = $pc_5;
      __label__ = 130;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 127:
    var $466 = HEAP32[$pn3_5 + 40 >> 2] | 0;
    var $st$4$0 = $466 | 0;
    var $467$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $466 + 4 | 0;
    var $467$1 = HEAP32[$st$4$1 >> 2];
    var $468 = __ZN13JSGCConstList6appendEN2JS5ValueE($457, $467$0, $467$1);
    if ($468) {
      __label__ = 128;
      break;
    } else {
      var $ok_9 = 0;
      var $table_2 = $table_1;
      __label__ = 131;
      break;
    }
   case 128:
    var $470 = __ZNK13JSGCConstList6lengthEv($457);
    HEAP8[$pc_5 + 1 | 0] = ($470 + 65535 | 0) >>> 8 & 255;
    var $475 = __ZNK13JSGCConstList6lengthEv($457);
    var $478 = $pc_5 + 2 | 0;
    HEAP8[$478] = $475 + 255 & 255;
    var $481 = HEAP32[$pn3_5 + 20 >> 2] - $top_0 | 0;
    var $482 = _js_SetJumpOffset($cx, $cg, $478, $481);
    if (($482 | 0) == 0) {
      var $ok_9 = 0;
      var $table_2 = $table_1;
      __label__ = 131;
      break;
    } else {
      __label__ = 129;
      break;
    }
   case 129:
    var $ok_8 = $482;
    var $pc_6 = $pc_5 + 4 | 0;
    __label__ = 130;
    break;
   case 130:
    var $pc_6;
    var $ok_8;
    var $ok_7 = $ok_8;
    var $pn3_5_in = $pn3_5 + 24 | 0;
    var $pc_5 = $pc_6;
    __label__ = 125;
    break;
   case 131:
    var $table_2;
    var $ok_9;
    if (($table_2 | 0) == 0) {
      var $ok_98 = $ok_9;
      __label__ = 133;
      break;
    } else {
      var $table_26 = $table_2;
      var $ok_97 = $ok_9;
      __label__ = 132;
      break;
    }
   case 132:
    var $ok_97;
    var $table_26;
    __ZN9JSContext5free_EPv($table_26);
    var $ok_98 = $ok_97;
    __label__ = 133;
    break;
   case 133:
    var $ok_98;
    if (($ok_98 | 0) == 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 134;
      break;
    }
   case 134:
    var $493 = _js_PopStatementCG($cx, $cg);
    if (($493 | 0) == 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 135;
      break;
    }
   case 135:
    var $497 = HEAP32[$1 >> 2];
    var $498 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($497, 80);
    if ($498) {
      __label__ = 136;
      break;
    } else {
      var $_0 = $493;
      __label__ = 137;
      break;
    }
   case 136:
    var $500 = __ZL14EmitLeaveBlockP9JSContextP15JSCodeGenerator4JSOpP11JSObjectBox($cx, $cg, 202, $box_0);
    var $_0 = $500;
    __label__ = 137;
    break;
   case 137:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10EmitSwitchP9JSContextP15JSCodeGeneratorP11JSParseNodeP10JSStmtInfo["X"] = 1;

function __ZL11EmitTraceOpP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $nextpn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($nextpn | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($nextpn, 25);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $_01 = $nextpn;
      __label__ = 6;
      break;
    }
   case 3:
    var $5 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($nextpn, 5);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_01 = $nextpn;
      __label__ = 6;
      break;
    }
   case 4:
    var $8 = HEAP32[$nextpn + 32 >> 2];
    if (($8 | 0) == 0) {
      var $_01 = $nextpn;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_01 = $8;
    __label__ = 6;
    break;
   case 6:
    var $_01;
    var $13 = HEAP32[$_01 + 8 >> 2];
    var $14 = __ZL21UpdateLineNumberNotesP9JSContextP15JSCodeGeneratorj($cx, $cg, $13);
    if (($14 | 0) == 0) {
      var $_0 = -1;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $17 = $cg + 612 | 0;
    var $18 = HEAPU16[$17 >> 1];
    if ($18 << 16 >> 16 == -1) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP16[$17 >> 1] = $18 + 1 & 65535;
    __label__ = 9;
    break;
   case 9:
    var $24 = ($18 & 65535) >>> 8 & 255;
    var $25 = $18 & 255;
    var $26 = _js_Emit3($cx, $cg, 109, $24, $25);
    var $_0 = $26;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN12TempPopScopeC1Ev($this) {
  __ZN12TempPopScopeC2Ev($this);
  return;
}

function __ZNK2js11UpvarCookie9asIntegerEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2jsL15TokenKindIsDeclENS_9TokenKindE($tt) {
  return ($tt | 0) == 46 | ($tt | 0) == 81;
}

function __ZNK11JSParseNode4exprEv($this_0_7_0_1_val) {
  return $this_0_7_0_1_val;
}

function __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, $op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[_js_CodeSpec + ($op << 3) + 4 >> 2] & 67108864 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cg + 614 | 0;
    var $7 = HEAP16[$6 >> 1];
    if ($7 << 16 >> 16 == -1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $7 + 1 & 65535;
    HEAP16[$6 >> 1] = $10;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN12TempPopScope8popBlockEP9JSContextP15JSCodeGenerator($this, $cx, $cg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg | 0;
    var $2 = $cg + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    HEAP32[$this >> 2] = $3;
    var $6 = HEAP32[$cg + 28 >> 2];
    HEAP32[$this + 4 >> 2] = $6;
    var $9 = HEAP32[$cg + 32 >> 2];
    HEAP32[$this + 8 >> 2] = $9;
    if ((HEAP16[HEAP32[$2 >> 2] >> 1] - 12 & 65535 & 65535) < 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _js_PopStatement($1);
    __label__ = 3;
    break;
   case 3:
    _js_PopStatement($1);
    var $16 = _js_Emit1($cx, $cg, 0);
    if (($16 | 0) > -1) {
      __label__ = 4;
      break;
    } else {
      var $22 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $19 = __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg);
    var $22 = ($19 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $22;
    return $22;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN12TempPopScope11repushBlockEP9JSContextP15JSCodeGenerator($this, $cx, $cg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    HEAP32[$cg + 24 >> 2] = $2;
    var $5 = HEAP32[$this + 4 >> 2];
    HEAP32[$cg + 28 >> 2] = $5;
    var $8 = HEAP32[$this + 8 >> 2];
    HEAP32[$cg + 32 >> 2] = $8;
    var $10 = _js_Emit1($cx, $cg, 0);
    if (($10 | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      var $16 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $13 = __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg);
    var $16 = ($13 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $16;
    return $16;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14EmitAssignmentP9JSContextP15JSCodeGeneratorP11JSParseNode4JSOpS4_($cx, $cg, $lhs, $op, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $atomIndex = __stackBase__;
    var $1 = $cg + 172 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $7 = HEAP32[$2 + 8 >> 2];
    var $8 = HEAP32[$2 >> 2];
    HEAP32[$atomIndex >> 2] = -1;
    var $9 = __ZNK11JSParseNode7getKindEv($lhs);
    if (($9 | 0) == 29) {
      __label__ = 2;
      break;
    } else if (($9 | 0) == 22) {
      __label__ = 8;
      break;
    } else if (($9 | 0) == 23) {
      __label__ = 10;
      break;
    } else if (($9 | 0) == 27) {
      __label__ = 12;
      break;
    } else if (($9 | 0) == 19) {
      __label__ = 13;
      break;
    } else {
      var $offset_0 = 1;
      __label__ = 15;
      break;
    }
   case 2:
    var $11 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $lhs);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$lhs + 40 >> 2];
    var $15 = __ZNK2js11UpvarCookie6isFreeEv($_idx_val);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = __ZNK2js11UpvarCookie9asIntegerEv($_idx_val);
    HEAP32[$atomIndex >> 2] = $17;
    var $offset_0 = 1;
    __label__ = 15;
    break;
   case 5:
    var $21 = HEAP32[$lhs + 32 >> 2];
    var $22 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $21, $atomIndex);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 57;
      break;
    }
   case 6:
    var $24 = __ZNK11JSParseNode7isConstEv($lhs);
    if ($24) {
      var $offset_0 = 1;
      __label__ = 15;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $26 = __ZNK11JSParseNode4isOpE4JSOp($lhs, 157);
    var $27 = $26 ? 217 : 110;
    var $28 = HEAP32[$atomIndex >> 2];
    var $29 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $27, $28, $cg, 0);
    if ($29) {
      var $offset_0 = 2;
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 57;
      break;
    }
   case 8:
    var $lhs_idx_val = HEAP32[$lhs + 36 >> 2];
    var $31 = __ZNK11JSParseNode4exprEv($lhs_idx_val);
    var $32 = _js_EmitTree($cx, $cg, $31);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $37 = HEAP32[$lhs + 32 >> 2];
    var $38 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $37, $atomIndex);
    if ($38) {
      var $offset_0 = 2;
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 57;
      break;
    }
   case 10:
    var $41 = HEAP32[$lhs + 32 >> 2];
    var $42 = _js_EmitTree($cx, $cg, $41);
    if (($42 | 0) == 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $47 = HEAP32[$lhs + 36 >> 2];
    var $48 = _js_EmitTree($cx, $cg, $47);
    if (($48 | 0) == 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      var $offset_0 = 3;
      __label__ = 15;
      break;
    }
   case 12:
    var $51 = _js_EmitTree($cx, $cg, $lhs);
    if (($51 | 0) == 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      var $offset_0 = 2;
      __label__ = 15;
      break;
    }
   case 13:
    var $55 = HEAP32[$lhs + 32 >> 2];
    var $56 = _js_EmitTree($cx, $cg, $55);
    if (($56 | 0) == 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $59 = _js_Emit1($cx, $cg, 172);
    if (($59 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      var $offset_0 = 2;
      __label__ = 15;
      break;
    }
   case 15:
    var $offset_0;
    var $62 = ($op | 0) != 0;
    if ($62) {
      __label__ = 16;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 16:
    var $64 = __ZNK11JSParseNode7getKindEv($lhs);
    if (($64 | 0) == 29) {
      __label__ = 17;
      break;
    } else if (($64 | 0) == 22) {
      __label__ = 29;
      break;
    } else if (($64 | 0) == 23 || ($64 | 0) == 27 || ($64 | 0) == 19) {
      __label__ = 34;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 17:
    var $66 = __ZNK11JSParseNode7isConstEv($lhs);
    if ($66) {
      __label__ = 18;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 18:
    var $68 = __ZNK11JSParseNode4isOpE4JSOp($lhs, 131);
    if ($68) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $70 = _js_Emit1($cx, $cg, 131);
    if (($70 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 20:
    var $73 = __ZNK11JSParseNode5getOpEv($lhs);
    var $74 = HEAP32[$atomIndex >> 2];
    var $75 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $73, $74, $cg, 0);
    if ($75) {
      __label__ = 36;
      break;
    } else {
      var $_0 = 0;
      __label__ = 57;
      break;
    }
   case 21:
    var $77 = __ZNK11JSParseNode4isOpE4JSOp($lhs, 111);
    if ($77) {
      __label__ = 22;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 22:
    var $79 = _js_Emit1($cx, $cg, 12);
    if (($79 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $82 = HEAP32[$atomIndex >> 2];
    var $83 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 198, $82, $cg, 0);
    if ($83) {
      __label__ = 36;
      break;
    } else {
      var $_0 = 0;
      __label__ = 57;
      break;
    }
   case 24:
    var $85 = __ZNK11JSParseNode4isOpE4JSOp($lhs, 157);
    if ($85) {
      __label__ = 25;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 25:
    var $89 = HEAP32[$lhs + 32 >> 2];
    var $90 = __ZL10BindGlobalP9JSContextP15JSCodeGeneratorP11JSParseNodeP6JSAtom($cg, $lhs, $89);
    if ($90) {
      __label__ = 26;
      break;
    } else {
      var $_0 = 0;
      __label__ = 57;
      break;
    }
   case 26:
    var $92 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $lhs, 156, $cg, 0);
    __label__ = 36;
    break;
   case 27:
    var $94 = __ZNK11JSParseNode4isOpE4JSOp($lhs, 85);
    var $95 = $94 ? 84 : 86;
    var $96 = HEAPU32[$atomIndex >> 2];
    var $98 = $96 >>> 8 & 255;
    var $99 = $96 & 255;
    var $100 = _js_Emit3($cx, $cg, $95, $98, $99);
    if (($100 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $103 = __ZNK11JSParseNode4isOpE4JSOp($lhs, 85);
    var $104 = $103 ? 84 : 86;
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, $104);
    __label__ = 36;
    break;
   case 29:
    var $106 = _js_Emit1($cx, $cg, 12);
    if (($106 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $111 = HEAPU32[$lhs + 32 >> 2];
    var $113 = HEAP32[$cx + 52 >> 2];
    if (($111 | 0) == (HEAP32[$113 + 210292 >> 2] | 0)) {
      __label__ = 31;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 31:
    var $119 = HEAP32[$atomIndex >> 2];
    var $120 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 165, $119, $cg, 0);
    if ($120) {
      __label__ = 32;
      break;
    } else {
      var $_0 = 0;
      __label__ = 57;
      break;
    }
   case 32:
    var $122 = __ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp($cx, $cg, 55);
    if ($122) {
      __label__ = 36;
      break;
    } else {
      var $_0 = 0;
      __label__ = 57;
      break;
    }
   case 33:
    var $128 = ($111 | 0) == (HEAP32[$113 + 210256 >> 2] | 0) ? 220 : 53;
    var $129 = HEAP32[$atomIndex >> 2];
    var $130 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $128, $129, $cg, 0);
    if ($130) {
      __label__ = 36;
      break;
    } else {
      var $_0 = 0;
      __label__ = 57;
      break;
    }
   case 34:
    var $132 = _js_Emit1($cx, $cg, 13);
    if (($132 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $135 = __ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp($cx, $cg, 55);
    if ($135) {
      __label__ = 36;
      break;
    } else {
      var $_0 = 0;
      __label__ = 57;
      break;
    }
   case 36:
    var $137 = ($rhs | 0) != 0;
    if ($137) {
      __label__ = 37;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 37:
    var $139 = _js_EmitTree($cx, $cg, $rhs);
    if (($139 | 0) == 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 38:
    var $142 = _js_Emit2($cx, $cg, 77, $offset_0);
    if (($142 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    if ($62) {
      __label__ = 40;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 40:
    var $146 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($lhs, 29);
    if ($146) {
      __label__ = 41;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 41:
    var $148 = __ZNK11JSParseNode7isConstEv($lhs);
    if ($148) {
      __label__ = 43;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $150 = _js_NewSrcNote($cx, $cg, 8);
    if (($150 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    var $153 = _js_Emit1($cx, $cg, $op);
    if (($153 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $156 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($lhs, 29);
    if ($156) {
      __label__ = 48;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $158 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($lhs, 24);
    if ($158) {
      __label__ = 48;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $160 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($lhs, 26);
    if ($160) {
      __label__ = 48;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $162 = HEAP32[$1 >> 2];
    var $171 = $8 - $7 + HEAP32[$162 + 8 >> 2] - HEAP32[$162 >> 2] | 0;
    var $172 = _js_NewSrcNote2($cx, $cg, 12, $171);
    if (($172 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    var $175 = __ZNK11JSParseNode7getKindEv($lhs);
    if (($175 | 0) == 29) {
      __label__ = 49;
      break;
    } else if (($175 | 0) == 22) {
      __label__ = 52;
      break;
    } else if (($175 | 0) == 23 || ($175 | 0) == 27) {
      __label__ = 53;
      break;
    } else if (($175 | 0) == 24 || ($175 | 0) == 26) {
      __label__ = 54;
      break;
    } else if (($175 | 0) == 19) {
      __label__ = 55;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 49:
    var $177 = __ZNK11JSParseNode7isConstEv($lhs);
    if ($177) {
      __label__ = 50;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 50:
    if ($137) {
      __label__ = 56;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $182 = HEAP32[$cg + 48 >> 2] + 40 | 0;
    var $183 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($182, $lhs, 0, 117, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 57;
    break;
   case 52:
    var $184 = __ZNK11JSParseNode5getOpEv($lhs);
    var $185 = HEAP32[$atomIndex >> 2];
    var $186 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $184, $185, $cg, 0);
    if ($186) {
      __label__ = 56;
      break;
    } else {
      var $_0 = 0;
      __label__ = 57;
      break;
    }
   case 53:
    var $188 = _js_Emit1($cx, $cg, 56);
    if (($188 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 54:
    var $191 = __ZL20EmitDestructuringOpsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode($cx, $cg, 111, $lhs);
    if (($191 | 0) == 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 55:
    var $194 = _js_Emit1($cx, $cg, 173);
    if (($194 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    var $_0 = 1;
    __label__ = 57;
    break;
   case 57:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14EmitAssignmentP9JSContextP15JSCodeGeneratorP11JSParseNode4JSOpS4_["X"] = 1;

function __ZNK11JSParseNode4isOpE4JSOp($this, $op) {
  var $1 = __ZNK11JSParseNode5getOpEv($this);
  return ($1 | 0) == ($op | 0);
}

function __ZL24MaybeEmitGroupAssignmentP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodePS3_($cx, $cg, $prologOp, $pn_0_7_0_0_val, $pn_0_7_0_1_val, $pop) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $pn_0_7_0_1_val;
    var $2 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_0_7_0_0_val, 24);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 2:
    var $4 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($1, 24);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 3:
    if ((HEAP32[$pn_0_7_0_1_val + 44 >> 2] & 1024 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 4:
    if (HEAPU32[$pn_0_7_0_0_val + 40 >> 2] >>> 0 > HEAPU32[$pn_0_7_0_1_val + 40 >> 2] >>> 0) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = __ZL19EmitGroupAssignmentP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodeS5_($cx, $cg, $prologOp, $pn_0_7_0_0_val, $1);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    HEAP32[$pop >> 2] = 0;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10NewTryNoteP9JSContextP15JSCodeGenerator13JSTryNoteKindjjj($cx, $cg, $kind, $stackDepth, $start, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 88 >> 2];
    var $4 = HEAP32[$cx + 96 >> 2];
    var $7 = $4 + 16 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    if ($9 >>> 0 > (HEAP32[$2 + 8 >> 2] - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $15 = $cx + 72 | 0;
    var $16 = _JS_ArenaAllocate($15, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    var $21 = $_p_0;
    if (($_p_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    HEAP8[$21 | 0] = $kind & 255;
    HEAP16[$21 + 2 >> 1] = $stackDepth & 65535;
    HEAP32[$21 + 4 >> 2] = $start;
    HEAP32[$21 + 8 >> 2] = $end - $start | 0;
    var $32 = $cg + 204 | 0;
    var $33 = HEAP32[$32 >> 2];
    HEAP32[$21 + 12 >> 2] = $33;
    HEAP32[$32 >> 2] = $21;
    var $35 = $cg + 200 | 0;
    var $37 = HEAP32[$35 >> 2] + 1 | 0;
    HEAP32[$35 >> 2] = $37;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10NewTryNoteP9JSContextP15JSCodeGenerator13JSTryNoteKindjjj["X"] = 1;

function __ZL15EmitBackPatchOpP9JSContextP15JSCodeGenerator4JSOpPi($cx, $cg, $lastp) {
  var $2 = HEAP32[$cg + 172 >> 2];
  var $9 = HEAP32[$2 + 8 >> 2] - HEAP32[$2 >> 2] | 0;
  var $11 = $9 - HEAP32[$lastp >> 2] | 0;
  HEAP32[$lastp >> 2] = $9;
  var $12 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 151, $11);
  return $12;
}

function __ZL19EmitKnownBlockChainP9JSContextP15JSCodeGeneratorP11JSObjectBox($cx, $cg, $box) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($box | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$box + 16 >> 2];
    var $5 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 188, $4, $cg, 0);
    var $_0 = $5 & 1;
    __label__ = 4;
    break;
   case 3:
    var $8 = _js_Emit1($cx, $cg, 189);
    var $_0 = $8 >>> 31 ^ 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14EmitLeaveBlockP9JSContextP15JSCodeGenerator4JSOpP11JSObjectBox($cx, $cg, $op, $box) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$box + 8 >> 2];
    var $4 = __ZNK8JSObject13propertyCountEv($3);
    var $5 = $box + 16 | 0;
    var $6 = HEAP32[$5 >> 2];
    var $7 = __ZL18EmitBigIndexPrefixP9JSContextP15JSCodeGeneratorj($cx, $cg, $6);
    if (($7 | 0) == 66) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $4 & 65535;
    var $12 = HEAP32[$5 >> 2] & 65535;
    var $13 = _js_Emit5($cx, $cg, $op, $10, $12);
    if (($13 | 0) < 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($7 | 0) == 0) {
      var $21 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $18 = _js_Emit1($cx, $cg, $7);
    var $21 = ($18 | 0) > -1;
    __label__ = 5;
    break;
   case 5:
    var $21;
    var $_0 = $21 & 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21UpdateLineNumberNotesP9JSContextP15JSCodeGeneratorj($cx, $cg, $line) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$cg + 172 >> 2] + 28 | 0;
    var $4 = HEAP32[$3 >> 2];
    var $5 = $line - $4 | 0;
    if (($4 | 0) == ($line | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$3 >> 2] = $line;
    if ($5 >>> 0 < ((($line >>> 0 > 127 & 1) << 1) + 2 | 0) >>> 0) {
      var $delta__0 = $5;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = _js_NewSrcNote2($cx, $cg, 23, $line);
    if (($14 | 0) < 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $delta__0;
    var $16 = _js_NewSrcNote($cx, $cg, 22);
    if (($16 | 0) < 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = $delta__0 - 1 | 0;
    if (($19 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $delta__0 = $19;
      __label__ = 4;
      break;
    }
   case 6:
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20EmitDestructuringOpsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode($cx, $cg, $prologOp, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL12OpToDeclType4JSOp($prologOp);
    var $2 = _js_NewSrcNote2($cx, $cg, 6, $1);
    if (($2 | 0) < 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL26EmitDestructuringOpsHelperP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK11JSParseNode25isDirectivePrologueMemberEv($this_0_7_0_2_val) {
  return ($this_0_7_0_2_val | 0) != 0;
}

function __ZN11JSParseNode5setOpE4JSOp($this, $op) {
  var $1 = $this;
  var $6 = HEAP32[$1 >> 2] & -16711681 | $op << 16 & 16711680;
  HEAP32[$1 >> 2] = $6;
  return;
}

function __ZL13EmitVariablesP9JSContextP15JSCodeGeneratorP11JSParseNodeiPi($cx, $cg, $pn, $inLetHead, $headNoteIndex) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $op = __stackBase__;
    var $atomIndex = __stackBase__ + 4;
    HEAP32[$headNoteIndex >> 2] = -1;
    var $2 = $pn + 44 | 0;
    var $5 = (HEAP32[$2 >> 2] & 8 | 0) == 0;
    var $6 = $pn + 32 | 0;
    var $7 = HEAP32[$6 >> 2];
    var $8 = ($inLetHead | 0) == 0;
    var $9 = $cg | 0;
    var $10 = $cg + 172 | 0;
    var $11 = $pn + 40 | 0;
    var $pn2_0 = $7;
    var $noteIndex_0 = -1;
    var $off_0 = -1;
    var $13 = $7;
    __label__ = 2;
    break;
   case 2:
    var $13;
    var $off_0;
    var $noteIndex_0;
    var $pn2_0;
    var $14 = ($pn2_0 | 0) == ($13 | 0);
    var $16 = HEAPU32[$pn2_0 + 24 >> 2];
    var $17 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_0, 29);
    if ($17) {
      __label__ = 20;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $19 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_0, 24);
    if ($19) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $21 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_0, 26);
    if ($21) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $23 = __ZNK11JSParseNode5getOpEv($pn);
    var $24 = __ZL22EmitDestructuringDeclsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode($cx, $cg, $23, $pn2_0);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 6:
    var $27 = $pn2_0 + 32 | 0;
    var $28 = HEAP32[$27 >> 2];
    var $29 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($28, 29);
    if ($29) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $pn3_0 = HEAP32[$pn2_0 + 36 >> 2];
    var $pn2_1 = $28;
    __label__ = 21;
    break;
   case 8:
    if ((HEAP32[$11 >> 2] | 0) == 1) {
      __label__ = 9;
      break;
    } else {
      var $52 = $28;
      __label__ = 15;
      break;
    }
   case 9:
    HEAP32[$op >> 2] = 81;
    if ($8) {
      __label__ = 10;
      break;
    } else {
      var $41 = 81;
      __label__ = 11;
      break;
    }
   case 10:
    var $39 = __ZNK11JSParseNode5getOpEv($pn);
    var $41 = $39;
    __label__ = 11;
    break;
   case 11:
    var $41;
    var $pn2_0_idx1_val = HEAP32[$pn2_0 + 36 >> 2];
    var $42 = __ZL24MaybeEmitGroupAssignmentP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodePS3_($cx, $cg, $41, $28, $pn2_0_idx1_val, $op);
    if (($42 | 0) == 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[$op >> 2] | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $52 = HEAP32[$27 >> 2];
    __label__ = 15;
    break;
   case 14:
    var $50 = HEAP32[$2 >> 2] & -69 | 64;
    HEAP32[$2 >> 2] = $50;
    __label__ = 50;
    break;
   case 15:
    var $52;
    var $53 = __ZNK11JSParseNode5getOpEv($pn);
    var $54 = __ZL22EmitDestructuringDeclsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode($cx, $cg, $53, $52);
    if (($54 | 0) == 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $59 = HEAP32[$pn2_0 + 36 >> 2];
    var $60 = _js_EmitTree($cx, $cg, $59);
    if (($60 | 0) == 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    if ($8) {
      __label__ = 18;
      break;
    } else {
      var $66 = 81;
      __label__ = 19;
      break;
    }
   case 18:
    var $64 = __ZNK11JSParseNode5getOpEv($pn);
    var $66 = $64;
    __label__ = 19;
    break;
   case 19:
    var $66;
    var $67 = __ZL20EmitDestructuringOpsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode($cx, $cg, $66, $52);
    if (($67 | 0) == 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 20:
    var $70 = __ZN11JSParseNode9maybeExprEv($pn2_0);
    var $pn3_0 = $70;
    var $pn2_1 = $pn2_0;
    __label__ = 21;
    break;
   case 21:
    var $pn2_1;
    var $pn3_0;
    var $72 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn2_1);
    if (($72 | 0) == 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $75 = __ZNK11JSParseNode5getOpEv($pn2_1);
    HEAP32[$op >> 2] = $75;
    if (($75 | 0) == 9) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    HEAP32[$atomIndex >> 2] = 0;
    __label__ = 33;
    break;
   case 24:
    var $79 = __ZNK11JSParseNode5getOpEv($pn);
    var $80 = __ZL16MaybeEmitVarDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodePj($cx, $cg, $79, $pn2_1, $atomIndex);
    if ($80) {
      __label__ = 25;
      break;
    } else {
      var $_0 = 0;
      __label__ = 58;
      break;
    }
   case 25:
    if (($pn3_0 | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $84 = HEAP32[$op >> 2];
    if (($84 | 0) == 111) {
      __label__ = 27;
      break;
    } else if (($84 | 0) == 157) {
      __label__ = 28;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 27:
    var $86 = HEAP32[$atomIndex >> 2];
    var $87 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 110, $86, $cg, 0);
    if ($87) {
      __label__ = 29;
      break;
    } else {
      var $_0 = 0;
      __label__ = 58;
      break;
    }
   case 28:
    var $89 = HEAP32[$atomIndex >> 2];
    var $90 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 217, $89, $cg, 0);
    if ($90) {
      __label__ = 29;
      break;
    } else {
      var $_0 = 0;
      __label__ = 58;
      break;
    }
   case 29:
    var $92 = __ZNK11JSParseNode4isOpE4JSOp($pn, 128);
    if ($92) {
      __label__ = 30;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    var $96 = HEAP32[$pn2_1 + 32 >> 2];
    var $97 = _js_DefineCompileTimeConstant($cg, $96, $pn3_0);
    if (($97 | 0) == 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $100 = HEAP32[$9 >> 2];
    var $101 = $100 & -17;
    HEAP32[$9 >> 2] = $101;
    var $102 = _js_EmitTree($cx, $cg, $pn3_0);
    if (($102 | 0) == 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $107 = HEAP32[$9 >> 2] | $100 & 16;
    HEAP32[$9 >> 2] = $107;
    __label__ = 33;
    break;
   case 33:
    if ($5) {
      __label__ = 34;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 34:
    if ($14 & $8) {
      __label__ = 35;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 35:
    var $111 = __ZNK11JSParseNode4isOpE4JSOp($pn, 128);
    if ($111) {
      var $116 = 1;
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $113 = __ZNK11JSParseNode4isOpE4JSOp($pn, 129);
    var $114 = $113 ? 0 : 2;
    var $116 = $114;
    __label__ = 37;
    break;
   case 37:
    var $116;
    var $117 = _js_NewSrcNote2($cx, $cg, 6, $116);
    if (($117 | 0) < 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $119 = HEAPU32[$op >> 2];
    if (($119 | 0) == 9) {
      __label__ = 39;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 39:
    var $122 = _js_Emit1($cx, $cg, 9);
    if (($122 | 0) < 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 40:
    var $_idx_val = HEAP32[$pn2_1 + 40 >> 2];
    var $126 = __ZNK2js11UpvarCookie6isFreeEv($_idx_val);
    var $127 = HEAPU32[$atomIndex >> 2];
    if ($126) {
      __label__ = 43;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    var $130 = $127 >>> 8 & 255;
    var $131 = $127 & 255;
    var $132 = _js_Emit3($cx, $cg, $119, $130, $131);
    if (($132 | 0) < 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, $119);
    __label__ = 44;
    break;
   case 43:
    var $136 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $119, $127, $cg, 0);
    if ($136) {
      __label__ = 44;
      break;
    } else {
      var $_0 = 0;
      __label__ = 58;
      break;
    }
   case 44:
    var $138 = HEAP32[$10 >> 2];
    var $145 = HEAP32[$138 + 8 >> 2] - HEAP32[$138 >> 2] | 0;
    if (($noteIndex_0 | 0) > -1) {
      __label__ = 45;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 45:
    var $148 = $145 - $off_0 | 0;
    var $149 = _js_SetSrcNoteOffset($cx, $cg, $noteIndex_0, 0, $148);
    if (($149 | 0) == 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    if (($16 | 0) == 0) {
      __label__ = 50;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $154 = _js_NewSrcNote2($cx, $cg, 7, 0);
    if (($154 | 0) < 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    var $157 = _js_Emit1($cx, $cg, 81);
    if (($157 | 0) < 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $pn2_0 = $16;
    var $noteIndex_0 = $154;
    var $off_0 = $145;
    var $13 = HEAP32[$6 >> 2];
    __label__ = 2;
    break;
   case 50:
    if ($8) {
      __label__ = 51;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 51:
    var $169 = HEAP32[$2 >> 2];
    __label__ = 55;
    break;
   case 52:
    var $160 = _js_NewSrcNote($cx, $cg, 6);
    HEAP32[$headNoteIndex >> 2] = $160;
    if (($160 | 0) < 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    var $163 = HEAPU32[$2 >> 2];
    if (($163 & 4 | 0) == 0) {
      __label__ = 54;
      break;
    } else {
      var $169 = $163;
      __label__ = 55;
      break;
    }
   case 54:
    var $167 = _js_Emit1($cx, $cg, 0);
    var $_0 = $167 >>> 31 ^ 1;
    __label__ = 58;
    break;
   case 55:
    var $169;
    if (($169 & 4 | 0) == 0) {
      var $176 = 1;
      __label__ = 57;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    var $173 = _js_Emit1($cx, $cg, 81);
    var $176 = ($173 | 0) > -1;
    __label__ = 57;
    break;
   case 57:
    var $176;
    var $_0 = $176 & 1;
    __label__ = 58;
    break;
   case 58:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13EmitVariablesP9JSContextP15JSCodeGeneratorP11JSParseNodeiPi["X"] = 1;

function __ZL21EmitNonLocalJumpFixupP9JSContextP15JSCodeGeneratorP10JSStmtInfo($cx, $cg, $toStmt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $npops = __stackBase__;
    var $1 = $cg + 192 | 0;
    var $2 = HEAP32[$1 >> 2];
    HEAP32[$npops >> 2] = 0;
    var $stmt_0_in = $cg + 24 | 0;
    __label__ = 2;
    break;
   case 2:
    var $stmt_0_in;
    var $stmt_0 = HEAPU32[$stmt_0_in >> 2];
    if (($stmt_0 | 0) == ($toStmt | 0)) {
      __label__ = 23;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAPU16[$stmt_0 >> 1] & 65535;
    if (($9 | 0) == 9) {
      __label__ = 4;
      break;
    } else if (($9 | 0) == 6) {
      __label__ = 8;
      break;
    } else if (($9 | 0) == 13) {
      __label__ = 12;
      break;
    } else if (($9 | 0) == 10) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 4:
    if ((HEAP32[$npops >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = __ZL9FlushPopsP9JSContextP15JSCodeGeneratorPi($cx, $cg, $npops);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = _js_NewSrcNote($cx, $cg, 11);
    if (($17 | 0) < 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = $stmt_0 + 12 | 0;
    var $21 = __ZL15EmitBackPatchOpP9JSContextP15JSCodeGenerator4JSOpPi($cx, $cg, $20);
    if (($21 | 0) < 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 8:
    if ((HEAP32[$npops >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $27 = __ZL9FlushPopsP9JSContextP15JSCodeGeneratorPi($cx, $cg, $npops);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $30 = _js_NewSrcNote($cx, $cg, 11);
    if (($30 | 0) < 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $33 = _js_Emit1($cx, $cg, 4);
    if (($33 | 0) < 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 12:
    if ((HEAP32[$npops >> 2] | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $39 = __ZL9FlushPopsP9JSContextP15JSCodeGeneratorPi($cx, $cg, $npops);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $42 = _js_NewSrcNote($cx, $cg, 11);
    if (($42 | 0) < 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $45 = _js_Emit1($cx, $cg, 78);
    if (($45 | 0) < 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $49 = HEAP32[$npops >> 2] + 2 | 0;
    HEAP32[$npops >> 2] = $49;
    __label__ = 17;
    break;
   case 17:
    if ((HEAP16[$stmt_0 + 2 >> 1] & 1) << 16 >> 16 == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if ((HEAP32[$npops >> 2] | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $59 = __ZL9FlushPopsP9JSContextP15JSCodeGeneratorPi($cx, $cg, $npops);
    if (($59 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $62 = _js_NewSrcNote($cx, $cg, 11);
    if (($62 | 0) < 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $67 = HEAP32[$stmt_0 + 20 >> 2];
    var $68 = __ZL14EmitLeaveBlockP9JSContextP15JSCodeGenerator4JSOpP11JSObjectBox($cx, $cg, 202, $67);
    if (($68 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $stmt_0_in = $stmt_0 + 24 | 0;
    __label__ = 2;
    break;
   case 23:
    if ((HEAP32[$npops >> 2] | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $76 = __ZL9FlushPopsP9JSContextP15JSCodeGeneratorPi($cx, $cg, $npops);
    if (($76 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    HEAP32[$1 >> 2] = $2;
    var $_0 = 1;
    __label__ = 26;
    break;
   case 26:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL21EmitNonLocalJumpFixupP9JSContextP15JSCodeGeneratorP10JSStmtInfo["X"] = 1;

function __ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi($cx, $cg, $pn, $answer) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 52 | 0;
    var $pn_tr = $pn;
    __label__ = 2;
    break;
   case 2:
    var $pn_tr;
    if (($pn_tr | 0) == 0) {
      var $_0 = 1;
      __label__ = 60;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$answer >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 60;
      break;
    }
   case 4:
    var $7 = __ZNK11JSParseNode8getArityEv($pn_tr);
    if (($7 | 0) == 4) {
      __label__ = 5;
      break;
    } else if (($7 | 0) == 5) {
      __label__ = 6;
      break;
    } else if (($7 | 0) == 3) {
      __label__ = 14;
      break;
    } else if (($7 | 0) == 2) {
      __label__ = 18;
      break;
    } else if (($7 | 0) == 1) {
      __label__ = 35;
      break;
    } else if (($7 | 0) == 6) {
      __label__ = 44;
      break;
    } else if (($7 | 0) == 7) {
      __label__ = 57;
      break;
    } else if (($7 | 0) == 0) {
      __label__ = 58;
      break;
    } else {
      var $_0 = 1;
      __label__ = 60;
      break;
    }
   case 5:
    HEAP32[$answer >> 2] = 0;
    var $_0 = 1;
    __label__ = 60;
    break;
   case 6:
    var $10 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 0);
    if ($10) {
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $12 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 68);
    if ($12) {
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $14 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 69);
    if ($14) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $16 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 72);
    if ($16) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $18 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 73);
    if ($18) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $pn2_01 = HEAP32[$pn_tr + 32 >> 2];
    if (($pn2_01 | 0) == 0) {
      var $_0 = 1;
      __label__ = 60;
      break;
    } else {
      var $ok_02 = 1;
      var $pn2_03 = $pn2_01;
      __label__ = 12;
      break;
    }
   case 12:
    var $pn2_03;
    var $ok_02;
    var $22 = __ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi($cx, $cg, $pn2_03, $answer);
    var $23 = $22 & $ok_02;
    var $pn2_0 = HEAP32[$pn2_03 + 24 >> 2];
    if (($pn2_0 | 0) == 0) {
      var $_0 = $23;
      __label__ = 60;
      break;
    } else {
      var $ok_02 = $23;
      var $pn2_03 = $pn2_0;
      __label__ = 12;
      break;
    }
   case 13:
    HEAP32[$answer >> 2] = 1;
    var $_0 = 1;
    __label__ = 60;
    break;
   case 14:
    var $29 = HEAP32[$pn_tr + 32 >> 2];
    var $30 = __ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi($cx, $cg, $29, $answer);
    if (($30 | 0) == 0) {
      var $45 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $35 = HEAP32[$pn_tr + 36 >> 2];
    var $36 = __ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi($cx, $cg, $35, $answer);
    if (($36 | 0) == 0) {
      var $45 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $41 = HEAP32[$pn_tr + 40 >> 2];
    var $42 = __ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi($cx, $cg, $41, $answer);
    var $45 = ($42 | 0) != 0;
    __label__ = 17;
    break;
   case 17:
    var $45;
    var $_0 = $45 & 1;
    __label__ = 60;
    break;
   case 18:
    var $48 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_tr, 4);
    if ($48) {
      __label__ = 19;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 19:
    var $51 = HEAPU32[$pn_tr + 32 >> 2];
    var $52 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($51, 29);
    if ($52) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    HEAP32[$answer >> 2] = 1;
    var $_0 = 1;
    __label__ = 60;
    break;
   case 21:
    var $55 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $51);
    if (($55 | 0) == 0) {
      var $_0 = 0;
      __label__ = 60;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $60 = HEAP32[$pn_tr + 36 >> 2];
    var $61 = __ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi($cx, $cg, $60, $answer);
    if (($61 | 0) == 0) {
      var $_0 = 0;
      __label__ = 60;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    if ((HEAP32[$answer >> 2] | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 1;
      __label__ = 60;
      break;
    }
   case 24:
    var $67 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 0);
    if ($67) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    var $69 = __ZNK11JSParseNode7isConstEv($51);
    if ($69) {
      var $_0 = 1;
      __label__ = 60;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    HEAP32[$answer >> 2] = 1;
    var $_0 = 1;
    __label__ = 60;
    break;
   case 27:
    var $72 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 68);
    if ($72) {
      __label__ = 31;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $74 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 69);
    if ($74) {
      __label__ = 31;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $76 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 72);
    if ($76) {
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $78 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 73);
    if ($78) {
      __label__ = 31;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 31:
    var $81 = HEAP32[$pn_tr + 32 >> 2];
    var $82 = __ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi($cx, $cg, $81, $answer);
    if (($82 | 0) == 0) {
      var $91 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $87 = HEAP32[$pn_tr + 36 >> 2];
    var $88 = __ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi($cx, $cg, $87, $answer);
    var $91 = ($88 | 0) != 0;
    __label__ = 33;
    break;
   case 33:
    var $91;
    var $_0 = $91 & 1;
    __label__ = 60;
    break;
   case 34:
    HEAP32[$answer >> 2] = 1;
    var $_0 = 1;
    __label__ = 60;
    break;
   case 35:
    var $95 = __ZNK11JSParseNode7getKindEv($pn_tr);
    if (($95 | 0) == 50) {
      __label__ = 36;
      break;
    } else if (($95 | 0) == 19) {
      __label__ = 41;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 36:
    var $98 = HEAPU32[$pn_tr + 32 >> 2];
    var $99 = __ZNK11JSParseNode7getKindEv($98);
    if (($99 | 0) == 29) {
      __label__ = 37;
      break;
    } else if (($99 | 0) == 22 || ($99 | 0) == 73 || ($99 | 0) == 27 || ($99 | 0) == 23) {
      __label__ = 40;
      break;
    } else {
      var $pn_tr = $98;
      __label__ = 2;
      break;
    }
   case 37:
    var $101 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $98);
    if (($101 | 0) == 0) {
      var $_0 = 0;
      __label__ = 60;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $104 = __ZNK11JSParseNode7isConstEv($98);
    if ($104) {
      __label__ = 39;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 39:
    HEAP32[$answer >> 2] = 0;
    var $_0 = 1;
    __label__ = 60;
    break;
   case 40:
    HEAP32[$answer >> 2] = 1;
    var $_0 = 1;
    __label__ = 60;
    break;
   case 41:
    var $107 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 32);
    if ($107) {
      __label__ = 42;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 42:
    var $pn_tr = HEAP32[$pn_tr + 32 >> 2];
    __label__ = 2;
    break;
   case 43:
    HEAP32[$answer >> 2] = 1;
    var $_0 = 1;
    __label__ = 60;
    break;
   case 44:
    var $113 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_tr, 29);
    if ($113) {
      __label__ = 45;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 45:
    var $115 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 0);
    if ($115) {
      __label__ = 51;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $117 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn_tr);
    if (($117 | 0) == 0) {
      var $_0 = 0;
      __label__ = 60;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $120 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 9);
    if ($120) {
      __label__ = 51;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    var $122 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 131);
    if ($122) {
      __label__ = 51;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $_idx_val = HEAP32[$pn_tr + 40 >> 2];
    var $125 = __ZNK2js11UpvarCookie6isFreeEv($_idx_val);
    if ($125) {
      __label__ = 50;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 50:
    HEAP32[$answer >> 2] = 1;
    __label__ = 51;
    break;
   case 51:
    var $128 = __ZN11JSParseNode9maybeExprEv($pn_tr);
    var $129 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_tr, 22);
    if ($129) {
      __label__ = 52;
      break;
    } else {
      var $pn_tr = $128;
      __label__ = 2;
      break;
    }
   case 52:
    var $131 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($128, 29);
    if ($131) {
      __label__ = 53;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 53:
    var $133 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $128);
    if (($133 | 0) == 0) {
      var $_0 = 0;
      __label__ = 60;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    var $136 = __ZNK11JSParseNode4isOpE4JSOp($128, 9);
    if ($136) {
      __label__ = 55;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 55:
    if ((HEAP32[$pn_tr + 32 >> 2] | 0) == (HEAP32[HEAP32[$1 >> 2] + 210256 >> 2] | 0)) {
      var $pn_tr = $128;
      __label__ = 2;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    HEAP32[$answer >> 2] = 1;
    var $pn_tr = $128;
    __label__ = 2;
    break;
   case 57:
    var $pn_tr = HEAP32[$pn_tr + 36 >> 2];
    __label__ = 2;
    break;
   case 58:
    var $152 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_tr, 58);
    if ($152) {
      __label__ = 59;
      break;
    } else {
      var $_0 = 1;
      __label__ = 60;
      break;
    }
   case 59:
    HEAP32[$answer >> 2] = 1;
    var $_0 = 1;
    __label__ = 60;
    break;
   case 60:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi["X"] = 1;

function __ZL17SetBackPatchDeltaP9JSContextP15JSCodeGeneratorPhi($cx, $cg, $pc, $delta) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = (HEAP32[$cg + 208 >> 2] | 0) == 0;
    if ($3 & ($delta | 0) < 32767) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP8[$pc + 1 | 0] = $delta >>> 8 & 255;
    HEAP8[$pc + 2 | 0] = $delta & 255;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 3:
    if (($delta | 0) > 1073741823) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $cg_idx_val = HEAP32[$cg + 24 >> 2];
    __ZL23ReportStatementTooLargeP9JSContextP15JSCodeGenerator($cx, $cg_idx_val);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 5:
    if ($3) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $16 = __ZL17BuildSpanDepTableP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = __ZL10GetSpanDepP15JSCodeGeneratorPh($cg, $pc);
    HEAP32[$19 + 12 >> 2] = $delta << 1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13GetJumpOffsetP15JSCodeGeneratorPh($cg, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$cg + 208 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = ((HEAPU8[$pc + 1 | 0] & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255) << 16 >> 16;
    __label__ = 9;
    break;
   case 3:
    var $15 = __ZL10GetSpanDepP15JSCodeGeneratorPh($cg, $pc);
    var $18 = HEAP32[$15 + 12 >> 2];
    if (($18 & 1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = $18 >> 1;
    __label__ = 9;
    break;
   case 5:
    var $25 = HEAP32[$15 >> 2];
    var $sd_0 = $15;
    __label__ = 6;
    break;
   case 6:
    var $sd_0;
    var $27 = $sd_0 - 16 | 0;
    if ($27 >>> 0 < $2 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ((HEAP32[$27 >> 2] | 0) == ($25 | 0)) {
      var $sd_0 = $27;
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = HEAP32[($18 & -2) >> 2] - HEAP32[$sd_0 + 4 >> 2] | 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, $op, $cg, $psuffix) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $4 = HEAP32[$pn + 32 >> 2];
    if (($op | 0) == 53) {
      __label__ = 2;
      break;
    } else {
      var $_01 = $op;
      var $13 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    if (($4 | 0) == (HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0)) {
      __label__ = 3;
      break;
    } else {
      var $_01 = 53;
      var $13 = $4;
      __label__ = 4;
      break;
    }
   case 3:
    var $_01 = 220;
    var $13 = $4;
    __label__ = 4;
    break;
   case 4:
    var $13;
    var $_01;
    var $14 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $13, $index);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = HEAP32[$index >> 2];
    var $17 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $_01, $16, $cg, $psuffix);
    var $_0 = $17;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11EmitXMLNameP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn_0_7_0_0_val, $op, $cg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $2 & -17;
    HEAP32[$1 >> 2] = $3;
    var $4 = _js_EmitTree($cx, $cg, $pn_0_7_0_0_val);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$1 >> 2] | $2 & 16;
    HEAP32[$1 >> 2] = $9;
    var $11 = HEAP32[$cg + 172 >> 2];
    var $21 = HEAP32[$11 + 8 >> 2] - HEAP32[$pn_0_7_0_0_val + 20 >> 2] - HEAP32[$11 >> 2] | 0;
    var $22 = _js_NewSrcNote2($cx, $cg, 12, $21);
    if (($22 | 0) < 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $25 = _js_Emit1($cx, $cg, $op);
    var $_0 = $25 >>> 31 ^ 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14EmitNameIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn, $op, $cg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $suffix = __stackBase__;
    HEAP32[$suffix >> 2] = 0;
    var $1 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, $op, $cg, $suffix);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 2:
    var $3 = _js_Emit1($cx, $cg, 0);
    if (($3 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = $cg + 192 | 0;
    var $8 = HEAP32[$6 >> 2] - 1 | 0;
    HEAP32[$6 >> 2] = $8;
    var $9 = $cg + 172 | 0;
    var $10 = HEAP32[$9 >> 2];
    var $17 = HEAP32[$10 + 8 >> 2] - HEAP32[$10 >> 2] | 0;
    var $18 = HEAP32[$suffix >> 2];
    if (($18 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $21 = _js_Emit1($cx, $cg, $18);
    if (($21 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $25 = HEAPU32[_js_CodeSpec + ($op << 3) + 4 >> 2];
    var $27 = ($25 & 33554432 | 0) != 0;
    var $29 = ($25 & 4096 | 0) != 0;
    var $33 = ($25 >>> 11 & 1 ^ 1) + 27 | 0;
    var $34 = $27 ? 217 : 110;
    var $35 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, $34, $cg, 0);
    if ($35) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 6:
    var $37 = $27 ? 156 : 59;
    var $38 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, $37, $cg, 0);
    if ($38) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 7:
    var $40 = _js_Emit1($cx, $cg, 35);
    if (($40 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($29) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $44 = _js_Emit1($cx, $cg, 12);
    if (($44 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $47 = _js_Emit1($cx, $cg, 63);
    if (($47 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $50 = _js_Emit1($cx, $cg, $33);
    if (($50 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ($29) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $54 = _js_Emit2($cx, $cg, 133, 2);
    if (($54 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $57 = _js_Emit1($cx, $cg, 10);
    if (($57 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $60 = $27 ? 157 : 111;
    var $61 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, $60, $cg, 0);
    if ($61) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 16:
    if ($29) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $64 = _js_Emit1($cx, $cg, 81);
    if (($64 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $cg_idx_val = HEAP32[$9 >> 2];
    var $cg_idx_val_idx_val = HEAP32[$cg_idx_val >> 2];
    var $cg_idx_val_idx1_val = HEAP32[$cg_idx_val + 8 >> 2];
    __ZL21UpdateDecomposeLengthP15JSCodeGeneratorj($cg_idx_val_idx_val, $cg_idx_val_idx1_val, $17);
    var $67 = HEAP32[$suffix >> 2];
    if (($67 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $70 = _js_Emit1($cx, $cg, $67);
    if (($70 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14EmitNameIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator["X"] = 1;

function __ZNK11JSParseNode7isConstEv($this) {
  var $1 = __ZNK11JSParseNode4testEj($this, 2);
  return $1;
}

function __ZL14EmitPropIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn, $op, $cg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $suffix = __stackBase__;
    HEAP32[$suffix >> 2] = 0;
    var $1 = __ZL10EmitPropOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratoriPS3_($cx, $pn, $op, $cg, 0, $suffix);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _js_Emit1($cx, $cg, 0);
    if (($4 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $cg + 172 | 0;
    var $8 = HEAP32[$7 >> 2];
    var $15 = HEAP32[$8 + 8 >> 2] - HEAP32[$8 >> 2] | 0;
    var $16 = HEAP32[$suffix >> 2];
    if (($16 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = _js_Emit1($cx, $cg, $16);
    if (($19 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = HEAPU32[_js_CodeSpec + ($op << 3) + 4 >> 2];
    var $25 = ($23 & 4096 | 0) != 0;
    var $29 = ($23 >>> 11 & 1 ^ 1) + 27 | 0;
    var $30 = _js_Emit1($cx, $cg, 12);
    if (($30 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $33 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, 53, $cg, 0);
    if ($33) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 7:
    var $35 = _js_Emit1($cx, $cg, 35);
    if (($35 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($25) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $39 = _js_Emit1($cx, $cg, 12);
    if (($39 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $42 = _js_Emit1($cx, $cg, 63);
    if (($42 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $45 = _js_Emit1($cx, $cg, $29);
    if (($45 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ($25) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $49 = _js_Emit2($cx, $cg, 133, 2);
    if (($49 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $52 = _js_Emit1($cx, $cg, 10);
    if (($52 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $55 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, 54, $cg, 0);
    if ($55) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 16:
    if ($25) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $58 = _js_Emit1($cx, $cg, 81);
    if (($58 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $cg_idx_val = HEAP32[$7 >> 2];
    var $cg_idx_val_idx_val = HEAP32[$cg_idx_val >> 2];
    var $cg_idx_val_idx1_val = HEAP32[$cg_idx_val + 8 >> 2];
    __ZL21UpdateDecomposeLengthP15JSCodeGeneratorj($cg_idx_val_idx_val, $cg_idx_val_idx1_val, $15);
    var $61 = HEAP32[$suffix >> 2];
    if (($61 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $64 = _js_Emit1($cx, $cg, $61);
    if (($64 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14EmitPropIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator["X"] = 1;

function __ZL14EmitElemIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn, $op, $cg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($pn | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL10EmitElemOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn, $op, $cg);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp($cx, $cg, $op);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 4:
    var $8 = _js_Emit1($cx, $cg, 0);
    if (($8 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = $cg + 192 | 0;
    var $13 = HEAP32[$11 >> 2] + 1 | 0;
    HEAP32[$11 >> 2] = $13;
    var $14 = $cg + 172 | 0;
    var $15 = HEAP32[$14 >> 2];
    var $22 = HEAP32[$15 + 8 >> 2] - HEAP32[$15 >> 2] | 0;
    var $24 = HEAPU32[_js_CodeSpec + ($op << 3) + 4 >> 2];
    var $26 = ($24 & 4096 | 0) != 0;
    var $30 = ($24 >>> 11 & 1 ^ 1) + 27 | 0;
    var $31 = _js_Emit1($cx, $cg, 231);
    if (($31 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $34 = _js_Emit1($cx, $cg, 13);
    if (($34 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $37 = __ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp($cx, $cg, 55);
    if ($37) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 8:
    var $39 = _js_Emit1($cx, $cg, 35);
    if (($39 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ($26) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $43 = _js_Emit1($cx, $cg, 12);
    if (($43 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $46 = _js_Emit1($cx, $cg, 63);
    if (($46 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $49 = _js_Emit1($cx, $cg, $30);
    if (($49 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if ($26) {
      __label__ = 14;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 14:
    var $53 = _js_Emit2($cx, $cg, 133, 3);
    if (($53 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $56 = _js_Emit2($cx, $cg, 133, 3);
    if (($56 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $59 = _js_Emit2($cx, $cg, 133, 2);
    if (($59 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $62 = __ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp($cx, $cg, 56);
    if ($62) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 18:
    if ($26) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $65 = _js_Emit1($cx, $cg, 81);
    if (($65 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $cg_idx_val = HEAP32[$14 >> 2];
    var $cg_idx_val_idx_val = HEAP32[$cg_idx_val >> 2];
    var $cg_idx_val_idx1_val = HEAP32[$cg_idx_val + 8 >> 2];
    __ZL21UpdateDecomposeLengthP15JSCodeGeneratorj($cg_idx_val_idx_val, $cg_idx_val_idx1_val, $22);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14EmitElemIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator["X"] = 1;

function __ZL10EmitPropOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratoriPS3_($cx, $pn, $op, $cg, $callContext, $psuffix) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN11JSParseNode9maybeExprEv($pn);
    if (($op | 0) == 187 || ($op | 0) == 53) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    if ((HEAP32[$pn + 32 >> 2] | 0) == (HEAP32[HEAP32[$cx + 52 >> 2] + 210292 >> 2] | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    if (($1 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = _js_EmitTree($cx, $cg, $1);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = ($callContext | 0) != 0 ? 196 : 55;
    var $20 = __ZL17EmitSpecialPropOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn, $19, $cg);
    var $_0 = $20 & 1;
    __label__ = 29;
    break;
   case 6:
    var $_not = ($callContext | 0) != 0;
    var $_mux = $_not ? 187 : $op;
    if ($_not | ($op | 0) != 53) {
      var $_02 = $_mux;
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 22);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $_02 = $op;
      __label__ = 14;
      break;
    }
   case 8:
    var $26 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($1, 29);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      var $_02 = $op;
      __label__ = 14;
      break;
    }
   case 9:
    var $28 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $1);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $31 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($31) {
      var $_02 = $op;
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    if ((HEAP32[$pn + 32 >> 2] | 0) == (HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0)) {
      __label__ = 12;
      break;
    } else {
      var $_02 = $op;
      __label__ = 14;
      break;
    }
   case 12:
    var $43 = __ZNK11JSParseNode4isOpE4JSOp($1, 9);
    if ($43) {
      __label__ = 13;
      break;
    } else {
      var $_02 = $op;
      __label__ = 14;
      break;
    }
   case 13:
    var $45 = _js_Emit1($cx, $cg, 139);
    var $_0 = $45 >>> 31 ^ 1;
    __label__ = 29;
    break;
   case 14:
    var $_02;
    var $47 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($1, 22);
    if ($47) {
      __label__ = 15;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 15:
    var $49 = $cg + 172 | 0;
    var $50 = HEAP32[$49 >> 2];
    var $57 = HEAP32[$50 + 8 >> 2] - HEAP32[$50 >> 2] | 0;
    var $pnup_0 = 0;
    var $pndot_0 = $1;
    __label__ = 16;
    break;
   case 16:
    var $pndot_0;
    var $pnup_0;
    HEAP32[$pndot_0 + 20 >> 2] = $57;
    var $60 = $pndot_0 + 36 | 0;
    var $62 = HEAP32[$60 >> 2];
    HEAP32[$60 >> 2] = $pnup_0;
    var $63 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($62, 22);
    if ($63) {
      var $pnup_0 = $pndot_0;
      var $pndot_0 = $62;
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $65 = _js_EmitTree($cx, $cg, $62);
    if (($65 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $67 = $cx + 52 | 0;
    var $pndown_0 = $62;
    var $pndot_1 = $pndot_0;
    __label__ = 19;
    break;
   case 19:
    var $pndot_1;
    var $pndown_0;
    var $69 = HEAP32[$49 >> 2];
    var $79 = HEAP32[$69 + 8 >> 2] - HEAP32[$pndown_0 + 20 >> 2] - HEAP32[$69 >> 2] | 0;
    var $80 = _js_NewSrcNote2($cx, $cg, 12, $79);
    if (($80 | 0) < 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $83 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pndot_1, 6);
    if ($83) {
      __label__ = 21;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 21:
    if ((HEAP32[$pndot_1 + 32 >> 2] | 0) == (HEAP32[HEAP32[$67 >> 2] + 210292 >> 2] | 0)) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    var $94 = __ZL17EmitSpecialPropOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pndot_1, 55, $cg);
    if ($94) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 23:
    var $96 = __ZNK11JSParseNode5getOpEv($pndot_1);
    var $97 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pndot_1, $96, $cg, 0);
    if ($97) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 24:
    var $99 = $pndot_1 + 36 | 0;
    var $100 = HEAP32[$99 >> 2];
    var $101 = $100;
    HEAP32[$99 >> 2] = $pndown_0;
    if (($100 | 0) == 0) {
      var $_pre_phi = $49;
      __label__ = 27;
      break;
    } else {
      var $pndown_0 = $pndot_1;
      var $pndot_1 = $101;
      __label__ = 19;
      break;
    }
   case 25:
    var $104 = _js_EmitTree($cx, $cg, $1);
    if (($104 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $_pre_phi = $cg + 172 | 0;
    __label__ = 27;
    break;
   case 27:
    var $_pre_phi;
    var $106 = HEAP32[$_pre_phi >> 2];
    var $116 = HEAP32[$106 + 8 >> 2] - HEAP32[$1 + 20 >> 2] - HEAP32[$106 >> 2] | 0;
    var $117 = _js_NewSrcNote2($cx, $cg, 12, $116);
    if (($117 | 0) < 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $120 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, $_02, $cg, $psuffix);
    var $_0 = $120 & 1;
    __label__ = 29;
    break;
   case 29:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10EmitPropOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratoriPS3_["X"] = 1;

function __ZL10EmitElemOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn, $op, $cg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 100;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ltmp = __stackBase__;
    var $rtmp = __stackBase__ + 48;
    var $slot = __stackBase__ + 96;
    var $1 = $cg + 172 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $9 = HEAP32[$2 + 8 >> 2] - HEAP32[$2 >> 2] | 0;
    var $10 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 5);
    if ($10) {
      __label__ = 2;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 2:
    var $12 = $pn + 32 | 0;
    var $13 = HEAPU32[$12 >> 2];
    var $pn_idx_val = HEAP32[$pn + 36 >> 2];
    var $14 = __ZNK11JSParseNode4lastEv($pn_idx_val);
    var $16 = HEAPU32[$13 + 24 >> 2];
    var $17 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($13, 29);
    if ($17) {
      __label__ = 3;
      break;
    } else {
      var $next_0 = $16;
      var $left_0 = $13;
      __label__ = 13;
      break;
    }
   case 3:
    var $19 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($16, 30);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $next_0 = $16;
      var $left_0 = $13;
      __label__ = 13;
      break;
    }
   case 4:
    var $21 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $13);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 42;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = __ZNK11JSParseNode4isOpE4JSOp($13, 9);
    if ($24) {
      __label__ = 6;
      break;
    } else {
      var $next_0 = $16;
      var $left_0 = $13;
      __label__ = 13;
      break;
    }
   case 6:
    var $27 = $16 + 32 | 0;
    var $28 = (tempDoubleI32[0] = HEAP32[$27 >> 2], tempDoubleI32[1] = HEAP32[$27 + 4 >> 2], tempDoubleF64[0]);
    var $29 = _JSDOUBLE_IS_INT321163($28, $slot);
    var $31 = HEAPU32[$slot >> 2];
    if (($29 | 0) != 0 & $31 >>> 0 < 65536) {
      __label__ = 7;
      break;
    } else {
      var $next_0 = $16;
      var $left_0 = $13;
      __label__ = 13;
      break;
    }
   case 7:
    var $cx_idx1_val = HEAP8[$cx + 232 | 0];
    var $34 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx1_val);
    if ($34) {
      var $next_0 = $16;
      var $left_0 = $13;
      __label__ = 13;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx2_val = HEAP32[$cg >> 2];
    var $36 = __ZNK13JSTreeContext12inStrictModeEv($_idx2_val);
    if ($36) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $38 = __ZNK13JSTreeContext16mutatesParameterEv($_idx2_val);
    if ($38) {
      var $next_0 = $16;
      var $left_0 = $13;
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $40 = __ZNK13JSTreeContext9callsEvalEv($_idx2_val);
    if ($40) {
      var $next_0 = $16;
      var $left_0 = $13;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    HEAP32[$16 + 20 >> 2] = $9;
    HEAP32[$13 + 20 >> 2] = $9;
    var $45 = $31 >>> 8 & 255;
    var $46 = $31 & 255;
    var $47 = _js_Emit3($cx, $cg, 138, $45, $46);
    if (($47 | 0) < 0) {
      var $_0 = 0;
      __label__ = 42;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, 138);
    var $next_0 = HEAP32[$16 + 24 >> 2];
    var $left_0 = $16;
    __label__ = 13;
    break;
   case 13:
    var $left_0;
    var $next_0;
    if (($left_0 | 0) == (HEAP32[$12 >> 2] | 0)) {
      __label__ = 14;
      break;
    } else {
      var $next_1 = $next_0;
      __label__ = 15;
      break;
    }
   case 14:
    var $55 = _js_EmitTree($cx, $cg, $left_0);
    if (($55 | 0) == 0) {
      var $_0 = 0;
      __label__ = 42;
      break;
    } else {
      var $next_1 = $next_0;
      __label__ = 15;
      break;
    }
   case 15:
    var $next_1;
    if (($next_1 | 0) == ($14 | 0)) {
      var $right_1 = $14;
      __label__ = 39;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $59 = _js_EmitTree($cx, $cg, $next_1);
    if (($59 | 0) == 0) {
      var $_0 = 0;
      __label__ = 42;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $62 = HEAP32[$1 >> 2];
    var $70 = HEAP32[$62 + 8 >> 2] - $9 - HEAP32[$62 >> 2] | 0;
    var $71 = _js_NewSrcNote2($cx, $cg, 12, $70);
    if (($71 | 0) < 0) {
      var $_0 = 0;
      __label__ = 42;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $74 = __ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp($cx, $cg, 55);
    if ($74) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 42;
      break;
    }
   case 19:
    var $next_1 = HEAP32[$next_1 + 24 >> 2];
    __label__ = 15;
    break;
   case 20:
    var $79 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 6);
    if ($79) {
      __label__ = 21;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 21:
    var $81 = __ZN11JSParseNode9maybeExprEv($pn);
    if (($81 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $left_1 = $81;
    var $_pre_phi13 = $pn + 32 | 0;
    var $_pre_phi17 = $pn + 4 | 0;
    __label__ = 24;
    break;
   case 23:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($ltmp, 31);
    __ZN11JSParseNode5setOpE4JSOp($ltmp, 110);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($ltmp, 0);
    var $86 = $ltmp + 4 | 0;
    var $87 = $pn + 4 | 0;
    HEAP32[$86 >> 2] = HEAP32[$87 >> 2];
    HEAP32[$86 + 4 >> 2] = HEAP32[$87 + 4 >> 2];
    HEAP32[$86 + 8 >> 2] = HEAP32[$87 + 8 >> 2];
    HEAP32[$86 + 12 >> 2] = HEAP32[$87 + 12 >> 2];
    var $89 = $pn + 32 | 0;
    var $_c = HEAP32[$89 >> 2];
    HEAP32[$ltmp + 32 >> 2] = $_c;
    var $left_1 = $ltmp;
    var $_pre_phi13 = $89;
    var $_pre_phi17 = $87;
    __label__ = 24;
    break;
   case 24:
    var $_pre_phi17;
    var $_pre_phi13;
    var $left_1;
    __ZN11JSParseNode7setKindEN2js9TokenKindE($rtmp, 31);
    var $94 = HEAP32[$_pre_phi13 >> 2] | 0;
    var $95 = __Z15js_IsIdentifierP14JSLinearString($94);
    var $97 = ($95 | 0) != 0 ? 165 : 61;
    __ZN11JSParseNode5setOpE4JSOp($rtmp, $97);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($rtmp, 0);
    var $99 = $rtmp + 4 | 0;
    HEAP32[$99 >> 2] = HEAP32[$_pre_phi17 >> 2];
    HEAP32[$99 + 4 >> 2] = HEAP32[$_pre_phi17 + 4 >> 2];
    HEAP32[$99 + 8 >> 2] = HEAP32[$_pre_phi17 + 8 >> 2];
    HEAP32[$99 + 12 >> 2] = HEAP32[$_pre_phi17 + 12 >> 2];
    var $_c4 = HEAP32[$_pre_phi13 >> 2];
    HEAP32[$rtmp + 32 >> 2] = $_c4;
    var $right_0 = $rtmp;
    var $left_2 = $left_1;
    __label__ = 26;
    break;
   case 25:
    var $right_0 = HEAP32[$pn + 36 >> 2];
    var $left_2 = HEAP32[$pn + 32 >> 2];
    __label__ = 26;
    break;
   case 26:
    var $left_2;
    var $right_0;
    if (($op | 0) == 55) {
      __label__ = 27;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 27:
    var $111 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($left_2, 29);
    if ($111) {
      __label__ = 28;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 28:
    var $113 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($right_0, 30);
    if ($113) {
      __label__ = 29;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 29:
    var $115 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $left_2);
    if (($115 | 0) == 0) {
      var $_0 = 0;
      __label__ = 42;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $118 = __ZNK11JSParseNode4isOpE4JSOp($left_2, 9);
    if ($118) {
      __label__ = 31;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 31:
    var $121 = $right_0 + 32 | 0;
    var $122 = (tempDoubleI32[0] = HEAP32[$121 >> 2], tempDoubleI32[1] = HEAP32[$121 + 4 >> 2], tempDoubleF64[0]);
    var $123 = _JSDOUBLE_IS_INT321163($122, $slot);
    if (($123 | 0) != 0 & HEAPU32[$slot >> 2] >>> 0 < 65536) {
      __label__ = 32;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 32:
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $128 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($128) {
      __label__ = 38;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $_idx_val = HEAP32[$cg >> 2];
    var $130 = __ZNK13JSTreeContext12inStrictModeEv($_idx_val);
    if ($130) {
      __label__ = 34;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 34:
    var $132 = __ZNK13JSTreeContext16mutatesParameterEv($_idx_val);
    if ($132) {
      __label__ = 38;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $134 = __ZNK13JSTreeContext9callsEvalEv($_idx_val);
    if ($134) {
      __label__ = 38;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    HEAP32[$right_0 + 20 >> 2] = $9;
    HEAP32[$left_2 + 20 >> 2] = $9;
    var $138 = HEAPU32[$slot >> 2];
    var $140 = $138 >>> 8 & 255;
    var $141 = $138 & 255;
    var $142 = _js_Emit3($cx, $cg, 138, $140, $141);
    if (($142 | 0) < 0) {
      var $_0 = 0;
      __label__ = 42;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, 138);
    var $_0 = 1;
    __label__ = 42;
    break;
   case 38:
    var $146 = _js_EmitTree($cx, $cg, $left_2);
    if (($146 | 0) == 0) {
      var $_0 = 0;
      __label__ = 42;
      break;
    } else {
      var $right_1 = $right_0;
      __label__ = 39;
      break;
    }
   case 39:
    var $right_1;
    var $148 = _js_EmitTree($cx, $cg, $right_1);
    if (($148 | 0) == 0) {
      var $_0 = 0;
      __label__ = 42;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $151 = HEAP32[$1 >> 2];
    var $159 = HEAP32[$151 + 8 >> 2] - $9 - HEAP32[$151 >> 2] | 0;
    var $160 = _js_NewSrcNote2($cx, $cg, 12, $159);
    if (($160 | 0) < 0) {
      var $_0 = 0;
      __label__ = 42;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    var $163 = __ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp($cx, $cg, $op);
    var $_0 = $163 & 1;
    __label__ = 42;
    break;
   case 42:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10EmitElemOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator["X"] = 1;

function __ZL10EmitNameOpP9JSContextP15JSCodeGeneratorP11JSParseNodei($cx, $cg, $pn, $callContext) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK11JSParseNode5getOpEv($pn);
    var $5 = ($callContext | 0) != 0;
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    if (($4 | 0) == 156) {
      __label__ = 4;
      break;
    } else if (($4 | 0) == 84) {
      __label__ = 5;
      break;
    } else if (($4 | 0) == 86) {
      __label__ = 6;
      break;
    } else if (($4 | 0) == 136) {
      __label__ = 7;
      break;
    } else if (($4 | 0) == 59) {
      var $op_02 = 57;
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $op_02 = 214;
    __label__ = 12;
    break;
   case 5:
    var $op_02 = 216;
    __label__ = 12;
    break;
   case 6:
    var $op_02 = 215;
    __label__ = 12;
    break;
   case 7:
    var $op_02 = 137;
    __label__ = 12;
    break;
   case 8:
    if (($4 | 0) == 131 || ($4 | 0) == 9) {
      __label__ = 9;
      break;
    } else {
      var $op_02 = $4;
      __label__ = 12;
      break;
    }
   case 9:
    var $13 = _js_Emit1($cx, $cg, $4);
    if (($13 | 0) < 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ($5) {
      __label__ = 11;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 11:
    var $17 = _js_Emit1($cx, $cg, 1);
    if (($17 | 0) < 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 12:
    var $op_02;
    var $_idx_val = HEAP32[$pn + 40 >> 2];
    var $20 = __ZNK2js11UpvarCookie6isFreeEv($_idx_val);
    if ($20) {
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $22 = __ZNK2js11UpvarCookie9asIntegerEv($_idx_val);
    var $24 = $22 >>> 8 & 255;
    var $25 = $22 & 255;
    var $26 = _js_Emit3($cx, $cg, $op_02, $24, $25);
    if (($26 | 0) < 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, $op_02);
    __label__ = 16;
    break;
   case 15:
    var $30 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, $op_02, $cg, 0);
    if ($30) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 16:
    var $_0 = 1;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK15JSCodeGenerator9hasSharpsEv($this_0_0_0_val) {
  return ($this_0_0_0_val & 32768 | 0) != 0;
}

function __ZNK13JSTreeContext12compileAndGoEv($this_0_0_val) {
  return ($this_0_0_val & 8192 | 0) != 0;
}

function __ZL19FitsWithoutBigIndexj($index) {
  return $index >>> 0 < 65536;
}

function __ZL14EmitEnterBlockP9JSContextP11JSParseNodeP15JSCodeGenerator($cx, $pn, $cg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $3 = $pn + 32 | 0;
    var $4 = HEAP32[$3 >> 2];
    var $5 = __ZL12EmitObjectOpP9JSContextP11JSObjectBox4JSOpP15JSCodeGenerator($cx, $4, 201, $cg);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAPU32[HEAP32[$3 >> 2] + 8 >> 2];
    var $11 = __ZNK8JSObject12getFixedSlotEj($10, 0);
    var $_idx = $11 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $12 = __ZNK2JS5Value7toInt32Ev($_idx_val$0, $_idx_val$1);
    var $13 = __ZL15AdjustBlockSlotP9JSContextP15JSCodeGeneratori($cg, $12);
    if (($13 | 0) < 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $18 = HEAPU32[__ZN2js10BlockClassE + 4 >> 2] >>> 8 & 255;
    var $19 = $10;
    var $20 = __ZNK8JSObject13propertyCountEv($19);
    if ($18 >>> 0 < ($18 + $20 | 0) >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $23 = $20 + $18 | 0;
    var $_idx2 = $1 | 0;
    var $slot_01 = $18;
    __label__ = 5;
    break;
   case 5:
    var $slot_01;
    var $25 = __ZNK8JSObject7getSlotEj($10, $slot_01);
    var $_idx1 = $25 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $26 = __ZNK2JS5Value11isUndefinedEv($_idx1_val$0, $_idx1_val$1);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $28 = __ZNK2JS5Value9toPrivateEv($_idx1_val$0, $_idx1_val$1);
    var $29 = $28;
    var $30 = $28 + 40 | 0;
    var $31 = $30;
    var $_idx5_val = HEAP32[$30 >> 2];
    var $32 = __ZNK2js11UpvarCookie5levelEv($_idx5_val);
    var $33 = __ZNK11JSParseNode9frameSlotEv($29);
    var $35 = $33 + $13 & 65535;
    __ZN2js11UpvarCookie3setEtt($31, $32, $35);
    var $36 = __ZN15JSCodeGenerator20shouldNoteClosedNameEP11JSParseNode($cg, $29);
    __ZN2JSL12BooleanValueEb1168($1, $36);
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($10, $slot_01, $_idx2_val$0, $_idx2_val$1);
    __label__ = 7;
    break;
   case 7:
    var $38 = $slot_01 + 1 | 0;
    if (($38 | 0) == ($23 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $slot_01 = $38;
      __label__ = 5;
      break;
    }
   case 8:
    if ((HEAP32[$cg >> 2] & 536870912 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $_idx4_val = HEAP8[$cg + 102 | 0];
    var $44 = __ZNK2js8Bindings17extensibleParentsEv($_idx4_val);
    if ($44) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 10:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN8JSObject16setBlockOwnShapeEP9JSContext($10, $cx_idx_val);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14EmitEnterBlockP9JSContextP11JSParseNodeP15JSCodeGenerator["X"] = 1;

function __ZL15AdjustBlockSlotP9JSContextP15JSCodeGeneratori($cg, $slot) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx1_val = HEAP32[$cg >> 2];
    var $1 = __ZNK13JSTreeContext10inFunctionEv($_idx1_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $slot;
      __label__ = 4;
      break;
    }
   case 2:
    var $_idx_val = HEAP16[$cg + 98 >> 1];
    var $3 = __ZNK2js8Bindings9countVarsEv($_idx_val);
    var $5 = ($3 & 65535) + $slot | 0;
    if ($5 >>> 0 > 65535) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $5;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = HEAP32[$cg + 48 >> 2] + 40 | 0;
    var $11 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($10, 0, 0, 199, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = -1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11EmitNewInitP9JSContextP15JSCodeGenerator10JSProtoKeyP11JSParseNodei($cx, $cg, $key, $pn, $sharpnum) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $key & 255;
    var $2 = _js_Emit3($cx, $cg, 89, $1, 0);
    if (($2 | 0) < 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $cg_idx_val = HEAP32[$cg >> 2];
    var $5 = __ZNK15JSCodeGenerator9hasSharpsEv($cg_idx_val);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 3:
    if ((HEAP32[$pn + 40 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = HEAPU32[$cg + 104 >> 2];
    var $14 = $12 >>> 8 & 255;
    var $15 = $12 & 255;
    var $16 = _js_Emit3($cx, $cg, 230, $14, $15);
    if (($16 | 0) < 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, 230);
    __label__ = 6;
    break;
   case 6:
    if (($sharpnum | 0) > -1) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 7:
    var $22 = _js_EmitN($cx, $cg, 95, 4);
    if (($22 | 0) < 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $28 = HEAPU32[HEAP32[$cg + 172 >> 2] >> 2];
    var $29 = $cg + 104 | 0;
    HEAP8[$22 + ($28 + 1) | 0] = HEAPU32[$29 >> 2] >>> 8 & 255;
    HEAP8[$22 + ($28 + 2) | 0] = HEAP32[$29 >> 2] & 255;
    HEAP8[$22 + ($28 + 3) | 0] = $sharpnum >>> 8 & 255;
    HEAP8[$22 + ($28 + 4) | 0] = $sharpnum & 255;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11EmitNewInitP9JSContextP15JSCodeGenerator10JSProtoKeyP11JSParseNodei["X"] = 1;

function __ZL11EmitEndInitP9JSContextP15JSCodeGeneratorj($cx, $cg, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cg_idx_val = HEAP32[$cg >> 2];
    var $1 = __ZNK15JSCodeGenerator9hasSharpsEv($cg_idx_val);
    if (($count | 0) == 0 | $1 ^ 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAPU32[$cg + 104 >> 2];
    var $7 = $5 >>> 8 & 255;
    var $8 = $5 & 255;
    var $9 = _js_Emit3($cx, $cg, 230, $7, $8);
    if (($9 | 0) < 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, 230);
    __label__ = 4;
    break;
   case 4:
    var $13 = _js_Emit1($cx, $cg, 92);
    var $_0 = ($13 | 0) > -1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN15JSCodeGenerator21checkSingletonContextEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx1 = $this | 0;
    var $_idx1_val = HEAPU32[$_idx1 >> 2];
    var $1 = __ZNK13JSTreeContext12compileAndGoEv($_idx1_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    var $3 = __ZNK13JSTreeContext10inFunctionEv($_idx1_val);
    if ($3) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $stmt_0_in = $this + 24 | 0;
    __label__ = 4;
    break;
   case 4:
    var $stmt_0_in;
    var $stmt_0 = HEAPU32[$stmt_0_in >> 2];
    if (($stmt_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAPU16[$stmt_0 >> 1] & 65535) > 10) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $stmt_0_in = $stmt_0 + 24 | 0;
    __label__ = 4;
    break;
   case 7:
    HEAP32[$_idx1 >> 2] = $_idx1_val | 134217728;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24EmitSingletonInitialiserP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $value = __stackBase__;
    var $1 = __ZN11JSParseNode16getConstantValueEP9JSContextbPN2JS5ValueE($pn, $cx, $value);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = HEAP32[$cg + 48 >> 2];
    var $value_idx = $value | 0;
    var $value_idx_val$0 = HEAP32[$value_idx >> 2];
    var $value_idx_val$1 = HEAP32[$value_idx + 4 >> 2];
    var $5 = __ZNK2JS5Value8toObjectEv($value_idx_val$0, $value_idx_val$1);
    var $6 = $4;
    var $7 = __ZN2js6Parser12newObjectBoxEP8JSObject($6, $5);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZL12EmitObjectOpP9JSContextP11JSObjectBox4JSOpP15JSCodeGenerator($cx, $7, 80, $cg);
    var $_0 = ($10 | 0) != 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12EmitNumberOpP9JSContextdP15JSCodeGenerator($cx, $dval, $cg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ival = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = _JSDOUBLE_IS_INT321163($dval, $ival);
    if (($2 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAPU32[$ival >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else if (($5 | 0) == 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $7 = _js_Emit1($cx, $cg, 62);
    var $_0 = $7 >>> 31 ^ 1;
    __label__ = 17;
    break;
   case 4:
    var $9 = _js_Emit1($cx, $cg, 63);
    var $_0 = $9 >>> 31 ^ 1;
    __label__ = 17;
    break;
   case 5:
    var $11 = $5 & 255;
    if (($11 << 24 >> 24 | 0) == ($5 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $15 = _js_Emit2($cx, $cg, 218, $11);
    var $_0 = $15 >>> 31 ^ 1;
    __label__ = 17;
    break;
   case 7:
    if ($5 >>> 0 < 65536) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $20 = $5 >>> 8 & 255;
    var $21 = _js_Emit3($cx, $cg, 88, $20, $11);
    if (($21 | 0) < 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, 88);
    var $_0 = 1;
    __label__ = 17;
    break;
   case 10:
    if ($5 >>> 0 < 16777216) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $27 = _js_EmitN($cx, $cg, 190, 3);
    if (($27 | 0) < 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $33 = HEAPU32[HEAP32[$cg + 172 >> 2] >> 2];
    HEAP8[$27 + ($33 + 1) | 0] = $5 >>> 16 & 255;
    HEAP8[$27 + ($33 + 2) | 0] = $5 >>> 8 & 255;
    HEAP8[$27 + ($33 + 3) | 0] = $11;
    var $_0 = 1;
    __label__ = 17;
    break;
   case 13:
    var $42 = _js_EmitN($cx, $cg, 219, 4);
    if (($42 | 0) < 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $48 = HEAPU32[HEAP32[$cg + 172 >> 2] >> 2];
    HEAP8[$42 + ($48 + 1) | 0] = $5 >>> 24 & 255;
    HEAP8[$42 + ($48 + 2) | 0] = $5 >>> 16 & 255;
    HEAP8[$42 + ($48 + 3) | 0] = $5 >>> 8 & 255;
    HEAP8[$42 + ($48 + 4) | 0] = $11;
    var $_0 = 1;
    __label__ = 17;
    break;
   case 15:
    var $60 = $cg + 268 | 0;
    __ZN2JSL11DoubleValueEd1164($1, $dval);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $61 = __ZN13JSGCConstList6appendEN2JS5ValueE($60, $_idx_val$0, $_idx_val$1);
    if ($61) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 16:
    var $63 = __ZNK13JSGCConstList6lengthEv($60);
    var $64 = $63 - 1 | 0;
    var $65 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 60, $64, $cg, 0);
    var $_0 = $65 & 1;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12EmitNumberOpP9JSContextdP15JSCodeGenerator["X"] = 1;

function __ZN2JSL14UndefinedValueEv1154($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZNK8JSObject16inDictionaryModeEv($this_0_0_val) {
  var $1 = __ZNK8JSObject12lastPropertyEv($this_0_0_val);
  var $_idx_val = HEAP8[$1 + 29 | 0];
  var $2 = __ZNK2js5Shape12inDictionaryEv($_idx_val);
  return $2;
}

function __ZL12EmitObjectOpP9JSContextP11JSObjectBox4JSOpP15JSCodeGenerator($cx, $objbox, $op, $cg) {
  var $1 = $cg + 292 | 0;
  var $2 = __ZN14JSCGObjectList5indexEP11JSObjectBox($1, $objbox);
  var $3 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $op, $2, $cg, 0);
  return $3 & 1;
}

function _js_SrcNoteLength($sn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU8[$sn];
    if (($1 & 255) > 191) {
      var $7 = 24;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = ($1 & 255) >>> 3;
    __label__ = 3;
    break;
   case 3:
    var $7;
    var $9 = HEAPU8[_js_SrcNoteSpec + ($7 << 3) + 4 | 0];
    var $_01 = $sn + 1 | 0;
    if ($9 << 24 >> 24 == 0) {
      var $_0_lcssa = $_01;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $arity_02 = $9 << 24 >> 24;
    var $sn_pn3 = $sn;
    var $_04 = $_01;
    __label__ = 5;
    break;
   case 5:
    var $_04;
    var $sn_pn3;
    var $arity_02;
    var $_1 = HEAP8[$_04] << 24 >> 24 < 0 ? $sn_pn3 + 3 | 0 : $_04;
    var $16 = $arity_02 - 1 | 0;
    var $_0 = $_1 + 1 | 0;
    if (($16 | 0) == 0) {
      var $_0_lcssa = $_0;
      __label__ = 6;
      break;
    } else {
      var $arity_02 = $16;
      var $sn_pn3 = $_1;
      var $_04 = $_0;
      __label__ = 5;
      break;
    }
   case 6:
    var $_0_lcssa;
    return $_0_lcssa - $sn | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_GetSrcNoteOffset($sn, $which) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_014 = $sn + 1 | 0;
    var $3 = HEAPU8[$_014] & 255;
    var $5 = ($3 & 128 | 0) != 0;
    if (($which | 0) == 0) {
      var $sn_pn_lcssa = $sn;
      var $_lcssa = $3;
      var $_lcssa3 = $5;
      __label__ = 3;
      break;
    } else {
      var $_025 = $which;
      var $sn_pn6 = $sn;
      var $_017 = $_014;
      var $6 = $5;
      __label__ = 2;
      break;
    }
   case 2:
    var $6;
    var $_017;
    var $sn_pn6;
    var $_025;
    var $_1 = $6 ? $sn_pn6 + 3 | 0 : $_017;
    var $8 = $_025 - 1 | 0;
    var $_01 = $_1 + 1 | 0;
    var $11 = HEAPU8[$_01] & 255;
    var $13 = ($11 & 128 | 0) != 0;
    if (($8 | 0) == 0) {
      var $sn_pn_lcssa = $_1;
      var $_lcssa = $11;
      var $_lcssa3 = $13;
      __label__ = 3;
      break;
    } else {
      var $_025 = $8;
      var $sn_pn6 = $_1;
      var $_017 = $_01;
      var $6 = $13;
      __label__ = 2;
      break;
    }
   case 3:
    var $_lcssa3;
    var $_lcssa;
    var $sn_pn_lcssa;
    if ($_lcssa3) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $_lcssa;
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = HEAPU8[$sn_pn_lcssa + 3 | 0] & 255 | $_lcssa << 16 & 8323072 | (HEAPU8[$sn_pn_lcssa + 2 | 0] & 255) << 8;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16OptimizeSpanDepsP9JSContextP15JSCodeGenerator($cx, $cg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $guard = __stackBase__;
    var $1 = $cg + 172 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $4 = HEAPU32[$2 >> 2];
    var $5 = $cg + 208 | 0;
    var $6 = HEAPU32[$5 >> 2];
    var $7 = $cg + 220 | 0;
    var $9 = $6 + (HEAP32[$7 >> 2] << 4) | 0;
    var $14 = HEAP32[$2 + 8 >> 2] - $4 | 0;
    var $15 = $cg + 212 | 0;
    var $growth_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $growth_0;
    var $pc_0 = 0;
    var $sd_0 = $6;
    var $sdtop_0 = 0;
    var $delta_0 = 0;
    var $top_0 = -1;
    var $pivot_0 = -1;
    var $done_0 = 1;
    var $op_0 = 0;
    var $type_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $type_0;
    var $op_0;
    var $done_0;
    var $pivot_0;
    var $top_0;
    var $delta_0;
    var $sdtop_0;
    var $sd_0;
    var $pc_0;
    if ($sd_0 >>> 0 < $9 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 4:
    var $20 = $sd_0 + 4 | 0;
    var $22 = HEAP32[$20 >> 2] + $delta_0 | 0;
    HEAP32[$20 >> 2] = $22;
    var $24 = HEAPU32[$sd_0 >> 2];
    if (($24 | 0) == ($top_0 | 0)) {
      var $pc_1 = $pc_0;
      var $sdtop_1 = $sdtop_0;
      var $top_1 = $top_0;
      var $pivot_1 = $pivot_0;
      var $op_1 = $op_0;
      var $type_1 = $type_0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $27 = $4 + $24 | 0;
    var $29 = HEAPU8[$27] & 255;
    var $32 = HEAP32[_js_CodeSpec + ($29 << 3) + 4 >> 2] & 31;
    if (($32 - 9 | 0) >>> 0 < 3) {
      var $pc_2 = $27;
      var $sd_1 = $sd_0;
      var $sdtop_2 = $sd_0;
      var $delta_2 = $delta_0;
      var $top_2 = $24;
      var $pivot_2 = $22;
      var $done_1 = $done_0;
      var $op_3 = $29;
      var $type_2 = $32;
      __label__ = 28;
      break;
    } else {
      var $pc_1 = $27;
      var $sdtop_1 = $sd_0;
      var $top_1 = $24;
      var $pivot_1 = $22;
      var $op_1 = $29;
      var $type_1 = $32;
      __label__ = 6;
      break;
    }
   case 6:
    var $type_1;
    var $op_1;
    var $pivot_1;
    var $top_1;
    var $sdtop_1;
    var $pc_1;
    if (($type_1 - 9 | 0) >>> 0 < 3) {
      var $pc_2 = $pc_1;
      var $sd_1 = $sd_0;
      var $sdtop_2 = $sdtop_1;
      var $delta_2 = $delta_0;
      var $top_2 = $top_1;
      var $pivot_2 = $pivot_1;
      var $done_1 = $done_0;
      var $op_3 = $op_1;
      var $type_2 = $type_1;
      __label__ = 28;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $42 = HEAP32[$sd_0 + 12 >> 2] & -2;
    if (($42 | 0) == 0) {
      var $pc_2 = $pc_1;
      var $sd_1 = $sd_0;
      var $sdtop_2 = $sdtop_1;
      var $delta_2 = $delta_0;
      var $top_2 = $top_1;
      var $pivot_2 = $pivot_1;
      var $done_1 = $done_0;
      var $op_3 = $op_1;
      var $type_2 = $type_1;
      __label__ = 28;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((32768 - $pivot_1 + HEAP32[$42 >> 2] | 0) >>> 0 > 65535) {
      __label__ = 9;
      break;
    } else {
      var $pc_2 = $pc_1;
      var $sd_1 = $sd_0;
      var $sdtop_2 = $sdtop_1;
      var $delta_2 = $delta_0;
      var $top_2 = $top_1;
      var $pivot_2 = $pivot_1;
      var $done_1 = $done_0;
      var $op_3 = $op_1;
      var $type_2 = $type_1;
      __label__ = 28;
      break;
    }
   case 9:
    if (($op_1 | 0) == 7) {
      __label__ = 10;
      break;
    } else if (($op_1 | 0) == 8) {
      __label__ = 11;
      break;
    } else if (($op_1 | 0) == 68) {
      __label__ = 12;
      break;
    } else if (($op_1 | 0) == 69) {
      __label__ = 13;
      break;
    } else if (($op_1 | 0) == 116) {
      __label__ = 14;
      break;
    } else if (($op_1 | 0) == 121) {
      __label__ = 15;
      break;
    } else if (($op_1 | 0) == 122) {
      __label__ = 16;
      break;
    } else if (($op_1 | 0) == 70) {
      __label__ = 17;
      break;
    } else if (($op_1 | 0) == 71) {
      __label__ = 18;
      break;
    } else if (($op_1 | 0) == 6) {
      var $op_2 = 141;
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 10:
    var $op_2 = 142;
    __label__ = 20;
    break;
   case 11:
    var $op_2 = 143;
    __label__ = 20;
    break;
   case 12:
    var $op_2 = 144;
    __label__ = 20;
    break;
   case 13:
    var $op_2 = 145;
    __label__ = 20;
    break;
   case 14:
    var $op_2 = 146;
    __label__ = 20;
    break;
   case 15:
    var $op_2 = 147;
    __label__ = 20;
    break;
   case 16:
    var $op_2 = 148;
    __label__ = 20;
    break;
   case 17:
    var $op_2 = 149;
    __label__ = 20;
    break;
   case 18:
    var $op_2 = 150;
    __label__ = 20;
    break;
   case 19:
    var $cg_idx6_val = HEAP32[$cg + 24 >> 2];
    __ZL23ReportStatementTooLargeP9JSContextP15JSCodeGenerator($cx, $cg_idx6_val);
    var $_0 = 0;
    __label__ = 82;
    break;
   case 20:
    var $op_2;
    HEAP8[$pc_1] = $op_2 & 255;
    var $deltaFromTop_0 = 0;
    var $sd2_0 = $sdtop_1;
    var $delta_1 = $delta_0;
    __label__ = 21;
    break;
   case 21:
    var $delta_1;
    var $sd2_0;
    var $deltaFromTop_0;
    if ($sd2_0 >>> 0 < $9 >>> 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 22:
    if ((HEAP32[$sd2_0 >> 2] | 0) == ($top_1 | 0)) {
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 23:
    var $70 = $sd2_0 + 4 | 0;
    var $71 = HEAP32[$70 >> 2];
    if ($sd2_0 >>> 0 > $sd_0 >>> 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $73 = $71 + $deltaFromTop_0 | 0;
    HEAP32[$70 >> 2] = $73;
    var $deltaFromTop_1 = $deltaFromTop_0 + 2 | 0;
    var $78 = $73;
    __label__ = 26;
    break;
   case 25:
    var $76 = $71 + $delta_1 | 0;
    HEAP32[$70 >> 2] = $76;
    var $deltaFromTop_1 = $deltaFromTop_0;
    var $78 = $76;
    __label__ = 26;
    break;
   case 26:
    var $78;
    var $deltaFromTop_1;
    var $79 = $delta_1 + 2 | 0;
    var $80 = HEAP32[$15 >> 2];
    __ZL17UpdateJumpTargetsP12JSJumpTargetii($80, $78);
    var $deltaFromTop_0 = $deltaFromTop_1;
    var $sd2_0 = $sd2_0 + 16 | 0;
    var $delta_1 = $79;
    __label__ = 21;
    break;
   case 27:
    var $pc_2 = $pc_1;
    var $sd_1 = $sd2_0 - 16 | 0;
    var $sdtop_2 = $sdtop_1;
    var $delta_2 = $delta_1;
    var $top_2 = $top_1;
    var $pivot_2 = $pivot_1;
    var $done_1 = 0;
    var $op_3 = $op_2;
    var $type_2 = $type_1;
    __label__ = 28;
    break;
   case 28:
    var $type_2;
    var $op_3;
    var $done_1;
    var $pivot_2;
    var $top_2;
    var $delta_2;
    var $sdtop_2;
    var $sd_1;
    var $pc_2;
    var $pc_0 = $pc_2;
    var $sd_0 = $sd_1 + 16 | 0;
    var $sdtop_0 = $sdtop_2;
    var $delta_0 = $delta_2;
    var $top_0 = $top_2;
    var $pivot_0 = $pivot_2;
    var $done_0 = $done_1;
    var $op_0 = $op_3;
    var $type_0 = $type_2;
    __label__ = 3;
    break;
   case 29:
    var $85 = $delta_0 + $growth_0 | 0;
    if (($done_0 | 0) == 0) {
      var $growth_0 = $85;
      __label__ = 2;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $88 = ($85 | 0) != 0;
    if ($88) {
      __label__ = 31;
      break;
    } else {
      var $base_1 = $4;
      __label__ = 36;
      break;
    }
   case 31:
    var $90 = HEAPU32[$1 >> 2];
    var $93 = $85 + $14 | 0;
    var $94 = $4 + $93 | 0;
    if ($94 >>> 0 > HEAPU32[$90 + 4 >> 2] >>> 0) {
      __label__ = 32;
      break;
    } else {
      var $base_0 = $4;
      var $next_0 = $94;
      var $107 = $90;
      __label__ = 35;
      break;
    }
   case 32:
    var $97 = __ZN9JSContext8realloc_EPvj($cx, $4, $93);
    if (($97 | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 33:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 82;
    break;
   case 34:
    var $102 = HEAP32[$1 >> 2] | 0;
    HEAP32[$102 >> 2] = $97;
    var $103 = $97 + $93 | 0;
    var $105 = HEAP32[$1 >> 2] + 4 | 0;
    HEAP32[$105 >> 2] = $103;
    var $base_0 = $97;
    var $next_0 = $103;
    var $107 = HEAP32[$1 >> 2];
    __label__ = 35;
    break;
   case 35:
    var $107;
    var $next_0;
    var $base_0;
    HEAP32[$107 + 8 >> 2] = $next_0;
    HEAP32[$guard >> 2] = -1;
    HEAP32[$guard + 4 >> 2] = $93;
    HEAP32[$guard + 8 >> 2] = $14;
    HEAP32[$guard + 12 >> 2] = 0;
    var $base_1 = $base_0;
    __label__ = 36;
    break;
   case 36:
    var $base_1;
    var $sd_2_ph = $sd_0;
    var $offset_0_ph = $14;
    var $top_3_ph = -1;
    var $pivot_3_ph = $pivot_0;
    var $type_3_ph = $type_0;
    __label__ = 37;
    break;
   case 37:
    var $type_3_ph;
    var $pivot_3_ph;
    var $top_3_ph;
    var $offset_0_ph;
    var $sd_2_ph;
    var $sd_2 = $sd_2_ph;
    var $top_3 = $top_3_ph;
    var $pivot_3 = $pivot_3_ph;
    var $type_3 = $type_3_ph;
    __label__ = 38;
    break;
   case 38:
    var $type_3;
    var $pivot_3;
    var $top_3;
    var $sd_2;
    var $115 = $sd_2 - 16 | 0;
    if ($115 >>> 0 < $6 >>> 0) {
      __label__ = 52;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $119 = HEAPU32[$115 >> 2];
    if (($119 | 0) == ($top_3 | 0)) {
      var $top_4 = $top_3;
      var $pivot_4 = $pivot_3;
      var $type_4 = $type_3;
      __label__ = 45;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $127 = HEAP32[_js_CodeSpec + ((HEAPU8[$base_1 + $119 | 0] & 255) << 3) + 4 >> 2] & 31;
    var $sd2_1 = $sd_2 - 32 | 0;
    __label__ = 41;
    break;
   case 41:
    var $sd2_1;
    if ($sd2_1 >>> 0 < $6 >>> 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    if ((HEAP32[$sd2_1 >> 2] | 0) == ($119 | 0)) {
      __label__ = 43;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 43:
    var $sd2_1 = $sd2_1 - 16 | 0;
    __label__ = 41;
    break;
   case 44:
    var $top_4 = $119;
    var $pivot_4 = HEAP32[$sd2_1 + 20 >> 2];
    var $type_4 = $127;
    __label__ = 45;
    break;
   case 45:
    var $type_4;
    var $pivot_4;
    var $top_4;
    var $141 = HEAPU32[$sd_2 - 16 + 8 >> 2];
    var $145 = HEAP32[$sd_2 - 16 + 12 >> 2] & -2;
    if (($145 | 0) == 0) {
      var $153 = 0;
      __label__ = 47;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $153 = HEAP32[$145 >> 2] - $pivot_4 | 0;
    __label__ = 47;
    break;
   case 47:
    var $153;
    if (($type_4 - 9 | 0) >>> 0 < 3) {
      __label__ = 49;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    HEAP8[$141 + ($base_1 + 1) | 0] = $153 >>> 8 & 255;
    HEAP8[$141 + ($base_1 + 2) | 0] = $153 & 255;
    var $sd_2 = $115;
    var $top_3 = $top_4;
    var $pivot_3 = $pivot_4;
    var $type_3 = $type_4;
    __label__ = 38;
    break;
   case 49:
    var $164 = HEAPU32[$sd_2 - 16 + 4 >> 2];
    var $166 = $141 + 1 | 0;
    var $167 = $offset_0_ph - $141 - 3 | 0;
    if (($167 | 0) == 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    var $170 = $164 + ($base_1 + 5) | 0;
    var $171 = $141 + ($base_1 + 3) | 0;
    _llvm_memmove_p0i8_p0i8_i32($170, $171, $167, 1, 0);
    __label__ = 51;
    break;
   case 51:
    HEAP8[$164 + ($base_1 + 1) | 0] = $153 >>> 24 & 255;
    HEAP8[$164 + ($base_1 + 2) | 0] = $153 >>> 16 & 255;
    HEAP8[$164 + ($base_1 + 3) | 0] = $153 >>> 8 & 255;
    HEAP8[$164 + ($base_1 + 4) | 0] = $153 & 255;
    var $sd_2_ph = $115;
    var $offset_0_ph = $166;
    var $top_3_ph = $top_4;
    var $pivot_3_ph = $pivot_4;
    var $type_3_ph = $type_4;
    __label__ = 37;
    break;
   case 52:
    if ($88) {
      __label__ = 53;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 53:
    var $186 = $cg + 152 | 0;
    var $187 = HEAP32[$186 >> 2];
    var $188 = $cg + 156 | 0;
    var $191 = $6;
    var $sd_3 = $6;
    var $snlimit_0 = $187 + HEAP32[$188 >> 2] | 0;
    var $sn_0 = $187;
    var $offset_1 = 0;
    var $growth_1 = 0;
    var $193 = $187;
    __label__ = 54;
    break;
   case 54:
    var $193;
    var $growth_1;
    var $offset_1;
    var $sn_0;
    var $snlimit_0;
    var $sd_3;
    if ($sn_0 >>> 0 < $snlimit_0 >>> 0) {
      __label__ = 55;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 55:
    var $196 = HEAPU8[$sn_0];
    var $_v = ($196 & 255) > 191 ? 63 : 7;
    var $200 = ($_v & ($196 & 255)) + $offset_1 | 0;
    var $sd_4_ph = $sd_3;
    var $snlimit_1_ph = $snlimit_0;
    var $sn_1_ph = $sn_0;
    var $growth_2_ph = $growth_1;
    var $201 = $193;
    __label__ = 56;
    break;
   case 56:
    var $201;
    var $growth_2_ph;
    var $sn_1_ph;
    var $snlimit_1_ph;
    var $sd_4_ph;
    var $sd_4 = $sd_4_ph;
    __label__ = 57;
    break;
   case 57:
    var $sd_4;
    if ($sd_4 >>> 0 < $9 >>> 0) {
      __label__ = 58;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 58:
    if ((HEAP32[$sd_4 + 8 >> 2] | 0) < ($200 | 0)) {
      __label__ = 59;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 59:
    var $209 = $sd_4 + 16 | 0;
    var $sd2_2 = ($209 | 0) == ($9 | 0) ? $guard : $209;
    var $215 = HEAP32[$sd2_2 + 4 >> 2] - $growth_2_ph - HEAP32[$sd2_2 + 8 >> 2] | 0;
    if (($215 | 0) > 0) {
      __label__ = 60;
      break;
    } else {
      var $sd_4 = $209;
      __label__ = 57;
      break;
    }
   case 60:
    var $218 = _js_AddToSrcNoteDelta($cx, $cg, $sn_1_ph, $215);
    if (($218 | 0) == 0) {
      var $_0 = 0;
      __label__ = 82;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    var $221 = HEAPU32[$186 >> 2];
    var $sd_4_ph = $209;
    var $snlimit_1_ph = $221 + HEAP32[$188 >> 2] | 0;
    var $sn_1_ph = $218;
    var $growth_2_ph = $215 + $growth_2_ph | 0;
    var $201 = $221;
    __label__ = 56;
    break;
   case 62:
    var $225 = HEAPU8[$sn_1_ph];
    if (($225 & 255) > 191) {
      var $231 = 24;
      __label__ = 64;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $231 = ($225 & 255) >>> 3;
    __label__ = 64;
    break;
   case 64:
    var $231;
    var $233 = HEAPU8[_js_SrcNoteSpec + ($231 << 3) + 6 | 0];
    if ($233 << 24 >> 24 == 0) {
      var $snlimit_5 = $snlimit_1_ph;
      var $sn_5 = $sn_1_ph;
      var $280 = $225;
      var $279 = $201;
      __label__ = 72;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 65:
    var $239 = (HEAPU8[_js_SrcNoteSpec + ($231 << 3) + 5 | 0] & 255) + $200 | 0;
    var $242 = HEAP8[_js_SrcNoteSpec + ($231 << 3) + 4 | 0] << 24 >> 24;
    var $245 = $sd_4 - $191 >> 4;
    var $sum = $239 + $growth_2_ph | 0;
    var $i_0 = 0;
    var $snlimit_3 = $snlimit_1_ph;
    var $sn_3 = $sn_1_ph;
    var $247 = $201;
    __label__ = 66;
    break;
   case 66:
    var $247;
    var $sn_3;
    var $snlimit_3;
    var $i_0;
    if ($i_0 >>> 0 < $242 >>> 0) {
      __label__ = 67;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 67:
    var $250 = _js_GetSrcNoteOffset($sn_3, $i_0);
    if (($250 | 0) == 0) {
      var $snlimit_4 = $snlimit_3;
      var $sn_4 = $sn_3;
      var $277 = $247;
      __label__ = 70;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 68:
    var $253 = $233 << 24 >> 24;
    var $254 = $253 * $250 | 0;
    var $255 = $254 + $239 | 0;
    var $257 = ($254 | 0) > -1 ? $245 : 0;
    var $cg_idx4_val = HEAP32[$5 >> 2];
    var $cg_idx5_val = HEAP32[$7 >> 2];
    var $258 = __ZL18FindNearestSpanDepP15JSCodeGeneratoriiP9JSSpanDep($cg_idx4_val, $cg_idx5_val, $255, $257, $guard);
    var $265 = $253 * ($255 - $sum + HEAP32[$258 + 4 >> 2] - HEAP32[$258 + 8 >> 2]) | 0;
    var $268 = $sn_3 - $247 | 0;
    var $269 = _js_SetSrcNoteOffset($cx, $cg, $268, $i_0, $265);
    if (($269 | 0) == 0) {
      var $_0 = 0;
      __label__ = 82;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 69:
    var $272 = HEAP32[$186 >> 2];
    var $snlimit_4 = $272 + HEAP32[$188 >> 2] | 0;
    var $sn_4 = $272 + $268 | 0;
    var $277 = $272;
    __label__ = 70;
    break;
   case 70:
    var $277;
    var $sn_4;
    var $snlimit_4;
    var $i_0 = $i_0 + 1 | 0;
    var $snlimit_3 = $snlimit_4;
    var $sn_3 = $sn_4;
    var $247 = $277;
    __label__ = 66;
    break;
   case 71:
    var $snlimit_5 = $snlimit_3;
    var $sn_5 = $sn_3;
    var $280 = HEAP8[$sn_3];
    var $279 = $247;
    __label__ = 72;
    break;
   case 72:
    var $279;
    var $280;
    var $sn_5;
    var $snlimit_5;
    if (($280 & 255) > 191) {
      var $286 = 24;
      __label__ = 74;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    var $286 = ($280 & 255) >>> 3;
    __label__ = 74;
    break;
   case 74:
    var $286;
    if (HEAP8[_js_SrcNoteSpec + ($286 << 3) + 4 | 0] << 24 >> 24 == 0) {
      var $293 = 1;
      __label__ = 76;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 75:
    var $291 = _js_SrcNoteLength($sn_5);
    var $293 = $291;
    __label__ = 76;
    break;
   case 76:
    var $293;
    var $sd_3 = $sd_4;
    var $snlimit_0 = $snlimit_5;
    var $sn_0 = $sn_5 + $293 | 0;
    var $offset_1 = $200;
    var $growth_1 = $growth_2_ph;
    var $193 = $279;
    __label__ = 54;
    break;
   case 77:
    var $296 = $cg + 164 | 0;
    var $298 = HEAP32[$296 >> 2] + $growth_1 | 0;
    HEAP32[$296 >> 2] = $298;
    var $tryNode_021 = HEAP32[$cg + 204 >> 2];
    if (($tryNode_021 | 0) == 0) {
      __label__ = 81;
      break;
    } else {
      var $tryNode_022 = $tryNode_021;
      __label__ = 78;
      break;
    }
   case 78:
    var $tryNode_022;
    var $301 = $tryNode_022 + 4 | 0;
    var $302 = HEAP32[$301 >> 2];
    var $cg_idx2_val = HEAP32[$5 >> 2];
    var $cg_idx3_val = HEAP32[$7 >> 2];
    var $303 = __ZL18FindNearestSpanDepP15JSCodeGeneratoriiP9JSSpanDep($cg_idx2_val, $cg_idx3_val, $302, 0, $guard);
    var $308 = HEAP32[$303 + 4 >> 2] - HEAP32[$303 + 8 >> 2] | 0;
    var $309 = $308 + $302 | 0;
    HEAP32[$301 >> 2] = $309;
    var $310 = $tryNode_022 + 8 | 0;
    var $311 = HEAP32[$310 >> 2];
    var $312 = $311 + $302 | 0;
    var $315 = $303 - $191 >> 4;
    var $cg_idx_val = HEAP32[$5 >> 2];
    var $cg_idx1_val = HEAP32[$7 >> 2];
    var $316 = __ZL18FindNearestSpanDepP15JSCodeGeneratoriiP9JSSpanDep($cg_idx_val, $cg_idx1_val, $312, $315, $guard);
    if (($316 | 0) == ($303 | 0)) {
      __label__ = 80;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 79:
    var $325 = $311 - $308 + HEAP32[$316 + 4 >> 2] - HEAP32[$316 + 8 >> 2] | 0;
    HEAP32[$310 >> 2] = $325;
    __label__ = 80;
    break;
   case 80:
    var $tryNode_0 = HEAP32[$tryNode_022 + 12 >> 2];
    if (($tryNode_0 | 0) == 0) {
      __label__ = 81;
      break;
    } else {
      var $tryNode_022 = $tryNode_0;
      __label__ = 78;
      break;
    }
   case 81:
    var $330 = HEAP32[$5 >> 2];
    __ZN9JSContext5free_EPv($330);
    HEAP32[$5 >> 2] = 0;
    var $331 = HEAP32[$15 >> 2];
    __ZL15FreeJumpTargetsP15JSCodeGeneratorP12JSJumpTarget($cg, $331);
    HEAP32[$15 >> 2] = 0;
    HEAP32[$cg + 224 >> 2] = 0;
    HEAP32[$7 >> 2] = 0;
    var $333 = HEAP32[$1 >> 2];
    var $340 = HEAP32[$333 + 8 >> 2] - HEAP32[$333 >> 2] | 0;
    HEAP32[$cg + 228 >> 2] = $340;
    var $_0 = 1;
    __label__ = 82;
    break;
   case 82:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16OptimizeSpanDepsP9JSContextP15JSCodeGenerator["X"] = 1;

function __ZN16EmitLevelManagerD1Ev($this_0_0_val) {
  __ZN16EmitLevelManagerD2Ev($this_0_0_val);
  return;
}

function __ZL12AllocSrcNoteP9JSContextP15JSCodeGenerator($cx, $cg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg + 172 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $4 = HEAP32[$2 + 12 >> 2];
    var $6 = HEAP32[$2 + 16 >> 2];
    var $8 = HEAP32[$2 + 20 >> 2];
    if (($6 | 0) == ($8 | 0)) {
      __label__ = 2;
      break;
    } else {
      var $26 = $2;
      __label__ = 8;
      break;
    }
   case 2:
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $13 = __ZN9JSContext7malloc_Ej($cx, 1024);
    var $newlength_0 = 1024;
    var $newnotes_0 = $13;
    __label__ = 5;
    break;
   case 4:
    var $15 = $8 << 1;
    var $16 = __ZN9JSContext8realloc_EPvj($cx, $4, $15);
    var $newlength_0 = $15;
    var $newnotes_0 = $16;
    __label__ = 5;
    break;
   case 5:
    var $newnotes_0;
    var $newlength_0;
    if (($newnotes_0 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = -1;
    __label__ = 9;
    break;
   case 7:
    var $22 = HEAP32[$1 >> 2] + 12 | 0;
    HEAP32[$22 >> 2] = $newnotes_0;
    var $24 = HEAP32[$1 >> 2] + 20 | 0;
    HEAP32[$24 >> 2] = $newlength_0;
    var $26 = HEAP32[$1 >> 2];
    __label__ = 8;
    break;
   case 8:
    var $26;
    var $27 = $6 + 1 | 0;
    HEAP32[$26 + 16 >> 2] = $27;
    var $_0 = $6;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_NewSrcNote3($cx, $cg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_NewSrcNote($cx, $cg, 18);
    if (($1 | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = _js_SetSrcNoteOffset($cx, $cg, $1, 0, 0);
    if (($4 | 0) == 0) {
      var $_0 = -1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = _js_SetSrcNoteOffset($cx, $cg, $1, 1, 0);
    if (($7 | 0) == 0) {
      var $_0 = -1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = $1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_AddToSrcNoteDelta($cx, $cg, $sn, $delta) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU8[$sn];
    var $2 = $1 & 255;
    var $3 = $2 & 248;
    var $4 = ($1 & 255) > 191;
    var $_v = $4 ? 63 : 7;
    var $6 = $4 ? 64 : 8;
    var $7 = ($_v & $2) + $delta | 0;
    if (($7 | 0) < ($6 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP8[$sn] = ($7 | 192) & 255;
    var $_0 = $sn;
    __label__ = 9;
    break;
   case 4:
    HEAP8[$sn] = ($7 & 7 | $3) & 255;
    var $_0 = $sn;
    __label__ = 9;
    break;
   case 5:
    var $18 = $cg + 152 | 0;
    var $22 = $sn - HEAP32[$18 >> 2] | 0;
    var $23 = $cg + 156 | 0;
    var $24 = HEAP32[$23 >> 2];
    if (($24 | 0) == (HEAP32[$cg + 160 >> 2] | 0)) {
      __label__ = 6;
      break;
    } else {
      var $_01 = $sn;
      var $35 = $24;
      __label__ = 8;
      break;
    }
   case 6:
    var $29 = __ZL12GrowSrcNotesP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_01 = HEAP32[$18 >> 2] + $22 | 0;
    var $35 = HEAP32[$23 >> 2];
    __label__ = 8;
    break;
   case 8:
    var $35;
    var $_01;
    var $36 = $35 - $22 | 0;
    HEAP32[$23 >> 2] = $35 + 1 | 0;
    var $38 = $_01 + 1 | 0;
    _llvm_memmove_p0i8_p0i8_i32($38, $_01, $36, 1, 0);
    HEAP8[$_01] = ($delta | 192) & 255;
    var $_0 = $38;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_AddToSrcNoteDelta["X"] = 1;

function __ZL12GrowSrcNotesP9JSContextP15JSCodeGenerator($cx, $cg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg + 172 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $5 = HEAP32[$2 + 20 >> 2] << 1;
    var $7 = HEAP32[$2 + 12 >> 2];
    var $8 = __ZN9JSContext8realloc_EPvj($cx, $7, $5);
    if (($8 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $13 = HEAP32[$1 >> 2] + 12 | 0;
    HEAP32[$13 >> 2] = $8;
    var $15 = HEAP32[$1 >> 2] + 20 | 0;
    HEAP32[$15 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23ReportStatementTooLargeP9JSContextP15JSCodeGenerator($cx, $cg_0_0_6_val) {
  var __stackBase__ = STACKTOP;
  var $1 = __ZL13StatementNameP15JSCodeGenerator($cg_0_0_6_val);
  _JS_ReportErrorNumber($cx, 4, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $1, tempInt));
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZN9JSContext12parseMapPoolEv($this_0_15_val) {
  return $this_0_15_val;
}

function __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js7MoveRefINS_15GlobalSlotArray5EntryEEcvRS2_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this_0_2_val, $this_0_3_val, $this_0_5_val) {
  return ($this_0_5_val + $this_0_3_val | 0) >>> 0 >= ($this_0_2_val * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN14JSCGObjectList6finishEP13JSObjectArray($this_0_1_val, $array_0_0_val, $array_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $objbox_0 = $this_0_1_val;
    var $cursor_0 = $array_0_0_val + ($array_0_1_val << 2) | 0;
    __label__ = 2;
    break;
   case 2:
    var $cursor_0;
    var $objbox_0;
    var $3 = $cursor_0 - 4 | 0;
    var $5 = HEAP32[$objbox_0 + 8 >> 2];
    HEAP32[$3 >> 2] = $5;
    var $7 = HEAP32[$objbox_0 + 4 >> 2];
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $objbox_0 = $7;
      var $cursor_0 = $3;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 3) | 0;
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZN2js10VectorImplIjLj8ENS_15TempAllocPolicyELb1EE13copyConstructIjEEvPjPKT_S7_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 3) | 0;
}

function __ZN2js7MoveRefINS_15GlobalSlotArray5EntryEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($this_0_0_val) {
  return $this_0_0_val + 8 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv($this_0_0_val) {
  return $this_0_0_val + 8 | 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEC2ERS9_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function _js_FinishTakingSrcNotes($cx, $cg, $notes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg + 108 | 0;
    var $2 = $cg + 124 | 0;
    var $3 = HEAPU32[$2 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$cg + 188 >> 2];
    if ((HEAP32[$cg + 136 >> 2] | 0) == ($9 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $cg + 172 | 0;
    HEAP32[$12 >> 2] = $1;
    var $13 = _js_NewSrcNote2($cx, $cg, 23, $9);
    if (($13 | 0) < 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = HEAP32[$2 >> 2];
    HEAP32[$12 >> 2] = $cg + 140 | 0;
    var $prologCount_0 = $16;
    __label__ = 15;
    break;
   case 5:
    var $28 = HEAP32[$cg + 116 >> 2] - HEAP32[$1 >> 2] - HEAP32[$cg + 132 >> 2] | 0;
    if (($28 | 0) > 0) {
      __label__ = 6;
      break;
    } else {
      var $prologCount_0 = $3;
      __label__ = 15;
      break;
    }
   case 6:
    if ((HEAP32[$cg + 156 >> 2] | 0) == 0) {
      var $prologCount_0 = $3;
      __label__ = 15;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $35 = $cg + 152 | 0;
    var $36 = HEAPU32[$35 >> 2];
    var $37 = HEAPU8[$36];
    var $38 = $37 & 255;
    if (($37 & 255) > 191) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $45 = $38 & 63 ^ 63;
    __label__ = 10;
    break;
   case 9:
    var $45 = $38 & 7 ^ 7;
    __label__ = 10;
    break;
   case 10:
    var $45;
    if (($28 | 0) < ($45 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $sn_0 = $36;
      var $delta_0 = $45;
      var $offset_0 = $28;
      __label__ = 12;
      break;
    }
   case 11:
    var $sn_0 = $36;
    var $delta_0 = $28;
    var $offset_0 = $28;
    __label__ = 12;
    break;
   case 12:
    var $offset_0;
    var $delta_0;
    var $sn_0;
    var $48 = _js_AddToSrcNoteDelta($cx, $cg, $sn_0, $delta_0);
    if (($48 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $51 = $offset_0 - $delta_0 | 0;
    if (($offset_0 | 0) == ($delta_0 | 0)) {
      var $prologCount_0 = $3;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $55 = ($51 | 0) < 63 ? $51 : 63;
    var $sn_0 = HEAP32[$35 >> 2];
    var $delta_0 = $55;
    var $offset_0 = $51;
    __label__ = 12;
    break;
   case 15:
    var $prologCount_0;
    var $58 = HEAP32[$cg + 156 >> 2];
    var $59 = $58 + $prologCount_0 | 0;
    if (($prologCount_0 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $63 = HEAP32[$cg + 120 >> 2];
    _memcpy($notes, $63, $prologCount_0, 1);
    __label__ = 17;
    break;
   case 17:
    var $65 = $notes + $prologCount_0 | 0;
    var $67 = HEAP32[$cg + 152 >> 2];
    _memcpy($65, $67, $58, 1);
    HEAP8[$notes + $59 | 0] = 0;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_FinishTakingSrcNotes["X"] = 1;

function _js_FinishTakingTryNotes($cg_0_10_val, $array_0_0_val, $array_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tn_0 = $array_0_0_val + $array_0_1_val * 12 | 0;
    var $tryNode_0 = $cg_0_10_val;
    __label__ = 2;
    break;
   case 2:
    var $tryNode_0;
    var $tn_0;
    var $3 = $tn_0 - 12 | 0;
    var $4 = $3 | 0;
    var $5 = $tryNode_0 | 0;
    HEAP32[$4 >> 2] = HEAP32[$5 >> 2];
    HEAP32[$4 + 4 >> 2] = HEAP32[$5 + 4 >> 2];
    HEAP32[$4 + 8 >> 2] = HEAP32[$5 + 8 >> 2];
    var $7 = HEAP32[$tryNode_0 + 12 >> 2];
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $tn_0 = $3;
      var $tryNode_0 = $7;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSGCConstList6finishEP12JSConstArray($this, $array) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this + 4 >> 2];
    var $1 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE5beginEv($_idx_val);
    var $_idx2_val = HEAP32[$this + 8 >> 2];
    var $2 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE3endEv($_idx_val, $_idx2_val);
    if (($1 | 0) == ($2 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $src_01 = $1;
    var $dst_02 = HEAP32[$array >> 2];
    __label__ = 3;
    break;
   case 3:
    var $dst_02;
    var $src_01;
    var $7 = $src_01 | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $dst_02 | 0;
    HEAP32[$9 >> 2] = $8$0;
    HEAP32[$9 + 4 >> 2] = $8$1;
    var $10 = $src_01 + 8 | 0;
    if (($10 | 0) == ($2 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $src_01 = $10;
      var $dst_02 = $dst_02 + 8 | 0;
      __label__ = 3;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ParseMapPool7releaseEPNS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEE($this, $map) {
  var $1 = $map;
  __ZN2js12ParseMapPool7recycleEPv($this, $1);
  return;
}

function __ZN2js12ParseMapPool7recycleEPv($this, $map) {
  var $1 = $this + 140 | 0;
  __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE16infallibleAppendERKS1_($1, $map);
  return;
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE13growStorageByEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE14internalAppendItEEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAPU32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $6 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t & 65535;
    var $6 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $6;
    HEAP32[$this_idx1 >> 2] = $6 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj32EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 2;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplIjLj8ENS_15TempAllocPolicyELb1EE13moveConstructIjEEvPjPKT_S7_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIjLj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIjLj8ES1_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, 1);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIjLj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIjLj8ES1_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $3 = $v + 4 | 0;
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($2, $5, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    var $10 = $v + 12 | 0;
    HEAP32[$3 >> 2] = $9;
    HEAP32[$10 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIjLj8ENS_15TempAllocPolicyELb1EE13moveConstructIjEEvPjPKT_S7_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIjLj8ENS_15TempAllocPolicyELb1EE13copyConstructIjEEvPjPKT_S7_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE13growStorageByEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE17growHeapStorageByEj($this);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t_0, $t_1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $10 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    var $8$1 = $t_1 | 0;
    var $st$9$0 = $4 | 0;
    HEAP32[$st$9$0 >> 2] = 0 | $t_0;
    var $st$9$1 = $4 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $8$1;
    var $10 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $10;
    HEAP32[$this_idx1 >> 2] = $10 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj128EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 3;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE17growHeapStorageByEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj16ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, 1);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 268435455) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 268435455) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj16ES3_EEj($v, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $v | 0;
    var $3 = $newcap << 3;
    var $4 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $v_idx = $v + 4 | 0;
    var $v_idx_val = HEAP32[$v_idx >> 2];
    var $8 = __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE12beginNoCheckEv($v_idx_val);
    var $v_idx4 = $v + 8 | 0;
    var $v_idx4_val = HEAP32[$v_idx4 >> 2];
    var $9 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE10endNoCheckEv($v_idx_val, $v_idx4_val);
    if (($8 | 0) == ($9 | 0)) {
      var $22 = $v_idx_val;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx = $1 | 0;
    var $dst_01 = $5;
    var $src_02 = $8;
    var $v_idx1_val5 = $v_idx_val;
    var $v_idx2_val7 = $v_idx4_val;
    __label__ = 4;
    break;
   case 4:
    var $v_idx2_val7;
    var $v_idx1_val5;
    var $src_02;
    var $dst_01;
    if (($dst_01 | 0) == 0) {
      var $v_idx1_val = $v_idx1_val5;
      var $v_idx2_val = $v_idx2_val7;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = $dst_01;
    HEAP32[$13 >> 2] = 0;
    HEAP32[$13 + 4 >> 2] = 0;
    __ZN2js4MoveINS_15GlobalSlotArray5EntryEEENS_7MoveRefIT_EERS4_($1, $src_02);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $14 = __ZNK2js7MoveRefINS_15GlobalSlotArray5EntryEEcvRS2_Ev($_idx_val);
    var $15 = $14;
    var $16$0 = HEAP32[$15 >> 2];
    var $16$1 = HEAP32[$15 + 4 >> 2];
    HEAP32[$13 >> 2] = $16$0;
    HEAP32[$13 + 4 >> 2] = $16$1;
    var $v_idx1_val = HEAP32[$v_idx >> 2];
    var $v_idx2_val = HEAP32[$v_idx4 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $v_idx2_val;
    var $v_idx1_val;
    var $18 = $dst_01 + 8 | 0;
    var $19 = $src_02 + 8 | 0;
    var $20 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE10endNoCheckEv($v_idx1_val, $v_idx2_val);
    if (($19 | 0) == ($20 | 0)) {
      var $22 = $v_idx1_val;
      __label__ = 7;
      break;
    } else {
      var $dst_01 = $18;
      var $src_02 = $19;
      var $v_idx1_val5 = $v_idx1_val;
      var $v_idx2_val7 = $v_idx2_val;
      __label__ = 4;
      break;
    }
   case 7:
    var $22;
    __ZN2js15TempAllocPolicy5free_EPv($22);
    HEAP32[$v_idx >> 2] = $5;
    HEAP32[$v + 12 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js10VectorImplINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj16ES3_EEj["X"] = 1;

function __ZN2js4MoveINS_15GlobalSlotArray5EntryEEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_15GlobalSlotArray5EntryEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_15GlobalSlotArray5EntryEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefINS_15GlobalSlotArray5EntryEEC2ERS2_($this, $t);
  return;
}

function __ZN2js10VectorImplINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx = $1 | 0;
    var $p_01 = $srcbeg;
    var $_02 = $dst;
    __label__ = 3;
    break;
   case 3:
    var $_02;
    var $p_01;
    if (($_02 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $5 = $_02;
    HEAP32[$5 >> 2] = 0;
    HEAP32[$5 + 4 >> 2] = 0;
    __ZN2js4MoveINS_15GlobalSlotArray5EntryEEENS_7MoveRefIT_EERKS4_($1, $p_01);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $6 = __ZNK2js7MoveRefINS_15GlobalSlotArray5EntryEEcvRS2_Ev($_idx_val);
    var $7 = $6;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    HEAP32[$5 >> 2] = $8$0;
    HEAP32[$5 + 4 >> 2] = $8$1;
    __label__ = 5;
    break;
   case 5:
    var $10 = $p_01 + 8 | 0;
    if (($10 | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      var $p_01 = $10;
      var $_02 = $_02 + 8 | 0;
      __label__ = 3;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_15GlobalSlotArray5EntryEEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_15GlobalSlotArray5EntryEEC1ERS2_($agg_result, $t);
  return;
}

function __ZNK2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 96,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $7 = $v | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $5 + 8 | 0;
    var $st$10$0 = $9 | 0;
    HEAP32[$st$10$0 >> 2] = $8$0;
    var $st$10$1 = $9 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $8$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 8 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 12 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 8 >> 2];
    var $this_idx1 = $this + 12 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 20 >> 2];
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 3:
    var $14 = $this | 0;
    var $15 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($14, $10);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $19 = $this + 16 | 0;
    var $21 = HEAP32[$19 >> 2] + 1 | 0;
    HEAP32[$19 >> 2] = $21;
    HEAP32[$2 >> 2] = $15;
    var $22 = $3 + $5 * 24 | 0;
    if (($5 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 6;
    break;
   case 6:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE6isLiveEv($src_01_idx_val);
    if ($24) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $26 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE10getKeyHashEv($src_01_idx1_val);
    var $27 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $26);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEENS_7MoveRefIT_EERSB_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEaSENS_7MoveRefIS8_EE($27, $_02_val);
    __label__ = 8;
    break;
   case 8:
    var $29 = $src_01 + 24 | 0;
    if (($29 | 0) == ($22 | 0)) {
      __label__ = 9;
      break;
    } else {
      var $src_01 = $29;
      __label__ = 6;
      break;
    }
   case 9:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($3);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 24 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 24 | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 24 | 0;
    var $2 = __ZN2js15TempAllocPolicy7malloc_Ej($alloc, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 24 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 24 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEaSENS_7MoveRefIS8_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 8 | 0;
  var $7 = $2 + 8 | 0;
  __ZN2js4MoveINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEENS_7MoveRefIT_EERS8_($1, $7);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js12HashMapEntryIP6JSAtomN2JS5ValueEEaSENS_7MoveRefIS5_EE($6, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEENS_7MoveRefIT_EERSB_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEC1ERS9_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js15TempAllocPolicy5free_EPv($0);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEC1ERS9_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEC2ERS9_($this, $t);
  return;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv($this) {
  return;
}

function __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomjEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE5emptyEv($this_0_1_val) {
  return ($this_0_1_val | 0) == 0;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this_0_2_val, $this_0_3_val, $this_0_5_val) {
  return ($this_0_5_val + $this_0_3_val | 0) >>> 0 >= ($this_0_2_val * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js12HashMapEntryIP6JSAtomN2JS5ValueEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 8 | 0;
  HEAP32[$2 >> 2] = 0;
  HEAP32[$2 + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($e) {
  return $e | 0;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE5clearEv($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE7popBackEv($this) {
  var $1 = $this + 4 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_EC2ESB_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  return;
}

function __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE8clearMapEv($this) {
  HEAP32[$this >> 2] = 0;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEC2ERS7_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomjEEEC2ERS4_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js12HashMapEntryIP6JSAtomjEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js12HashMapEntryIP6JSAtomN2JS5ValueEEaSENS_7MoveRefIS5_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEptEv($rhs_0);
  var $4 = $3 | 0;
  __ZN2js4MoveIP6JSAtomEENS_7MoveRefIT_EERKS4_($1, $4);
  var $_idx1_val = HEAP32[$1 >> 2];
  var $5 = __ZNK2js7MoveRefIP6JSAtomEcvRS2_Ev($_idx1_val);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = $3 + 8 | 0;
  __ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERS4_($2, $8);
  var $_idx_val = HEAP32[$2 >> 2];
  var $9 = __ZNK2js7MoveRefIN2JS5ValueEEcvRS2_Ev($_idx_val);
  var $10 = $9 | 0;
  var $11$0 = HEAP32[$10 >> 2];
  var $11$1 = HEAP32[$10 + 4 >> 2];
  var $12 = $this + 8 | 0;
  HEAP32[$12 >> 2] = $11$0;
  HEAP32[$12 + 4 >> 2] = $11$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 8 | 0;
  __ZN2js12HashMapEntryIP6JSAtomN2JS5ValueEEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIP6JSAtomN2JS5ValueEEC1Ev($this) {
  __ZN2js12HashMapEntryIP6JSAtomN2JS5ValueEEC2Ev($this);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l_val1) {
  var $1 = __ZN2js13PointerHasherIP6JSAtomLj2EE4hashERKS2_($l_val1);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 24 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $l_val4 = HEAP32[$l >> 2];
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($6, $l_val4);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 24 | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $l_val = HEAP32[$l >> 2];
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($27, $l_val);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($e, $l_val1) {
  var $1 = $e + 8 | 0;
  var $2 = __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($1);
  var $_val = HEAP32[$2 >> 2];
  var $3 = __ZN2js13PointerHasherIP6JSAtomLj2EE5matchERKS2_S5_($_val, $l_val1);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js12ParseMapPool7acquireINS_9InlineMapIP6JSAtomjLj24EEEEEPT_v($this) {
  var $1 = __ZN2js12ParseMapPool8allocateEv($this);
  return $1;
}

function __ZN2js12ParseMapPool8allocateEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this + 144 >> 2];
    var $1 = __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE5emptyEv($_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js12ParseMapPool13allocateFreshEv($this);
    var $_0 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = $this + 140 | 0;
    var $6 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE7popCopyEv($5);
    var $7 = __ZN2js12ParseMapPool9asAtomMapEPv($6);
    __ZN2js9InlineMapIP6JSAtomjLj24EE5clearEv($7);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE7popCopyEv($this) {
  var $this_idx_val = HEAP32[$this >> 2];
  var $this_idx1_val = HEAP32[$this + 4 >> 2];
  var $1 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE4backEv($this_idx_val, $this_idx1_val);
  var $2 = HEAP32[$1 >> 2];
  __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE7popBackEv($this);
  return $2;
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE4backEv($this_0_0_val, $this_0_1_val) {
  var $1 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE3endEv($this_0_0_val, $this_0_1_val);
  return $1 - 4 | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $0 = $this | 0;
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($0, 16);
    HEAP32[$this + 24 >> 2] = $1;
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, 4);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj32EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEED2Ev($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$this + 4 >> 2];
  __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE10releaseMapEP9JSContext($1, $3);
  return;
}

function __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE10releaseMapEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $cx_idx_val = HEAP32[$cx + 100 >> 2];
    var $5 = __ZN9JSContext12parseMapPoolEv($cx_idx_val);
    __ZN2js12ParseMapPool7releaseEPNS_9InlineMapIP6JSAtomjLj24EEE($5, $2);
    HEAP32[$1 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ParseMapPool7releaseEPNS_9InlineMapIP6JSAtomjLj24EEE($this, $map) {
  var $1 = $map;
  __ZN2js12ParseMapPool7recycleEPv($this, $1);
  return;
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEC2ES1_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj32EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 8;
  return;
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEEC2ES3_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj128EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 16;
  return;
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEEC2ES2_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj32EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 8;
  return;
}

function __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES7_($this, $a_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_EC1ESB_($1, $a_0);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_EC1ESB_($this, $ap_01) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_EC2ESB_($this, $ap_01);
  return;
}

function __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEEC2EP9JSContext($this, $cx) {
  HEAP32[$this + 4 >> 2] = $cx;
  var $2 = $this | 0;
  __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE4initEv($2);
  return;
}

function __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE4initEv($this) {
  __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE8clearMapEv($this);
  return;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE12switchAndAddERKS2_RKj($this, $key, $value) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js9InlineMapIP6JSAtomjLj24EE11switchToMapEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this + 200 | 0;
    var $4 = __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKj($3, $key, $value);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKj($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $7 = HEAP32[$v >> 2];
    var $8 = $5 + 4 | 0;
    HEAP32[$8 >> 2] = $7;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 12 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 8 >> 2];
    var $this_idx1 = $this + 12 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 20 >> 2];
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx2_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx2_val);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 3:
    var $14 = $this | 0;
    var $15 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($14, $10);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $19 = $this + 16 | 0;
    var $21 = HEAP32[$19 >> 2] + 1 | 0;
    HEAP32[$19 >> 2] = $21;
    HEAP32[$2 >> 2] = $15;
    var $22 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_01 = $1 | 0;
    var $src_01 = $3;
    __label__ = 6;
    break;
   case 6:
    var $src_01;
    var $_idx = $src_01 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isLiveEv($_idx_val);
    if ($24) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE14unsetCollisionEv($src_01);
    var $src_01_idx_val = HEAP32[$_idx >> 2];
    var $26 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE10getKeyHashEv($src_01_idx_val);
    var $27 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $26);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEENS_7MoveRefIT_EERS9_($1, $src_01);
    var $_01_val = HEAP32[$_01 >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEaSENS_7MoveRefIS6_EE($27, $_01_val);
    __label__ = 8;
    break;
   case 8:
    var $29 = $src_01 + 12 | 0;
    if (($29 | 0) == ($22 | 0)) {
      __label__ = 9;
      break;
    } else {
      var $src_01 = $29;
      __label__ = 6;
      break;
    }
   case 9:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($3);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js15TempAllocPolicy7malloc_Ej($alloc, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEaSENS_7MoveRefIS6_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = $2 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIP6JSAtomjEEEENS_7MoveRefIT_EERS6_($1, $7);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js12HashMapEntryIP6JSAtomjEaSENS_7MoveRefIS3_EE($6, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEENS_7MoveRefIT_EERS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEC1ERS7_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEC2ERS7_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIP6JSAtomjEaSENS_7MoveRefIS3_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomjEEEptEv($rhs_0);
  var $4 = $3 | 0;
  __ZN2js4MoveIP6JSAtomEENS_7MoveRefIT_EERKS4_($1, $4);
  var $_idx_val = HEAP32[$1 >> 2];
  var $5 = __ZNK2js7MoveRefIP6JSAtomEcvRS2_Ev($_idx_val);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = $3 + 4 | 0;
  __ZN2js4MoveIjEENS_7MoveRefIT_EERS2_($2, $8);
  var $_idx2_val = HEAP32[$2 >> 2];
  var $9 = __ZNK2js7MoveRefIjEcvRjEv($_idx2_val);
  var $10 = HEAP32[$9 >> 2];
  HEAP32[$this + 4 >> 2] = $10;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIP6JSAtomjEEEENS_7MoveRefIT_EERS6_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomjEEEC1ERS4_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomjEEEC1ERS4_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomjEEEC2ERS4_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP6JSAtomjEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIP6JSAtomjEC1Ev($this) {
  __ZN2js12HashMapEntryIP6JSAtomjEC2Ev($this);
  return;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE11switchToMapEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 200 | 0;
    var $2 = __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE11initializedEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv($1);
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js9InlineMapIP6JSAtomjLj24EE5countEv($this);
    var $6 = __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($1, $5);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 4:
    var $9 = $this | 0;
    var $11 = $this + 8 + (HEAP32[$9 >> 2] << 3) | 0;
    var $it_0 = $this + 8 | 0;
    __label__ = 5;
    break;
   case 5:
    var $it_0;
    if (($it_0 | 0) == ($11 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $it_0 | 0;
    if ((HEAP32[$15 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKj($1, $15, $it_0 + 4 | 0);
    if ($20) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $it_0 = $it_0 + 8 | 0;
    __label__ = 5;
    break;
   case 9:
    HEAP32[$9 >> 2] = 25;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKj($this, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $p = __stackBase__;
  __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($p, $this, $k);
  var $1 = __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKj($this, $p, $k, $v);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l_val1) {
  var $1 = __ZN2js13PointerHasherIP6JSAtomLj2EE4hashERKS2_($l_val1);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5countEv($this_0_3_val) {
  return $this_0_3_val;
}

function __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE6lengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11initializedEv($this_0_6_val) {
  return ($this_0_6_val | 0) != 0;
}

function __ZNK2js5Shape12inDictionaryEv($this_0_8_val) {
  return ($this_0_8_val & 2) << 24 >> 24 != 0;
}

function __ZNK13JSTreeContext12inStrictModeEv($this_0_0_val) {
  return ($this_0_0_val & 262144 | 0) != 0;
}

function __ZNK13JSTreeContext16mutatesParameterEv($this_0_0_val) {
  return ($this_0_0_val & 16777216 | 0) != 0;
}

function _JSDOUBLE_IS_NEGZERO1166($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d != 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $_0 = tempDoubleI32[1] >>> 31 | 0 << 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11JSParseNode7setKindEN2js9TokenKindE($this, $kind) {
  var $2 = $this;
  var $5 = HEAP32[$2 >> 2] & -65536 | $kind & 65535;
  HEAP32[$2 >> 2] = $5;
  return;
}

function __ZN11JSParseNode8setArityE16JSParseNodeArity($this, $a) {
  var $1 = $this;
  var $6 = HEAP32[$1 >> 2] & -520093697 | $a << 24 & 520093696;
  HEAP32[$1 >> 2] = $6;
  return;
}

function __ZNK11JSParseNode8getArityEv($this) {
  return HEAPU32[$this >> 2] >>> 24 & 31;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_jEE($e) {
  return $e | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC2EPNS3_10InlineElemEb($this, $ptr, $found) {
  HEAP32[$this + 8 >> 2] = $ptr;
  HEAP8[$this + 12 | 0] = 1;
  HEAP8[$this + 13 | 0] = $found & 1;
  return;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC2ERKNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E6AddPtrE($this, $p) {
  var $1 = $p;
  var $2 = $this;
  var $3$0 = HEAP32[$1 >> 2];
  var $3$1 = HEAP32[$1 + 4 >> 2];
  HEAP32[$2 >> 2] = $3$0;
  HEAP32[$2 + 4 >> 2] = $3$1;
  HEAP8[$this + 12 | 0] = 0;
  return;
}

function __ZL13StatementNameP15JSCodeGenerator($cg_0_0_6_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($cg_0_0_6_val | 0) == 0) {
      var $_0 = STRING_TABLE.__str120413 | 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZL13statementName + ((HEAPU16[$cg_0_0_6_val >> 1] & 65535) << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN16EmitLevelManagerD2Ev($this_0_0_val) {
  var $1 = $this_0_0_val + 236 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZL18FindNearestSpanDepP15JSCodeGeneratoriiP9JSSpanDep($cg_0_11_val, $cg_0_14_val, $offset, $lo, $guard) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $hi_0_ph = $cg_0_14_val - 1 | 0;
    var $_01_ph = $lo;
    __label__ = 2;
    break;
   case 2:
    var $_01_ph;
    var $hi_0_ph;
    var $hi_0 = $hi_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $hi_0;
    if (($_01_ph | 0) > ($hi_0 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $6 = ($hi_0 + $_01_ph | 0) / 2 & -1;
    var $8 = HEAP32[$cg_0_11_val + ($6 << 4) + 8 >> 2];
    if (($8 | 0) == ($offset | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $_0 = $cg_0_11_val + ($6 << 4) | 0;
    __label__ = 11;
    break;
   case 6:
    if (($8 | 0) < ($offset | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $hi_0_ph = $hi_0;
    var $_01_ph = $6 + 1 | 0;
    __label__ = 2;
    break;
   case 8:
    var $hi_0 = $6 - 1 | 0;
    __label__ = 3;
    break;
   case 9:
    if (($_01_ph | 0) == ($cg_0_14_val | 0)) {
      var $_0 = $guard;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = $cg_0_11_val + ($_01_ph << 4) | 0;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 3) | 0;
}

function __ZL21UpdateDecomposeLengthP15JSCodeGeneratorj($cg_0_3_val_0_0_val, $cg_0_3_val_0_2_val, $start) {
  HEAP8[$cg_0_3_val_0_0_val + ($start - 1) | 0] = $cg_0_3_val_0_2_val - $start - $cg_0_3_val_0_0_val & 255;
  return;
}

function __ZNK11JSParseNode4testEj($this, $flag) {
  return ($flag & 4095 & HEAP32[$this + 44 >> 2] | 0) != 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $l_val4 = HEAP32[$l >> 2];
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($6, $l_val4);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $l_val = HEAP32[$l >> 2];
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($27, $l_val);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($e, $l_val1) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_jEE($1);
  var $_val = HEAP32[$2 >> 2];
  var $3 = __ZN2js13PointerHasherIP6JSAtomLj2EE5matchERKS2_S5_($_val, $l_val1);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE10isLiveHashEj($hash);
  return $1;
}

function __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE11initializedEv($this) {
  var $_idx_val = HEAP32[$this + 24 >> 2];
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11initializedEv($_idx_val);
  return $1;
}

function __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5clearEv($1);
  return;
}

function __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E4initEj($1, $len);
  return $2;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE5countEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK2js9InlineMapIP6JSAtomjLj24EE8usingMapEv($_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this + 200 | 0;
    var $4 = __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv($3);
    var $9 = $4;
    __label__ = 4;
    break;
   case 3:
    var $9 = HEAP32[$this + 4 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv($this) {
  var $_idx_val = HEAP32[$this + 12 >> 2];
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5countEv($_idx_val);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $4 = $length * 171 | 0;
    var $capacity_0 = $4 >>> 0 < 2048 ? 16 : $4 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 5;
      break;
    }
   case 4:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $8 = $roundUp_01 << 1;
    var $9 = $roundUpLog2_02 + 1 | 0;
    if ($8 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $8;
      var $roundUpLog2_02 = $9;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = $8;
      var $roundUpLog2_0_lcssa = $9;
      __label__ = 5;
      break;
    }
   case 5:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $11 = $this | 0;
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($11, $roundUp_0_lcssa);
    HEAP32[$this + 24 >> 2] = $12;
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5clearEv($this) {
  var $3 = HEAP32[$this + 24 >> 2];
  var $6 = HEAP32[$this + 8 >> 2] * 12 | 0;
  _memset($3, 0, $6, 1);
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZNK2js9InlineMapIP6JSAtomjLj24EE6AddPtr5foundEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = (HEAP8[$this + 13 | 0] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $_idx_val = HEAP32[$this >> 2];
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($_idx_val);
    var $13 = $11;
    __label__ = 4;
    break;
   case 4:
    var $13;
    return $13;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this_0_0_val) {
  var $_idx_val = HEAP32[$this_0_0_val >> 2];
  var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isLiveEv($_idx_val);
  return $1;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC1ERKNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E6AddPtrE($this, $p) {
  __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC2ERKNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E6AddPtrE($this, $p);
  return;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC1EPNS3_10InlineElemEb($this, $ptr, $found) {
  __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC2EPNS3_10InlineElemEb($this, $ptr, $found);
  return;
}

function __ZL17UpdateJumpTargetsP12JSJumpTargetii($jt, $pivot) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $jt_tr = $jt;
    __label__ = 2;
    break;
   case 2:
    var $jt_tr;
    var $1 = $jt_tr | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) > ($pivot | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $5 = $2 + 2 | 0;
    HEAP32[$1 >> 2] = $5;
    var $7 = HEAP32[$jt_tr + 8 >> 2];
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZL17UpdateJumpTargetsP12JSJumpTargetii($7, $pivot);
    __label__ = 5;
    break;
   case 5:
    var $12 = HEAP32[$jt_tr + 12 >> 2];
    if (($12 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $jt_tr = $12;
      __label__ = 2;
      break;
    }
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15FreeJumpTargetsP15JSCodeGeneratorP12JSJumpTarget($cg, $jt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $jt + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZL15FreeJumpTargetsP15JSCodeGeneratorP12JSJumpTarget($cg, $2);
    __label__ = 3;
    break;
   case 3:
    var $7 = HEAP32[$jt + 12 >> 2];
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZL15FreeJumpTargetsP15JSCodeGeneratorP12JSJumpTarget($cg, $7);
    __label__ = 5;
    break;
   case 5:
    var $11 = $cg + 216 | 0;
    var $12 = HEAP32[$11 >> 2];
    HEAP32[$1 >> 2] = $12;
    HEAP32[$11 >> 2] = $jt;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSDOUBLE_IS_INT321163($d, $pi) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSDOUBLE_IS_NEGZERO1166($d);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $d & -1;
    HEAP32[$pi >> 2] = $4;
    var $_0 = ($4 | 0) == $d & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSGCConstList6appendEN2JS5ValueE($this, $_0_0_0_val$0, $_0_0_0_val$1) {
  var $1 = $this | 0;
  var $2 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($1, $_0_0_0_val$0, $_0_0_0_val$1);
  return $2;
}

function __ZN2JSL11DoubleValueEd1164($agg_result, $dbl) {
  __ZN2JS5Value9setDoubleEd($agg_result, $dbl);
  return;
}

function __ZNK13JSGCConstList6lengthEv($this) {
  var $_idx_val = HEAP32[$this + 8 >> 2];
  var $1 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE6lengthEv($_idx_val);
  return $1;
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($this, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $_0_0_0_val$0, $_0_0_0_val$1);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $5 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_03 = $1 | 0;
    var $st$1$0 = $_03 | 0;
    HEAP32[$st$1$0 >> 2] = $_0_0_0_val$0;
    var $st$1$1 = $_03 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $_0_0_0_val$1;
    var $5 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    HEAP32[$this_idx1 >> 2] = $5 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 3;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplIN2JS5ValueELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIN2JS5ValueELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj0ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 268435455) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 268435455) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIN2JS5ValueELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj0ES3_EEj($v, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $v | 0;
    var $3 = $newcap << 3;
    var $4 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $v_idx = $v + 4 | 0;
    var $v_idx_val = HEAP32[$v_idx >> 2];
    var $8 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($v_idx_val);
    var $v_idx4 = $v + 8 | 0;
    var $v_idx4_val = HEAP32[$v_idx4 >> 2];
    var $9 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($v_idx_val, $v_idx4_val);
    if (($8 | 0) == ($9 | 0)) {
      var $22 = $v_idx_val;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx = $1 | 0;
    var $dst_01 = $5;
    var $src_02 = $8;
    var $v_idx1_val5 = $v_idx_val;
    var $v_idx2_val7 = $v_idx4_val;
    __label__ = 4;
    break;
   case 4:
    var $v_idx2_val7;
    var $v_idx1_val5;
    var $src_02;
    var $dst_01;
    if (($dst_01 | 0) == 0) {
      var $v_idx1_val = $v_idx1_val5;
      var $v_idx2_val = $v_idx2_val7;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = $dst_01 | 0;
    HEAP32[$13 >> 2] = 0;
    HEAP32[$13 + 4 >> 2] = 0;
    __ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERS4_($1, $src_02);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $14 = __ZNK2js7MoveRefIN2JS5ValueEEcvRS2_Ev($_idx_val);
    var $15 = $14 | 0;
    var $16$0 = HEAP32[$15 >> 2];
    var $16$1 = HEAP32[$15 + 4 >> 2];
    HEAP32[$13 >> 2] = $16$0;
    HEAP32[$13 + 4 >> 2] = $16$1;
    var $v_idx1_val = HEAP32[$v_idx >> 2];
    var $v_idx2_val = HEAP32[$v_idx4 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $v_idx2_val;
    var $v_idx1_val;
    var $18 = $dst_01 + 8 | 0;
    var $19 = $src_02 + 8 | 0;
    var $20 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($v_idx1_val, $v_idx2_val);
    if (($19 | 0) == ($20 | 0)) {
      var $22 = $v_idx1_val;
      __label__ = 7;
      break;
    } else {
      var $dst_01 = $18;
      var $src_02 = $19;
      var $v_idx1_val5 = $v_idx1_val;
      var $v_idx2_val7 = $v_idx2_val;
      __label__ = 4;
      break;
    }
   case 7:
    var $22;
    __ZN2js15TempAllocPolicy5free_EPv($22);
    HEAP32[$v_idx >> 2] = $5;
    HEAP32[$v + 12 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js10VectorImplIN2JS5ValueELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj0ES3_EEj["X"] = 1;

function __ZN2js10VectorImplIN2JS5ValueELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx = $1 | 0;
    var $p_01 = $srcbeg;
    var $_02 = $dst;
    __label__ = 3;
    break;
   case 3:
    var $_02;
    var $p_01;
    if (($_02 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $5 = $_02 | 0;
    HEAP32[$5 >> 2] = 0;
    HEAP32[$5 + 4 >> 2] = 0;
    __ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERKS4_($1, $p_01);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $6 = __ZNK2js7MoveRefIN2JS5ValueEEcvRS2_Ev($_idx_val);
    var $7 = $6 | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    HEAP32[$5 >> 2] = $8$0;
    HEAP32[$5 + 4 >> 2] = $8$1;
    __label__ = 5;
    break;
   case 5:
    var $10 = $p_01 + 8 | 0;
    if (($10 | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      var $p_01 = $10;
      var $_02 = $_02 + 8 | 0;
      __label__ = 3;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSTreeContext16needStrictChecksEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[HEAP32[HEAP32[$this + 48 >> 2] + 12 >> 2] + 32 >> 2];
    var $5 = __ZNK9JSContext15hasStrictOptionEv($_idx_val);
    if ($5) {
      var $9 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this >> 2];
    var $7 = __ZNK13JSTreeContext12inStrictModeEv($this_idx_val);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK11JSParseNode9frameSlotEv($this) {
  var $_idx_val = HEAP32[$this + 40 >> 2];
  var $2 = __ZNK2js11UpvarCookie4slotEv($_idx_val);
  return $2 & 65535;
}

function __ZN2JSL12BooleanValueEb1168($agg_result, $boo) {
  __ZN2JS5Value10setBooleanEb($agg_result, $boo);
  return;
}

function __ZN8JSObject16setBlockOwnShapeEP9JSContext($this, $cx_0_11_val) {
  var $1 = __Z16js_GenerateShapeP9JSContext($cx_0_11_val);
  __ZN8JSObject11setOwnShapeEj($this, $1);
  return;
}

function __ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp($cx, $cg, $op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_Emit1($cx, $cg, $op);
    if (($1 | 0) < 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, $op);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11JSParseNode9maybeExprEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this >> 2] & 1073741824 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 36 >> 2];
    var $6 = __ZNK11JSParseNode4exprEv($this_idx_val);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17EmitSpecialPropOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn, $op, $cg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $3 = HEAP32[$pn + 32 >> 2];
    var $4 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $3, $index);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = HEAP32[$index >> 2];
    var $7 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 165, $6, $cg, 0);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = __ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp($cx, $cg, $op);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9FlushPopsP9JSContextP15JSCodeGeneratorPi($cx, $cg, $npops) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_NewSrcNote($cx, $cg, 11);
    if (($1 | 0) < 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAPU32[$npops >> 2];
    var $6 = $4 >>> 8 & 255;
    var $7 = $4 & 255;
    var $8 = _js_Emit3($cx, $cg, 11, $6, $7);
    if (($8 | 0) < 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, 11);
    HEAP32[$npops >> 2] = 0;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL22EmitDestructuringDeclsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode($cx, $cg, $prologOp, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 24);
    var $3 = HEAP32[$pn + 32 >> 2];
    if ($1) {
      var $pn2_0 = $3;
      __label__ = 2;
      break;
    } else {
      var $pn2_1 = $3;
      __label__ = 6;
      break;
    }
   case 2:
    var $pn2_0;
    if (($pn2_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_0, 3);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_0, 29);
    var $_ZL21EmitDestructuringDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode__ZL22EmitDestructuringDeclsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode = $8 ? 98 : 100;
    var $9 = FUNCTION_TABLE[$_ZL21EmitDestructuringDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode__ZL22EmitDestructuringDeclsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode]($cx, $cg, $prologOp, $pn2_0);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $pn2_0 = HEAP32[$pn2_0 + 24 >> 2];
    __label__ = 2;
    break;
   case 6:
    var $pn2_1;
    if (($pn2_1 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = HEAP32[$pn2_1 + 36 >> 2];
    var $19 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($18, 29);
    var $_ZL21EmitDestructuringDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode__ZL22EmitDestructuringDeclsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode1 = $19 ? 98 : 100;
    var $20 = FUNCTION_TABLE[$_ZL21EmitDestructuringDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode__ZL22EmitDestructuringDeclsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode1]($cx, $cg, $prologOp, $18);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $pn2_1 = HEAP32[$pn2_1 + 24 >> 2];
    __label__ = 6;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12OpToDeclType4JSOp($op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($op | 0) == 128) {
      __label__ = 2;
      break;
    } else if (($op | 0) == 129) {
      __label__ = 3;
      break;
    } else if (($op | 0) == 0) {
      var $_0 = 2;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $_0 = 3;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5Shape16hasDefaultGetterEv($this_0_4_0_val) {
  return ($this_0_4_0_val | 0) == 0;
}

function __ZN13JSTreeContext15asCodeGeneratorEv($this) {
  return $this;
}

function __ZNK11JSParseNode6isUsedEv($this) {
  return (HEAP32[$this >> 2] & 1073741824 | 0) != 0;
}

function __ZN12TempPopScopeC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZNK13JSTreeContext10scopeChainEv($this) {
  return HEAP32[$this + 60 >> 2];
}

function __ZL16MaybeEmitVarDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodePj($cx, $cg, $prologOp, $pn, $result) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $atomIndex = __stackBase__;
    var $1 = $pn + 40 | 0;
    var $_idx5_val = HEAP32[$1 >> 2];
    var $2 = __ZNK2js11UpvarCookie6isFreeEv($_idx5_val);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2js11UpvarCookie4slotEv($_idx5_val);
    var $5 = $4 & 65535;
    HEAP32[$atomIndex >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    var $9 = HEAP32[$pn + 32 >> 2];
    var $10 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $9, $atomIndex);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 4:
    var $12 = __ZNK11JSParseNode5getOpEv($pn);
    var $_idx4 = $cg | 0;
    if ((HEAP32[_js_CodeSpec + ($12 << 3) + 4 >> 2] & 31 | 0) == 2) {
      __label__ = 5;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 5:
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $18 = __ZNK13JSTreeContext10inFunctionEv($_idx4_val);
    if ($18 & ($_idx4_val & 256 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$pn + 44 >> 2] & 64 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    var $29 = $cg + 172 | 0;
    HEAP32[$29 >> 2] = $cg + 108 | 0;
    var $31 = HEAP32[$pn + 8 >> 2];
    var $32 = __ZL21UpdateLineNumberNotesP9JSContextP15JSCodeGeneratorj($cx, $cg, $31);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $35 = HEAP32[$atomIndex >> 2];
    var $36 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $prologOp, $35, $cg, 0);
    if ($36) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 9:
    HEAP32[$29 >> 2] = $cg + 140 | 0;
    __label__ = 10;
    break;
   case 10:
    var $_idx3_val = HEAP32[$_idx4 >> 2];
    var $39 = __ZNK13JSTreeContext10inFunctionEv($_idx3_val);
    if ($39) {
      __label__ = 11;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 11:
    var $41 = __ZNK11JSParseNode5getOpEv($pn);
    if ((HEAP32[_js_CodeSpec + ($41 << 3) + 4 >> 2] & 31 | 0) == 7) {
      __label__ = 12;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 12:
    var $_idx_val = HEAP32[$1 >> 2];
    var $47 = __ZNK2js11UpvarCookie4slotEv($_idx_val);
    var $_idx2_val = HEAP16[$cg + 98 >> 1];
    var $48 = __ZNK2js8Bindings9countVarsEv($_idx2_val);
    if (($47 & 65535) < ($48 & 65535)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $51 = __ZN15JSCodeGenerator20shouldNoteClosedNameEP11JSParseNode($cg, $pn);
    if ($51) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $53 = $cg + 564 | 0;
    var $54 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE6appendItEEbT_($53, $47);
    if ($54) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 15:
    if (($result | 0) == 0) {
      var $_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $58 = HEAP32[$atomIndex >> 2];
    HEAP32[$result >> 2] = $58;
    var $_0 = 1;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16MaybeEmitVarDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodePj["X"] = 1;

function __ZL21EmitDestructuringDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode($cx, $cg, $prologOp, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZL16MaybeEmitVarDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodePj($cx, $cg, $prologOp, $pn, 0);
    var $_0 = $4 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26EmitDestructuringOpsHelperP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$pn + 40 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $5 = _js_Emit1($cx, $cg, 12);
    if (($5 | 0) > -1) {
      __label__ = 3;
      break;
    } else {
      var $11 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = _js_Emit1($cx, $cg, 81);
    var $11 = ($8 | 0) > -1;
    __label__ = 4;
    break;
   case 4:
    var $11;
    var $_0 = $11 & 1;
    __label__ = 24;
    break;
   case 5:
    var $14 = $pn + 32 | 0;
    var $pn2_0_in = $14;
    var $index_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $index_0;
    var $pn2_0_in;
    var $pn2_0 = HEAPU32[$pn2_0_in >> 2];
    if (($pn2_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($pn2_0 | 0) == (HEAP32[$14 >> 2] | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = _js_NewSrcNote($cx, $cg, 5);
    if (($21 | 0) < 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $24 = _js_Emit1($cx, $cg, 12);
    if (($24 | 0) < 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $27 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 24);
    if ($27) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $30 = __ZL12EmitNumberOpP9JSContextdP15JSCodeGenerator($cx, $index_0 >>> 0, $cg);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      var $pn3_01 = $pn2_0;
      __label__ = 18;
      break;
    }
   case 12:
    var $34 = HEAPU32[$pn2_0 + 32 >> 2];
    var $35 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($34, 30);
    if ($35) {
      __label__ = 13;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 13:
    var $37 = _js_NewSrcNote($cx, $cg, 1);
    if (($37 | 0) < 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $41 = $34 + 32 | 0;
    var $42 = (tempDoubleI32[0] = HEAP32[$41 >> 2], tempDoubleI32[1] = HEAP32[$41 + 4 >> 2], tempDoubleF64[0]);
    var $43 = __ZL12EmitNumberOpP9JSContextdP15JSCodeGenerator($cx, $42, $cg);
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $pn3_01 = HEAP32[$pn2_0 + 36 >> 2];
    __label__ = 18;
    break;
   case 16:
    var $49 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $34, 53, $cg, 0);
    if ($49) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 17:
    var $pn3_02 = HEAP32[$pn2_0 + 36 >> 2];
    __label__ = 19;
    break;
   case 18:
    var $pn3_01;
    var $53 = __ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp($cx, $cg, 55);
    if ($53) {
      var $pn3_02 = $pn3_01;
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 19:
    var $pn3_02;
    var $55 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn3_02, 3);
    if ($55) {
      __label__ = 20;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 20:
    var $57 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn3_02, 0);
    if ($57) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    var $59 = _js_Emit1($cx, $cg, 81);
    if (($59 | 0) < 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    var $62 = __ZL20EmitDestructuringLHSP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn3_02);
    if (($62 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $pn2_0_in = $pn2_0 + 24 | 0;
    var $index_0 = $index_0 + 1 | 0;
    __label__ = 6;
    break;
   case 24:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL26EmitDestructuringOpsHelperP9JSContextP15JSCodeGeneratorP11JSParseNode["X"] = 1;

function __ZL20EmitDestructuringLHSP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 24);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 26);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $5 = __ZL26EmitDestructuringOpsHelperP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = _js_Emit1($cx, $cg, 81);
    if (($8 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 5:
    var $11 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 29);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $13 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $16 = __ZNK11JSParseNode7isConstEv($pn);
    if ($16) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $18 = __ZNK11JSParseNode13isInitializedEv($pn);
    if ($18) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $20 = _js_Emit1($cx, $cg, 81);
    var $_0 = $20 >>> 31 ^ 1;
    __label__ = 21;
    break;
   case 10:
    var $22 = __ZNK11JSParseNode5getOpEv($pn);
    if (($22 | 0) == 111 || ($22 | 0) == 157) {
      __label__ = 11;
      break;
    } else if (($22 | 0) == 14) {
      __label__ = 12;
      break;
    } else if (($22 | 0) == 87) {
      __label__ = 13;
      break;
    } else if (($22 | 0) == 85) {
      __label__ = 15;
      break;
    } else if (($22 | 0) == 124) {
      __label__ = 20;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 11:
    var $24 = __ZL10EmitElemOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn, 124, $cg);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 12:
    var $27 = __ZL10EmitElemOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn, 209, $cg);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 13:
    var $_idx1_val = HEAP32[$pn + 40 >> 2];
    var $31 = __ZNK2js11UpvarCookie9asIntegerEv($_idx1_val);
    var $33 = $31 >>> 8 & 255;
    var $34 = $31 & 255;
    var $35 = _js_Emit3($cx, $cg, 132, $33, $34);
    if (($35 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, 132);
    __label__ = 20;
    break;
   case 15:
    var $_idx_val = HEAP32[$pn + 40 >> 2];
    var $40 = __ZNK2js11UpvarCookie9asIntegerEv($_idx_val);
    var $42 = $40 >>> 8 & 255;
    var $43 = $40 & 255;
    var $44 = _js_Emit3($cx, $cg, 85, $42, $43);
    if (($44 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $47 = __ZNK11JSParseNode5getOpEv($pn);
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, $47);
    var $48 = _js_Emit1($cx, $cg, 81);
    if (($48 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 17:
    var $51 = $cg + 172 | 0;
    var $52 = HEAP32[$51 >> 2];
    var $54 = HEAP32[$52 + 8 >> 2];
    var $56 = HEAP32[$52 >> 2];
    var $57 = _js_EmitTree($cx, $cg, $pn);
    if (($57 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $62 = HEAP32[$51 >> 2];
    var $71 = $56 - $54 + HEAP32[$62 + 8 >> 2] - HEAP32[$62 >> 2] | 0;
    var $72 = _js_NewSrcNote2($cx, $cg, 12, $71);
    if (($72 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $75 = __ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp($cx, $cg, 124);
    if ($75) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 20:
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL20EmitDestructuringLHSP9JSContextP15JSCodeGeneratorP11JSParseNode["X"] = 1;

function __ZNK11JSParseNode13isInitializedEv($this) {
  var $1 = __ZNK11JSParseNode4testEj($this, 4);
  return $1;
}

function __ZL18EmitBigIndexPrefixP9JSContextP15JSCodeGeneratorj($cx, $cg, $index) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL19FitsWithoutBigIndexj($index);
    if ($1) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $index >>> 16;
    if ($index >>> 0 < 262144) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = $3 + 210 | 0;
    var $7 = _js_Emit1($cx, $cg, $6);
    var $_0 = ($7 >> 31 & -127) + 193 | 0;
    __label__ = 7;
    break;
   case 4:
    if ($index >>> 0 > 8388607) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 4, 14, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 66;
    __label__ = 7;
    break;
   case 6:
    var $15 = $3 & 255;
    var $16 = _js_Emit2($cx, $cg, 191, $15);
    var $_0 = ($16 >> 31 & -126) + 192 | 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19EmitGroupAssignmentP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodeS5_($cx, $cg, $prologOp, $lhs, $rhs) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg + 192 | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $pn_0_in = $rhs + 32 | 0;
    var $limit_0 = $2;
    __label__ = 2;
    break;
   case 2:
    var $limit_0;
    var $pn_0_in;
    var $pn_0 = HEAP32[$pn_0_in >> 2];
    if (($pn_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($limit_0 | 0) == 65536) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = HEAP32[$cg + 48 >> 2] + 40 | 0;
    var $12 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($11, $rhs, 0, 200, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 19;
    break;
   case 5:
    var $14 = _js_EmitTree($cx, $cg, $pn_0);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $pn_0_in = $pn_0 + 24 | 0;
    var $limit_0 = $limit_0 + 1 | 0;
    __label__ = 2;
    break;
   case 7:
    var $20 = __ZL12OpToDeclType4JSOp($prologOp);
    var $21 = _js_NewSrcNote2($cx, $cg, 7, $20);
    if (($21 | 0) < 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $pn_1_in = $lhs + 32 | 0;
    var $i_0 = $2;
    __label__ = 9;
    break;
   case 9:
    var $i_0;
    var $pn_1_in;
    var $pn_1 = HEAPU32[$pn_1_in >> 2];
    if (($pn_1 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $28 = __ZL15AdjustBlockSlotP9JSContextP15JSCodeGeneratori($cg, $i_0);
    if (($28 | 0) < 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $32 = $28 >>> 8 & 255;
    var $33 = $28 & 255;
    var $34 = _js_Emit3($cx, $cg, 86, $32, $33);
    if (($34 | 0) < 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, 86);
    var $37 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_1, 3);
    if ($37) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $39 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn_1, 0);
    if ($39) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $41 = _js_Emit1($cx, $cg, 81);
    if (($41 | 0) < 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $44 = __ZL20EmitDestructuringLHSP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn_1);
    if (($44 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $pn_1_in = $pn_1 + 24 | 0;
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 9;
    break;
   case 17:
    var $50 = $limit_0 - $2 | 0;
    var $52 = $50 >>> 8 & 255;
    var $53 = $50 & 255;
    var $54 = _js_Emit3($cx, $cg, 11, $52, $53);
    if (($54 | 0) < 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, 11);
    HEAP32[$1 >> 2] = $2;
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19EmitGroupAssignmentP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodeS5_["X"] = 1;

function __ZL25LookupCompileTimeConstantP9JSContextP15JSCodeGeneratorP6JSAtomPN2JS5ValueE($cx, $cg, $atom, $constp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 8;
    HEAP32[$1 >> 2] = $atom;
    __ZN2JS5Value8setMagicE10JSWhyMagic($constp, 5);
    var $3 = $2 | 0;
    var $p_idx = $p | 0;
    var $_01 = $cg;
    var $5 = $atom;
    __label__ = 2;
    break;
   case 2:
    var $5;
    var $_01;
    var $6 = $_01 | 0;
    var $_idx5 = $_01 | 0;
    var $_idx5_val = HEAP32[$_idx5 >> 2];
    var $7 = __ZNK13JSTreeContext10inFunctionEv($_idx5_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZNK13JSTreeContext12compileAndGoEv($_idx5_val);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $50 = $5;
      __label__ = 15;
      break;
    }
   case 4:
    var $11 = _js_LexicalLookup($6, $5, 0);
    if (($11 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 5:
    __ZNK2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_($p, $_01 + 240 | 0, $1);
    var $p_idx_val = HEAP32[$p_idx >> 2];
    var $p_idx_val_idx_val = HEAP32[$p_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($2, $p_idx_val_idx_val);
    if ((HEAP32[$3 >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($p_idx_val);
    var $19 = $18 + 8 | 0;
    var $st$2$0 = $19 | 0;
    var $20$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $19 + 4 | 0;
    var $20$1 = HEAP32[$st$2$1 >> 2];
    var $21 = $constp | 0;
    var $st$7$0 = $21 | 0;
    HEAP32[$st$7$0 >> 2] = $20$0;
    var $st$7$1 = $21 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $20$1;
    __label__ = 17;
    break;
   case 7:
    var $_idx4_val = HEAP32[$_idx5 >> 2];
    var $23 = __ZNK13JSTreeContext10inFunctionEv($_idx4_val);
    if ($23) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = HEAP32[$1 >> 2];
    var $27 = __ZNK2js8Bindings10hasBindingEP9JSContextP6JSAtom($_01 + 92 | 0, $cx, $26);
    if ($27) {
      __label__ = 17;
      break;
    } else {
      var $50 = $26;
      __label__ = 15;
      break;
    }
   case 9:
    var $29 = __ZNK13JSTreeContext10scopeChainEv($6);
    var $30 = HEAP32[$1 >> 2];
    var $31 = __ZL12ATOM_TO_JSIDP6JSAtom1150($30);
    var $32 = __ZN8JSObject12nativeLookupEP9JSContexti($29, $cx, $31);
    if (($32 | 0) == 0) {
      var $50 = $30;
      __label__ = 15;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_idx3_val = HEAP8[$32 + 28 | 0];
    var $36 = __ZNK2js5Shape8writableEv($_idx3_val);
    if ($36) {
      __label__ = 17;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $38 = __ZNK2js5Shape12configurableEv($_idx3_val);
    if ($38) {
      __label__ = 17;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $_idx1_val = HEAP32[$32 + 16 >> 2];
    var $40 = __ZNK2js5Shape16hasDefaultGetterEv($_idx1_val);
    if ($40) {
      __label__ = 13;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 13:
    var $43 = HEAP32[$32 + 24 >> 2];
    var $_idx_val_idx_val = HEAP32[HEAP32[$29 >> 2] + 4 >> 2];
    var $44 = __ZNK8JSObject12containsSlotEj($_idx_val_idx_val, $43);
    if ($44) {
      __label__ = 14;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 14:
    var $46 = __ZNK8JSObject7getSlotEj($29, $43);
    var $47 = $46 | 0;
    var $st$2$0 = $47 | 0;
    var $48$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $47 + 4 | 0;
    var $48$1 = HEAP32[$st$2$1 >> 2];
    var $49 = $constp | 0;
    var $st$7$0 = $49 | 0;
    HEAP32[$st$7$0 >> 2] = $48$0;
    var $st$7$1 = $49 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $48$1;
    __label__ = 17;
    break;
   case 15:
    var $50;
    var $52 = HEAP32[$_01 + 72 >> 2];
    if (($52 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $55 = __ZN13JSTreeContext15asCodeGeneratorEv($52);
    if (($55 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $_01 = $55;
      var $5 = $50;
      __label__ = 2;
      break;
    }
   case 17:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL25LookupCompileTimeConstantP9JSContextP15JSCodeGeneratorP6JSAtomPN2JS5ValueE["X"] = 1;

function __ZL22AllocateSwitchConstantP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 88 >> 2];
    var $4 = HEAP32[$cx + 96 >> 2];
    var $7 = $4 + 8 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    if ($9 >>> 0 > (HEAP32[$2 + 8 >> 2] - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $15 = $cx + 72 | 0;
    var $16 = _JS_ArenaAllocate($15, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17AddSwitchSpanDepsP9JSContextP15JSCodeGeneratorPh($cx, $cg, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP8[$pc];
    var $10 = ((HEAPU8[$pc + 1 | 0] & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255) << 16 >> 16;
    var $11 = __ZL10AddSpanDepP9JSContextP15JSCodeGeneratorPhS3_i($cx, $cg, $pc, $pc, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $19 = $pc + 4 | 0;
    var $22 = (HEAPU8[$pc + 3 | 0] & 255) << 8 | HEAPU8[$19] & 255;
    if ($1 << 24 >> 24 == 70) {
      __label__ = 3;
      break;
    } else {
      var $indexlen_0_ph = 2;
      var $njumps_0_ph = $22;
      var $pc2_0_ph = $19;
      __label__ = 4;
      break;
    }
   case 3:
    var $29 = $pc + 6 | 0;
    var $indexlen_0_ph = 0;
    var $njumps_0_ph = 1 - ($22 << 16 >> 16) + (((HEAPU8[$pc + 5 | 0] & 255) << 8 | HEAPU8[$29] & 255) << 16 >> 16) | 0;
    var $pc2_0_ph = $29;
    __label__ = 4;
    break;
   case 4:
    var $pc2_0_ph;
    var $njumps_0_ph;
    var $indexlen_0_ph;
    var $_sum1 = $indexlen_0_ph | 1;
    var $_sum = $indexlen_0_ph + 2 | 0;
    var $njumps_0 = $njumps_0_ph;
    var $pc2_0 = $pc2_0_ph;
    __label__ = 5;
    break;
   case 5:
    var $pc2_0;
    var $njumps_0;
    if (($njumps_0 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $44 = $pc2_0 + $_sum | 0;
    var $48 = ((HEAPU8[$pc2_0 + $_sum1 | 0] & 255) << 8 | HEAPU8[$44] & 255) << 16 >> 16;
    var $49 = __ZL10AddSpanDepP9JSContextP15JSCodeGeneratorPhS3_i($cx, $cg, $pc, $pc2_0 + $indexlen_0_ph | 0, $48);
    if (($49 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $njumps_0 = $njumps_0 - 1 | 0;
    var $pc2_0 = $44;
    __label__ = 5;
    break;
   case 8:
    var $_0 = $pc2_0 + 1 | 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17AddSwitchSpanDepsP9JSContextP15JSCodeGeneratorPh["X"] = 1;

function __ZL10AddSpanDepP9JSContextP15JSCodeGeneratorPhS3_i($cx, $cg, $pc, $pc2, $off) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg + 220 | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = $2 + 1 | 0;
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $cg_idx1_val = HEAP32[$cg + 24 >> 2];
    __ZL23ReportStatementTooLargeP9JSContextP15JSCodeGenerator($cx, $cg_idx1_val);
    var $_0 = 0;
    __label__ = 15;
    break;
   case 3:
    var $10 = $cg + 208 | 0;
    var $11 = HEAPU32[$10 >> 2];
    if (($2 - 1 & $2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $21 = $11;
      __label__ = 7;
      break;
    }
   case 4:
    var $13 = ($11 | 0) != 0;
    if ($2 >>> 0 > 255 | $13 ^ 1) {
      __label__ = 5;
      break;
    } else {
      var $21 = $11;
      __label__ = 7;
      break;
    }
   case 5:
    var $phitmp_ = $13 ? $2 << 5 : 4096;
    var $16 = $11;
    var $17 = __ZN9JSContext8realloc_EPvj($cx, $16, $phitmp_);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = $17;
    HEAP32[$10 >> 2] = $20;
    var $21 = $20;
    __label__ = 7;
    break;
   case 7:
    var $21;
    HEAP32[$1 >> 2] = $3;
    var $22 = $21 + ($2 << 4) | 0;
    var $23 = $cg + 172 | 0;
    var $29 = $pc - HEAP32[HEAP32[$23 >> 2] >> 2] | 0;
    HEAP32[$22 >> 2] = $29;
    var $36 = $pc2 - HEAP32[HEAP32[$23 >> 2] >> 2] | 0;
    HEAP32[$21 + ($2 << 4) + 8 >> 2] = $36;
    HEAP32[$21 + ($2 << 4) + 4 >> 2] = $36;
    if ((HEAP32[_js_CodeSpec + ((HEAPU8[$pc] & 255) << 3) + 4 >> 2] & 32768 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if (($off | 0) > 1073741823) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $cg_idx_val = HEAP32[$cg + 24 >> 2];
    __ZL23ReportStatementTooLargeP9JSContextP15JSCodeGenerator($cx, $cg_idx_val);
    var $_0 = 0;
    __label__ = 15;
    break;
   case 10:
    HEAP32[$21 + ($2 << 4) + 12 >> 2] = $off << 1;
    __label__ = 14;
    break;
   case 11:
    if (($off | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    HEAP32[$21 + ($2 << 4) + 12 >> 2] = 1;
    __label__ = 14;
    break;
   case 13:
    var $57 = __ZL16SetSpanDepTargetP9JSContextP15JSCodeGeneratorP9JSSpanDepi($cx, $cg, $22, $off);
    if (($57 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $index_0 = $2 >>> 0 < 65535 ? $2 : 65535;
    HEAP8[$pc2 + 1 | 0] = $index_0 >>> 8 & 255;
    HEAP8[$pc2 + 2 | 0] = $index_0 & 255;
    var $_0 = 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10AddSpanDepP9JSContextP15JSCodeGeneratorPhS3_i["X"] = 1;

function __ZNK2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js8Bindings10hasBindingEP9JSContextP6JSAtom($this, $cx, $name) {
  var $1 = $this;
  var $2 = $cx;
  var $3 = __ZNK2js8Bindings6lookupEP9JSContextP6JSAtomPj($1, $2, $name, 0);
  return ($3 | 0) != 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry);
  return;
}

function __ZNK11JSParseNode13isDeoptimizedEv($this) {
  var $1 = __ZNK11JSParseNode4testEj($this, 1024);
  return $1;
}

function __ZN12JSDefinition4kindEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZNK11JSParseNode7getKindEv($1);
    if (($2 | 0) == 34) {
      var $_0 = 3;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK11JSParseNode4isOpE4JSOp($1, 0);
    if ($5) {
      var $_0 = 5;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK11JSParseNode4isOpE4JSOp($1, 84);
    if ($7) {
      var $_0 = 4;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZNK11JSParseNode7isConstEv($1);
    if ($9) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZNK11JSParseNode5isLetEv($1);
    var $_ = $11 ? 2 : 0;
    var $_0 = $_;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK11JSParseNode10isTopLevelEv($this) {
  var $1 = __ZNK11JSParseNode4testEj($this, 16);
  return $1;
}

function __ZNK12JSDefinition8isGlobalEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK11JSParseNode4testEj($1, 64);
  return $2;
}

function __ZNK13JSTreeContext3funEv($this_0_14_0_val) {
  return $this_0_14_0_val;
}

function __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js7MoveRefINS_11UpvarCookieEEcvRS1_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5countEv($this_0_3_val) {
  return $this_0_3_val;
}

function __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZL14JSID_FROM_BITSj1189($bits) {
  return $bits;
}

function __ZNK2js11TokenStream11getFilenameEv($this_0_9_val) {
  return $this_0_9_val;
}

function __ZNK13JSTreeContext16mightAliasLocalsEv($this_0_0_val) {
  return ($this_0_0_val & 67108864 | 0) != 0;
}

function __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE5emptyEv($this_0_2_val) {
  return ($this_0_2_val | 0) == 0;
}

function __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE8usingMapEv($this_0_0_val) {
  return $this_0_0_val >>> 0 > 24;
}

function __ZNK13JSTreeContext13usesArgumentsEv($this_0_0_val) {
  return ($this_0_0_val & 128 | 0) != 0;
}

function __ZN13JSTreeContext8compilerEv($this_0_11_val) {
  return $this_0_11_val;
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE11allocPolicyEv($this) {
  return $this | 0;
}

function __ZN2js7MoveRefINS_11UpvarCookieEEC2ERS1_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC2EPNS3_10InlineElemE($this, $ie) {
  HEAP32[$this + 4 >> 2] = $ie;
  HEAP8[$this + 8 | 0] = 1;
  return;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC2ENS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E3PtrE($this, $p_0) {
  HEAP32[$this >> 2] = $p_0;
  HEAP8[$this + 8 | 0] = 0;
  return;
}

function __ZN16EmitLevelManagerC2EP15JSCodeGenerator($this, $cg) {
  HEAP32[$this >> 2] = $cg;
  var $2 = $cg + 236 | 0;
  var $4 = HEAP32[$2 >> 2] + 1 | 0;
  HEAP32[$2 >> 2] = $4;
  return;
}

function __ZN2js2gcL15GetGCObjectKindEjb1183($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18BalanceJumpTargetsPP12JSJumpTarget($jtp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[$jtp >> 2];
    var $2 = $1 + 4 | 0;
    var $3 = HEAPU32[$2 >> 2];
    if (($3 | 0) < -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $doubleRotate_0 = (HEAP32[HEAP32[$1 + 8 >> 2] + 4 >> 2] | 0) > 0 & 1;
    var $dir_0 = 1;
    __label__ = 5;
    break;
   case 3:
    if (($3 | 0) > 1) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $doubleRotate_0 = HEAPU32[HEAP32[$1 + 12 >> 2] + 4 >> 2] >>> 31;
    var $dir_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $dir_0;
    var $doubleRotate_0;
    var $20 = 1 - $dir_0 | 0;
    var $22 = $1 + 8 + ($20 << 2) | 0;
    var $23 = HEAPU32[$22 >> 2];
    if (($doubleRotate_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $25 = $23 + 8 + ($dir_0 << 2) | 0;
    var $26 = HEAPU32[$25 >> 2];
    HEAP32[$jtp >> 2] = $26;
    var $27 = $26 + 8 + ($dir_0 << 2) | 0;
    var $28 = HEAP32[$27 >> 2];
    HEAP32[$22 >> 2] = $28;
    HEAP32[$27 >> 2] = $1;
    var $29 = $26 + 8 + ($20 << 2) | 0;
    var $30 = HEAP32[$29 >> 2];
    HEAP32[$25 >> 2] = $30;
    HEAP32[$29 >> 2] = $23;
    var $31 = $26 + 4 | 0;
    var $32 = HEAP32[$31 >> 2];
    var $34 = ($32 | 0) > 0 ? -$32 | 0 : 0;
    var $37 = HEAP32[$26 + 8 >> 2] + 4 | 0;
    HEAP32[$37 >> 2] = $34;
    var $38 = HEAP32[$31 >> 2];
    var $40 = ($38 | 0) < 0 ? -$38 | 0 : 0;
    var $43 = HEAP32[$26 + 12 >> 2] + 4 | 0;
    HEAP32[$43 >> 2] = $40;
    HEAP32[$31 >> 2] = 0;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 7:
    HEAP32[$jtp >> 2] = $23;
    var $45 = $23 + 8 + ($dir_0 << 2) | 0;
    var $46 = HEAP32[$45 >> 2];
    HEAP32[$22 >> 2] = $46;
    HEAP32[$45 >> 2] = $1;
    var $47 = $23 + 4 | 0;
    var $48 = HEAPU32[$47 >> 2];
    var $50 = ($48 | 0) != 0 & 1;
    var $storemerge_v = ($dir_0 | 0) == 0 ? -1 : 1;
    var $storemerge = $48 + $storemerge_v | 0;
    HEAP32[$47 >> 2] = $storemerge;
    HEAP32[$2 >> 2] = -$storemerge | 0;
    var $_0 = $50;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18BalanceJumpTargetsPP12JSJumpTarget["X"] = 1;

function __ZL17TryConvertToGnameP15JSCodeGeneratorP11JSParseNodeP4JSOp($cg, $pn, $op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$cg >> 2];
    var $1 = __ZNK13JSTreeContext12compileAndGoEv($_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$cg + 48 >> 2];
    var $3 = __ZN13JSTreeContext8compilerEv($_idx1_val);
    if ((HEAP32[HEAP32[$3 + 992 >> 2] >> 2] | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK13JSTreeContext16mightAliasLocalsEv($_idx_val);
    if ($10) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = __ZNK11JSParseNode13isDeoptimizedEv($pn);
    if ($12) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($_idx_val & 262144 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 6:
    var $17 = HEAP32[$op >> 2];
    if (($17 | 0) == 59) {
      __label__ = 7;
      break;
    } else if (($17 | 0) == 111) {
      __label__ = 8;
      break;
    } else if (($17 | 0) == 41) {
      __label__ = 9;
      break;
    } else if (($17 | 0) == 47) {
      __label__ = 10;
      break;
    } else if (($17 | 0) == 44) {
      __label__ = 11;
      break;
    } else if (($17 | 0) == 50) {
      __label__ = 12;
      break;
    } else if (($17 | 0) == 14 || ($17 | 0) == 36) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 7:
    HEAP32[$op >> 2] = 156;
    __label__ = 13;
    break;
   case 8:
    HEAP32[$op >> 2] = 157;
    __label__ = 13;
    break;
   case 9:
    HEAP32[$op >> 2] = 158;
    __label__ = 13;
    break;
   case 10:
    HEAP32[$op >> 2] = 160;
    __label__ = 13;
    break;
   case 11:
    HEAP32[$op >> 2] = 159;
    __label__ = 13;
    break;
   case 12:
    HEAP32[$op >> 2] = 161;
    __label__ = 13;
    break;
   case 13:
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Bindings8addUpvarEP9JSContextP6JSAtom($this, $cx, $name) {
  var $1 = $this;
  var $2 = $cx;
  var $3 = __ZN2js8Bindings3addEP9JSContextP6JSAtomNS_11BindingKindE($1, $2, $name, 4);
  return $3;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5countEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE8usingMapEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this + 200 | 0;
    var $4 = __ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv($3);
    var $9 = $4;
    __label__ = 4;
    break;
   case 3:
    var $9 = HEAP32[$this + 4 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE19growByUninitializedEj($this, $incr) {
  __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr);
  return;
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE16replaceRawBufferEPS1_j($this, $p, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    if ($length >>> 0 < 9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = $this + 16 | 0;
    var $9 = __ZN7mozilla14AlignedStorageILj32EE4addrEv($8);
    var $10 = $9;
    HEAP32[$this + 4 >> 2] = $10;
    HEAP32[$this + 8 >> 2] = $length;
    HEAP32[$this + 12 >> 2] = 8;
    var $14 = $p + ($length << 2) | 0;
    __ZN2js10VectorImplINS_11UpvarCookieELj8ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_($10, $p, $14);
    var $15 = $p;
    __ZN2js15TempAllocPolicy5free_EPv($15);
    __label__ = 6;
    break;
   case 5:
    HEAP32[$this + 4 >> 2] = $p;
    HEAP32[$this + 8 >> 2] = $length;
    HEAP32[$this + 12 >> 2] = $length;
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEEixEj($this_0_1_val, $i) {
  var $1 = __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE5beginEv($this_0_1_val);
  return $1 + ($i << 2) | 0;
}

function __ZN2js10VectorImplINS_11UpvarCookieELj8ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_($dst, $srcbeg, $srcend) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx = $1 | 0;
    var $p_01 = $srcbeg;
    var $_02 = $dst;
    __label__ = 3;
    break;
   case 3:
    var $_02;
    var $p_01;
    if (($_02 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $5 = $_02 | 0;
    HEAP32[$5 >> 2] = 0;
    __ZN2js4MoveINS_11UpvarCookieEEENS_7MoveRefIT_EERKS3_($1, $p_01);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $6 = __ZNK2js7MoveRefINS_11UpvarCookieEEcvRS1_Ev($_idx_val);
    var $8 = HEAP32[$6 >> 2];
    HEAP32[$5 >> 2] = $8;
    __label__ = 5;
    break;
   case 5:
    var $10 = $p_01 + 4 | 0;
    if (($10 | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      var $p_01 = $10;
      var $_02 = $_02 + 4 | 0;
      __label__ = 3;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_11UpvarCookieEEENS_7MoveRefIT_EERKS3_($agg_result, $t) {
  __ZN2js7MoveRefINS_11UpvarCookieEEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_11UpvarCookieEEC1ERS1_($this, $t) {
  __ZN2js7MoveRefINS_11UpvarCookieEEC2ERS1_($this, $t);
  return;
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 8 | 0;
    var $4 = HEAPU32[$3 >> 2];
    if ((HEAP32[$this + 12 >> 2] - $4 | 0) >>> 0 < $incr >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $10 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = HEAP32[$3 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $10;
    HEAP32[$3 >> 2] = $10 + $incr | 0;
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 2;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplINS_11UpvarCookieELj8ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplINS_11UpvarCookieELj8ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj8ES2_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplINS_11UpvarCookieELj8ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj8ES2_EEj($v, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $v | 0;
    var $3 = $newcap << 2;
    var $4 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $v_idx = $v + 4 | 0;
    var $v_idx_val = HEAP32[$v_idx >> 2];
    var $8 = __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($v_idx_val);
    var $v_idx4 = $v + 8 | 0;
    var $v_idx4_val = HEAP32[$v_idx4 >> 2];
    var $9 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE10endNoCheckEv($v_idx_val, $v_idx4_val);
    if (($8 | 0) == ($9 | 0)) {
      var $22 = $v_idx_val;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx = $1 | 0;
    var $dst_01 = $5;
    var $src_02 = $8;
    var $v_idx1_val5 = $v_idx_val;
    var $v_idx2_val7 = $v_idx4_val;
    __label__ = 4;
    break;
   case 4:
    var $v_idx2_val7;
    var $v_idx1_val5;
    var $src_02;
    var $dst_01;
    if (($dst_01 | 0) == 0) {
      var $v_idx1_val = $v_idx1_val5;
      var $v_idx2_val = $v_idx2_val7;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = $dst_01 | 0;
    HEAP32[$13 >> 2] = 0;
    __ZN2js4MoveINS_11UpvarCookieEEENS_7MoveRefIT_EERS3_($1, $src_02);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $14 = __ZNK2js7MoveRefINS_11UpvarCookieEEcvRS1_Ev($_idx_val);
    var $16 = HEAP32[$14 >> 2];
    HEAP32[$13 >> 2] = $16;
    var $v_idx1_val = HEAP32[$v_idx >> 2];
    var $v_idx2_val = HEAP32[$v_idx4 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $v_idx2_val;
    var $v_idx1_val;
    var $18 = $dst_01 + 4 | 0;
    var $19 = $src_02 + 4 | 0;
    var $20 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE10endNoCheckEv($v_idx1_val, $v_idx2_val);
    if (($19 | 0) == ($20 | 0)) {
      var $22 = $v_idx1_val;
      __label__ = 7;
      break;
    } else {
      var $dst_01 = $18;
      var $src_02 = $19;
      var $v_idx1_val5 = $v_idx1_val;
      var $v_idx2_val7 = $v_idx2_val;
      __label__ = 4;
      break;
    }
   case 7:
    var $22;
    __ZN2js15TempAllocPolicy5free_EPv($22);
    HEAP32[$v_idx >> 2] = $5;
    HEAP32[$v + 12 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js10VectorImplINS_11UpvarCookieELj8ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj8ES2_EEj["X"] = 1;

function __ZN2js4MoveINS_11UpvarCookieEEENS_7MoveRefIT_EERS3_($agg_result, $t) {
  __ZN2js7MoveRefINS_11UpvarCookieEEC1ERS1_($agg_result, $t);
  return;
}

function __ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv($this) {
  var $_idx_val = HEAP32[$this + 12 >> 2];
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5countEv($_idx_val);
  return $1;
}

function __ZNK11JSParseNode5isLetEv($this) {
  var $1 = __ZNK11JSParseNode4testEj($this, 1);
  return $1;
}

function __ZL15BindKnownGlobalP9JSContextP15JSCodeGeneratorP11JSParseNodeS4_P6JSAtom($cg, $dn, $pn, $atom) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $atom;
    var $_idx4_val = HEAP32[$cg >> 2];
    var $2 = __ZNK13JSTreeContext16mightAliasLocalsEv($_idx4_val);
    if ($2) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx2_val = HEAP32[$cg + 48 >> 2];
    var $4 = __ZN13JSTreeContext8compilerEv($_idx2_val);
    var $6 = HEAP32[$4 + 992 >> 2];
    var $_idx1_val = HEAP32[$dn + 40 >> 2];
    var $8 = __ZNK2js11UpvarCookie6isFreeEv($_idx1_val);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = $6 + 216 | 0;
    __ZN2js9InlineMapIP6JSAtomjLj24EE6lookupERKS2_($p, $10, $1);
    var $11 = __ZN2js9InlineMapIP6JSAtomjLj24EE3Ptr5valueEv($p);
    var $index_0_in = $11;
    var $27 = HEAP32[$1 >> 2];
    __label__ = 7;
    break;
   case 4:
    var $14 = HEAP32[$6 + 4 >> 2];
    if (($14 | 0) == ($cg | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    HEAP32[$pn + 40 >> 2] = $_idx1_val;
    var $19 = $pn + 44 | 0;
    var $21 = HEAP32[$19 >> 2] | 512;
    HEAP32[$19 >> 2] = $21;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 6:
    var $23 = __ZNK2js11UpvarCookie9asIntegerEv($_idx1_val);
    var $_idx3_val = HEAP32[$14 + 368 >> 2];
    var $24 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEEixEj($_idx3_val, $23);
    var $index_0_in = $24 + 4 | 0;
    var $27 = $atom;
    __label__ = 7;
    break;
   case 7:
    var $27;
    var $index_0_in;
    var $index_0 = HEAP32[$index_0_in >> 2];
    var $28 = $pn + 40 | 0;
    var $29 = $28;
    var $30 = __ZN15JSCodeGenerator12addGlobalUseEP6JSAtomjPN2js11UpvarCookieE($cg, $27, $index_0, $29);
    if ($30) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $_idx_val = HEAP32[$28 >> 2];
    var $32 = __ZNK2js11UpvarCookie6isFreeEv($_idx_val);
    if ($32) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $35 = $pn + 44 | 0;
    var $37 = HEAP32[$35 >> 2] | 512;
    HEAP32[$35 >> 2] = $37;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15BindKnownGlobalP9JSContextP15JSCodeGeneratorP11JSParseNodeS4_P6JSAtom["X"] = 1;

function __ZN2js9InlineMapIP6JSAtomjLj24EE6lookupERKS2_($agg_result, $this, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $_idx_val = HEAP32[$this >> 2];
    var $2 = __ZNK2js9InlineMapIP6JSAtomjLj24EE8usingMapEv($_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this + 200 | 0;
    __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_($1, $4, $key);
    var $_0_val = HEAP32[$1 >> 2];
    __ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC1ENS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E3PtrE($agg_result, $_0_val);
    __label__ = 9;
    break;
   case 3:
    var $7 = $this + 8 + ($_idx_val << 3) | 0;
    var $it_0 = $this + 8 | 0;
    __label__ = 4;
    break;
   case 4:
    var $it_0;
    if (($it_0 | 0) == ($7 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$it_0 >> 2] | 0) == (HEAP32[$key >> 2] | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC1EPNS3_10InlineElemE($agg_result, $it_0);
    __label__ = 9;
    break;
   case 7:
    var $it_0 = $it_0 + 8 | 0;
    __label__ = 4;
    break;
   case 8:
    __ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC1EPNS3_10InlineElemE($agg_result, 0);
    __label__ = 9;
    break;
   case 9:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE3Ptr5valueEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 8 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = HEAP32[$this + 4 >> 2] + 4 | 0;
    __label__ = 4;
    break;
   case 3:
    var $_idx_val = HEAP32[$this >> 2];
    var $10 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($_idx_val);
    var $13 = $10 + 4 | 0;
    __label__ = 4;
    break;
   case 4:
    var $13;
    return $13;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEEixEj($this_0_1_val, $i) {
  var $1 = __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE5beginEv($this_0_1_val);
  return $1 + ($i << 3) | 0;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC1ENS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E3PtrE($this, $p_01) {
  __ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC2ENS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E3PtrE($this, $p_01);
  return;
}

function __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_($agg_result, $1, $l);
  return;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC1EPNS3_10InlineElemE($this, $ie) {
  __ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC2EPNS3_10InlineElemE($this, $ie);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS5_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry);
  return;
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1177($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, __ZN2js11ObjectClassE, $1, $parent, 0, (__ZN2js11ObjectClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $7 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, __ZN2js11ObjectClassE, $kind);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $10);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13AddJumpTargetP17AddJumpTargetArgsPP12JSJumpTarget($args, $jtp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[$jtp >> 2];
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 2:
    var $5 = HEAPU32[$args + 4 >> 2];
    var $6 = $5 + 216 | 0;
    var $7 = HEAPU32[$6 >> 2];
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = HEAP32[$7 + 8 >> 2];
    HEAP32[$6 >> 2] = $11;
    var $jt_0 = $7;
    __label__ = 9;
    break;
   case 4:
    var $13 = $args | 0;
    var $14 = HEAPU32[$13 >> 2];
    var $16 = HEAP32[$14 + 88 >> 2];
    var $18 = HEAP32[$14 + 96 >> 2];
    var $21 = $18 + 16 & ($18 ^ -1);
    var $22 = $16 + 12 | 0;
    var $23 = HEAPU32[$22 >> 2];
    var $25 = HEAPU32[$16 + 8 >> 2];
    if ($21 >>> 0 > $25 >>> 0 | $23 >>> 0 > ($25 - $21 | 0) >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $30 = $14 + 72 | 0;
    var $31 = _JS_ArenaAllocate($30, $21);
    var $_p_0 = $31;
    __label__ = 7;
    break;
   case 6:
    var $34 = $21 + $23 | 0;
    HEAP32[$22 >> 2] = $34;
    var $_p_0 = $23;
    __label__ = 7;
    break;
   case 7:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $jt_0 = $_p_0;
      __label__ = 9;
      break;
    }
   case 8:
    var $39 = HEAP32[$13 >> 2];
    __Z20js_ReportOutOfMemoryP9JSContext($39);
    var $_0 = 0;
    __label__ = 18;
    break;
   case 9:
    var $jt_0;
    var $42 = HEAP32[$args + 8 >> 2];
    HEAP32[$jt_0 >> 2] = $42;
    HEAP32[$jt_0 + 4 >> 2] = 0;
    HEAP32[$jt_0 + 12 >> 2] = 0;
    HEAP32[$jt_0 + 8 >> 2] = 0;
    var $47 = $5 + 224 | 0;
    var $49 = HEAP32[$47 >> 2] + 1 | 0;
    HEAP32[$47 >> 2] = $49;
    HEAP32[$args + 12 >> 2] = $jt_0;
    HEAP32[$jtp >> 2] = $jt_0;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 10:
    var $53 = HEAP32[$1 >> 2];
    var $55 = HEAP32[$args + 8 >> 2];
    if (($53 | 0) == ($55 | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$args + 12 >> 2] = $1;
    var $_0 = 0;
    __label__ = 18;
    break;
   case 12:
    if (($55 | 0) < ($53 | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $62 = $1 + 8 | 0;
    var $63 = __ZL13AddJumpTargetP17AddJumpTargetArgsPP12JSJumpTarget($args, $62);
    var $balanceDelta_0 = -$63 | 0;
    __label__ = 15;
    break;
   case 14:
    var $66 = $1 + 12 | 0;
    var $67 = __ZL13AddJumpTargetP17AddJumpTargetArgsPP12JSJumpTarget($args, $66);
    var $balanceDelta_0 = $67;
    __label__ = 15;
    break;
   case 15:
    var $balanceDelta_0;
    if ((HEAP32[$args + 12 >> 2] | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $73 = $1 + 4 | 0;
    var $75 = HEAP32[$73 >> 2] + $balanceDelta_0 | 0;
    HEAP32[$73 >> 2] = $75;
    if (($balanceDelta_0 | 0) == 0 | ($75 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $79 = __ZL18BalanceJumpTargetsPP12JSJumpTarget($jtp);
    var $_0 = 1 - $79 | 0;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13AddJumpTargetP17AddJumpTargetArgsPP12JSJumpTarget["X"] = 1;

function _js_GetStackUses($cs_0_1_val, $op, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($cs_0_1_val << 24 >> 24 > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $cs_0_1_val << 24 >> 24;
    __label__ = 4;
    break;
   case 3:
    var $5 = _js_GetVariableStackUses($op, $pc);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL10Int32ValueEi1190($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEED1Ev($this) {
  __ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEED2Ev($this);
  return;
}

function __ZN2js9AtomDeclsD1Ev($this) {
  __ZN2js9AtomDeclsD2Ev($this);
  return;
}

function __ZN2js9AtomDeclsD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $7 = __ZN9JSContext12parseMapPoolEv($_idx_val);
    __ZN2js12ParseMapPool7releaseEPNS_9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EEE($7, $2);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ParseMapPool7releaseEPNS_9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EEE($this, $map) {
  var $1 = $map;
  __ZN2js12ParseMapPool7recycleEPv($this, $1);
  return;
}

function __ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEED2Ev($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$this + 4 >> 2];
  __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE10releaseMapEP9JSContext($1, $3);
  return;
}

function __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 24 >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_ED1Ev($this_0_6_val) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_ED2Ev($this_0_6_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_ED2Ev($this_0_6_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_6_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($this_0_6_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject7isErrorEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js10ErrorClassE | 0);
}

function __ZN14JSCGObjectListC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js9AtomDeclsC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN13JSGCConstListD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEED1Ev($1);
  return;
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9AtomDecls4initEv($this) {
  var $_idx_val = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
  var $3 = __ZN9JSContext12parseMapPoolEv($_idx_val);
  var $4 = __ZN2js12ParseMapPool7acquireINS_9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EEEEEPT_v($3);
  HEAP32[$this + 4 >> 2] = $4;
  return ($4 | 0) != 0;
}

function __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE9ensureMapEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $cx_idx_val = HEAP32[$cx + 100 >> 2];
    var $5 = __ZN9JSContext12parseMapPoolEv($cx_idx_val);
    var $6 = __ZN2js12ParseMapPool7acquireINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEEPT_v($5);
    HEAP32[$1 >> 2] = $6;
    var $_0 = ($6 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ParseMapPool7acquireINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEEPT_v($this) {
  var $1 = __ZN2js12ParseMapPool8allocateEv($this);
  return $1;
}

function __ZN2js12ParseMapPool7acquireINS_9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EEEEEPT_v($this) {
  var $1 = __ZN2js12ParseMapPool8allocateEv($this);
  return $1;
}

function __ZN13JSGCConstListC2EP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEEC1ES3_($2, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEEC1ES3_($this, $ap_01) {
  __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap_01);
  return;
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZN2js9AtomDeclsC1EP9JSContext($this, $cx) {
  __ZN2js9AtomDeclsC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEEC1EP9JSContext($this, $cx) {
  __ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEEC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEEC2EP9JSContext($this, $cx) {
  HEAP32[$this + 4 >> 2] = $cx;
  var $2 = $this | 0;
  __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE4initEv($2);
  return;
}

function __ZL11exn_resolveP9JSContextP8JSObjectijPS2_($cx, $obj, $id, $flags, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    HEAP32[$objp >> 2] = 0;
    var $5 = __ZL13GetExnPrivateP8JSObject($obj);
    if (($5 | 0) == 0) {
      var $_0 = 1;
      __label__ = 15;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZL12JSID_IS_ATOMi1253($id);
    if (($8 | 0) == 0) {
      var $_0 = 1;
      __label__ = 15;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = _JSID_TO_STRING1254($id);
    var $13 = HEAP32[$cx + 52 >> 2];
    if (($11 | 0) == (HEAP32[$13 + 210264 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $20 = HEAP32[$5 + 4 >> 2];
    if (($20 | 0) == 0) {
      var $_0 = 1;
      __label__ = 15;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _STRING_TO_JSVAL1211($1, $20);
    var $_06 = $1 | 0;
    var $attrs_0 = 0;
    var $prop_0 = STRING_TABLE._js_message_str | 0;
    var $v_0_0_0$1 = HEAP32[$_06 + 4 >> 2];
    var $v_0_0_0$0 = HEAP32[$_06 >> 2];
    __label__ = 13;
    break;
   case 6:
    if (($11 | 0) == (HEAP32[$13 + 210216 >> 2] | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $30 = HEAP32[$5 + 8 >> 2];
    _STRING_TO_JSVAL1211($2, $30);
    var $_07 = $2 | 0;
    var $st$4$0 = $_07 | 0;
    var $st$4$1 = $_07 + 4 | 0;
    var $attrs_0 = 1;
    var $prop_0 = STRING_TABLE._js_fileName_str | 0;
    var $v_0_0_0$1 = HEAP32[$st$4$1 >> 2];
    var $v_0_0_0$0 = HEAP32[$st$4$0 >> 2];
    __label__ = 13;
    break;
   case 8:
    if (($11 | 0) == (HEAP32[$13 + 210260 >> 2] | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $38 = HEAP32[$5 + 12 >> 2];
    _INT_TO_JSVAL($3, $38);
    var $_09 = $3 | 0;
    var $st$4$0 = $_09 | 0;
    var $st$4$1 = $_09 + 4 | 0;
    var $attrs_0 = 1;
    var $prop_0 = STRING_TABLE._js_lineNumber_str | 0;
    var $v_0_0_0$1 = HEAP32[$st$4$1 >> 2];
    var $v_0_0_0$0 = HEAP32[$st$4$0 >> 2];
    __label__ = 13;
    break;
   case 10:
    if (($11 | 0) == (HEAP32[$13 + 210304 >> 2] | 0)) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 15;
      break;
    }
   case 11:
    var $45 = __ZL18StackTraceToStringP9JSContextP12JSExnPrivate($cx, $5);
    if (($45 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    HEAP32[$5 + 16 >> 2] = 0;
    _STRING_TO_JSVAL1211($4, $45);
    var $_011 = $4 | 0;
    var $st$4$0 = $_011 | 0;
    var $st$4$1 = $_011 + 4 | 0;
    var $attrs_0 = 1;
    var $prop_0 = STRING_TABLE._js_stack_str | 0;
    var $v_0_0_0$1 = HEAP32[$st$4$1 >> 2];
    var $v_0_0_0$0 = HEAP32[$st$4$0 >> 2];
    __label__ = 13;
    break;
   case 13:
    var $v_0_0_0$0;
    var $v_0_0_0$1;
    var $prop_0;
    var $attrs_0;
    var $50 = $cx;
    var $51 = $obj;
    var $52 = _JS_DefineProperty($50, $51, $prop_0, $v_0_0_0$0, $v_0_0_0$1, 0, 0, $attrs_0);
    if (($52 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11exn_resolveP9JSContextP8JSObjectijPS2_["X"] = 1;

function __ZL12exn_finalizeP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL13GetExnPrivateP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$1 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $5;
    __ZN9JSContext5free_EPv($8);
    __label__ = 4;
    break;
   case 4:
    var $10 = $1;
    __ZN9JSContext5free_EPv($10);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9exn_traceP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL13GetExnPrivateP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$1 + 4 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $trc;
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($8, $5);
    __label__ = 4;
    break;
   case 4:
    var $11 = HEAP32[$1 + 8 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = $trc;
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($14, $11);
    __label__ = 6;
    break;
   case 6:
    var $16 = $1 + 16 | 0;
    if ((HEAP32[$16 >> 2] | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = $trc + 4 | 0;
    var $21 = $trc;
    var $elem_012 = $1 + 24 | 0;
    var $vcount_013 = 0;
    var $i_014 = 0;
    __label__ = 8;
    break;
   case 8:
    var $i_014;
    var $vcount_013;
    var $elem_012;
    var $24 = HEAP32[$elem_012 >> 2];
    if (($24 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($21, $24);
    __label__ = 10;
    break;
   case 10:
    if ((HEAP32[$20 >> 2] | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $31 = HEAP32[$elem_012 + 8 >> 2];
    if (($31 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __Z21js_MarkScriptFilenamePKc($31);
    __label__ = 13;
    break;
   case 13:
    var $36 = HEAP32[$elem_012 + 4 >> 2] + $vcount_013 | 0;
    var $37 = $i_014 + 1 | 0;
    if (($37 | 0) == (HEAP32[$16 >> 2] | 0)) {
      __label__ = 14;
      break;
    } else {
      var $elem_012 = $elem_012 + 16 | 0;
      var $vcount_013 = $36;
      var $i_014 = $37;
      __label__ = 8;
      break;
    }
   case 14:
    if (($36 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $42 = __ZL24GetStackTraceValueBufferP12JSExnPrivate($1);
    var $i_110 = 0;
    var $vp_011 = $42;
    __label__ = 16;
    break;
   case 16:
    var $vp_011;
    var $i_110;
    var $vp_03_0 = $vp_011 | 0;
    var $tmp$0 = HEAP32[$vp_03_0 >> 2];
    var $tmp$1 = HEAP32[$vp_03_0 + 4 >> 2];
    var $44 = _JSVAL_IS_TRACEABLE($tmp$0, $tmp$1);
    if (($44 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $47 = _JSVAL_TO_GCTHING($tmp$0, $tmp$1);
    var $48 = _JSVAL_TRACE_KIND($tmp$0, $tmp$1);
    _JS_CallTracer($21, $47, $48);
    __label__ = 18;
    break;
   case 18:
    var $50 = $i_110 + 1 | 0;
    if (($50 | 0) == ($36 | 0)) {
      __label__ = 19;
      break;
    } else {
      var $i_110 = $50;
      var $vp_011 = $vp_011 + 8 | 0;
      __label__ = 16;
      break;
    }
   case 19:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9exn_traceP8JSTracerP8JSObject["X"] = 1;

function __Z21js_ErrorFromExceptionP9JSContextN2JS5ValueE($_0_0_0_val$0, $_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSVAL_IS_PRIMITIVE($_0_0_0_val$0, $_0_0_0_val$1);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = _JSVAL_TO_OBJECT1203($_0_0_0_val$0, $_0_0_0_val$1);
    var $_idx2_val = HEAP32[$4 + 4 >> 2];
    var $5 = __ZNK8JSObject7isErrorEv($_idx2_val);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $7 = __ZL13GetExnPrivateP8JSObject($4);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = HEAP32[$7 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSVAL_IS_PRIMITIVE($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE1218($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_PRIMITIVE_IMPL1252($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_OBJECT1203($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE1218($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_OBJECT_IMPL1225($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL13GetExnPrivateP8JSObject($obj) {
  var $_idx_val = HEAP32[$obj + 24 >> 2];
  var $2 = __ZNK8JSObject10getPrivateEv($_idx_val);
  return $2;
}

function __ZL12exn_toSourceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $localroots = __stackBase__;
    var $tvr = __stackBase__ + 24;
    var $1 = __stackBase__ + 40;
    var $2 = __stackBase__ + 48;
    var $lineno = __stackBase__ + 56;
    var $3 = $localroots | 0;
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $st$7$0 = $$emscripten$temp$0 | 0;
    var $4$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $$emscripten$temp$0 + 4 | 0;
    var $4$1 = HEAP32[$st$7$1 >> 2];
    var $5 = $localroots | 0;
    HEAP32[$5 >> 2] = $4$0;
    HEAP32[$5 + 4 >> 2] = $4$1;
    var $6 = $localroots + 8 | 0;
    HEAP32[$6 >> 2] = $4$0;
    HEAP32[$6 + 4 >> 2] = $4$1;
    var $7 = $localroots + 16 | 0;
    HEAP32[$7 >> 2] = $4$0;
    HEAP32[$7 + 4 >> 2] = $4$1;
    var $8 = $vp + 8 | 0;
    var $9 = $cx;
    var $10 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($9, $8);
    if (($10 | 0) == 0) {
      var $_1 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $17 = HEAP32[HEAP32[$cx + 52 >> 2] + 210272 >> 2];
    var $18 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($10, $9, $17, $vp);
    if (($18 | 0) == 0) {
      var $_1 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $21 = $cx;
    var $vp_idx = $vp | 0;
    var $st$2$0 = $vp_idx | 0;
    var $vp_idx_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $vp_idx + 4 | 0;
    var $vp_idx_val$1 = HEAP32[$st$2$1 >> 2];
    var $22 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($21, $vp_idx_val$0, $vp_idx_val$1);
    if (($22 | 0) == 0) {
      var $_1 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value9setStringEP8JSString($vp, $22);
    __ZN2js15AutoArrayRooterC1EP9JSContextjPN2JS5ValueE($tvr, $9, 3, $3);
    var $25 = _JS_GetProperty($9, $10, STRING_TABLE._js_message_str | 0, $3);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $28 = __Z16js_ValueToSourceP9JSContextRKN2JS5ValueE($21, $3);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _STRING_TO_JSVAL1211($1, $28);
    var $31 = $1 | 0;
    var $st$2$0 = $31 | 0;
    var $32$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $31 + 4 | 0;
    var $32$1 = HEAP32[$st$2$1 >> 2];
    HEAP32[$5 >> 2] = $32$0;
    HEAP32[$5 + 4 >> 2] = $32$1;
    var $33 = $localroots + 8 | 0;
    var $34 = _JS_GetProperty($9, $10, STRING_TABLE._js_fileName_str | 0, $33);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $37 = __Z16js_ValueToSourceP9JSContextRKN2JS5ValueE($21, $33);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    _STRING_TO_JSVAL1211($2, $37);
    var $40 = $2 | 0;
    var $st$2$0 = $40 | 0;
    var $41$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $40 + 4 | 0;
    var $41$1 = HEAP32[$st$2$1 >> 2];
    var $42 = $33 | 0;
    var $st$7$0 = $42 | 0;
    HEAP32[$st$7$0 >> 2] = $41$0;
    var $st$7$1 = $42 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $41$1;
    var $43 = $localroots + 16 | 0;
    var $44 = _JS_GetProperty($9, $10, STRING_TABLE._js_lineNumber_str | 0, $43);
    if (($44 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $47 = __ZN2js17ValueToECMAUint32EP9JSContextRKN2JS5ValueEPj($9, $43, $lineno);
    if ($47) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 33;
      break;
    }
   case 10:
    if ((HEAP32[$lineno >> 2] | 0) == 0) {
      var $lineno_length_0 = 0;
      var $lineno_as_str_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_idx4 = $43 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    var $52 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($21, $_idx4_val$0, $_idx4_val$1);
    if (($52 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $_idx3_val = HEAP32[$52 >> 2];
    var $55 = __ZNK8JSString6lengthEv($_idx3_val);
    var $lineno_length_0 = $55;
    var $lineno_as_str_0 = $52;
    __label__ = 13;
    break;
   case 13:
    var $lineno_as_str_0;
    var $lineno_length_0;
    var $_idx2_val = HEAP32[$22 >> 2];
    var $57 = __ZNK8JSString6lengthEv($_idx2_val);
    var $_idx1_val = HEAP32[$28 >> 2];
    var $58 = __ZNK8JSString6lengthEv($_idx1_val);
    var $60 = $58 + ($57 + 8) | 0;
    var $_idx_val = HEAP32[$37 >> 2];
    var $61 = __ZNK8JSString6lengthEv($_idx_val);
    var $62 = ($61 | 0) != 0;
    if ($62) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    var $65 = $61 + ($60 + 2) | 0;
    if (($lineno_as_str_0 | 0) == 0) {
      var $length_0 = $65;
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $length_0 = $65 + ($lineno_length_0 + 2) | 0;
    __label__ = 18;
    break;
   case 16:
    if (($lineno_as_str_0 | 0) == 0) {
      var $length_0 = $60;
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $length_0 = $60 + ($lineno_length_0 + 6) | 0;
    __label__ = 18;
    break;
   case 18:
    var $length_0;
    var $78 = __ZN9JSContext7malloc_Ej($9, ($length_0 << 1) + 2 | 0);
    var $79 = $78;
    if (($78 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $83 = $78 + 2 | 0;
    HEAP16[$79 >> 1] = 40;
    var $85 = $78 + 4 | 0;
    HEAP16[$83 >> 1] = 110;
    var $87 = $78 + 6 | 0;
    HEAP16[$85 >> 1] = 101;
    var $89 = $78 + 8 | 0;
    HEAP16[$87 >> 1] = 119;
    var $90 = $78 + 10 | 0;
    HEAP16[$89 >> 1] = 32;
    var $91 = __ZN8JSString8getCharsEP9JSContext($22, $9);
    if (($91 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $94 = $90;
    var $95 = $91;
    var $96 = $57 << 1;
    _memcpy($90, $95, $96, 1);
    var $_sum = $57 + 1 | 0;
    var $98 = $94 + ($_sum << 1) | 0;
    HEAP16[$94 + ($57 << 1) >> 1] = 40;
    var $99 = __ZN8JSString8getCharsEP9JSContext($28, $9);
    if (($99 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    if (($58 | 0) == 0) {
      var $cp_0 = $98;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $104 = $98;
    var $105 = $99;
    var $106 = $58 << 1;
    _memcpy($104, $105, $106, 1);
    var $cp_0 = $94 + ($_sum + $58 << 1) | 0;
    __label__ = 23;
    break;
   case 23:
    var $cp_0;
    if ($62) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    HEAP16[$cp_0 >> 1] = 44;
    HEAP16[$cp_0 + 2 >> 1] = 32;
    var $111 = __ZN8JSString8getCharsEP9JSContext($37, $9);
    if (($111 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 25:
    if (($lineno_as_str_0 | 0) == 0) {
      var $cp_2 = $cp_0;
      __label__ = 30;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    HEAP16[$cp_0 >> 1] = 44;
    HEAP16[$cp_0 + 2 >> 1] = 32;
    HEAP16[$cp_0 + 4 >> 1] = 34;
    HEAP16[$cp_0 + 6 >> 1] = 34;
    var $cp_15 = $cp_0 + 8 | 0;
    __label__ = 28;
    break;
   case 27:
    var $122 = $111;
    var $123 = $61 << 1;
    _memcpy($cp_0 + 4 | 0, $122, $123, 1);
    var $124 = $cp_0 + ($61 + 2 << 1) | 0;
    if (($lineno_as_str_0 | 0) == 0) {
      var $cp_2 = $124;
      __label__ = 30;
      break;
    } else {
      var $cp_15 = $124;
      __label__ = 28;
      break;
    }
   case 28:
    var $cp_15;
    HEAP16[$cp_15 >> 1] = 44;
    HEAP16[$cp_15 + 2 >> 1] = 32;
    var $128 = __ZN8JSString8getCharsEP9JSContext($lineno_as_str_0, $9);
    if (($128 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $133 = $128;
    _memcpy($cp_15 + 4 | 0, $133, $lineno_length_0 << 1, 1);
    var $cp_2 = $cp_15 + ($lineno_length_0 + 2 << 1) | 0;
    __label__ = 30;
    break;
   case 30:
    var $cp_2;
    HEAP16[$cp_2 >> 1] = 41;
    HEAP16[$cp_2 + 2 >> 1] = 41;
    HEAP16[$cp_2 + 4 >> 1] = 0;
    var $138 = __Z12js_NewStringP9JSContextPtj($21, $79, $length_0);
    if (($138 | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    __ZN9JSContext5free_EPv($78);
    var $_0 = 0;
    __label__ = 33;
    break;
   case 32:
    var $142 = $138 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $142);
    var $_0 = 1;
    __label__ = 33;
    break;
   case 33:
    var $_0;
    __ZN2js15AutoArrayRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 34;
    break;
   case 34:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12exn_toSourceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL12exn_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx + 52 | 0;
    var $10 = HEAP32[HEAP32[$6 >> 2] + 210272 >> 2];
    var $11 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($3, $2, $10, $v);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = $v | 0;
    var $15$0 = HEAP32[$14 >> 2];
    var $15$1 = HEAP32[$14 + 4 >> 2];
    var $16 = _JSVAL_IS_STRING($15$0, $15$1);
    if (($16 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $st$0$0 = $14 | 0;
    var $19$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $14 + 4 | 0;
    var $19$1 = HEAP32[$st$0$1 >> 2];
    var $20 = _JSVAL_TO_STRING($19$0, $19$1);
    var $27 = $20;
    __label__ = 6;
    break;
   case 5:
    var $27 = HEAP32[HEAP32[$6 >> 2] + 144136 >> 2] | 0;
    __label__ = 6;
    break;
   case 6:
    var $27;
    __ZN2JS5Value9setStringEP8JSString($vp, $27);
    var $28 = _JS_GetProperty($2, $3, STRING_TABLE._js_message_str | 0, $v);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $st$0$0 = $14 | 0;
    var $31$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $14 + 4 | 0;
    var $31$1 = HEAP32[$st$0$1 >> 2];
    var $32 = _JSVAL_IS_STRING($31$0, $31$1);
    if (($32 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $st$0$0 = $14 | 0;
    var $35$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $14 + 4 | 0;
    var $35$1 = HEAP32[$st$0$1 >> 2];
    var $36 = _JSVAL_TO_STRING($35$0, $35$1);
    var $43 = $36;
    __label__ = 10;
    break;
   case 9:
    var $43 = HEAP32[HEAP32[$6 >> 2] + 144136 >> 2] | 0;
    __label__ = 10;
    break;
   case 10:
    var $43;
    var $_idx1_val = HEAP32[$43 >> 2];
    var $44 = __ZNK8JSString6lengthEv($_idx1_val);
    if (($44 | 0) == 0) {
      var $result_0 = $27;
      __label__ = 18;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_idx_val = HEAP32[$27 >> 2];
    var $47 = __ZNK8JSString6lengthEv($_idx_val);
    var $48 = $47 + 2 | 0;
    var $49 = ($47 | 0) != 0;
    var $_ = $49 ? $48 : 0;
    var $50 = $_ + $44 | 0;
    var $52 = ($50 << 1) + 2 | 0;
    var $53 = __ZN9JSContext7malloc_Ej($2, $52);
    var $54 = $53;
    if (($53 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ($49) {
      __label__ = 13;
      break;
    } else {
      var $cp_0 = $54;
      __label__ = 15;
      break;
    }
   case 13:
    var $58 = __ZN8JSString8getCharsEP9JSContext($27, $2);
    if (($58 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $61 = $58;
    var $62 = $47 << 1;
    _memcpy($53, $61, $62, 1);
    var $64 = $54 + ($47 + 1 << 1) | 0;
    HEAP16[$54 + ($47 << 1) >> 1] = 58;
    var $65 = $54 + ($48 << 1) | 0;
    HEAP16[$64 >> 1] = 32;
    var $cp_0 = $65;
    __label__ = 15;
    break;
   case 15:
    var $cp_0;
    var $67 = __ZN8JSString8getCharsEP9JSContext($43, $2);
    if (($67 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $71 = $67;
    var $72 = $44 << 1;
    _memcpy($cp_0, $71, $72, 1);
    HEAP16[$cp_0 + ($44 << 1) >> 1] = 0;
    var $74 = $cx;
    var $75 = __Z12js_NewStringP9JSContextPtj($74, $54, $50);
    var $76 = $75 | 0;
    if (($75 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $result_0 = $76;
      __label__ = 18;
      break;
    }
   case 17:
    __ZN9JSContext5free_EPv($53);
    var $_0 = 0;
    __label__ = 19;
    break;
   case 18:
    var $result_0;
    __ZN2JS5Value9setStringEP8JSString($vp, $result_0);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12exn_toStringP9JSContextjPN2JS5ValueE["X"] = 1;

function __Z23js_InitExceptionClassesP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $objectProto = __stackBase__;
    var $1 = $obj;
    var $2 = __ZN8JSObject8asGlobalEv($1);
    var $3 = $2;
    var $4 = $cx;
    var $5 = $2;
    var $6 = $objectProto;
    var $7 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($4, $5, 1, $6, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAP32[$objectProto >> 2];
    var $11 = __ZL14InitErrorClassP9JSContextPN2js12GlobalObjectEiR8JSObject($cx, $3, 0, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = $cx;
    var $15 = $11;
    var $16 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($14, $15, 0, __ZL17exception_methods);
    if ($16) {
      var $i_0 = 1;
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 4:
    var $i_0;
    if (($i_0 | 0) < 8) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $11;
      __label__ = 7;
      break;
    }
   case 5:
    var $19 = __ZL14InitErrorClassP9JSContextPN2js12GlobalObjectEiR8JSObject($cx, $3, $i_0, $11);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 4;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14InitErrorClassP9JSContextPN2js12GlobalObjectEiR8JSObject($cx, $global, $type, $proto) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $empty = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 24;
    var $4 = __ZL20GetExceptionProtoKeyi($type);
    var $5 = $cx + 52 | 0;
    var $8 = HEAP32[HEAP32[$5 >> 2] + 210020 + ($4 << 2) >> 2];
    var $9 = $global;
    var $10 = $cx;
    var $11 = $proto;
    var $12 = __ZN2js12GlobalObject30createBlankPrototypeInheritingEP9JSContextPNS_5ClassER8JSObject($9, $10, $11);
    var $13 = $12;
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $19 = HEAP32[HEAP32[$5 >> 2] + 144136 >> 2] | 0;
    __ZN2JSL11StringValueEP8JSString1239($empty, $19);
    var $20 = HEAP32[$5 >> 2];
    var $23 = HEAP32[$20 + 210272 >> 2] | 0;
    var $24 = __ZL12ATOM_TO_JSIDP6JSAtom1223($23);
    var $26 = HEAP32[$20 + 210264 >> 2];
    var $29 = HEAP32[$20 + 210216 >> 2] | 0;
    var $30 = __ZL12ATOM_TO_JSIDP6JSAtom1223($29);
    var $33 = HEAP32[$20 + 210260 >> 2] | 0;
    var $34 = __ZL12ATOM_TO_JSIDP6JSAtom1223($33);
    var $35 = $8 | 0;
    __ZN2JSL11StringValueEP8JSString1239($1, $35);
    var $36 = $cx;
    var $37 = $12;
    var $38 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($36, $37, $24, $1, 10, 12, 0, 0, 0, 0);
    if (($38 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $41 = $26 | 0;
    var $42 = __ZL12ATOM_TO_JSIDP6JSAtom1223($41);
    var $43 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($36, $37, $42, $empty, 10, 12, 0, 0, 0, 0);
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $46 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($36, $37, $30, $empty, 10, 12, 1, 0, 0, 0);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JSL10Int32ValueEi1240($2, 0);
    var $49 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($36, $37, $34, $2, 10, 12, 1, 0, 0, 0);
    if (($49 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $52 = $8;
    var $53 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($9, $10, 102, __ZN2js10ErrorClassE, $52, 1);
    if (($53 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JSL10Int32ValueEi1240($3, $type);
    var $56 = $53;
    var $_idx = $3 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($56, 0, $_idx_val$0, $_idx_val$1);
    var $57 = $53 | 0;
    var $58 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($10, $57, $12);
    if ($58) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $60 = $cx;
    var $61 = $global;
    var $62 = $12;
    var $63 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($60, $61, $4, $56, $62);
    var $_ = $63 ? $13 : 0;
    var $_0 = $_;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14InitErrorClassP9JSContextPN2js12GlobalObjectEiR8JSObject["X"] = 1;

function __Z27js_GetLocalizedErrorMessageP9JSContextPvPKcj($cx_0_7_val, $errorNumber) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($cx_0_7_val | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$cx_0_7_val + 16 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = FUNCTION_TABLE[$4](0, 0, $errorNumber);
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $errorString_1 = $7;
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __Z18js_GetErrorMessagePvPKcj(undef, undef, $errorNumber);
    var $errorString_1 = $9;
    __label__ = 5;
    break;
   case 5:
    var $errorString_1;
    return $errorString_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20GetExceptionProtoKeyi($exn) {
  return $exn + 14 | 0;
}

function __Z19js_ErrorToExceptionP9JSContextPKcP13JSErrorReportPFPK19JSErrorFormatStringPvS2_jES8_($cx, $message, $reportp, $callback) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 92;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tv = __stackBase__;
    var $errProto = __stackBase__ + 32;
    var $tvr = __stackBase__ + 36;
    var $1 = __stackBase__ + 52;
    var $2 = __stackBase__ + 60;
    var $3 = __stackBase__ + 68;
    var $4 = __stackBase__ + 76;
    var $5 = __stackBase__ + 84;
    var $6 = $reportp + 24 | 0;
    if ((HEAP32[$6 >> 2] & 1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 2:
    var $12 = HEAP32[$reportp + 28 >> 2];
    if (($callback | 0) == 0 | ($callback | 0) == 4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $cx_idx_val = HEAP32[$cx + 36 >> 2];
    var $16 = __Z27js_GetLocalizedErrorMessageP9JSContextPvPKcj($cx_idx_val, $12);
    var $errorString_0 = $16;
    __label__ = 5;
    break;
   case 4:
    var $18 = FUNCTION_TABLE[$callback](0, 0, $12);
    var $errorString_0 = $18;
    __label__ = 5;
    break;
   case 5:
    var $errorString_0;
    if (($errorString_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = HEAP16[$errorString_0 + 6 >> 1];
    var $24 = $23 << 16 >> 16;
    if ($23 << 16 >> 16 == -1) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $27 = $cx + 44 | 0;
    if (HEAP8[$27] << 24 >> 24 == 0) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 8:
    HEAP8[$27] = 1;
    __ZN2jsL12PodArrayZeroIN2JS5ValueELj4EEEvRAT0__T_($tv);
    var $31 = $tv | 0;
    var $32 = $cx;
    __ZN2js15AutoArrayRooterC1EP9JSContextjPN2JS5ValueE($tvr, $32, 4, $31);
    var $33 = __ZL20GetExceptionProtoKeyi($24);
    var $34 = $cx;
    var $35 = $errProto;
    var $36 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($34, 0, $33, $35, 0);
    if (($36 | 0) == 0) {
      var $ok_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $39 = HEAP32[$errProto >> 2];
    _OBJECT_TO_JSVAL1210($1, $39);
    var $40 = $1 | 0;
    var $41$0 = HEAP32[$40 >> 2];
    var $41$1 = HEAP32[$40 + 4 >> 2];
    var $42 = $tv | 0;
    HEAP32[$42 >> 2] = $41$0;
    HEAP32[$42 + 4 >> 2] = $41$1;
    var $_idx_val = HEAP32[$39 + 20 >> 2];
    var $44 = __ZNK8JSObject9getParentEv($_idx_val);
    var $45 = $44;
    var $46 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_($cx, $39, $45);
    if (($46 | 0) == 0) {
      var $ok_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    _OBJECT_TO_JSVAL1210($2, $46);
    var $49 = $2 | 0;
    var $st$2$0 = $49 | 0;
    var $50$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $49 + 4 | 0;
    var $50$1 = HEAP32[$st$2$1 >> 2];
    var $51 = $tv + 8 | 0;
    var $st$7$0 = $51 | 0;
    HEAP32[$st$7$0 >> 2] = $50$0;
    var $st$7$1 = $51 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $50$1;
    var $52 = _JS_NewStringCopyZ($32, $message);
    if (($52 | 0) == 0) {
      var $ok_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    _STRING_TO_JSVAL1211($3, $52);
    var $55 = $3 | 0;
    var $st$2$0 = $55 | 0;
    var $56$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $55 + 4 | 0;
    var $56$1 = HEAP32[$st$2$1 >> 2];
    var $57 = $tv + 16 | 0;
    var $st$7$0 = $57 | 0;
    HEAP32[$st$7$0 >> 2] = $56$0;
    var $st$7$1 = $57 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $56$1;
    var $59 = HEAP32[$reportp >> 2];
    var $60 = _JS_NewStringCopyZ($32, $59);
    if (($60 | 0) == 0) {
      var $ok_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    _STRING_TO_JSVAL1211($4, $60);
    var $63 = $4 | 0;
    var $st$2$0 = $63 | 0;
    var $64$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $63 + 4 | 0;
    var $64$1 = HEAP32[$st$2$1 >> 2];
    var $65 = $tv + 24 | 0;
    var $st$7$0 = $65 | 0;
    HEAP32[$st$7$0 >> 2] = $64$0;
    var $st$7$1 = $65 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $64$1;
    var $67 = HEAP32[$reportp + 4 >> 2];
    var $68 = __ZL14InitExnPrivateP9JSContextP8JSObjectP8JSStringS4_jP13JSErrorReporti($cx, $46, $52, $60, $67, $reportp, $24);
    var $69 = $68 & 1;
    if ($68) {
      __label__ = 13;
      break;
    } else {
      var $ok_0 = $69;
      __label__ = 14;
      break;
    }
   case 13:
    _OBJECT_TO_JSVAL1210($5, $46);
    var $_idx1 = $5 | 0;
    var $st$2$0 = $_idx1 | 0;
    var $_idx1_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx1 + 4 | 0;
    var $_idx1_val$1 = HEAP32[$st$2$1 >> 2];
    _JS_SetPendingException($32, $_idx1_val$0, $_idx1_val$1);
    var $72 = HEAP32[$6 >> 2] | 2;
    HEAP32[$6 >> 2] = $72;
    var $ok_0 = $69;
    __label__ = 14;
    break;
   case 14:
    var $ok_0;
    HEAP8[$27] = 0;
    __ZN2js15AutoArrayRooterD1Ev($tvr);
    var $_0 = $ok_0;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z19js_ErrorToExceptionP9JSContextPKcP13JSErrorReportPFPK19JSErrorFormatStringPvS2_jES8_["X"] = 1;

function __ZN2jsL12PodArrayZeroIN2JS5ValueELj4EEEvRAT0__T_($t) {
  var $1 = $t;
  _memset($1, 0, 32, 1);
  return;
}

function _OBJECT_TO_JSVAL1210($agg_result, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL_IMPL1238($1, $obj);
    var $_0 = $1 | 0;
    var $_0_val$0 = HEAP32[$_0 >> 2];
    var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
    __ZL13IMPL_TO_JSVAL12jsval_layout1228($agg_result, $_0_val$0, $_0_val$1);
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $6 = $agg_result | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_($cx, $proto, $parent) {
  var $3 = HEAPU32[__ZN2js10ErrorClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb1230($3);
  var $5 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1231($cx, $proto, $parent, $4);
  return $5;
}

function _STRING_TO_JSVAL1211($agg_result, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _STRING_TO_JSVAL_IMPL1229($1, $str);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout1228($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZL14InitExnPrivateP9JSContextP8JSObjectP8JSStringS4_jP13JSErrorReporti($cx, $exnObject, $message, $filename, $lineno, $report, $exnType) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 120;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $frames = __stackBase__;
    var $1 = __stackBase__ + 24;
    var $values = __stackBase__ + 28;
    var $2 = __stackBase__ + 52;
    var $seg = __stackBase__ + 56;
    var $i = __stackBase__ + 68;
    var $v = __stackBase__ + 108;
    var $3 = __stackBase__ + 116;
    var $4 = $cx;
    var $5 = _JS_GetSecurityCallbacks($4);
    if (($5 | 0) == 0) {
      var $11 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = HEAP32[$5 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $11;
    var $12 = $1;
    __ZN2js15TempAllocPolicyC1EP9JSContext($12, $4);
    var $_06_val = HEAP32[$1 >> 2];
    __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEEC1ES2_($frames, $_06_val);
    __ZN2js15TempAllocPolicyC1EP9JSContext($2, $4);
    var $13 = $values;
    var $_0_val = HEAP32[$2 >> 2];
    __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEEC1ES3_($13, $_0_val);
    __ZN19SuppressErrorsGuardC1EP9JSContext($seg, $cx);
    __ZN2js13FrameRegsIterC1EP9JSContextNS_9StackIter11SavedOptionE($i, $4);
    var $14 = $cx + 56 | 0;
    var $15 = ($11 | 0) == 0;
    var $16 = $cx + 52 | 0;
    var $17 = $cx;
    var $frames_idx = $frames + 4 | 0;
    var $frames_idx7 = $frames + 8 | 0;
    var $_012 = $3 | 0;
    __label__ = 4;
    break;
   case 4:
    var $19 = __ZNK2js13FrameRegsIter4doneEv($i);
    if ($19) {
      __label__ = 20;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $21 = __ZNK2js13FrameRegsIter2fpEv($i);
    var $22 = $21;
    var $23 = __ZNK2js10StackFrame11compartmentEv($22);
    if (($23 | 0) == (HEAP32[$14 >> 2] | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 6:
    if ($15) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx1_val = HEAP32[$21 >> 2];
    var $28 = __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($_idx1_val);
    if ($28) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    __ZN2JSL9NullValueEv1222($v);
    var $33 = HEAP32[HEAP32[$16 >> 2] + 210196 >> 2] | 0;
    var $34 = __ZL12ATOM_TO_JSIDP6JSAtom1223($33);
    var $35 = __ZNK2js10StackFrame6calleeEv($21);
    var $36 = $35;
    var $37 = FUNCTION_TABLE[$11]($cx, $36, $34, 4, $v);
    if (($37 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $40 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE6growByEj($frames);
    if ($40) {
      __label__ = 10;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 10:
    var $frames_idx_val = HEAP32[$frames_idx >> 2];
    var $frames_idx7_val = HEAP32[$frames_idx7 >> 2];
    var $42 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE4backEv($frames_idx_val, $frames_idx7_val);
    var $_idx = $21 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $43 = __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($_idx_val);
    if ($43) {
      __label__ = 11;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 11:
    var $45 = __ZNK2js10StackFrame3funEv($21);
    var $46 = $45 + 72 | 0;
    if ((HEAP32[$46 >> 2] | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $_in = $46;
    __label__ = 14;
    break;
   case 13:
    var $_in = HEAP32[$16 >> 2] + 144136 | 0;
    __label__ = 14;
    break;
   case 14:
    var $_in;
    var $56 = HEAP32[$_in >> 2] | 0;
    var $57 = $42 | 0;
    HEAP32[$57 >> 2] = $56;
    var $58 = __ZNK2js10StackFrame13numActualArgsEv($21);
    var $59 = $42 + 4 | 0;
    HEAP32[$59 >> 2] = $58;
    __ZN9AppendArgC1ERN2js6VectorIN2JS5ValueELj0ENS0_15TempAllocPolicyEEE($3, $values);
    var $_012_val = HEAP32[$_012 >> 2];
    var $60 = __ZN2js10StackFrame25forEachCanonicalActualArgI9AppendArgEEbT_jj($22, $_012_val);
    if ($60) {
      __label__ = 16;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    var $62 = $42 | 0;
    HEAP32[$62 >> 2] = 0;
    var $63 = $42 + 4 | 0;
    HEAP32[$63 >> 2] = 0;
    __label__ = 16;
    break;
   case 16:
    var $_idx2_val = HEAP32[$_idx >> 2];
    var $65 = __ZNK2js10StackFrame13isScriptFrameEv($_idx2_val);
    if ($65) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $67 = __ZNK2js10StackFrame6scriptEv($21);
    var $69 = HEAP32[$67 + 52 >> 2];
    var $70 = $42 + 8 | 0;
    HEAP32[$70 >> 2] = $69;
    var $71 = __ZNK2js13FrameRegsIter2pcEv($i);
    var $72 = $21;
    var $73 = __Z22js_FramePCToLineNumberP9JSContextPN2js10StackFrameEPh($17, $72, $71);
    var $74 = $42 + 12 | 0;
    HEAP32[$74 >> 2] = $73;
    __label__ = 19;
    break;
   case 18:
    var $76 = $42 + 12 | 0;
    HEAP32[$76 >> 2] = 0;
    var $77 = $42 + 8 | 0;
    HEAP32[$77 >> 2] = 0;
    __label__ = 19;
    break;
   case 19:
    __ZN2js13FrameRegsIterppEv($i);
    __label__ = 4;
    break;
   case 20:
    __ZN19SuppressErrorsGuardD1Ev($seg);
    var $frames_idx10_val = HEAP32[$frames_idx7 >> 2];
    var $80 = __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE6lengthEv($frames_idx10_val);
    var $81 = $80 << 4;
    var $82 = $values + 8 | 0;
    var $_idx4_val = HEAP32[$82 >> 2];
    var $83 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE6lengthEv($_idx4_val);
    var $86 = $81 + 24 + ($83 << 3) | 0;
    var $87 = __ZN9JSContext7malloc_Ej($4, $86);
    if (($87 | 0) == 0) {
      var $_1 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    if (($report | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $92 = __ZL15CopyErrorReportP9JSContextP13JSErrorReport($cx, $report);
    var $93 = $87;
    HEAP32[$93 >> 2] = $92;
    if (($92 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 23:
    __ZN9JSContext5free_EPv($87);
    var $_1 = 0;
    __label__ = 28;
    break;
   case 24:
    var $97 = $87;
    HEAP32[$97 >> 2] = 0;
    __label__ = 25;
    break;
   case 25:
    var $100 = $87 + 4 | 0;
    HEAP32[$100 >> 2] = $message;
    var $102 = $87 + 8 | 0;
    HEAP32[$102 >> 2] = $filename;
    var $104 = $87 + 12 | 0;
    HEAP32[$104 >> 2] = $lineno;
    var $frames_idx9_val = HEAP32[$frames_idx7 >> 2];
    var $105 = __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE6lengthEv($frames_idx9_val);
    var $107 = $87 + 16 | 0;
    HEAP32[$107 >> 2] = $105;
    var $109 = $87 + 20 | 0;
    HEAP32[$109 >> 2] = $exnType;
    var $111 = $87 + 24 | 0;
    var $frames_idx8_val = HEAP32[$frames_idx7 >> 2];
    var $112 = __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE6lengthEv($frames_idx8_val);
    var $114 = $111 + ($112 << 4) | 0;
    var $frames_idx11_val = HEAP32[$frames_idx >> 2];
    var $115 = __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE5beginEv($frames_idx11_val);
    __ZN2jsL7PodCopyI16JSStackTraceElemEEvPT_PKS2_j($111, $115, $112);
    var $_idx5_val = HEAP32[$values + 4 >> 2];
    var $117 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE5beginEv($_idx5_val);
    var $_idx3_val = HEAP32[$82 >> 2];
    var $118 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE6lengthEv($_idx3_val);
    __ZN2jsL7PodCopyIN2JS5ValueEEEvPT_PKS3_j1224($114, $117, $118);
    var $119 = $exnObject;
    __ZN8JSObject10setPrivateEPv($119, $87);
    var $_1 = 1;
    __label__ = 28;
    break;
   case 26:
    __ZN19SuppressErrorsGuardD1Ev($seg);
    var $_1 = 0;
    __label__ = 28;
    break;
   case 27:
    __ZN19SuppressErrorsGuardD1Ev($seg);
    var $_1 = 0;
    __label__ = 28;
    break;
   case 28:
    var $_1;
    __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEED1Ev($13);
    __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEED1Ev($frames);
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14InitExnPrivateP9JSContextP8JSObjectP8JSStringS4_jP13JSErrorReporti["X"] = 1;

function __Z26js_ReportUncaughtExceptionP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 124;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $exn = __stackBase__;
    var $roots = __stackBase__ + 8;
    var $report = __stackBase__ + 48;
    var $tvr = __stackBase__ + 88;
    var $bytesStorage = __stackBase__ + 104;
    var $1 = __stackBase__ + 108;
    var $filename = __stackBase__ + 116;
    var $lineno = __stackBase__ + 120;
    var $2 = $cx;
    var $_idx1_val = HEAP32[$cx + 20 >> 2];
    var $4 = _JS_IsExceptionPending($_idx1_val);
    if (($4 | 0) == 0) {
      var $_2 = 1;
      __label__ = 27;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = _JS_GetPendingException($2, $exn);
    if (($7 | 0) == 0) {
      var $_2 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2jsL12PodArrayZeroIN2JS5ValueELj5EEEvRAT0__T_($roots);
    var $10 = $roots | 0;
    __ZN2js15AutoArrayRooterC1EP9JSContextjPN2JS5ValueE($tvr, $2, 5, $10);
    var $11 = $exn | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = _JSVAL_IS_PRIMITIVE($12$0, $12$1);
    if (($13 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $exnObject_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = _JSVAL_TO_OBJECT1203($12$0, $12$1);
    var $17 = $roots | 0;
    var $st$2$0 = $17 | 0;
    HEAP32[$st$2$0 >> 2] = $12$0;
    var $st$2$1 = $17 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $12$1;
    var $exnObject_0 = $16;
    __label__ = 5;
    break;
   case 5:
    var $exnObject_0;
    _JS_ClearPendingException($2);
    var $19 = __Z21js_ErrorFromExceptionP9JSContextN2JS5ValueE($12$0, $12$1);
    var $20 = $cx;
    var $21 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($20, $12$0, $12$1);
    __ZN16JSAutoByteStringC1Ev($bytesStorage);
    if (($21 | 0) == 0) {
      var $bytes_0 = STRING_TABLE.__str1193 | 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _STRING_TO_JSVAL1211($1, $21);
    var $24 = $1 | 0;
    var $st$2$0 = $24 | 0;
    var $25$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $24 + 4 | 0;
    var $25$1 = HEAP32[$st$2$1 >> 2];
    var $26 = $roots + 8 | 0;
    HEAP32[$26 >> 2] = $25$0;
    HEAP32[$26 + 4 >> 2] = $25$1;
    var $27 = __ZN16JSAutoByteString6encodeEP9JSContextP8JSString($bytesStorage, $2, $21);
    if (($27 | 0) == 0) {
      var $_1 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $bytesStorage_idx7_val = HEAP32[$bytesStorage >> 2];
    var $30 = __ZNK16JSAutoByteString3ptrEv($bytesStorage_idx7_val);
    var $bytes_0 = $30;
    __label__ = 8;
    break;
   case 8:
    var $bytes_0;
    __ZN16JSAutoByteStringC1Ev($filename);
    if (($19 | 0) != 0 | ($exnObject_0 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $exnObject_0_idx_val = HEAP32[$exnObject_0 + 4 >> 2];
    var $35 = __ZNK8JSObject7isErrorEv($exnObject_0_idx_val);
    if ($35) {
      __label__ = 10;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 10:
    var $37 = $roots + 16 | 0;
    var $38 = $exnObject_0;
    var $39 = _JS_GetProperty($2, $38, STRING_TABLE._js_message_str | 0, $37);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $42 = $37 | 0;
    var $st$1$0 = $42 | 0;
    var $43$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $42 + 4 | 0;
    var $43$1 = HEAP32[$st$1$1 >> 2];
    var $44 = _JSVAL_IS_STRING($43$0, $43$1);
    if (($44 | 0) == 0) {
      var $bytes_1 = $bytes_0;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN16JSAutoByteString5clearEv($bytesStorage);
    var $47 = __ZN16JSAutoByteString6encodeEP9JSContextP8JSString($bytesStorage, $2, $21);
    if (($47 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $bytesStorage_idx6_val = HEAP32[$bytesStorage >> 2];
    var $50 = __ZNK16JSAutoByteString3ptrEv($bytesStorage_idx6_val);
    var $bytes_1 = $50;
    __label__ = 14;
    break;
   case 14:
    var $bytes_1;
    var $52 = $roots + 24 | 0;
    var $53 = _JS_GetProperty($2, $38, STRING_TABLE._js_fileName_str | 0, $52);
    if (($53 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $_idx12 = $52 | 0;
    var $st$1$0 = $_idx12 | 0;
    var $_idx12_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx12 + 4 | 0;
    var $_idx12_val$1 = HEAP32[$st$1$1 >> 2];
    var $56 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($20, $_idx12_val$0, $_idx12_val$1);
    if (($56 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $59 = __ZN16JSAutoByteString6encodeEP9JSContextP8JSString($filename, $2, $56);
    if (($59 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $62 = $roots + 32 | 0;
    var $63 = _JS_GetProperty($2, $38, STRING_TABLE._js_lineNumber_str | 0, $62);
    if (($63 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $66 = __ZN2js17ValueToECMAUint32EP9JSContextRKN2JS5ValueEPj($2, $62, $lineno);
    if ($66) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 25;
      break;
    }
   case 19:
    __ZN2jsL7PodZeroI13JSErrorReportEEvPT_1214($report);
    var $filename_idx5_val = HEAP32[$filename >> 2];
    var $68 = __ZNK16JSAutoByteString3ptrEv($filename_idx5_val);
    HEAP32[$report >> 2] = $68;
    var $70 = HEAP32[$lineno >> 2];
    HEAP32[$report + 4 >> 2] = $70;
    var $72$0 = HEAP32[$42 >> 2];
    var $72$1 = HEAP32[$42 + 4 >> 2];
    var $73 = _JSVAL_IS_STRING($72$0, $72$1);
    if (($73 | 0) == 0) {
      var $bytes_21 = $bytes_1;
      var $reportp_02 = $report;
      __label__ = 24;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $76$0 = HEAP32[$42 >> 2];
    var $76$1 = HEAP32[$42 + 4 >> 2];
    var $77 = _JSVAL_TO_STRING($76$0, $76$1);
    var $78 = __ZN8JSString11ensureFixedEP9JSContext($77, $2);
    if (($78 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $_idx_val = HEAP32[$78 + 4 >> 2];
    var $81 = __ZNK14JSLinearString5charsEv($_idx_val);
    HEAP32[$report + 32 >> 2] = $81;
    var $bytes_21 = $bytes_1;
    var $reportp_02 = $report;
    __label__ = 24;
    break;
   case 22:
    if (($19 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      var $bytes_21 = $bytes_0;
      var $reportp_02 = $19;
      __label__ = 24;
      break;
    }
   case 23:
    _JS_ReportErrorNumber($2, 4, 147, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $bytes_0, tempInt));
    var $_0 = 1;
    __label__ = 25;
    break;
   case 24:
    var $reportp_02;
    var $bytes_21;
    var $86 = $reportp_02 + 24 | 0;
    var $88 = HEAP32[$86 >> 2] | 2;
    HEAP32[$86 >> 2] = $88;
    _JS_SetPendingException($2, $12$0, $12$1);
    __Z19js_ReportErrorAgainP9JSContextPKcP13JSErrorReport($2, $bytes_21, $reportp_02);
    _JS_ClearPendingException($2);
    var $_0 = 1;
    __label__ = 25;
    break;
   case 25:
    var $_0;
    var $filename_idx_val = HEAP32[$filename >> 2];
    __ZN16JSAutoByteStringD1Ev($filename_idx_val);
    var $_1 = $_0;
    __label__ = 26;
    break;
   case 26:
    var $_1;
    var $bytesStorage_idx_val = HEAP32[$bytesStorage >> 2];
    __ZN16JSAutoByteStringD1Ev($bytesStorage_idx_val);
    __ZN2js15AutoArrayRooterD1Ev($tvr);
    var $_2 = $_1;
    __label__ = 27;
    break;
   case 27:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z26js_ReportUncaughtExceptionP9JSContext["X"] = 1;

function __ZN2jsL12PodArrayZeroIN2JS5ValueELj5EEEvRAT0__T_($t) {
  var $1 = $t;
  _memset($1, 0, 40, 1);
  return;
}

function _JSVAL_IS_STRING($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE1218($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_STRING_IMPL1221($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN16JSAutoByteString5clearEv($this) {
  var $1 = $this | 0;
  var $2 = HEAP32[$1 >> 2];
  __ZN2js10Foreground5free_EPv($2);
  HEAP32[$1 >> 2] = 0;
  return;
}

function __ZN2jsL7PodZeroI13JSErrorReportEEvPT_1214($t) {
  var $1 = $t;
  _memset($1, 0, 40, 1);
  return;
}

function _JSVAL_TO_STRING($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE1218($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_STRING_IMPL1217($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __Z18js_CopyErrorObjectP9JSContextP8JSObjectS2_($cx, $errobj, $scope) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $autoFree = __stackBase__;
    var $messageAnchor = __stackBase__ + 8;
    var $filenameAnchor = __stackBase__ + 12;
    var $proto = __stackBase__ + 16;
    var $1 = $cx;
    var $2 = __ZL13GetExnPrivateP8JSObject($errobj);
    var $4 = HEAP32[$2 + 16 >> 2];
    if (($4 | 0) == 0) {
      var $valueCount_0_lcssa = 0;
      __label__ = 4;
      break;
    } else {
      var $valueCount_01 = 0;
      var $i_02 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $i_02;
    var $valueCount_01;
    var $8 = HEAP32[$2 + 24 + ($i_02 << 4) + 4 >> 2] + $valueCount_01 | 0;
    var $9 = $i_02 + 1 | 0;
    if (($9 | 0) == ($4 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $valueCount_01 = $8;
      var $i_02 = $9;
      __label__ = 2;
      break;
    }
   case 3:
    var $valueCount_0_lcssa = $8 << 3;
    __label__ = 4;
    break;
   case 4:
    var $valueCount_0_lcssa;
    var $13 = ($4 << 4) + 24 + $valueCount_0_lcssa | 0;
    var $14 = __ZN9JSContext7malloc_Ej($1, $13);
    if (($14 | 0) == 0) {
      var $_3 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = $14;
    HEAP32[$autoFree >> 2] = $cx;
    var $19 = $autoFree + 4 | 0;
    HEAP32[$19 >> 2] = $17;
    var $21 = HEAP32[$2 >> 2];
    if (($21 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $24 = __ZL15CopyErrorReportP9JSContextP13JSErrorReport($cx, $21);
    var $25 = $14;
    HEAP32[$25 >> 2] = $24;
    if (($24 | 0) == 0) {
      var $_2 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $28 = $14;
    HEAP32[$28 >> 2] = 0;
    __label__ = 8;
    break;
   case 8:
    var $31 = HEAP32[$2 + 4 >> 2];
    var $33 = $14 + 4 | 0;
    HEAP32[$33 >> 2] = $31;
    var $34 = $cx + 56 | 0;
    var $36 = HEAP32[$34 >> 2];
    var $37 = __ZN13JSCompartment4wrapEP9JSContextPP8JSString($36, $1, $33);
    if ($37) {
      __label__ = 9;
      break;
    } else {
      var $_2 = 0;
      __label__ = 12;
      break;
    }
   case 9:
    var $39 = HEAP32[$33 >> 2];
    __ZN2JS6AnchorIP8JSStringEC1ES2_($messageAnchor, $39);
    var $41 = HEAP32[$2 + 8 >> 2];
    var $43 = $14 + 8 | 0;
    HEAP32[$43 >> 2] = $41;
    var $45 = HEAP32[$34 >> 2];
    var $46 = __ZN13JSCompartment4wrapEP9JSContextPP8JSString($45, $1, $43);
    if ($46) {
      __label__ = 10;
      break;
    } else {
      var $_2 = 0;
      __label__ = 12;
      break;
    }
   case 10:
    var $48 = HEAP32[$43 >> 2];
    __ZN2JS6AnchorIP8JSStringEC1ES2_($filenameAnchor, $48);
    var $50 = HEAP32[$2 + 12 >> 2];
    var $52 = $14 + 12 | 0;
    HEAP32[$52 >> 2] = $50;
    var $54 = $14 + 16 | 0;
    HEAP32[$54 >> 2] = 0;
    var $56 = HEAP32[$2 + 20 >> 2];
    var $58 = $14 + 20 | 0;
    HEAP32[$58 >> 2] = $56;
    var $59 = $scope;
    var $60 = __ZNK8JSObject9getGlobalEv($59);
    var $61 = __ZL20GetExceptionProtoKeyi($56);
    var $62 = $cx;
    var $63 = $60 | 0;
    var $64 = $proto;
    var $65 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($62, $63, $61, $64, 0);
    if (($65 | 0) == 0) {
      var $_2 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $68 = HEAP32[$proto >> 2];
    var $_idx_val = HEAP32[$68 + 20 >> 2];
    var $70 = __ZNK8JSObject9getParentEv($_idx_val);
    var $71 = $70;
    var $72 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_($cx, $68, $71);
    var $73 = $72;
    __ZN8JSObject10setPrivateEPv($73, $14);
    HEAP32[$19 >> 2] = 0;
    var $_2 = $72;
    __label__ = 12;
    break;
   case 12:
    var $_2;
    __ZZ18js_CopyErrorObjectP9JSContextP8JSObjectS2_EN8AutoFreeD2Ev($autoFree);
    var $_3 = $_2;
    __label__ = 13;
    break;
   case 13:
    var $_3;
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18js_CopyErrorObjectP9JSContextP8JSObjectS2_["X"] = 1;

function __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE6lengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js7MoveRefI16JSStackTraceElemEcvRS1_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZL14JSID_FROM_BITSj1226($bits) {
  return $bits;
}

function _JSVAL_TO_STRING_IMPL1217($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_IS_STRING_IMPL1221($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -123) & 1;
}

function _JSVAL_TO_OBJECT_IMPL1225($l_0$0, $l_0$1) {
  return $l_0$0;
}

function __ZL13JSVAL_TO_IMPLN2JS5ValueE1218($agg_result, $_0_0_0_val$0, $_0_0_0_val$1) {
  var $agg_result_0 = $agg_result | 0;
  HEAP32[$agg_result_0 >> 2] = $_0_0_0_val$0;
  HEAP32[$agg_result_0 + 4 >> 2] = $_0_0_0_val$1;
  return;
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 4) | 0;
}

function __ZN9AppendArgC2ERN2js6VectorIN2JS5ValueELj0ENS0_15TempAllocPolicyEEE($this, $values) {
  HEAP32[$this >> 2] = $values;
  return;
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 4) | 0;
}

function __ZN2js7MoveRefI16JSStackTraceElemEC2ERS1_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZL13IMPL_TO_JSVAL12jsval_layout1228($agg_result, $l_0$0, $l_0$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $l_0$0;
  HEAP32[$1 + 4 >> 2] = $l_0$1;
  return;
}

function _STRING_TO_JSVAL_IMPL1229($agg_result, $str) {
  HEAP32[$agg_result + 4 >> 2] = -123;
  HEAP32[$agg_result >> 2] = $str;
  return;
}

function __ZN2js2gcL15GetGCObjectKindEjb1230($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _OBJECT_TO_JSVAL_IMPL1238($agg_result, $obj) {
  HEAP32[$agg_result + 4 >> 2] = -121;
  HEAP32[$agg_result >> 2] = $obj;
  return;
}

function __ZL15CopyErrorReportP9JSContextP13JSErrorReport($cx, $report) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $report | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      var $8 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = _strlen($2);
    var $8 = $5 + 1 | 0;
    __label__ = 3;
    break;
   case 3:
    var $8;
    var $9 = $report + 8 | 0;
    var $10 = HEAP32[$9 >> 2];
    if (($10 | 0) == 0) {
      var $16 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = _strlen($10);
    var $16 = $13 + 1 | 0;
    __label__ = 5;
    break;
   case 5:
    var $16;
    var $17 = $report + 16 | 0;
    var $18 = HEAP32[$17 >> 2];
    if (($18 | 0) == 0) {
      var $25 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = __Z9js_strlenPKt($18);
    var $25 = ($21 << 1) + 2 | 0;
    __label__ = 7;
    break;
   case 7:
    var $25;
    var $26 = $report + 32 | 0;
    var $27 = HEAP32[$26 >> 2];
    if (($27 | 0) == 0) {
      var $argsCopySize_1 = 0;
      var $argsArraySize_0 = 0;
      var $ucmessageSize_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $30 = __Z9js_strlenPKt($27);
    var $32 = ($30 << 1) + 2 | 0;
    var $34 = HEAP32[$report + 36 >> 2];
    if (($34 | 0) == 0) {
      var $argsCopySize_1 = 0;
      var $argsArraySize_0 = 0;
      var $ucmessageSize_0 = $32;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $36 = HEAP32[$34 >> 2];
    if (($36 | 0) == 0) {
      var $argsCopySize_1 = 0;
      var $argsArraySize_0 = 4;
      var $ucmessageSize_0 = $32;
      __label__ = 12;
      break;
    } else {
      var $i_01 = 0;
      var $argsCopySize_02 = 0;
      var $38 = $36;
      __label__ = 10;
      break;
    }
   case 10:
    var $38;
    var $argsCopySize_02;
    var $i_01;
    var $39 = __Z9js_strlenPKt($38);
    var $42 = $argsCopySize_02 + 2 + ($39 << 1) | 0;
    var $43 = $i_01 + 1 | 0;
    var $45 = HEAP32[$34 + ($43 << 2) >> 2];
    if (($45 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $i_01 = $43;
      var $argsCopySize_02 = $42;
      var $38 = $45;
      __label__ = 10;
      break;
    }
   case 11:
    var $argsCopySize_1 = $42;
    var $argsArraySize_0 = ($43 << 2) + 4 | 0;
    var $ucmessageSize_0 = $32;
    __label__ = 12;
    break;
   case 12:
    var $ucmessageSize_0;
    var $argsArraySize_0;
    var $argsCopySize_1;
    var $48 = $argsArraySize_0 + 40 | 0;
    var $54 = $cx;
    var $55 = __ZN9JSContext7malloc_Ej($54, $16 + $8 + $25 + $ucmessageSize_0 + $argsCopySize_1 + $48 | 0);
    if (($55 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $58 = $55;
    _memset($55, 0, 40, 1);
    var $59 = $55 + 40 | 0;
    if (($argsArraySize_0 | 0) == 0) {
      var $cursor_1 = $59;
      __label__ = 17;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $62 = $59;
    var $64 = $55 + 36 | 0;
    HEAP32[$64 >> 2] = $62;
    var $65 = $55 + $48 | 0;
    var $66 = $report + 36 | 0;
    if ((HEAP32[HEAP32[$66 >> 2] >> 2] | 0) == 0) {
      var $i_1_lcssa = 0;
      var $cursor_0_lcssa = $65;
      var $86 = $62;
      __label__ = 16;
      break;
    } else {
      var $i_14 = 0;
      var $cursor_05 = $65;
      var $70 = $62;
      __label__ = 15;
      break;
    }
   case 15:
    var $70;
    var $cursor_05;
    var $i_14;
    HEAP32[$70 + ($i_14 << 2) >> 2] = $cursor_05;
    var $75 = HEAP32[HEAP32[$66 >> 2] + ($i_14 << 2) >> 2];
    var $76 = __Z9js_strlenPKt($75);
    var $78 = ($76 << 1) + 2 | 0;
    var $79 = $75;
    _memcpy($cursor_05, $79, $78, 1);
    var $80 = $cursor_05 + $78 | 0;
    var $81 = $i_14 + 1 | 0;
    var $_pre = HEAP32[$64 >> 2];
    if ((HEAP32[HEAP32[$66 >> 2] + ($81 << 2) >> 2] | 0) == 0) {
      var $i_1_lcssa = $81;
      var $cursor_0_lcssa = $80;
      var $86 = $_pre;
      __label__ = 16;
      break;
    } else {
      var $i_14 = $81;
      var $cursor_05 = $80;
      var $70 = $_pre;
      __label__ = 15;
      break;
    }
   case 16:
    var $86;
    var $cursor_0_lcssa;
    var $i_1_lcssa;
    HEAP32[$86 + ($i_1_lcssa << 2) >> 2] = 0;
    var $cursor_1 = $cursor_0_lcssa;
    __label__ = 17;
    break;
   case 17:
    var $cursor_1;
    if ((HEAP32[$26 >> 2] | 0) == 0) {
      var $cursor_2 = $cursor_1;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    HEAP32[$55 + 32 >> 2] = $cursor_1;
    var $96 = HEAP32[$26 >> 2];
    _memcpy($cursor_1, $96, $ucmessageSize_0, 1);
    var $cursor_2 = $cursor_1 + $ucmessageSize_0 | 0;
    __label__ = 19;
    break;
   case 19:
    var $cursor_2;
    if ((HEAP32[$17 >> 2] | 0) == 0) {
      var $cursor_3 = $cursor_2;
      __label__ = 22;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $104 = $55 + 16 | 0;
    HEAP32[$104 >> 2] = $cursor_2;
    var $106 = HEAP32[$17 >> 2];
    _memcpy($cursor_2, $106, $25, 1);
    var $107 = $cursor_2 + $25 | 0;
    var $109 = HEAP32[$report + 20 >> 2];
    if (($109 | 0) == 0) {
      var $cursor_3 = $107;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $118 = HEAP32[$104 >> 2] + ($109 - HEAP32[$17 >> 2] >> 1 << 1) | 0;
    HEAP32[$55 + 20 >> 2] = $118;
    var $cursor_3 = $107;
    __label__ = 22;
    break;
   case 22:
    var $cursor_3;
    if ((HEAP32[$9 >> 2] | 0) == 0) {
      var $cursor_4 = $cursor_3;
      __label__ = 25;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $126 = $55 + 8 | 0;
    HEAP32[$126 >> 2] = $cursor_3;
    var $127 = HEAP32[$9 >> 2];
    _memcpy($cursor_3, $127, $16, 1);
    var $128 = $cursor_3 + $16 | 0;
    var $130 = HEAP32[$report + 12 >> 2];
    if (($130 | 0) == 0) {
      var $cursor_4 = $128;
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $138 = HEAP32[$126 >> 2] + ($130 - HEAP32[$9 >> 2]) | 0;
    HEAP32[$55 + 12 >> 2] = $138;
    var $cursor_4 = $128;
    __label__ = 25;
    break;
   case 25:
    var $cursor_4;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    HEAP32[$55 >> 2] = $cursor_4;
    var $146 = HEAP32[$1 >> 2];
    _memcpy($cursor_4, $146, $8, 1);
    __label__ = 27;
    break;
   case 27:
    var $149 = HEAP32[$report + 4 >> 2];
    HEAP32[$55 + 4 >> 2] = $149;
    var $153 = HEAP32[$report + 28 >> 2];
    HEAP32[$55 + 28 >> 2] = $153;
    var $157 = HEAP32[$report + 24 >> 2];
    HEAP32[$55 + 24 >> 2] = $157;
    var $_0 = $58;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15CopyErrorReportP9JSContextP13JSErrorReport["X"] = 1;

function __ZZ18js_CopyErrorObjectP9JSContextP8JSObjectS2_EN8AutoFreeD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$2 >> 2];
    __ZN9JSContext5free_EPv($7);
    var $9 = HEAP32[$1 >> 2];
    __ZN9JSContext5free_EPv($9);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEEC1ES2_($this, $ap_01) {
  __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEEC2ES2_($this, $ap_01);
  return;
}

function __ZN19SuppressErrorsGuardC1EP9JSContext($this, $cx) {
  __ZN19SuppressErrorsGuardC2EP9JSContext($this, $cx);
  return;
}

function __ZNK2js10StackFrame11compartmentEv($this) {
  var $1 = $this;
  var $2 = __ZNK2js10StackFrame10scopeChainEv($1);
  var $3 = $2;
  var $4 = __ZNK2js2gc4Cell11compartmentEv($3);
  return $4;
}

function __ZN2JSL9NullValueEv1222($agg_result) {
  __ZN2JS5Value7setNullEv($agg_result);
  return;
}

function __ZL12ATOM_TO_JSIDP6JSAtom1223($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj1226($1);
  return $2;
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE6growByEj($this) {
  var $1 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE10growByImplILb1EEEbj($this);
  return $1;
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE4backEv($this_0_1_val, $this_0_2_val) {
  var $1 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val);
  return $1 - 16 | 0;
}

function __ZN2js10StackFrame25forEachCanonicalActualArgI9AppendArgEEbT_jj($this, $op_0) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js10StackFrame3funEv($1);
    var $5 = HEAPU16[$2 + 56 >> 1] & 65535;
    var $6 = __ZNK2js10StackFrame13formalArgsEndEv($1);
    var $7 = __ZNK2js10StackFrame13numActualArgsEv($1);
    var $9 = $6 + (-$5 << 3) | 0;
    if ($7 >>> 0 > $5 >>> 0) {
      var $_1 = 0;
      var $p1_0 = $9;
      __label__ = 5;
      break;
    } else {
      var $_01 = 0;
      var $p_0 = $9;
      __label__ = 2;
      break;
    }
   case 2:
    var $p_0;
    var $_01;
    if ($_01 >>> 0 < $7 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 3:
    var $p_0_idx = $p_0 | 0;
    var $st$1$0 = $p_0_idx | 0;
    var $p_0_idx_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $p_0_idx + 4 | 0;
    var $p_0_idx_val$1 = HEAP32[$st$1$1 >> 2];
    var $12 = __ZN9AppendArgclEjPN2JS5ValueE($op_0, $p_0_idx_val$0, $p_0_idx_val$1);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 4:
    var $_01 = $_01 + 1 | 0;
    var $p_0 = $p_0 + 8 | 0;
    __label__ = 2;
    break;
   case 5:
    var $p1_0;
    var $_1;
    if ($_1 >>> 0 < $5 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $p1_0_idx = $p1_0 | 0;
    var $st$1$0 = $p1_0_idx | 0;
    var $p1_0_idx_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $p1_0_idx + 4 | 0;
    var $p1_0_idx_val$1 = HEAP32[$st$1$1 >> 2];
    var $18 = __ZN9AppendArgclEjPN2JS5ValueE($op_0, $p1_0_idx_val$0, $p1_0_idx_val$1);
    if ($18) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 7:
    var $_1 = $_1 + 1 | 0;
    var $p1_0 = $p1_0 + 8 | 0;
    __label__ = 5;
    break;
   case 8:
    var $p2_0 = $6 + (-2 - $5 - $7 + $_1 << 3) | 0;
    var $_2 = $_1;
    __label__ = 9;
    break;
   case 9:
    var $_2;
    var $p2_0;
    if ($_2 >>> 0 < $7 >>> 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 10:
    var $p2_0_idx = $p2_0 | 0;
    var $st$1$0 = $p2_0_idx | 0;
    var $p2_0_idx_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $p2_0_idx + 4 | 0;
    var $p2_0_idx_val$1 = HEAP32[$st$1$1 >> 2];
    var $28 = __ZN9AppendArgclEjPN2JS5ValueE($op_0, $p2_0_idx_val$0, $p2_0_idx_val$1);
    if ($28) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 11:
    var $p2_0 = $p2_0 + 8 | 0;
    var $_2 = $_2 + 1 | 0;
    __label__ = 9;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js10StackFrame25forEachCanonicalActualArgI9AppendArgEEbT_jj["X"] = 1;

function __ZN9AppendArgC1ERN2js6VectorIN2JS5ValueELj0ENS0_15TempAllocPolicyEEE($this, $values) {
  __ZN9AppendArgC2ERN2js6VectorIN2JS5ValueELj0ENS0_15TempAllocPolicyEEE($this, $values);
  return;
}

function __ZN19SuppressErrorsGuardD1Ev($this) {
  __ZN19SuppressErrorsGuardD2Ev($this);
  return;
}

function __ZN2jsL7PodCopyI16JSStackTraceElemEEvPT_PKS2_j($dst, $src, $nelem) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($nelem >>> 0 < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $src + ($nelem << 4) | 0;
    if (($nelem | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $src;
      var $_03 = $dst;
      __label__ = 3;
      break;
    }
   case 3:
    var $_03;
    var $_012;
    var $5 = $_03;
    var $6 = $_012;
    HEAP32[$5 >> 2] = HEAP32[$6 >> 2];
    HEAP32[$5 + 4 >> 2] = HEAP32[$6 + 4 >> 2];
    HEAP32[$5 + 8 >> 2] = HEAP32[$6 + 8 >> 2];
    HEAP32[$5 + 12 >> 2] = HEAP32[$6 + 12 >> 2];
    var $7 = $_012 + 16 | 0;
    if (($7 | 0) == ($3 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $7;
      var $_03 = $_03 + 16 | 0;
      __label__ = 3;
      break;
    }
   case 4:
    var $11 = $dst;
    var $12 = $src;
    var $13 = $nelem << 4;
    _memcpy($11, $12, $13, 1);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodCopyIN2JS5ValueEEEvPT_PKS3_j1224($dst, $src, $nelem) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($nelem >>> 0 < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $src + ($nelem << 3) | 0;
    if (($nelem | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $src;
      var $_03 = $dst;
      __label__ = 3;
      break;
    }
   case 3:
    var $_03;
    var $_012;
    var $5 = $_012 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $_03 | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $8 = $_012 + 8 | 0;
    if (($8 | 0) == ($3 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $8;
      var $_03 = $_03 + 8 | 0;
      __label__ = 3;
      break;
    }
   case 4:
    var $12 = $dst;
    var $13 = $src;
    var $14 = $nelem << 3;
    _memcpy($12, $13, $14, 1);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN19SuppressErrorsGuardD2Ev($this) {
  var $1 = $this | 0;
  var $5 = HEAP32[$1 >> 2];
  var $6 = HEAP32[$this + 8 >> 2];
  _JS_RestoreExceptionState($5, $6);
  var $10 = HEAP32[$1 >> 2];
  var $11 = HEAP32[$this + 4 >> 2];
  var $12 = _JS_SetErrorReporter($10, $11);
  return;
}

function __ZN9AppendArgclEjPN2JS5ValueE($this_0_0_val, $vp_0_0_0_val$0, $vp_0_0_0_val$1) {
  var $1 = $this_0_0_val;
  var $2 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($1, $vp_0_0_0_val$0, $vp_0_0_0_val$1);
  return $2;
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE10growByImplILb1EEEbj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 8 | 0;
    var $4 = HEAP32[$3 >> 2];
    if ((HEAP32[$this + 12 >> 2] | 0) == ($4 | 0)) {
      __label__ = 2;
      break;
    } else {
      var $this_idx1_val = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE13growStorageByEj($this);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $this_idx1_val = HEAP32[$3 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $this_idx1_val;
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $9 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    var $10 = $9 + 16 | 0;
    __ZN2js10VectorImplI16JSStackTraceElemLj0ENS_15TempAllocPolicyELb0EE10initializeEPS1_S4_($9, $10);
    HEAP32[$3 >> 2] = $this_idx1_val + 1 | 0;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE13growStorageByEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplI16JSStackTraceElemLj0ENS_15TempAllocPolicyELb0EE10initializeEPS1_S4_($begin, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($begin | 0) == ($end | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $begin;
      __label__ = 2;
      break;
    }
   case 2:
    var $p_01;
    if (($p_01 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $4 = $p_01;
    HEAP32[$4 >> 2] = 0;
    HEAP32[$4 + 4 >> 2] = 0;
    HEAP32[$4 + 8 >> 2] = 0;
    HEAP32[$4 + 12 >> 2] = 0;
    __label__ = 4;
    break;
   case 4:
    var $6 = $p_01 + 16 | 0;
    if (($6 | 0) == ($end | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $6;
      __label__ = 2;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 4;
    var $7 = $this;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($7, $6);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplI16JSStackTraceElemLj0ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplI16JSStackTraceElemLj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj0ES2_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, 1);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 134217727) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 134217727) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplI16JSStackTraceElemLj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj0ES2_EEj($v, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $newcap << 4;
    var $3 = $v;
    var $4 = __ZN2js15TempAllocPolicy7malloc_Ej($3, $2);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $v_idx = $v + 4 | 0;
    var $v_idx_val = HEAP32[$v_idx >> 2];
    var $8 = __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($v_idx_val);
    var $v_idx4 = $v + 8 | 0;
    var $v_idx4_val = HEAP32[$v_idx4 >> 2];
    var $9 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE10endNoCheckEv($v_idx_val, $v_idx4_val);
    if (($8 | 0) == ($9 | 0)) {
      var $21 = $v_idx_val;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx = $1 | 0;
    var $dst_01 = $5;
    var $src_02 = $8;
    var $v_idx1_val5 = $v_idx_val;
    var $v_idx2_val7 = $v_idx4_val;
    __label__ = 4;
    break;
   case 4:
    var $v_idx2_val7;
    var $v_idx1_val5;
    var $src_02;
    var $dst_01;
    if (($dst_01 | 0) == 0) {
      var $v_idx1_val = $v_idx1_val5;
      var $v_idx2_val = $v_idx2_val7;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = $dst_01;
    HEAP32[$13 >> 2] = 0;
    HEAP32[$13 + 4 >> 2] = 0;
    HEAP32[$13 + 8 >> 2] = 0;
    HEAP32[$13 + 12 >> 2] = 0;
    __ZN2js4MoveI16JSStackTraceElemEENS_7MoveRefIT_EERS3_($1, $src_02);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $14 = __ZNK2js7MoveRefI16JSStackTraceElemEcvRS1_Ev($_idx_val);
    var $15 = $14;
    HEAP32[$13 >> 2] = HEAP32[$15 >> 2];
    HEAP32[$13 + 4 >> 2] = HEAP32[$15 + 4 >> 2];
    HEAP32[$13 + 8 >> 2] = HEAP32[$15 + 8 >> 2];
    HEAP32[$13 + 12 >> 2] = HEAP32[$15 + 12 >> 2];
    var $v_idx1_val = HEAP32[$v_idx >> 2];
    var $v_idx2_val = HEAP32[$v_idx4 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $v_idx2_val;
    var $v_idx1_val;
    var $17 = $dst_01 + 16 | 0;
    var $18 = $src_02 + 16 | 0;
    var $19 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE10endNoCheckEv($v_idx1_val, $v_idx2_val);
    if (($18 | 0) == ($19 | 0)) {
      var $21 = $v_idx1_val;
      __label__ = 7;
      break;
    } else {
      var $dst_01 = $17;
      var $src_02 = $18;
      var $v_idx1_val5 = $v_idx1_val;
      var $v_idx2_val7 = $v_idx2_val;
      __label__ = 4;
      break;
    }
   case 7:
    var $21;
    __ZN2js15TempAllocPolicy5free_EPv($21);
    HEAP32[$v_idx >> 2] = $5;
    HEAP32[$v + 12 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveI16JSStackTraceElemEENS_7MoveRefIT_EERS3_($agg_result, $t) {
  __ZN2js7MoveRefI16JSStackTraceElemEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefI16JSStackTraceElemEC1ERS1_($this, $t) {
  __ZN2js7MoveRefI16JSStackTraceElemEC2ERS1_($this, $t);
  return;
}

function __ZN2js10VectorImplI16JSStackTraceElemLj0ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_($dst, $srcbeg, $srcend) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx = $1 | 0;
    var $p_01 = $srcbeg;
    var $_02 = $dst;
    __label__ = 3;
    break;
   case 3:
    var $_02;
    var $p_01;
    if (($_02 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $5 = $_02;
    HEAP32[$5 >> 2] = 0;
    HEAP32[$5 + 4 >> 2] = 0;
    HEAP32[$5 + 8 >> 2] = 0;
    HEAP32[$5 + 12 >> 2] = 0;
    __ZN2js4MoveI16JSStackTraceElemEENS_7MoveRefIT_EERKS3_($1, $p_01);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $6 = __ZNK2js7MoveRefI16JSStackTraceElemEcvRS1_Ev($_idx_val);
    var $7 = $6;
    HEAP32[$5 >> 2] = HEAP32[$7 >> 2];
    HEAP32[$5 + 4 >> 2] = HEAP32[$7 + 4 >> 2];
    HEAP32[$5 + 8 >> 2] = HEAP32[$7 + 8 >> 2];
    HEAP32[$5 + 12 >> 2] = HEAP32[$7 + 12 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $9 = $p_01 + 16 | 0;
    if (($9 | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      var $p_01 = $9;
      var $_02 = $_02 + 16 | 0;
      __label__ = 3;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveI16JSStackTraceElemEENS_7MoveRefIT_EERKS3_($agg_result, $t) {
  __ZN2js7MoveRefI16JSStackTraceElemEC1ERS1_($agg_result, $t);
  return;
}

function __ZN19SuppressErrorsGuardC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  var $2 = $this + 4 | 0;
  var $3 = $cx;
  var $4 = _JS_SetErrorReporter($3, 0);
  HEAP32[$2 >> 2] = $4;
  var $6 = $this + 8 | 0;
  var $7 = _JS_SaveExceptionState($3);
  HEAP32[$6 >> 2] = $7;
  return;
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEEC2ES2_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1231($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $proto;
    var $2 = $cx;
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($1, $2, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($2, $kind);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_0 = $7;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $parent;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, __ZN2js10ErrorClassE, $3, $10, 0, (__ZN2js10ErrorClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $11 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($3, $2, __ZN2js10ErrorClassE, $kind);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $11 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($6, $14);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11StringValueEP8JSString1239($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2JSL10Int32ValueEi1240($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function _JSID_IS_STRING1247($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSVAL_IS_PRIMITIVE_IMPL1252($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 < 4294967175 & 1;
}

function _JSID_TO_STRING1254($iden) {
  return $iden;
}

function _JSVAL_TO_GCTHING_IMPL1256($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_IS_TRACEABLE_IMPL1257($l_0$0, $l_0$1) {
  var $2 = $l_0$1;
  return (($2 | 0) == -123 | ($2 | 0) == -121) & 1;
}

function __ZNK2js10StackFrame17hasOverriddenArgsEv($this_0_0_val) {
  return ($this_0_0_val & 1024 | 0) != 0;
}

function _INT32_TO_JSVAL_IMPL1251($agg_result, $i) {
  HEAP32[$agg_result + 4 >> 2] = -127;
  HEAP32[$agg_result >> 2] = $i;
  return;
}

function __ZL24GetStackTraceValueBufferP12JSExnPrivate($priv) {
  return $priv + 24 + (HEAP32[$priv + 16 >> 2] << 4) | 0;
}

function __ZL9ExceptionP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 68;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $protov = __stackBase__ + 8;
    var $iter = __stackBase__ + 16;
    var $lineno = __stackBase__ + 56;
    var $1 = __stackBase__ + 60;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $_idx6_val = HEAPU32[$args >> 2];
    var $2 = __ZNK2js12CallReceiver6calleeEv($_idx6_val);
    var $3 = $cx + 52 | 0;
    var $7 = $cx;
    var $8 = HEAP32[HEAP32[$3 >> 2] + 210200 >> 2];
    var $9 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($2, $7, $8, $protov);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $protov_idx = $protov | 0;
    var $protov_idx_val$0 = HEAP32[$protov_idx >> 2];
    var $protov_idx_val$1 = HEAP32[$protov_idx + 4 >> 2];
    var $12 = __ZNK2JS5Value8isObjectEv($protov_idx_val$0, $protov_idx_val$1);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($7, 4, 135, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str11194 | 0, tempInt));
    var $_0 = 0;
    __label__ = 27;
    break;
   case 4:
    var $15 = __ZNK2JS5Value8toObjectEv($protov_idx_val$0, $protov_idx_val$1);
    var $16 = $15;
    var $_idx4_val = HEAP32[$15 + 20 >> 2];
    var $17 = __ZNK8JSObject9getParentEv($_idx4_val);
    var $18 = $17;
    var $19 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_($cx, $16, $18);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $args_idx8_val = HEAP32[$args + 4 >> 2];
    var $22 = __ZNK2js8CallArgs4argcEv($args_idx8_val);
    if (($22 | 0) == 0) {
      var $message_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $25 = __ZNK2js8CallArgsixEj($_idx6_val, 0);
    var $_idx3 = $25 | 0;
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    var $26 = __ZNK2JS5Value11isUndefinedEv($_idx3_val$0, $_idx3_val$1);
    if ($26) {
      var $message_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $28 = $cx;
    var $29 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($28, $_idx3_val$0, $_idx3_val$1);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2JS5Value9setStringEP8JSString($25, $29);
    var $message_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $message_0;
    __ZN2js13FrameRegsIterC1EP9JSContextNS_9StackIter11SavedOptionE($iter, $7);
    __label__ = 10;
    break;
   case 10:
    var $34 = __ZNK2js13FrameRegsIter4doneEv($iter);
    if ($34) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $36 = __ZNK2js13FrameRegsIter2fpEv($iter);
    var $_idx2_val = HEAP32[$36 >> 2];
    var $37 = __ZNK2js10StackFrame13isScriptFrameEv($_idx2_val);
    if ($37) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN2js13FrameRegsIterppEv($iter);
    __label__ = 10;
    break;
   case 13:
    if ($22 >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    var $41 = __ZNK2js8CallArgsixEj($_idx6_val, 1);
    var $42 = $cx;
    var $_idx15 = $41 | 0;
    var $_idx15_val$0 = HEAP32[$_idx15 >> 2];
    var $_idx15_val$1 = HEAP32[$_idx15 + 4 >> 2];
    var $43 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($42, $_idx15_val$0, $_idx15_val$1);
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    __ZN2JS5Value9setStringEP8JSString($41, $43);
    var $filename_0 = $43;
    __label__ = 19;
    break;
   case 16:
    var $47 = __ZNK2js13FrameRegsIter4doneEv($iter);
    if ($47) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $49 = __ZNK2js13FrameRegsIter2fpEv($iter);
    var $50 = __ZNK2js10StackFrame6scriptEv($49);
    var $52 = HEAP32[$50 + 52 >> 2];
    var $53 = __ZL16FilenameToStringP9JSContextPKc($cx, $52);
    if (($53 | 0) == 0) {
      var $_0 = 0;
      __label__ = 27;
      break;
    } else {
      var $filename_0 = $53;
      __label__ = 19;
      break;
    }
   case 18:
    var $filename_0 = HEAP32[HEAP32[$3 >> 2] + 144136 >> 2] | 0;
    __label__ = 19;
    break;
   case 19:
    var $filename_0;
    if ($22 >>> 0 > 2) {
      __label__ = 20;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 20:
    var $63 = __ZNK2js8CallArgsixEj($_idx6_val, 2);
    var $64 = __ZN2js17ValueToECMAUint32EP9JSContextRKN2JS5ValueEPj($7, $63, $lineno);
    if ($64) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 0;
      __label__ = 27;
      break;
    }
   case 21:
    var $76 = HEAP32[$lineno >> 2];
    __label__ = 25;
    break;
   case 22:
    var $66 = __ZNK2js13FrameRegsIter4doneEv($iter);
    if ($66) {
      var $74 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $68 = __ZNK2js13FrameRegsIter2fpEv($iter);
    var $69 = __ZNK2js13FrameRegsIter2pcEv($iter);
    var $70 = $cx;
    var $71 = $68;
    var $72 = __Z22js_FramePCToLineNumberP9JSContextPN2js10StackFrameEPh($70, $71, $69);
    var $74 = $72;
    __label__ = 24;
    break;
   case 24:
    var $74;
    HEAP32[$lineno >> 2] = $74;
    var $76 = $74;
    __label__ = 25;
    break;
   case 25:
    var $76;
    var $77 = __ZNK2js12CallReceiver6calleeEv($_idx6_val);
    __ZNK8JSObject15getReservedSlotEj($1, $77, 0);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $78 = __ZNK2JS5Value7toInt32Ev($_idx_val$0, $_idx_val$1);
    var $79 = __ZL14InitExnPrivateP9JSContextP8JSObjectP8JSStringS4_jP13JSErrorReporti($cx, $19, $message_0, $filename_0, $76, 0, $78);
    if ($79) {
      __label__ = 26;
      break;
    } else {
      var $_0 = 0;
      __label__ = 27;
      break;
    }
   case 26:
    var $81 = __ZNK2js12CallReceiver4rvalEv($_idx6_val);
    var $82 = $19;
    __ZN2JS5Value9setObjectER8JSObject($81, $82);
    var $_0 = 1;
    __label__ = 27;
    break;
   case 27:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9ExceptionP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL16FilenameToStringP9JSContextPKc($cx, $filename) {
  var $1 = $cx;
  var $2 = _JS_NewStringCopyZ($1, $filename);
  return $2;
}

function __ZL12JSID_IS_ATOMi1253($id) {
  var $1 = _JSID_IS_STRING1247($id);
  return $1;
}

function _INT_TO_JSVAL($agg_result, $i) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _INT32_TO_JSVAL_IMPL1251($1, $i);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout1228($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZL18StackTraceToStringP9JSContextP12JSExnPrivate($cx, $priv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ulnbuf = __stackBase__;
    var $1 = __ZL24GetStackTraceValueBufferP12JSExnPrivate($priv);
    var $5 = $priv + 24 + (HEAP32[$priv + 16 >> 2] << 4) | 0;
    var $6 = $cx;
    var $7 = $ulnbuf | 0;
    var $stackbuf_0 = 0;
    var $stacklen_0 = 0;
    var $stackmax_0 = 0;
    var $elem_0 = $priv + 24 | 0;
    var $values_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $values_0;
    var $elem_0;
    var $stackmax_0;
    var $stacklen_0;
    var $stackbuf_0;
    if (($elem_0 | 0) == ($5 | 0)) {
      var $stackbuf_17 = $stackbuf_0;
      var $stacklen_7 = $stacklen_0;
      var $stackmax_17 = $stackmax_0;
      __label__ = 64;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAP32[$elem_0 >> 2];
    if (($12 | 0) == 0) {
      var $stackbuf_8 = $stackbuf_0;
      var $stacklen_3 = $stacklen_0;
      var $stackmax_8 = $stackmax_0;
      var $values_2 = $values_0;
      __label__ = 37;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx1_val = HEAP32[$12 >> 2];
    var $15 = __ZNK8JSString6lengthEv($_idx1_val);
    var $16 = __ZN8JSString8getCharsEP9JSContext($12, $6);
    if (($16 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_0;
      __label__ = 71;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ($15 >>> 0 > ($stackmax_0 - $stacklen_0 | 0) >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $stackbuf_1 = $stackbuf_0;
    var $stackmax_1 = $stackmax_0;
    var $_pre_phi = $15 + $stacklen_0 | 0;
    __label__ = 11;
    break;
   case 7:
    if ($stackmax_0 >>> 0 > 1048575) {
      var $stackbuf_17 = $stackbuf_0;
      var $stacklen_7 = $stacklen_0;
      var $stackmax_17 = $stackmax_0;
      __label__ = 64;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($15 >>> 0 < (1048576 - $stacklen_0 | 0) >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $stackbuf_17 = $stackbuf_0;
      var $stacklen_7 = $stacklen_0;
      var $stackmax_17 = $stackmax_0;
      __label__ = 64;
      break;
    }
   case 9:
    var $27 = $15 + $stacklen_0 | 0;
    var $28 = _JS_CeilingLog2($27);
    var $29 = 1 << $28;
    var $32 = ($29 << 1) + 2 | 0;
    var $33 = __ZN9JSContext8realloc_EPvj($6, $stackbuf_0, $32);
    if (($33 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_0;
      __label__ = 71;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $stackbuf_1 = $33;
    var $stackmax_1 = $29;
    var $_pre_phi = $27;
    __label__ = 11;
    break;
   case 11:
    var $_pre_phi;
    var $stackmax_1;
    var $stackbuf_1;
    var $40 = $16;
    var $41 = $15 << 1;
    _memcpy($stackbuf_1 + ($stacklen_0 << 1) | 0, $40, $41, 1);
    if (($_pre_phi | 0) == ($stackmax_1 | 0)) {
      __label__ = 12;
      break;
    } else {
      var $stackbuf_2 = $stackbuf_1;
      var $stackmax_2 = $stackmax_1;
      __label__ = 15;
      break;
    }
   case 12:
    if ($stackmax_1 >>> 0 > 1048575) {
      var $stackbuf_17 = $stackbuf_1;
      var $stacklen_7 = $_pre_phi;
      var $stackmax_17 = $stackmax_1;
      __label__ = 64;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $_ = ($stackmax_1 | 0) == 0 ? 64 : $stackmax_1 << 1;
    var $51 = __ZN9JSContext8realloc_EPvj($6, $stackbuf_1, $_ << 1 | 2);
    if (($51 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_1;
      __label__ = 71;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $stackbuf_2 = $51;
    var $stackmax_2 = $_;
    __label__ = 15;
    break;
   case 15:
    var $stackmax_2;
    var $stackbuf_2;
    HEAP16[$stackbuf_2 + ($_pre_phi << 1) >> 1] = 40;
    var $58 = $elem_0 + 4 | 0;
    var $stackbuf_3 = $stackbuf_2;
    var $stacklen_1 = $_pre_phi + 1 | 0;
    var $stackmax_3 = $stackmax_2;
    var $i_0 = 0;
    var $values_1 = $values_0;
    __label__ = 16;
    break;
   case 16:
    var $values_1;
    var $i_0;
    var $stackmax_3;
    var $stacklen_1;
    var $stackbuf_3;
    if (($i_0 | 0) == (HEAP32[$58 >> 2] | 0)) {
      __label__ = 32;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    if (($i_0 | 0) == 0) {
      var $stackbuf_5 = $stackbuf_3;
      var $stacklen_2 = $stacklen_1;
      var $stackmax_5 = $stackmax_3;
      __label__ = 23;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if (($stacklen_1 | 0) == ($stackmax_3 | 0)) {
      __label__ = 19;
      break;
    } else {
      var $stackbuf_4 = $stackbuf_3;
      var $stackmax_4 = $stackmax_3;
      __label__ = 22;
      break;
    }
   case 19:
    if ($stackmax_3 >>> 0 > 1048575) {
      var $stackbuf_17 = $stackbuf_3;
      var $stacklen_7 = $stacklen_1;
      var $stackmax_17 = $stackmax_3;
      __label__ = 64;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $_1 = ($stackmax_3 | 0) == 0 ? 64 : $stackmax_3 << 1;
    var $74 = __ZN9JSContext8realloc_EPvj($6, $stackbuf_3, $_1 << 1 | 2);
    if (($74 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_3;
      __label__ = 71;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $stackbuf_4 = $74;
    var $stackmax_4 = $_1;
    __label__ = 22;
    break;
   case 22:
    var $stackmax_4;
    var $stackbuf_4;
    HEAP16[$stackbuf_4 + ($stacklen_1 << 1) >> 1] = 44;
    var $stackbuf_5 = $stackbuf_4;
    var $stacklen_2 = $stacklen_1 + 1 | 0;
    var $stackmax_5 = $stackmax_4;
    __label__ = 23;
    break;
   case 23:
    var $stackmax_5;
    var $stacklen_2;
    var $stackbuf_5;
    var $82 = __ZL18ValueToShortSourceP9JSContextRKN2JS5ValueE($cx, $values_1);
    if (($82 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_5;
      __label__ = 71;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $_idx_val = HEAP32[$82 >> 2];
    var $85 = __ZNK8JSString6lengthEv($_idx_val);
    var $86 = __ZN8JSString8getCharsEP9JSContext($82, $6);
    if (($86 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_5;
      __label__ = 71;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    if ($85 >>> 0 > ($stackmax_5 - $stacklen_2 | 0) >>> 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $stackbuf_6 = $stackbuf_5;
    var $stackmax_6 = $stackmax_5;
    var $_pre_phi16 = $85 + $stacklen_2 | 0;
    __label__ = 31;
    break;
   case 27:
    if ($stackmax_5 >>> 0 > 1048575) {
      var $stackbuf_17 = $stackbuf_5;
      var $stacklen_7 = $stacklen_2;
      var $stackmax_17 = $stackmax_5;
      __label__ = 64;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    if ($85 >>> 0 < (1048576 - $stacklen_2 | 0) >>> 0) {
      __label__ = 29;
      break;
    } else {
      var $stackbuf_17 = $stackbuf_5;
      var $stacklen_7 = $stacklen_2;
      var $stackmax_17 = $stackmax_5;
      __label__ = 64;
      break;
    }
   case 29:
    var $97 = $85 + $stacklen_2 | 0;
    var $98 = _JS_CeilingLog2($97);
    var $99 = 1 << $98;
    var $102 = ($99 << 1) + 2 | 0;
    var $103 = __ZN9JSContext8realloc_EPvj($6, $stackbuf_5, $102);
    if (($103 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_5;
      __label__ = 71;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $stackbuf_6 = $103;
    var $stackmax_6 = $99;
    var $_pre_phi16 = $97;
    __label__ = 31;
    break;
   case 31:
    var $_pre_phi16;
    var $stackmax_6;
    var $stackbuf_6;
    var $110 = $86;
    var $111 = $85 << 1;
    _memcpy($stackbuf_6 + ($stacklen_2 << 1) | 0, $110, $111, 1);
    var $stackbuf_3 = $stackbuf_6;
    var $stacklen_1 = $_pre_phi16;
    var $stackmax_3 = $stackmax_6;
    var $i_0 = $i_0 + 1 | 0;
    var $values_1 = $values_1 + 8 | 0;
    __label__ = 16;
    break;
   case 32:
    if (($stacklen_1 | 0) == ($stackmax_3 | 0)) {
      __label__ = 33;
      break;
    } else {
      var $stackbuf_7 = $stackbuf_3;
      var $stackmax_7 = $stackmax_3;
      __label__ = 36;
      break;
    }
   case 33:
    if ($stackmax_3 >>> 0 > 1048575) {
      var $stackbuf_17 = $stackbuf_3;
      var $stacklen_7 = $stacklen_1;
      var $stackmax_17 = $stackmax_3;
      __label__ = 64;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $_2 = ($stackmax_3 | 0) == 0 ? 64 : $stackmax_3 << 1;
    var $124 = __ZN9JSContext8realloc_EPvj($6, $stackbuf_3, $_2 << 1 | 2);
    if (($124 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_3;
      __label__ = 71;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $stackbuf_7 = $124;
    var $stackmax_7 = $_2;
    __label__ = 36;
    break;
   case 36:
    var $stackmax_7;
    var $stackbuf_7;
    HEAP16[$stackbuf_7 + ($stacklen_1 << 1) >> 1] = 41;
    var $stackbuf_8 = $stackbuf_7;
    var $stacklen_3 = $stacklen_1 + 1 | 0;
    var $stackmax_8 = $stackmax_7;
    var $values_2 = $values_1;
    __label__ = 37;
    break;
   case 37:
    var $values_2;
    var $stackmax_8;
    var $stacklen_3;
    var $stackbuf_8;
    if (($stacklen_3 | 0) == ($stackmax_8 | 0)) {
      __label__ = 38;
      break;
    } else {
      var $stackbuf_9 = $stackbuf_8;
      var $stackmax_9 = $stackmax_8;
      __label__ = 41;
      break;
    }
   case 38:
    if ($stackmax_8 >>> 0 > 1048575) {
      var $stackbuf_17 = $stackbuf_8;
      var $stacklen_7 = $stacklen_3;
      var $stackmax_17 = $stackmax_8;
      __label__ = 64;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $_3 = ($stackmax_8 | 0) == 0 ? 64 : $stackmax_8 << 1;
    var $141 = __ZN9JSContext8realloc_EPvj($6, $stackbuf_8, $_3 << 1 | 2);
    if (($141 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_8;
      __label__ = 71;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $stackbuf_9 = $141;
    var $stackmax_9 = $_3;
    __label__ = 41;
    break;
   case 41:
    var $stackmax_9;
    var $stackbuf_9;
    var $146 = $stacklen_3 + 1 | 0;
    HEAP16[$stackbuf_9 + ($stacklen_3 << 1) >> 1] = 64;
    var $149 = HEAP32[$elem_0 + 8 >> 2];
    if (($149 | 0) == 0) {
      var $stackbuf_12 = $stackbuf_9;
      var $stacklen_5 = $146;
      var $stackmax_12 = $stackmax_9;
      __label__ = 48;
      break;
    } else {
      var $cp_0 = $149;
      var $stackbuf_10 = $stackbuf_9;
      var $stacklen_4 = $146;
      var $stackmax_10 = $stackmax_9;
      __label__ = 42;
      break;
    }
   case 42:
    var $stackmax_10;
    var $stacklen_4;
    var $stackbuf_10;
    var $cp_0;
    var $151 = HEAPU8[$cp_0];
    if ($151 << 24 >> 24 == 0) {
      var $stackbuf_12 = $stackbuf_10;
      var $stacklen_5 = $stacklen_4;
      var $stackmax_12 = $stackmax_10;
      __label__ = 48;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    if (($stacklen_4 | 0) == ($stackmax_10 | 0)) {
      __label__ = 44;
      break;
    } else {
      var $stackbuf_11 = $stackbuf_10;
      var $stackmax_11 = $stackmax_10;
      var $168 = $151;
      __label__ = 47;
      break;
    }
   case 44:
    if ($stackmax_10 >>> 0 > 1048575) {
      var $stackbuf_17 = $stackbuf_10;
      var $stacklen_7 = $stacklen_4;
      var $stackmax_17 = $stackmax_10;
      __label__ = 64;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $_4 = ($stackmax_10 | 0) == 0 ? 64 : $stackmax_10 << 1;
    var $163 = __ZN9JSContext8realloc_EPvj($6, $stackbuf_10, $_4 << 1 | 2);
    if (($163 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_10;
      __label__ = 71;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $stackbuf_11 = $163;
    var $stackmax_11 = $_4;
    var $168 = HEAP8[$cp_0];
    __label__ = 47;
    break;
   case 47:
    var $168;
    var $stackmax_11;
    var $stackbuf_11;
    HEAP16[$stackbuf_11 + ($stacklen_4 << 1) >> 1] = $168 << 24 >> 24;
    var $cp_0 = $cp_0 + 1 | 0;
    var $stackbuf_10 = $stackbuf_11;
    var $stacklen_4 = $stacklen_4 + 1 | 0;
    var $stackmax_10 = $stackmax_11;
    __label__ = 42;
    break;
   case 48:
    var $stackmax_12;
    var $stacklen_5;
    var $stackbuf_12;
    if (($stacklen_5 | 0) == ($stackmax_12 | 0)) {
      __label__ = 49;
      break;
    } else {
      var $stackbuf_13 = $stackbuf_12;
      var $stackmax_13 = $stackmax_12;
      __label__ = 52;
      break;
    }
   case 49:
    if ($stackmax_12 >>> 0 > 1048575) {
      var $stackbuf_17 = $stackbuf_12;
      var $stacklen_7 = $stacklen_5;
      var $stackmax_17 = $stackmax_12;
      __label__ = 64;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    var $_5 = ($stackmax_12 | 0) == 0 ? 64 : $stackmax_12 << 1;
    var $182 = __ZN9JSContext8realloc_EPvj($6, $stackbuf_12, $_5 << 1 | 2);
    if (($182 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_12;
      __label__ = 71;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $stackbuf_13 = $182;
    var $stackmax_13 = $_5;
    __label__ = 52;
    break;
   case 52:
    var $stackmax_13;
    var $stackbuf_13;
    HEAP16[$stackbuf_13 + ($stacklen_5 << 1) >> 1] = 58;
    var $189 = HEAP32[$elem_0 + 12 >> 2];
    var $190 = _JS_snprintf($7, 11, STRING_TABLE.__str544300 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $189, tempInt));
    var $cp_1 = $7;
    var $stackbuf_14 = $stackbuf_13;
    var $stacklen_6_in = $stacklen_5;
    var $stackmax_14 = $stackmax_13;
    __label__ = 53;
    break;
   case 53:
    var $stackmax_14;
    var $stacklen_6_in;
    var $stackbuf_14;
    var $cp_1;
    var $stacklen_6 = $stacklen_6_in + 1 | 0;
    var $192 = HEAPU8[$cp_1];
    var $194 = ($stacklen_6 | 0) == ($stackmax_14 | 0);
    if ($192 << 24 >> 24 == 0) {
      __label__ = 59;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    if ($194) {
      __label__ = 55;
      break;
    } else {
      var $stackbuf_15 = $stackbuf_14;
      var $stackmax_15 = $stackmax_14;
      var $209 = $192;
      __label__ = 58;
      break;
    }
   case 55:
    if ($stackmax_14 >>> 0 > 1048575) {
      var $stackbuf_17 = $stackbuf_14;
      var $stacklen_7 = $stacklen_6;
      var $stackmax_17 = $stackmax_14;
      __label__ = 64;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    var $_6 = ($stackmax_14 | 0) == 0 ? 64 : $stackmax_14 << 1;
    var $204 = __ZN9JSContext8realloc_EPvj($6, $stackbuf_14, $_6 << 1 | 2);
    if (($204 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_14;
      __label__ = 71;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    var $stackbuf_15 = $204;
    var $stackmax_15 = $_6;
    var $209 = HEAP8[$cp_1];
    __label__ = 58;
    break;
   case 58:
    var $209;
    var $stackmax_15;
    var $stackbuf_15;
    HEAP16[$stackbuf_15 + ($stacklen_6 << 1) >> 1] = $209 << 24 >> 24;
    var $cp_1 = $cp_1 + 1 | 0;
    var $stackbuf_14 = $stackbuf_15;
    var $stacklen_6_in = $stacklen_6;
    var $stackmax_14 = $stackmax_15;
    __label__ = 53;
    break;
   case 59:
    if ($194) {
      __label__ = 60;
      break;
    } else {
      var $stackbuf_16 = $stackbuf_14;
      var $stackmax_16 = $stackmax_14;
      __label__ = 63;
      break;
    }
   case 60:
    if ($stackmax_14 >>> 0 > 1048575) {
      var $stackbuf_17 = $stackbuf_14;
      var $stacklen_7 = $stacklen_6;
      var $stackmax_17 = $stackmax_14;
      __label__ = 64;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    var $_7 = ($stackmax_14 | 0) == 0 ? 64 : $stackmax_14 << 1;
    var $222 = __ZN9JSContext8realloc_EPvj($6, $stackbuf_14, $_7 << 1 | 2);
    if (($222 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_14;
      __label__ = 71;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 62:
    var $stackbuf_16 = $222;
    var $stackmax_16 = $_7;
    __label__ = 63;
    break;
   case 63:
    var $stackmax_16;
    var $stackbuf_16;
    HEAP16[$stackbuf_16 + ($stacklen_6 << 1) >> 1] = 10;
    var $stackbuf_0 = $stackbuf_16;
    var $stacklen_0 = $stacklen_6_in + 2 | 0;
    var $stackmax_0 = $stackmax_16;
    var $elem_0 = $elem_0 + 16 | 0;
    var $values_0 = $values_2;
    __label__ = 2;
    break;
   case 64:
    var $stackmax_17;
    var $stacklen_7;
    var $stackbuf_17;
    if (($stacklen_7 | 0) == 0) {
      __label__ = 65;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 65:
    var $_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 73;
    break;
   case 66:
    if ($stacklen_7 >>> 0 < $stackmax_17 >>> 0) {
      __label__ = 67;
      break;
    } else {
      var $stackbuf_18 = $stackbuf_17;
      __label__ = 69;
      break;
    }
   case 67:
    var $243 = __ZN9JSContext8realloc_EPvj($6, $stackbuf_17, ($stacklen_7 << 1) + 2 | 0);
    if (($243 | 0) == 0) {
      var $stackbuf_18 = $stackbuf_17;
      __label__ = 69;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 68:
    var $stackbuf_18 = $243;
    __label__ = 69;
    break;
   case 69:
    var $stackbuf_18;
    HEAP16[$stackbuf_18 + ($stacklen_7 << 1) >> 1] = 0;
    var $249 = $cx;
    var $250 = __Z12js_NewStringP9JSContextPtj($249, $stackbuf_18, $stacklen_7);
    if (($250 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_18;
      __label__ = 71;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    var $_0 = $250 | 0;
    __label__ = 73;
    break;
   case 71:
    var $stackbuf_19;
    if (($stackbuf_19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 73;
      break;
    } else {
      __label__ = 72;
      break;
    }
   case 72:
    __ZN9JSContext5free_EPv($stackbuf_19);
    var $_0 = 0;
    __label__ = 73;
    break;
   case 73:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18StackTraceToStringP9JSContextP12JSExnPrivate["X"] = 1;

function __ZL18ValueToShortSourceP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 156;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str = __stackBase__;
    var $ac = __stackBase__ + 4;
    var $buf = __stackBase__ + 56;
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $1 = __ZNK2JS5Value8isObjectEv($v_idx_val$0, $v_idx_val$1);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $cx;
    var $4 = __Z16js_ValueToSourceP9JSContextRKN2JS5ValueE($3, $v);
    var $_1 = $4;
    __label__ = 14;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8toObjectEv($v_idx_val$0, $v_idx_val$1);
    var $7 = $cx;
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $7, $6);
    var $8 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$6 + 4 >> 2];
    var $10 = __ZNK8JSObject10isFunctionEv($_idx_val);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $_idx2_val = HEAP32[$6 + 24 >> 2];
    var $12 = __ZNK8JSObject18getFunctionPrivateEv($_idx2_val);
    var $_idx4_val = HEAP32[$12 + 72 >> 2];
    var $13 = _JS_GetFunctionId($_idx4_val);
    HEAP32[$str >> 2] = $13;
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $16 = $cx;
    var $17 = __Z16js_ValueToSourceP9JSContextRKN2JS5ValueE($16, $v);
    HEAP32[$str >> 2] = $17;
    if (($17 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    _JS_ClearPendingException($7);
    var $20 = _JS_NewStringCopyZ($7, STRING_TABLE.__str31196 | 0);
    HEAP32[$str >> 2] = $20;
    var $29 = $20;
    __label__ = 10;
    break;
   case 8:
    var $22 = $buf | 0;
    var $23 = __ZNK8JSObject8getClassEv($_idx_val);
    var $25 = HEAP32[$23 >> 2];
    var $26 = _JS_snprintf($22, 100, STRING_TABLE.__str41197 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $25, tempInt));
    var $27 = _JS_NewStringCopyZ($7, $22);
    HEAP32[$str >> 2] = $27;
    var $29 = $27;
    __label__ = 10;
    break;
   case 9:
    __ZN2js15AutoCompartment5leaveEv($ac);
    __label__ = 11;
    break;
   case 10:
    var $29;
    __ZN2js15AutoCompartment5leaveEv($ac);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $34 = HEAP32[$cx + 56 >> 2];
    var $35 = __ZN13JSCompartment4wrapEP9JSContextPP8JSString($34, $7, $str);
    if ($35) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 12:
    var $_0 = HEAP32[$str >> 2];
    __label__ = 13;
    break;
   case 13:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_1 = $_0;
    __label__ = 14;
    break;
   case 14:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18ValueToShortSourceP9JSContextRKN2JS5ValueE["X"] = 1;

function _JSVAL_IS_TRACEABLE($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE1218($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_TRACEABLE_IMPL1257($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_GCTHING($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE1218($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_GCTHING_IMPL1256($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TRACE_KIND($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE1218($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TRACE_KIND_IMPL($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TRACE_KIND_IMPL($l_0$0, $l_0$1) {
  var $1 = _JSVAL_IS_STRING_IMPL1221($l_0$0, $l_0$1);
  return $1;
}

function __ZNK8JSObject13hasSlotsArrayEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 32 >> 2];
    if (($2 | 0) == 0) {
      var $8 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject10fixedSlotsEv($this);
    var $8 = ($2 | 0) != ($5 | 0);
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject15numDynamicSlotsEj($this, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx1_val = HEAP32[$this + 4 >> 2];
    var $1 = __ZNK8JSObject12isDenseArrayEv($this_idx1_val);
    if ($1) {
      var $6 = $capacity;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 8 >> 2];
    var $3 = __ZNK8JSObject13numFixedSlotsEv($this_idx_val);
    var $6 = $capacity - $3 | 0;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z15js_GetArgsValueP9JSContextPN2js10StackFrameEPN2JS5ValueE($cx, $fp, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fp_idx_val = HEAP32[$fp >> 2];
    var $1 = __ZNK2js10StackFrame17hasOverriddenArgsEv($fp_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $fp;
    var $4 = __ZNK2js10StackFrame7callObjEv($3);
    var $5 = $4;
    var $9 = HEAP32[HEAP32[$cx + 52 >> 2] + 210176 >> 2];
    var $10 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($5, $cx, $9, $vp);
    var $_0 = $10;
    __label__ = 5;
    break;
   case 3:
    var $12 = __Z16js_GetArgsObjectP9JSContextPN2js10StackFrameE($cx, $fp);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value9setObjectER8JSObject($vp, $12);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_GetArgsObjectP9JSContextPN2js10StackFrameE($cx, $fp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $fp_idx_val = HEAP32[$fp >> 2];
    var $2 = __ZNK2js10StackFrame16isEvalInFunctionEv($fp_idx_val);
    if ($2) {
      var $_012 = $fp;
      __label__ = 2;
      break;
    } else {
      var $_01_lcssa = $fp;
      var $_01_lcssa_idx_val4 = $fp_idx_val;
      __label__ = 3;
      break;
    }
   case 2:
    var $_012;
    var $_012_idx_val = HEAP32[$_012 + 16 >> 2];
    var $3 = __ZNK2js10StackFrame4prevEv($_012_idx_val);
    var $_idx_val = HEAP32[$3 >> 2];
    var $4 = __ZNK2js10StackFrame16isEvalInFunctionEv($_idx_val);
    if ($4) {
      var $_012 = $3;
      __label__ = 2;
      break;
    } else {
      var $_01_lcssa = $3;
      var $_01_lcssa_idx_val4 = $_idx_val;
      __label__ = 3;
      break;
    }
   case 3:
    var $_01_lcssa_idx_val4;
    var $_01_lcssa;
    var $5 = __ZNK2js10StackFrame6scriptEv($_01_lcssa);
    if ((HEAP8[$5 + 38 | 0] & 2) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      var $_01_lcssa_idx_val = $_01_lcssa_idx_val4;
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js5types20MarkArgumentsCreatedEP9JSContextP8JSScript($cx, $5);
    var $_01_lcssa_idx_val = HEAP32[$_01_lcssa >> 2];
    __label__ = 5;
    break;
   case 5:
    var $_01_lcssa_idx_val;
    var $11 = __ZNK2js10StackFrame10hasArgsObjEv($_01_lcssa_idx_val);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $13 = __ZNK2js10StackFrame7argsObjEv($_01_lcssa);
    var $_0 = $13 | 0;
    __label__ = 12;
    break;
   case 7:
    var $16 = __ZNK2js10StackFrame13numActualArgsEv($_01_lcssa);
    var $17 = __ZNK2js10StackFrame6calleeEv($_01_lcssa);
    var $18 = __ZN2js15ArgumentsObject6createEP9JSContextjR8JSObject($cx, $16, $17);
    var $20 = $18 | 0;
    if (($18 | 0) == 0) {
      var $_0 = $20;
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx2_val = HEAP32[$18 + 4 >> 2];
    var $22 = __ZNK8JSObject17isStrictArgumentsEv($_idx2_val);
    if ($22) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $24 = __ZNK2js15ArgumentsObject4dataEv($18);
    var $25 = $24 + 8 | 0;
    __ZN6PutArgC1EPN2JS5ValueE($1, $25);
    var $_01_val = HEAP32[$1 >> 2];
    __ZN2js10StackFrame25forEachCanonicalActualArgI6PutArgEEbT_jj($_01_lcssa, $_01_val);
    __label__ = 11;
    break;
   case 10:
    var $27 = $18;
    __ZN2js15ArgumentsObject13setStackFrameEPNS_10StackFrameE($27, $_01_lcssa);
    __label__ = 11;
    break;
   case 11:
    __ZN2js10StackFrame10setArgsObjERNS_15ArgumentsObjectE($_01_lcssa, $18);
    var $_0 = $20;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z16js_GetArgsObjectP9JSContextPN2js10StackFrameE["X"] = 1;

function _JSID_IS_INT1285($iden) {
  return $iden & 1;
}

function _JSID_TO_INT1286($iden) {
  return $iden >> 1;
}

function __ZNK2js10StackFrame16isEvalInFunctionEv($this_0_0_val) {
  return ($this_0_0_val & 10 | 0) == 10;
}

function __ZN2js10StackFrame10setArgsObjERNS_15ArgumentsObjectE($this, $obj) {
  HEAP32[$this + 8 >> 2] = $obj;
  var $2 = $this | 0;
  var $4 = HEAP32[$2 >> 2] | 32768;
  HEAP32[$2 >> 2] = $4;
  return;
}

function __ZN2jsL20CallObjectLambdaNameEP10JSFunction($fun) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP16[$fun + 58 >> 1] & 8) << 16 >> 16 == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$fun + 72 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame27setScopeChainWithOwnCallObjERNS_10CallObjectE($this, $obj) {
  HEAP32[$this + 12 >> 2] = $obj | 0;
  var $3 = $this | 0;
  var $5 = HEAP32[$3 >> 2] | 540672;
  HEAP32[$3 >> 2] = $5;
  return;
}

function __Z18js_GetArgsPropertyP9JSContextPN2js10StackFrameEiPN2JS5ValueE($cx, $fp, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $fp_idx_val = HEAP32[$fp >> 2];
    var $1 = __ZNK2js10StackFrame17hasOverriddenArgsEv($fp_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $3 = $fp;
    var $4 = __ZNK2js10StackFrame7callObjEv($3);
    var $5 = $4;
    var $9 = HEAP32[HEAP32[$cx + 52 >> 2] + 210176 >> 2];
    var $10 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($5, $cx, $9, $v);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $v_idx1 = $v | 0;
    var $st$1$0 = $v_idx1 | 0;
    var $v_idx1_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $v_idx1 + 4 | 0;
    var $v_idx1_val$1 = HEAP32[$st$1$1 >> 2];
    var $13 = __ZNK2JS5Value11isPrimitiveEv($v_idx1_val$0, $v_idx1_val$1);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = $cx;
    var $16 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($15, $v);
    var $17 = $16;
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      var $obj_0 = $17;
      __label__ = 6;
      break;
    }
   case 5:
    var $20 = __ZNK2JS5Value8toObjectEv($v_idx1_val$0, $v_idx1_val$1);
    var $obj_0 = $20;
    __label__ = 6;
    break;
   case 6:
    var $obj_0;
    var $22 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($obj_0, $cx, $id, $vp);
    var $_0 = $22;
    __label__ = 22;
    break;
   case 7:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $24 = _JSID_IS_INT1285($id);
    if (($24 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = _JSID_TO_INT1286($id);
    var $28 = __ZNK2js10StackFrame12maybeArgsObjEv($fp);
    var $29 = __ZNK2js10StackFrame13numActualArgsEv($fp);
    var $31 = ($28 | 0) != 0;
    if ($27 >>> 0 < $29 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 9:
    if ($31) {
      __label__ = 10;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 10:
    var $34 = __ZNK2js15ArgumentsObject7elementEj($28, $27);
    var $_idx = $34 | 0;
    var $st$2$0 = $_idx | 0;
    var $_idx_val$0 = HEAPU32[$st$2$0 >> 2];
    var $st$2$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAPU32[$st$2$1 >> 2];
    var $35 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx_val$0, $_idx_val$1);
    if ($35) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $37 = $28 | 0;
    var $38 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($37, $cx, $id, $vp);
    var $_0 = $38;
    __label__ = 22;
    break;
   case 12:
    var $40 = __ZNK2js10StackFrame14functionScriptEv($fp);
    if ((HEAP8[$40 + 36 | 0] & 8) << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $46 = $vp | 0;
    var $st$1$0 = $46 | 0;
    HEAP32[$st$1$0 >> 2] = $_idx_val$0;
    var $st$1$1 = $46 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $_idx_val$1;
    var $_0 = 1;
    __label__ = 22;
    break;
   case 14:
    var $48 = __ZNK2js10StackFrame18canonicalActualArgEj($fp, $27);
    var $49 = $48 | 0;
    var $st$2$0 = $49 | 0;
    var $50$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $49 + 4 | 0;
    var $50$1 = HEAP32[$st$2$1 >> 2];
    var $51 = $vp | 0;
    HEAP32[$51 >> 2] = $50$0;
    HEAP32[$51 + 4 >> 2] = $50$1;
    var $_0 = 1;
    __label__ = 22;
    break;
   case 15:
    if ($31) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 1;
      __label__ = 22;
      break;
    }
   case 16:
    var $54 = $28 | 0;
    var $55 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($54, $cx, $id, $vp);
    var $_0 = $55;
    __label__ = 22;
    break;
   case 17:
    var $61 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $62 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $61);
    if (($62 | 0) == 0) {
      var $_0 = 1;
      __label__ = 22;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $65 = __ZNK2js10StackFrame12maybeArgsObjEv($fp);
    if (($65 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $68 = __ZNK2js15ArgumentsObject19hasOverriddenLengthEv($65);
    if ($68) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $70 = $65 | 0;
    var $71 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($70, $cx, $id, $vp);
    var $_0 = $71;
    __label__ = 22;
    break;
   case 21:
    var $73 = __ZNK2js10StackFrame13numActualArgsEv($fp);
    __ZN2JS5Value8setInt32Ei($vp, $73);
    var $_0 = 1;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18js_GetArgsPropertyP9JSContextPN2js10StackFrameEiPN2JS5ValueE["X"] = 1;

function __ZNK2js10StackFrame12maybeArgsObjEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK2js10StackFrame10hasArgsObjEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $5 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2js10StackFrame7argsObjEv($this);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame14functionScriptEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK2js10StackFrame11isEvalFrameEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = HEAP32[$this + 8 >> 2];
    __label__ = 4;
    break;
   case 3:
    var $7 = __ZNK2js10StackFrame3funEv($this);
    var $8 = __ZNK10JSFunction6scriptEv($7);
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $atom) {
  var $1 = __ZL12ATOM_TO_JSIDP6JSAtom1293($atom);
  return ($1 | 0) == ($id | 0) & 1;
}

function __ZN2js15ArgumentsObject6createEP9JSContextjR8JSObject($cx, $argc, $callee) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $proto = __stackBase__;
    var $1 = $callee;
    var $2 = __ZNK8JSObject9getGlobalEv($1);
    var $3 = $cx;
    var $4 = $2 | 0;
    var $5 = $proto;
    var $6 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($3, $4, 1, $5, 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$proto >> 2];
    var $10 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($9, $cx, 0, 0);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, 2);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = __ZN2js10EmptyShape22getEmptyArgumentsShapeEP9JSContext($cx);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = ($argc << 3) + 8 | 0;
    var $21 = __ZN9JSContext7malloc_Ej($cx, $20);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $24 = $21;
    var $26 = $21 + 8 | 0;
    __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueEj1288($26, $argc);
    var $callee_idx_val = HEAP32[$callee + 24 >> 2];
    var $27 = __ZNK8JSObject18getFunctionPrivateEv($callee_idx_val);
    var $28 = __ZNK10JSFunction12inStrictModeEv($27);
    var $29 = $28 ? __ZN2js26StrictArgumentsObjectClassE : __ZN2js26NormalArgumentsObjectClassE;
    var $_idx_val = HEAP32[$9 + 20 >> 2];
    var $30 = __ZNK8JSObject9getParentEv($_idx_val);
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($13, $29, $10, $30, 0, 0);
    var $31 = $16 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($13, $31);
    var $32 = __ZN8JSObject11asArgumentsEv($13);
    __ZN2js15ArgumentsObject16setInitialLengthEj($32, $argc);
    __ZN2js15ArgumentsObject16setCalleeAndDataER8JSObjectPNS_13ArgumentsDataE($32, $callee, $24);
    var $_0 = $32;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10EmptyShape22getEmptyArgumentsShapeEP9JSContext($cx) {
  var $3 = HEAP32[$cx + 56 >> 2] + 748 | 0;
  var $4 = __ZN2js10EmptyShape6ensureEP9JSContextPNS_5ClassEPPS0_($cx, __ZN2js26NormalArgumentsObjectClassE, $3);
  return $4;
}

function __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueEj1288($vec, $len) {
  var $1 = $vec + ($len << 3) | 0;
  __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueES2_1378($vec, $1);
  return;
}

function __ZN2js15ArgumentsObject16setInitialLengthEj($this, $length) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $3 = $length << 1;
  __ZN2JSL10Int32ValueEi1375($1, $3);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, 0, $_idx_val$0, $_idx_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js15ArgumentsObject16setCalleeAndDataER8JSObjectPNS_13ArgumentsDataE($this, $callee, $data) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $3 = $data;
  __ZN2JSL12PrivateValueEPv1335($1, $3);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, 1, $_idx_val$0, $_idx_val$1);
  var $4 = $data | 0;
  __ZN2JS5Value9setObjectER8JSObject($4, $callee);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js10StackFrame25forEachCanonicalActualArgI6PutArgEEbT_jj($this, $op_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $op = __stackBase__;
    HEAP32[$op >> 2] = $op_0;
    var $1 = __ZNK2js10StackFrame3funEv($this);
    var $3 = HEAPU16[$1 + 56 >> 1];
    var $4 = $3 & 65535;
    var $5 = __ZNK2js10StackFrame13formalArgsEndEv($this);
    var $6 = __ZNK2js10StackFrame13numActualArgsEv($this);
    var $8 = $5 + (-$4 << 3) | 0;
    if ($6 >>> 0 > $4 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    if ($3 << 16 >> 16 == 0) {
      var $_1_lcssa = 0;
      __label__ = 6;
      break;
    } else {
      var $p1_013 = $8;
      var $_114 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    if (($6 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $p_06 = $8;
      var $_017 = 0;
      __label__ = 4;
      break;
    }
   case 4:
    var $_017;
    var $p_06;
    __ZN6PutArgclEjPN2JS5ValueE($op, $p_06);
    var $12 = $_017 + 1 | 0;
    if (($12 | 0) == ($6 | 0)) {
      __label__ = 9;
      break;
    } else {
      var $p_06 = $p_06 + 8 | 0;
      var $_017 = $12;
      __label__ = 4;
      break;
    }
   case 5:
    var $_114;
    var $p1_013;
    __ZN6PutArgclEjPN2JS5ValueE($op, $p1_013);
    var $14 = $_114 + 1 | 0;
    if (($14 | 0) == ($4 | 0)) {
      var $_1_lcssa = $4;
      __label__ = 6;
      break;
    } else {
      var $p1_013 = $p1_013 + 8 | 0;
      var $_114 = $14;
      __label__ = 5;
      break;
    }
   case 6:
    var $_1_lcssa;
    if ($_1_lcssa >>> 0 < $6 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $_29 = $_1_lcssa;
    var $p2_010 = $5 + (-2 - $4 - $6 + $_1_lcssa << 3) | 0;
    __label__ = 8;
    break;
   case 8:
    var $p2_010;
    var $_29;
    __ZN6PutArgclEjPN2JS5ValueE($op, $p2_010);
    var $20 = $_29 + 1 | 0;
    if (($20 | 0) == ($6 | 0)) {
      __label__ = 9;
      break;
    } else {
      var $_29 = $20;
      var $p2_010 = $p2_010 + 8 | 0;
      __label__ = 8;
      break;
    }
   case 9:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN6PutArgC1EPN2JS5ValueE($this, $dst) {
  __ZN6PutArgC2EPN2JS5ValueE($this, $dst);
  return;
}

function __Z16js_PutArgsObjectPN2js10StackFrameE($fp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2js10StackFrame7argsObjEv($fp);
    var $_idx_val = HEAP32[$2 + 4 >> 2];
    var $4 = __ZNK8JSObject17isNormalArgumentsEv($_idx_val);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZNK2js15ArgumentsObject4dataEv($2);
    var $7 = $6 + 8 | 0;
    __ZN6PutArgC1EPN2JS5ValueE($1, $7);
    var $_0_val = HEAP32[$1 >> 2];
    __ZN2js10StackFrame25forEachCanonicalActualArgI6PutArgEEbT_jj($fp, $_0_val);
    var $8 = $2;
    __ZN2js15ArgumentsObject13setStackFrameEPNS_10StackFrameE($8, 0);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16args_delPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN8JSObject11asArgumentsEv($obj);
    var $3 = _JSID_IS_INT1285($id);
    if (($3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = _JSID_TO_INT1286($id);
    var $7 = __ZNK2js15ArgumentsObject13initialLengthEv($2);
    if ($6 >>> 0 < $7 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    __ZN2JSL10MagicValueE10JSWhyMagic1374($1);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN2js15ArgumentsObject10setElementEjRKN2JS5ValueE($2, $6, $_idx_val$0, $_idx_val$1);
    __label__ = 8;
    break;
   case 4:
    var $12 = HEAP32[$cx + 52 >> 2];
    var $15 = HEAP32[$12 + 210256 >> 2] | 0;
    var $16 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $15);
    if (($16 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js15ArgumentsObject20markLengthOverriddenEv($2);
    __label__ = 8;
    break;
   case 6:
    var $22 = HEAP32[$12 + 210192 >> 2] | 0;
    var $23 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $22);
    if (($23 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $26 = $2 | 0;
    var $27 = __ZN8JSObject17asNormalArgumentsEv($26);
    __ZN2js21NormalArgumentsObject11clearCalleeEv($27);
    __label__ = 8;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14args_enumerateP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $1 = __ZN8JSObject17asNormalArgumentsEv($obj);
    var $2 = $1 | 0;
    var $3 = __ZNK2js15ArgumentsObject13initialLengthEv($2);
    var $4 = $cx;
    var $5 = $1;
    var $6 = $cx + 52 | 0;
    var $i_0 = -2;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if (($i_0 | 0) == ($3 | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($i_0 | 0) == -2) {
      __label__ = 4;
      break;
    } else if (($i_0 | 0) == -1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $14 = HEAP32[HEAP32[$6 >> 2] + 210256 >> 2] | 0;
    var $15 = __ZL12ATOM_TO_JSIDP6JSAtom1293($14);
    var $25 = $15;
    __label__ = 7;
    break;
   case 5:
    var $20 = HEAP32[HEAP32[$6 >> 2] + 210192 >> 2] | 0;
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom1293($20);
    var $25 = $21;
    __label__ = 7;
    break;
   case 6:
    var $23 = _INT_TO_JSID1373($i_0);
    var $25 = $23;
    __label__ = 7;
    break;
   case 7:
    var $25;
    var $26 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($4, $5, $25, $pobj, $prop);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12args_resolveP9JSContextP8JSObjectijPS2_($cx, $obj, $id, $flags, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $undef = __stackBase__;
    HEAP32[$objp >> 2] = 0;
    var $1 = __ZN8JSObject17asNormalArgumentsEv($obj);
    var $2 = _JSID_IS_INT1285($id);
    if (($2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = _JSID_TO_INT1286($id);
    var $6 = $1 | 0;
    var $7 = __ZNK2js15ArgumentsObject13initialLengthEv($6);
    if ($5 >>> 0 < $7 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 10;
      break;
    }
   case 3:
    var $10 = __ZNK2js15ArgumentsObject7elementEj($6, $5);
    var $_idx = $10 | 0;
    var $st$2$0 = $_idx | 0;
    var $_idx_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAP32[$st$2$1 >> 2];
    var $11 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx_val$0, $_idx_val$1);
    if ($11) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      var $attrs_0 = 193;
      __label__ = 8;
      break;
    }
   case 4:
    var $14 = HEAP32[$cx + 52 >> 2];
    var $17 = HEAP32[$14 + 210256 >> 2] | 0;
    var $18 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $17);
    if (($18 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $21 = $1 | 0;
    var $22 = __ZNK2js15ArgumentsObject19hasOverriddenLengthEv($21);
    if ($22) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      var $attrs_0 = 192;
      __label__ = 8;
      break;
    }
   case 6:
    var $26 = HEAP32[$14 + 210192 >> 2] | 0;
    var $27 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $26);
    if (($27 | 0) == 0) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $30 = __ZNK2js21NormalArgumentsObject6calleeEv($1);
    var $_idx1 = $30 | 0;
    var $st$2$0 = $_idx1 | 0;
    var $_idx1_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx1 + 4 | 0;
    var $_idx1_val$1 = HEAP32[$st$2$1 >> 2];
    var $31 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx1_val$0, $_idx1_val$1);
    if ($31) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      var $attrs_0 = 192;
      __label__ = 8;
      break;
    }
   case 8:
    var $attrs_0;
    __ZN2JSL14UndefinedValueEv1350($undef);
    var $33 = $cx;
    var $34 = $1;
    var $35 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($33, $34, $id, $undef, 108, 110, $attrs_0);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    HEAP32[$objp >> 2] = $1 | 0;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12args_resolveP9JSContextP8JSObjectijPS2_["X"] = 1;

function __ZL13args_finalizeP9JSContextP8JSObject($cx, $obj) {
  var $1 = __ZN8JSObject11asArgumentsEv($obj);
  var $2 = __ZNK2js15ArgumentsObject4dataEv($1);
  var $3 = $2;
  __ZN9JSContext5free_EPv($3);
  return;
}

function __ZL10args_traceP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject11asArgumentsEv($obj);
    var $2 = __ZNK2js15ArgumentsObject7onTraceEv($1);
    if ($2) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2js15ArgumentsObject4dataEv($1);
    var $_idx = $4 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $5 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $7);
    __label__ = 4;
    break;
   case 4:
    var $9 = __ZNK2js15ArgumentsObject13initialLengthEv($1);
    var $10 = $4 + 8 | 0;
    __ZN2js2gc14MarkValueRangeEP8JSTracerjPKN2JS5ValueEPKc($trc, $9, $10);
    var $_idx2_val = HEAP32[$1 + 24 >> 2];
    __ZL18MaybeMarkGeneratorP8JSTracerP8JSObject($trc, $_idx2_val);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20strictargs_enumerateP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $1 = __ZN8JSObject17asStrictArgumentsEv($obj);
    var $2 = $cx + 52 | 0;
    var $6 = HEAP32[HEAP32[$2 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12ATOM_TO_JSIDP6JSAtom1293($6);
    var $8 = $cx;
    var $9 = $1;
    var $10 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($8, $9, $7, $pobj, $prop);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $16 = HEAP32[HEAP32[$2 >> 2] + 210192 >> 2] | 0;
    var $17 = __ZL12ATOM_TO_JSIDP6JSAtom1293($16);
    var $18 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($8, $9, $17, $pobj, $prop);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $24 = HEAP32[HEAP32[$2 >> 2] + 210196 >> 2] | 0;
    var $25 = __ZL12ATOM_TO_JSIDP6JSAtom1293($24);
    var $26 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($8, $9, $25, $pobj, $prop);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $29 = $1 | 0;
    var $30 = __ZNK2js15ArgumentsObject13initialLengthEv($29);
    var $i_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_0;
    if ($i_0 >>> 0 < $30 >>> 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 6:
    var $34 = _INT_TO_JSID1373($i_0);
    var $35 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($8, $9, $34, $pobj, $prop);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 5;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18strictargs_resolveP9JSContextP8JSObjectijPS2_($cx, $obj, $id, $flags, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $undef = __stackBase__;
    HEAP32[$objp >> 2] = 0;
    var $1 = __ZN8JSObject17asStrictArgumentsEv($obj);
    var $2 = _JSID_IS_INT1285($id);
    if (($2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = _JSID_TO_INT1286($id);
    var $6 = $1 | 0;
    var $7 = __ZNK2js15ArgumentsObject13initialLengthEv($6);
    if ($5 >>> 0 < $7 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 3:
    var $10 = __ZNK2js15ArgumentsObject7elementEj($6, $5);
    var $_idx = $10 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $11 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx_val$0, $_idx_val$1);
    if ($11) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      var $setter_0 = 106;
      var $getter_0 = 104;
      var $attrs_0 = 193;
      __label__ = 9;
      break;
    }
   case 4:
    var $14 = HEAPU32[$cx + 52 >> 2];
    var $17 = HEAP32[$14 + 210256 >> 2] | 0;
    var $18 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $17);
    if (($18 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $21 = $1 | 0;
    var $22 = __ZNK2js15ArgumentsObject19hasOverriddenLengthEv($21);
    if ($22) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      var $setter_0 = 106;
      var $getter_0 = 104;
      var $attrs_0 = 192;
      __label__ = 9;
      break;
    }
   case 6:
    var $26 = HEAP32[$14 + 210192 >> 2] | 0;
    var $27 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $26);
    if (($27 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $32 = HEAP32[$14 + 210196 >> 2] | 0;
    var $33 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $32);
    if (($33 | 0) == 0) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $36 = $1 | 0;
    var $37 = __ZNK8JSObject17getThrowTypeErrorEv($36);
    var $38 = __ZN2jsL16CastAsPropertyOpEP8JSObject1357($37);
    var $39 = __ZN2jsL22CastAsStrictPropertyOpEP8JSObject1358($37);
    var $setter_0 = $39;
    var $getter_0 = $38;
    var $attrs_0 = 116;
    __label__ = 9;
    break;
   case 9:
    var $attrs_0;
    var $getter_0;
    var $setter_0;
    __ZN2JSL14UndefinedValueEv1350($undef);
    var $41 = $cx;
    var $42 = $1;
    var $43 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($41, $42, $id, $undef, $getter_0, $setter_0, $attrs_0);
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    HEAP32[$objp >> 2] = $1 | 0;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18strictargs_resolveP9JSContextP8JSObjectijPS2_["X"] = 1;

function __ZN2js19CreateFunCallObjectEP9JSContextPNS_10StackFrameE($cx, $fp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2js10StackFrame10scopeChainEv($fp);
    var $3 = __ZNK2js10StackFrame3funEv($fp);
    var $4 = __ZN2jsL20CallObjectLambdaNameEP10JSFunction($3);
    if (($4 | 0) == 0) {
      var $scopeChain_0 = $2;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZL16NewDeclEnvObjectP9JSContextPN2js10StackFrameE($cx, $fp);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZL12ATOM_TO_JSIDP6JSAtom1293($4);
    var $11 = __ZNK2js10StackFrame6calleeEv($fp);
    __ZN2JSL11ObjectValueER8JSObject1294($1, $11);
    var $12 = $cx;
    var $13 = $7;
    var $14 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($12, $13, $10, $1, 0, 0, 6, 0, 0, 0);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      var $scopeChain_0 = $7;
      __label__ = 4;
      break;
    }
   case 4:
    var $scopeChain_0;
    var $17 = __ZNK2js10StackFrame6scriptEv($fp);
    var $18 = __ZNK2js10StackFrame6calleeEv($fp);
    var $19 = __ZN2js10CallObject6createEP9JSContextP8JSScriptR8JSObjectPS5_($cx, $17, $scopeChain_0, $18);
    var $20 = $19;
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js10CallObject13setStackFrameEPNS_10StackFrameE($20, $fp);
    __ZN2js10StackFrame27setScopeChainWithOwnCallObjERNS_10CallObjectE($fp, $20);
    var $_0 = $20;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16NewDeclEnvObjectP9JSContextPN2js10StackFrameE($cx, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, 2);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js10EmptyShape20getEmptyDeclEnvShapeEP9JSContext($cx);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js10StackFrame10scopeChainEv($fp);
    var $8 = $fp;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($1, __ZN2js12DeclEnvClassE, __ZN2js5types15emptyTypeObjectE, $7, $8, 0);
    var $9 = $4 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($1, $9);
    var $_0 = $1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12ATOM_TO_JSIDP6JSAtom1293($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj1372($1);
  return $2;
}

function __ZN2JSL11ObjectValueER8JSObject1294($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN2js10CallObject13setStackFrameEPNS_10StackFrameE($this, $frame) {
  var $1 = $this | 0;
  var $2 = $frame;
  __ZN8JSObject10setPrivateEPv($1, $2);
  return;
}

function __ZN2js20CreateEvalCallObjectEP9JSContextPNS_10StackFrameE($cx, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame6scriptEv($fp);
    var $2 = __ZNK2js10StackFrame10scopeChainEv($fp);
    var $3 = __ZN2js10CallObject6createEP9JSContextP8JSScriptR8JSObjectPS5_($cx, $1, $2, 0);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js10CallObject13setStackFrameEPNS_10StackFrameE($4, $fp);
    __ZN2js10StackFrame27setScopeChainWithOwnCallObjERNS_10CallObjectE($fp, $4);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js8Bindings9countArgsEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZeqRK8JSObjectS1_($lhs, $rhs) {
  return ($lhs | 0) == ($rhs | 0);
}

function __ZN8JSObject16hasMethodBarrierEv($this_0_2_val) {
  return ($this_0_2_val & 32 | 0) != 0;
}

function __ZNK2js5Shape7hasSlotEv($this_0_7_val) {
  return ($this_0_7_val & 64) << 24 >> 24 == 0;
}

function __ZN10JSFunction14compiledFunObjEv($this) {
  return $this | 0;
}

function __Z16js_PutCallObjectPN2js10StackFrameE($fp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $fp;
    var $3 = __ZNK2js10StackFrame7callObjEv($2);
    var $4 = $3;
    var $5 = __ZN8JSObject6asCallEv($4);
    var $6 = $5;
    var $fp_idx_val = HEAP32[$fp >> 2];
    var $7 = __ZNK2js10StackFrame10hasArgsObjEv($fp_idx_val);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $9 = __ZNK2js10StackFrame17hasOverriddenArgsEv($fp_idx_val);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2js10StackFrame7argsObjEv($fp);
    var $12 = $11 | 0;
    __ZN2JSL11ObjectValueER8JSObject1294($1, $12);
    var $_idx8 = $1 | 0;
    var $_idx8_val$0 = HEAP32[$_idx8 >> 2];
    var $_idx8_val$1 = HEAP32[$_idx8 + 4 >> 2];
    __ZN2js10CallObject12setArgumentsERKN2JS5ValueE($6, $_idx8_val$0, $_idx8_val$1);
    __label__ = 4;
    break;
   case 4:
    __Z16js_PutArgsObjectPN2js10StackFrameE($fp);
    __label__ = 5;
    break;
   case 5:
    var $15 = __ZNK2js10StackFrame6scriptEv($fp);
    var $16 = __ZNK2js10CallObject9isForEvalEv($6);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $_idx6_val = HEAP16[$15 + 70 >> 1];
    var $18 = __ZNK2js8Bindings9countVarsEv($_idx6_val);
    var $19 = $18 & 65535;
    var $20 = __ZNK2js10StackFrame5slotsEv($2);
    __ZN2js10CallObject10copyValuesEjPN2JS5ValueEjS3_($6, 0, 0, $19, $20);
    __label__ = 21;
    break;
   case 7:
    var $22 = __ZNK2js10StackFrame3funEv($fp);
    var $_idx2_val = HEAPU16[$15 + 68 >> 1];
    var $_idx3_val = HEAPU16[$15 + 70 >> 1];
    var $23 = __ZNK2js8Bindings16countArgsAndVarsEv($_idx2_val, $_idx3_val);
    if (($23 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $26 = __ZNK10JSFunction6scriptEv($22);
    if ((HEAP8[$26 + 36 | 0] & 32) << 24 >> 24 == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = __ZNK2js8Bindings9countArgsEv($_idx2_val);
    var $33 = __ZNK2js8Bindings9countVarsEv($_idx3_val);
    var $34 = $32 & 65535;
    var $35 = $33 & 65535;
    var $36 = __ZNK2js10StackFrame10formalArgsEv($fp);
    var $37 = __ZNK2js10StackFrame5slotsEv($2);
    __ZN2js10CallObject10copyValuesEjPN2JS5ValueEjS3_($6, $34, $36, $35, $37);
    __label__ = 16;
    break;
   case 10:
    var $39 = $26 + 48 | 0;
    var $40 = HEAPU16[$39 >> 1];
    if ($40 << 16 >> 16 == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $42 = $40 & 65535;
    var $_idx9 = $26 + 88 | 0;
    var $i_02 = 0;
    __label__ = 12;
    break;
   case 12:
    var $i_02;
    var $_idx9_val = HEAP32[$_idx9 >> 2];
    var $44 = __ZN8JSScript12getClosedArgEj($_idx9_val, $i_02);
    var $45 = __ZNK2js10StackFrame9formalArgEj($fp, $44);
    var $_idx10 = $45 | 0;
    var $st$5$0 = $_idx10 | 0;
    var $_idx10_val$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $_idx10 + 4 | 0;
    var $_idx10_val$1 = HEAP32[$st$5$1 >> 2];
    __ZN2js10CallObject6setArgEjRKN2JS5ValueE($6, $44, $_idx10_val$0, $_idx10_val$1);
    var $46 = $i_02 + 1 | 0;
    if (($46 | 0) == ($42 | 0)) {
      __label__ = 13;
      break;
    } else {
      var $i_02 = $46;
      __label__ = 12;
      break;
    }
   case 13:
    var $48 = HEAPU16[$26 + 50 >> 1];
    if ($48 << 16 >> 16 == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $50 = __ZNK2js10StackFrame5slotsEv($2);
    var $51 = $48 & 65535;
    var $_idx12 = $26 + 88 | 0;
    var $i2_01 = 0;
    __label__ = 15;
    break;
   case 15:
    var $i2_01;
    var $_idx11_val = HEAP16[$39 >> 1];
    var $_idx12_val = HEAP32[$_idx12 >> 2];
    var $52 = __ZN8JSScript12getClosedVarEj($_idx11_val, $_idx12_val, $i2_01);
    var $_idx13 = $50 + ($52 << 3) | 0;
    var $st$5$0 = $_idx13 | 0;
    var $_idx13_val$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $_idx13 + 4 | 0;
    var $_idx13_val$1 = HEAP32[$st$5$1 >> 2];
    __ZN2js10CallObject6setVarEjRKN2JS5ValueE($6, $52, $_idx13_val$0, $_idx13_val$1);
    var $53 = $i2_01 + 1 | 0;
    if (($53 | 0) == ($51 | 0)) {
      __label__ = 16;
      break;
    } else {
      var $i2_01 = $53;
      __label__ = 15;
      break;
    }
   case 16:
    var $_idx1_val_idx_val = HEAP32[HEAP32[$26 + 100 >> 2] + 12 >> 2];
    var $56 = __ZNK8JSScript7nestingEv($_idx1_val_idx_val);
    if (($56 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    if ((HEAP8[$26 + 37 | 0] & 16) << 24 >> 24 == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $64 = __ZN2js10CallObject8argArrayEv($6);
    var $65 = $56 + 16 | 0;
    HEAP32[$65 >> 2] = $64;
    var $66 = __ZN2js10CallObject8varArrayEv($6);
    var $67 = $56 + 20 | 0;
    HEAP32[$67 >> 2] = $66;
    __label__ = 19;
    break;
   case 19:
    var $69 = $22;
    var $70 = __Z16js_IsNamedLambdaP10JSFunction($69);
    if ($70) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $_idx_val = HEAP32[$5 + 20 >> 2];
    var $72 = __ZNK8JSObject9getParentEv($_idx_val);
    __ZN8JSObject10setPrivateEPv($72, 0);
    __label__ = 21;
    break;
   case 21:
    __ZN2js10CallObject13setStackFrameEPNS_10StackFrameE($6, 0);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z16js_PutCallObjectPN2js10StackFrameE["X"] = 1;

function __ZN2js10CallObject12setArgumentsERKN2JS5ValueE($this, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  var $1 = $this | 0;
  __ZN8JSObject12setFixedSlotEjRKN2JS5ValueE($1, 1, $v_0_0_0_val$0, $v_0_0_0_val$1);
  return;
}

function __ZNK2js10CallObject9isForEvalEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK8JSObject12getFixedSlotEj($1, 0);
  var $_idx = $2 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $3 = __ZNK2JS5Value6isNullEv($_idx_val$0, $_idx_val$1);
  return $3;
}

function __ZN2js10CallObject10copyValuesEjPN2JS5ValueEjS3_($this, $nargs, $argv, $nvars, $slots) {
  var $1 = $this;
  __ZN8JSObject13copySlotRangeEjPKN2JS5ValueEj($1, 2, $argv, $nargs);
  var $2 = $nargs + 2 | 0;
  __ZN8JSObject13copySlotRangeEjPKN2JS5ValueEj($1, $2, $slots, $nvars);
  return;
}

function __ZN2js10CallObject6setArgEjRKN2JS5ValueE($this, $i, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  var $1 = $this | 0;
  var $2 = $i + 2 | 0;
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($1, $2, $v_0_0_0_val$0, $v_0_0_0_val$1);
  return;
}

function __ZN2js10CallObject6setVarEjRKN2JS5ValueE($this, $i, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  var $1 = __ZNK2js10CallObject17getCalleeFunctionEv($this);
  var $2 = $this | 0;
  var $7 = $i + 2 + (HEAPU16[$1 + 56 >> 1] & 65535) | 0;
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, $7, $v_0_0_0_val$0, $v_0_0_0_val$1);
  return;
}

function __ZN2js10CallObject8argArrayEv($this) {
  var $1 = $this | 0;
  var $2 = __ZN8JSObject14getSlotAddressEj($1, 2);
  return $2;
}

function __ZN2js10CallObject8varArrayEv($this) {
  var $1 = __ZNK2js10CallObject17getCalleeFunctionEv($this);
  var $2 = $this | 0;
  var $6 = (HEAPU16[$1 + 56 >> 1] & 65535) + 2 | 0;
  var $7 = __ZN8JSObject14getSlotAddressEj($2, $6);
  return $7;
}

function __ZN2js10GetCallArgEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject6asCallEv($obj);
    var $2 = $1;
    var $3 = _JSID_TO_INT1286($id);
    var $4 = $3 & 65535;
    var $5 = __ZNK2js10CallObject15maybeStackFrameEv($2);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK2js10StackFrame9formalArgEj($5, $4);
    var $9 = $8 | 0;
    var $st$2$0 = $9 | 0;
    var $10$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $9 + 4 | 0;
    var $10$1 = HEAP32[$st$2$1 >> 2];
    var $11 = $vp | 0;
    var $st$7$0 = $11 | 0;
    HEAP32[$st$7$0 >> 2] = $10$0;
    var $st$7$1 = $11 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $10$1;
    __label__ = 4;
    break;
   case 3:
    var $13 = __ZNK2js10CallObject3argEj($2, $4);
    var $14 = $13 | 0;
    var $st$2$0 = $14 | 0;
    var $15$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $14 + 4 | 0;
    var $15$1 = HEAP32[$st$2$1 >> 2];
    var $16 = $vp | 0;
    var $st$7$0 = $16 | 0;
    HEAP32[$st$7$0 >> 2] = $15$0;
    var $st$7$1 = $16 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $15$1;
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10CallObject15maybeStackFrameEv($this) {
  var $_idx_val = HEAP32[$this + 24 >> 2];
  var $1 = __ZNK8JSObject10getPrivateEv($_idx_val);
  return $1;
}

function __ZNK2js10CallObject3argEj($this, $i) {
  var $1 = $this | 0;
  var $2 = $i + 2 | 0;
  var $3 = __ZNK8JSObject7getSlotEj($1, $2);
  return $3;
}

function __ZN2js10SetCallArgEP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject6asCallEv($obj);
    var $2 = $1;
    var $3 = _JSID_TO_INT1286($id);
    var $4 = $3 & 65535;
    var $5 = __ZNK2js10CallObject15maybeStackFrameEv($2);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK2js10StackFrame9formalArgEj($5, $4);
    var $9 = $vp | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $8 | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    __label__ = 4;
    break;
   case 3:
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    __ZN2js10CallObject6setArgEjRKN2JS5ValueE($2, $4, $vp_idx_val$0, $vp_idx_val$1);
    __label__ = 4;
    break;
   case 4:
    var $14 = __ZNK2js10CallObject17getCalleeFunctionEv($2);
    var $15 = __ZNK10JSFunction6scriptEv($14);
    var $16 = __ZN8JSScript14ensureHasTypesEP9JSContextP10JSFunction($15, $cx, $14);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js5types10TypeScript11SetArgumentEP9JSContextP8JSScriptjRKN2JS5ValueE($cx, $15, $4, $vp);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10CallObject17getCalleeFunctionEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK8JSObject12getFixedSlotEj($1, 0);
  var $_idx = $2 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $3 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
  var $_idx1_val = HEAP32[$3 + 24 >> 2];
  var $4 = __ZNK8JSObject18getFunctionPrivateEv($_idx1_val);
  return $4;
}

function __ZN8JSScript14ensureHasTypesEP9JSContextP10JSFunction($this, $cx, $fun) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 100 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $7 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZN8JSScript9makeTypesEP9JSContextP10JSFunction($this, $cx, $fun);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript11SetArgumentEP9JSContextP8JSScriptjRKN2JS5ValueE($cx, $script, $arg, $value) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $2 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $value_idx = $value | 0;
    var $value_idx_val$0 = HEAP32[$value_idx >> 2];
    var $value_idx_val$1 = HEAP32[$value_idx + 4 >> 2];
    __ZN2js5types12GetValueTypeEP9JSContextRKN2JS5ValueE($1, $value_idx_val$0, $value_idx_val$1);
    var $_0_val = HEAP32[$1 >> 2];
    __ZN2js5types10TypeScript11SetArgumentEP9JSContextP8JSScriptjNS0_4TypeE($cx, $script, $arg, $_0_val);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12GetCallUpvarEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = __ZN8JSObject6asCallEv($obj);
  var $2 = $1;
  var $3 = _JSID_TO_INT1286($id);
  var $4 = $3 & 65535;
  var $5 = __ZNK2js10CallObject9getCalleeEv($2);
  var $6 = __ZN8JSObject19getFlatClosureUpvarEj($5, $4);
  var $7 = $6 | 0;
  var $8$0 = HEAP32[$7 >> 2];
  var $8$1 = HEAP32[$7 + 4 >> 2];
  var $9 = $vp | 0;
  HEAP32[$9 >> 2] = $8$0;
  HEAP32[$9 + 4 >> 2] = $8$1;
  return 1;
}

function __ZNK2js10CallObject9getCalleeEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK8JSObject12getFixedSlotEj($1, 0);
  var $_idx = $2 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $3 = __ZNK2JS5Value14toObjectOrNullEv($_idx_val$0, $_idx_val$1);
  return $3;
}

function __ZN8JSObject19getFlatClosureUpvarEj($this, $i) {
  var $1 = __ZNK8JSObject20getFlatClosureUpvarsEv($this);
  return $1 + ($i << 3) | 0;
}

function __ZN2js12SetCallUpvarEP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var $1 = __ZN8JSObject6asCallEv($obj);
  var $2 = $1;
  var $3 = _JSID_TO_INT1286($id);
  var $4 = $3 & 65535;
  var $5 = __ZNK2js10CallObject9getCalleeEv($2);
  var $vp_idx = $vp | 0;
  var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
  var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
  __ZN8JSObject19setFlatClosureUpvarEjRKN2JS5ValueE($5, $4, $vp_idx_val$0, $vp_idx_val$1);
  return 1;
}

function __ZN8JSObject19setFlatClosureUpvarEjRKN2JS5ValueE($this, $i, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  var $1 = __ZNK8JSObject20getFlatClosureUpvarsEv($this);
  var $2 = $1 + ($i << 3) | 0;
  HEAP32[$2 >> 2] = $v_0_0_0_val$0;
  HEAP32[$2 + 4 >> 2] = $v_0_0_0_val$1;
  return;
}

function __ZN2js10GetCallVarEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject6asCallEv($obj);
    var $2 = $1;
    var $3 = _JSID_TO_INT1286($id);
    var $4 = $3 & 65535;
    var $5 = __ZNK2js10CallObject15maybeStackFrameEv($2);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZN2js10StackFrame7varSlotEj($5, $4);
    var $9 = $8 | 0;
    var $st$2$0 = $9 | 0;
    var $10$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $9 + 4 | 0;
    var $10$1 = HEAP32[$st$2$1 >> 2];
    var $11 = $vp | 0;
    var $st$7$0 = $11 | 0;
    HEAP32[$st$7$0 >> 2] = $10$0;
    var $st$7$1 = $11 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $10$1;
    __label__ = 4;
    break;
   case 3:
    var $13 = __ZNK2js10CallObject3varEj($2, $4);
    var $14 = $13 | 0;
    var $st$2$0 = $14 | 0;
    var $15$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $14 + 4 | 0;
    var $15$1 = HEAP32[$st$2$1 >> 2];
    var $16 = $vp | 0;
    var $st$7$0 = $16 | 0;
    HEAP32[$st$7$0 >> 2] = $15$0;
    var $st$7$1 = $16 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $15$1;
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame7varSlotEj($this, $i) {
  var $1 = $this;
  var $2 = __ZNK2js10StackFrame5slotsEv($1);
  return $2 + ($i << 3) | 0;
}

function __ZNK2js10CallObject3varEj($this, $i) {
  var $1 = __ZNK2js10CallObject17getCalleeFunctionEv($this);
  var $2 = $this | 0;
  var $7 = $i + 2 + (HEAPU16[$1 + 56 >> 1] & 65535) | 0;
  var $8 = __ZNK8JSObject7getSlotEj($2, $7);
  return $8;
}

function __ZN2js10SetCallVarEP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject6asCallEv($obj);
    var $2 = $1;
    var $3 = _JSID_TO_INT1286($id);
    var $4 = $3 & 65535;
    var $5 = __ZNK2js10CallObject15maybeStackFrameEv($2);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZN2js10StackFrame7varSlotEj($5, $4);
    var $9 = $vp | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $8 | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    __label__ = 4;
    break;
   case 3:
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    __ZN2js10CallObject6setVarEjRKN2JS5ValueE($2, $4, $vp_idx_val$0, $vp_idx_val$1);
    __label__ = 4;
    break;
   case 4:
    var $14 = __ZNK2js10CallObject17getCalleeFunctionEv($2);
    var $15 = __ZNK10JSFunction6scriptEv($14);
    var $16 = __ZN8JSScript14ensureHasTypesEP9JSContextP10JSFunction($15, $cx, $14);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js5types10TypeScript8SetLocalEP9JSContextP8JSScriptjRKN2JS5ValueE($cx, $15, $4, $vp);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript8SetLocalEP9JSContextP8JSScriptjRKN2JS5ValueE($cx, $script, $local, $value) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $2 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $value_idx = $value | 0;
    var $value_idx_val$0 = HEAP32[$value_idx >> 2];
    var $value_idx_val$1 = HEAP32[$value_idx + 4 >> 2];
    __ZN2js5types12GetValueTypeEP9JSContextRKN2JS5ValueE($1, $value_idx_val$0, $value_idx_val$1);
    var $_0_val = HEAP32[$1 >> 2];
    __ZN2js5types10TypeScript8SetLocalEP9JSContextP8JSScriptjNS0_4TypeE($cx, $script, $local, $_0_val);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12call_resolveP9JSContextP8JSObjectijPS2_($cx, $obj, $id, $flags, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZL12JSID_IS_ATOMi1319($id);
    if (($2 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN8JSObject6asCallEv($obj);
    var $6 = $5;
    var $7 = __ZNK2js10CallObject9getCalleeEv($6);
    if (($7 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = HEAP32[HEAP32[$cx + 52 >> 2] + 210176 >> 2] | 0;
    var $15 = __ZL12ATOM_TO_JSIDP6JSAtom1293($14);
    if (($15 | 0) == ($id | 0)) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 4:
    __ZN2JSL14UndefinedValueEv1350($1);
    var $18 = $cx;
    var $19 = $obj;
    var $20 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($18, $19, $id, $1, 112, 114, 69, 0, 0, 2);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10call_traceP8JSTracerP8JSObject($trc, $obj) {
  var $obj_idx_val = HEAP32[$obj + 24 >> 2];
  __ZL18MaybeMarkGeneratorP8JSTracerP8JSObject($trc, $obj_idx_val);
  return;
}

function __ZN2js10StackFrame20getValidCalleeObjectEP9JSContextPN2JS5ValueE($this, $cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $clone = __stackBase__;
    var $this_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK2js10StackFrame15isFunctionFrameEv($this_idx_val);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value7setNullEv($vp);
    var $_0 = 1;
    __label__ = 25;
    break;
   case 3:
    var $4 = __ZNK2js10StackFrame3funEv($this);
    var $5 = __ZNK2js10StackFrame6calleeEv($this);
    __ZN2JS5Value9setObjectER8JSObject($vp, $5);
    var $6 = __ZNK2js10StackFrame12functionThisEv($this);
    var $_idx = $6 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $7 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 25;
      break;
    }
   case 4:
    var $9 = __ZN10JSFunction14compiledFunObjEv($4);
    var $10 = __ZeqRK8JSObjectS1_($9, $5);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 25;
      break;
    }
   case 5:
    var $12 = __ZNK10JSFunction10methodAtomEv($4);
    if (($12 | 0) == 0) {
      var $_0 = 1;
      __label__ = 25;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $first_barriered_thisp_0 = 0;
    var $thisp_0 = $15;
    __label__ = 7;
    break;
   case 7:
    var $thisp_0;
    var $first_barriered_thisp_0;
    var $thisp_0_idx_val = HEAP32[$thisp_0 >> 2];
    var $17 = __ZNK8JSObject8isNativeEv($thisp_0_idx_val);
    if ($17) {
      __label__ = 8;
      break;
    } else {
      var $first_barriered_thisp_1 = $first_barriered_thisp_0;
      __label__ = 21;
      break;
    }
   case 8:
    var $thisp_0_idx6_val = HEAP32[$thisp_0 + 8 >> 2];
    var $19 = __ZN8JSObject16hasMethodBarrierEv($thisp_0_idx6_val);
    if ($19) {
      __label__ = 9;
      break;
    } else {
      var $first_barriered_thisp_1 = $first_barriered_thisp_0;
      __label__ = 21;
      break;
    }
   case 9:
    var $21 = __ZNK10JSFunction10methodAtomEv($4);
    var $22 = __ZL12ATOM_TO_JSIDP6JSAtom1293($21);
    var $23 = __ZN8JSObject12nativeLookupEP9JSContexti($thisp_0, $cx, $22);
    if (($23 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_idx3_val = HEAP8[$23 + 29 | 0];
    var $26 = __ZNK2js5Shape8isMethodEv($_idx3_val);
    if ($26) {
      __label__ = 11;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 11:
    var $28 = __ZNK2js5Shape12methodObjectEv($23);
    var $29 = __ZeqRK8JSObjectS1_($28, $5);
    if ($29) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $31 = __ZN8JSObject17methodReadBarrierEP9JSContextRKN2js5ShapeEPN2JS5ValueE($thisp_0, $cx, $23, $vp);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $vp_idx = $vp | 0;
    var $st$1$0 = $vp_idx | 0;
    var $vp_idx_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $vp_idx + 4 | 0;
    var $vp_idx_val$1 = HEAP32[$st$1$1 >> 2];
    var $34 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
    __ZN2js10StackFrame15overwriteCalleeER8JSObject($this, $34);
    var $_0 = 1;
    __label__ = 25;
    break;
   case 14:
    var $_idx5_val = HEAP8[$23 + 28 | 0];
    var $36 = __ZNK2js5Shape7hasSlotEv($_idx5_val);
    if ($36) {
      __label__ = 15;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 15:
    var $39 = HEAP32[$23 + 24 >> 2];
    var $40 = __ZNK8JSObject7getSlotEj($thisp_0, $39);
    var $41 = $40 | 0;
    var $42$0 = HEAP32[$41 >> 2];
    var $42$1 = HEAP32[$41 + 4 >> 2];
    var $43 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject1303($42$0, $42$1, $clone);
    if ($43) {
      __label__ = 16;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 16:
    var $45 = HEAP32[$clone >> 2];
    var $_idx2_val = HEAP32[$45 + 24 >> 2];
    var $46 = __ZNK8JSObject18getFunctionPrivateEv($_idx2_val);
    if (($46 | 0) == ($4 | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 17:
    var $49 = __ZNK8JSObject12hasMethodObjERKS_($45, $thisp_0);
    if ($49) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $51 = $vp | 0;
    var $st$1$0 = $51 | 0;
    HEAP32[$st$1$0 >> 2] = $42$0;
    var $st$1$1 = $51 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $42$1;
    __ZN2js10StackFrame15overwriteCalleeER8JSObject($this, $45);
    var $_0 = 1;
    __label__ = 25;
    break;
   case 19:
    if (($first_barriered_thisp_0 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      var $first_barriered_thisp_1 = $first_barriered_thisp_0;
      __label__ = 21;
      break;
    }
   case 20:
    var $first_barriered_thisp_1 = $thisp_0;
    __label__ = 21;
    break;
   case 21:
    var $first_barriered_thisp_1;
    var $thisp_0_idx4_val_idx_val = HEAP32[HEAP32[$thisp_0 + 36 >> 2] >> 2];
    var $56 = __ZNK8JSObject8getProtoEv($thisp_0_idx4_val_idx_val);
    if (($56 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      var $first_barriered_thisp_0 = $first_barriered_thisp_1;
      var $thisp_0 = $56;
      __label__ = 7;
      break;
    }
   case 22:
    if (($first_barriered_thisp_1 | 0) == 0) {
      var $_0 = 1;
      __label__ = 25;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $61 = __Z19CloneFunctionObjectP9JSContextP10JSFunction($cx, $4);
    if (($61 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    __ZN8JSObject12setMethodObjERS_($61, $first_barriered_thisp_1);
    __ZN2js10StackFrame15overwriteCalleeER8JSObject($this, $61);
    __ZN2JS5Value9setObjectER8JSObject($vp, $61);
    var $_0 = 1;
    __label__ = 25;
    break;
   case 25:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js10StackFrame20getValidCalleeObjectEP9JSContextPN2JS5ValueE["X"] = 1;

function __ZNK2js10StackFrame12functionThisEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK2js10StackFrame11isEvalFrameEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_pn = $this;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZNK2js10StackFrame10formalArgsEv($this);
    var $_pn = $5;
    __label__ = 4;
    break;
   case 4:
    var $_pn;
    return $_pn - 8 | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK10JSFunction10methodAtomEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP16[$this + 58 >> 1];
    var $1 = __ZNK10JSFunction8joinableEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $10 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $this | 0;
    var $4 = __ZNK8JSObject7getSlotEj($3, 0);
    var $_idx1 = $4 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $5 = __ZNK2JS5Value8isStringEv($_idx1_val$0, $_idx1_val$1);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $10 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZNK2JS5Value8toStringEv($_idx1_val$0, $_idx1_val$1);
    var $8 = __ZNK8JSString6asAtomEv($7);
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame15overwriteCalleeER8JSObject($this, $newCallee) {
  var $1 = __ZNK2js10StackFrame14mutableCalleevEv($this);
  __ZN2JS5Value9setObjectER8JSObject($1, $newCallee);
  return;
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject1303($v_0_0_0_val$0, $v_0_0_0_val$1, $funobj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    HEAP32[$funobj >> 2] = $3;
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZNK8JSObject10isFunctionEv($_idx_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject12hasMethodObjERKS_($this, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 28 >> 2];
    var $1 = __ZNK8JSObject8numSlotsEv($this_idx_val);
    if ($1 >>> 0 > 1) {
      __label__ = 2;
      break;
    } else {
      var $10 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject12getFixedSlotEj($this, 1);
    var $_idx = $4 | 0;
    var $_idx_val$0 = HEAPU32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $5 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $10 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $8 = __ZeqRK8JSObjectS1_($7, $obj);
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z20js_XDRFunctionObjectP10JSXDRStatePP8JSObject($xdr, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $firstword = __stackBase__;
    var $flagsword = __stackBase__ + 4;
    var $funNameBytes = __stackBase__ + 8;
    var $tvr = __stackBase__ + 12;
    var $script = __stackBase__ + 28;
    var $2 = HEAPU32[$xdr + 8 >> 2];
    var $3 = $xdr | 0;
    if ((HEAP32[$3 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[HEAP32[$objp >> 2] + 24 >> 2];
    var $8 = __ZNK8JSObject18getFunctionPrivateEv($_idx_val);
    var $_idx1 = $8 + 58 | 0;
    var $_idx1_val = HEAP16[$_idx1 >> 1];
    var $9 = __ZNK10JSFunction13isInterpretedEv($_idx1_val);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN16JSAutoByteStringC1Ev($funNameBytes);
    var $_idx2_val = HEAP32[$8 + 72 >> 2];
    var $11 = __ZN2js20GetFunctionNameBytesEP9JSContextP10JSFunctionP16JSAutoByteString($2, $_idx2_val, $funNameBytes);
    if (($11 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _JS_ReportErrorNumber($2, 4, 11, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $11, tempInt));
    __label__ = 5;
    break;
   case 5:
    var $funNameBytes_idx_val = HEAP32[$funNameBytes >> 2];
    __ZN16JSAutoByteStringD1Ev($funNameBytes_idx_val);
    var $_1 = 0;
    __label__ = 20;
    break;
   case 6:
    var $25 = (HEAP32[$8 + 72 >> 2] | 0) != 0 & 1 | (HEAPU16[$8 + 64 >> 1] & 65535) << 2;
    HEAP32[$firstword >> 2] = $25;
    var $32 = (HEAPU16[$8 + 56 >> 1] & 65535) << 16 | HEAPU16[$_idx1 >> 1] & 65535;
    HEAP32[$flagsword >> 2] = $32;
    var $fun_0 = $8;
    __label__ = 9;
    break;
   case 7:
    var $34 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($2, 0, 0, 0, 16384, 0, 0);
    if (($34 | 0) == 0) {
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $37 = $34 | 0;
    __ZN8JSObject11clearParentEv($37);
    __ZN8JSObject9clearTypeEv($37);
    var $fun_0 = $34;
    __label__ = 9;
    break;
   case 9:
    var $fun_0;
    var $39 = $fun_0 | 0;
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($tvr, $2, $39);
    var $40 = $xdr;
    var $41 = _JS_XDRUint32($40, $firstword);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ((HEAP32[$firstword >> 2] & 1 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $50 = _js_XDRAtom($40, $fun_0 + 72 | 0);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $53 = _JS_XDRUint32($40, $flagsword);
    if (($53 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if ((HEAP32[$3 >> 2] | 0) == 1) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    HEAP16[$fun_0 + 56 >> 1] = HEAPU32[$flagsword >> 2] >>> 16 & 65535;
    HEAP16[$fun_0 + 58 >> 1] = HEAP32[$flagsword >> 2] & 65535;
    HEAP16[$fun_0 + 64 >> 1] = HEAPU32[$firstword >> 2] >>> 2 & 65535;
    __label__ = 15;
    break;
   case 15:
    var $72 = $fun_0 + 60 | 0;
    var $73 = $72;
    var $74 = HEAP32[$73 >> 2];
    HEAP32[$script >> 2] = $74;
    var $75 = $xdr;
    var $76 = $script;
    var $77 = __Z12js_XDRScriptP10JSXDRStatePP8JSScript($75, $76);
    if (($77 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $_c = HEAP32[$script >> 2];
    HEAP32[$72 >> 2] = $_c;
    if ((HEAP32[$3 >> 2] | 0) == 1) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 1;
      __label__ = 19;
      break;
    }
   case 17:
    HEAP32[$objp >> 2] = $39;
    var $85 = HEAP32[$73 >> 2];
    var $86 = __ZN8JSScript15typeSetFunctionEP9JSContextP10JSFunctionb($85, $2, $fun_0, 0);
    if ($86) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 18:
    var $88 = __ZNK10JSFunction6scriptEv($fun_0);
    var $89 = $2;
    var $90 = $88;
    __Z20js_CallNewScriptHookP9JSContextP8JSScriptP10JSFunction($89, $90, $fun_0);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    __ZN2js16AutoObjectRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 20;
    break;
   case 20:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z20js_XDRFunctionObjectP10JSXDRStatePP8JSObject["X"] = 1;

function __ZN8JSObject11clearParentEv($this) {
  HEAP32[$this + 20 >> 2] = 0;
  return;
}

function __ZN8JSObject9clearTypeEv($this) {
  HEAP32[$this + 36 >> 2] = __ZN2js5types15emptyTypeObjectE;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($cx, $funobj, $native, $nargs, $flags, $parent, $atom) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($funobj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN8JSObject9setParentEPS_($funobj, $parent);
    var $_01 = $funobj;
    __label__ = 6;
    break;
   case 3:
    var $4 = __ZN2jsL11NewFunctionEP9JSContextP8JSObject($cx, $parent);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($native | 0) == 0) {
      var $_01 = $4;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = $4;
    var $10 = $cx;
    __ZN8JSObject16setSingletonTypeEP9JSContext($9, $10);
    var $_01 = $4;
    __label__ = 6;
    break;
   case 6:
    var $_01;
    var $12 = $_01;
    HEAP16[$_01 + 56 >> 1] = $nargs & 65535;
    HEAP16[$12 + 58 >> 1] = $flags & 65535 & -6152;
    var $20 = $_01 + 60 | 0;
    var $21 = $20 + 4 | 0;
    if (($flags & 49152) >>> 0 > 16383) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    HEAP16[$21 >> 1] = 0;
    HEAP32[$20 >> 2] = 0;
    __label__ = 11;
    break;
   case 8:
    HEAP32[$21 >> 2] = 0;
    if (($flags & 8192 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    HEAP32[$20 + 8 >> 2] = 0;
    __label__ = 11;
    break;
   case 10:
    HEAP32[$20 >> 2] = $native;
    HEAP32[$20 + 8 >> 2] = 0;
    __label__ = 11;
    break;
   case 11:
    HEAP32[$_01 + 72 >> 2] = $atom;
    __ZN8JSObject10setPrivateEPv($_01, $_01);
    var $_0 = $12;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom["X"] = 1;

function __ZL13fun_enumerateP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $found = __stackBase__;
    var $obj_idx_val = HEAP32[$obj + 8 >> 2];
    var $1 = __ZNK8JSObject15isBoundFunctionEv($obj_idx_val);
    var $_pre = $cx + 52 | 0;
    if ($1) {
      var $_pre_phi = $_pre;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[HEAP32[$_pre >> 2] + 210200 >> 2] | 0;
    var $7 = __ZL12ATOM_TO_JSIDP6JSAtom1293($6);
    var $8 = __ZN8JSObject11hasPropertyEP9JSContextiPbj($obj, $cx, $7, $found, 1);
    if ($8) {
      var $_pre_phi = $_pre;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $_pre_phi;
    var $12 = HEAP32[HEAP32[$_pre_phi >> 2] + 210256 >> 2] | 0;
    var $13 = __ZL12ATOM_TO_JSIDP6JSAtom1293($12);
    var $14 = __ZN8JSObject11hasPropertyEP9JSContextiPbj($obj, $cx, $13, $found, 1);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $19 = HEAP32[HEAP32[$_pre_phi >> 2] + 210272 >> 2] | 0;
    var $20 = __ZL12ATOM_TO_JSIDP6JSAtom1293($19);
    var $21 = __ZN8JSObject11hasPropertyEP9JSContextiPbj($obj, $cx, $20, $found, 1);
    if ($21) {
      var $i_0 = 0;
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $i_0;
    if ($i_0 >>> 0 < 2) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 6:
    var $32 = HEAP32[HEAP32[$_pre_phi >> 2] + 209948 + (HEAPU16[__ZL15poisonPillProps + ($i_0 << 1) >> 1] & 65535) >> 2];
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom1293($32);
    var $34 = __ZN8JSObject11hasPropertyEP9JSContextiPbj($obj, $cx, $33, $found, 1);
    if ($34) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 5;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11fun_resolveP9JSContextP8JSObjectijPS2_($cx, $obj, $id, $flags, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __ZL12JSID_IS_ATOMi1319($id);
    if (($2 | 0) == 0) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $obj_idx_val = HEAP32[$obj + 24 >> 2];
    var $5 = __ZNK8JSObject18getFunctionPrivateEv($obj_idx_val);
    var $7 = HEAPU32[$cx + 52 >> 2];
    var $10 = HEAP32[$7 + 210200 >> 2] | 0;
    var $11 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $10);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = $5;
    var $15 = __ZNK10JSFunction8isNativeEv($14);
    if ($15) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx1_val = HEAP16[$5 + 58 >> 1];
    var $17 = __ZNK10JSFunction19isFunctionPrototypeEv($_idx1_val);
    if ($17) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = __ZL35ResolveInterpretedFunctionPrototypeP9JSContextP8JSObject($cx, $obj);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 24;
    break;
   case 7:
    var $25 = HEAP32[$7 + 210256 >> 2] | 0;
    var $26 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $25);
    if (($26 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $31 = HEAP32[$7 + 210272 >> 2] | 0;
    var $32 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $31);
    if (($32 | 0) == 0) {
      var $i_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $37 = HEAPU16[$5 + 56 >> 1] & 65535;
    __ZN2JS5Value8setInt32Ei($v, $37);
    __label__ = 13;
    break;
   case 10:
    var $40 = HEAPU32[$5 + 72 >> 2];
    if (($40 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $46 = $40;
      __label__ = 12;
      break;
    }
   case 11:
    var $46 = HEAP32[$7 + 144136 >> 2];
    __label__ = 12;
    break;
   case 12:
    var $46;
    __ZN2JS5Value9setStringEP8JSString($v, $46 | 0);
    __label__ = 13;
    break;
   case 13:
    var $49 = $cx;
    var $50 = $obj;
    var $51 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($49, $50, $id, $v, 10, 12, 6, 0, 0, 0);
    if (($51 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 24;
    break;
   case 15:
    var $i_0;
    if ($i_0 >>> 0 < 2) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 1;
      __label__ = 24;
      break;
    }
   case 16:
    var $63 = HEAP32[$7 + 209948 + (HEAPU16[__ZL15poisonPillProps + ($i_0 << 1) >> 1] & 65535) >> 2];
    var $64 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $63);
    if (($64 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $_idx_val = HEAP16[$5 + 58 >> 1];
    var $67 = __ZNK10JSFunction13isInterpretedEv($_idx_val);
    if ($67) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $69 = __ZNK10JSFunction12inStrictModeEv($5);
    if ($69) {
      __label__ = 20;
      break;
    } else {
      var $attrs_0 = 4;
      var $setter_0 = 12;
      var $getter_0 = 116;
      __label__ = 21;
      break;
    }
   case 19:
    var $obj_idx2_val = HEAP32[$obj + 8 >> 2];
    var $71 = __ZNK8JSObject15isBoundFunctionEv($obj_idx2_val);
    if ($71) {
      __label__ = 20;
      break;
    } else {
      var $attrs_0 = 4;
      var $setter_0 = 12;
      var $getter_0 = 116;
      __label__ = 21;
      break;
    }
   case 20:
    var $73 = __ZNK8JSObject17getThrowTypeErrorEv($obj);
    var $74 = __ZN2jsL16CastAsPropertyOpEP8JSObject1357($73);
    var $75 = __ZN2jsL22CastAsStrictPropertyOpEP8JSObject1358($73);
    var $attrs_0 = 52;
    var $setter_0 = $75;
    var $getter_0 = $74;
    __label__ = 21;
    break;
   case 21:
    var $getter_0;
    var $setter_0;
    var $attrs_0;
    __ZN2JSL14UndefinedValueEv1350($1);
    var $77 = $cx;
    var $78 = $obj;
    var $79 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($77, $78, $id, $1, $getter_0, $setter_0, $attrs_0, 0, 0, 0);
    if (($79 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 24;
    break;
   case 23:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 15;
    break;
   case 24:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11fun_resolveP9JSContextP8JSObjectijPS2_["X"] = 1;

function __ZL12fun_finalizeP9JSContextP8JSObject($cx, $obj) {
  __ZN8JSObject27finalizeUpvarsIfFlatClosureEv($obj);
  return;
}

function __ZL15fun_hasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi($cx, $obj, $v, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pval = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $_01 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $_01_idx_val = HEAP32[$_01 + 4 >> 2];
    var $3 = __ZNK8JSObject10isFunctionEv($_01_idx_val);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $_01_idx2_val = HEAP32[$_01 + 8 >> 2];
    var $5 = __ZNK8JSObject15isBoundFunctionEv($_01_idx2_val);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_01_idx3_val = HEAP32[$_01 + 20 >> 2];
    var $7 = __ZNK8JSObject22getBoundFunctionTargetEv($_01_idx3_val);
    var $_01 = $7;
    __label__ = 2;
    break;
   case 5:
    var $12 = HEAP32[HEAP32[$cx + 52 >> 2] + 210200 >> 2];
    var $13 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($_01, $cx, $12, $pval);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $pval_idx1 = $pval | 0;
    var $pval_idx1_val$0 = HEAP32[$pval_idx1 >> 2];
    var $pval_idx1_val$1 = HEAP32[$pval_idx1 + 4 >> 2];
    var $16 = __ZNK2JS5Value11isPrimitiveEv($pval_idx1_val$0, $pval_idx1_val$1);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2JSL11ObjectValueER8JSObject1294($1, $_01);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $18 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, 135, -1, $_idx_val$0, $_idx_val$1, 0, 0);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 8:
    var $20 = __ZNK2JS5Value8toObjectEv($pval_idx1_val$0, $pval_idx1_val$1);
    var $21 = $20;
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $22 = __Z13js_IsDelegateP9JSContextP8JSObjectRKN2JS5ValueE($21, $v_idx_val$0, $v_idx_val$1);
    var $23 = $22 & 1;
    HEAP32[$bp >> 2] = $23;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15fun_hasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi["X"] = 1;

function __ZL9fun_traceP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj_idx_val = HEAP32[$obj + 24 >> 2];
    var $1 = __ZNK8JSObject10getPrivateEv($obj_idx_val);
    var $2 = $1;
    if (($1 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $1;
    if (($5 | 0) == ($obj | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $5);
    var $_idx2_val = HEAP16[$1 + 58 >> 1];
    var $9 = __ZNK10JSFunction13isFlatClosureEv($_idx2_val);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 4:
    var $11 = __ZNK10JSFunction6scriptEv($2);
    var $_idx3_val = HEAP16[$11 + 72 >> 1];
    var $12 = __ZNK2js8Bindings9hasUpvarsEv($_idx3_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 5:
    var $14 = __ZNK2js8Bindings11countUpvarsEv($_idx3_val);
    var $15 = $14 & 65535;
    var $16 = __ZNK8JSObject20getFlatClosureUpvarsEv($obj);
    __ZN2js2gc14MarkValueRangeEP8JSTracerjPKN2JS5ValueEPKc($trc, $15, $16);
    __label__ = 11;
    break;
   case 6:
    var $20 = HEAP32[$1 + 72 >> 2];
    if (($20 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = $20 | 0;
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($trc, $23);
    __label__ = 8;
    break;
   case 8:
    var $_idx_val = HEAP16[$1 + 58 >> 1];
    var $26 = __ZNK10JSFunction13isInterpretedEv($_idx_val);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $28 = __ZNK10JSFunction6scriptEv($2);
    if (($28 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2js2gc10MarkScriptEP8JSTracerP8JSScriptPKc($trc, $28);
    __label__ = 11;
    break;
   case 11:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18fun_toStringHelperP9JSContextP8JSObjectj($cx, $obj, $indent) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fun = __stackBase__;
    var $p = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $str = __stackBase__ + 16;
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $2 = __ZNK8JSObject10isFunctionEv($obj_idx_val);
    if ($2) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject15isFunctionProxyEv($obj_idx_val);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZN2js7JSProxy12fun_toStringEP9JSContextP8JSObjectj($cx, $obj, $indent);
    var $_0 = $6;
    __label__ = 17;
    break;
   case 4:
    _JS_ReportErrorNumber($cx, 4, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str73060 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE._js_toString_str | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str267560 | 0, tempInt));
    var $_0 = 0;
    __label__ = 17;
    break;
   case 5:
    var $obj_idx1_val = HEAP32[$obj + 24 >> 2];
    var $9 = __ZNK8JSObject18getFunctionPrivateEv($obj_idx1_val);
    HEAP32[$fun >> 2] = $9;
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $12 = ($indent | 0) != 0;
    if ($12) {
      var $28 = $9;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $15 = HEAP32[$cx + 56 >> 2];
    var $_idx2_val = HEAP8[$15 + 1860 | 0];
    var $16 = __ZNK7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE5emptyEv($_idx2_val);
    if ($16) {
      var $28 = $9;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $18 = $15 + 1836 | 0;
    var $19 = __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE3refEv($18);
    __ZNK2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6lookupERKS2_($p, $19, $fun);
    var $p_idx_val = HEAP32[$p >> 2];
    var $p_idx_val_idx_val = HEAP32[$p_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($1, $p_idx_val_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $28 = HEAP32[$fun >> 2];
    __label__ = 11;
    break;
   case 10:
    var $24 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($p_idx_val);
    var $_0 = HEAP32[$24 + 4 >> 2];
    __label__ = 17;
    break;
   case 11:
    var $28;
    var $29 = _JS_DecompileFunction($cx, $28, $indent);
    HEAP32[$str >> 2] = $29;
    var $30 = ($29 | 0) == 0;
    var $_mux = $30 ? 0 : $29;
    if ($30 | $12) {
      var $_0 = $_mux;
      __label__ = 17;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $33 = HEAP32[$cx + 56 >> 2];
    var $34 = $33 + 1836 | 0;
    var $_idx_val = HEAP8[$33 + 1860 | 0];
    var $35 = __ZNK7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE5emptyEv($_idx_val);
    if ($35) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $_pre8 = __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE3refEv($34);
    var $_pre_phi = $_pre8;
    __label__ = 15;
    break;
   case 14:
    __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE9constructEv($34);
    var $37 = __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE3refEv($34);
    var $38 = __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE4initEj($37);
    if ($38) {
      var $_pre_phi = $37;
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 15:
    var $_pre_phi;
    var $40 = __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3putERKS2_RKS4_($_pre_phi, $fun, $str);
    if (($40 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $_0 = HEAP32[$str >> 2];
    __label__ = 17;
    break;
   case 17:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18fun_toStringHelperP9JSContextP8JSObjectj["X"] = 1;

function __ZNK2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 118,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE9constructEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZN7mozilla15AlignedStorage2IN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE4addrEv($1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES7_($2);
    __label__ = 3;
    break;
   case 3:
    HEAP8[$this + 24 | 0] = 1;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E4initEj($1);
  return $2;
}

function __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3putERKS2_RKS4_($this, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZNK2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE12lookupForAddERKS2_($p, $this, $k);
    var $_idx = $p | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $_idx_val_idx_val = HEAP32[$_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($1, $_idx_val_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$v >> 2];
    var $7 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($_idx_val);
    var $8 = $7 + 4 | 0;
    HEAP32[$8 >> 2] = $6;
    var $9 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv($_idx_val);
    var $_0 = $9;
    __label__ = 5;
    break;
   case 3:
    var $11 = __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($this, $p, $k, $v);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx2_val = HEAP32[$_idx >> 2];
    var $13 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv($_idx2_val);
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z11js_fun_callP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $thisv = __stackBase__;
    var $args = __stackBase__ + 8;
    var $1 = $vp + 8 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZL13js_IsCallableRKN2JS5ValueE1306($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js13FunctionClassE);
    var $_1 = 0;
    __label__ = 9;
    break;
   case 3:
    var $6 = $vp + 16 | 0;
    if (($argc | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value12setUndefinedEv($thisv);
    var $_01 = 0;
    var $argv_0 = $6;
    __label__ = 6;
    break;
   case 5:
    var $10 = $6 | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = $thisv | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    var $_01 = $argc - 1 | 0;
    var $argv_0 = $vp + 24 | 0;
    __label__ = 6;
    break;
   case 6:
    var $argv_0;
    var $_01;
    __ZN2js15InvokeArgsGuardC1Ev($args);
    var $17 = $cx + 60 | 0;
    var $18 = $cx;
    var $19 = $args;
    var $20 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($17, $18, $_01, $19);
    if ($20) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $_idx1 = $args | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $22 = __ZNK2js12CallReceiver7calleevEv($_idx1_val);
    var $23 = $22 | 0;
    var $st$4$0 = $23 | 0;
    HEAP32[$st$4$0 >> 2] = $2$0;
    var $st$4$1 = $23 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $2$1;
    var $_idx2_val = HEAP32[$_idx1 >> 2];
    var $24 = __ZNK2js12CallReceiver5thisvEv($_idx2_val);
    var $25 = $thisv | 0;
    var $26$0 = HEAP32[$25 >> 2];
    var $26$1 = HEAP32[$25 + 4 >> 2];
    var $27 = $24 | 0;
    var $st$16$0 = $27 | 0;
    HEAP32[$st$16$0 >> 2] = $26$0;
    var $st$16$1 = $27 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $26$1;
    var $_idx_val = HEAP32[$_idx1 >> 2];
    var $28 = __ZNK2js8CallArgs4argvEv($_idx_val);
    var $29 = $28;
    _memcpy($29, $argv_0, $_01 << 3, 1);
    var $32 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($cx, $args, 0);
    var $_idx3_val = HEAP32[$_idx1 >> 2];
    var $33 = __ZNK2js12CallReceiver4rvalEv($_idx3_val);
    var $34 = $33 | 0;
    var $35$0 = HEAP32[$34 >> 2];
    var $35$1 = HEAP32[$34 + 4 >> 2];
    var $36 = $vp | 0;
    HEAP32[$36 >> 2] = $35$0;
    HEAP32[$36 + 4 >> 2] = $35$1;
    var $_0 = $32 & 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    __ZN2js15InvokeArgsGuardD1Ev($args);
    var $_1 = $_0;
    __label__ = 9;
    break;
   case 9:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z11js_fun_callP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL13js_IsCallableRKN2JS5ValueE1306($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZN8JSObject10isCallableEv($_idx_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z12js_fun_applyP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $length = __stackBase__;
    var $args = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $st$3$0 = $1 | 0;
    var $2$0 = HEAPU32[$st$3$0 >> 2];
    var $st$3$1 = $1 + 4 | 0;
    var $2$1 = HEAPU32[$st$3$1 >> 2];
    var $3 = __ZL13js_IsCallableRKN2JS5ValueE1306($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js13FunctionClassE);
    var $_1 = 0;
    __label__ = 16;
    break;
   case 3:
    if ($argc >>> 0 < 2) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx6 = $vp + 24 | 0;
    var $_idx6_val$0 = HEAPU32[$_idx6 >> 2];
    var $_idx6_val$1 = HEAPU32[$_idx6 + 4 >> 2];
    var $8 = __ZNK2JS5Value17isNullOrUndefinedEv($_idx6_val$0, $_idx6_val$1);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = ($argc | 0) != 0 & 1;
    var $12 = __Z11js_fun_callP9JSContextjPN2JS5ValueE($cx, $11, $vp);
    var $_1 = $12;
    __label__ = 16;
    break;
   case 6:
    var $14 = __ZNK2JS5Value8isObjectEv($_idx6_val$0, $_idx6_val$1);
    if ($14) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 4, 154, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str79 | 0, tempInt));
    var $_1 = 0;
    __label__ = 16;
    break;
   case 8:
    var $17 = __ZNK2JS5Value8toObjectEv($_idx6_val$0, $_idx6_val$1);
    var $18 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $17, $length);
    if (($18 | 0) == 0) {
      var $_1 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $21 = HEAPU32[$length >> 2];
    if ($21 >>> 0 > 491520) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    _JS_ReportErrorNumber($cx, 4, 61, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 16;
    break;
   case 11:
    __ZN2js15InvokeArgsGuardC1Ev($args);
    var $26 = $cx + 60 | 0;
    var $27 = $cx;
    var $28 = $args;
    var $29 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($26, $27, $21, $28);
    if ($29) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 12:
    var $_idx3 = $args | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $31 = __ZNK2js12CallReceiver7calleevEv($_idx3_val);
    var $32 = $31 | 0;
    var $st$4$0 = $32 | 0;
    HEAP32[$st$4$0 >> 2] = $2$0;
    var $st$4$1 = $32 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $2$1;
    var $_idx4_val = HEAP32[$_idx3 >> 2];
    var $33 = __ZNK2js12CallReceiver5thisvEv($_idx4_val);
    var $34 = $vp + 16 | 0;
    var $35$0 = HEAP32[$34 >> 2];
    var $35$1 = HEAP32[$34 + 4 >> 2];
    var $36 = $33 | 0;
    var $st$16$0 = $36 | 0;
    HEAP32[$st$16$0 >> 2] = $35$0;
    var $st$16$1 = $36 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $35$1;
    var $_idx_val = HEAP32[$_idx3 >> 2];
    var $37 = __ZNK2js8CallArgs4argvEv($_idx_val);
    var $38 = __ZN2js11GetElementsEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $17, $21, $37);
    if ($38) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 13:
    var $40 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($cx, $args, 0);
    if ($40) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 14:
    var $_idx5_val = HEAP32[$_idx3 >> 2];
    var $42 = __ZNK2js12CallReceiver4rvalEv($_idx5_val);
    var $43 = $42 | 0;
    var $st$3$0 = $43 | 0;
    var $44$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $43 + 4 | 0;
    var $44$1 = HEAP32[$st$3$1 >> 2];
    var $45 = $vp | 0;
    HEAP32[$45 >> 2] = $44$0;
    HEAP32[$45 + 4 >> 2] = $44$1;
    var $_0 = 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    __ZN2js15InvokeArgsGuardD1Ev($args);
    var $_1 = $_0;
    __label__ = 16;
    break;
   case 16:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z12js_fun_applyP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2js28CallOrConstructBoundFunctionEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $1 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
    var $2 = __ZN2jsL14IsConstructingEPKN2JS5ValueE1307($vp);
    var $3 = __ZNK8JSObject29getBoundFunctionArgumentCountEv($1);
    var $4 = $3 + $argc | 0;
    if ($4 >>> 0 > 491520) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __Z27js_ReportAllocationOverflowP9JSContext($cx);
    var $_1 = 0;
    __label__ = 11;
    break;
   case 3:
    var $_idx5_val = HEAP32[$1 + 20 >> 2];
    var $8 = __ZNK8JSObject22getBoundFunctionTargetEv($_idx5_val);
    var $9 = __ZNK8JSObject20getBoundFunctionThisEv($1);
    __ZN2js15InvokeArgsGuardC1Ev($args);
    var $11 = $cx + 60 | 0;
    var $12 = $cx;
    var $13 = $args;
    var $14 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($11, $12, $4, $13);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 4:
    var $_idx_pre = $args | 0;
    if (($3 | 0) == 0) {
      var $_idx_pre_phi = $_idx_pre;
      __label__ = 6;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 5;
      break;
    }
   case 5:
    var $i_01;
    var $_idx3_val = HEAP32[$_idx_pre >> 2];
    var $16 = __ZNK2js8CallArgsixEj($_idx3_val, $i_01);
    var $17 = __ZNK8JSObject24getBoundFunctionArgumentEj($1, $i_01);
    var $18 = $17 | 0;
    var $19$0 = HEAP32[$18 >> 2];
    var $19$1 = HEAP32[$18 + 4 >> 2];
    var $20 = $16 | 0;
    var $st$10$0 = $20 | 0;
    HEAP32[$st$10$0 >> 2] = $19$0;
    var $st$10$1 = $20 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $19$1;
    var $21 = $i_01 + 1 | 0;
    if (($21 | 0) == ($3 | 0)) {
      var $_idx_pre_phi = $_idx_pre;
      __label__ = 6;
      break;
    } else {
      var $i_01 = $21;
      __label__ = 5;
      break;
    }
   case 6:
    var $_idx_pre_phi;
    var $_idx_val = HEAP32[$_idx_pre_phi >> 2];
    var $22 = __ZNK2js8CallArgs4argvEv($_idx_val);
    var $24 = $22 + ($3 << 3) | 0;
    var $26 = $vp + 16 | 0;
    var $27 = $argc << 3;
    _memcpy($24, $26, $27, 1);
    var $_idx1_val = HEAP32[$_idx_pre_phi >> 2];
    var $28 = __ZNK2js12CallReceiver7calleevEv($_idx1_val);
    __ZN2JS5Value9setObjectER8JSObject($28, $8);
    if ($2) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx2_val = HEAP32[$_idx_pre_phi >> 2];
    var $30 = __ZNK2js12CallReceiver5thisvEv($_idx2_val);
    var $31 = $9 | 0;
    var $st$3$0 = $31 | 0;
    var $32$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $31 + 4 | 0;
    var $32$1 = HEAP32[$st$3$1 >> 2];
    var $33 = $30 | 0;
    var $st$8$0 = $33 | 0;
    HEAP32[$st$8$0 >> 2] = $32$0;
    var $st$8$1 = $33 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $32$1;
    var $34 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($cx, $args, 0);
    if ($34) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $35 = __ZN2js17InvokeConstructorEP9JSContextRNS_15InvokeArgsGuardE($cx, $args);
    if ($35) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    var $_idx4_val = HEAP32[$_idx_pre_phi >> 2];
    var $37 = __ZNK2js12CallReceiver4rvalEv($_idx4_val);
    var $38 = $37 | 0;
    var $st$3$0 = $38 | 0;
    var $39$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $38 + 4 | 0;
    var $39$1 = HEAP32[$st$3$1 >> 2];
    HEAP32[$vp_idx >> 2] = $39$0;
    HEAP32[$vp_idx + 4 >> 2] = $39$1;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    __ZN2js15InvokeArgsGuardD1Ev($args);
    var $_1 = $_0;
    __label__ = 11;
    break;
   case 11:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js28CallOrConstructBoundFunctionEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2jsL14IsConstructingEPKN2JS5ValueE1307($vp) {
  var $_idx = $vp + 8 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $1 = __ZNK2JS5Value7isMagicEv($_idx_val$0, $_idx_val$1);
  return $1;
}

function __ZNK8JSObject29getBoundFunctionArgumentCountEv($this) {
  var $1 = __ZNK8JSObject7getSlotEj($this, 1);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $2 = __ZNK2JS5Value15toPrivateUint32Ev($_idx_val$0, $_idx_val$1);
  return $2;
}

function __ZNK8JSObject22getBoundFunctionTargetEv($this_0_5_val) {
  var $1 = __ZNK8JSObject9getParentEv($this_0_5_val);
  return $1;
}

function __ZNK8JSObject20getBoundFunctionThisEv($this) {
  var $1 = __ZNK8JSObject7getSlotEj($this, 0);
  return $1;
}

function __ZNK8JSObject24getBoundFunctionArgumentEj($this, $which) {
  var $1 = $which + 2 | 0;
  var $2 = __ZNK8JSObject7getSlotEj($this, $1);
  return $2;
}

function __ZL12fun_toSourceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __Z18fun_toStringHelperP9JSContextP8JSObjectj($cx, $2, 32768);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value9setStringEP8JSString($vp, $5);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12fun_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $indent = __stackBase__;
    HEAP32[$indent >> 2] = 0;
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $vp + 16 | 0;
    var $4 = __ZN2js17ValueToECMAUint32EP9JSContextRKN2JS5ValueEPj($cx, $3, $indent);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $6 = $vp + 8 | 0;
    var $7 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $6);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = HEAP32[$indent >> 2];
    var $11 = __Z18fun_toStringHelperP9JSContextP8JSObjectj($cx, $7, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JS5Value9setStringEP8JSString($vp, $11);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js8Bindings11countUpvarsEv($this_0_3_val) {
  return $this_0_3_val;
}

function __ZNK2js8Bindings9hasUpvarsEv($this_0_3_val) {
  return $this_0_3_val << 16 >> 16 != 0;
}

function __ZNK8JSObject10isDelegateEv($this_0_2_val) {
  return ($this_0_2_val & 1 | 0) != 0;
}

function __ZN2jsL3MinIPN2JS5ValueEEET_S4_S4_($t1, $t2) {
  var $2 = $t1 >>> 0 < $t2 >>> 0 ? $t1 : $t2;
  return $2;
}

function __ZNK2js11TokenStream12currentTokenEv($this) {
  return $this + 4 + (HEAP32[$this + 132 >> 2] << 5) | 0;
}

function __ZN2JS6AnchorIP8JSStringE3setERKS2_($this, $t_val) {
  HEAP32[$this >> 2] = $t_val;
  return;
}

function __ZN8JSObject13clearDelegateEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZL8fun_bindP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $thisArg = __stackBase__;
    var $_idx5 = $vp + 8 | 0;
    var $_idx5_val$0 = HEAP32[$_idx5 >> 2];
    var $_idx5_val$1 = HEAP32[$_idx5 + 4 >> 2];
    var $1 = __ZL13js_IsCallableRKN2JS5ValueE1306($_idx5_val$0, $_idx5_val$1);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js13FunctionClassE);
    var $_0 = 0;
    __label__ = 13;
    break;
   case 3:
    var $4 = __ZNK2JS5Value8toObjectEv($_idx5_val$0, $_idx5_val$1);
    if ($argc >>> 0 > 1) {
      __label__ = 4;
      break;
    } else {
      var $argslen_0 = 0;
      var $args_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $argslen_0 = $argc - 1 | 0;
    var $args_0 = $vp + 24 | 0;
    __label__ = 5;
    break;
   case 5:
    var $args_0;
    var $argslen_0;
    var $_idx2_val = HEAP32[$4 + 4 >> 2];
    var $10 = __ZNK8JSObject10isFunctionEv($_idx2_val);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      var $21 = 0;
      var $length_06 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $_idx4_val = HEAP32[$4 + 24 >> 2];
    var $12 = __ZNK8JSObject18getFunctionPrivateEv($_idx4_val);
    var $15 = HEAPU16[$12 + 56 >> 1] & 65535;
    var $_ = $15 >>> 0 > $argslen_0 >>> 0 ? $15 - $argslen_0 | 0 : 0;
    var $_idx3_val = HEAP32[$4 + 24 >> 2];
    var $18 = __ZNK8JSObject18getFunctionPrivateEv($_idx3_val);
    var $21 = HEAP32[$18 + 72 >> 2];
    var $length_06 = $_;
    __label__ = 7;
    break;
   case 7:
    var $length_06;
    var $21;
    var $22 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($cx, 0, 120, $length_06, 512, $4, $21);
    var $23 = $22 | 0;
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if (($argc | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $28 = $vp + 16 | 0;
    var $29$0 = HEAP32[$28 >> 2];
    var $29$1 = HEAP32[$28 + 4 >> 2];
    var $30 = $thisArg | 0;
    HEAP32[$30 >> 2] = $29$0;
    HEAP32[$30 + 4 >> 2] = $29$1;
    __label__ = 11;
    break;
   case 10:
    __ZN2JSL14UndefinedValueEv1350($thisArg);
    __label__ = 11;
    break;
   case 11:
    var $33 = __ZN8JSObject17initBoundFunctionEP9JSContextRKN2JS5ValueEPS4_j($23, $cx, $thisArg, $args_0, $argslen_0);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 12:
    __ZN2JS5Value9setObjectER8JSObject($vp, $23);
    var $_0 = 1;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL8fun_bindP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL15fun_isGeneratorP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $funobj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $_idx2 = $vp + 8 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    var $3 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject1303($_idx2_val$0, $_idx2_val$1, $funobj);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL12BooleanValueEb1348($1, 0);
    var $5 = $1 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $vp | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    __label__ = 6;
    break;
   case 3:
    var $_idx_val = HEAP32[HEAP32[$funobj >> 2] + 24 >> 2];
    var $10 = __ZNK8JSObject18getFunctionPrivateEv($_idx_val);
    var $_idx1_val = HEAP16[$10 + 58 >> 1];
    var $11 = __ZNK10JSFunction13isInterpretedEv($_idx1_val);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $result_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = __ZNK10JSFunction6scriptEv($10);
    var $result_0 = HEAP8[HEAP32[$13 >> 2]] << 24 >> 24 == -51;
    __label__ = 5;
    break;
   case 5:
    var $result_0;
    __ZN2JSL12BooleanValueEb1348($2, $result_0);
    var $19 = $2 | 0;
    var $20$0 = HEAP32[$19 >> 2];
    var $20$1 = HEAP32[$19 + 4 >> 2];
    var $21 = $vp | 0;
    HEAP32[$21 >> 2] = $20$0;
    HEAP32[$21 + 4 >> 2] = $20$1;
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15fun_isGeneratorP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2js8FunctionEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 956;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $bindings = __stackBase__ + 8;
    var $lineno = __stackBase__ + 20;
    var $aaa = __stackBase__ + 24;
    var $ts = __stackBase__ + 32;
    var $name = __stackBase__ + 944;
    var $dummy = __stackBase__ + 948;
    var $strAnchor = __stackBase__ + 952;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($call, $argc, $vp);
    var $_idx6 = $call | 0;
    var $_idx6_val = HEAP32[$_idx6 >> 2];
    var $1 = __ZNK2js12CallReceiver6calleeEv($_idx6_val);
    var $2 = $1;
    var $3 = __ZNK8JSObject9getGlobalEv($2);
    var $4 = $3;
    var $5 = $cx;
    var $6 = __ZN2js12GlobalObject23isRuntimeCodeGenEnabledEP9JSContext($4, $5);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 4, 247, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_7 = 0;
    __label__ = 38;
    break;
   case 3:
    __ZN2js8BindingsC1EP9JSContext($bindings);
    var $9 = __ZN2js24CurrentScriptFileAndLineEP9JSContextPjNS_10LineOptionE($cx, $lineno, 1);
    var $10 = __ZNK2js8CallArgs4argvEv($_idx6_val);
    var $11 = $argc - 1 | 0;
    var $12 = ($argc | 0) != 0;
    var $_ = $12 ? $11 : 0;
    if (($_ | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $cx;
    var $i_0 = 0;
    var $args_length_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $args_length_0;
    var $i_0;
    if ($i_0 >>> 0 < $_ >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $18 = $10 + ($i_0 << 3) | 0;
    var $_idx10 = $18 | 0;
    var $st$2$0 = $_idx10 | 0;
    var $_idx10_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx10 + 4 | 0;
    var $_idx10_val$1 = HEAP32[$st$2$1 >> 2];
    var $19 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($14, $_idx10_val$0, $_idx10_val$1);
    if (($19 | 0) == 0) {
      var $_7 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JS5Value9setStringEP8JSString($18, $19);
    var $_idx2_val = HEAP32[$19 >> 2];
    var $22 = __ZNK8JSString6lengthEv($_idx2_val);
    var $uadd = _llvm_uadd_with_overflow_i32($args_length_0, $22);
    var $23 = $uadd.f1;
    if ($23) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    __Z27js_ReportAllocationOverflowP9JSContext($cx);
    var $_7 = 0;
    __label__ = 38;
    break;
   case 9:
    var $26 = $uadd.f0;
    var $i_0 = $i_0 + 1 | 0;
    var $args_length_0 = $26;
    __label__ = 5;
    break;
   case 10:
    var $29 = $args_length_0 + $_ | 0;
    var $30 = $29 - 1 | 0;
    if ($30 >>> 0 < $args_length_0 >>> 0 | $30 >>> 0 > 2147483646) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    __Z27js_ReportAllocationOverflowP9JSContext($cx);
    var $_7 = 0;
    __label__ = 38;
    break;
   case 12:
    var $35 = $cx + 72 | 0;
    __ZN2js18AutoArenaAllocatorC1EP11JSArenaPool($aaa, $35);
    var $aaa_idx = $aaa | 0;
    var $aaa_idx_val = HEAPU32[$aaa_idx >> 2];
    var $36 = __ZN2js18AutoArenaAllocator5allocItEEPT_j($aaa_idx_val, $29);
    if (($36 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $i2_0 = 0;
      var $cp_0 = $36;
      __label__ = 14;
      break;
    }
   case 13:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $aaa_idx13_val = $aaa_idx_val;
    __label__ = 30;
    break;
   case 14:
    var $cp_0;
    var $i2_0;
    if ($i2_0 >>> 0 < $_ >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $_idx4 = $10 + ($i2_0 << 3) | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    var $41 = __ZNK2JS5Value8toStringEv($_idx4_val$0, $_idx4_val$1);
    var $_idx1_val = HEAP32[$41 >> 2];
    var $42 = __ZNK8JSString6lengthEv($_idx1_val);
    var $43 = __ZN8JSString8getCharsEP9JSContext($41, $cx);
    if (($43 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $47 = $43;
    var $48 = $42 << 1;
    _memcpy($cp_0, $47, $48, 1);
    var $50 = $i2_0 + 1 | 0;
    var $52 = $50 >>> 0 < $_ >>> 0 ? 44 : 0;
    var $53 = $cp_0 + ($42 + 1 << 1) | 0;
    HEAP16[$cp_0 + ($42 << 1) >> 1] = $52;
    var $i2_0 = $50;
    var $cp_0 = $53;
    __label__ = 14;
    break;
   case 17:
    __ZN2js11TokenStreamC2EP9JSContext($ts, $cx);
    var $55 = HEAP32[$lineno >> 2];
    var $56 = __ZNK9JSContext11findVersionEv($cx);
    __ZN2js11TokenStream4initEPKtjPKcj9JSVersion($ts, $36, $30, $9, $55, $56);
    var $57 = __ZN2js11TokenStream8getTokenEv($ts);
    if (($57 | 0) == 0) {
      var $_14 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $name_idx7 = $name | 0;
    var $tt_0 = $57;
    __label__ = 19;
    break;
   case 19:
    var $tt_0;
    if (($tt_0 | 0) == 29) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    __ZL11OnBadFormalP9JSContextN2js9TokenKindE($cx, $tt_0);
    var $_14 = 1;
    __label__ = 31;
    break;
   case 21:
    var $62 = __ZNK2js11TokenStream12currentTokenEv($ts);
    var $64 = HEAPU32[$62 + 28 >> 2];
    var $65 = __ZNK2js8Bindings10hasBindingEP9JSContextP6JSAtom($bindings, $cx, $64);
    if ($65) {
      __label__ = 22;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 22:
    __ZN16JSAutoByteStringC1Ev($name);
    var $67 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $64, $name);
    var $name_idx5_val = HEAPU32[$name_idx7 >> 2];
    if (($67 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    __ZN16JSAutoByteStringD1Ev($name_idx5_val);
    var $_14 = 1;
    __label__ = 31;
    break;
   case 24:
    var $70 = __ZNK16JSAutoByteString3ptrEv($name_idx5_val);
    var $71 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($ts, 0, 5, 111, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $70, tempInt));
    var $_8 = $71 & 1 ^ 1;
    __ZN16JSAutoByteStringD1Ev($name_idx5_val);
    if ($71) {
      __label__ = 25;
      break;
    } else {
      var $_14 = $_8;
      __label__ = 31;
      break;
    }
   case 25:
    var $74 = __ZN2js8Bindings11addArgumentEP9JSContextP6JSAtomPt($bindings, $cx, $64, $dummy);
    if ($74) {
      __label__ = 26;
      break;
    } else {
      var $_14 = 1;
      __label__ = 31;
      break;
    }
   case 26:
    var $76 = __ZN2js11TokenStream8getTokenEv($ts);
    if (($76 | 0) == 3) {
      __label__ = 28;
      break;
    } else if (($76 | 0) == 0) {
      var $_14 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZL11OnBadFormalP9JSContextN2js9TokenKindE($cx, $76);
    var $_14 = 1;
    __label__ = 31;
    break;
   case 28:
    var $79 = __ZN2js11TokenStream8getTokenEv($ts);
    var $tt_0 = $79;
    __label__ = 19;
    break;
   case 29:
    var $aaa_idx13_val = HEAP32[$aaa_idx >> 2];
    __label__ = 30;
    break;
   case 30:
    var $aaa_idx13_val;
    var $aaa_idx14_val = HEAP32[$aaa + 4 >> 2];
    __ZN2js18AutoArenaAllocatorD1Ev($aaa_idx13_val, $aaa_idx14_val);
    var $_7 = 0;
    __label__ = 38;
    break;
   case 31:
    var $_14;
    __ZN2js11TokenStreamD2Ev($ts);
    var $aaa_idx11_val = HEAP32[$aaa_idx >> 2];
    var $aaa_idx12_val = HEAP32[$aaa + 4 >> 2];
    __ZN2js18AutoArenaAllocatorD1Ev($aaa_idx11_val, $aaa_idx12_val);
    if (($_14 | 0) == 1) {
      var $_7 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    __ZN2JS6AnchorIP8JSStringEC1ES2_($strAnchor, 0);
    if ($12) {
      __label__ = 33;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 33:
    var $82 = $cx;
    var $_idx9 = $10 + ($11 << 3) | 0;
    var $st$2$0 = $_idx9 | 0;
    var $_idx9_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx9 + 4 | 0;
    var $_idx9_val$1 = HEAP32[$st$2$1 >> 2];
    var $83 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($82, $_idx9_val$0, $_idx9_val$1);
    if (($83 | 0) == 0) {
      var $_7 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    __ZN2JS6AnchorIP8JSStringE3setERKS2_($strAnchor, $83);
    var $86 = __ZN8JSString8getCharsEP9JSContext($83, $cx);
    var $_idx_val = HEAP32[$83 >> 2];
    var $87 = __ZNK8JSString6lengthEv($_idx_val);
    var $length_0 = $87;
    var $chars_0 = $86;
    var $95 = HEAP32[$cx + 52 >> 2];
    __label__ = 36;
    break;
   case 35:
    var $90 = HEAP32[$cx + 52 >> 2];
    var $_idx3_val = HEAP32[HEAP32[$90 + 144136 >> 2] + 4 >> 2];
    var $93 = __ZNK14JSLinearString5charsEv($_idx3_val);
    var $length_0 = 0;
    var $chars_0 = $93;
    var $95 = $90;
    __label__ = 36;
    break;
   case 36:
    var $95;
    var $chars_0;
    var $length_0;
    var $96 = $3;
    var $99 = HEAP32[$95 + 210168 >> 2] | 0;
    var $100 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($cx, 0, 0, 0, 16392, $96, $99);
    if (($100 | 0) == 0) {
      var $_7 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $103 = $cx;
    var $104 = __ZN2js25PrincipalsForCompiledCodeERKNS_8CallArgsEP9JSContext($call, $103);
    var $105 = $104;
    var $106 = HEAP32[$lineno >> 2];
    var $107 = __ZNK9JSContext11findVersionEv($cx);
    var $108 = __ZN2js8Compiler19compileFunctionBodyEP9JSContextP10JSFunctionP12JSPrincipalsPNS_8BindingsEPKtjPKcj9JSVersion($cx, $100, $105, $bindings, $chars_0, $length_0, $9, $106, $107);
    var $_idx8_val = HEAP32[$_idx6 >> 2];
    var $109 = __ZNK2js12CallReceiver4rvalEv($_idx8_val);
    var $110 = $100 | 0;
    __ZN2JS5Value9setObjectER8JSObject($109, $110);
    var $_7 = $108 & 1;
    __label__ = 38;
    break;
   case 38:
    var $_7;
    STACKTOP = __stackBase__;
    return $_7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8FunctionEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2js24CurrentScriptFileAndLineEP9JSContextPjNS_10LineOptionE($cx, $linenop, $opt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($opt | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK9JSContext4regsEv($cx);
    var $5 = HEAPU32[$3 + 4 >> 2];
    HEAP32[$linenop >> 2] = (HEAPU8[$5 + 4 | 0] & 255) << 8 | HEAPU8[$5 + 5 | 0] & 255;
    var $14 = __ZNK9JSContext2fpEv($cx);
    var $15 = __ZNK2js10StackFrame6scriptEv($14);
    var $_0 = HEAP32[$15 + 52 >> 2];
    __label__ = 4;
    break;
   case 3:
    var $19 = $cx;
    var $20 = __ZN2js28CurrentScriptFileAndLineSlowEP9JSContextPj($19, $linenop);
    var $_0 = $20;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18AutoArenaAllocator5allocItEEPT_j($this_0_0_val, $elems) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this_0_0_val + 16 >> 2];
    var $5 = HEAP32[$this_0_0_val + 24 >> 2];
    var $8 = $5 + ($elems << 1) & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($this_0_0_val, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream8getTokenEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 136 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 - 1 | 0;
    HEAP32[$1 >> 2] = $5;
    var $6 = $this + 132 | 0;
    var $9 = HEAP32[$6 >> 2] + 1 & 3;
    HEAP32[$6 >> 2] = $9;
    var $10 = __ZNK2js11TokenStream12currentTokenEv($this);
    var $_0 = HEAP32[$10 >> 2];
    __label__ = 4;
    break;
   case 3:
    var $14 = __ZN2js11TokenStream16getTokenInternalEv($this);
    var $_0 = $14;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11OnBadFormalP9JSContextN2js9TokenKindE($cx, $tt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($tt | 0) == -1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 4, 20, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL35ResolveInterpretedFunctionPrototypeP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $objProto = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $obj_idx_val = HEAP32[$obj + 20 >> 2];
    var $3 = __ZNK8JSObject9getParentEv($obj_idx_val);
    var $4 = $cx;
    var $5 = $3;
    var $6 = $objProto;
    var $7 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($4, $5, 1, $6, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAP32[$objProto >> 2];
    var $11 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_1314($cx, __ZN2js11ObjectClassE, $10, $3);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = $11;
    var $15 = $cx;
    __ZN8JSObject16setSingletonTypeEP9JSContext($14, $15);
    var $16 = $cx + 52 | 0;
    var $20 = HEAP32[HEAP32[$16 >> 2] + 210200 >> 2] | 0;
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom1293($20);
    __ZN2JSL11ObjectValueER8JSObject1294($1, $11);
    var $22 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj, $cx, $21, $1, 10, 12, 4);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $28 = HEAP32[HEAP32[$16 >> 2] + 210204 >> 2] | 0;
    var $29 = __ZL12ATOM_TO_JSIDP6JSAtom1293($28);
    __ZN2JSL11ObjectValueER8JSObject1294($2, $obj);
    var $30 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($11, $cx, $29, $2, 10, 12, 0);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_0 = $11;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL11NewFunctionEP9JSContextP8JSObject($cx, $parent) {
  var $1 = __ZN2js6detailL9NewObjectILb0ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE1342($cx, $parent);
  return $1;
}

function __Z22js_CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectS4_($cx, $fun, $parent, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 56 >> 2];
    var $3 = $fun;
    var $4 = __ZNK2js2gc4Cell11compartmentEv($3);
    if (($2 | 0) == ($4 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $7 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_1314($cx, __ZN2js13FunctionClassE, $proto, $parent);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx3_val = HEAP32[$fun + 36 >> 2];
    var $_idx3_val_idx_val = HEAP32[$_idx3_val >> 2];
    var $10 = __ZNK8JSObject8getProtoEv($_idx3_val_idx_val);
    if (($10 | 0) == ($proto | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $_idx2_val = HEAP32[$fun + 8 >> 2];
    var $13 = __ZNK8JSObject16hasSingletonTypeEv($_idx2_val);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = __ZNK8JSObject4typeEv($_idx3_val);
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($7, $15);
    __label__ = 6;
    break;
   case 6:
    var $17 = $fun;
    __ZN8JSObject10setPrivateEPv($7, $17);
    var $_0 = $7;
    __label__ = 12;
    break;
   case 7:
    var $19 = __ZN2jsL11NewFunctionEP9JSContextP8JSObject($cx, $parent);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = $19;
    var $24 = HEAP16[$fun + 56 >> 1];
    HEAP16[$19 + 56 >> 1] = $24;
    var $28 = HEAP16[$fun + 58 >> 1];
    var $29 = $22 + 58 | 0;
    HEAP16[$29 >> 1] = $28;
    var $30 = $19 + 60 | 0;
    var $_idx_val = HEAP32[$fun + 24 >> 2];
    var $31 = __ZNK8JSObject18getFunctionPrivateEv($_idx_val);
    var $33 = $30;
    var $34 = $31 + 60 | 0;
    HEAP32[$33 >> 2] = HEAP32[$34 >> 2];
    HEAP32[$33 + 4 >> 2] = HEAP32[$34 + 4 >> 2];
    HEAP32[$33 + 8 >> 2] = HEAP32[$34 + 8 >> 2];
    var $_c = HEAP32[$fun + 72 >> 2];
    HEAP32[$19 + 72 >> 2] = $_c;
    var $38 = $19;
    __ZN8JSObject10setPrivateEPv($19, $38);
    var $_idx1_val = HEAP16[$29 >> 1];
    var $39 = __ZNK10JSFunction13isInterpretedEv($_idx1_val);
    if ($39) {
      __label__ = 9;
      break;
    } else {
      var $_0 = $19;
      __label__ = 12;
      break;
    }
   case 9:
    var $41 = __ZNK10JSFunction6scriptEv($22);
    HEAP32[$30 >> 2] = 0;
    var $42 = $cx;
    var $43 = $41;
    var $44 = __Z14js_CloneScriptP9JSContextP8JSScript($42, $43);
    if (($44 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $47 = $44;
    HEAP32[$30 >> 2] = $44;
    var $48 = __ZN8JSScript15typeSetFunctionEP9JSContextP10JSFunctionb($47, $cx, $22, 0);
    if ($48) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 11:
    var $50 = __ZNK10JSFunction6scriptEv($22);
    var $51 = $50;
    var $52 = $19;
    __Z20js_CallNewScriptHookP9JSContextP8JSScriptP10JSFunction($42, $51, $52);
    var $53 = __ZNK10JSFunction6scriptEv($22);
    __ZN2js8Debugger11onNewScriptEP9JSContextP8JSScriptP8JSObjectNS0_13NewScriptKindE($cx, $53, $19, 1);
    var $_0 = $19;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z22js_CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectS4_["X"] = 1;

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_1314($cx, $clasp, $proto, $parent) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb1337($4);
  var $6 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1338($cx, $clasp, $proto, $parent, $5);
  return $6;
}

function __ZN2js8Debugger11onNewScriptEP9JSContextP8JSScriptP8JSObjectNS0_13NewScriptKindE($cx, $script, $obj, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $script;
    var $2 = __ZNK2js2gc4Cell11compartmentEv($1);
    var $3 = __ZN13JSCompartment12getDebuggeesEv($2);
    var $4 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5emptyEv($3);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js8Debugger19slowPathOnNewScriptEP9JSContextP8JSScriptP8JSObjectNS0_13NewScriptKindE($cx, $script, $obj, $kind);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19js_AllocFlatClosureP9JSContextP10JSFunctionP8JSObject($cx, $fun, $scopeChain) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z19CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectb($cx, $fun, $scopeChain, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK10JSFunction6scriptEv($fun);
    var $_idx_val = HEAP16[$4 + 72 >> 1];
    var $5 = __ZNK2js8Bindings11countUpvarsEv($_idx_val);
    if ($5 << 16 >> 16 == 0) {
      var $_0 = $1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = ($5 & 65535) << 3;
    var $10 = __ZN9JSContext7malloc_Ej($cx, $9);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $10;
    __ZN8JSObject20setFlatClosureUpvarsEPN2JS5ValueE($1, $13);
    var $_0 = $1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject20setFlatClosureUpvarsEPN2JS5ValueE($this, $upvars) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $upvars;
  __ZN2JSL12PrivateValueEPv1335($1, $2);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  __ZN8JSObject12setFixedSlotEjRKN2JS5ValueE($this, 0, $_idx_val$0, $_idx_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __Z17js_NewFlatClosureP9JSContextP10JSFunction4JSOpj($cx, $fun) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK9JSContext2fpEv($cx);
    var $2 = __ZNK2js10StackFrame10scopeChainEv($1);
    var $3 = __Z19js_AllocFlatClosureP9JSContextP10JSFunctionP8JSObject($cx, $fun, $2);
    if (($3 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK10JSFunction6scriptEv($fun);
    var $_idx2_val = HEAP16[$6 + 72 >> 1];
    var $7 = __ZNK2js8Bindings9hasUpvarsEv($_idx2_val);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $9 = __ZNK8JSObject20getFlatClosureUpvarsEv($3);
    var $12 = HEAPU16[$6 + 46 >> 1] & 65535;
    var $_idx_val = HEAP32[$6 + 4 >> 2];
    var $_idx1_val = HEAP8[$6 + 17 | 0];
    var $13 = __ZN8JSScript6upvarsEv($_idx_val, $_idx1_val);
    var $15 = HEAPU32[$13 + 4 >> 2];
    if (($15 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = $13 | 0;
    var $i_01 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_01;
    var $21 = HEAP32[HEAP32[$17 >> 2] + ($i_01 << 2) >> 2];
    var $22 = __ZN2js8GetUpvarEP9JSContextjNS_11UpvarCookieE($cx, $12, $21);
    var $23 = $22 | 0;
    var $24$0 = HEAP32[$23 >> 2];
    var $24$1 = HEAP32[$23 + 4 >> 2];
    var $25 = $9 + ($i_01 << 3) | 0;
    HEAP32[$25 >> 2] = $24$0;
    HEAP32[$25 + 4 >> 2] = $24$1;
    var $26 = $i_01 + 1 | 0;
    if (($26 | 0) == ($15 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $i_01 = $26;
      __label__ = 5;
      break;
    }
   case 6:
    return $3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_DefineFunctionP9JSContextP8JSObjectiPFiS0_jPN2JS5ValueEEjj($cx, $obj, $id, $native, $nargs, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $3 = ($attrs & 4096 | 0) == 0;
    var $_01 = $3 ? $attrs : $attrs & -4097;
    var $gop_0 = $3 ? 0 : 10;
    var $sop_0 = $3 ? 0 : 12;
    var $obj_idx1 = $obj + 8 | 0;
    var $obj_idx1_val = HEAP32[$obj_idx1 >> 2];
    var $5 = __ZNK8JSObject10isDelegateEv($obj_idx1_val);
    var $6 = $_01 & 10232;
    var $7 = __ZL12JSID_IS_ATOMi1319($id);
    if (($7 | 0) == 0) {
      var $12 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZL12JSID_TO_ATOMi1320($id);
    var $12 = $10;
    __label__ = 3;
    break;
   case 3:
    var $12;
    var $13 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($cx, 0, $native, $nargs, $6, $obj, $12);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ($5) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $obj_idx_val = HEAP32[$obj_idx1 >> 2];
    var $17 = __ZNK8JSObject10isDelegateEv($obj_idx_val);
    if ($17) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN8JSObject13clearDelegateEv($obj);
    __label__ = 7;
    break;
   case 7:
    var $20 = $13 | 0;
    __ZN2JSL11ObjectValueER8JSObject1294($1, $20);
    var $21 = $_01 & -2041;
    var $22 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj, $cx, $id, $1, $gop_0, $sop_0, $21);
    var $_ = ($22 | 0) == 0 ? 0 : $13;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12JSID_IS_ATOMi1319($id) {
  var $1 = _JSID_IS_STRING1333($id);
  return $1;
}

function __ZL12JSID_TO_ATOMi1320($id) {
  var $1 = _JSID_TO_STRING1332($id);
  return $1;
}

function __Z18js_ValueToFunctionP9JSContextPKN2JS5ValueEj($cx, $vp, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $funobj = __stackBase__;
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject1303($vp_idx_val$0, $vp_idx_val$1, $funobj);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj($cx, $vp, $flags);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $_idx_val = HEAP32[HEAP32[$funobj >> 2] + 24 >> 2];
    var $5 = __ZNK8JSObject18getFunctionPrivateEv($_idx_val);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj($cx, $vp, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $i = __stackBase__ + 24;
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $3 = $flags >>> 7 & 1 | 22;
    __ZN2js13FrameRegsIterC1EP9JSContextNS_9StackIter11SavedOptionE($i, $cx);
    var $4 = __ZNK2js13FrameRegsIter4doneEv($i);
    if ($4) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK2js13FrameRegsIter2fpEv($i);
    var $7 = __ZNK2js10StackFrame6scriptEv($6);
    var $8 = __ZNK2js13FrameRegsIter2pcEv($i);
    var $9 = _js_ReconstructStackDepth($cx, $7, $8);
    var $10 = __ZNK2js13FrameRegsIter2fpEv($i);
    var $11 = $10;
    var $12 = __ZNK2js10StackFrame4baseEv($11);
    var $13 = $12 + ($9 << 3) | 0;
    if ($12 >>> 0 > $vp >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = __ZNK2js13FrameRegsIter2spEv($i);
    var $17 = __ZN2jsL3MinIPN2JS5ValueEEET_S4_S4_($13, $16);
    if ($17 >>> 0 > $vp >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $23 = $vp - $13 >> 3;
    if (($23 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $spindex_1 = $23;
      __label__ = 6;
      break;
    }
   case 5:
    var $spindex_1 = $flags >>> 16 & 1;
    __label__ = 6;
    break;
   case 6:
    var $spindex_1;
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $27 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, $3, $spindex_1, $vp_idx_val$0, $vp_idx_val$1, 0, 0);
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z24js_ValueToFunctionObjectP9JSContextPN2JS5ValueEj($cx, $vp, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $funobj = __stackBase__;
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject1303($vp_idx_val$0, $vp_idx_val$1, $funobj);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj($cx, $vp, $flags);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $_0 = HEAP32[$funobj >> 2];
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z24js_ValueToCallableObjectP9JSContextPN2JS5ValueEj($cx, $vp, $flags) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $1 = __ZNK2JS5Value8isObjectEv($vp_idx_val$0, $vp_idx_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZN8JSObject10isCallableEv($_idx_val);
    if ($4) {
      var $_0 = $3;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj($cx, $vp, $flags);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13FrameRegsIter2spEv($this) {
  var $_idx_val = HEAP32[$this + 24 >> 2];
  var $1 = __ZNK2js9StackIter2spEv($_idx_val);
  return $1;
}

function __ZNK2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIP10JSFunctionP8JSStringEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefIP10JSFunctionEcvRS2_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefIP8JSStringEcvRS2_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv($this) {
  return;
}

function __ZNK2js9StackIter2spEv($this_0_6_val) {
  return $this_0_6_val;
}

function _JSVAL_TO_PRIVATE_UINT32_IMPL($l_0$0, $l_0$1) {
  return $l_0$0;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this_0_1_val, $this_0_2_val, $this_0_4_val) {
  return ($this_0_4_val + $this_0_2_val | 0) >>> 0 >= ($this_0_1_val * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZN2js13PointerHasherIP10JSFunctionLj2EE5matchERKS2_S5_($k_val, $l_val) {
  return ($k_val | 0) == ($l_val | 0);
}

function __ZN2js13PointerHasherIP10JSFunctionLj2EE4hashERKS2_($l_val) {
  return $l_val >>> 2;
}

function _JSID_TO_STRING1332($iden) {
  return $iden;
}

function _JSID_IS_STRING1333($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function __ZN2jsL16GetClassProtoKeyEPNS_5ClassE1345() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[__ZN2js13FunctionClassE + 4 >> 2];
    var $2 = $1 >>> 24;
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $1 >>> 17 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject15isBoundFunctionEv($this_0_2_val) {
  return ($this_0_2_val & 1024 | 0) != 0;
}

function __ZNK10JSFunction19isFunctionPrototypeEv($this_0_2_val) {
  return ($this_0_2_val & 2048) << 16 >> 16 != 0;
}

function __ZN2jsL16CastAsPropertyOpEP8JSObject1357($object) {
  return $object;
}

function __ZN2jsL22CastAsStrictPropertyOpEP8JSObject1358($object) {
  return $object;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEC2ERS9_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefIP8JSStringEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefIP10JSFunctionEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js12HashMapEntryIP10JSFunctionP8JSStringEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($e) {
  return $e | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_EC2ESB_($this) {
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  return;
}

function __ZN2js2gcL15GetGCObjectKindEjb1337($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _PRIVATE_UINT32_TO_JSVAL_IMPL($agg_result, $ui) {
  HEAP32[$agg_result + 4 >> 2] = 0;
  HEAP32[$agg_result >> 2] = $ui;
  return;
}

function __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $7 = HEAP32[$v >> 2];
    var $8 = $5 + 4 | 0;
    HEAP32[$8 >> 2] = $7;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 8 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 16 >> 2];
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 5;
    break;
   case 5:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $22 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE6isLiveEv($src_01_idx_val);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE10getKeyHashEv($src_01_idx1_val);
    var $25 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEENS_7MoveRefIT_EERSB_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEaSENS_7MoveRefIS8_EE($25, $_02_val);
    __label__ = 7;
    break;
   case 7:
    var $27 = $src_01 + 12 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($3);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej($1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEaSENS_7MoveRefIS8_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = $2 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIP10JSFunctionP8JSStringEEEENS_7MoveRefIT_EERS8_($1, $7);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js12HashMapEntryIP10JSFunctionP8JSStringEaSENS_7MoveRefIS5_EE($6, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEENS_7MoveRefIT_EERSB_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEC1ERS9_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEC1ERS9_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEC2ERS9_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIP10JSFunctionP8JSStringEaSENS_7MoveRefIS5_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIP10JSFunctionP8JSStringEEEptEv($rhs_0);
  var $4 = $3 | 0;
  __ZN2js4MoveIP10JSFunctionEENS_7MoveRefIT_EERKS4_($1, $4);
  var $_idx_val = HEAP32[$1 >> 2];
  var $5 = __ZNK2js7MoveRefIP10JSFunctionEcvRS2_Ev($_idx_val);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = $3 + 4 | 0;
  __ZN2js4MoveIP8JSStringEENS_7MoveRefIT_EERS4_($2, $8);
  var $_idx2_val = HEAP32[$2 >> 2];
  var $9 = __ZNK2js7MoveRefIP8JSStringEcvRS2_Ev($_idx2_val);
  var $10 = HEAP32[$9 >> 2];
  HEAP32[$this + 4 >> 2] = $10;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIP10JSFunctionP8JSStringEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js4MoveIP10JSFunctionEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefIP10JSFunctionEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js4MoveIP8JSStringEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefIP8JSStringEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIP8JSStringEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIP8JSStringEC2ERS2_($this, $t);
  return;
}

function __ZN2js7MoveRefIP10JSFunctionEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIP10JSFunctionEC2ERS2_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP10JSFunctionP8JSStringEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIP10JSFunctionP8JSStringEC1Ev($this) {
  __ZN2js12HashMapEntryIP10JSFunctionP8JSStringEC2Ev($this);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l_val1) {
  var $1 = __ZN2js13PointerHasherIP10JSFunctionLj2EE4hashERKS2_($l_val1);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $l_val4 = HEAP32[$l >> 2];
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($6, $l_val4);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $l_val = HEAP32[$l >> 2];
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($27, $l_val);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($e, $l_val1) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($1);
  var $_val = HEAP32[$2 >> 2];
  var $3 = __ZN2js13PointerHasherIP10JSFunctionLj2EE5matchERKS2_S5_($_val, $l_val1);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $0 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j(16);
    HEAP32[$this + 20 >> 2] = $0;
    if (($0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, 4);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES7_($this) {
  __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES7_($this);
  return;
}

function __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES7_($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_EC1ESB_($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_EC1ESB_($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_EC2ESB_($this);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry);
  return;
}

function __ZN6PutArgclEjPN2JS5ValueE($this, $src) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    var $_idx = $2 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $3 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx_val$0, $_idx_val$1);
    if ($3) {
      var $8 = $2;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $src | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $st$5$0 = $_idx | 0;
    HEAP32[$st$5$0 >> 2] = $6$0;
    var $st$5$1 = $_idx + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $6$1;
    var $8 = HEAP32[$1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $8;
    HEAP32[$1 >> 2] = $8 + 8 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL12PrivateValueEPv1335($agg_result, $ptr) {
  __ZN2JS5Value10setPrivateEPv($agg_result, $ptr);
  return;
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1338($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, $clasp, $1, $parent, 0, $7);
    var $8 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, $clasp, $kind);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $8 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $11);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb0ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE1342($cx, $parent) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = 0;
    var $2 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_1343($cx, $parent, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    var $4 = HEAP32[$1 >> 2];
    var $5 = ($4 | 0) == 0;
    if ($5) {
      var $9 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($4, $cx, 0, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      var $9 = $7;
      __label__ = 4;
      break;
    }
   case 4:
    var $9;
    var $10 = $cx;
    var $11 = __Z16js_NewGCFunctionP9JSContext($10);
    var $12 = $11;
    if (($11 | 0) == 0) {
      var $_0 = $12;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_not = ($parent | 0) == 0 ^ 1;
    var $parent_mux = $_not ? $parent : 0;
    if ($_not | $5) {
      var $19 = $parent_mux;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx_val = HEAP32[$4 + 20 >> 2];
    var $17 = __ZNK8JSObject9getParentEv($_idx_val);
    var $19 = $17;
    __label__ = 7;
    break;
   case 7:
    var $19;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($12, __ZN2js13FunctionClassE, $9, $19, 0, (__ZN2js13FunctionClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $_ZN2js13FunctionClassE_idx_val = HEAP32[__ZN2js13FunctionClassE + 4 >> 2];
    var $20 = __ZNK2js5Class8isNativeEv($_ZN2js13FunctionClassE_idx_val);
    if ($20) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $22 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE1344($cx, $12, $9);
    if ($22) {
      var $_0 = $12;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_0 = 0;
    __label__ = 11;
    break;
   case 10:
    __ZN8JSObject21setSharedNonNativeMapEv($12);
    var $_0 = $12;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_1343($cx, $parent, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL16GetClassProtoKeyEPNS_5ClassE1345();
    var $2 = $cx;
    var $3 = $parent;
    var $4 = $proto;
    var $5 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, $1, $4, __ZN2js13FunctionClassE);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$proto >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, 1, $4, 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE1344($cx, $obj, $type) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAPU32[__ZN2js13FunctionClassE + 4 >> 2] >>> 8 & 255;
    var $obj_idx_val = HEAP32[$obj + 28 >> 2];
    var $4 = __ZNK8JSObject8numSlotsEv($obj_idx_val);
    if ($3 >>> 0 > $4 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $obj;
    var $8 = $cx;
    var $9 = __ZN8JSObject10allocSlotsEP9JSContextj($7, $8, $3);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $11 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($type, __ZN2js13FunctionClassE);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($type, $cx, __ZN2js13FunctionClassE, 2);
    var $empty_0 = $13;
    __label__ = 6;
    break;
   case 5:
    var $15 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, __ZN2js13FunctionClassE);
    var $empty_0 = $15;
    __label__ = 6;
    break;
   case 6:
    var $empty_0;
    if (($empty_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($obj, $empty_0 | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL12BooleanValueEb1348($agg_result, $boo) {
  __ZN2JS5Value10setBooleanEb($agg_result, $boo);
  return;
}

function __ZN2JSL14UndefinedValueEv1350($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN8JSObject17initBoundFunctionEP9JSContextRKN2JS5ValueEPS4_j($this, $cx, $thisArg, $args, $argslen) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 8 | 0;
    var $4 = HEAP32[$2 >> 2] | 1024;
    HEAP32[$2 >> 2] = $4;
    var $thisArg_idx = $thisArg | 0;
    var $thisArg_idx_val$0 = HEAP32[$thisArg_idx >> 2];
    var $thisArg_idx_val$1 = HEAP32[$thisArg_idx + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, 0, $thisArg_idx_val$0, $thisArg_idx_val$1);
    __ZN2JSL18PrivateUint32ValueEj($1, $argslen);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, 1, $_idx_val$0, $_idx_val$1);
    if (($argslen | 0) == 0) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $7 = __ZNK8JSObject8getClassEv($this_idx_val);
    var $8 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, $7);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = $8 | 0;
    var $12 = $8 + 4 | 0;
    var $14 = HEAP32[$12 >> 2] + $argslen | 0;
    HEAP32[$12 >> 2] = $14;
    __ZN8JSObject6setMapEPN2js5ShapeE($this, $11);
    var $15 = $this;
    var $16 = $cx;
    var $17 = __ZN8JSObject27ensureInstanceReservedSlotsEP9JSContextj($15, $16, $argslen);
    if ($17) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    __ZN8JSObject13copySlotRangeEjPKN2JS5ValueEj($15, 2, $args, $argslen);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL18PrivateUint32ValueEj($agg_result, $ui) {
  __ZN2JS5Value16setPrivateUint32Ej($agg_result, $ui);
  return;
}

function __ZN2JS5Value16setPrivateUint32Ej($this, $ui) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _PRIVATE_UINT32_TO_JSVAL_IMPL($1, $ui);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2JS5Value15toPrivateUint32Ev($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_TO_PRIVATE_UINT32_IMPL($this_0_0_0_val$0, $this_0_0_0_val$1);
  return $1;
}

function __ZN8JSObject27finalizeUpvarsIfFlatClosureEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 24 >> 2];
    var $1 = __ZNK8JSObject18getFunctionPrivateEv($this_idx_val);
    if (($1 | 0) == 0 | ($1 | 0) == ($this | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx2_val = HEAP16[$1 + 58 >> 1];
    var $6 = __ZNK10JSFunction13isFlatClosureEv($_idx2_val);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $8 = __ZNK8JSObject7getSlotEj($this, 0);
    var $_idx = $8 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $9 = __ZNK2JS5Value8isDoubleEv($_idx_val$0, $_idx_val$1);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = __ZNK2JS5Value9toPrivateEv($_idx_val$0, $_idx_val$1);
    __ZN2js10Foreground5free_EPv($11);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject17getThrowTypeErrorEv($this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject9getGlobalEv($1);
  var $3 = $2;
  var $4 = __ZNK2js12GlobalObject17getThrowTypeErrorEv($3);
  return $4;
}

function __ZL14JSID_FROM_BITSj1372($bits) {
  return $bits;
}

function __ZNK10JSFunction8joinableEv($this_0_2_val) {
  return ($this_0_2_val & 1) << 16 >> 16 != 0;
}

function __ZNK2js10StackFrame19isFloatingGeneratorEv($this_0_0_val) {
  return ($this_0_0_val & 64 | 0) != 0;
}

function __ZN2js7analyzeL7ArgSlotEj1371($arg) {
  return $arg + 2 | 0;
}

function _INT_TO_JSID1373($i) {
  return $i << 1 | 1;
}

function __ZNK2js2gc5Chunk18hasAvailableArenasEv($this_0_2_4_val) {
  return ($this_0_2_4_val | 0) != 0;
}

function __ZN8JSObject17asStrictArgumentsEv($this) {
  return $this;
}

function __ZN8JSObject17asNormalArgumentsEv($this) {
  return $this;
}

function __ZN2js10StackFrame17setOverriddenArgsEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1024;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN6PutArgC2EPN2JS5ValueE($this, $dst) {
  HEAP32[$this >> 2] = $dst;
  return;
}

function __ZN2js2gc11ArenaHeader17setAsNotAllocatedEv($this) {
  HEAP32[$this + 12 >> 2] = 20;
  return;
}

function __ZN2js2gc11ArenaHeader4initEP13JSCompartmentNS0_9AllocKindE($this, $comp, $kind) {
  HEAP32[$this >> 2] = $comp;
  var $4 = $this + 12 | 0;
  var $7 = HEAP32[$4 >> 2] & -256 | $kind & 255;
  HEAP32[$4 >> 2] = $7;
  HEAP32[$this + 8 >> 2] = 268374016;
  return;
}

function __ZN2js2gc5Chunk23removeFromAvailableListEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 1048320 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $this + 1048324 | 0;
    var $4 = HEAP32[$3 >> 2];
    HEAP32[$4 >> 2] = $2;
    var $5 = HEAP32[$1 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$3 >> 2];
    var $9 = $5 + 1048324 | 0;
    HEAP32[$9 >> 2] = $8;
    __label__ = 3;
    break;
   case 3:
    HEAP32[$3 >> 2] = 0;
    HEAP32[$1 >> 2] = 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15fun_getPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $_01_idx_val = HEAP32[$_01 + 4 >> 2];
    var $2 = __ZNK8JSObject10isFunctionEv($_01_idx_val);
    if ($2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_01_idx8_val_idx_val = HEAP32[HEAP32[$_01 + 36 >> 2] >> 2];
    var $4 = __ZNK8JSObject8getProtoEv($_01_idx8_val_idx_val);
    if (($4 | 0) == 0) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      var $_01 = $4;
      __label__ = 2;
      break;
    }
   case 4:
    var $_01_idx5_val = HEAP32[$_01 + 24 >> 2];
    var $7 = __ZNK8JSObject18getFunctionPrivateEv($_01_idx5_val);
    var $_idx7_val = HEAP16[$7 + 58 >> 1];
    var $8 = __ZNK10JSFunction13isInterpretedEv($_idx7_val);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $10 = __ZNK10JSFunction6scriptEv($7);
    var $11 = $10 + 38 | 0;
    var $13 = HEAP8[$11] | 4;
    HEAP8[$11] = $13;
    var $14 = $7 | 0;
    __ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj($cx, $14, 1048576);
    __label__ = 6;
    break;
   case 6:
    __ZN2JS5Value7setNullEv($vp);
    var $16 = __ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind1359($cx);
    if (($16 | 0) == 0) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      var $fp_0 = $16;
      __label__ = 7;
      break;
    }
   case 7:
    var $fp_0;
    var $fp_0_idx2_val = HEAP32[$fp_0 >> 2];
    var $18 = __ZNK2js10StackFrame15isFunctionFrameEv($fp_0_idx2_val);
    if ($18) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $20 = __ZNK2js10StackFrame3funEv($fp_0);
    if (($20 | 0) == ($7 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $fp_0_idx1_val = HEAP32[$fp_0 + 16 >> 2];
    var $22 = __ZNK2js10StackFrame4prevEv($fp_0_idx1_val);
    if (($22 | 0) == 0) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      var $fp_0 = $22;
      __label__ = 7;
      break;
    }
   case 10:
    var $26 = HEAP32[$cx + 52 >> 2];
    var $29 = HEAP32[$26 + 210176 >> 2] | 0;
    var $30 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $29);
    if (($30 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $33 = _JS_ReportErrorFlagsAndNumber($cx, 5, 158, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str142435 | 0, tempInt));
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $36 = __Z15js_GetArgsValueP9JSContextPN2js10StackFrameEPN2JS5ValueE($cx, $fp_0, $vp);
    var $_0 = $36;
    __label__ = 24;
    break;
   case 13:
    var $40 = HEAP32[$26 + 210196 >> 2] | 0;
    var $41 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $40);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $fp_0_idx_val = HEAP32[$fp_0 + 16 >> 2];
    var $44 = __ZNK2js10StackFrame4prevEv($fp_0_idx_val);
    if (($44 | 0) == 0) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $47 = __Z20js_GetScriptedCallerP9JSContextPN2js10StackFrameE($cx, $44);
    if (($47 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $50 = __ZN2js10StackFrame20getValidCalleeObjectEP9JSContextPN2JS5ValueE($47, $cx, $vp);
    if ($50) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 17:
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $52 = __ZNK2JS5Value8isObjectEv($vp_idx_val$0, $vp_idx_val$1);
    if ($52) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 1;
      __label__ = 24;
      break;
    }
   case 18:
    var $54 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
    var $55 = $54;
    var $56 = __ZNK2js2gc4Cell11compartmentEv($55);
    if (($56 | 0) == (HEAP32[$cx + 56 >> 2] | 0)) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    __ZN2JS5Value7setNullEv($vp);
    var $_0 = 1;
    __label__ = 24;
    break;
   case 20:
    var $_idx_val = HEAP32[$54 + 4 >> 2];
    var $62 = __ZNK8JSObject10isFunctionEv($_idx_val);
    if ($62) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 1;
      __label__ = 24;
      break;
    }
   case 21:
    var $_idx4_val = HEAP32[$54 + 24 >> 2];
    var $64 = __ZNK8JSObject18getFunctionPrivateEv($_idx4_val);
    var $_idx6_val = HEAP16[$64 + 58 >> 1];
    var $65 = __ZNK10JSFunction13isInterpretedEv($_idx6_val);
    if ($65) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 1;
      __label__ = 24;
      break;
    }
   case 22:
    var $67 = __ZNK10JSFunction12inStrictModeEv($64);
    if ($67) {
      __label__ = 23;
      break;
    } else {
      var $_0 = 1;
      __label__ = 24;
      break;
    }
   case 23:
    var $69 = _JS_ReportErrorFlagsAndNumber($cx, 0, 256, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 24:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15fun_getPropertyP9JSContextP8JSObjectiPN2JS5ValueE["X"] = 1;

function __ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind1359($cx) {
  var $1 = __ZNK9JSContext7maybefpEv($cx);
  return $1;
}

function __ZNK2js12GlobalObject17getThrowTypeErrorEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK8JSObject7getSlotEj($1, 111);
  var $_idx = $2 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $3 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
  return $3;
}

function __ZN8JSObject11hasPropertyEP9JSContextiPbj($this, $cx, $id, $foundp, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $rf = __stackBase__ + 8;
    __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $cx, $flags);
    var $1 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($this, $cx, $id, $pobj, $prop);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP8[$foundp] = (HEAP32[$prop >> 2] | 0) != 0 & 1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    var $rf_idx_val = HEAP32[$rf >> 2];
    var $rf_idx1_val = HEAP32[$rf + 4 >> 2];
    __ZN18JSAutoResolveFlagsD1Ev($rf_idx_val, $rf_idx1_val);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18MaybeMarkGeneratorP8JSTracerP8JSObject($trc, $obj_0_6_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject10getPrivateEv($obj_0_6_val);
    if (($1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$1 >> 2];
    var $4 = __ZNK2js10StackFrame19isFloatingGeneratorEv($_idx_val);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = $1;
    var $7 = __Z27js_FloatingFrameToGeneratorPN2js10StackFrameE($6);
    var $9 = HEAP32[$7 >> 2];
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $9);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16GetCallArgumentsEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject6asCallEv($obj);
    var $2 = $1;
    var $3 = __ZNK2js10CallObject15maybeStackFrameEv($2);
    if (($3 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$3 >> 2];
    var $6 = __ZNK2js10StackFrame17hasOverriddenArgsEv($_idx_val);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __Z16js_GetArgsObjectP9JSContextPN2js10StackFrameE($cx, $3);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value9setObjectER8JSObject($vp, $8);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $12 = __ZNK2js10CallObject12getArgumentsEv($2);
    var $13 = $12 | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $vp | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16SetCallArgumentsEP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject6asCallEv($obj);
    var $2 = $1;
    var $3 = __ZNK2js10CallObject15maybeStackFrameEv($2);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js10StackFrame17setOverriddenArgsEv($3);
    __label__ = 3;
    break;
   case 3:
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    __ZN2js10CallObject12setArgumentsERKN2JS5ValueE($2, $vp_idx_val$0, $vp_idx_val$1);
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10CallObject12getArgumentsEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK8JSObject12getFixedSlotEj($1, 1);
  return $2;
}

function __ZN2js5types10TypeScript8SetLocalEP9JSContextP8JSScriptjNS0_4TypeE($cx, $script, $local, $type_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZN2js5types10TypeScript10LocalTypesEP8JSScriptj($script, $local);
    var $4 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($3, $type_0);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    var $6 = __ZN2js5types10TypeScript10LocalTypesEP8JSScriptj($script, $local);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($6, $cx, $type_0);
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript10LocalTypesEP8JSScriptj($script, $i) {
  var $2 = HEAP32[$script + 100 >> 2];
  var $3 = __ZN2js5types10TypeScript9typeArrayEv($2);
  var $6 = HEAPU16[$script + 22 >> 1] & 65535;
  var $7 = __ZN2js7analyzeL9LocalSlotEP8JSScriptj1368($script, $i);
  return $3 + ($6 + $7) * 12 | 0;
}

function __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($this, $type_0) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx3_val = HEAP32[$this >> 2];
    var $1 = __ZNK2js5types7TypeSet7unknownEv($this_idx3_val);
    if ($1) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js5types4Type9isUnknownEv($type_0);
    if ($3) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK2js5types4Type11isPrimitiveEv($type_0);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZNK2js5types4Type9primitiveEv($type_0);
    var $8 = __ZN2js5types17PrimitiveTypeFlagE11JSValueType($7);
    var $_0 = ($8 & $this_idx3_val | 0) != 0;
    __label__ = 7;
    break;
   case 5:
    var $12 = __ZNK2js5types4Type11isAnyObjectEv($type_0);
    var $14 = ($this_idx3_val & 128 | 0) != 0;
    if ($12 | $14) {
      var $_0 = $14 | $12 ^ 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = HEAP32[$this + 4 >> 2];
    var $18 = __ZNK2js5types7TypeSet15baseObjectCountEv($this_idx3_val);
    var $19 = __ZNK2js5types4Type9objectKeyEv($type_0);
    var $20 = __ZN2js5typesL13HashSetLookupIPNS0_13TypeObjectKeyES2_S2_EEPT0_PS5_jT_($17, $18, $19);
    var $_0 = ($20 | 0) != 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5typesL15HashSetCapacityEj1366($count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 < 9) {
      var $_0 = 8;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $count | 1;
    var $4 = _llvm_ctlz_i32($3);
    var $_0 = 1 << 33 - $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5typesL7HashKeyIPNS0_13TypeObjectKeyES2_EEjT_1367($v) {
  var $1 = __ZN2js5types13TypeObjectKey7keyBitsEPS1_($v);
  return ((($1 & 255 ^ 84696351) * 16777619 ^ $1 >>> 8 & 255) * 16777619 ^ $1 >>> 16 & 255) * 16777619 ^ $1 >>> 24;
}

function __ZN2js5typesL13HashSetLookupIPNS0_13TypeObjectKeyES2_S2_EEPT0_PS5_jT_($values, $count, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($count | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($count | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $2 = $values;
    var $3 = __ZN2js5types13TypeObjectKey6getKeyEPS1_($2);
    var $5 = ($3 | 0) == ($key | 0) ? $2 : 0;
    var $_0 = $5;
    __label__ = 11;
    break;
   case 3:
    if ($count >>> 0 < 9) {
      var $i_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $i_0;
    if ($i_0 >>> 0 < $count >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $11 = HEAPU32[$values + ($i_0 << 2) >> 2];
    var $12 = __ZN2js5types13TypeObjectKey6getKeyEPS1_($11);
    if (($12 | 0) == ($key | 0)) {
      var $_0 = $11;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 4;
    break;
   case 7:
    var $17 = __ZN2js5typesL15HashSetCapacityEj1366($count);
    var $18 = __ZN2js5typesL7HashKeyIPNS0_13TypeObjectKeyES2_EEjT_1367($key);
    var $19 = $17 - 1 | 0;
    var $_pn = $18;
    __label__ = 8;
    break;
   case 8:
    var $_pn;
    var $pos_0 = $_pn & $19;
    var $22 = HEAP32[$values + ($pos_0 << 2) >> 2];
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $25 = __ZN2js5types13TypeObjectKey6getKeyEPS1_($22);
    if (($25 | 0) == ($key | 0)) {
      var $_0 = $22;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_pn = $pos_0 + 1 | 0;
    __label__ = 8;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyzeL9LocalSlotEP8JSScriptj1368($script, $local) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$script + 37 | 0] & 4) << 24 >> 24 == 0) {
      var $11 = 2;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $script_idx_val_idx_val = HEAP32[HEAP32[$script + 100 >> 2] + 4 >> 2];
    var $6 = __ZNK8JSScript8functionEv($script_idx_val_idx_val);
    var $11 = (HEAPU16[$6 + 56 >> 1] & 65535) + 2 | 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11 + $local | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript11SetArgumentEP9JSContextP8JSScriptjNS0_4TypeE($cx, $script, $arg, $type_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $script_idx3 = $script + 22 | 0;
    var $script_idx3_val = HEAP16[$script_idx3 >> 1];
    var $script_idx4 = $script + 100 | 0;
    var $script_idx4_val = HEAP32[$script_idx4 >> 2];
    var $3 = __ZN2js5types10TypeScript8ArgTypesEP8JSScriptj($script_idx3_val, $script_idx4_val, $arg);
    var $4 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($3, $type_0);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    var $script_idx_val = HEAP16[$script_idx3 >> 1];
    var $script_idx2_val = HEAP32[$script_idx4 >> 2];
    var $6 = __ZN2js5types10TypeScript8ArgTypesEP8JSScriptj($script_idx_val, $script_idx2_val, $arg);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($6, $cx, $type_0);
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript8ArgTypesEP8JSScriptj($script_0_11_val, $script_0_32_val, $i) {
  var $1 = __ZN2js5types10TypeScript9typeArrayEv($script_0_32_val);
  var $2 = $script_0_11_val & 65535;
  var $3 = __ZN2js7analyzeL7ArgSlotEj1371($i);
  return $1 + ($2 + $3) * 12 | 0;
}

function __ZN2js10EmptyShape20getEmptyDeclEnvShapeEP9JSContext($cx) {
  var $3 = HEAP32[$cx + 56 >> 2] + 760 | 0;
  var $4 = __ZN2js10EmptyShape6ensureEP9JSContextPNS_5ClassEPPS0_($cx, __ZN2js12DeclEnvClassE, $3);
  return $4;
}

function __ZN2js10EmptyShape6ensureEP9JSContextPNS_5ClassEPPS0_($cx, $clasp, $shapep) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$shapep >> 2];
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $1;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, $clasp);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$shapep >> 2] = $4;
    var $_0 = $4;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15StrictArgGetterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $1 = __ZNK8JSObject17isStrictArgumentsEv($obj_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $3 = __ZN8JSObject17asStrictArgumentsEv($obj);
    var $4 = _JSID_IS_INT1285($id);
    if (($4 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = _JSID_TO_INT1286($id);
    var $8 = $3 | 0;
    var $9 = __ZNK2js15ArgumentsObject13initialLengthEv($8);
    if ($7 >>> 0 < $9 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $12 = __ZNK2js15ArgumentsObject7elementEj($8, $7);
    var $_idx = $12 | 0;
    var $_idx_val$0 = HEAPU32[$_idx >> 2];
    var $_idx_val$1 = HEAPU32[$_idx + 4 >> 2];
    var $13 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx_val$0, $_idx_val$1);
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = $vp | 0;
    HEAP32[$15 >> 2] = $_idx_val$0;
    HEAP32[$15 + 4 >> 2] = $_idx_val$1;
    __label__ = 8;
    break;
   case 6:
    var $17 = $3 | 0;
    var $18 = __ZNK2js15ArgumentsObject19hasOverriddenLengthEv($17);
    if ($18) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = __ZNK2js15ArgumentsObject13initialLengthEv($17);
    __ZN2JS5Value8setInt32Ei($vp, $20);
    __label__ = 8;
    break;
   case 8:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15StrictArgSetterP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $1 = __ZNK8JSObject17isStrictArgumentsEv($obj_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 2:
    var $3 = __ZN8JSObject17asStrictArgumentsEv($obj);
    var $4 = _JSID_IS_INT1285($id);
    if (($4 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = _JSID_TO_INT1286($id);
    var $8 = $3 | 0;
    var $9 = __ZNK2js15ArgumentsObject13initialLengthEv($8);
    if ($7 >>> 0 < $9 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    __ZN2js15ArgumentsObject10setElementEjRKN2JS5ValueE($8, $7, $vp_idx_val$0, $vp_idx_val$1);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 5:
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $13 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $14 = $cx;
    var $15 = $3;
    var $16 = __Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($14, $15, $id, $13, $strict);
    if (($16 | 0) == 0) {
      var $22 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($14, $15, $id, 0, $vp, $strict);
    var $22 = ($19 | 0) != 0;
    __label__ = 7;
    break;
   case 7:
    var $22;
    var $23 = $22 & 1;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_0 = $23;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15ArgumentsObject10setElementEjRKN2JS5ValueE($this, $i, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  var $1 = __ZNK2js15ArgumentsObject4dataEv($this);
  var $2 = $1 + 8 + ($i << 3) | 0;
  HEAP32[$2 >> 2] = $v_0_0_0_val$0;
  HEAP32[$2 + 4 >> 2] = $v_0_0_0_val$1;
  return;
}

function __ZNK2js21NormalArgumentsObject6calleeEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js15ArgumentsObject4dataEv($1);
  return $2 | 0;
}

function __ZL9ArgGetterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$obj + 4 >> 2];
    var $2 = __ZNK8JSObject17isNormalArgumentsEv($_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    var $4 = __ZN8JSObject17asNormalArgumentsEv($obj);
    var $5 = _JSID_IS_INT1285($id);
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = _JSID_TO_INT1286($id);
    var $9 = $4 | 0;
    var $10 = __ZNK2js15ArgumentsObject13initialLengthEv($9);
    if ($8 >>> 0 < $10 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 4:
    var $13 = __ZNK2js15ArgumentsObject15maybeStackFrameEv($9);
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = __ZNK2js10StackFrame18canonicalActualArgEj($13, $8);
    var $17 = $16 | 0;
    var $st$2$0 = $17 | 0;
    var $18$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $17 + 4 | 0;
    var $18$1 = HEAP32[$st$2$1 >> 2];
    var $19 = $vp | 0;
    var $st$7$0 = $19 | 0;
    HEAP32[$st$7$0 >> 2] = $18$0;
    var $st$7$1 = $19 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $18$1;
    __label__ = 12;
    break;
   case 6:
    var $21 = __ZNK2js15ArgumentsObject7elementEj($9, $8);
    var $22 = $21 | 0;
    var $st$2$0 = $22 | 0;
    var $23$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $22 + 4 | 0;
    var $23$1 = HEAP32[$st$2$1 >> 2];
    var $24 = $vp | 0;
    var $st$7$0 = $24 | 0;
    HEAP32[$st$7$0 >> 2] = $23$0;
    var $st$7$1 = $24 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $23$1;
    __label__ = 12;
    break;
   case 7:
    var $30 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $31 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $30);
    if (($31 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $34 = $4 | 0;
    var $35 = __ZNK2js15ArgumentsObject19hasOverriddenLengthEv($34);
    if ($35) {
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $37 = __ZNK2js15ArgumentsObject13initialLengthEv($34);
    __ZN2JS5Value8setInt32Ei($vp, $37);
    __label__ = 12;
    break;
   case 10:
    var $39 = __ZNK2js21NormalArgumentsObject6calleeEv($4);
    var $_idx1 = $39 | 0;
    var $st$2$0 = $_idx1 | 0;
    var $_idx1_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx1 + 4 | 0;
    var $_idx1_val$1 = HEAP32[$st$2$1 >> 2];
    var $40 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx1_val$0, $_idx1_val$1);
    if ($40) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $42 = $vp | 0;
    HEAP32[$42 >> 2] = $_idx1_val$0;
    HEAP32[$42 + 4 >> 2] = $_idx1_val$1;
    __label__ = 12;
    break;
   case 12:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9ArgGetterP9JSContextP8JSObjectiPN2JS5ValueE["X"] = 1;

function __ZL9ArgSetterP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $_idx_val = HEAP32[$obj + 4 >> 2];
    var $2 = __ZNK8JSObject17isNormalArgumentsEv($_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 2:
    var $4 = __ZN8JSObject17asNormalArgumentsEv($obj);
    var $5 = _JSID_IS_INT1285($id);
    if (($5 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = _JSID_TO_INT1286($id);
    var $9 = $4 | 0;
    var $10 = __ZNK2js15ArgumentsObject13initialLengthEv($9);
    if ($8 >>> 0 < $10 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    var $13 = __ZNK2js15ArgumentsObject15maybeStackFrameEv($9);
    if (($13 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = __ZNK2js10StackFrame14functionScriptEv($13);
    if ((HEAP8[$16 + 36 | 0] & 64) << 24 >> 24 == 0) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = __ZNK2js10StackFrame13numFormalArgsEv($13);
    if ($8 >>> 0 < $22 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2js5types10TypeScript11SetArgumentEP9JSContextP8JSScriptjRKN2JS5ValueE($cx, $16, $8, $vp);
    __label__ = 8;
    break;
   case 8:
    var $26 = __ZNK2js10StackFrame18canonicalActualArgEj($13, $8);
    var $27 = $vp | 0;
    var $28$0 = HEAP32[$27 >> 2];
    var $28$1 = HEAP32[$27 + 4 >> 2];
    var $29 = $26 | 0;
    HEAP32[$29 >> 2] = $28$0;
    HEAP32[$29 + 4 >> 2] = $28$1;
    var $_0 = 1;
    __label__ = 12;
    break;
   case 9:
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $31 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $32 = $cx;
    var $33 = $4;
    var $34 = __Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($32, $33, $id, $31, 0);
    if (($34 | 0) == 0) {
      var $40 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $37 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($32, $33, $id, $vp, 0, 0, 1);
    var $40 = ($37 | 0) != 0;
    __label__ = 11;
    break;
   case 11:
    var $40;
    var $41 = $40 & 1;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_0 = $41;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9ArgSetterP9JSContextP8JSObjectiiPN2JS5ValueE["X"] = 1;

function __ZN2JSL10MagicValueE10JSWhyMagic1374($agg_result) {
  __ZN2JS5Value8setMagicE10JSWhyMagic($agg_result, 1);
  return;
}

function __ZN2js15ArgumentsObject20markLengthOverriddenEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $3 = __ZNK8JSObject7getSlotEj($2, 0);
  var $_idx = $3 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $4 = __ZNK2JS5Value7toInt32Ev($_idx_val$0, $_idx_val$1);
  var $5 = $4 | 1;
  __ZN2JSL10Int32ValueEi1375($1, $5);
  var $_idx1 = $1 | 0;
  var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
  var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, 0, $_idx1_val$0, $_idx1_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js21NormalArgumentsObject11clearCalleeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $3 = __ZNK2js15ArgumentsObject4dataEv($2);
  __ZN2JSL10MagicValueE10JSWhyMagic1374($1);
  var $4 = $1 | 0;
  var $5$0 = HEAP32[$4 >> 2];
  var $5$1 = HEAP32[$4 + 4 >> 2];
  var $6 = $3 | 0;
  HEAP32[$6 >> 2] = $5$0;
  HEAP32[$6 + 4 >> 2] = $5$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2JSL10Int32ValueEi1375($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueES2_1378($beg, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($beg | 0) == ($end | 0)) {
      __label__ = 3;
      break;
    } else {
      var $v_01 = $beg;
      __label__ = 2;
      break;
    }
   case 2:
    var $v_01;
    __ZN2JS5Value12setUndefinedEv($v_01);
    var $2 = $v_01 + 8 | 0;
    if (($2 | 0) == ($end | 0)) {
      __label__ = 3;
      break;
    } else {
      var $v_01 = $2;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc5Chunk4initEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 1032192 | 0;
    var $prevp_01 = $this + 1048328 | 0;
    var $a_02 = $this | 0;
    __label__ = 2;
    break;
   case 2:
    var $a_02;
    var $prevp_01;
    var $4 = $a_02 | 0;
    HEAP32[$prevp_01 >> 2] = $4;
    __ZN2js2gc11ArenaHeader17setAsNotAllocatedEv($4);
    var $6 = $a_02 + 4096 | 0;
    if (($6 | 0) == ($1 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $prevp_01 = $a_02 + 4 | 0;
      var $a_02 = $6;
      __label__ = 2;
      break;
    }
   case 3:
    HEAP32[$this + 1028100 >> 2] = 0;
    var $9 = $this + 1032192 | 0;
    __ZN2js2gc11ChunkBitmap5clearEv($9);
    HEAP32[$this + 1048332 >> 2] = 0;
    HEAP32[$this + 1048336 >> 2] = 252;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc11ChunkBitmap5clearEv($this) {
  var $1 = $this | 0;
  __ZN2jsL12PodArrayZeroIjLj4032EEEvRAT0__T_($1);
  return;
}

function __ZN2js2gc5Chunk13allocateArenaEP13JSCompartmentNS0_9AllocKindE($this, $comp, $thingKind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 1048328 | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $4 = HEAP32[$2 + 4 >> 2];
    HEAP32[$1 >> 2] = $4;
    __ZN2js2gc11ArenaHeader4initEP13JSCompartmentNS0_9AllocKindE($2, $comp, $thingKind);
    var $5 = $this + 1048336 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = __ZNK2js2gc5Chunk18hasAvailableArenasEv($7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc5Chunk23removeFromAvailableListEv($this);
    __label__ = 3;
    break;
   case 3:
    var $13 = HEAP32[$comp >> 2] + 140 | 0;
    var $15 = HEAP32[$13 >> 2] + 4096 | 0;
    HEAP32[$13 >> 2] = $15;
    var $16 = $comp + 328 | 0;
    var $18 = HEAP32[$16 >> 2] + 4096 | 0;
    HEAP32[$16 >> 2] = $18;
    if ($18 >>> 0 < HEAPU32[$comp + 332 >> 2] >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js20TriggerCompartmentGCEP13JSCompartment($comp);
    __label__ = 5;
    break;
   case 5:
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js2gc5Chunk6unusedEv($this_0_2_4_val) {
  return ($this_0_2_4_val | 0) == 252;
}

function __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($this_0_0_val, $this_0_1_val) {
  return ($this_0_0_val | 0) == ($this_0_1_val | 0);
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($this_0_0_val, $this_0_1_val) {
  return ($this_0_0_val | 0) == ($this_0_1_val | 0);
}

function __ZN2jsL3MaxIjEET_S1_S1_($t1) {
  var $2 = $t1 >>> 0 > 31457280 ? $t1 : 31457280;
  return $2;
}

function __ZN2jsL3MinIfEET_S1_S1_($t1, $t2) {
  var $2 = $t1 < $t2 ? $t1 : $t2;
  return $2;
}

function __ZN2js2gc11IsGCAllowedEP9JSContext($cx_0_11_val_0_67_2_val) {
  return ($cx_0_11_val_0_67_2_val & 1) << 24 >> 24 == 0;
}

function __ZNK2JS5Value11payloadWordEv($this) {
  return $this;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5clearEv($this) {
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN2js20TriggerCompartmentGCEP13JSCompartment($comp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $comp | 0;
    var $2 = HEAPU32[$1 >> 2];
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[__ZN2js8gcReasonE >> 2] = 4;
    __label__ = 4;
    break;
   case 3:
    var $7 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $7;
    __label__ = 4;
    break;
   case 4:
    if ((HEAP32[$2 + 192 >> 2] | 0) == 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    if ((HEAP32[$2 >> 2] | 0) == ($comp | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js9TriggerGCEP9JSRuntime($2);
    __label__ = 14;
    break;
   case 7:
    var $18 = $2 + 196 | 0;
    if ((HEAP32[$18 >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = $2 + 144076 | 0;
    if ((HEAP32[$22 >> 2] | 0) == ($comp | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    HEAP32[$22 >> 2] = 0;
    __label__ = 14;
    break;
   case 10:
    var $28 = HEAPU32[$2 + 140 >> 2];
    if ($28 >>> 0 > 8192) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    if ($28 >>> 0 < ((HEAPU32[$2 + 144 >> 2] >>> 1) * 3 | 0) >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN2js9TriggerGCEP9JSRuntime($2);
    __label__ = 14;
    break;
   case 13:
    HEAP32[$18 >> 2] = 1;
    HEAP32[$2 + 144076 >> 2] = $comp;
    var $39 = HEAP32[$1 >> 2];
    __ZN2js28TriggerAllOperationCallbacksEP9JSRuntime($39);
    __label__ = 14;
    break;
   case 14:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc5Chunk12releaseArenaEPNS0_11ArenaHeaderE($this, $aheader) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $aheader | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$3 >> 2];
    var $6 = $5 + 140 | 0;
    var $8 = HEAP32[$6 >> 2] - 4096 | 0;
    HEAP32[$6 >> 2] = $8;
    var $9 = $3 + 328 | 0;
    var $11 = HEAP32[$9 >> 2] - 4096 | 0;
    HEAP32[$9 >> 2] = $11;
    __ZN2js2gc11ArenaHeader17setAsNotAllocatedEv($aheader);
    var $12 = $this + 1048328 | 0;
    var $13 = HEAP32[$12 >> 2];
    HEAP32[$aheader + 4 >> 2] = $13;
    HEAP32[$12 >> 2] = $aheader;
    var $15 = $this + 1048336 | 0;
    var $16 = HEAP32[$15 >> 2];
    var $17 = $16 + 1 | 0;
    HEAP32[$15 >> 2] = $17;
    if (($16 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $20 = HEAP32[$2 >> 2];
    var $_idx_val = HEAP32[$20 >> 2];
    var $_idx1_val = HEAP8[$20 + 341 | 0];
    __ZN2js2gc5Chunk18addToAvailableListEP13JSCompartment($this, $_idx_val, $_idx1_val);
    __label__ = 5;
    break;
   case 3:
    var $22 = __ZNK2js2gc5Chunk6unusedEv($17);
    if ($22) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $24 = $5 + 48 | 0;
    HEAP32[$1 >> 2] = $this;
    __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6removeERKS3_($24, $1);
    __ZN2js2gc5Chunk23removeFromAvailableListEv($this);
    HEAP32[$this + 1048332 >> 2] = 0;
    var $26 = $5 + 80 | 0;
    var $27 = HEAP32[$26 >> 2];
    HEAP32[$this + 1048320 >> 2] = $27;
    HEAP32[$26 >> 2] = $this;
    var $29 = $5 + 84 | 0;
    var $31 = HEAP32[$29 >> 2] + 1 | 0;
    HEAP32[$29 >> 2] = $31;
    __label__ = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc5Chunk12releaseArenaEPNS0_11ArenaHeaderE["X"] = 1;

function __ZN2js2gc5Chunk18addToAvailableListEP13JSCompartment($this, $comp_0_0_val, $comp_0_7_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z21GetAvailableChunkListP13JSCompartment($comp_0_0_val, $comp_0_7_val);
    var $2 = $this + 1048320 | 0;
    HEAP32[$this + 1048324 >> 2] = $1;
    var $4 = HEAP32[$1 >> 2];
    var $_pre = $2 | 0;
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4 + 1048324 | 0;
    HEAP32[$7 >> 2] = $_pre;
    __label__ = 3;
    break;
   case 3:
    HEAP32[$_pre >> 2] = $4;
    HEAP32[$1 >> 2] = $this;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6removeERKS3_($this, $l) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 4;
    __ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6lookupERKS3_($p, $this, $l);
    var $p_idx_val = HEAP32[$p >> 2];
    var $p_idx_val_idx_val = HEAP32[$p_idx_val >> 2];
    __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($1, $p_idx_val_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS3_NS6_6SetOpsES5_E3PtrE($this, $p_idx_val);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z20IsAboutToBeFinalizedP9JSContextPKv($cx_0_11_val_0_36_val, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $thing;
    var $2 = __ZNK2js2gc4Cell11compartmentEv($1);
    if (($cx_0_11_val_0_36_val | 0) == 0 | ($2 | 0) == ($cx_0_11_val_0_36_val | 0)) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZNK2js2gc4Cell8isMarkedEj($1);
    var $_0 = $6 ^ 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js2gc4Cell8isMarkedEj($this) {
  var $1 = __ZNK2js2gc4Cell5chunkEv($this);
  var $2 = $1 + 1032192 | 0;
  var $3 = __ZN2js2gc11ChunkBitmap8isMarkedEPKNS0_4CellEj($2, $this);
  return $3;
}

function __Z9js_InitGCP9JSRuntimej($rt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $rt + 48 | 0;
    var $2 = __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE4initEj($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = $rt + 88 | 0;
    var $5 = __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE4initEj($4);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $7 = $rt + 112 | 0;
    var $8 = __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE4initEj($7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$rt + 152 >> 2] = 33554432;
    __ZN9JSRuntime19setGCMaxMallocBytesEj($rt, 33554432);
    HEAP32[$rt + 160 >> 2] = 3e4;
    __ZN9JSRuntime14setGCLastBytesEj18JSGCInvocationKind($rt, 8192, 0);
    var $12 = _PRMJ_Now();
    var $12$0 = $12[0];
    var $12$1 = $12[1];
    var $13$0 = (i64Math.add($12$0, $12$1, 6e7, 0), i64Math.result[0]);
    var $13$1 = i64Math.result[1];
    var $14 = $rt + 184 | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj($1);
  return $2;
}

function __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj($1);
  return $2;
}

function __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E4initEj($1);
  return $2;
}

function __ZN9JSRuntime14setGCLastBytesEj18JSGCInvocationKind($this, $lastBytes, $gckind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this + 148 >> 2] = $lastBytes;
    if (($gckind | 0) == 2) {
      var $6 = $lastBytes;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2jsL3MaxIjEET_S1_S1_($lastBytes);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    var $11 = HEAPU32[$this + 152 >> 2] >>> 0;
    var $12 = __ZN2jsL3MinIfEET_S1_S1_($11, ($6 >>> 0) * 3);
    var $13 = $12 >= 0 ? Math.floor($12) : Math.ceil($12);
    HEAP32[$this + 144 >> 2] = $13;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js28MarkStackRangeConservativelyEP8JSTracerPN2JS5ValueES4_($trc, $beginv, $endv) {
  var $1 = __ZNK2JS5Value11payloadWordEv($beginv);
  var $2 = __ZNK2JS5Value11payloadWordEv($endv);
  __ZN2jsL23MarkRangeConservativelyEP8JSTracerPKjS3_($trc, $1, $2);
  return;
}

function __ZN2jsL23MarkRangeConservativelyEP8JSTracerPKjS3_($trc, $begin, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($begin | 0) == ($end | 0)) {
      __label__ = 3;
      break;
    } else {
      var $i_01 = $begin;
      __label__ = 2;
      break;
    }
   case 2:
    var $i_01;
    var $2 = HEAP32[$i_01 >> 2];
    __ZN2jsL22MarkWordConservativelyEP8JSTracerj($trc, $2);
    var $3 = $i_01 + 4 | 0;
    if (($3 | 0) == ($end | 0)) {
      __label__ = 3;
      break;
    } else {
      var $i_01 = $3;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js26MarkConservativeStackRootsEP8JSTracer($trc) {
  var $5 = HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144280 | 0;
  __ZN2jsL28MarkThreadDataConservativelyEP8JSTracerPNS_10ThreadDataE($trc, $5);
  return;
}

function __ZN2jsL28MarkThreadDataConservativelyEP8JSTracerPNS_10ThreadDataE($trc, $td) {
  var $2 = HEAP32[$td + 65600 >> 2];
  var $4 = HEAP32[$td + 65608 >> 2];
  __ZN2jsL23MarkRangeConservativelyEP8JSTracerPKjS3_($trc, $2, $4);
  var $5 = $td + 65612 | 0;
  var $6 = $td + 65652 | 0;
  __ZN2jsL23MarkRangeConservativelyEP8JSTracerPKjS3_($trc, $5, $6);
  return;
}

function __ZN2js24ConservativeGCThreadData14recordStackTopEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  var setjmpTable = {
    "1": (function(value) {
      __label__ = 2;
      $4 = value;
    }),
    dummy: 0
  };
  while (1) try {
    switch (__label__) {
     case 1:
      HEAP32[$this >> 2] = __stackBase__;
      var $4 = (HEAP32[$this + 4 >> 2] = __label__, 0);
      __label__ = 2;
      break;
     case 2:
      STACKTOP = __stackBase__;
      return;
     default:
      assert(0, "bad label: " + __label__);
    }
  } catch (e) {
    if (!e.longjmp) throw e;
    setjmpTable[e.label](e.value);
  }
}

function __Z11js_FinishGCP9JSRuntime($rt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $rt + 4 | 0;
    var $_idx = $1 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $2 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($_idx_val);
    var $_idx4 = $rt + 8 | 0;
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $3 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx_val, $_idx4_val);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $c_05 = $2;
      __label__ = 2;
      break;
    }
   case 2:
    var $c_05;
    var $5 = HEAP32[$c_05 >> 2];
    __ZN2js10Foreground7delete_I13JSCompartmentEEvPT_($5);
    var $6 = $c_05 + 4 | 0;
    var $_idx1_val = HEAP32[$_idx >> 2];
    var $_idx2_val = HEAP32[$_idx4 >> 2];
    var $7 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx1_val, $_idx2_val);
    if (($6 | 0) == ($7 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $c_05 = $6;
      __label__ = 2;
      break;
    }
   case 3:
    __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5clearEv($1);
    HEAP32[$rt >> 2] = 0;
    HEAP32[$rt + 72 >> 2] = 0;
    HEAP32[$rt + 76 >> 2] = 0;
    var $12 = $rt + 48 | 0;
    __ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE3allEv($r, $12);
    var $r_idx6 = $r | 0;
    var $r_idx6_val = HEAP32[$r_idx6 >> 2];
    var $r_idx7 = $r + 4 | 0;
    var $r_idx7_val = HEAP32[$r_idx7 >> 2];
    var $13 = __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r_idx6_val, $r_idx7_val);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      var $r_idx8_val = $r_idx6_val;
      __label__ = 4;
      break;
    }
   case 4:
    var $r_idx8_val;
    var $14 = __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($r_idx8_val);
    var $15 = HEAP32[$14 >> 2];
    __Z14ReleaseGCChunkP9JSRuntimePN2js2gc5ChunkE($15);
    __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($r);
    var $r_idx_val = HEAP32[$r_idx6 >> 2];
    var $r_idx5_val = HEAP32[$r_idx7 >> 2];
    var $16 = __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r_idx_val, $r_idx5_val);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      var $r_idx8_val = $r_idx_val;
      __label__ = 4;
      break;
    }
   case 5:
    __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE5clearEv($12);
    var $17 = $rt + 80 | 0;
    var $18 = HEAP32[$17 >> 2];
    if (($18 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $chunk_01 = $18;
      __label__ = 6;
      break;
    }
   case 6:
    var $chunk_01;
    var $21 = HEAP32[$chunk_01 + 1048320 >> 2];
    __Z14ReleaseGCChunkP9JSRuntimePN2js2gc5ChunkE($chunk_01);
    if (($21 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $chunk_01 = $21;
      __label__ = 6;
      break;
    }
   case 7:
    HEAP32[$17 >> 2] = 0;
    HEAP32[$rt + 84 >> 2] = 0;
    var $24 = $rt + 88 | 0;
    __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE5clearEv($24);
    var $25 = $rt + 112 | 0;
    __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE5clearEv($25);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z11js_FinishGCP9JSRuntime["X"] = 1;

function __ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE3allEv($agg_result, $this) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $_idx1_val = HEAP32[$this + 20 >> 2];
  __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3allEv($agg_result, $_idx_val, $_idx1_val);
  return;
}

function __Z14ReleaseGCChunkP9JSRuntimePN2js2gc5ChunkE($p) {
  var $1 = $p;
  __ZN2js11FreeGCChunkEPv($1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 8 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$5 >> 2];
    var $8 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isLiveEv($_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE5clearEv($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5clearEv($1);
  return;
}

function __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE5clearEv($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5clearEv($1);
  return;
}

function __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE5clearEv($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5clearEv($1);
  return;
}

function __Z10js_AddRootP9JSContextPN2JS5ValueEPKc($cx, $vp, $name) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 52 >> 2];
    var $3 = _js_AddRootRT($2, $vp, $name);
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportOutOfMemory($cx);
    __label__ = 3;
    break;
   case 3:
    return $3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_AddRootRT($rt, $vp, $name) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $lock = __stackBase__;
  var $1 = __stackBase__ + 4;
  var $2 = __stackBase__ + 8;
  __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $rt);
  var $3 = $rt + 88 | 0;
  HEAP32[$1 >> 2] = $vp;
  __ZN2js8RootInfoC1EPKc12JSGCRootType($2, $name, 0);
  var $5 = __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3putERKS1_RKS2_($3, $1, $2);
  var $7 = ($5 | 0) != 0 & 1;
  STACKTOP = __stackBase__;
  return $7;
}

function __Z17js_AddGCThingRootP9JSContextPPvPKc($cx, $rp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 52 >> 2];
    var $3 = _js_AddGCThingRootRT($2, $rp);
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportOutOfMemory($cx);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_AddGCThingRootRT($rt, $rp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $lock = __stackBase__;
  var $1 = __stackBase__ + 4;
  var $2 = __stackBase__ + 8;
  __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $rt);
  var $3 = $rt + 88 | 0;
  HEAP32[$1 >> 2] = $rp;
  __ZN2js8RootInfoC1EPKc12JSGCRootType($2, STRING_TABLE.__str145438 | 0, 1);
  var $5 = __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3putERKS1_RKS2_($3, $1, $2);
  var $7 = ($5 | 0) != 0 & 1;
  STACKTOP = __stackBase__;
  return $7;
}

function __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3putERKS1_RKS2_($this, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZNK2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE12lookupForAddERKS1_($p, $this, $k);
    var $_idx = $p | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $_idx_val_idx_val = HEAP32[$_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($1, $_idx_val_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($_idx_val);
    var $8 = $v;
    var $9 = $6 + 4 | 0;
    var $10$0 = HEAP32[$8 >> 2];
    var $10$1 = HEAP32[$8 + 4 >> 2];
    var $st$8$0 = $9 | 0;
    HEAP32[$st$8$0 >> 2] = $10$0;
    var $st$8$1 = $9 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $10$1;
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrdeEv($_idx_val);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 3:
    var $13 = __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E6AddPtrERKS1_RKS2_($this, $p, $k, $v);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx2_val = HEAP32[$_idx >> 2];
    var $15 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrdeEv($_idx2_val);
    var $_0 = $15;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8RootInfoC1EPKc12JSGCRootType($this, $name, $type) {
  __ZN2js8RootInfoC2EPKc12JSGCRootType($this, $name, $type);
  return;
}

function _js_RemoveRoot($rt, $rp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $lock = __stackBase__ + 4;
  HEAP32[$1 >> 2] = $rp;
  __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $rt);
  var $2 = $rt + 88 | 0;
  __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6removeERKS1_($2, $1);
  HEAP8[$rt + 144088 | 0] = 1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6removeERKS1_($this, $l) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 4;
    __ZNK2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6lookupERKS1_($p, $this, $l);
    var $p_idx_val = HEAP32[$p >> 2];
    var $p_idx_val_idx_val = HEAP32[$p_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($1, $p_idx_val_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E3PtrE($this, $p_idx_val);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 16 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$5 >> 2];
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isLiveEv($_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment14setGCLastBytesEj18JSGCInvocationKind($this, $lastBytes, $gckind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this + 336 >> 2] = $lastBytes;
    if (($gckind | 0) == 2) {
      var $6 = $lastBytes;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2jsL3MaxIjEET_S1_S1_($lastBytes);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    var $13 = HEAPU32[HEAP32[$this >> 2] + 152 >> 2] >>> 0;
    var $14 = __ZN2jsL3MinIfEET_S1_S1_($13, ($6 >>> 0) * 3);
    var $15 = $14 >= 0 ? Math.floor($14) : Math.ceil($14);
    HEAP32[$this + 332 >> 2] = $15;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc10ArenaLists15finalizeObjectsEP9JSContext($this, $cx) {
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, 0);
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, 2);
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, 4);
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, 6);
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, 8);
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, 10);
  __ZN2js2gc10ArenaLists13finalizeLaterEP9JSContextNS0_9AllocKindE($this, $cx, 12);
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, 16);
  return;
}

function __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, $thingKind) {
  var $1 = $this + 160 + ($thingKind << 3) | 0;
  __ZN2js2gcL14FinalizeArenasEP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $1, $thingKind);
  return;
}

function __ZN2js2gc10ArenaLists13finalizeLaterEP9JSContextNS0_9AllocKindE($this, $cx, $thingKind) {
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, $thingKind);
  return;
}

function __ZN2js2gc10ArenaLists15finalizeStringsEP9JSContext($this, $cx) {
  __ZN2js2gc10ArenaLists13finalizeLaterEP9JSContextNS0_9AllocKindE($this, $cx, 17);
  __ZN2js2gc10ArenaLists13finalizeLaterEP9JSContextNS0_9AllocKindE($this, $cx, 18);
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, 19);
  return;
}

function __ZN2js2gc10ArenaLists14finalizeShapesEP9JSContext($this, $cx) {
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, 14);
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, 15);
  return;
}

function __ZN2js2gc10ArenaLists15finalizeScriptsEP9JSContext($this, $cx) {
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, 13);
  return;
}

function __ZN2js2gc10ArenaLists14refillFreeListEP9JSContextNS0_9AllocKindE($cx, $thingKind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lock = __stackBase__;
    var $2 = HEAPU32[$cx + 56 >> 2];
    var $4 = HEAPU32[$2 >> 2];
    var $8 = $4 + 140 | 0;
    var $9 = $4 + 152 | 0;
    var $10 = $2 + 8 | 0;
    var $cx_idx1 = $cx + 52 | 0;
    var $runGC_0 = (HEAP32[$4 + 196 >> 2] | 0) != 0;
    __label__ = 2;
    break;
   case 2:
    var $runGC_0;
    if ($runGC_0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $cx_idx1_val_idx_val = HEAP8[HEAP32[$cx_idx1 >> 2] + 144304 | 0];
    var $13 = __ZN2js2gc11IsGCAllowedEP9JSContext($cx_idx1_val_idx_val);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    __ZN2js2gcL14RunLastDitchGCEP9JSContext($cx);
    if (HEAPU32[$8 >> 2] >>> 0 > HEAPU32[$9 >> 2] >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $20 = __ZN2js2gc10ArenaLists20allocateFromFreeListENS0_9AllocKindEj($10, $thingKind, $19);
    if (($20 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $20;
      __label__ = 14;
      break;
    }
   case 6:
    var $23 = __ZN2js2gc10ArenaLists17allocateFromArenaEP13JSCompartmentNS0_9AllocKindE($10, $2, $thingKind);
    if (($23 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = $23;
      __label__ = 14;
      break;
    }
   case 7:
    if ($runGC_0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $cx_idx_val_idx_val = HEAP8[HEAP32[$cx_idx1 >> 2] + 144304 | 0];
    var $27 = __ZN2js2gc11IsGCAllowedEP9JSContext($cx_idx_val_idx_val);
    if ($27) {
      var $runGC_0 = 1;
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $4);
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    HEAP32[__ZN2js8gcReasonE >> 2] = 8;
    __label__ = 12;
    break;
   case 11:
    var $33 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $33;
    __label__ = 12;
    break;
   case 12:
    __ZN2js9TriggerGCEP9JSRuntime($4);
    __label__ = 13;
    break;
   case 13:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc10ArenaLists14refillFreeListEP9JSContextNS0_9AllocKindE["X"] = 1;

function __ZN2js2gcL14RunLastDitchGCEP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $keep = __stackBase__;
    var $2 = HEAP32[$cx + 52 >> 2];
    __ZN2js13AutoKeepAtomsC1EP9JSRuntime($keep, $2);
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[__ZN2js8gcReasonE >> 2] = 5;
    __label__ = 4;
    break;
   case 3:
    var $7 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $7;
    __label__ = 4;
    break;
   case 4:
    var $10 = HEAP32[$2 + 144076 >> 2];
    __Z5js_GCP9JSContextP13JSCompartment18JSGCInvocationKind($cx, $10, 0);
    var $keep_idx_val = HEAP32[$keep >> 2];
    __ZN2js13AutoKeepAtomsD1Ev($keep_idx_val);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc10ArenaLists17allocateFromArenaEP13JSCompartmentNS0_9AllocKindE($this, $comp, $thingKind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $maybeLock = __stackBase__;
    var $1 = __stackBase__ + 4;
    __ZN2js10AutoLockGCC1EP9JSRuntime($maybeLock, 0);
    var $2 = $this + 160 + ($thingKind << 3) + 4 | 0;
    var $4 = HEAP32[HEAP32[$2 >> 2] >> 2];
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4 + 4 | 0;
    HEAP32[$2 >> 2] = $7;
    var $8 = $this + ($thingKind << 3) | 0;
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($1, $4);
    var $9 = $1;
    var $10 = $8;
    var $11$0 = HEAP32[$9 >> 2];
    var $11$1 = HEAP32[$9 + 4 >> 2];
    HEAP32[$10 >> 2] = $11$0;
    HEAP32[$10 + 4 >> 2] = $11$1;
    __ZN2js2gc11ArenaHeader14setAsFullyUsedEv($4);
    var $12 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $13 = __ZN2js2gc8FreeSpan18infallibleAllocateEj($8, $12);
    var $_0 = $13;
    __label__ = 9;
    break;
   case 3:
    var $maybeLock_idx_val = HEAP32[$maybeLock >> 2];
    var $15 = __ZNK2js10AutoLockGC6lockedEv($maybeLock_idx_val);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $18 = HEAP32[$comp >> 2];
    __ZN2js10AutoLockGC4lockEP9JSRuntime($maybeLock, $18);
    __label__ = 5;
    break;
   case 5:
    var $20 = __ZL9PickChunkP13JSCompartment($comp);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = __ZN2js2gc5Chunk13allocateArenaEP13JSCompartmentNS0_9AllocKindE($20, $comp, $thingKind);
    var $24 = $this + 160 + ($thingKind << 3) | 0;
    var $25 = HEAP32[$24 >> 2];
    var $26 = $23 + 4 | 0;
    HEAP32[$26 >> 2] = $25;
    if ((HEAP32[$24 >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    HEAP32[$2 >> 2] = $26;
    __label__ = 8;
    break;
   case 8:
    HEAP32[$24 >> 2] = $23;
    var $31 = __ZNK2js2gc11ArenaHeader12arenaAddressEv($23);
    var $32 = $this + ($thingKind << 3) | 0;
    var $33 = __ZN2js2gc5Arena16firstThingOffsetENS0_9AllocKindE($thingKind);
    var $34 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $35 = __ZN2js2gc8FreeSpan20allocateFromNewArenaEjjj($32, $31, $33, $34);
    var $_0 = $35;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc10ArenaLists17allocateFromArenaEP13JSCompartmentNS0_9AllocKindE["X"] = 1;

function __ZN2js9TriggerGCEP9JSRuntime($rt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $rt + 196 | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = 1;
    HEAP32[$rt + 144076 >> 2] = 0;
    __ZN2js28TriggerAllOperationCallbacksEP9JSRuntime($rt);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc19GetGCThingTraceKindEPKv($thing) {
  var $1 = $thing;
  var $2 = __ZNK2js2gc4Cell12getAllocKindEv($1);
  var $3 = __ZN2js2gcL19MapAllocToTraceKindENS0_9AllocKindE($2);
  return $3;
}

function __ZN2js8GCMarkerC2EP9JSContext($this, $cx) {
  HEAP32[$this + 24 >> 2] = 0;
  HEAP32[$this + 28 >> 2] = 0;
  var $3 = $this + 36 | 0;
  var $4 = $cx + 52 | 0;
  var $6 = HEAP32[$4 >> 2] + 204 | 0;
  __ZN2js9MarkStackIP8JSObjectEC1EPPvj($3, $6);
  var $7 = $this + 48 | 0;
  var $9 = HEAP32[$4 >> 2] + 131276 | 0;
  __ZN2js9MarkStackIP6JSRopeEC1EPPvj($7, $9);
  var $10 = $this + 60 | 0;
  var $12 = HEAP32[$4 >> 2] + 135372 | 0;
  __ZN2js9MarkStackIPNS_5types10TypeObjectEEC1EPPvj($10, $12);
  var $13 = $this + 72 | 0;
  var $15 = HEAP32[$4 >> 2] + 139468 | 0;
  __ZN2js9MarkStackIP5JSXMLEC1EPPvj($13, $15);
  var $16 = $this + 84 | 0;
  var $18 = HEAP32[$4 >> 2] + 143564 | 0;
  __ZN2js9MarkStackINS_13LargeMarkItemEEC1EPPvj($16, $18);
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = -1;
  HEAP32[$this + 20 >> 2] = 0;
  return;
}

function __ZN2js9MarkStackIP8JSObjectEC1EPPvj($this, $buffer) {
  __ZN2js9MarkStackIP8JSObjectEC2EPPvj($this, $buffer);
  return;
}

function __ZN2js9MarkStackIP6JSRopeEC1EPPvj($this, $buffer) {
  __ZN2js9MarkStackIP6JSRopeEC2EPPvj($this, $buffer);
  return;
}

function __ZN2js9MarkStackIPNS_5types10TypeObjectEEC1EPPvj($this, $buffer) {
  __ZN2js9MarkStackIPNS_5types10TypeObjectEEC2EPPvj($this, $buffer);
  return;
}

function __ZN2js9MarkStackIP5JSXMLEC1EPPvj($this, $buffer) {
  __ZN2js9MarkStackIP5JSXMLEC2EPPvj($this, $buffer);
  return;
}

function __ZN2js9MarkStackINS_13LargeMarkItemEEC1EPPvj($this, $buffer) {
  __ZN2js9MarkStackINS_13LargeMarkItemEEC2EPPvj($this, $buffer);
  return;
}

function __ZN2js8GCMarker20delayMarkingChildrenEPKv($this, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $thing;
    var $2 = __ZNK2js2gc4Cell11arenaHeaderEv($1);
    if ((HEAP32[$2 + 12 >> 2] & 256 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $this + 28 | 0;
    var $10 = HEAP32[$9 >> 2];
    __ZN2js2gc11ArenaHeader21setNextDelayedMarkingEPNS0_5ArenaE($2, $10);
    var $11 = __ZN2js2gc11ArenaHeader8getArenaEv($2);
    HEAP32[$9 >> 2] = $11;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc11ArenaHeader21setNextDelayedMarkingEPNS0_5ArenaE($this, $arena) {
  var $2 = $this + 12 | 0;
  var $3 = HEAP32[$2 >> 2];
  var $4 = __ZNK2js2gc5Arena7addressEv($arena);
  var $9 = $3 & 255 | $4 >>> 3 & 536870400 | 256;
  HEAP32[$2 >> 2] = $9;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5Range5emptyEv($this_0_0_val, $this_0_1_val) {
  return ($this_0_0_val | 0) == ($this_0_1_val | 0);
}

function __ZNK2js2gc18GCCompartmentsIter4doneEv($this_0_0_val, $this_0_1_val) {
  return ($this_0_0_val | 0) == ($this_0_1_val | 0);
}

function __ZNK2js2gc11ArenaHeader21getNextDelayedMarkingEv($this) {
  return HEAP32[$this + 12 >> 2] << 3 & -4096;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5Range5frontEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN2js2gc18GCCompartmentsIter4nextEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] + 4 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN13AutoGCSessionC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  HEAP8[HEAP32[$cx + 52 >> 2] + 144090 | 0] = 1;
  return;
}

function __ZN13AutoGCSessionD2Ev($this_0_0_val_0_11_val) {
  HEAP8[$this_0_0_val_0_11_val + 144090 | 0] = 0;
  return;
}

function __ZN2js2gcL19MapAllocToTraceKindENS0_9AllocKindE($thingKind) {
  return HEAP32[__ZZN2js2gcL19MapAllocToTraceKindENS0_9AllocKindEE3map + ($thingKind << 2) >> 2];
}

function __ZN2js2gc11ArenaHeader8getArenaEv($this) {
  var $1 = __ZNK2js2gc11ArenaHeader12arenaAddressEv($this);
  return $1;
}

function __ZN2js8GCMarker19markDelayedChildrenEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 28 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $4 = $2;
      __label__ = 2;
      break;
    }
   case 2:
    var $4;
    var $6 = __ZNK2js2gc11ArenaHeader21getNextDelayedMarkingEv($4 | 0);
    HEAP32[$1 >> 2] = $6;
    var $8 = $4 + 12 | 0;
    var $10 = HEAP32[$8 >> 2] & -257;
    HEAP32[$8 >> 2] = $10;
    __ZN2jsL19MarkDelayedChildrenEPNS_8GCMarkerEPNS_2gc5ArenaE($this, $4);
    var $11 = HEAP32[$1 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $4 = $11;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL19MarkDelayedChildrenEPNS_8GCMarkerEPNS_2gc5ArenaE($trc, $a) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $a | 0;
    var $2 = __ZNK2js2gc11ArenaHeader12getAllocKindEv($1);
    var $3 = __ZN2js2gcL19MapAllocToTraceKindENS0_9AllocKindE($2);
    var $4 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($2);
    var $5 = __ZN2js2gc5Arena9thingsEndEv($a);
    var $6 = __ZN2js2gc5Arena11thingsStartENS0_9AllocKindE($a, $2);
    if (($6 | 0) == ($5 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $trc | 0;
    var $thing_01 = $6;
    __label__ = 3;
    break;
   case 3:
    var $thing_01;
    var $10 = $thing_01;
    var $11 = __ZNK2js2gc4Cell8isMarkedEj($10);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    _JS_TraceChildren($8, $10 | 0, $3);
    __label__ = 5;
    break;
   case 5:
    var $15 = $thing_01 + $4 | 0;
    if (($15 | 0) == ($5 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $thing_01 = $15;
      __label__ = 3;
      break;
    }
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18js_TraceStackFrameP8JSTracerPN2js10StackFrameE($trc, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame10scopeChainEv($fp);
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $1);
    var $fp_idx1_val = HEAP32[$fp >> 2];
    var $2 = __ZNK2js10StackFrame12isDummyFrameEv($fp_idx1_val);
    if ($2) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2js10StackFrame10hasArgsObjEv($fp_idx1_val);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZNK2js10StackFrame7argsObjEv($fp);
    var $7 = $6 | 0;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $7);
    __label__ = 4;
    break;
   case 4:
    var $9 = __ZNK2js10StackFrame6scriptEv($fp);
    __ZN2js2gc10MarkScriptEP8JSTracerP8JSScriptPKc($trc, $9);
    var $10 = __ZNK2js10StackFrame6scriptEv($fp);
    var $11 = $10;
    var $12 = __ZNK2js2gc4Cell11compartmentEv($11);
    HEAP8[$12 + 712 | 0] = 1;
    var $14 = $fp;
    var $15 = __ZN2js10StackFrame11returnValueEv($14);
    var $_idx = $15 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $_idx_val$0, $_idx_val$1);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js19AutoEnumStateRooter5traceEP8JSTracer($this_0_1_val, $trc) {
  __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $this_0_1_val);
  return;
}

function __ZN2js11MarkContextEP8JSTracerP9JSContext($trc, $acx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $3 = HEAP32[$acx + 132 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $acx_idx_val = HEAP32[$acx + 32 >> 2];
    var $6 = __ZNK9JSContext12hasRunOptionEj($acx_idx_val, 8192);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $3);
    __label__ = 4;
    break;
   case 4:
    var $acx_idx2_val = HEAP32[$acx + 20 >> 2];
    var $9 = __ZN9JSContext18isExceptionPendingEv($acx_idx2_val);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $acx_idx3 = $acx + 24 | 0;
    var $st$1$0 = $acx_idx3 | 0;
    var $acx_idx3_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $acx_idx3 + 4 | 0;
    var $acx_idx3_val$1 = HEAP32[$st$1$1 >> 2];
    __ZN9JSContext19getPendingExceptionEv($1, $acx_idx3_val$0, $acx_idx3_val$1);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $_idx_val$0, $_idx_val$1);
    __label__ = 6;
    break;
   case 6:
    var $gcr_01 = HEAP32[$acx + 196 >> 2];
    if (($gcr_01 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $gcr_02 = $gcr_01;
      __label__ = 7;
      break;
    }
   case 7:
    var $gcr_02;
    __ZN2js12AutoGCRooter5traceEP8JSTracer($gcr_02, $trc);
    var $gcr_0 = HEAP32[$gcr_02 >> 2];
    if (($gcr_0 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $gcr_02 = $gcr_0;
      __label__ = 7;
      break;
    }
   case 8:
    if ((HEAP32[$acx + 136 >> 2] | 0) > 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $20 = $trc;
    var $_idx4_val = HEAP32[$acx + 144 >> 2];
    __Z16js_TraceSharpMapP8JSTracerP16JSSharpObjectMap($20, $_idx4_val);
    __label__ = 10;
    break;
   case 10:
    var $_idx1 = $acx + 224 | 0;
    var $st$1$0 = $_idx1 | 0;
    var $_idx1_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx1 + 4 | 0;
    var $_idx1_val$1 = HEAP32[$st$1$1 >> 2];
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $_idx1_val$0, $_idx1_val$1);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11MarkContextEP8JSTracerP9JSContext["X"] = 1;

function __ZN2js12AutoGCRooter5traceEP8JSTracer($this, $trc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    if (($2 | 0) == -1) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == -3) {
      __label__ = 3;
      break;
    } else if (($2 | 0) == -5) {
      __label__ = 4;
      break;
    } else if (($2 | 0) == -6) {
      __label__ = 5;
      break;
    } else if (($2 | 0) == -7) {
      __label__ = 6;
      break;
    } else if (($2 | 0) == -13) {
      __label__ = 9;
      break;
    } else if (($2 | 0) == -8) {
      __label__ = 17;
      break;
    } else if (($2 | 0) == -9) {
      __label__ = 18;
      break;
    } else if (($2 | 0) == -10) {
      __label__ = 19;
      break;
    } else if (($2 | 0) == -11) {
      __label__ = 21;
      break;
    } else if (($2 | 0) == -12) {
      __label__ = 22;
      break;
    } else if (($2 | 0) == -14) {
      __label__ = 23;
      break;
    } else if (($2 | 0) == -15) {
      __label__ = 25;
      break;
    } else if (($2 | 0) == -4) {
      __label__ = 26;
      break;
    } else if (($2 | 0) == -16) {
      __label__ = 27;
      break;
    } else if (($2 | 0) == -2) {
      __label__ = 28;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 2:
    var $_idx = $this + 16 | 0;
    var $st$2$0 = $_idx | 0;
    var $_idx_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAP32[$st$2$1 >> 2];
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $_idx_val$0, $_idx_val$1);
    __label__ = 30;
    break;
   case 3:
    var $6 = $this;
    __ZN2js6Parser5traceEP8JSTracer($6, $trc);
    __label__ = 30;
    break;
   case 4:
    var $_idx6_val = HEAP32[$this + 12 >> 2];
    __ZN2js19AutoEnumStateRooter5traceEP8JSTracer($_idx6_val, $trc);
    __label__ = 30;
    break;
   case 5:
    var $12 = HEAP32[$this + 12 >> 2];
    var $14 = HEAP32[$12 >> 2];
    var $15 = $12 + 4 | 0;
    __ZN2js2gc11MarkIdRangeEP8JSTracerjPiPKc($trc, $14, $15);
    __label__ = 30;
    break;
   case 6:
    var $_idx7_val = HEAP32[$this + 20 >> 2];
    var $18 = __ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE6lengthEv($_idx7_val);
    if (($18 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = $this + 16 | 0;
    var $i_01 = 0;
    __label__ = 8;
    break;
   case 8:
    var $i_01;
    var $_idx8_val = HEAP32[$20 >> 2];
    var $21 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEEixEj($_idx8_val, $i_01);
    var $_idx1 = $21 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $_idx1_val$0, $_idx1_val$1);
    var $_idx2 = $21 + 8 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $_idx2_val$0, $_idx2_val$1);
    var $_idx3 = $21 + 16 | 0;
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $_idx3_val$0, $_idx3_val$1);
    var $_idx4 = $21 + 24 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $_idx4_val$0, $_idx4_val$1);
    var $22 = $i_01 + 1 | 0;
    if (($22 | 0) == ($18 | 0)) {
      __label__ = 30;
      break;
    } else {
      var $i_01 = $22;
      __label__ = 8;
      break;
    }
   case 9:
    var $24 = $this + 16 | 0;
    var $26 = HEAP32[$24 >> 2];
    if (($26 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $26);
    __label__ = 11;
    break;
   case 11:
    var $_idx5 = $24 + 16 | 0;
    var $st$2$0 = $_idx5 | 0;
    var $_idx5_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx5 + 4 | 0;
    var $_idx5_val$1 = HEAP32[$st$2$1 >> 2];
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $_idx5_val$0, $_idx5_val$1);
    var $31 = $24 + 4 | 0;
    var $32 = HEAP32[$31 >> 2];
    if (($32 & 16 | 0) == 0) {
      var $43 = $32;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $38 = HEAP32[$24 + 8 >> 2];
    if (($38 | 0) == 0) {
      var $43 = $32;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $41 = __ZN2js12CastAsObjectEPFiP9JSContextP8JSObjectiPN2JS5ValueEE($38);
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $41);
    var $43 = HEAP32[$31 >> 2];
    __label__ = 14;
    break;
   case 14:
    var $43;
    if (($43 & 32 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $49 = HEAP32[$24 + 12 >> 2];
    if (($49 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $52 = __ZN2js12CastAsObjectEPFiP9JSContextP8JSObjectiiPN2JS5ValueEE($49);
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $52);
    __label__ = 30;
    break;
   case 17:
    var $56 = HEAP32[$this + 12 >> 2];
    var $59 = HEAP32[$this + 20 >> 2];
    __ZN2js2gc15MarkObjectRangeEP8JSTracerjPP8JSObjectPKc($trc, $56, $59);
    var $63 = HEAP32[$this + 24 >> 2];
    var $64 = $trc;
    __ZN16JSXMLArrayCursor5traceEP8JSTracer($63, $64);
    __label__ = 30;
    break;
   case 18:
    var $69 = $trc;
    var $70 = HEAP32[$this + 12 >> 2];
    _js_TraceXML($69, $70);
    __label__ = 30;
    break;
   case 19:
    var $74 = HEAP32[$this + 12 >> 2];
    if (($74 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $74);
    __label__ = 30;
    break;
   case 21:
    var $80 = HEAP32[$this + 12 >> 2];
    __ZN2js2gc6MarkIdEP8JSTraceriPKc($trc, $80);
    __label__ = 30;
    break;
   case 22:
    var $_idx9_val = HEAP32[$this + 20 >> 2];
    var $83 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE6lengthEv($_idx9_val);
    var $_idx10_val = HEAP32[$this + 16 >> 2];
    var $85 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE5beginEv($_idx10_val);
    __ZN2js2gc14MarkValueRangeEP8JSTracerjPKN2JS5ValueEPKc($trc, $83, $85);
    __label__ = 30;
    break;
   case 23:
    var $89 = HEAP32[$this + 12 >> 2];
    if (($89 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($trc, $89);
    __label__ = 30;
    break;
   case 25:
    var $_idx11_val = HEAP32[$this + 20 >> 2];
    var $94 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE6lengthEv($_idx11_val);
    var $_idx12_val = HEAP32[$this + 16 >> 2];
    var $96 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE5beginEv($_idx12_val);
    __ZN2js2gc11MarkIdRangeEP8JSTracerjPiPKc($trc, $94, $96);
    __label__ = 30;
    break;
   case 26:
    var $_idx13_val = HEAP32[$this + 20 >> 2];
    var $99 = __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE6lengthEv($_idx13_val);
    var $_idx14_val = HEAP32[$this + 16 >> 2];
    var $101 = __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE5beginEv($_idx14_val);
    __ZN2js2gc14MarkShapeRangeEP8JSTracerjPPKNS_5ShapeEPKc($trc, $99, $101);
    __label__ = 30;
    break;
   case 27:
    var $_idx15_val = HEAP32[$this + 20 >> 2];
    var $104 = __ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE6lengthEv($_idx15_val);
    var $_idx16_val = HEAP32[$this + 16 >> 2];
    var $106 = __ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE5beginEv($_idx16_val);
    __ZN2js2gc15MarkObjectRangeEP8JSTracerjPP8JSObjectPKc($trc, $104, $106);
    __label__ = 30;
    break;
   case 28:
    var $_idx17_val = HEAP32[$this + 16 >> 2];
    var $109 = __ZNK2js14AutoValueArray6lengthEv($_idx17_val);
    var $_idx18_val = HEAP32[$this + 12 >> 2];
    var $111 = __ZNK2js14AutoValueArray5startEv($_idx18_val);
    __ZN2js2gc14MarkValueRangeEP8JSTracerjPKN2JS5ValueEPKc($trc, $109, $111);
    __label__ = 30;
    break;
   case 29:
    var $115 = HEAP32[$this + 12 >> 2];
    __ZN2js2gc14MarkValueRangeEP8JSTracerjPKN2JS5ValueEPKc($trc, $2, $115);
    __label__ = 30;
    break;
   case 30:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js12AutoGCRooter5traceEP8JSTracer["X"] = 1;

function __ZN2js11MarkRuntimeEP8JSTracer($trc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $r1 = __stackBase__ + 8;
    var $iter = __stackBase__ + 16;
    var $c = __stackBase__ + 20;
    var $i = __stackBase__ + 28;
    var $4 = HEAP32[HEAP32[$trc >> 2] + 52 >> 2];
    if ((HEAP32[$4 + 24 >> 2] | 0) == 3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js26MarkConservativeStackRootsEP8JSTracer($trc);
    __label__ = 3;
    break;
   case 3:
    var $10 = $4 + 88 | 0;
    __ZNK2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3allEv($r, $10);
    var $r_idx8 = $r | 0;
    var $r_idx8_val = HEAP32[$r_idx8 >> 2];
    var $r_idx9 = $r + 4 | 0;
    var $r_idx9_val = HEAP32[$r_idx9 >> 2];
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r_idx8_val, $r_idx9_val);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      var $r_idx10_val = $r_idx8_val;
      __label__ = 4;
      break;
    }
   case 4:
    var $r_idx10_val;
    var $12 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($r_idx10_val);
    var $_idx_val = HEAP32[$12 >> 2];
    var $_idx11_val = HEAP32[$12 + 8 >> 2];
    __ZL17gc_root_traversalP8JSTracerRKN2js12HashMapEntryIPvNS1_8RootInfoEEE($trc, $_idx_val, $_idx11_val);
    __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($r);
    var $r_idx_val = HEAP32[$r_idx8 >> 2];
    var $r_idx7_val = HEAP32[$r_idx9 >> 2];
    var $13 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r_idx_val, $r_idx7_val);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      var $r_idx10_val = $r_idx_val;
      __label__ = 4;
      break;
    }
   case 5:
    var $14 = $4 + 112 | 0;
    __ZNK2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE3allEv($r1, $14);
    var $r1_idx13 = $r1 | 0;
    var $r1_idx13_val = HEAP32[$r1_idx13 >> 2];
    var $r1_idx14 = $r1 + 4 | 0;
    var $r1_idx14_val = HEAP32[$r1_idx14 >> 2];
    var $15 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5Range5emptyEv($r1_idx13_val, $r1_idx14_val);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      var $r1_idx15_val = $r1_idx13_val;
      __label__ = 6;
      break;
    }
   case 6:
    var $r1_idx15_val;
    var $16 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5Range5frontEv($r1_idx15_val);
    var $_idx16_val = HEAP32[$16 >> 2];
    __ZL17gc_lock_traversalRKN2js12HashMapEntryIPvjEEP8JSTracer($_idx16_val, $trc);
    __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5Range8popFrontEv($r1);
    var $r1_idx_val = HEAP32[$r1_idx13 >> 2];
    var $r1_idx12_val = HEAP32[$r1_idx14 >> 2];
    var $17 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5Range5emptyEv($r1_idx_val, $r1_idx12_val);
    if ($17) {
      __label__ = 7;
      break;
    } else {
      var $r1_idx15_val = $r1_idx_val;
      __label__ = 6;
      break;
    }
   case 7:
    __Z17js_TraceAtomStateP8JSTracer($trc);
    var $18 = $4 + 210584 | 0;
    __ZN2js13StaticStrings5traceEP8JSTracer($18, $trc);
    HEAP32[$iter >> 2] = 0;
    var $19 = __Z18js_ContextIteratorP9JSRuntimeiPP9JSContext($4, $iter);
    if (($19 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $21 = $19;
      __label__ = 8;
      break;
    }
   case 8:
    var $21;
    __ZN2js11MarkContextEP8JSTracerP9JSContext($trc, $21);
    var $22 = __Z18js_ContextIteratorP9JSRuntimeiPP9JSContext($4, $iter);
    if (($22 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $21 = $22;
      __label__ = 8;
      break;
    }
   case 9:
    __ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime($c, $4);
    var $c_idx4 = $c | 0;
    var $c_idx4_val = HEAP32[$c_idx4 >> 2];
    var $c_idx5 = $c + 4 | 0;
    var $c_idx5_val = HEAP32[$c_idx5 >> 2];
    var $24 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c_idx4_val, $c_idx5_val);
    if ($24) {
      __label__ = 13;
      break;
    } else {
      var $c_idx6_val = $c_idx4_val;
      __label__ = 10;
      break;
    }
   case 10:
    var $c_idx6_val;
    var $c_idx6_val_val = HEAP32[$c_idx6_val >> 2];
    var $25 = __ZNK2js2gc18GCCompartmentsIterptEv($c_idx6_val_val);
    if ((HEAP8[$25 + 372 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN13JSCompartment9markTypesEP8JSTracer($25, $trc);
    __label__ = 12;
    break;
   case 12:
    __ZN2js2gc18GCCompartmentsIter4nextEv($c);
    var $c_idx_val = HEAP32[$c_idx4 >> 2];
    var $c_idx3_val = HEAP32[$c_idx5 >> 2];
    var $32 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c_idx_val, $c_idx3_val);
    if ($32) {
      __label__ = 13;
      break;
    } else {
      var $c_idx6_val = $c_idx_val;
      __label__ = 10;
      break;
    }
   case 13:
    __ZN2js14ThreadDataIterC1EP9JSRuntime($i, $4);
    var $i_idx1 = $i + 4 | 0;
    var $i_idx1_val = HEAP8[$i_idx1];
    var $33 = __ZNK2js14ThreadDataIter5emptyEv($i_idx1_val);
    if ($33) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $i_idx2 = $i | 0;
    __label__ = 15;
    break;
   case 15:
    var $i_idx2_val = HEAP32[$i_idx2 >> 2];
    var $34 = __ZNK2js14ThreadDataIter10threadDataEv($i_idx2_val);
    __ZN2js10ThreadData4markEP8JSTracer($34, $trc);
    __ZN2js14ThreadDataIter8popFrontEv($i);
    var $i_idx_val = HEAP8[$i_idx1];
    var $35 = __ZNK2js14ThreadDataIter5emptyEv($i_idx_val);
    if ($35) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 16:
    var $37 = HEAP32[$4 + 144100 >> 2];
    if (($37 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $41 = HEAP32[$4 + 144104 >> 2];
    FUNCTION_TABLE[$37]($trc, $41);
    __label__ = 18;
    break;
   case 18:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11MarkRuntimeEP8JSTracer["X"] = 1;

function __ZNK2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3allEv($agg_result, $this) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $_idx1_val = HEAP32[$this + 20 >> 2];
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $_idx_val, $_idx1_val);
  return;
}

function __ZL17gc_root_traversalP8JSTracerRKN2js12HashMapEntryIPvNS1_8RootInfoEEE($trc, $entry_0_0_val, $entry_0_1_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($entry_0_1_1_val | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$entry_0_0_val >> 2];
    __ZN2js2gc11MarkGCThingEP8JSTracerPv($trc, $4);
    __label__ = 4;
    break;
   case 3:
    var $_idx = $entry_0_0_val;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN2js2gc12MarkValueRawEP8JSTracerRKN2JS5ValueE($trc, $_idx_val$0, $_idx_val$1);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE3allEv($agg_result, $this) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $_idx1_val = HEAP32[$this + 20 >> 2];
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3allEv($agg_result, $_idx_val, $_idx1_val);
  return;
}

function __ZL17gc_lock_traversalRKN2js12HashMapEntryIPvjEEP8JSTracer($entry_0_0_val, $trc) {
  __ZN2js2gc11MarkGCThingEP8JSTracerPvPKc($trc, $entry_0_0_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$5 >> 2];
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE6isLiveEv($_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime($this, $rt) {
  __ZN2js2gc18GCCompartmentsIterC2EP9JSRuntime($this, $rt);
  return;
}

function __ZNK2js2gc18GCCompartmentsIterptEv($this_0_0_val_val) {
  var $1 = __ZNK2js2gc18GCCompartmentsIter3getEv($this_0_0_val_val);
  return $1;
}

function __ZN2js10ThreadData4markEP8JSTracer($this, $trc) {
  var $2 = $this + 4 | 0;
  var $3 = $trc;
  __ZN2js10StackSpace4markEP8JSTracer($2, $3);
  return;
}

function __ZN2js7MaybeGCEP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$cx + 52 >> 2];
    var $4 = HEAPU32[$cx + 56 >> 2];
    if ((HEAP32[$2 + 196 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[__ZN2js8gcReasonE >> 2] = 1;
    __label__ = 5;
    break;
   case 4:
    var $13 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $13;
    __label__ = 5;
    break;
   case 5:
    var $18 = ($4 | 0) == (HEAP32[$2 + 144076 >> 2] | 0) ? $4 : 0;
    __Z5js_GCP9JSContextP13JSCompartment18JSGCInvocationKind($cx, $18, 0);
    __label__ = 20;
    break;
   case 6:
    var $21 = HEAPU32[$4 + 328 >> 2];
    if ($21 >>> 0 > 8192) {
      __label__ = 7;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 7:
    if ($21 >>> 0 < ((HEAPU32[$4 + 332 >> 2] >>> 2) * 3 | 0) >>> 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    HEAP32[__ZN2js8gcReasonE >> 2] = 1;
    __label__ = 11;
    break;
   case 10:
    var $34 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $34;
    __label__ = 11;
    break;
   case 11:
    var $39 = (HEAP32[$2 + 192 >> 2] | 0) == 1 ? $4 : 0;
    __Z5js_GCP9JSContextP13JSCompartment18JSGCInvocationKind($cx, $39, 0);
    __label__ = 20;
    break;
   case 12:
    var $41 = _PRMJ_Now();
    var $41$0 = $41[0];
    var $41$1 = $41[1];
    var $42 = $2 + 176 | 0;
    var $43$0 = HEAP32[$42 >> 2];
    var $43$1 = HEAP32[$42 + 4 >> 2];
    if (($43$0 == 0 && $43$1 == 0) | (($43$1 | 0) > ($41$1 | 0) || ($43$1 | 0) == ($41$1 | 0) && $43$0 >>> 0 > $41$0 >>> 0)) {
      __label__ = 20;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if ((HEAP8[$2 + 172 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    if ((HEAP32[$2 + 80 >> 2] | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    HEAP32[__ZN2js8gcReasonE >> 2] = 1;
    __label__ = 18;
    break;
   case 17:
    var $60 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $60;
    __label__ = 18;
    break;
   case 18:
    __Z5js_GCP9JSContextP13JSCompartment18JSGCInvocationKind($cx, 0, 2);
    __label__ = 20;
    break;
   case 19:
    var $63$0 = (i64Math.add($41$0, $41$1, 2e7, 0), i64Math.result[0]);
    var $63$1 = i64Math.result[1];
    HEAP32[$42 >> 2] = $63$0;
    HEAP32[$42 + 4 >> 2] = $63$1;
    __label__ = 20;
    break;
   case 20:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7MaybeGCEP9JSContext["X"] = 1;

function __Z5js_GCP9JSContextP13JSCompartment18JSGCInvocationKind($cx, $comp, $gckind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 88;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $gcTimer = __stackBase__;
    var $autoGCProbe = __stackBase__ + 80;
    var $lock = __stackBase__ + 84;
    var $2 = HEAP32[$cx + 52 >> 2];
    var $6 = ($gckind | 0) == 1;
    if ((HEAP32[$2 + 24 >> 2] | 0) == 2 | $6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 2:
    __ZN2jsL25RecordNativeStackTopForGCEP9JSContext($2);
    __ZN2js7GCTimerC2EP9JSRuntimeP13JSCompartment($gcTimer, $2, $comp);
    __ZZ5js_GCP9JSContextP13JSCompartment18JSGCInvocationKindEN11AutoGCProbeC2ES2_($autoGCProbe, $comp);
    var $10 = $2 + 144092 | 0;
    var $11 = $2 + 144088 | 0;
    __label__ = 3;
    break;
   case 3:
    var $12 = HEAP32[$10 >> 2];
    if (($12 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = FUNCTION_TABLE[$12]($cx, 0);
    if (($15 | 0) != 0 | $6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 5:
    __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $2);
    HEAP8[$11] = 0;
    __ZL7GCCycleP9JSContextP13JSCompartment18JSGCInvocationKindRN2js7GCTimerE($cx, $comp, $gckind, $gcTimer);
    var $18 = HEAP32[$10 >> 2];
    if (($18 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = FUNCTION_TABLE[$18]($cx, 1);
    __label__ = 7;
    break;
   case 7:
    if ($6) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    if ((HEAP8[$11] & 1) << 24 >> 24 == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 9:
    var $27 = _PRMJ_Now();
    var $27$0 = $27[0];
    var $27$1 = $27[1];
    var $28$0 = (i64Math.add($27$0, $27$1, 2e7, 0), i64Math.result[0]);
    var $28$1 = i64Math.result[1];
    var $29 = $2 + 176 | 0;
    var $st$7$0 = $29 | 0;
    HEAP32[$st$7$0 >> 2] = $28$0;
    var $st$7$1 = $29 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $28$1;
    HEAP8[$2 + 172 | 0] = 0;
    __ZN2js7GCTimer6finishEb($gcTimer);
    __label__ = 10;
    break;
   case 10:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z5js_GCP9JSContextP13JSCompartment18JSGCInvocationKind["X"] = 1;

function __ZN2jsL25RecordNativeStackTopForGCEP9JSContext($cx_0_11_val) {
  var $1 = $cx_0_11_val + 209888 | 0;
  __ZN2js24ConservativeGCThreadData14recordStackTopEv($1);
  return;
}

function __ZL7GCCycleP9JSContextP13JSCompartment18JSGCInvocationKindRN2js7GCTimerE($cx, $comp, $gckind, $gcTimer) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $gcsession = __stackBase__;
    var $sc = __stackBase__ + 4;
    var $unlock = __stackBase__ + 16;
    var $2 = HEAP32[$cx + 52 >> 2];
    var $3 = $2 + 144089 | 0;
    if ((HEAP8[$3] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    __ZN13AutoGCSessionC2EP9JSContext($gcsession, $cx);
    if ((HEAP32[$2 + 229028 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    __ZN2js19SwitchToCompartmentC1EP9JSContextP13JSCompartment($sc, $cx, 0);
    var $12 = $2 + 144080 | 0;
    HEAP32[$12 >> 2] = $comp;
    HEAP8[$3] = 1;
    __ZN2js12AutoUnlockGCC1EP9JSRuntime($unlock, $2);
    __ZL12MarkAndSweepP9JSContext18JSGCInvocationKindRN2js7GCTimerE($cx, $gckind, $gcTimer);
    HEAP8[$3] = 0;
    HEAP8[$2 + 144091 | 0] = 0;
    var $15 = HEAP32[$2 + 140 >> 2];
    __ZN9JSRuntime14setGCLastBytesEj18JSGCInvocationKind($2, $15, $gckind);
    HEAP32[$12 >> 2] = 0;
    var $16 = $2 + 200 | 0;
    HEAP32[$16 >> 2] = 0;
    var $_idx = $2 + 4 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $17 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($_idx_val);
    var $_idx4 = $2 + 8 | 0;
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $18 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx_val, $_idx4_val);
    if (($17 | 0) == ($18 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $c_01 = $17;
      __label__ = 4;
      break;
    }
   case 4:
    var $c_01;
    var $20 = HEAP32[$c_01 >> 2];
    var $22 = HEAP32[$20 + 328 >> 2];
    __ZN13JSCompartment14setGCLastBytesEj18JSGCInvocationKind($20, $22, $gckind);
    var $23 = $c_01 + 4 | 0;
    var $_idx1_val = HEAP32[$_idx >> 2];
    var $_idx2_val = HEAP32[$_idx4 >> 2];
    var $24 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx1_val, $_idx2_val);
    if (($23 | 0) == ($24 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $c_01 = $23;
      __label__ = 4;
      break;
    }
   case 5:
    __ZN2js19SwitchToCompartmentD1Ev($sc);
    __label__ = 6;
    break;
   case 6:
    var $gcsession_idx_val_idx_val = HEAP32[HEAP32[$gcsession >> 2] + 52 >> 2];
    __ZN13AutoGCSessionD2Ev($gcsession_idx_val_idx_val);
    __label__ = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL7GCCycleP9JSContextP13JSCompartment18JSGCInvocationKindRN2js7GCTimerE["X"] = 1;

function __ZN2js12TraceRuntimeEP8JSTracer($trc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $copy = __stackBase__;
  var $1 = $trc | 0;
  var $4 = HEAP32[HEAP32[$1 >> 2] + 52 >> 2];
  __ZN2js24AutoCopyFreeListToArenasC1EP9JSRuntime($copy, $4);
  var $_idx_val = HEAP32[HEAP32[$1 >> 2] + 52 >> 2];
  __ZN2jsL25RecordNativeStackTopForGCEP9JSContext($_idx_val);
  __ZN2js11MarkRuntimeEP8JSTracer($trc);
  __ZN2js24AutoCopyFreeListToArenasD1Ev($copy);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js24AutoCopyFreeListToArenasC1EP9JSRuntime($this, $rt) {
  __ZN2js24AutoCopyFreeListToArenasC2EP9JSRuntime($this, $rt);
  return;
}

function __ZN2js24AutoCopyFreeListToArenasD1Ev($this) {
  __ZN2js24AutoCopyFreeListToArenasD2Ev($this);
  return;
}

function __ZN2js12AutoUnlockGCC1EP9JSRuntime($this, $rt) {
  __ZN2js12AutoUnlockGCC2EP9JSRuntime($this, $rt);
  return;
}

function __ZNK2js7MoveRefIPvEcvRS1_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIPvNS_8RootInfoEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_8RootInfoEEcvRS1_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE12hasCollisionEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js13PointerHasherIPvLj2EE5matchERKS1_S4_($k_val, $l_val) {
  return ($k_val | 0) == ($l_val | 0);
}

function __ZN2js13PointerHasherIPvLj2EE4hashERKS1_($l_val) {
  return $l_val >>> 2;
}

function __ZN2js9MarkStackINS_13LargeMarkItemEEC2EPPvj($this, $buffer) {
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 63;
  HEAP32[$this >> 2] = $buffer;
  return;
}

function __ZN2js9MarkStackIP5JSXMLEC2EPPvj($this, $buffer) {
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 1023;
  HEAP32[$this >> 2] = $buffer;
  return;
}

function __ZN2js9MarkStackIPNS_5types10TypeObjectEEC2EPPvj($this, $buffer) {
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 1023;
  HEAP32[$this >> 2] = $buffer;
  return;
}

function __ZN2js9MarkStackIP6JSRopeEC2EPPvj($this, $buffer) {
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 1023;
  HEAP32[$this >> 2] = $buffer;
  return;
}

function __ZN2js9MarkStackIP8JSObjectEC2EPPvj($this, $buffer) {
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 32767;
  HEAP32[$this >> 2] = $buffer;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js7MoveRefIPvEC2ERS1_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js12HashMapEntryIPvjEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js12HashMapEntryIPvNS_8RootInfoEEaSERKS3_($this, $rhs) {
  var $2 = HEAP32[$rhs >> 2];
  HEAP32[$this >> 2] = $2;
  var $6 = $rhs + 4 | 0;
  var $7 = $this + 4 | 0;
  var $8$0 = HEAP32[$6 >> 2];
  var $8$1 = HEAP32[$6 + 4 >> 2];
  HEAP32[$7 >> 2] = $8$0;
  HEAP32[$7 + 4 >> 2] = $8$1;
  return;
}

function __ZN2js12HashMapEntryIPvNS_8RootInfoEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEC2ERS7_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIPvNS_8RootInfoEEEEC2ERS4_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_8RootInfoEEC2ERS1_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S2_EE($e) {
  return $e | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrdeEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN2js12IterateCellsEP9JSContextP13JSCompartmentNS_2gc9AllocKindEPvPFvS1_S6_S6_13JSGCTraceKindjE($cx, $compartment) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lock = __stackBase__;
    var $gcsession = __stackBase__ + 4;
    var $unlock = __stackBase__ + 8;
    var $copy = __stackBase__ + 12;
    var $i = __stackBase__ + 16;
    var $i1 = __stackBase__ + 48;
    var $2 = HEAP32[$cx + 52 >> 2];
    __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $2);
    __ZN13AutoGCSessionC2EP9JSContext($gcsession, $cx);
    __ZN2js12AutoUnlockGCC1EP9JSRuntime($unlock, $2);
    __ZN2js24AutoCopyFreeListToArenasC1EP9JSRuntime($copy, $2);
    if (($compartment | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc15CellIterUnderGCC1EP13JSCompartmentNS0_9AllocKindE($i, $compartment, 13);
    var $5 = $i | 0;
    var $_idx8 = $i + 28 | 0;
    var $_idx8_val = HEAP32[$_idx8 >> 2];
    var $6 = __ZNK2js2gc12CellIterImpl4doneEv($_idx8_val);
    if ($6) {
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js2gc12CellIterImpl4nextEv($5);
    var $_idx7_val = HEAP32[$_idx8 >> 2];
    var $7 = __ZNK2js2gc12CellIterImpl4doneEv($_idx7_val);
    if ($7) {
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 4:
    var $_idx = $2 + 4 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $9 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($_idx_val);
    var $_idx4 = $2 + 8 | 0;
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $10 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx_val, $_idx4_val);
    if (($9 | 0) == ($10 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $i1 | 0;
    var $_idx6 = $i1 + 28 | 0;
    var $c_03 = $9;
    __label__ = 6;
    break;
   case 6:
    var $c_03;
    var $14 = HEAP32[$c_03 >> 2];
    __ZN2js2gc15CellIterUnderGCC1EP13JSCompartmentNS0_9AllocKindE($i1, $14, 13);
    var $_idx6_val = HEAP32[$_idx6 >> 2];
    var $15 = __ZNK2js2gc12CellIterImpl4doneEv($_idx6_val);
    if ($15) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2js2gc12CellIterImpl4nextEv($12);
    var $_idx5_val = HEAP32[$_idx6 >> 2];
    var $16 = __ZNK2js2gc12CellIterImpl4doneEv($_idx5_val);
    if ($16) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 8:
    var $17 = $c_03 + 4 | 0;
    var $_idx1_val = HEAP32[$_idx >> 2];
    var $_idx2_val = HEAP32[$_idx4 >> 2];
    var $18 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx1_val, $_idx2_val);
    if (($17 | 0) == ($18 | 0)) {
      __label__ = 9;
      break;
    } else {
      var $c_03 = $17;
      __label__ = 6;
      break;
    }
   case 9:
    __ZN2js24AutoCopyFreeListToArenasD1Ev($copy);
    var $gcsession_idx_val_idx_val = HEAP32[HEAP32[$gcsession >> 2] + 52 >> 2];
    __ZN13AutoGCSessionD2Ev($gcsession_idx_val_idx_val);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js12IterateCellsEP9JSContextP13JSCompartmentNS_2gc9AllocKindEPvPFvS1_S6_S6_13JSGCTraceKindjE["X"] = 1;

function __ZN2js2gc14NewCompartmentEP9JSContextP12JSPrincipals($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lock = __stackBase__;
    var $2 = HEAP32[$cx + 52 >> 2];
    var $3 = __ZN9JSContext4new_I13JSCompartmentP9JSRuntimeEEPT_T0_($cx, $2);
    if (($3 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN13JSCompartment4initEP9JSContext($3, $cx);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    HEAP8[$3 + 341 | 0] = 0;
    __ZN13JSCompartment14setGCLastBytesEj18JSGCInvocationKind($3, 8192, 0);
    __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $2);
    var $9 = $2 + 4 | 0;
    var $10 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6appendIS2_EEbT_($9, $3);
    if ($10) {
      var $_1 = $3;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    __label__ = 5;
    break;
   case 5:
    __ZN2js10Foreground7delete_I13JSCompartmentEEvPT_($3);
    var $_1 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext4new_I13JSCompartmentP9JSRuntimeEEPT_T0_($this, $p1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 1988);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN13JSCompartmentC2EP9JSRuntime($4, $p1);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z11js_NewGCXMLP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK9JSContext28runningWithTrustedPrincipalsEv($cx);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[_sE4XObjectsCreated >> 2] + 1 | 0;
    HEAP32[_sE4XObjectsCreated >> 2] = $4;
    __label__ = 3;
    break;
   case 3:
    var $6 = __Z10NewGCThingI5JSXMLEPT_P9JSContextN2js2gc9AllocKindEj($cx);
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z10NewGCThingI5JSXMLEPT_P9JSContextN2js2gc9AllocKindEj($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$cx + 56 >> 2] + 8 | 0;
    var $4 = __ZN2js2gc10ArenaLists20allocateFromFreeListENS0_9AllocKindEj($3, 16, 72);
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $9 = $4;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js2gc10ArenaLists14refillFreeListEP9JSContextNS0_9AllocKindE($cx, 16);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc5Arena11thingsStartENS0_9AllocKindE($this, $thingKind) {
  var $1 = __ZNK2js2gc5Arena7addressEv($this);
  var $2 = __ZN2js2gc5Arena16firstThingOffsetENS0_9AllocKindE($thingKind);
  return $2 | $1;
}

function __ZNK2js2gc5Arena7addressEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js2gc11ArenaHeader7addressEv($1);
  return $2;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3allEv($agg_result, $this_0_1_val, $this_0_5_val) {
  var $1 = $this_0_5_val + $this_0_1_val * 12 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5RangeC1EPNS0_14HashTableEntryIS4_EESE_($agg_result, $this_0_5_val, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5RangeC1EPNS0_14HashTableEntryIS4_EESE_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5RangeC2EPNS0_14HashTableEntryIS4_EESE_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5RangeC2EPNS0_14HashTableEntryIS4_EESE_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$4 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE6isLiveEv($_idx_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $this_0_1_val, $this_0_5_val) {
  var $1 = $this_0_5_val + ($this_0_1_val << 4) | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_($agg_result, $this_0_5_val, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$4 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isLiveEv($_idx_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 16 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E11createTableERS7_j($capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej($1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveIPvEENS_7MoveRefIT_EERKS3_($agg_result, $t) {
  __ZN2js7MoveRefIPvEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIPvEC1ERS1_($this, $t) {
  __ZN2js7MoveRefIPvEC2ERS1_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPvjEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIPvjEC1Ev($this) {
  __ZN2js12HashMapEntryIPvjEC2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS5_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e_idx_val = HEAP32[$e >> 2];
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE12hasCollisionEv($e_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPvNS_8RootInfoEEC1Ev($1);
  __ZN2js12HashMapEntryIPvNS_8RootInfoEEaSERKS3_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPvNS_8RootInfoEEC1Ev($1);
  __ZN2js12HashMapEntryIPvNS_8RootInfoEEaSERKS3_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12HashMapEntryIPvNS_8RootInfoEEC1Ev($this) {
  __ZN2js12HashMapEntryIPvNS_8RootInfoEEC2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + ($5 << 4) | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 5;
    break;
   case 5:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $22 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isLiveEv($src_01_idx_val);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE10getKeyHashEv($src_01_idx1_val);
    var $25 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEENS_7MoveRefIT_EERS9_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEaSENS_7MoveRefIS6_EE($25, $_02_val);
    __label__ = 7;
    break;
   case 7:
    var $27 = $src_01 + 16 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($3);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 4;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej($1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + ($capacity << 4) | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 16 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 4) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + ($15 << 4) | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEaSENS_7MoveRefIS6_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = $2 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIPvNS_8RootInfoEEEEENS_7MoveRefIT_EERS6_($1, $7);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js12HashMapEntryIPvNS_8RootInfoEEaSENS_7MoveRefIS3_EE($6, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEENS_7MoveRefIT_EERS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEC1ERS7_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEC2ERS7_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIPvNS_8RootInfoEEaSENS_7MoveRefIS3_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIPvNS_8RootInfoEEEEptEv($rhs_0);
  var $4 = $3 | 0;
  __ZN2js4MoveIPvEENS_7MoveRefIT_EERKS3_($1, $4);
  var $_idx_val = HEAP32[$1 >> 2];
  var $5 = __ZNK2js7MoveRefIPvEcvRS1_Ev($_idx_val);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = $this + 4 | 0;
  var $9 = $3 + 4 | 0;
  __ZN2js4MoveINS_8RootInfoEEENS_7MoveRefIT_EERS3_($2, $9);
  var $_idx2_val = HEAP32[$2 >> 2];
  var $10 = __ZNK2js7MoveRefINS_8RootInfoEEcvRS1_Ev($_idx2_val);
  var $11 = $10;
  var $12 = $8;
  var $13$0 = HEAP32[$11 >> 2];
  var $13$1 = HEAP32[$11 + 4 >> 2];
  HEAP32[$12 >> 2] = $13$0;
  HEAP32[$12 + 4 >> 2] = $13$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIPvNS_8RootInfoEEEEENS_7MoveRefIT_EERS6_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIPvNS_8RootInfoEEEEC1ERS4_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIPvNS_8RootInfoEEEEC1ERS4_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIPvNS_8RootInfoEEEEC2ERS4_($this, $t);
  return;
}

function __ZN2js4MoveINS_8RootInfoEEENS_7MoveRefIT_EERS3_($agg_result, $t) {
  __ZN2js7MoveRefINS_8RootInfoEEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_8RootInfoEEC1ERS1_($this, $t) {
  __ZN2js7MoveRefINS_8RootInfoEEC2ERS1_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPvNS_8RootInfoEEC1Ev($2);
  return;
}

function __ZNK2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6lookupERKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 122,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E3PtrE($this, $p_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeENSC_3PtrE($1, $p_0);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeENSC_3PtrE($this, $p_0) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS5_EE($this, $p_0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv($this);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS3_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS5_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS3_($l_val1) {
  var $1 = __ZN2js13PointerHasherIPvLj2EE4hashERKS1_($l_val1);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 4) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $l_val4 = HEAP32[$l >> 2];
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS3_($6, $l_val4);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + ($26 << 4) | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $l_val = HEAP32[$l >> 2];
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS3_($27, $l_val);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_jj["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS3_($e, $l_val1) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S2_EE($1);
  var $_val = HEAP32[$2 >> 2];
  var $3 = __ZN2js13PointerHasherIPvLj2EE5matchERKS1_S4_($_val, $l_val1);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE10isLiveHashEj($hash);
  return $1;
}

function __ZNK2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE12lookupForAddERKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS3_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E6AddPtrERKS1_RKS2_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $8 = $v;
    var $9 = $5 + 4 | 0;
    var $10$0 = HEAP32[$8 >> 2];
    var $10$1 = HEAP32[$8 + 4 >> 2];
    var $st$11$0 = $9 | 0;
    HEAP32[$st$11$0 >> 2] = $10$0;
    var $st$11$1 = $9 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $10$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefIPNS_2gc5ChunkEEcvRS3_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS3_($t) {
  return $t;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this_0_1_val, $this_0_2_val, $this_0_4_val) {
  return ($this_0_4_val + $this_0_2_val | 0) >>> 0 >= ($this_0_1_val * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE12hasCollisionEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js13GCChunkHasher5matchEPNS_2gc5ChunkES3_($k, $l) {
  return ($k | 0) == ($l | 0);
}

function __ZN2js13GCChunkHasher4hashEPNS_2gc5ChunkE($chunk) {
  return $chunk >>> 20;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEC2ERS7_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefIPNS_2gc5ChunkEEC2ERS3_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE10setRemovedEv($this) {
  HEAP32[$this >> 2] = 1;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE7setFreeEv($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js12AutoUnlockGCC2EP9JSRuntime($this, $rt) {
  HEAP32[$this >> 2] = $rt;
  return;
}

function __ZN2js2gc11ArenaHeader14setAsFullyUsedEv($this) {
  HEAP32[$this + 8 >> 2] = 268374016;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 8 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 16 >> 2];
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS3_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS3_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5clearEv($this) {
  var $3 = HEAP32[$this + 20 >> 2];
  var $6 = HEAP32[$this + 4 >> 2] * 12 | 0;
  _memset($3, 0, $6, 1);
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5clearEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $4 = HEAP32[$this + 20 >> 2];
    var $6 = HEAP32[$this + 4 >> 2];
    var $7 = $4 + ($6 << 4) | 0;
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = $1 | 0;
    var $e_01 = $4;
    __label__ = 3;
    break;
   case 3:
    var $e_01;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEC1Ev($2);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEENS_7MoveRefIT_EERKS9_($1, $2);
    var $_0_val = HEAP32[$_0 >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEaSENS_7MoveRefIS6_EE($e_01, $_0_val);
    var $9 = $e_01 + 16 | 0;
    if (($9 | 0) == ($7 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $e_01 = $9;
      __label__ = 3;
      break;
    }
   case 4:
    HEAP32[$this + 16 >> 2] = 0;
    HEAP32[$this + 8 >> 2] = 0;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEENS_7MoveRefIT_EERKS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5clearEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $4 = HEAP32[$this + 20 >> 2];
    var $6 = HEAP32[$this + 4 >> 2];
    var $7 = $4 + ($6 << 3) | 0;
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = $1 | 0;
    var $e_01 = $4;
    __label__ = 3;
    break;
   case 3:
    var $e_01;
    __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEEC1Ev($2);
    __ZN2js4MoveINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEENS_7MoveRefIT_EERKS9_($1, $2);
    var $_0_val = HEAP32[$_0 >> 2];
    __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEEaSENS_7MoveRefIS6_EE($e_01, $_0_val);
    var $9 = $e_01 + 8 | 0;
    if (($9 | 0) == ($7 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $e_01 = $9;
      __label__ = 3;
      break;
    }
   case 4:
    HEAP32[$this + 16 >> 2] = 0;
    HEAP32[$this + 8 >> 2] = 0;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEEaSENS_7MoveRefIS6_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $2 + 4 | 0;
  __ZN2js4MoveIPNS_2gc5ChunkEEENS_7MoveRefIT_EERS5_($1, $6);
  var $_idx_val = HEAP32[$1 >> 2];
  var $7 = __ZNK2js7MoveRefIPNS_2gc5ChunkEEcvRS3_Ev($_idx_val);
  var $8 = HEAP32[$7 >> 2];
  HEAP32[$this + 4 >> 2] = $8;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEENS_7MoveRefIT_EERKS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEEC2Ev($this);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEC1ERS7_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEC2ERS7_($this, $t);
  return;
}

function __ZN2js4MoveIPNS_2gc5ChunkEEENS_7MoveRefIT_EERS5_($agg_result, $t) {
  __ZN2js7MoveRefIPNS_2gc5ChunkEEC1ERS3_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIPNS_2gc5ChunkEEC1ERS3_($this, $t) {
  __ZN2js7MoveRefIPNS_2gc5ChunkEEC2ERS3_($this, $t);
  return;
}

function __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3allEv($agg_result, $this_0_1_val, $this_0_5_val) {
  var $1 = $this_0_5_val + ($this_0_1_val << 3) | 0;
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC1EPNS0_14HashTableEntryIS5_EESF_($agg_result, $this_0_5_val, $1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC1EPNS0_14HashTableEntryIS5_EESF_($this, $c, $e) {
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC2EPNS0_14HashTableEntryIS5_EESF_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC2EPNS0_14HashTableEntryIS5_EESF_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$4 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isLiveEv($_idx_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 8 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $roundUp_01 = 16;
    var $roundUpLog2_02 = 4;
    __label__ = 2;
    break;
   case 2:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $1 = $roundUp_01 << 1;
    var $2 = $roundUpLog2_02 + 1 | 0;
    if ($1 >>> 0 < 342) {
      var $roundUp_01 = $1;
      var $roundUpLog2_02 = $2;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E11createTableERS7_j($1);
    HEAP32[$this + 20 >> 2] = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E16setTableSizeLog2Ej($this, $2);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $roundUp_01 = 16;
    var $roundUpLog2_02 = 4;
    __label__ = 2;
    break;
   case 2:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $1 = $roundUp_01 << 1;
    var $2 = $roundUpLog2_02 + 1 | 0;
    if ($1 >>> 0 < 342) {
      var $roundUp_01 = $1;
      var $roundUpLog2_02 = $2;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($1);
    HEAP32[$this + 20 >> 2] = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $2);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $0 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j(32);
    HEAP32[$this + 20 >> 2] = $0;
    if (($0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, 5);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j($capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 3;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej($1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + ($capacity << 3) | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 8 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6lookupERKS3_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS5_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 124,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS3_NS6_6SetOpsES5_E3PtrE($this, $p_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE($1, $p_0);
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE($this, $p_0) {
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS5_EE($this, $p_0);
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv($this);
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS5_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e_idx_val = HEAP32[$e >> 2];
    var $1 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE12hasCollisionEv($e_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j($10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + ($5 << 3) | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 5;
    break;
   case 5:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $22 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isLiveEv($src_01_idx_val);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE10getKeyHashEv($src_01_idx1_val);
    var $25 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEENS_7MoveRefIT_EERS9_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEEaSENS_7MoveRefIS6_EE($25, $_02_val);
    __label__ = 7;
    break;
   case 7:
    var $27 = $src_01 + 8 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj($3);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 3) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + ($15 << 3) | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEENS_7MoveRefIT_EERS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS5_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS5_($l_val);
  var $2 = __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS5_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS5_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS5_($l_val) {
  var $1 = __ZN2js13GCChunkHasher4hashEPNS_2gc5ChunkE($l_val);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry);
  return;
}

function __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS5_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 3) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $l_val4 = HEAP32[$l >> 2];
    var $11 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS5_EERS5_($6, $l_val4);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + ($26 << 3) | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $l_val = HEAP32[$l >> 2];
    var $35 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS5_EERS5_($27, $l_val);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS5_jj["X"] = 1;

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS5_EERS5_($e, $l_val) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS3_($1);
  var $3 = HEAP32[$2 >> 2];
  var $4 = __ZN2js13GCChunkHasher5matchEPNS_2gc5ChunkES3_($3, $l_val);
  return $4;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js24AutoCopyFreeListToArenasD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    var $_idx_val = HEAP32[$2 + 4 >> 2];
    var $3 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($_idx_val);
    var $_idx4_val = HEAP32[$2 + 8 >> 2];
    var $4 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx_val, $_idx4_val);
    if (($3 | 0) == ($4 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $c_01 = $3;
      __label__ = 2;
      break;
    }
   case 2:
    var $c_01;
    var $7 = HEAP32[$c_01 >> 2] + 8 | 0;
    __ZN2js2gc10ArenaLists22clearFreeListsInArenasEv($7);
    var $8 = $c_01 + 4 | 0;
    var $9 = HEAP32[$1 >> 2];
    var $_idx1_val = HEAP32[$9 + 4 >> 2];
    var $_idx2_val = HEAP32[$9 + 8 >> 2];
    var $10 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx1_val, $_idx2_val);
    if (($8 | 0) == ($10 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $c_01 = $8;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc10ArenaLists22clearFreeListsInArenasEv($this) {
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 0);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 1);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 2);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 3);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 4);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 5);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 6);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 7);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 8);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 9);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 10);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 11);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 12);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 13);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 14);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 15);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 16);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 17);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 18);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 19);
  return;
}

function __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this + ($kind << 3) >> 2];
    var $_idx1_val = HEAP32[$this + ($kind << 3) + 4 >> 2];
    var $1 = __ZNK2js2gc8FreeSpan7isEmptyEv($_idx_val, $_idx1_val);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js2gc8FreeSpan11arenaHeaderEv($_idx1_val);
    __ZN2js2gc11ArenaHeader14setAsFullyUsedEv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js24AutoCopyFreeListToArenasC2EP9JSRuntime($this, $rt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this >> 2] = $rt;
    var $_idx = $rt + 4 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $2 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($_idx_val);
    var $_idx4 = $rt + 8 | 0;
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $3 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx_val, $_idx4_val);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $c_01 = $2;
      __label__ = 2;
      break;
    }
   case 2:
    var $c_01;
    var $6 = HEAP32[$c_01 >> 2] + 8 | 0;
    __ZN2js2gc10ArenaLists21copyFreeListsToArenasEv($6);
    var $7 = $c_01 + 4 | 0;
    var $_idx1_val = HEAP32[$_idx >> 2];
    var $_idx2_val = HEAP32[$_idx4 >> 2];
    var $8 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx1_val, $_idx2_val);
    if (($7 | 0) == ($8 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $c_01 = $7;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc10ArenaLists21copyFreeListsToArenasEv($this) {
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 0);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 1);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 2);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 3);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 4);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 5);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 6);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 7);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 8);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 9);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 10);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 11);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 12);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 13);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 14);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 15);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 16);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 17);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 18);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 19);
  return;
}

function __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, $thingKind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this + ($thingKind << 3) >> 2];
    var $_idx1_val = HEAP32[$this + ($thingKind << 3) + 4 >> 2];
    var $1 = __ZNK2js2gc8FreeSpan7isEmptyEv($_idx_val, $_idx1_val);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js2gc8FreeSpan11arenaHeaderEv($_idx1_val);
    __ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE($3, $_idx_val, $_idx1_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12MarkAndSweepP9JSContext18JSGCInvocationKindRN2js7GCTimerE($cx, $gckind, $gcTimer) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 96;
  var $gcmarker = __stackBase__;
  var $2 = HEAP32[$cx + 52 >> 2];
  var $3 = $2 + 164 | 0;
  var $5 = HEAP32[$3 >> 2] + 1 | 0;
  HEAP32[$3 >> 2] = $5;
  var $6 = $2 + 196 | 0;
  HEAP32[$6 >> 2] = 0;
  var $7 = $2 + 144076 | 0;
  HEAP32[$7 >> 2] = 0;
  __ZN9JSRuntime18resetGCMallocBytesEv($2);
  __ZN2js8GCMarkerC2EP9JSContext($gcmarker, $cx);
  var $8 = $2 + 168 | 0;
  HEAP32[$8 >> 2] = $gcmarker;
  __ZL14BeginMarkPhaseP9JSContextPN2js8GCMarkerE18JSGCInvocationKindRNS1_7GCTimerE($cx, $gcmarker, $gcTimer);
  __ZN2js8GCMarker14drainMarkStackEv($gcmarker);
  __ZL12EndMarkPhaseP9JSContextPN2js8GCMarkerE18JSGCInvocationKindRNS1_7GCTimerE($cx, $gcmarker);
  __ZL10SweepPhaseP9JSContextPN2js8GCMarkerE18JSGCInvocationKindRNS1_7GCTimerE($cx, $gcmarker, $gckind, $gcTimer);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js2gc18GCCompartmentsIter3getEv($this_0_0_val_val) {
  return $this_0_0_val_val;
}

function __ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE6lengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE6lengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE6lengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZNK2js14AutoValueArray6lengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZNK2js14AutoValueArray5startEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js10AutoLockGC6lockedEv($this_0_0_val) {
  return ($this_0_0_val | 0) != 0;
}

function __ZNK2js2gc10ArenaLists18arenaListsAreEmptyEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if (($i_0 | 0) == 20) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$this + 160 + ($i_0 << 3) >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE8shrinkByEj($this, $incr) {
  var $1 = $this + 4 | 0;
  var $3 = HEAP32[$1 >> 2] - $incr | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE10initializeEPS2_S5_($begin, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($begin | 0) == ($end | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $begin;
      __label__ = 2;
      break;
    }
   case 2:
    var $p_01;
    if (($p_01 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$p_01 >> 2] = 0;
    __label__ = 4;
    break;
   case 4:
    var $5 = $p_01 + 4 | 0;
    if (($5 | 0) == ($end | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $5;
      __label__ = 2;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZZ5js_GCP9JSContextP13JSCompartment18JSGCInvocationKindEN11AutoGCProbeC2ES2_($this, $comp) {
  HEAP32[$this >> 2] = $comp;
  return;
}

function __ZN2js2gc8FreeSpan18infallibleAllocateEj($this, $thingSize) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAPU32[$1 >> 2];
    if ($2 >>> 0 < HEAPU32[$this + 4 >> 2] >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $2 + $thingSize | 0;
    __label__ = 4;
    break;
   case 3:
    var $9 = $2;
    var $10 = $this;
    var $11$0 = HEAP32[$9 >> 2];
    var $11$1 = HEAP32[$9 + 4 >> 2];
    HEAP32[$10 >> 2] = $11$0;
    HEAP32[$10 + 4 >> 2] = $11$1;
    __label__ = 4;
    break;
   case 4:
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10AutoLockGC4lockEP9JSRuntime($this, $rt) {
  HEAP32[$this >> 2] = $rt;
  return;
}

function __ZN2js2gc8FreeSpan20allocateFromNewArenaEjjj($this, $arenaAddr, $firstThingOffset, $thingSize) {
  var $1 = $firstThingOffset | $arenaAddr;
  HEAP32[$this >> 2] = $1 + $thingSize | 0;
  HEAP32[$this + 4 >> 2] = $arenaAddr | 4095;
  return $1;
}

function __Z21GetAvailableChunkListP13JSCompartment($comp_0_0_val, $comp_0_7_val) {
  var $5 = ($comp_0_7_val & 1) << 24 >> 24 != 0 ? $comp_0_0_val + 72 | 0 : $comp_0_0_val + 76 | 0;
  return $5;
}

function __ZL14BeginMarkPhaseP9JSContextPN2js8GCMarkerE18JSGCInvocationKindRNS1_7GCTimerE($cx, $gcmarker, $gcTimer) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $c = __stackBase__;
    var $iter = __stackBase__ + 8;
    var $r = __stackBase__ + 12;
    var $1 = $cx + 52 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $2 + 209944 | 0;
    if ((HEAP32[$3 >> 2] & 16777216 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP8[$2 + 144091 | 0] = 1;
    HEAP32[$3 >> 2] = 0;
    var $9 = $2 + 44 | 0;
    HEAP32[$9 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    __ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime($c, $2);
    var $c_idx6 = $c | 0;
    var $c_idx6_val = HEAP32[$c_idx6 >> 2];
    var $c_idx7 = $c + 4 | 0;
    var $c_idx7_val = HEAP32[$c_idx7 >> 2];
    var $11 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c_idx6_val, $c_idx7_val);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      var $c_idx8_val = $c_idx6_val;
      __label__ = 4;
      break;
    }
   case 4:
    var $c_idx8_val;
    var $c_idx8_val_val = HEAP32[$c_idx8_val >> 2];
    var $12 = __ZNK2js2gc18GCCompartmentsIterptEv($c_idx8_val_val);
    __ZN13JSCompartment5purgeEP9JSContext($12);
    __ZN2js2gc18GCCompartmentsIter4nextEv($c);
    var $c_idx_val = HEAP32[$c_idx6 >> 2];
    var $c_idx5_val = HEAP32[$c_idx7 >> 2];
    var $13 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c_idx_val, $c_idx5_val);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      var $c_idx8_val = $c_idx_val;
      __label__ = 4;
      break;
    }
   case 5:
    var $cx_idx_val = HEAP32[$1 >> 2];
    __Z15js_PurgeThreadsP9JSContext($cx_idx_val);
    HEAP32[$iter >> 2] = 0;
    var $14 = __Z18js_ContextIteratorP9JSRuntimeiPP9JSContext($2, $iter);
    if (($14 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $16 = $14;
      __label__ = 6;
      break;
    }
   case 6:
    var $16;
    __ZN9JSContext5purgeEv($16);
    var $17 = __Z18js_ContextIteratorP9JSRuntimeiPP9JSContext($2, $iter);
    if (($17 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $16 = $17;
      __label__ = 6;
      break;
    }
   case 7:
    if ((HEAP8[$gcTimer + 77 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $24 = _PRMJ_Now();
    var $24$1 = $24[1];
    var $25 = $gcTimer + 12 | 0;
    HEAP32[$25 >> 2] = $24[0];
    HEAP32[$25 + 4 >> 2] = $24$1;
    __label__ = 9;
    break;
   case 9:
    var $27 = $2 + 48 | 0;
    __ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE3allEv($r, $27);
    var $r_idx10 = $r | 0;
    var $r_idx10_val = HEAP32[$r_idx10 >> 2];
    var $r_idx11 = $r + 4 | 0;
    var $r_idx11_val = HEAP32[$r_idx11 >> 2];
    var $28 = __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r_idx10_val, $r_idx11_val);
    if ($28) {
      __label__ = 11;
      break;
    } else {
      var $r_idx12_val = $r_idx10_val;
      __label__ = 10;
      break;
    }
   case 10:
    var $r_idx12_val;
    var $29 = __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($r_idx12_val);
    var $31 = HEAP32[$29 >> 2] + 1032192 | 0;
    __ZN2js2gc11ChunkBitmap5clearEv($31);
    __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($r);
    var $r_idx_val = HEAP32[$r_idx10 >> 2];
    var $r_idx9_val = HEAP32[$r_idx11 >> 2];
    var $32 = __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r_idx_val, $r_idx9_val);
    if ($32) {
      __label__ = 11;
      break;
    } else {
      var $r_idx12_val = $r_idx_val;
      __label__ = 10;
      break;
    }
   case 11:
    if ((HEAP32[$2 + 144080 >> 2] | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $_pre_phi = $gcmarker | 0;
    __label__ = 16;
    break;
   case 13:
    var $_idx = $2 + 4 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $37 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($_idx_val);
    var $_idx4 = $2 + 8 | 0;
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $38 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx_val, $_idx4_val);
    var $_pre15 = $gcmarker | 0;
    if (($37 | 0) == ($38 | 0)) {
      var $_pre_phi16 = $_pre15;
      __label__ = 15;
      break;
    } else {
      var $c1_01 = $37;
      __label__ = 14;
      break;
    }
   case 14:
    var $c1_01;
    var $40 = HEAP32[$c1_01 >> 2];
    __ZN13JSCompartment28markCrossCompartmentWrappersEP8JSTracer($40, $_pre15);
    var $41 = $c1_01 + 4 | 0;
    var $_idx1_val = HEAP32[$_idx >> 2];
    var $_idx2_val = HEAP32[$_idx4 >> 2];
    var $42 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx1_val, $_idx2_val);
    if (($41 | 0) == ($42 | 0)) {
      var $_pre_phi16 = $_pre15;
      __label__ = 15;
      break;
    } else {
      var $c1_01 = $41;
      __label__ = 14;
      break;
    }
   case 15:
    var $_pre_phi16;
    __ZN2js8Debugger43markCrossCompartmentDebuggerObjectReferentsEP8JSTracer($_pre_phi16);
    var $_pre_phi = $_pre_phi16;
    __label__ = 16;
    break;
   case 16:
    var $_pre_phi;
    __ZN2js11MarkRuntimeEP8JSTracer($_pre_phi);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14BeginMarkPhaseP9JSContextPN2js8GCMarkerE18JSGCInvocationKindRNS1_7GCTimerE["X"] = 1;

function __ZL12EndMarkPhaseP9JSContextPN2js8GCMarkerE18JSGCInvocationKindRNS1_7GCTimerE($cx, $gcmarker) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 52 >> 2];
    var $3 = $gcmarker | 0;
    __label__ = 2;
    break;
   case 2:
    var $5 = __ZN2js13WatchpointMap18markAllIterativelyEP8JSTracer($3);
    if ($5) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZN2js11WeakMapBase18markAllIterativelyEP8JSTracer($3);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZN2js8Debugger18markAllIterativelyEPNS_8GCMarkerE($gcmarker);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js8GCMarker14drainMarkStackEv($gcmarker);
    __label__ = 2;
    break;
   case 6:
    var $11 = $2 + 168 | 0;
    HEAP32[$11 >> 2] = 0;
    var $13 = HEAP32[$2 + 144092 >> 2];
    if (($13 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $16 = FUNCTION_TABLE[$13]($cx, 2);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10SweepPhaseP9JSContextPN2js8GCMarkerE18JSGCInvocationKindRNS1_7GCTimerE($cx, $gcmarker, $gckind, $gcTimer) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $c = __stackBase__;
    var $c1 = __stackBase__ + 8;
    var $c2 = __stackBase__ + 16;
    var $c3 = __stackBase__ + 24;
    var $c4 = __stackBase__ + 32;
    var $c5 = __stackBase__ + 40;
    var $c6 = __stackBase__ + 48;
    var $c7 = __stackBase__ + 56;
    var $1 = $cx + 52 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $gcTimer + 77 | 0;
    if ((HEAP8[$3] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = _PRMJ_Now();
    var $8$1 = $8[1];
    var $9 = $gcTimer + 20 | 0;
    var $st$4$0 = $9 | 0;
    HEAP32[$st$4$0 >> 2] = $8[0];
    var $st$4$1 = $9 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $8$1;
    __label__ = 3;
    break;
   case 3:
    var $11 = $gcmarker | 0;
    __ZN2js11WeakMapBase8sweepAllEP8JSTracer($11);
    __Z17js_SweepAtomStateP9JSContext($cx);
    __ZN2js13WatchpointMap8sweepAllEP9JSContext($cx);
    __ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime($c, $2);
    var $c_idx23 = $c | 0;
    var $c_idx23_val = HEAP32[$c_idx23 >> 2];
    var $c_idx24 = $c + 4 | 0;
    var $c_idx24_val = HEAP32[$c_idx24 >> 2];
    var $12 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c_idx23_val, $c_idx24_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js2gc18GCCompartmentsIter4nextEv($c);
    var $c_idx_val = HEAP32[$c_idx23 >> 2];
    var $c_idx22_val = HEAP32[$c_idx24 >> 2];
    var $13 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c_idx_val, $c_idx22_val);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 5:
    var $14 = $2 + 144080 | 0;
    if ((HEAP32[$14 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $21 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    __ZN2js8Debugger8sweepAllEP9JSContext($cx);
    if ((HEAP32[$14 >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $21 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $cx_idx_val = HEAP32[$1 >> 2];
    var $20 = __ZL25ComputeJitReleaseIntervalP9JSContext($cx_idx_val);
    var $21 = $20;
    __label__ = 8;
    break;
   case 8:
    var $21;
    __ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime($c1, $2);
    var $c1_idx20 = $c1 | 0;
    var $c1_idx20_val = HEAP32[$c1_idx20 >> 2];
    var $c1_idx21 = $c1 + 4 | 0;
    var $c1_idx21_val = HEAP32[$c1_idx21 >> 2];
    var $22 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c1_idx20_val, $c1_idx21_val);
    if ($22) {
      __label__ = 10;
      break;
    } else {
      var $c1_idx29_val = $c1_idx20_val;
      __label__ = 9;
      break;
    }
   case 9:
    var $c1_idx29_val;
    var $c1_idx29_val_val = HEAP32[$c1_idx29_val >> 2];
    var $23 = __ZNK2js2gc18GCCompartmentsIterptEv($c1_idx29_val_val);
    __ZN13JSCompartment5sweepEP9JSContextj($23, $cx, $21);
    __ZN2js2gc18GCCompartmentsIter4nextEv($c1);
    var $c1_idx_val = HEAP32[$c1_idx20 >> 2];
    var $c1_idx19_val = HEAP32[$c1_idx21 >> 2];
    var $24 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c1_idx_val, $c1_idx19_val);
    if ($24) {
      __label__ = 10;
      break;
    } else {
      var $c1_idx29_val = $c1_idx_val;
      __label__ = 9;
      break;
    }
   case 10:
    __ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime($c2, $2);
    var $c2_idx17 = $c2 | 0;
    var $c2_idx17_val = HEAP32[$c2_idx17 >> 2];
    var $c2_idx18 = $c2 + 4 | 0;
    var $c2_idx18_val = HEAP32[$c2_idx18 >> 2];
    var $25 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c2_idx17_val, $c2_idx18_val);
    if ($25) {
      __label__ = 12;
      break;
    } else {
      var $c2_idx28_val = $c2_idx17_val;
      __label__ = 11;
      break;
    }
   case 11:
    var $c2_idx28_val;
    var $c2_idx28_val_val = HEAP32[$c2_idx28_val >> 2];
    var $26 = __ZNK2js2gc18GCCompartmentsIterptEv($c2_idx28_val_val);
    var $27 = $26 + 8 | 0;
    __ZN2js2gc10ArenaLists15finalizeObjectsEP9JSContext($27, $cx);
    __ZN2js2gc18GCCompartmentsIter4nextEv($c2);
    var $c2_idx_val = HEAP32[$c2_idx17 >> 2];
    var $c2_idx16_val = HEAP32[$c2_idx18 >> 2];
    var $28 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c2_idx_val, $c2_idx16_val);
    if ($28) {
      __label__ = 12;
      break;
    } else {
      var $c2_idx28_val = $c2_idx_val;
      __label__ = 11;
      break;
    }
   case 12:
    if ((HEAP8[$3] & 1) << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $33 = _PRMJ_Now();
    var $33$1 = $33[1];
    var $34 = $gcTimer + 28 | 0;
    var $st$4$0 = $34 | 0;
    HEAP32[$st$4$0 >> 2] = $33[0];
    var $st$4$1 = $34 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $33$1;
    __label__ = 14;
    break;
   case 14:
    __ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime($c3, $2);
    var $c3_idx14 = $c3 | 0;
    var $c3_idx14_val = HEAP32[$c3_idx14 >> 2];
    var $c3_idx15 = $c3 + 4 | 0;
    var $c3_idx15_val = HEAP32[$c3_idx15 >> 2];
    var $36 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c3_idx14_val, $c3_idx15_val);
    if ($36) {
      __label__ = 16;
      break;
    } else {
      var $c3_idx27_val = $c3_idx14_val;
      __label__ = 15;
      break;
    }
   case 15:
    var $c3_idx27_val;
    var $c3_idx27_val_val = HEAP32[$c3_idx27_val >> 2];
    var $37 = __ZNK2js2gc18GCCompartmentsIterptEv($c3_idx27_val_val);
    var $38 = $37 + 8 | 0;
    __ZN2js2gc10ArenaLists15finalizeStringsEP9JSContext($38, $cx);
    __ZN2js2gc18GCCompartmentsIter4nextEv($c3);
    var $c3_idx_val = HEAP32[$c3_idx14 >> 2];
    var $c3_idx13_val = HEAP32[$c3_idx15 >> 2];
    var $39 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c3_idx_val, $c3_idx13_val);
    if ($39) {
      __label__ = 16;
      break;
    } else {
      var $c3_idx27_val = $c3_idx_val;
      __label__ = 15;
      break;
    }
   case 16:
    if ((HEAP8[$3] & 1) << 24 >> 24 == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $44 = _PRMJ_Now();
    var $44$1 = $44[1];
    var $45 = $gcTimer + 36 | 0;
    var $st$4$0 = $45 | 0;
    HEAP32[$st$4$0 >> 2] = $44[0];
    var $st$4$1 = $45 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $44$1;
    __label__ = 18;
    break;
   case 18:
    __ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime($c4, $2);
    var $c4_idx11 = $c4 | 0;
    var $c4_idx11_val = HEAP32[$c4_idx11 >> 2];
    var $c4_idx12 = $c4 + 4 | 0;
    var $c4_idx12_val = HEAP32[$c4_idx12 >> 2];
    var $47 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c4_idx11_val, $c4_idx12_val);
    if ($47) {
      __label__ = 20;
      break;
    } else {
      var $c4_idx26_val = $c4_idx11_val;
      __label__ = 19;
      break;
    }
   case 19:
    var $c4_idx26_val;
    var $c4_idx26_val_val = HEAP32[$c4_idx26_val >> 2];
    var $48 = __ZNK2js2gc18GCCompartmentsIterptEv($c4_idx26_val_val);
    var $49 = $48 + 8 | 0;
    __ZN2js2gc10ArenaLists15finalizeScriptsEP9JSContext($49, $cx);
    __ZN2js2gc18GCCompartmentsIter4nextEv($c4);
    var $c4_idx_val = HEAP32[$c4_idx11 >> 2];
    var $c4_idx10_val = HEAP32[$c4_idx12 >> 2];
    var $50 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c4_idx_val, $c4_idx10_val);
    if ($50) {
      __label__ = 20;
      break;
    } else {
      var $c4_idx26_val = $c4_idx_val;
      __label__ = 19;
      break;
    }
   case 20:
    if ((HEAP8[$3] & 1) << 24 >> 24 == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $55 = _PRMJ_Now();
    var $55$1 = $55[1];
    var $56 = $gcTimer + 44 | 0;
    var $st$4$0 = $56 | 0;
    HEAP32[$st$4$0 >> 2] = $55[0];
    var $st$4$1 = $56 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $55$1;
    __label__ = 22;
    break;
   case 22:
    __ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime($c5, $2);
    var $c5_idx8 = $c5 | 0;
    var $c5_idx8_val = HEAP32[$c5_idx8 >> 2];
    var $c5_idx9 = $c5 + 4 | 0;
    var $c5_idx9_val = HEAP32[$c5_idx9 >> 2];
    var $58 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c5_idx8_val, $c5_idx9_val);
    if ($58) {
      __label__ = 24;
      break;
    } else {
      var $c5_idx25_val = $c5_idx8_val;
      __label__ = 23;
      break;
    }
   case 23:
    var $c5_idx25_val;
    var $c5_idx25_val_val = HEAP32[$c5_idx25_val >> 2];
    var $59 = __ZNK2js2gc18GCCompartmentsIterptEv($c5_idx25_val_val);
    var $60 = $59 + 8 | 0;
    __ZN2js2gc10ArenaLists14finalizeShapesEP9JSContext($60, $cx);
    __ZN2js2gc18GCCompartmentsIter4nextEv($c5);
    var $c5_idx_val = HEAP32[$c5_idx8 >> 2];
    var $c5_idx7_val = HEAP32[$c5_idx9 >> 2];
    var $61 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c5_idx_val, $c5_idx7_val);
    if ($61) {
      __label__ = 24;
      break;
    } else {
      var $c5_idx25_val = $c5_idx_val;
      __label__ = 23;
      break;
    }
   case 24:
    if ((HEAP8[$3] & 1) << 24 >> 24 == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $66 = _PRMJ_Now();
    var $66$1 = $66[1];
    var $67 = $gcTimer + 52 | 0;
    var $st$4$0 = $67 | 0;
    HEAP32[$st$4$0 >> 2] = $66[0];
    var $st$4$1 = $67 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $66$1;
    __label__ = 26;
    break;
   case 26:
    __ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime($c6, $2);
    var $c6_idx5 = $c6 | 0;
    var $c6_idx5_val = HEAP32[$c6_idx5 >> 2];
    var $c6_idx6 = $c6 + 4 | 0;
    var $c6_idx6_val = HEAP32[$c6_idx6 >> 2];
    var $69 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c6_idx5_val, $c6_idx6_val);
    if ($69) {
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2js2gc18GCCompartmentsIter4nextEv($c6);
    var $c6_idx_val = HEAP32[$c6_idx5 >> 2];
    var $c6_idx4_val = HEAP32[$c6_idx6 >> 2];
    var $70 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c6_idx_val, $c6_idx4_val);
    if ($70) {
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 28:
    __ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime($c7, $2);
    var $c7_idx2 = $c7 | 0;
    var $c7_idx2_val = HEAP32[$c7_idx2 >> 2];
    var $c7_idx3 = $c7 + 4 | 0;
    var $c7_idx3_val = HEAP32[$c7_idx3 >> 2];
    var $71 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c7_idx2_val, $c7_idx3_val);
    if ($71) {
      __label__ = 30;
      break;
    } else {
      var $c7_idx30_val = $c7_idx2_val;
      __label__ = 29;
      break;
    }
   case 29:
    var $c7_idx30_val;
    var $c7_idx30_val_val = HEAP32[$c7_idx30_val >> 2];
    var $72 = __ZNK2js2gc18GCCompartmentsItercvP13JSCompartmentEv($c7_idx30_val_val);
    var $73 = $72;
    __Z23js_SweepScriptFilenamesP13JSCompartment($73);
    __ZN2js2gc18GCCompartmentsIter4nextEv($c7);
    var $c7_idx_val = HEAP32[$c7_idx2 >> 2];
    var $c7_idx1_val = HEAP32[$c7_idx3 >> 2];
    var $74 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c7_idx_val, $c7_idx1_val);
    if ($74) {
      __label__ = 30;
      break;
    } else {
      var $c7_idx30_val = $c7_idx_val;
      __label__ = 29;
      break;
    }
   case 30:
    if ((HEAP32[$14 >> 2] | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    __ZL17SweepCompartmentsP9JSContext18JSGCInvocationKind($cx, $gckind);
    __label__ = 32;
    break;
   case 32:
    __ZL14ExpireGCChunksP9JSRuntime18JSGCInvocationKind($2, $gckind);
    if ((HEAP8[$3] & 1) << 24 >> 24 == 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $83 = _PRMJ_Now();
    var $83$1 = $83[1];
    var $84 = $gcTimer + 60 | 0;
    var $st$4$0 = $84 | 0;
    HEAP32[$st$4$0 >> 2] = $83[0];
    var $st$4$1 = $84 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $83$1;
    __label__ = 34;
    break;
   case 34:
    var $87 = HEAP32[$2 + 144092 >> 2];
    if (($87 | 0) == 0) {
      __label__ = 36;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $90 = FUNCTION_TABLE[$87]($cx, 3);
    __label__ = 36;
    break;
   case 36:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10SweepPhaseP9JSContextPN2js8GCMarkerE18JSGCInvocationKindRNS1_7GCTimerE["X"] = 1;

function __ZNK2js2gc18GCCompartmentsItercvP13JSCompartmentEv($this_0_0_val_val) {
  var $1 = __ZNK2js2gc18GCCompartmentsIter3getEv($this_0_0_val_val);
  return $1;
}

function __ZL25ComputeJitReleaseIntervalP9JSContext($cx_0_11_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _PRMJ_Now();
    var $1$0 = $1[0];
    var $1$1 = $1[1];
    var $2 = $cx_0_11_val + 184 | 0;
    var $3$0 = HEAP32[$2 >> 2];
    var $3$1 = HEAP32[$2 + 4 >> 2];
    if (($1$1 | 0) < ($3$1 | 0) || ($1$1 | 0) == ($3$1 | 0) && $1$0 >>> 0 < $3$0 >>> 0) {
      var $releaseInterval_1 = 0;
      __label__ = 4;
      break;
    } else {
      var $releaseInterval_01 = 8;
      var $5$1 = $3$1;
      var $5$0 = $3$0;
      __label__ = 2;
      break;
    }
   case 2:
    var $5$0;
    var $5$1;
    var $releaseInterval_01;
    var $6 = $releaseInterval_01 - 1 | 0;
    var $7 = ($6 | 0) == 1;
    var $8$0 = $7 ? $1$0 : $5$0;
    var $8$1 = $7 ? $1$1 : $5$1;
    var $9$0 = (i64Math.add($8$0, $8$1, 6e7, 0), i64Math.result[0]);
    var $9$1 = i64Math.result[1];
    if (($1$1 | 0) < ($9$1 | 0) || ($1$1 | 0) == ($9$1 | 0) && $1$0 >>> 0 < $9$0 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $releaseInterval_01 = $6;
      var $5$1 = $9$1;
      var $5$0 = $9$0;
      __label__ = 2;
      break;
    }
   case 3:
    HEAP32[$2 >> 2] = $9$0;
    HEAP32[$2 + 4 >> 2] = $9$1;
    var $releaseInterval_1 = $6;
    __label__ = 4;
    break;
   case 4:
    var $releaseInterval_1;
    return $releaseInterval_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17SweepCompartmentsP9JSContext18JSGCInvocationKind($cx, $gckind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 52 >> 2];
    var $4 = HEAPU32[$2 + 32 >> 2];
    var $5 = $2 + 4 | 0;
    var $_idx1 = $5 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $6 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($_idx1_val);
    var $7 = $6 + 4 | 0;
    var $_idx3_val = HEAP32[$2 + 8 >> 2];
    var $8 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx1_val, $_idx3_val);
    var $9 = ($gckind | 0) == 1;
    var $10 = ($4 | 0) == 0;
    var $write_0_ph = $7;
    var $read_0_ph = $7;
    __label__ = 2;
    break;
   case 2:
    var $read_0_ph;
    var $write_0_ph;
    var $read_0 = $read_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $read_0;
    if ($read_0 >>> 0 < $8 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 4:
    var $14 = $read_0 + 4 | 0;
    var $15 = HEAPU32[$read_0 >> 2];
    if ((HEAP8[$15 + 340 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 5:
    var $21 = $15 + 8 | 0;
    var $22 = __ZNK2js2gc10ArenaLists18arenaListsAreEmptyEv($21);
    if ($22 | $9) {
      __label__ = 6;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 6:
    if ($10) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = FUNCTION_TABLE[$4]($cx, $15, 0);
    __label__ = 8;
    break;
   case 8:
    var $27 = $15 + 4 | 0;
    var $28 = HEAP32[$27 >> 2];
    if (($28 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $31 = $28 + 12 | 0;
    var $33 = HEAP32[$31 >> 2] - 1 | 0;
    HEAP32[$31 >> 2] = $33;
    var $35 = HEAP32[$27 >> 2];
    if (($33 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $38 = HEAP32[$35 + 16 >> 2];
    FUNCTION_TABLE[$38]($cx, $35);
    __label__ = 11;
    break;
   case 11:
    __ZN9JSContext7delete_I13JSCompartmentEEvPT_($15);
    var $read_0 = $14;
    __label__ = 3;
    break;
   case 12:
    HEAP32[$write_0_ph >> 2] = $15;
    var $write_0_ph = $write_0_ph + 4 | 0;
    var $read_0_ph = $14;
    __label__ = 2;
    break;
   case 13:
    var $_idx_val = HEAP32[$_idx1 >> 2];
    var $43 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($_idx_val);
    var $47 = $write_0_ph - $43 >> 2;
    __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6resizeEj($5, $47);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17SweepCompartmentsP9JSContext18JSGCInvocationKind["X"] = 1;

function __ZL14ExpireGCChunksP9JSRuntime18JSGCInvocationKind($rt, $gckind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lock = __stackBase__;
    __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $rt);
    var $2 = ($gckind | 0) == 2;
    var $3 = $rt + 84 | 0;
    var $chunkp_0_ph = $rt + 80 | 0;
    __label__ = 2;
    break;
   case 2:
    var $chunkp_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $5 = HEAP32[$chunkp_0_ph >> 2];
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ($2) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = $5 + 1048332 | 0;
    var $10 = HEAP32[$9 >> 2];
    if (($10 | 0) == 4) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $14 = HEAP32[$5 + 1048320 >> 2];
    HEAP32[$chunkp_0_ph >> 2] = $14;
    var $16 = HEAP32[$3 >> 2] - 1 | 0;
    HEAP32[$3 >> 2] = $16;
    __Z14ReleaseGCChunkP9JSRuntimePN2js2gc5ChunkE($5);
    __label__ = 3;
    break;
   case 7:
    var $18 = $10 + 1 | 0;
    HEAP32[$9 >> 2] = $18;
    var $chunkp_0_ph = $5 + 1048320 | 0;
    __label__ = 2;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext7delete_I13JSCompartmentEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN13JSCompartmentD2Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6resizeEj($this, $newLength) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 < $newLength >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $newLength - $2 | 0;
    var $6 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6growByEj($this, $5);
    __label__ = 4;
    break;
   case 3:
    var $8 = $2 - $newLength | 0;
    __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE8shrinkByEj($this, $8);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6growByEj($this, $incr) {
  var $1 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE10growByImplILb1EEEbj($this, $incr);
  return $1;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE10growByImplILb1EEEbj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 4 | 0;
    var $4 = HEAPU32[$3 >> 2];
    if ((HEAP32[$this + 8 >> 2] - $4 | 0) >>> 0 < $incr >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $this_idx1_val = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE13growStorageByEj($this, $incr);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $this_idx1_val = HEAP32[$3 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $this_idx1_val;
    var $this_idx_val = HEAP32[$this >> 2];
    var $10 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    var $11 = $10 + ($incr << 2) | 0;
    __ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE10initializeEPS2_S5_($10, $11);
    var $13 = HEAP32[$3 >> 2] + $incr | 0;
    HEAP32[$3 >> 2] = $13;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc18GCCompartmentsIterC2EP9JSRuntime($this, $rt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $rt + 144080 | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$this >> 2] = $1;
    HEAP32[$this + 4 >> 2] = $1 + 4 | 0;
    __label__ = 4;
    break;
   case 3:
    var $_idx = $rt + 4 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $9 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($_idx_val);
    HEAP32[$this >> 2] = $9;
    var $_idx1_val = HEAP32[$_idx >> 2];
    var $_idx2_val = HEAP32[$rt + 8 >> 2];
    var $11 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx1_val, $_idx2_val);
    HEAP32[$this + 4 >> 2] = $11;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc5Arena9thingsEndEv($this) {
  var $1 = __ZNK2js2gc5Arena7addressEv($this);
  return $1 + 4096 | 0;
}

function __ZL9PickChunkP13JSCompartment($comp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $chunk = __stackBase__;
    var $p = __stackBase__ + 4;
    var $1 = $comp | 0;
    var $2 = HEAP32[$1 >> 2];
    var $comp_idx1 = $comp + 341 | 0;
    var $comp_idx1_val = HEAP8[$comp_idx1];
    var $3 = __Z21GetAvailableChunkListP13JSCompartment($2, $comp_idx1_val);
    var $4 = HEAP32[$3 >> 2];
    HEAP32[$chunk >> 2] = $4;
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $4;
      __label__ = 9;
      break;
    }
   case 2:
    var $7 = $2 + 80 | 0;
    var $8 = HEAP32[$7 >> 2];
    HEAP32[$chunk >> 2] = $8;
    if (($8 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAP32[$8 + 1048320 >> 2];
    HEAP32[$7 >> 2] = $12;
    var $13 = $2 + 84 | 0;
    var $15 = HEAP32[$13 >> 2] - 1 | 0;
    HEAP32[$13 >> 2] = $15;
    __label__ = 6;
    break;
   case 4:
    var $17 = __Z15AllocateGCChunkP9JSRuntime();
    HEAP32[$chunk >> 2] = $17;
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js2gc5Chunk4initEv($17);
    HEAP8[$2 + 172 | 0] = 1;
    __label__ = 6;
    break;
   case 6:
    var $22 = $2 + 48 | 0;
    __ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE12lookupForAddERKS3_($p, $22, $chunk);
    var $23 = __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS3_NS6_6SetOpsES5_E6AddPtrERS9_($22, $p, $chunk);
    var $24 = HEAP32[$chunk >> 2];
    if ($23) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __Z14ReleaseGCChunkP9JSRuntimePN2js2gc5ChunkE($24);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 8:
    var $27 = $24 + 1048324 | 0;
    HEAP32[$27 >> 2] = 0;
    var $28 = $24 + 1048320 | 0;
    HEAP32[$28 >> 2] = 0;
    var $comp_idx2_val = HEAP32[$1 >> 2];
    var $comp_idx3_val = HEAP8[$comp_idx1];
    __ZN2js2gc5Chunk18addToAvailableListEP13JSCompartment($24, $comp_idx2_val, $comp_idx3_val);
    var $_0 = $24;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z15AllocateGCChunkP9JSRuntime() {
  var $1 = __ZN2js12AllocGCChunkEv();
  return $1;
}

function __ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE12lookupForAddERKS3_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERS5_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS3_NS6_6SetOpsES5_E6AddPtrERS9_($this, $p, $t) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS5_($1, $p, $t);
  return $2;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS5_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$t >> 2];
    var $6 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$6 >> 2] = $3;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv($this_0_1_val, $this_0_2_val, $this_0_4_val) {
  return ($this_0_4_val + $this_0_2_val | 0) >>> 0 >= ($this_0_1_val * 192 | 0) >>> 8 >>> 0;
}

function __ZNK2js2gc11ArenaHeader13hasFreeThingsEv($this_0_2_val) {
  return ($this_0_2_val | 0) != 268374016;
}

function __ZNK2js2gc8FreeSpan17nextSpanUncheckedEj($this_0_1_val) {
  return $this_0_1_val;
}

function __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js13AutoKeepAtomsD2Ev($this_0_0_val) {
  var $1 = $this_0_0_val + 136 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js13AutoKeepAtomsC2EP9JSRuntime($this, $rt) {
  HEAP32[$this >> 2] = $rt;
  var $2 = $rt + 136 | 0;
  var $4 = HEAP32[$2 >> 2] + 1 | 0;
  HEAP32[$2 >> 2] = $4;
  return;
}

function __ZNK16JSExternalString12externalTypeEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 8 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 16 >> 2];
    var $12 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERS5_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS5_($l_val);
  var $2 = __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS5_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js13AutoKeepAtomsC1EP9JSRuntime($this, $rt) {
  __ZN2js13AutoKeepAtomsC2EP9JSRuntime($this, $rt);
  return;
}

function __ZN2js13AutoKeepAtomsD1Ev($this_0_0_val) {
  __ZN2js13AutoKeepAtomsD2Ev($this_0_0_val);
  return;
}

function __ZN2js2gcL14FinalizeArenasEP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, $thingKind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($thingKind | 0) == 0 || ($thingKind | 0) == 1 || ($thingKind | 0) == 2 || ($thingKind | 0) == 3 || ($thingKind | 0) == 4 || ($thingKind | 0) == 5 || ($thingKind | 0) == 6 || ($thingKind | 0) == 7 || ($thingKind | 0) == 8 || ($thingKind | 0) == 9 || ($thingKind | 0) == 10 || ($thingKind | 0) == 11 || ($thingKind | 0) == 12) {
      __label__ = 2;
      break;
    } else if (($thingKind | 0) == 13) {
      __label__ = 3;
      break;
    } else if (($thingKind | 0) == 14) {
      __label__ = 4;
      break;
    } else if (($thingKind | 0) == 15) {
      __label__ = 5;
      break;
    } else if (($thingKind | 0) == 16) {
      __label__ = 6;
      break;
    } else if (($thingKind | 0) == 18) {
      __label__ = 7;
      break;
    } else if (($thingKind | 0) == 17) {
      __label__ = 8;
      break;
    } else if (($thingKind | 0) == 19) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 2:
    __ZN2js2gc19FinalizeTypedArenasI8JSObjectEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, $thingKind);
    __label__ = 10;
    break;
   case 3:
    __ZN2js2gc19FinalizeTypedArenasI8JSScriptEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, 13);
    __label__ = 10;
    break;
   case 4:
    __ZN2js2gc19FinalizeTypedArenasINS_5ShapeEEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, 14);
    __label__ = 10;
    break;
   case 5:
    __ZN2js2gc19FinalizeTypedArenasINS_5types10TypeObjectEEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($al, 15);
    __label__ = 10;
    break;
   case 6:
    __ZN2js2gc19FinalizeTypedArenasI5JSXMLEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, 16);
    __label__ = 10;
    break;
   case 7:
    __ZN2js2gc19FinalizeTypedArenasI8JSStringEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($al, 18);
    __label__ = 10;
    break;
   case 8:
    __ZN2js2gc19FinalizeTypedArenasI13JSShortStringEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($al, 17);
    __label__ = 10;
    break;
   case 9:
    __ZN2js2gc19FinalizeTypedArenasI16JSExternalStringEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, 19);
    __label__ = 10;
    break;
   case 10:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc19FinalizeTypedArenasI8JSObjectEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, $thingKind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $available = __stackBase__;
    __ZN2js2gc10ArenaLists9ArenaListC1Ev($available);
    var $1 = $al | 0;
    var $2 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $3 = $available + 4 | 0;
    var $ap_0_ph = $1;
    __label__ = 2;
    break;
   case 2:
    var $ap_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $4 = HEAP32[$ap_0_ph >> 2];
    if (($4 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZN2js2gc11ArenaHeader8getArenaEv($4);
    var $8 = __ZN2js2gc5Arena8finalizeI8JSObjectEEbP9JSContextNS0_9AllocKindEj($7, $cx, $thingKind, $2);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = HEAP32[$4 + 4 >> 2];
    HEAP32[$ap_0_ph >> 2] = $11;
    var $12 = __ZNK2js2gc11ArenaHeader5chunkEv($4);
    __ZN2js2gc5Chunk12releaseArenaEPNS0_11ArenaHeaderE($12, $4);
    __label__ = 3;
    break;
   case 6:
    var $_idx_val = HEAP32[$4 + 8 >> 2];
    var $14 = __ZNK2js2gc11ArenaHeader13hasFreeThingsEv($_idx_val);
    var $15 = $4 + 4 | 0;
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $ap_0_ph = $15;
      __label__ = 2;
      break;
    }
   case 7:
    var $17 = HEAP32[$15 >> 2];
    HEAP32[$ap_0_ph >> 2] = $17;
    var $18 = HEAP32[$3 >> 2];
    HEAP32[$18 >> 2] = $4;
    HEAP32[$3 >> 2] = $15;
    __label__ = 3;
    break;
   case 8:
    var $20 = HEAP32[$3 >> 2];
    HEAP32[$20 >> 2] = 0;
    var $22 = HEAP32[$available >> 2];
    HEAP32[$ap_0_ph >> 2] = $22;
    HEAP32[$al + 4 >> 2] = $ap_0_ph;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc19FinalizeTypedArenasI8JSScriptEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, $thingKind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $available = __stackBase__;
    __ZN2js2gc10ArenaLists9ArenaListC1Ev($available);
    var $1 = $al | 0;
    var $2 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $3 = $available + 4 | 0;
    var $ap_0_ph = $1;
    __label__ = 2;
    break;
   case 2:
    var $ap_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $4 = HEAP32[$ap_0_ph >> 2];
    if (($4 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZN2js2gc11ArenaHeader8getArenaEv($4);
    var $8 = __ZN2js2gc5Arena8finalizeI8JSScriptEEbP9JSContextNS0_9AllocKindEj($7, $cx, $thingKind, $2);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = HEAP32[$4 + 4 >> 2];
    HEAP32[$ap_0_ph >> 2] = $11;
    var $12 = __ZNK2js2gc11ArenaHeader5chunkEv($4);
    __ZN2js2gc5Chunk12releaseArenaEPNS0_11ArenaHeaderE($12, $4);
    __label__ = 3;
    break;
   case 6:
    var $_idx_val = HEAP32[$4 + 8 >> 2];
    var $14 = __ZNK2js2gc11ArenaHeader13hasFreeThingsEv($_idx_val);
    var $15 = $4 + 4 | 0;
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $ap_0_ph = $15;
      __label__ = 2;
      break;
    }
   case 7:
    var $17 = HEAP32[$15 >> 2];
    HEAP32[$ap_0_ph >> 2] = $17;
    var $18 = HEAP32[$3 >> 2];
    HEAP32[$18 >> 2] = $4;
    HEAP32[$3 >> 2] = $15;
    __label__ = 3;
    break;
   case 8:
    var $20 = HEAP32[$3 >> 2];
    HEAP32[$20 >> 2] = 0;
    var $22 = HEAP32[$available >> 2];
    HEAP32[$ap_0_ph >> 2] = $22;
    HEAP32[$al + 4 >> 2] = $ap_0_ph;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc19FinalizeTypedArenasINS_5ShapeEEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, $thingKind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $available = __stackBase__;
    __ZN2js2gc10ArenaLists9ArenaListC1Ev($available);
    var $1 = $al | 0;
    var $2 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $3 = $available + 4 | 0;
    var $ap_0_ph = $1;
    __label__ = 2;
    break;
   case 2:
    var $ap_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $4 = HEAP32[$ap_0_ph >> 2];
    if (($4 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZN2js2gc11ArenaHeader8getArenaEv($4);
    var $8 = __ZN2js2gc5Arena8finalizeINS_5ShapeEEEbP9JSContextNS0_9AllocKindEj($7, $cx, $thingKind, $2);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = HEAP32[$4 + 4 >> 2];
    HEAP32[$ap_0_ph >> 2] = $11;
    var $12 = __ZNK2js2gc11ArenaHeader5chunkEv($4);
    __ZN2js2gc5Chunk12releaseArenaEPNS0_11ArenaHeaderE($12, $4);
    __label__ = 3;
    break;
   case 6:
    var $_idx_val = HEAP32[$4 + 8 >> 2];
    var $14 = __ZNK2js2gc11ArenaHeader13hasFreeThingsEv($_idx_val);
    var $15 = $4 + 4 | 0;
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $ap_0_ph = $15;
      __label__ = 2;
      break;
    }
   case 7:
    var $17 = HEAP32[$15 >> 2];
    HEAP32[$ap_0_ph >> 2] = $17;
    var $18 = HEAP32[$3 >> 2];
    HEAP32[$18 >> 2] = $4;
    HEAP32[$3 >> 2] = $15;
    __label__ = 3;
    break;
   case 8:
    var $20 = HEAP32[$3 >> 2];
    HEAP32[$20 >> 2] = 0;
    var $22 = HEAP32[$available >> 2];
    HEAP32[$ap_0_ph >> 2] = $22;
    HEAP32[$al + 4 >> 2] = $ap_0_ph;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc19FinalizeTypedArenasINS_5types10TypeObjectEEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($al, $thingKind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $available = __stackBase__;
    __ZN2js2gc10ArenaLists9ArenaListC1Ev($available);
    var $1 = $al | 0;
    var $2 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $3 = $available + 4 | 0;
    var $ap_0_ph = $1;
    __label__ = 2;
    break;
   case 2:
    var $ap_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $4 = HEAP32[$ap_0_ph >> 2];
    if (($4 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZN2js2gc11ArenaHeader8getArenaEv($4);
    var $8 = __ZN2js2gc5Arena8finalizeINS_5types10TypeObjectEEEbP9JSContextNS0_9AllocKindEj($7, $thingKind, $2);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = HEAP32[$4 + 4 >> 2];
    HEAP32[$ap_0_ph >> 2] = $11;
    var $12 = __ZNK2js2gc11ArenaHeader5chunkEv($4);
    __ZN2js2gc5Chunk12releaseArenaEPNS0_11ArenaHeaderE($12, $4);
    __label__ = 3;
    break;
   case 6:
    var $_idx_val = HEAP32[$4 + 8 >> 2];
    var $14 = __ZNK2js2gc11ArenaHeader13hasFreeThingsEv($_idx_val);
    var $15 = $4 + 4 | 0;
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $ap_0_ph = $15;
      __label__ = 2;
      break;
    }
   case 7:
    var $17 = HEAP32[$15 >> 2];
    HEAP32[$ap_0_ph >> 2] = $17;
    var $18 = HEAP32[$3 >> 2];
    HEAP32[$18 >> 2] = $4;
    HEAP32[$3 >> 2] = $15;
    __label__ = 3;
    break;
   case 8:
    var $20 = HEAP32[$3 >> 2];
    HEAP32[$20 >> 2] = 0;
    var $22 = HEAP32[$available >> 2];
    HEAP32[$ap_0_ph >> 2] = $22;
    HEAP32[$al + 4 >> 2] = $ap_0_ph;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc19FinalizeTypedArenasI5JSXMLEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, $thingKind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $available = __stackBase__;
    __ZN2js2gc10ArenaLists9ArenaListC1Ev($available);
    var $1 = $al | 0;
    var $2 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $3 = $available + 4 | 0;
    var $ap_0_ph = $1;
    __label__ = 2;
    break;
   case 2:
    var $ap_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $4 = HEAP32[$ap_0_ph >> 2];
    if (($4 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZN2js2gc11ArenaHeader8getArenaEv($4);
    var $8 = __ZN2js2gc5Arena8finalizeI5JSXMLEEbP9JSContextNS0_9AllocKindEj($7, $cx, $thingKind, $2);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = HEAP32[$4 + 4 >> 2];
    HEAP32[$ap_0_ph >> 2] = $11;
    var $12 = __ZNK2js2gc11ArenaHeader5chunkEv($4);
    __ZN2js2gc5Chunk12releaseArenaEPNS0_11ArenaHeaderE($12, $4);
    __label__ = 3;
    break;
   case 6:
    var $_idx_val = HEAP32[$4 + 8 >> 2];
    var $14 = __ZNK2js2gc11ArenaHeader13hasFreeThingsEv($_idx_val);
    var $15 = $4 + 4 | 0;
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $ap_0_ph = $15;
      __label__ = 2;
      break;
    }
   case 7:
    var $17 = HEAP32[$15 >> 2];
    HEAP32[$ap_0_ph >> 2] = $17;
    var $18 = HEAP32[$3 >> 2];
    HEAP32[$18 >> 2] = $4;
    HEAP32[$3 >> 2] = $15;
    __label__ = 3;
    break;
   case 8:
    var $20 = HEAP32[$3 >> 2];
    HEAP32[$20 >> 2] = 0;
    var $22 = HEAP32[$available >> 2];
    HEAP32[$ap_0_ph >> 2] = $22;
    HEAP32[$al + 4 >> 2] = $ap_0_ph;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc19FinalizeTypedArenasI8JSStringEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($al, $thingKind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $available = __stackBase__;
    __ZN2js2gc10ArenaLists9ArenaListC1Ev($available);
    var $1 = $al | 0;
    var $2 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $3 = $available + 4 | 0;
    var $ap_0_ph = $1;
    __label__ = 2;
    break;
   case 2:
    var $ap_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $4 = HEAP32[$ap_0_ph >> 2];
    if (($4 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZN2js2gc11ArenaHeader8getArenaEv($4);
    var $8 = __ZN2js2gc5Arena8finalizeI8JSStringEEbP9JSContextNS0_9AllocKindEj($7, $thingKind, $2);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = HEAP32[$4 + 4 >> 2];
    HEAP32[$ap_0_ph >> 2] = $11;
    var $12 = __ZNK2js2gc11ArenaHeader5chunkEv($4);
    __ZN2js2gc5Chunk12releaseArenaEPNS0_11ArenaHeaderE($12, $4);
    __label__ = 3;
    break;
   case 6:
    var $_idx_val = HEAP32[$4 + 8 >> 2];
    var $14 = __ZNK2js2gc11ArenaHeader13hasFreeThingsEv($_idx_val);
    var $15 = $4 + 4 | 0;
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $ap_0_ph = $15;
      __label__ = 2;
      break;
    }
   case 7:
    var $17 = HEAP32[$15 >> 2];
    HEAP32[$ap_0_ph >> 2] = $17;
    var $18 = HEAP32[$3 >> 2];
    HEAP32[$18 >> 2] = $4;
    HEAP32[$3 >> 2] = $15;
    __label__ = 3;
    break;
   case 8:
    var $20 = HEAP32[$3 >> 2];
    HEAP32[$20 >> 2] = 0;
    var $22 = HEAP32[$available >> 2];
    HEAP32[$ap_0_ph >> 2] = $22;
    HEAP32[$al + 4 >> 2] = $ap_0_ph;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc19FinalizeTypedArenasI13JSShortStringEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($al, $thingKind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $available = __stackBase__;
    __ZN2js2gc10ArenaLists9ArenaListC1Ev($available);
    var $1 = $al | 0;
    var $2 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $3 = $available + 4 | 0;
    var $ap_0_ph = $1;
    __label__ = 2;
    break;
   case 2:
    var $ap_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $4 = HEAP32[$ap_0_ph >> 2];
    if (($4 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZN2js2gc11ArenaHeader8getArenaEv($4);
    var $8 = __ZN2js2gc5Arena8finalizeI13JSShortStringEEbP9JSContextNS0_9AllocKindEj($7, $thingKind, $2);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = HEAP32[$4 + 4 >> 2];
    HEAP32[$ap_0_ph >> 2] = $11;
    var $12 = __ZNK2js2gc11ArenaHeader5chunkEv($4);
    __ZN2js2gc5Chunk12releaseArenaEPNS0_11ArenaHeaderE($12, $4);
    __label__ = 3;
    break;
   case 6:
    var $_idx_val = HEAP32[$4 + 8 >> 2];
    var $14 = __ZNK2js2gc11ArenaHeader13hasFreeThingsEv($_idx_val);
    var $15 = $4 + 4 | 0;
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $ap_0_ph = $15;
      __label__ = 2;
      break;
    }
   case 7:
    var $17 = HEAP32[$15 >> 2];
    HEAP32[$ap_0_ph >> 2] = $17;
    var $18 = HEAP32[$3 >> 2];
    HEAP32[$18 >> 2] = $4;
    HEAP32[$3 >> 2] = $15;
    __label__ = 3;
    break;
   case 8:
    var $20 = HEAP32[$3 >> 2];
    HEAP32[$20 >> 2] = 0;
    var $22 = HEAP32[$available >> 2];
    HEAP32[$ap_0_ph >> 2] = $22;
    HEAP32[$al + 4 >> 2] = $ap_0_ph;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc19FinalizeTypedArenasI16JSExternalStringEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, $thingKind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $available = __stackBase__;
    __ZN2js2gc10ArenaLists9ArenaListC1Ev($available);
    var $1 = $al | 0;
    var $2 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $3 = $available + 4 | 0;
    var $ap_0_ph = $1;
    __label__ = 2;
    break;
   case 2:
    var $ap_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $4 = HEAP32[$ap_0_ph >> 2];
    if (($4 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZN2js2gc11ArenaHeader8getArenaEv($4);
    var $8 = __ZN2js2gc5Arena8finalizeI16JSExternalStringEEbP9JSContextNS0_9AllocKindEj($7, $cx, $thingKind, $2);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = HEAP32[$4 + 4 >> 2];
    HEAP32[$ap_0_ph >> 2] = $11;
    var $12 = __ZNK2js2gc11ArenaHeader5chunkEv($4);
    __ZN2js2gc5Chunk12releaseArenaEPNS0_11ArenaHeaderE($12, $4);
    __label__ = 3;
    break;
   case 6:
    var $_idx_val = HEAP32[$4 + 8 >> 2];
    var $14 = __ZNK2js2gc11ArenaHeader13hasFreeThingsEv($_idx_val);
    var $15 = $4 + 4 | 0;
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $ap_0_ph = $15;
      __label__ = 2;
      break;
    }
   case 7:
    var $17 = HEAP32[$15 >> 2];
    HEAP32[$ap_0_ph >> 2] = $17;
    var $18 = HEAP32[$3 >> 2];
    HEAP32[$18 >> 2] = $4;
    HEAP32[$3 >> 2] = $15;
    __label__ = 3;
    break;
   case 8:
    var $20 = HEAP32[$3 >> 2];
    HEAP32[$20 >> 2] = 0;
    var $22 = HEAP32[$available >> 2];
    HEAP32[$ap_0_ph >> 2] = $22;
    HEAP32[$al + 4 >> 2] = $ap_0_ph;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc5Arena8finalizeI16JSExternalStringEEbP9JSContextNS0_9AllocKindEj($this, $cx, $thingKind, $thingSize) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nextFree = __stackBase__;
    var $newListHead = __stackBase__ + 8;
    var $1 = __ZN2js2gc5Arena11thingsStartENS0_9AllocKindE($this, $thingKind);
    var $2 = __ZN2js2gc5Arena9thingsEndEv($this);
    var $3 = $2 - 1 | 0;
    var $4 = $this | 0;
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($nextFree, $4);
    var $5 = $nextFree + 4 | 0;
    var $6 = $nextFree | 0;
    var $7 = $nextFree;
    var $allClear_0 = 1;
    var $newFreeSpanStart_0 = 0;
    var $newListTail_0 = $newListHead;
    var $thing_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $thing_0;
    var $newListTail_0;
    var $newFreeSpanStart_0;
    var $allClear_0;
    var $9 = HEAP32[$6 >> 2];
    if (($thing_0 | 0) == ($9 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $12 = HEAP32[$5 >> 2];
    if (($12 | 0) == ($3 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $newFreeSpanStart_1 = ($newFreeSpanStart_0 | 0) == 0 ? $thing_0 : $newFreeSpanStart_0;
    var $16 = __ZNK2js2gc8FreeSpan8nextSpanEv($12);
    var $17 = $16;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    HEAP32[$7 >> 2] = $18$0;
    HEAP32[$7 + 4 >> 2] = $18$1;
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_1;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $12;
    __label__ = 9;
    break;
   case 5:
    var $21 = __ZNK2js2gc4Cell8isMarkedEj($thing_0);
    var $22 = ($newFreeSpanStart_0 | 0) == 0;
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if ($22) {
      var $allClear_1 = 0;
      var $newFreeSpanStart_3 = 0;
      var $newListTail_1 = $newListTail_0;
      var $thing_1 = $thing_0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$newListTail_0 >> 2] = $newFreeSpanStart_0;
    var $26 = $thing_0 - $thingSize | 0;
    HEAP32[$newListTail_0 + 4 >> 2] = $26;
    var $28 = __ZNK2js2gc8FreeSpan17nextSpanUncheckedEj($26);
    var $allClear_1 = 0;
    var $newFreeSpanStart_3 = 0;
    var $newListTail_1 = $28;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 8:
    var $newFreeSpanStart_2 = $22 ? $thing_0 : $newFreeSpanStart_0;
    __ZN16JSExternalString8finalizeEP9JSContext($thing_0, $cx);
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_2;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 9:
    var $thing_1;
    var $newListTail_1;
    var $newFreeSpanStart_3;
    var $allClear_1;
    var $allClear_0 = $allClear_1;
    var $newFreeSpanStart_0 = $newFreeSpanStart_3;
    var $newListTail_0 = $newListTail_1;
    var $thing_0 = $thing_1 + $thingSize | 0;
    __label__ = 2;
    break;
   case 10:
    if (($allClear_0 & 1) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    var $_newFreeSpanStart_0 = ($newFreeSpanStart_0 | 0) == 0 ? $9 : $newFreeSpanStart_0;
    HEAP32[$newListTail_0 >> 2] = $_newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $3;
    var $newListHead_idx_val = HEAP32[$newListHead >> 2];
    var $newListHead_idx1_val = HEAP32[$newListHead + 4 >> 2];
    __ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE($4, $newListHead_idx_val, $newListHead_idx1_val);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc5Arena8finalizeI16JSExternalStringEEbP9JSContextNS0_9AllocKindEj["X"] = 1;

function __ZN16JSExternalString8finalizeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK16JSExternalString12externalTypeEv($this);
    var $3 = HEAP32[__ZN16JSExternalString14str_finalizersE + ($1 << 2) >> 2];
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $this | 0;
    FUNCTION_TABLE[$3]($cx, $6);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc5Arena8finalizeI13JSShortStringEEbP9JSContextNS0_9AllocKindEj($this, $thingKind, $thingSize) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nextFree = __stackBase__;
    var $newListHead = __stackBase__ + 8;
    var $1 = __ZN2js2gc5Arena11thingsStartENS0_9AllocKindE($this, $thingKind);
    var $2 = __ZN2js2gc5Arena9thingsEndEv($this);
    var $3 = $2 - 1 | 0;
    var $4 = $this | 0;
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($nextFree, $4);
    var $5 = $nextFree + 4 | 0;
    var $6 = $nextFree | 0;
    var $7 = $nextFree;
    var $allClear_0 = 1;
    var $newFreeSpanStart_0 = 0;
    var $newListTail_0 = $newListHead;
    var $thing_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $thing_0;
    var $newListTail_0;
    var $newFreeSpanStart_0;
    var $allClear_0;
    var $9 = HEAP32[$6 >> 2];
    if (($thing_0 | 0) == ($9 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $12 = HEAP32[$5 >> 2];
    if (($12 | 0) == ($3 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $newFreeSpanStart_1 = ($newFreeSpanStart_0 | 0) == 0 ? $thing_0 : $newFreeSpanStart_0;
    var $16 = __ZNK2js2gc8FreeSpan8nextSpanEv($12);
    var $17 = $16;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    HEAP32[$7 >> 2] = $18$0;
    HEAP32[$7 + 4 >> 2] = $18$1;
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_1;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $12;
    __label__ = 9;
    break;
   case 5:
    var $21 = __ZNK2js2gc4Cell8isMarkedEj($thing_0);
    var $22 = ($newFreeSpanStart_0 | 0) == 0;
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if ($22) {
      var $allClear_1 = 0;
      var $newFreeSpanStart_3 = 0;
      var $newListTail_1 = $newListTail_0;
      var $thing_1 = $thing_0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$newListTail_0 >> 2] = $newFreeSpanStart_0;
    var $26 = $thing_0 - $thingSize | 0;
    HEAP32[$newListTail_0 + 4 >> 2] = $26;
    var $28 = __ZNK2js2gc8FreeSpan17nextSpanUncheckedEj($26);
    var $allClear_1 = 0;
    var $newFreeSpanStart_3 = 0;
    var $newListTail_1 = $28;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 8:
    var $newFreeSpanStart_2 = $22 ? $thing_0 : $newFreeSpanStart_0;
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_2;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 9:
    var $thing_1;
    var $newListTail_1;
    var $newFreeSpanStart_3;
    var $allClear_1;
    var $allClear_0 = $allClear_1;
    var $newFreeSpanStart_0 = $newFreeSpanStart_3;
    var $newListTail_0 = $newListTail_1;
    var $thing_0 = $thing_1 + $thingSize | 0;
    __label__ = 2;
    break;
   case 10:
    if (($allClear_0 & 1) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    var $_newFreeSpanStart_0 = ($newFreeSpanStart_0 | 0) == 0 ? $9 : $newFreeSpanStart_0;
    HEAP32[$newListTail_0 >> 2] = $_newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $3;
    var $newListHead_idx_val = HEAP32[$newListHead >> 2];
    var $newListHead_idx1_val = HEAP32[$newListHead + 4 >> 2];
    __ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE($4, $newListHead_idx_val, $newListHead_idx1_val);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc5Arena8finalizeI13JSShortStringEEbP9JSContextNS0_9AllocKindEj["X"] = 1;

function __ZN2js2gc5Arena8finalizeI8JSStringEEbP9JSContextNS0_9AllocKindEj($this, $thingKind, $thingSize) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nextFree = __stackBase__;
    var $newListHead = __stackBase__ + 8;
    var $1 = __ZN2js2gc5Arena11thingsStartENS0_9AllocKindE($this, $thingKind);
    var $2 = __ZN2js2gc5Arena9thingsEndEv($this);
    var $3 = $2 - 1 | 0;
    var $4 = $this | 0;
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($nextFree, $4);
    var $5 = $nextFree + 4 | 0;
    var $6 = $nextFree | 0;
    var $7 = $nextFree;
    var $allClear_0 = 1;
    var $newFreeSpanStart_0 = 0;
    var $newListTail_0 = $newListHead;
    var $thing_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $thing_0;
    var $newListTail_0;
    var $newFreeSpanStart_0;
    var $allClear_0;
    var $9 = HEAP32[$6 >> 2];
    if (($thing_0 | 0) == ($9 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $12 = HEAP32[$5 >> 2];
    if (($12 | 0) == ($3 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $newFreeSpanStart_1 = ($newFreeSpanStart_0 | 0) == 0 ? $thing_0 : $newFreeSpanStart_0;
    var $16 = __ZNK2js2gc8FreeSpan8nextSpanEv($12);
    var $17 = $16;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    HEAP32[$7 >> 2] = $18$0;
    HEAP32[$7 + 4 >> 2] = $18$1;
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_1;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $12;
    __label__ = 9;
    break;
   case 5:
    var $21 = __ZNK2js2gc4Cell8isMarkedEj($thing_0);
    var $22 = ($newFreeSpanStart_0 | 0) == 0;
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if ($22) {
      var $allClear_1 = 0;
      var $newFreeSpanStart_3 = 0;
      var $newListTail_1 = $newListTail_0;
      var $thing_1 = $thing_0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$newListTail_0 >> 2] = $newFreeSpanStart_0;
    var $26 = $thing_0 - $thingSize | 0;
    HEAP32[$newListTail_0 + 4 >> 2] = $26;
    var $28 = __ZNK2js2gc8FreeSpan17nextSpanUncheckedEj($26);
    var $allClear_1 = 0;
    var $newFreeSpanStart_3 = 0;
    var $newListTail_1 = $28;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 8:
    var $newFreeSpanStart_2 = $22 ? $thing_0 : $newFreeSpanStart_0;
    __ZN8JSString8finalizeEP9JSContext($thing_0);
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_2;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 9:
    var $thing_1;
    var $newListTail_1;
    var $newFreeSpanStart_3;
    var $allClear_1;
    var $allClear_0 = $allClear_1;
    var $newFreeSpanStart_0 = $newFreeSpanStart_3;
    var $newListTail_0 = $newListTail_1;
    var $thing_0 = $thing_1 + $thingSize | 0;
    __label__ = 2;
    break;
   case 10:
    if (($allClear_0 & 1) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    var $_newFreeSpanStart_0 = ($newFreeSpanStart_0 | 0) == 0 ? $9 : $newFreeSpanStart_0;
    HEAP32[$newListTail_0 >> 2] = $_newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $3;
    var $newListHead_idx_val = HEAP32[$newListHead >> 2];
    var $newListHead_idx1_val = HEAP32[$newListHead + 4 >> 2];
    __ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE($4, $newListHead_idx_val, $newListHead_idx1_val);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc5Arena8finalizeI8JSStringEEbP9JSContextNS0_9AllocKindEj["X"] = 1;

function __ZN8JSString8finalizeEP9JSContext($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK8JSString6isFlatEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN8JSString6asFlatEv($this);
    __ZN12JSFlatString8finalizeEP9JSRuntime($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc5Chunk17withinArenasRangeEj($addr) {
  return ($addr & 1032192) >>> 0 < 1032192;
}

function __ZN2js2gc5Chunk10arenaIndexEj($addr) {
  return $addr >>> 12 & 255;
}

function __ZN2js14FindChunkStartEPv($p) {
  return $p + 1048575 & -1048576;
}

function __ZN2js8RootInfoC2EPKc12JSGCRootType($this, $name, $type) {
  HEAP32[$this >> 2] = $name;
  HEAP32[$this + 4 >> 2] = $type;
  return;
}

function __ZNK2js2gc11ArenaHeader9allocatedEv($this) {
  return (HEAP32[$this + 12 >> 2] & 252) >>> 0 < 20;
}

function __ZN2js2gc5Arena8finalizeI5JSXMLEEbP9JSContextNS0_9AllocKindEj($this, $cx, $thingKind, $thingSize) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nextFree = __stackBase__;
    var $newListHead = __stackBase__ + 8;
    var $1 = __ZN2js2gc5Arena11thingsStartENS0_9AllocKindE($this, $thingKind);
    var $2 = __ZN2js2gc5Arena9thingsEndEv($this);
    var $3 = $2 - 1 | 0;
    var $4 = $this | 0;
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($nextFree, $4);
    var $5 = $nextFree + 4 | 0;
    var $6 = $nextFree | 0;
    var $7 = $nextFree;
    var $allClear_0 = 1;
    var $newFreeSpanStart_0 = 0;
    var $newListTail_0 = $newListHead;
    var $thing_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $thing_0;
    var $newListTail_0;
    var $newFreeSpanStart_0;
    var $allClear_0;
    var $9 = HEAP32[$6 >> 2];
    if (($thing_0 | 0) == ($9 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $12 = HEAP32[$5 >> 2];
    if (($12 | 0) == ($3 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $newFreeSpanStart_1 = ($newFreeSpanStart_0 | 0) == 0 ? $thing_0 : $newFreeSpanStart_0;
    var $16 = __ZNK2js2gc8FreeSpan8nextSpanEv($12);
    var $17 = $16;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    HEAP32[$7 >> 2] = $18$0;
    HEAP32[$7 + 4 >> 2] = $18$1;
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_1;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $12;
    __label__ = 9;
    break;
   case 5:
    var $21 = __ZNK2js2gc4Cell8isMarkedEj($thing_0);
    var $22 = ($newFreeSpanStart_0 | 0) == 0;
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if ($22) {
      var $allClear_1 = 0;
      var $newFreeSpanStart_3 = 0;
      var $newListTail_1 = $newListTail_0;
      var $thing_1 = $thing_0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$newListTail_0 >> 2] = $newFreeSpanStart_0;
    var $26 = $thing_0 - $thingSize | 0;
    HEAP32[$newListTail_0 + 4 >> 2] = $26;
    var $28 = __ZNK2js2gc8FreeSpan17nextSpanUncheckedEj($26);
    var $allClear_1 = 0;
    var $newFreeSpanStart_3 = 0;
    var $newListTail_1 = $28;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 8:
    var $newFreeSpanStart_2 = $22 ? $thing_0 : $newFreeSpanStart_0;
    __ZN5JSXML8finalizeEP9JSContext($thing_0, $cx);
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_2;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 9:
    var $thing_1;
    var $newListTail_1;
    var $newFreeSpanStart_3;
    var $allClear_1;
    var $allClear_0 = $allClear_1;
    var $newFreeSpanStart_0 = $newFreeSpanStart_3;
    var $newListTail_0 = $newListTail_1;
    var $thing_0 = $thing_1 + $thingSize | 0;
    __label__ = 2;
    break;
   case 10:
    if (($allClear_0 & 1) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    var $_newFreeSpanStart_0 = ($newFreeSpanStart_0 | 0) == 0 ? $9 : $newFreeSpanStart_0;
    HEAP32[$newListTail_0 >> 2] = $_newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $3;
    var $newListHead_idx_val = HEAP32[$newListHead >> 2];
    var $newListHead_idx1_val = HEAP32[$newListHead + 4 >> 2];
    __ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE($4, $newListHead_idx_val, $newListHead_idx1_val);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc5Arena8finalizeI5JSXMLEEbP9JSContextNS0_9AllocKindEj["X"] = 1;

function __ZN5JSXML8finalizeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 16 | 0;
    if (HEAPU32[$1 >> 2] >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = $this + 24 | 0;
    __ZN10JSXMLArray6finishEP9JSContext($6);
    if ((HEAP32[$1 >> 2] | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = $this + 40 | 0;
    __ZN10JSXMLArray6finishEP9JSContext($11);
    var $13 = $this + 56 | 0;
    __ZN10JSXMLArray6finishEP9JSContext($13);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc5Arena8finalizeINS_5types10TypeObjectEEEbP9JSContextNS0_9AllocKindEj($this, $thingKind, $thingSize) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nextFree = __stackBase__;
    var $newListHead = __stackBase__ + 8;
    var $1 = __ZN2js2gc5Arena11thingsStartENS0_9AllocKindE($this, $thingKind);
    var $2 = __ZN2js2gc5Arena9thingsEndEv($this);
    var $3 = $2 - 1 | 0;
    var $4 = $this | 0;
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($nextFree, $4);
    var $5 = $nextFree + 4 | 0;
    var $6 = $nextFree | 0;
    var $7 = $nextFree;
    var $allClear_0 = 1;
    var $newFreeSpanStart_0 = 0;
    var $newListTail_0 = $newListHead;
    var $thing_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $thing_0;
    var $newListTail_0;
    var $newFreeSpanStart_0;
    var $allClear_0;
    var $9 = HEAP32[$6 >> 2];
    if (($thing_0 | 0) == ($9 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $12 = HEAP32[$5 >> 2];
    if (($12 | 0) == ($3 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $newFreeSpanStart_1 = ($newFreeSpanStart_0 | 0) == 0 ? $thing_0 : $newFreeSpanStart_0;
    var $16 = __ZNK2js2gc8FreeSpan8nextSpanEv($12);
    var $17 = $16;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    HEAP32[$7 >> 2] = $18$0;
    HEAP32[$7 + 4 >> 2] = $18$1;
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_1;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $12;
    __label__ = 9;
    break;
   case 5:
    var $21 = __ZNK2js2gc4Cell8isMarkedEj($thing_0);
    var $22 = ($newFreeSpanStart_0 | 0) == 0;
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if ($22) {
      var $allClear_1 = 0;
      var $newFreeSpanStart_3 = 0;
      var $newListTail_1 = $newListTail_0;
      var $thing_1 = $thing_0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$newListTail_0 >> 2] = $newFreeSpanStart_0;
    var $26 = $thing_0 - $thingSize | 0;
    HEAP32[$newListTail_0 + 4 >> 2] = $26;
    var $28 = __ZNK2js2gc8FreeSpan17nextSpanUncheckedEj($26);
    var $allClear_1 = 0;
    var $newFreeSpanStart_3 = 0;
    var $newListTail_1 = $28;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 8:
    var $newFreeSpanStart_2 = $22 ? $thing_0 : $newFreeSpanStart_0;
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_2;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 9:
    var $thing_1;
    var $newListTail_1;
    var $newFreeSpanStart_3;
    var $allClear_1;
    var $allClear_0 = $allClear_1;
    var $newFreeSpanStart_0 = $newFreeSpanStart_3;
    var $newListTail_0 = $newListTail_1;
    var $thing_0 = $thing_1 + $thingSize | 0;
    __label__ = 2;
    break;
   case 10:
    if (($allClear_0 & 1) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    var $_newFreeSpanStart_0 = ($newFreeSpanStart_0 | 0) == 0 ? $9 : $newFreeSpanStart_0;
    HEAP32[$newListTail_0 >> 2] = $_newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $3;
    var $newListHead_idx_val = HEAP32[$newListHead >> 2];
    var $newListHead_idx1_val = HEAP32[$newListHead + 4 >> 2];
    __ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE($4, $newListHead_idx_val, $newListHead_idx1_val);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc5Arena8finalizeINS_5types10TypeObjectEEEbP9JSContextNS0_9AllocKindEj["X"] = 1;

function __ZN2js2gc5Arena8finalizeINS_5ShapeEEEbP9JSContextNS0_9AllocKindEj($this, $cx, $thingKind, $thingSize) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nextFree = __stackBase__;
    var $newListHead = __stackBase__ + 8;
    var $1 = __ZN2js2gc5Arena11thingsStartENS0_9AllocKindE($this, $thingKind);
    var $2 = __ZN2js2gc5Arena9thingsEndEv($this);
    var $3 = $2 - 1 | 0;
    var $4 = $this | 0;
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($nextFree, $4);
    var $5 = $nextFree + 4 | 0;
    var $6 = $nextFree | 0;
    var $7 = $nextFree;
    var $allClear_0 = 1;
    var $newFreeSpanStart_0 = 0;
    var $newListTail_0 = $newListHead;
    var $thing_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $thing_0;
    var $newListTail_0;
    var $newFreeSpanStart_0;
    var $allClear_0;
    var $9 = HEAP32[$6 >> 2];
    if (($thing_0 | 0) == ($9 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $12 = HEAP32[$5 >> 2];
    if (($12 | 0) == ($3 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $newFreeSpanStart_1 = ($newFreeSpanStart_0 | 0) == 0 ? $thing_0 : $newFreeSpanStart_0;
    var $16 = __ZNK2js2gc8FreeSpan8nextSpanEv($12);
    var $17 = $16;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    HEAP32[$7 >> 2] = $18$0;
    HEAP32[$7 + 4 >> 2] = $18$1;
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_1;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $12;
    __label__ = 9;
    break;
   case 5:
    var $21 = __ZNK2js2gc4Cell8isMarkedEj($thing_0);
    var $22 = ($newFreeSpanStart_0 | 0) == 0;
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if ($22) {
      var $allClear_1 = 0;
      var $newFreeSpanStart_3 = 0;
      var $newListTail_1 = $newListTail_0;
      var $thing_1 = $thing_0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$newListTail_0 >> 2] = $newFreeSpanStart_0;
    var $26 = $thing_0 - $thingSize | 0;
    HEAP32[$newListTail_0 + 4 >> 2] = $26;
    var $28 = __ZNK2js2gc8FreeSpan17nextSpanUncheckedEj($26);
    var $allClear_1 = 0;
    var $newFreeSpanStart_3 = 0;
    var $newListTail_1 = $28;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 8:
    var $newFreeSpanStart_2 = $22 ? $thing_0 : $newFreeSpanStart_0;
    __ZN2js5Shape8finalizeEP9JSContext($thing_0);
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_2;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 9:
    var $thing_1;
    var $newListTail_1;
    var $newFreeSpanStart_3;
    var $allClear_1;
    var $allClear_0 = $allClear_1;
    var $newFreeSpanStart_0 = $newFreeSpanStart_3;
    var $newListTail_0 = $newListTail_1;
    var $thing_0 = $thing_1 + $thingSize | 0;
    __label__ = 2;
    break;
   case 10:
    if (($allClear_0 & 1) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    var $_newFreeSpanStart_0 = ($newFreeSpanStart_0 | 0) == 0 ? $9 : $newFreeSpanStart_0;
    HEAP32[$newListTail_0 >> 2] = $_newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $3;
    var $newListHead_idx_val = HEAP32[$newListHead >> 2];
    var $newListHead_idx1_val = HEAP32[$newListHead + 4 >> 2];
    __ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE($4, $newListHead_idx_val, $newListHead_idx1_val);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc5Arena8finalizeINS_5ShapeEEEbP9JSContextNS0_9AllocKindEj["X"] = 1;

function __ZN2js2gc5Arena8finalizeI8JSScriptEEbP9JSContextNS0_9AllocKindEj($this, $cx, $thingKind, $thingSize) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nextFree = __stackBase__;
    var $newListHead = __stackBase__ + 8;
    var $1 = __ZN2js2gc5Arena11thingsStartENS0_9AllocKindE($this, $thingKind);
    var $2 = __ZN2js2gc5Arena9thingsEndEv($this);
    var $3 = $2 - 1 | 0;
    var $4 = $this | 0;
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($nextFree, $4);
    var $5 = $nextFree + 4 | 0;
    var $6 = $nextFree | 0;
    var $7 = $nextFree;
    var $8 = $cx;
    var $allClear_0 = 1;
    var $newFreeSpanStart_0 = 0;
    var $newListTail_0 = $newListHead;
    var $thing_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $thing_0;
    var $newListTail_0;
    var $newFreeSpanStart_0;
    var $allClear_0;
    var $10 = HEAP32[$6 >> 2];
    if (($thing_0 | 0) == ($10 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $13 = HEAP32[$5 >> 2];
    if (($13 | 0) == ($3 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $newFreeSpanStart_1 = ($newFreeSpanStart_0 | 0) == 0 ? $thing_0 : $newFreeSpanStart_0;
    var $17 = __ZNK2js2gc8FreeSpan8nextSpanEv($13);
    var $18 = $17;
    var $19$0 = HEAP32[$18 >> 2];
    var $19$1 = HEAP32[$18 + 4 >> 2];
    HEAP32[$7 >> 2] = $19$0;
    HEAP32[$7 + 4 >> 2] = $19$1;
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_1;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $13;
    __label__ = 9;
    break;
   case 5:
    var $22 = __ZNK2js2gc4Cell8isMarkedEj($thing_0);
    var $23 = ($newFreeSpanStart_0 | 0) == 0;
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if ($23) {
      var $allClear_1 = 0;
      var $newFreeSpanStart_3 = 0;
      var $newListTail_1 = $newListTail_0;
      var $thing_1 = $thing_0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$newListTail_0 >> 2] = $newFreeSpanStart_0;
    var $27 = $thing_0 - $thingSize | 0;
    HEAP32[$newListTail_0 + 4 >> 2] = $27;
    var $29 = __ZNK2js2gc8FreeSpan17nextSpanUncheckedEj($27);
    var $allClear_1 = 0;
    var $newFreeSpanStart_3 = 0;
    var $newListTail_1 = $29;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 8:
    var $newFreeSpanStart_2 = $23 ? $thing_0 : $newFreeSpanStart_0;
    __ZN8JSScript8finalizeEP9JSContext($thing_0, $8);
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_2;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 9:
    var $thing_1;
    var $newListTail_1;
    var $newFreeSpanStart_3;
    var $allClear_1;
    var $allClear_0 = $allClear_1;
    var $newFreeSpanStart_0 = $newFreeSpanStart_3;
    var $newListTail_0 = $newListTail_1;
    var $thing_0 = $thing_1 + $thingSize | 0;
    __label__ = 2;
    break;
   case 10:
    if (($allClear_0 & 1) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    var $_newFreeSpanStart_0 = ($newFreeSpanStart_0 | 0) == 0 ? $10 : $newFreeSpanStart_0;
    HEAP32[$newListTail_0 >> 2] = $_newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $3;
    var $newListHead_idx_val = HEAP32[$newListHead >> 2];
    var $newListHead_idx1_val = HEAP32[$newListHead + 4 >> 2];
    __ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE($4, $newListHead_idx_val, $newListHead_idx1_val);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc5Arena8finalizeI8JSScriptEEbP9JSContextNS0_9AllocKindEj["X"] = 1;

function __ZN2js2gc5Arena8finalizeI8JSObjectEEbP9JSContextNS0_9AllocKindEj($this, $cx, $thingKind, $thingSize) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nextFree = __stackBase__;
    var $newListHead = __stackBase__ + 8;
    var $1 = __ZN2js2gc5Arena11thingsStartENS0_9AllocKindE($this, $thingKind);
    var $2 = __ZN2js2gc5Arena9thingsEndEv($this);
    var $3 = $2 - 1 | 0;
    var $4 = $this | 0;
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($nextFree, $4);
    var $5 = $nextFree + 4 | 0;
    var $6 = $nextFree | 0;
    var $7 = $nextFree;
    var $allClear_0 = 1;
    var $newFreeSpanStart_0 = 0;
    var $newListTail_0 = $newListHead;
    var $thing_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $thing_0;
    var $newListTail_0;
    var $newFreeSpanStart_0;
    var $allClear_0;
    var $9 = HEAP32[$6 >> 2];
    if (($thing_0 | 0) == ($9 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $12 = HEAP32[$5 >> 2];
    if (($12 | 0) == ($3 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $newFreeSpanStart_1 = ($newFreeSpanStart_0 | 0) == 0 ? $thing_0 : $newFreeSpanStart_0;
    var $16 = __ZNK2js2gc8FreeSpan8nextSpanEv($12);
    var $17 = $16;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    HEAP32[$7 >> 2] = $18$0;
    HEAP32[$7 + 4 >> 2] = $18$1;
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_1;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $12;
    __label__ = 9;
    break;
   case 5:
    var $21 = __ZNK2js2gc4Cell8isMarkedEj($thing_0);
    var $22 = ($newFreeSpanStart_0 | 0) == 0;
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if ($22) {
      var $allClear_1 = 0;
      var $newFreeSpanStart_3 = 0;
      var $newListTail_1 = $newListTail_0;
      var $thing_1 = $thing_0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$newListTail_0 >> 2] = $newFreeSpanStart_0;
    var $26 = $thing_0 - $thingSize | 0;
    HEAP32[$newListTail_0 + 4 >> 2] = $26;
    var $28 = __ZNK2js2gc8FreeSpan17nextSpanUncheckedEj($26);
    var $allClear_1 = 0;
    var $newFreeSpanStart_3 = 0;
    var $newListTail_1 = $28;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 8:
    var $newFreeSpanStart_2 = $22 ? $thing_0 : $newFreeSpanStart_0;
    __ZN8JSObject8finalizeEP9JSContext($thing_0, $cx);
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_2;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 9:
    var $thing_1;
    var $newListTail_1;
    var $newFreeSpanStart_3;
    var $allClear_1;
    var $allClear_0 = $allClear_1;
    var $newFreeSpanStart_0 = $newFreeSpanStart_3;
    var $newListTail_0 = $newListTail_1;
    var $thing_0 = $thing_1 + $thingSize | 0;
    __label__ = 2;
    break;
   case 10:
    if (($allClear_0 & 1) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    var $_newFreeSpanStart_0 = ($newFreeSpanStart_0 | 0) == 0 ? $9 : $newFreeSpanStart_0;
    HEAP32[$newListTail_0 >> 2] = $_newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $3;
    var $newListHead_idx_val = HEAP32[$newListHead >> 2];
    var $newListHead_idx1_val = HEAP32[$newListHead + 4 >> 2];
    __ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE($4, $newListHead_idx_val, $newListHead_idx1_val);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc5Arena8finalizeI8JSObjectEEbP9JSContextNS0_9AllocKindEj["X"] = 1;

function __ZN8JSObject8finalizeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx1_val = HEAP32[$this >> 2];
    var $1 = __ZNK8JSObject9isNewbornEv($this_idx1_val);
    if ($1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK8JSObject8getClassEv($this_idx_val);
    var $5 = HEAP32[$3 + 36 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    FUNCTION_TABLE[$5]($cx, $this);
    __label__ = 4;
    break;
   case 4:
    __ZN8JSObject6finishEP9JSContext($this);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject6finishEP9JSContext($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject13hasSlotsArrayEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$this + 32 >> 2];
    __ZN9JSContext5free_EPv($5);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22MarkWordConservativelyEP8JSTracerj($trc, $w) {
  __ZN2js17MarkIfGCThingWordEP8JSTracerj($trc, $w);
  return;
}

function __ZN2js17MarkIfGCThingWordEP8JSTracerj($trc, $w) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $chunk = __stackBase__;
    if (($w & 3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $4 = $w & -8;
    var $5 = __ZN2js2gc5Chunk11fromAddressEj($4);
    HEAP32[$chunk >> 2] = $5;
    var $10 = HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 48 | 0;
    var $11 = __ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE3hasERKS3_($10, $chunk);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    var $13 = __ZN2js2gc5Chunk17withinArenasRangeEj($4);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $15 = __ZN2js2gc5Chunk10arenaIndexEj($4);
    var $17 = HEAP32[$chunk >> 2] + ($15 << 12) | 0;
    var $18 = __ZNK2js2gc11ArenaHeader9allocatedEv($17);
    if ($18) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $20 = __ZNK2js2gc11ArenaHeader12getAllocKindEv($17);
    var $21 = $w & 4088;
    var $22 = __ZN2js2gc5Arena16firstThingOffsetENS0_9AllocKindE($20);
    if ($21 >>> 0 < $22 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $25 = $21 - $22 | 0;
    var $26 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($20);
    var $28 = $4 - ($25 >>> 0) % ($26 >>> 0) | 0;
    var $29 = __ZN2js10InFreeListEPNS_2gc11ArenaHeaderEj($17, $28);
    if ($29) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $31 = $28;
    var $32 = __ZN2js2gcL19MapAllocToTraceKindENS0_9AllocKindE($20);
    __ZN2js2gc8MarkKindEP8JSTracerPv13JSGCTraceKind($trc, $31, $32);
    __label__ = 8;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE3hasERKS3_($this, $l) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = $this | 0;
  __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS5_($1, $3, $l);
  var $_idx_val_idx_val = HEAP32[HEAP32[$1 >> 2] >> 2];
  __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($2, $_idx_val_idx_val);
  var $6 = (HEAP32[$2 >> 2] | 0) != 0;
  STACKTOP = __stackBase__;
  return $6;
}

function __ZN2js10InFreeListEPNS_2gc11ArenaHeaderEj($aheader, $addr) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $firstSpan = __stackBase__;
    var $aheader_idx_val = HEAP32[$aheader + 8 >> 2];
    var $1 = __ZNK2js2gc11ArenaHeader13hasFreeThingsEv($aheader_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($firstSpan, $aheader);
    var $span_0 = $firstSpan;
    __label__ = 3;
    break;
   case 3:
    var $span_0;
    if (HEAPU32[$span_0 >> 2] >>> 0 > $addr >>> 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = HEAPU32[$span_0 + 4 >> 2];
    if ($9 >>> 0 < $addr >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 5:
    var $12 = __ZNK2js2gc8FreeSpan8nextSpanEv($9);
    var $span_0 = $12;
    __label__ = 3;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc11ChunkBitmap8isMarkedEPKNS0_4CellEj($this, $cell) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $word = __stackBase__;
  var $mask = __stackBase__ + 4;
  __ZN2js2gc11ChunkBitmap18getMarkWordAndMaskEPKNS0_4CellEjPPjS5_($this, $cell, 0, $word, $mask);
  var $5 = (HEAP32[$mask >> 2] & HEAP32[HEAP32[$word >> 2] >> 2] | 0) != 0;
  STACKTOP = __stackBase__;
  return $5;
}

function __ZN2jsL12PodArrayZeroIjLj4032EEEvRAT0__T_($t) {
  var $1 = $t;
  _memset($1, 0, 16128, 1);
  return;
}

function __ZN2js12AllocGCChunkEv() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL8MapPagesPvj(0, 2097152);
    var $2 = $1;
    var $3 = $2 + 1048576 | 0;
    var $4 = $2 & 1048575;
    var $5 = $3 - $4 | 0;
    var $6 = $5;
    if (($3 | 0) == ($4 | 0)) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($5 & 1048575 | 0) == 0) {
      var $_0 = $6;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZL10UnmapPagesPvj($6, 1048576);
    var $12 = __ZN2js14FindChunkStartEPv($6);
    var $13 = __ZL8MapPagesPvj($12, 1048576);
    var $p_0 = $13;
    __label__ = 4;
    break;
   case 4:
    var $p_0;
    if (($p_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $p_0;
      __label__ = 7;
      break;
    }
   case 5:
    var $17 = __ZL8MapPagesPvj(0, 2097152);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZL10UnmapPagesPvj($17, 2097152);
    var $20 = __ZN2js14FindChunkStartEPv($17);
    var $21 = __ZL8MapPagesPvj($20, 1048576);
    var $p_0 = $21;
    __label__ = 4;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8MapPagesPvj($addr, $size) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _mmap($addr, $size, 3, 4098, -1, 0);
    if (($1 | 0) == -1) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($addr | 0) == 0 | ($1 | 0) == ($addr | 0)) {
      var $_0 = $1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = _munmap($1, $size);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10UnmapPagesPvj($addr, $size) {
  var $1 = _munmap($addr, $size);
  return;
}

function __ZN2js11FreeGCChunkEPv($p) {
  __ZL10UnmapPagesPvj($p, 1048576);
  return;
}

function __ZN2js2gc10MarkStringEP8JSTracerP8JSString($trc, $str) {
  __ZN2js2gc4MarkI8JSStringEEvP8JSTracerPT_($trc, $str);
  return;
}

function __ZN2js2gc4MarkI8JSStringEEvP8JSTracerPT_($trc, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $6 = HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $thing;
    var $10 = __ZNK2js2gc4Cell11compartmentEv($9);
    if (($10 | 0) == ($6 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $14 = HEAP32[$trc + 4 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = $trc;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSString($17, $thing);
    __label__ = 6;
    break;
   case 5:
    var $19 = $thing;
    var $20 = __ZN2js2gc19GetGCThingTraceKindEPKv($19);
    FUNCTION_TABLE[$14]($trc, $19, $20);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($trc, $str) {
  __ZN2js2gc10MarkStringEP8JSTracerP8JSString($trc, $str);
  return;
}

function __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $obj) {
  __ZN2js2gc4MarkI8JSObjectEEvP8JSTracerPT_($trc, $obj);
  return;
}

function __ZN2js2gc4MarkI8JSObjectEEvP8JSTracerPT_($trc, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $6 = HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $thing;
    var $10 = __ZNK2js2gc4Cell11compartmentEv($9);
    if (($10 | 0) == ($6 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $14 = HEAP32[$trc + 4 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = $trc;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSObject($17, $thing);
    __label__ = 6;
    break;
   case 5:
    var $19 = $thing;
    var $20 = __ZN2js2gc19GetGCThingTraceKindEPKv($19);
    FUNCTION_TABLE[$14]($trc, $19, $20);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc26MarkCrossCompartmentObjectEP8JSTracerR8JSObjectPKc($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $6 = HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $obj;
    var $10 = __ZNK2js2gc4Cell11compartmentEv($9);
    if (($6 | 0) == ($10 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $obj);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc21MarkObjectWithPrinterEP8JSTracerR8JSObjectPFvS2_PcjEPKvj($trc, $obj) {
  __ZN2js2gc4MarkI8JSObjectEEvP8JSTracerPT_($trc, $obj);
  return;
}

function __ZN2js2gc10MarkScriptEP8JSTracerP8JSScriptPKc($trc, $script) {
  __ZN2js2gc4MarkI8JSScriptEEvP8JSTracerPT_($trc, $script);
  return;
}

function __ZN2js2gc4MarkI8JSScriptEEvP8JSTracerPT_($trc, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $6 = HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $thing;
    var $10 = __ZNK2js2gc4Cell11compartmentEv($9);
    if (($10 | 0) == ($6 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $14 = HEAP32[$trc + 4 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = $trc;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSScript($17, $thing);
    __label__ = 6;
    break;
   case 5:
    var $19 = $thing;
    var $20 = __ZN2js2gc19GetGCThingTraceKindEPKv($19);
    FUNCTION_TABLE[$14]($trc, $19, $20);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc9MarkShapeEP8JSTracerPKNS_5ShapeEPKc($trc, $shape) {
  __ZN2js2gc4MarkIKNS_5ShapeEEEvP8JSTracerPT_($trc, $shape);
  return;
}

function __ZN2js2gc4MarkIKNS_5ShapeEEEvP8JSTracerPT_($trc, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $6 = HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $thing;
    var $10 = __ZNK2js2gc4Cell11compartmentEv($9);
    if (($10 | 0) == ($6 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $14 = HEAP32[$trc + 4 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = $trc;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($17, $thing);
    __label__ = 6;
    break;
   case 5:
    var $19 = $thing;
    var $20 = __ZN2js2gc19GetGCThingTraceKindEPKv($19);
    FUNCTION_TABLE[$14]($trc, $19, $20);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc14MarkTypeObjectEP8JSTracerPNS_5types10TypeObjectEPKc($trc, $type) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($type | 0) == (__ZN2js5types15emptyTypeObjectE | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc4MarkINS_5types10TypeObjectEEEvP8JSTracerPT_($trc, $type);
    if ((HEAP32[$trc + 4 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    var $8 = HEAP32[$type + 4 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $8);
    __label__ = 5;
    break;
   case 5:
    var $13 = HEAP32[$type + 28 >> 2];
    if (($13 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = $13 | 0;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $16);
    __label__ = 7;
    break;
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject10typeFromGCEv($this_0_9_val) {
  return $this_0_9_val;
}

function _JSID_IS_STRING1510($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_TO_STRING1511($iden) {
  return $iden;
}

function _JSID_IS_OBJECT1512($iden) {
  return ($iden & 7 | 0) == 4 & ($iden | 0) != 4 & 1;
}

function _JSID_TO_OBJECT1513($iden) {
  return $iden & -8;
}

function __ZNK2js5Shape14hasGetterValueEv($this_0_7_val) {
  return ($this_0_7_val & 16) << 24 >> 24 != 0;
}

function __ZNK2js5Shape14hasSetterValueEv($this_0_7_val) {
  return ($this_0_7_val & 32) << 24 >> 24 != 0;
}

function __ZNK6JSRope10rightChildEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN8JSScript6constsEv($this_0_1_val, $this_0_10_val) {
  return $this_0_1_val + ($this_0_10_val & 255) | 0;
}

function __ZNK2js5Shape12getterObjectEv($this) {
  return HEAP32[$this + 16 >> 2];
}

function __ZNK2js5Shape12setterObjectEv($this) {
  return HEAP32[$this + 20 >> 2];
}

function __ZN2js2gc4MarkINS_5types10TypeObjectEEEvP8JSTracerPT_($trc, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $6 = HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $thing;
    var $10 = __ZNK2js2gc4Cell11compartmentEv($9);
    if (($10 | 0) == ($6 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $14 = HEAP32[$trc + 4 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = $trc;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPNS_5types10TypeObjectE($17, $thing);
    __label__ = 6;
    break;
   case 5:
    var $19 = $thing;
    var $20 = __ZN2js2gc19GetGCThingTraceKindEPKv($19);
    FUNCTION_TABLE[$14]($trc, $19, $20);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc4MarkI5JSXMLEEvP8JSTracerPT_($trc, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $6 = HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $thing;
    var $10 = __ZNK2js2gc4Cell11compartmentEv($9);
    if (($10 | 0) == ($6 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $14 = HEAP32[$trc + 4 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = $trc;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP5JSXML($17, $thing);
    __label__ = 6;
    break;
   case 5:
    var $19 = $thing;
    var $20 = __ZN2js2gc19GetGCThingTraceKindEPKv($19);
    FUNCTION_TABLE[$14]($trc, $19, $20);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc15MarkObjectRangeEP8JSTracerjPP8JSObjectPKc($trc, $len, $vec) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($len | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $i_01;
    var $3 = HEAP32[$vec + ($i_01 << 2) >> 2];
    if (($3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js2gc4MarkI8JSObjectEEvP8JSTracerPT_($trc, $3);
    __label__ = 4;
    break;
   case 4:
    var $7 = $i_01 + 1 | 0;
    if (($7 | 0) == ($len | 0)) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = $7;
      __label__ = 2;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc12MarkXMLRangeEP8JSTracerjPP5JSXMLPKc($trc, $len, $vec) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($len | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $i_01;
    var $3 = HEAP32[$vec + ($i_01 << 2) >> 2];
    if (($3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js2gc4MarkI5JSXMLEEvP8JSTracerPT_($trc, $3);
    __label__ = 4;
    break;
   case 4:
    var $7 = $i_01 + 1 | 0;
    if (($7 | 0) == ($len | 0)) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = $7;
      __label__ = 2;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc6MarkIdEP8JSTraceri($trc, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_STRING1510($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_STRING1511($id);
    __ZN2js2gc4MarkI8JSStringEEvP8JSTracerPT_($trc, $4);
    __label__ = 5;
    break;
   case 3:
    var $6 = _JSID_IS_OBJECT1512($id);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _JSID_TO_OBJECT1513($id);
    __ZN2js2gc4MarkI8JSObjectEEvP8JSTracerPT_($trc, $9);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc6MarkIdEP8JSTraceriPKc($trc, $id) {
  __ZN2js2gc6MarkIdEP8JSTraceri($trc, $id);
  return;
}

function __ZN2js2gc11MarkIdRangeEP8JSTracerPiS3_PKc($trc, $beg, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($beg | 0) == ($end | 0)) {
      __label__ = 3;
      break;
    } else {
      var $idp_01 = $beg;
      __label__ = 2;
      break;
    }
   case 2:
    var $idp_01;
    var $2 = HEAP32[$idp_01 >> 2];
    __ZN2js2gc6MarkIdEP8JSTraceri($trc, $2);
    var $3 = $idp_01 + 4 | 0;
    if (($3 | 0) == ($end | 0)) {
      __label__ = 3;
      break;
    } else {
      var $idp_01 = $3;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc11MarkIdRangeEP8JSTracerjPiPKc($trc, $len, $vec) {
  var $1 = $vec + ($len << 2) | 0;
  __ZN2js2gc11MarkIdRangeEP8JSTracerPiS3_PKc($trc, $vec, $1);
  return;
}

function __ZN2js2gc8MarkKindEP8JSTracerPv13JSGCTraceKind($trc, $thing, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($kind | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($kind | 0) == 1) {
      __label__ = 3;
      break;
    } else if (($kind | 0) == 2) {
      __label__ = 4;
      break;
    } else if (($kind | 0) == 4) {
      __label__ = 5;
      break;
    } else if (($kind | 0) == 5) {
      __label__ = 6;
      break;
    } else if (($kind | 0) == 3) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $2 = $thing;
    __ZN2js2gc4MarkI8JSObjectEEvP8JSTracerPT_($trc, $2);
    __label__ = 8;
    break;
   case 3:
    var $4 = $thing;
    __ZN2js2gc10MarkStringEP8JSTracerP8JSString($trc, $4);
    __label__ = 8;
    break;
   case 4:
    var $6 = $thing;
    __ZN2js2gc4MarkI8JSScriptEEvP8JSTracerPT_($trc, $6);
    __label__ = 8;
    break;
   case 5:
    var $8 = $thing;
    __ZN2js2gc4MarkINS_5ShapeEEEvP8JSTracerPT_($trc, $8);
    __label__ = 8;
    break;
   case 6:
    var $10 = $thing;
    __ZN2js2gc14MarkTypeObjectEP8JSTracerPNS_5types10TypeObjectEPKc($trc, $10);
    __label__ = 8;
    break;
   case 7:
    var $12 = $thing;
    __ZN2js2gc4MarkI5JSXMLEEvP8JSTracerPT_($trc, $12);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc4MarkINS_5ShapeEEEvP8JSTracerPT_($trc, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $6 = HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $thing;
    var $10 = __ZNK2js2gc4Cell11compartmentEv($9);
    if (($10 | 0) == ($6 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $14 = HEAP32[$trc + 4 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = $trc;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($17, $thing);
    __label__ = 6;
    break;
   case 5:
    var $19 = $thing;
    var $20 = __ZN2js2gc19GetGCThingTraceKindEPKv($19);
    FUNCTION_TABLE[$14]($trc, $19, $20);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc12MarkValueRawEP8JSTracerRKN2JS5ValueE($trc, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value10isMarkableEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value9toGCThingEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $4 = __ZNK2JS5Value6gcKindEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    __ZN2js2gc8MarkKindEP8JSTracerPv13JSGCTraceKind($trc, $3, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value6gcKindEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_TRACE_KIND_IMPL1545($this_0_0_0_val$0, $this_0_0_0_val$1);
  return $1;
}

function __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  __ZN2js2gc12MarkValueRawEP8JSTracerRKN2JS5ValueE($trc, $v_0_0_0_val$0, $v_0_0_0_val$1);
  return;
}

function __ZN2js2gc25MarkCrossCompartmentValueEP8JSTracerRKN2JS5ValueEPKc($trc, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value10isMarkableEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $8 = HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2JS5Value9toGCThingEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $12 = $11;
    var $13 = __ZNK2js2gc4Cell11compartmentEv($12);
    if (($13 | 0) == ($8 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $v_0_0_0_val$0, $v_0_0_0_val$1);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc14MarkValueRangeEP8JSTracerPKN2JS5ValueES6_PKc($trc, $beg, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($beg >>> 0 < $end >>> 0) {
      var $vp_01 = $beg;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $vp_01;
    var $vp_01_idx = $vp_01 | 0;
    var $vp_01_idx_val$0 = HEAP32[$vp_01_idx >> 2];
    var $vp_01_idx_val$1 = HEAP32[$vp_01_idx + 4 >> 2];
    __ZN2js2gc12MarkValueRawEP8JSTracerRKN2JS5ValueE($trc, $vp_01_idx_val$0, $vp_01_idx_val$1);
    var $2 = $vp_01 + 8 | 0;
    if ($2 >>> 0 < $end >>> 0) {
      var $vp_01 = $2;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc14MarkValueRangeEP8JSTracerjPKN2JS5ValueEPKc($trc, $len, $vec) {
  var $1 = $vec + ($len << 3) | 0;
  __ZN2js2gc14MarkValueRangeEP8JSTracerPKN2JS5ValueES6_PKc($trc, $vec, $1);
  return;
}

function __ZN2js2gc14MarkShapeRangeEP8JSTracerPPKNS_5ShapeES6_PKc($trc, $beg, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($beg >>> 0 < $end >>> 0) {
      var $sp_01 = $beg;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $sp_01;
    var $2 = HEAP32[$sp_01 >> 2];
    __ZN2js2gc9MarkShapeEP8JSTracerPKNS_5ShapeEPKc($trc, $2);
    var $3 = $sp_01 + 4 | 0;
    if ($3 >>> 0 < $end >>> 0) {
      var $sp_01 = $3;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc14MarkShapeRangeEP8JSTracerjPPKNS_5ShapeEPKc($trc, $len, $vec) {
  var $1 = $vec + ($len << 2) | 0;
  __ZN2js2gc14MarkShapeRangeEP8JSTracerPPKNS_5ShapeES6_PKc($trc, $vec, $1);
  return;
}

function __ZN2js2gc11MarkGCThingEP8JSTracerPv($trc, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($thing | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2js2gc19GetGCThingTraceKindEPKv($thing);
    __ZN2js2gc8MarkKindEP8JSTracerPv13JSGCTraceKind($trc, $thing, $3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc11MarkGCThingEP8JSTracerPvPKc($trc, $thing) {
  __ZN2js2gc11MarkGCThingEP8JSTracerPv($trc, $thing);
  return;
}

function __ZN2js2gc11MarkGCThingEP8JSTracerPvPKcj($trc, $thing) {
  __ZN2js2gc11MarkGCThingEP8JSTracerPv($trc, $thing);
  return;
}

function __ZN2js2gc12MarkChildrenEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj_idx2 = $obj | 0;
    var $obj_idx2_val = HEAP32[$obj_idx2 >> 2];
    var $1 = __ZNK8JSObject9isNewbornEv($obj_idx2_val);
    if ($1) {
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $obj_idx3_val = HEAP32[$obj + 36 >> 2];
    var $3 = __ZNK8JSObject10typeFromGCEv($obj_idx3_val);
    __ZN2js2gc14MarkTypeObjectEP8JSTracerPNS_5types10TypeObjectEPKc($trc, $3);
    var $obj_idx6 = $obj + 4 | 0;
    var $obj_idx6_val = HEAP32[$obj_idx6 >> 2];
    var $4 = __ZNK8JSObject12isDenseArrayEv($obj_idx6_val);
    if ($4) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = HEAP32[$obj + 16 >> 2];
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js2gc14MarkTypeObjectEP8JSTracerPNS_5types10TypeObjectEPKc($trc, $7);
    __label__ = 5;
    break;
   case 5:
    var $obj_idx_val = HEAP32[$obj + 20 >> 2];
    var $11 = __ZNK8JSObject9getParentEv($obj_idx_val);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $11);
    __label__ = 7;
    break;
   case 7:
    var $obj_idx1_val = HEAP32[$obj_idx6 >> 2];
    var $14 = __ZNK8JSObject8getClassEv($obj_idx1_val);
    var $16 = HEAP32[$14 + 64 >> 2];
    if (($16 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    FUNCTION_TABLE[$16]($trc, $obj);
    __label__ = 9;
    break;
   case 9:
    var $obj_idx4_val = HEAP32[$obj_idx2 >> 2];
    var $20 = __ZNK8JSObject8isNativeEv($obj_idx4_val);
    if ($20) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    __ZN2js2gc9MarkShapeEP8JSTracerPKNS_5ShapeEPKc($trc, $obj_idx4_val);
    var $obj_idx5_val_idx_val = HEAP32[HEAP32[$obj_idx2 >> 2] + 4 >> 2];
    var $22 = __ZNK8JSObject8slotSpanEv($obj_idx5_val_idx_val);
    if (($22 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 11;
      break;
    }
   case 11:
    var $i_01;
    var $24 = __ZNK8JSObject13nativeGetSlotEj($obj, $i_01);
    var $_idx = $24 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN2js2gc12MarkValueRawEP8JSTracerRKN2JS5ValueE($trc, $_idx_val$0, $_idx_val$1);
    var $25 = $i_01 + 1 | 0;
    if (($25 | 0) == ($22 | 0)) {
      __label__ = 12;
      break;
    } else {
      var $i_01 = $25;
      __label__ = 11;
      break;
    }
   case 12:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc12MarkChildrenEP8JSTracerP8JSObject["X"] = 1;

function __ZN2js2gc12MarkChildrenEP8JSTracerP8JSString($trc, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str_idx_val = HEAP32[$str >> 2];
    var $1 = __ZNK8JSString11isDependentEv($str_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN8JSString11asDependentEv($str);
    var $_idx_val = HEAP32[$3 + 8 >> 2];
    var $4 = __ZNK17JSDependentString4baseEv($_idx_val);
    var $5 = $4 | 0;
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($trc, $5);
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZNK8JSString6isRopeEv($str_idx_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZN8JSString6asRopeEv($str);
    var $10 = __ZNK6JSRope9leftChildEv($9);
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($trc, $10);
    var $11 = __ZNK6JSRope10rightChildEv($9);
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($trc, $11);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc12MarkChildrenEP8JSTracerP8JSScript($trc, $script) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$script + 40 >> 2];
    var $4 = HEAP32[$script + 56 >> 2];
    __ZN2js2gcL13MarkAtomRangeEP8JSTracerjPP6JSAtomPKc($trc, $2, $4);
    var $6 = HEAP8[$script + 16 | 0];
    var $7 = __ZN8JSScript13isValidOffsetEh($6);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $script_idx_val = HEAP32[$script + 4 >> 2];
    var $9 = __ZN8JSScript7objectsEv($script_idx_val, $6);
    var $11 = HEAP32[$9 + 4 >> 2];
    var $13 = HEAP32[$9 >> 2];
    __ZN2js2gc15MarkObjectRangeEP8JSTracerjPP8JSObjectPKc($trc, $11, $13);
    __label__ = 3;
    break;
   case 3:
    var $16 = HEAP8[$script + 18 | 0];
    var $17 = __ZN8JSScript13isValidOffsetEh($16);
    if ($17) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$script + 4 >> 2];
    var $20 = __ZN8JSScript7regexpsEv($_idx_val, $16);
    var $22 = HEAP32[$20 + 4 >> 2];
    var $24 = HEAP32[$20 >> 2];
    __ZN2js2gc15MarkObjectRangeEP8JSTracerjPP8JSObjectPKc($trc, $22, $24);
    __label__ = 5;
    break;
   case 5:
    var $27 = HEAP8[$script + 21 | 0];
    var $28 = __ZN8JSScript13isValidOffsetEh($27);
    if ($28) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $script_idx3_val = HEAP32[$script + 4 >> 2];
    var $30 = __ZN8JSScript6constsEv($script_idx3_val, $27);
    var $32 = HEAP32[$30 + 4 >> 2];
    var $34 = HEAP32[$30 >> 2];
    __ZN2js2gc14MarkValueRangeEP8JSTracerjPKN2JS5ValueEPKc($trc, $32, $34);
    __label__ = 7;
    break;
   case 7:
    if (HEAP8[$script + 37 | 0] << 24 >> 24 < 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $41 = HEAP32[$script + 84 >> 2];
    if (($41 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $41);
    __label__ = 10;
    break;
   case 10:
    if ((HEAP32[$trc + 4 >> 2] | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $50 = HEAP32[$script + 52 >> 2];
    if (($50 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __Z21js_MarkScriptFilenamePKc($50);
    __label__ = 13;
    break;
   case 13:
    var $55 = $trc;
    var $_idx5_val = HEAP32[$script + 64 >> 2];
    __ZN2js8Bindings5traceEP8JSTracer($_idx5_val, $55);
    var $57 = HEAP32[$script + 100 >> 2];
    if (($57 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZN2js5types10TypeScript5traceEP8JSTracer($57, $trc);
    __label__ = 15;
    break;
   case 15:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc12MarkChildrenEP8JSTracerP8JSScript["X"] = 1;

function __ZN2js2gcL13MarkAtomRangeEP8JSTracerjPP6JSAtomPKc($trc, $len, $vec) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($len | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $i_01;
    var $3 = HEAP32[$vec + ($i_01 << 2) >> 2];
    if (($3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js2gc4MarkI6JSAtomEEvP8JSTracerPT_($trc, $3);
    __label__ = 4;
    break;
   case 4:
    var $7 = $i_01 + 1 | 0;
    if (($7 | 0) == ($len | 0)) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = $7;
      __label__ = 2;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript5traceEP8JSTracer($this, $trc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 | 0;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $5);
    __label__ = 3;
    break;
   case 3:
    var $this_idx_val = HEAP32[$this + 8 >> 2];
    var $7 = __ZN2js5types10TypeScript8hasScopeEv($this_idx_val);
    if ($7 ^ 1 | ($this_idx_val | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $this_idx_val | 0;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $10);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc12MarkChildrenEP8JSTracerPKNS_5ShapeE($trc, $shape) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_0 = $shape;
    __label__ = 2;
    break;
   case 2:
    var $_0;
    var $3 = HEAP32[$_0 + 12 >> 2];
    __ZN2js2gc6MarkIdEP8JSTraceriPKc($trc, $3);
    var $_0_idx = $_0 + 28 | 0;
    var $_0_idx_val = HEAP8[$_0_idx];
    var $4 = __ZNK2js5Shape14hasGetterValueEv($_0_idx_val);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0_idx2_val = $_0_idx_val;
      __label__ = 5;
      break;
    }
   case 3:
    var $_0_idx1_val = HEAP32[$_0 + 16 >> 2];
    var $6 = __ZNK2js5Shape6getterEv($_0_idx1_val);
    if (($6 | 0) == 0) {
      var $_0_idx2_val = $_0_idx_val;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZNK2js5Shape12getterObjectEv($_0);
    __ZN2js2gc21MarkObjectWithPrinterEP8JSTracerR8JSObjectPFvS2_PcjEPKvj($trc, $9);
    var $_0_idx2_val = HEAP8[$_0_idx];
    __label__ = 5;
    break;
   case 5:
    var $_0_idx2_val;
    var $11 = __ZNK2js5Shape14hasSetterValueEv($_0_idx2_val);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $_0_idx3_val = HEAP32[$_0 + 20 >> 2];
    var $13 = __ZNK2js5Shape6setterEv($_0_idx3_val);
    if (($13 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $16 = __ZNK2js5Shape12setterObjectEv($_0);
    __ZN2js2gc21MarkObjectWithPrinterEP8JSTracerR8JSObjectPFvS2_PcjEPKvj($trc, $16);
    __label__ = 8;
    break;
   case 8:
    var $_0_idx4_val = HEAP8[$_0 + 29 | 0];
    var $18 = __ZNK2js5Shape8isMethodEv($_0_idx4_val);
    if ($18) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $20 = __ZNK2js5Shape12methodObjectEv($_0);
    __ZN2js2gc21MarkObjectWithPrinterEP8JSTracerR8JSObjectPFvS2_PcjEPKvj($trc, $20);
    __label__ = 10;
    break;
   case 10:
    var $_0_idx5_val = HEAP32[$_0 + 32 >> 2];
    var $22 = __ZNK2js5Shape8previousEv($_0_idx5_val);
    if (($22 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = $22;
      __label__ = 2;
      break;
    }
   case 11:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc12MarkChildrenEP8JSTracerPNS_5types10TypeObjectE($trc, $type) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $type + 4 | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $type_idx = $type + 12 | 0;
    var $type_idx_val = HEAP32[$type_idx >> 2];
    var $5 = __ZN2js5types10TypeObject16getPropertyCountEv($type_idx_val);
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $type_idx2 = $type + 24 | 0;
    var $i_03 = 0;
    var $type_idx1_val = $type_idx_val;
    __label__ = 4;
    break;
   case 4:
    var $type_idx1_val;
    var $i_03;
    var $type_idx2_val = HEAP32[$type_idx2 >> 2];
    var $7 = __ZN2js5types10TypeObject11getPropertyEj($type_idx1_val, $type_idx2_val, $i_03);
    if (($7 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = HEAP32[$7 >> 2];
    __ZN2js2gc6MarkIdEP8JSTraceriPKc($trc, $11);
    __label__ = 6;
    break;
   case 6:
    var $13 = $i_03 + 1 | 0;
    if (($13 | 0) == ($5 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $i_03 = $13;
    var $type_idx1_val = HEAP32[$type_idx >> 2];
    __label__ = 4;
    break;
   case 8:
    var $14 = $type + 8 | 0;
    var $15 = HEAP32[$14 >> 2];
    if (($15 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $i2_01 = 0;
      var $17 = $15;
      __label__ = 9;
      break;
    }
   case 9:
    var $17;
    var $i2_01;
    var $19 = HEAP32[$17 + ($i2_01 << 2) >> 2];
    if (($19 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $22 = $19 | 0;
    __ZN2js2gc9MarkShapeEP8JSTracerPKNS_5ShapeEPKc($trc, $22);
    __label__ = 11;
    break;
   case 11:
    var $24 = $i2_01 + 1 | 0;
    if (($24 | 0) == 12) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $i2_01 = $24;
    var $17 = HEAP32[$14 >> 2];
    __label__ = 9;
    break;
   case 13:
    var $26 = HEAP32[$type >> 2];
    if (($26 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $26);
    __label__ = 15;
    break;
   case 15:
    var $29 = HEAP32[$1 >> 2];
    if (($29 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $29);
    __label__ = 17;
    break;
   case 17:
    var $33 = $type + 16 | 0;
    var $34 = HEAP32[$33 >> 2];
    if (($34 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $39 = HEAP32[$34 >> 2] | 0;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $39);
    var $42 = HEAP32[HEAP32[$33 >> 2] + 8 >> 2];
    __ZN2js2gc9MarkShapeEP8JSTracerPKNS_5ShapeEPKc($trc, $42);
    __label__ = 19;
    break;
   case 19:
    var $45 = HEAP32[$type + 28 >> 2];
    if (($45 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $48 = $45 | 0;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $48);
    __label__ = 21;
    break;
   case 21:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc12MarkChildrenEP8JSTracerPNS_5types10TypeObjectE["X"] = 1;

function __ZN2js5types10TypeObject16getPropertyCountEv($this_0_3_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5types10TypeObject17basePropertyCountEv($this_0_3_val);
    if ($1 >>> 0 > 8) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js5typesL15HashSetCapacityEj1539($1);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObject11getPropertyEj($this_0_3_val, $this_0_6_val, $i) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5types10TypeObject17basePropertyCountEv($this_0_3_val);
    if (($1 | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $this_0_6_val;
    __label__ = 4;
    break;
   case 3:
    var $_0 = HEAP32[$this_0_6_val + ($i << 2) >> 2];
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc12MarkChildrenEP8JSTracerP5JSXML($trc, $xml) {
  var $1 = $trc;
  var $2 = $xml;
  _js_TraceXML($1, $2);
  return;
}

function __ZNK2js8GCMarker12getMarkColorEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZN2js9MarkStackIP6JSRopeE7isEmptyEv($this_0_1_val) {
  return ($this_0_1_val | 0) == 0;
}

function __ZN2js9MarkStackIP8JSObjectE7isEmptyEv($this_0_1_val) {
  return ($this_0_1_val | 0) == 0;
}

function __ZN2js9MarkStackIPNS_5types10TypeObjectEE7isEmptyEv($this_0_1_val) {
  return ($this_0_1_val | 0) == 0;
}

function __ZN2js9MarkStackIP5JSXMLE7isEmptyEv($this_0_1_val) {
  return ($this_0_1_val | 0) == 0;
}

function __ZN2js9MarkStackINS_13LargeMarkItemEE7isEmptyEv($this_0_1_val) {
  return ($this_0_1_val | 0) == 0;
}

function __ZN2js9MarkStackIP6JSRopeE3popEv($this) {
  var $1 = $this + 4 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return HEAP32[HEAP32[$this >> 2] + ($3 << 2) >> 2];
}

function __ZN2js9MarkStackIP8JSObjectE3popEv($this) {
  var $1 = $this + 4 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return HEAP32[HEAP32[$this >> 2] + ($3 << 2) >> 2];
}

function __ZN2js9MarkStackIPNS_5types10TypeObjectEE3popEv($this) {
  var $1 = $this + 4 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return HEAP32[HEAP32[$this >> 2] + ($3 << 2) >> 2];
}

function __ZN2js9MarkStackIP5JSXMLE3popEv($this) {
  var $1 = $this + 4 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return HEAP32[HEAP32[$this >> 2] + ($3 << 2) >> 2];
}

function __ZN2js9MarkStackINS_13LargeMarkItemEE4peekEv($this_0_0_val, $this_0_1_val) {
  return $this_0_0_val + ($this_0_1_val - 1 << 3) | 0;
}

function __ZN2js9MarkStackINS_13LargeMarkItemEE3popEv($agg_result, $this) {
  var $1 = $this + 4 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  var $7 = HEAP32[$this >> 2] + ($3 << 3) | 0;
  var $8 = $agg_result;
  var $9$0 = HEAP32[$7 >> 2];
  var $9$1 = HEAP32[$7 + 4 >> 2];
  HEAP32[$8 >> 2] = $9$0;
  HEAP32[$8 + 4 >> 2] = $9$1;
  return;
}

function __ZL23js_RegenerateShapeForGCP9JSRuntime($rt) {
  var $1 = $rt + 209944 | 0;
  var $2 = HEAP32[$1 >> 2];
  var $5 = $2 + 1 | $2 & 16777216;
  HEAP32[$1 >> 2] = $5;
  return $5;
}

function __ZN2js9MarkStackIP8JSObjectE4pushES2_($this, $item) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == (HEAP32[$this + 8 >> 2] | 0)) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $2 + 1 | 0;
    HEAP32[$1 >> 2] = $7;
    var $10 = HEAP32[$this >> 2] + ($2 << 2) | 0;
    HEAP32[$10 >> 2] = $item;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8GCMarker14drainMarkStackEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this | 0;
    var $6 = HEAP32[HEAP32[$this >> 2] + 52 >> 2];
    var $8 = HEAP32[$6 + 144080 >> 2];
    var $9 = $6 + 144084 | 0;
    HEAP32[$9 >> 2] = $8;
    var $10 = __ZN2js8GCMarker16isMarkStackEmptyEv($this);
    if ($10) {
      __label__ = 17;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = $this + 48 | 0;
    var $12 = $this + 36 | 0;
    var $13 = $this + 60 | 0;
    var $14 = $this + 72 | 0;
    var $15 = $this + 84 | 0;
    var $_idx3 = $this + 52 | 0;
    var $_idx1 = $this + 40 | 0;
    var $_idx5 = $this + 64 | 0;
    var $_idx7 = $this + 76 | 0;
    var $_idx8 = $this + 88 | 0;
    var $_idx9 = $15 | 0;
    __label__ = 3;
    break;
   case 3:
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $16 = __ZN2js9MarkStackIP6JSRopeE7isEmptyEv($_idx3_val);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = __ZN2js9MarkStackIP6JSRopeE3popEv($11);
    __ZN2js2gcL8ScanRopeEPNS_8GCMarkerEP6JSRope($this, $17);
    var $_idx2_val = HEAP32[$_idx3 >> 2];
    var $18 = __ZN2js9MarkStackIP6JSRopeE7isEmptyEv($_idx2_val);
    if ($18) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 5:
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $19 = __ZN2js9MarkStackIP8JSObjectE7isEmptyEv($_idx1_val);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = __ZN2js9MarkStackIP8JSObjectE3popEv($12);
    __ZN2js2gcL10ScanObjectEPNS_8GCMarkerEP8JSObject($this, $20);
    var $_idx_val = HEAP32[$_idx1 >> 2];
    var $21 = __ZN2js9MarkStackIP8JSObjectE7isEmptyEv($_idx_val);
    if ($21) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 7:
    var $_idx5_val = HEAP32[$_idx5 >> 2];
    var $22 = __ZN2js9MarkStackIPNS_5types10TypeObjectEE7isEmptyEv($_idx5_val);
    if ($22) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $23 = __ZN2js9MarkStackIPNS_5types10TypeObjectEE3popEv($13);
    __ZN2js2gcL14ScanTypeObjectEPNS_8GCMarkerEPNS_5types10TypeObjectE($this, $23);
    var $_idx4_val = HEAP32[$_idx5 >> 2];
    var $24 = __ZN2js9MarkStackIPNS_5types10TypeObjectEE7isEmptyEv($_idx4_val);
    if ($24) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 9:
    var $_idx7_val = HEAP32[$_idx7 >> 2];
    var $25 = __ZN2js9MarkStackIP5JSXMLE7isEmptyEv($_idx7_val);
    if ($25) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $26 = __ZN2js9MarkStackIP5JSXMLE3popEv($14);
    __ZN2js2gc12MarkChildrenEP8JSTracerP5JSXML($2, $26);
    var $_idx6_val = HEAP32[$_idx7 >> 2];
    var $27 = __ZN2js9MarkStackIP5JSXMLE7isEmptyEv($_idx6_val);
    if ($27) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 11:
    var $_idx8_val = HEAP32[$_idx8 >> 2];
    var $28 = __ZN2js9MarkStackINS_13LargeMarkItemEE7isEmptyEv($_idx8_val);
    if ($28) {
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $_idx9_val = HEAP32[$_idx9 >> 2];
    var $30 = __ZN2js9MarkStackINS_13LargeMarkItemEE4peekEv($_idx9_val, $_idx8_val);
    var $31 = __ZN2js2gcL15ScanLargeObjectEPNS_8GCMarkerERNS_13LargeMarkItemE($this, $30);
    if ($31) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    __ZN2js9MarkStackINS_13LargeMarkItemEE3popEv($1, $15);
    __label__ = 14;
    break;
   case 14:
    var $34 = __ZN2js8GCMarker16isMarkStackEmptyEv($this);
    if ($34) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    __ZN2js8GCMarker19markDelayedChildrenEv($this);
    __label__ = 16;
    break;
   case 16:
    var $36 = __ZN2js8GCMarker16isMarkStackEmptyEv($this);
    if ($36) {
      __label__ = 17;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 17:
    HEAP32[$9 >> 2] = 0;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8GCMarker14drainMarkStackEv["X"] = 1;

function __ZN2js8GCMarker16isMarkStackEmptyEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this + 40 >> 2];
    var $1 = __ZN2js9MarkStackIP8JSObjectE7isEmptyEv($_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this + 52 >> 2];
    var $3 = __ZN2js9MarkStackIP6JSRopeE7isEmptyEv($_idx1_val);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $11 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $_idx2_val = HEAP32[$this + 64 >> 2];
    var $5 = __ZN2js9MarkStackIPNS_5types10TypeObjectEE7isEmptyEv($_idx2_val);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $11 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $_idx3_val = HEAP32[$this + 76 >> 2];
    var $7 = __ZN2js9MarkStackIP5JSXMLE7isEmptyEv($_idx3_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      var $11 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $_idx4_val = HEAP32[$this + 88 >> 2];
    var $9 = __ZN2js9MarkStackINS_13LargeMarkItemEE7isEmptyEv($_idx4_val);
    var $11 = $9;
    __label__ = 6;
    break;
   case 6:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL8ScanRopeEPNS_8GCMarkerEP6JSRope($gcmarker, $rope) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_0 = $rope;
    __label__ = 2;
    break;
   case 2:
    var $_0;
    var $2 = __ZNK6JSRope10rightChildEv($_0);
    var $_idx1_val = HEAP32[$2 >> 2];
    var $3 = __ZNK8JSString6isRopeEv($_idx1_val);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $5 = $2;
    var $6 = __ZNK2js2gc4Cell14markIfUnmarkedEj($5, 0);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $8 = __ZN8JSString6asRopeEv($2);
    __ZN2js8GCMarker8pushRopeEP6JSRope($gcmarker, $8);
    __label__ = 6;
    break;
   case 5:
    var $10 = __ZN8JSString8asLinearEv($2);
    __ZN14JSLinearString4markEP8JSTracer($10);
    __label__ = 6;
    break;
   case 6:
    var $12 = __ZNK6JSRope9leftChildEv($_0);
    var $_idx_val = HEAP32[$12 >> 2];
    var $13 = __ZNK8JSString8isLinearEv($_idx_val);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $15 = __ZN8JSString8asLinearEv($12);
    __ZN14JSLinearString4markEP8JSTracer($15);
    __label__ = 9;
    break;
   case 8:
    var $17 = __ZN8JSString6asRopeEv($12);
    var $18 = $12;
    var $19 = __ZNK2js2gc4Cell14markIfUnmarkedEj($18, 0);
    if ($19) {
      var $_0 = $17;
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL10ScanObjectEPNS_8GCMarkerEP8JSObject($gcmarker, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $obj_idx2 = $obj | 0;
    var $obj_idx2_val = HEAP32[$obj_idx2 >> 2];
    var $3 = __ZNK8JSObject9isNewbornEv($obj_idx2_val);
    if ($3) {
      __label__ = 25;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $obj_idx3_val = HEAP32[$obj + 36 >> 2];
    var $5 = __ZNK8JSObject10typeFromGCEv($obj_idx3_val);
    if (($5 | 0) == (__ZN2js5types15emptyTypeObjectE | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPNS_5types10TypeObjectE($gcmarker, $5);
    __label__ = 4;
    break;
   case 4:
    var $obj_idx_val = HEAP32[$obj + 20 >> 2];
    var $9 = __ZNK8JSObject9getParentEv($obj_idx_val);
    if (($9 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSObject($gcmarker, $9);
    __label__ = 6;
    break;
   case 6:
    var $obj_idx1_val = HEAP32[$obj + 4 >> 2];
    var $13 = __ZNK8JSObject8getClassEv($obj_idx1_val);
    var $14 = $13 + 64 | 0;
    var $15 = HEAPU32[$14 >> 2];
    if (($15 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($13 | 0) == (__ZN2js10ArrayClassE | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 8:
    var $20 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
    if ($20 >>> 0 > 2048) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $23 = $gcmarker + 84 | 0;
    __ZN2js13LargeMarkItemC1EP8JSObject($1, $obj);
    var $_04_val = HEAP32[$1 >> 2];
    var $_15_val = HEAP32[$1 + 4 >> 2];
    var $24 = __ZN2js9MarkStackINS_13LargeMarkItemEE4pushES1_($23, $_04_val, $_15_val);
    if ($24) {
      __label__ = 17;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $26 = HEAP32[$14 >> 2];
    var $27 = $gcmarker | 0;
    FUNCTION_TABLE[$26]($27, $obj);
    __label__ = 17;
    break;
   case 11:
    var $29 = $gcmarker | 0;
    FUNCTION_TABLE[$15]($29, $obj);
    __label__ = 17;
    break;
   case 12:
    var $32 = HEAP32[$obj + 16 >> 2];
    if (($32 | 0) == 0) {
      var $36 = $15;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPNS_5types10TypeObjectE($gcmarker, $32);
    var $36 = HEAP32[$14 >> 2];
    __label__ = 14;
    break;
   case 14:
    var $36;
    var $37 = $gcmarker | 0;
    FUNCTION_TABLE[$36]($37, $obj);
    __label__ = 17;
    break;
   case 15:
    var $40 = HEAP32[$obj + 16 >> 2];
    if (($40 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPNS_5types10TypeObjectE($gcmarker, $40);
    __label__ = 17;
    break;
   case 17:
    var $obj_idx6_val = HEAP32[$obj_idx2 >> 2];
    var $43 = __ZNK8JSObject8isNativeEv($obj_idx6_val);
    if ($43) {
      __label__ = 18;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 18:
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $obj_idx6_val);
    var $48 = HEAP32[HEAP32[$gcmarker >> 2] + 52 >> 2];
    if ((HEAP8[$48 + 144091 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $55 = HEAP32[$obj_idx6_val >> 2];
    var $obj_idx7_val = HEAP32[$obj + 8 >> 2];
    var $56 = __ZNK8JSObject11hasOwnShapeEv($obj_idx7_val);
    if ($56) {
      __label__ = 20;
      break;
    } else {
      var $newShape_0 = $55;
      __label__ = 21;
      break;
    }
   case 20:
    var $58 = __ZL23js_RegenerateShapeForGCP9JSRuntime($48);
    var $newShape_0 = $58;
    __label__ = 21;
    break;
   case 21:
    var $newShape_0;
    HEAP32[$obj + 12 >> 2] = $newShape_0;
    __label__ = 22;
    break;
   case 22:
    var $obj_idx8_val_idx_val = HEAP32[HEAP32[$obj_idx2 >> 2] + 4 >> 2];
    var $62 = __ZNK8JSObject8slotSpanEv($obj_idx8_val_idx_val);
    if ($62 >>> 0 > 2048) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $65 = $gcmarker + 84 | 0;
    __ZN2js13LargeMarkItemC1EP8JSObject($2, $obj);
    var $_0_val = HEAP32[$2 >> 2];
    var $_1_val = HEAP32[$2 + 4 >> 2];
    var $66 = __ZN2js9MarkStackINS_13LargeMarkItemEE4pushES1_($65, $_0_val, $_1_val);
    if ($66) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    __ZN8JSObject9scanSlotsEPN2js8GCMarkerE($obj, $gcmarker);
    __label__ = 25;
    break;
   case 25:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gcL10ScanObjectEPNS_8GCMarkerEP8JSObject["X"] = 1;

function __ZN2js2gcL14ScanTypeObjectEPNS_8GCMarkerEPNS_5types10TypeObjectE($gcmarker, $type) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$type + 4 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    var $type_idx = $type + 12 | 0;
    var $type_idx_val = HEAP32[$type_idx >> 2];
    var $5 = __ZN2js5types10TypeObject16getPropertyCountEv($type_idx_val);
    if (($5 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $type_idx2 = $type + 24 | 0;
    var $i_03 = 0;
    var $type_idx1_val = $type_idx_val;
    __label__ = 4;
    break;
   case 4:
    var $type_idx1_val;
    var $i_03;
    var $type_idx2_val = HEAP32[$type_idx2 >> 2];
    var $7 = __ZN2js5types10TypeObject11getPropertyEj($type_idx1_val, $type_idx2_val, $i_03);
    if (($7 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = HEAP32[$7 >> 2];
    var $12 = _JSID_IS_STRING1510($11);
    if (($12 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = _JSID_TO_STRING1511($11);
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSString($gcmarker, $15);
    __label__ = 7;
    break;
   case 7:
    var $17 = $i_03 + 1 | 0;
    if (($17 | 0) == ($5 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $i_03 = $17;
    var $type_idx1_val = HEAP32[$type_idx >> 2];
    __label__ = 4;
    break;
   case 9:
    var $18 = $type + 8 | 0;
    var $19 = HEAP32[$18 >> 2];
    if (($19 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $21 = HEAP32[$19 >> 2];
    if (($21 | 0) == 0) {
      var $26 = $19;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $24 = $21 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $24);
    var $26 = HEAP32[$18 >> 2];
    __label__ = 12;
    break;
   case 12:
    var $26;
    var $28 = HEAP32[$26 + 4 >> 2];
    if (($28 | 0) == 0) {
      var $48 = $26;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 13:
    var $31 = HEAP32[$type >> 2];
    if (($31 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSObject($gcmarker, $31);
    __label__ = 15;
    break;
   case 15:
    var $35 = $type + 16 | 0;
    var $36 = HEAP32[$35 >> 2];
    if (($36 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $40 = HEAP32[$36 >> 2];
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP10JSFunction($gcmarker, $40);
    var $43 = HEAP32[HEAP32[$35 >> 2] + 8 >> 2];
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $43);
    __label__ = 17;
    break;
   case 17:
    return;
   case 18:
    var $46 = $28 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $46);
    var $48 = HEAP32[$18 >> 2];
    __label__ = 19;
    break;
   case 19:
    var $48;
    var $50 = HEAP32[$48 + 8 >> 2];
    if (($50 | 0) == 0) {
      var $55 = $48;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $53 = $50 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $53);
    var $55 = HEAP32[$18 >> 2];
    __label__ = 21;
    break;
   case 21:
    var $55;
    var $57 = HEAP32[$55 + 12 >> 2];
    if (($57 | 0) == 0) {
      var $62 = $55;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $60 = $57 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $60);
    var $62 = HEAP32[$18 >> 2];
    __label__ = 23;
    break;
   case 23:
    var $62;
    var $64 = HEAP32[$62 + 16 >> 2];
    if (($64 | 0) == 0) {
      var $69 = $62;
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $67 = $64 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $67);
    var $69 = HEAP32[$18 >> 2];
    __label__ = 25;
    break;
   case 25:
    var $69;
    var $71 = HEAP32[$69 + 20 >> 2];
    if (($71 | 0) == 0) {
      var $76 = $69;
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $74 = $71 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $74);
    var $76 = HEAP32[$18 >> 2];
    __label__ = 27;
    break;
   case 27:
    var $76;
    var $78 = HEAP32[$76 + 24 >> 2];
    if (($78 | 0) == 0) {
      var $83 = $76;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $81 = $78 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $81);
    var $83 = HEAP32[$18 >> 2];
    __label__ = 29;
    break;
   case 29:
    var $83;
    var $85 = HEAP32[$83 + 28 >> 2];
    if (($85 | 0) == 0) {
      var $90 = $83;
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $88 = $85 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $88);
    var $90 = HEAP32[$18 >> 2];
    __label__ = 31;
    break;
   case 31:
    var $90;
    var $92 = HEAP32[$90 + 32 >> 2];
    if (($92 | 0) == 0) {
      var $97 = $90;
      __label__ = 33;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $95 = $92 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $95);
    var $97 = HEAP32[$18 >> 2];
    __label__ = 33;
    break;
   case 33:
    var $97;
    var $99 = HEAP32[$97 + 36 >> 2];
    if (($99 | 0) == 0) {
      var $104 = $97;
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $102 = $99 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $102);
    var $104 = HEAP32[$18 >> 2];
    __label__ = 35;
    break;
   case 35:
    var $104;
    var $106 = HEAP32[$104 + 40 >> 2];
    if (($106 | 0) == 0) {
      var $111 = $104;
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $109 = $106 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $109);
    var $111 = HEAP32[$18 >> 2];
    __label__ = 37;
    break;
   case 37:
    var $111;
    var $113 = HEAP32[$111 + 44 >> 2];
    if (($113 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $116 = $113 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $116);
    __label__ = 13;
    break;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gcL14ScanTypeObjectEPNS_8GCMarkerEPNS_5types10TypeObjectE["X"] = 1;

function __ZN2js2gcL15ScanLargeObjectEPNS_8GCMarkerERNS_13LargeMarkItemE($gcmarker, $item) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$item >> 2];
    var $3 = $item + 4 | 0;
    var $4 = HEAPU32[$3 >> 2];
    var $_idx3_val = HEAP32[$2 + 4 >> 2];
    var $5 = __ZNK8JSObject12isDenseArrayEv($_idx3_val);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $7 = __ZN8JSObject30getDenseArrayInitializedLengthEv($2);
    var $8 = $4 + 2048 | 0;
    var $_ = $8 >>> 0 < $7 >>> 0 ? $8 : $7;
    if ($_ >>> 0 > $4 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $capacity_0 = $7;
      var $stop_0 = $_;
      __label__ = 7;
      break;
    }
   case 3:
    var $_idx4 = $2 + 32 | 0;
    var $i_04 = $_;
    __label__ = 4;
    break;
   case 4:
    var $i_04;
    var $11 = $i_04 - 1 | 0;
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $12 = __ZN8JSObject20getDenseArrayElementEj($_idx4_val, $11);
    var $_idx2 = $12 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN2js2gcL9ScanValueEPNS_8GCMarkerERKN2JS5ValueE($gcmarker, $_idx2_val$0, $_idx2_val$1);
    if ($11 >>> 0 > $4 >>> 0) {
      var $i_04 = $11;
      __label__ = 4;
      break;
    } else {
      var $capacity_0 = $7;
      var $stop_0 = $_;
      __label__ = 7;
      break;
    }
   case 5:
    var $_idx_val_idx_val = HEAP32[HEAP32[$2 >> 2] + 4 >> 2];
    var $15 = __ZNK8JSObject8slotSpanEv($_idx_val_idx_val);
    var $16 = $4 + 2048 | 0;
    var $_1 = $16 >>> 0 < $15 >>> 0 ? $16 : $15;
    if ($_1 >>> 0 > $4 >>> 0) {
      var $i1_02 = $_1;
      __label__ = 6;
      break;
    } else {
      var $capacity_0 = $15;
      var $stop_0 = $_1;
      __label__ = 7;
      break;
    }
   case 6:
    var $i1_02;
    var $19 = $i1_02 - 1 | 0;
    var $20 = __ZNK8JSObject13nativeGetSlotEj($2, $19);
    var $_idx1 = $20 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN2js2gcL9ScanValueEPNS_8GCMarkerERKN2JS5ValueE($gcmarker, $_idx1_val$0, $_idx1_val$1);
    if ($19 >>> 0 > $4 >>> 0) {
      var $i1_02 = $19;
      __label__ = 6;
      break;
    } else {
      var $capacity_0 = $15;
      var $stop_0 = $_1;
      __label__ = 7;
      break;
    }
   case 7:
    var $stop_0;
    var $capacity_0;
    if (($stop_0 | 0) == ($capacity_0 | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $25 = HEAP32[$3 >> 2] + 2048 | 0;
    HEAP32[$3 >> 2] = $25;
    var $_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gcL15ScanLargeObjectEPNS_8GCMarkerERNS_13LargeMarkItemE["X"] = 1;

function _JS_TraceChildren($trc, $thing, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($kind | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($kind | 0) == 1) {
      __label__ = 3;
      break;
    } else if (($kind | 0) == 2) {
      __label__ = 4;
      break;
    } else if (($kind | 0) == 4) {
      __label__ = 5;
      break;
    } else if (($kind | 0) == 5) {
      __label__ = 6;
      break;
    } else if (($kind | 0) == 3) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $2 = $thing;
    __ZN2js2gc12MarkChildrenEP8JSTracerP8JSObject($trc, $2);
    __label__ = 8;
    break;
   case 3:
    var $4 = $thing;
    __ZN2js2gc12MarkChildrenEP8JSTracerP8JSString($trc, $4);
    __label__ = 8;
    break;
   case 4:
    var $6 = $thing;
    __ZN2js2gc12MarkChildrenEP8JSTracerP8JSScript($trc, $6);
    __label__ = 8;
    break;
   case 5:
    var $8 = $thing;
    __ZN2js2gc12MarkChildrenEP8JSTracerPKNS_5ShapeE($trc, $8);
    __label__ = 8;
    break;
   case 6:
    var $10 = $thing;
    __ZN2js2gc12MarkChildrenEP8JSTracerPNS_5types10TypeObjectE($trc, $10);
    __label__ = 8;
    break;
   case 7:
    var $12 = $thing;
    __ZN2js2gc12MarkChildrenEP8JSTracerP5JSXML($trc, $12);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $thing;
    var $gcmarker_idx_val = HEAP32[$gcmarker + 24 >> 2];
    var $2 = __ZNK2js8GCMarker12getMarkColorEv($gcmarker_idx_val);
    var $3 = __ZNK2js2gc4Cell14markIfUnmarkedEj($1, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js2gcL9ScanShapeEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $thing);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL9ScanShapeEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $shape) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $gcmarker | 0;
    var $gcmarker_idx = $gcmarker + 24 | 0;
    var $_0 = $shape;
    __label__ = 2;
    break;
   case 2:
    var $_0;
    var $5 = HEAP32[HEAP32[$1 >> 2] + 52 >> 2];
    if ((HEAP8[$5 + 144091 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZL23js_RegenerateShapeForGCP9JSRuntime($5);
    HEAP32[$_0 >> 2] = $11;
    __label__ = 4;
    break;
   case 4:
    var $15 = HEAP32[$_0 + 12 >> 2];
    var $16 = _JSID_IS_STRING1510($15);
    if (($16 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = _JSID_TO_STRING1511($15);
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSString($gcmarker, $19);
    __label__ = 8;
    break;
   case 6:
    var $21 = _JSID_IS_OBJECT1512($15);
    if (($21 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = _JSID_TO_OBJECT1513($15);
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSObject($gcmarker, $24);
    __label__ = 8;
    break;
   case 8:
    var $_0_idx = $_0 + 28 | 0;
    var $_0_idx_val = HEAP8[$_0_idx];
    var $26 = __ZNK2js5Shape14hasGetterValueEv($_0_idx_val);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      var $_0_idx2_val = $_0_idx_val;
      __label__ = 11;
      break;
    }
   case 9:
    var $_0_idx1_val = HEAP32[$_0 + 16 >> 2];
    var $28 = __ZNK2js5Shape6getterEv($_0_idx1_val);
    if (($28 | 0) == 0) {
      var $_0_idx2_val = $_0_idx_val;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $31 = __ZNK2js5Shape12getterObjectEv($_0);
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSObject($gcmarker, $31);
    var $_0_idx2_val = HEAP8[$_0_idx];
    __label__ = 11;
    break;
   case 11:
    var $_0_idx2_val;
    var $33 = __ZNK2js5Shape14hasSetterValueEv($_0_idx2_val);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $_0_idx3_val = HEAP32[$_0 + 20 >> 2];
    var $35 = __ZNK2js5Shape6setterEv($_0_idx3_val);
    if (($35 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $38 = __ZNK2js5Shape12setterObjectEv($_0);
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSObject($gcmarker, $38);
    __label__ = 14;
    break;
   case 14:
    var $_0_idx4_val = HEAP8[$_0 + 29 | 0];
    var $40 = __ZNK2js5Shape8isMethodEv($_0_idx4_val);
    if ($40) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $42 = __ZNK2js5Shape12methodObjectEv($_0);
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSObject($gcmarker, $42);
    __label__ = 16;
    break;
   case 16:
    var $_0_idx5_val = HEAP32[$_0 + 32 >> 2];
    var $44 = __ZNK2js5Shape8previousEv($_0_idx5_val);
    if (($44 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $47 = $44;
    var $gcmarker_idx_val = HEAP32[$gcmarker_idx >> 2];
    var $48 = __ZNK2js8GCMarker12getMarkColorEv($gcmarker_idx_val);
    var $49 = __ZNK2js2gc4Cell14markIfUnmarkedEj($47, $48);
    if ($49) {
      var $_0 = $44;
      __label__ = 2;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gcL9ScanShapeEPNS_8GCMarkerEPKNS_5ShapeE["X"] = 1;

function __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSString($gcmarker, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str_idx_val = HEAP32[$str >> 2];
    var $1 = __ZNK8JSString8isLinearEv($str_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN8JSString8asLinearEv($str);
    __ZN14JSLinearString4markEP8JSTracer($3);
    __label__ = 5;
    break;
   case 3:
    var $5 = $str;
    var $6 = __ZNK2js2gc4Cell14markIfUnmarkedEj($5, 0);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZN8JSString6asRopeEv($str);
    __ZN2js2gcL8ScanRopeEPNS_8GCMarkerEP6JSRope($gcmarker, $8);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSObject($gcmarker, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $thing;
    var $gcmarker_idx_val = HEAP32[$gcmarker + 24 >> 2];
    var $2 = __ZNK2js8GCMarker12getMarkColorEv($gcmarker_idx_val);
    var $3 = __ZNK2js2gc4Cell14markIfUnmarkedEj($1, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js8GCMarker10pushObjectEP8JSObject($gcmarker, $thing);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8GCMarker10pushObjectEP8JSObject($this, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 36 | 0;
    var $2 = __ZN2js9MarkStackIP8JSObjectE4pushES2_($1, $obj);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $obj;
    __ZN2js8GCMarker20delayMarkingChildrenEPKv($this, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP5JSXML($gcmarker, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $thing;
    var $gcmarker_idx_val = HEAP32[$gcmarker + 24 >> 2];
    var $2 = __ZNK2js8GCMarker12getMarkColorEv($gcmarker_idx_val);
    var $3 = __ZNK2js2gc4Cell14markIfUnmarkedEj($1, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js8GCMarker7pushXMLEP5JSXML($gcmarker, $thing);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject11hasOwnShapeEv($this_0_2_val) {
  return ($this_0_2_val & 128 | 0) != 0;
}

function __ZN2js5types10TypeScript8hasScopeEv($this_0_2_val) {
  return ($this_0_2_val | 0) != 1;
}

function _JSVAL_IS_STRING_IMPL1546($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -123) & 1;
}

function __ZN9JSRuntime6GCData14isTimerEnabledEv($this_0_2_val) {
  return ($this_0_2_val & 1) << 24 >> 24 != 0;
}

function _JS_CompareValues($v1, $v2) {
  return ($v1 | 0) == ($v2 | 0) & 1;
}

function __ZN2js9MarkStackIP5JSXMLE4pushES2_($this, $item) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == (HEAP32[$this + 8 >> 2] | 0)) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $2 + 1 | 0;
    HEAP32[$1 >> 2] = $7;
    var $10 = HEAP32[$this >> 2] + ($2 << 2) | 0;
    HEAP32[$10 >> 2] = $item;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9MarkStackIPNS_5types10TypeObjectEE4pushES3_($this, $item) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == (HEAP32[$this + 8 >> 2] | 0)) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $2 + 1 | 0;
    HEAP32[$1 >> 2] = $7;
    var $10 = HEAP32[$this >> 2] + ($2 << 2) | 0;
    HEAP32[$10 >> 2] = $item;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9MarkStackINS_13LargeMarkItemEE4pushES1_($this, $item_0, $item_1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == (HEAP32[$this + 8 >> 2] | 0)) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $item_0;
    var $8 = $2 + 1 | 0;
    HEAP32[$1 >> 2] = $8;
    var $12 = HEAP32[$this >> 2] + ($2 << 3) | 0;
    var $16$1 = $item_1 | 0;
    var $st$15$0 = $12 | 0;
    HEAP32[$st$15$0 >> 2] = 0 | $7;
    var $st$15$1 = $12 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $16$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13LargeMarkItemC2EP8JSObject($this, $obj) {
  HEAP32[$this >> 2] = $obj;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js9MarkStackIP6JSRopeE4pushES2_($this, $item) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == (HEAP32[$this + 8 >> 2] | 0)) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $2 + 1 | 0;
    HEAP32[$1 >> 2] = $7;
    var $10 = HEAP32[$this >> 2] + ($2 << 2) | 0;
    HEAP32[$10 >> 2] = $item;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime6GCData13setFirstEnterEy($this, $v$0, $v$1) {
  var $1 = $this | 0;
  HEAP32[$1 >> 2] = $v$0;
  HEAP32[$1 + 4 >> 2] = $v$1;
  HEAP8[$this + 8 | 0] = 1;
  return;
}

function _JS_HashString($key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP8[$key];
    if ($1 << 24 >> 24 == 0) {
      var $h_0_lcssa = 0;
      __label__ = 3;
      break;
    } else {
      var $h_01 = 0;
      var $s_02 = $key;
      var $3 = $1;
      __label__ = 2;
      break;
    }
   case 2:
    var $3;
    var $s_02;
    var $h_01;
    var $8 = $3 & 255 ^ ($h_01 << 4 | $h_01 >>> 28);
    var $9 = $s_02 + 1 | 0;
    var $10 = HEAPU8[$9];
    if ($10 << 24 >> 24 == 0) {
      var $h_0_lcssa = $8;
      __label__ = 3;
      break;
    } else {
      var $h_01 = $8;
      var $s_02 = $9;
      var $3 = $10;
      __label__ = 2;
      break;
    }
   case 3:
    var $h_0_lcssa;
    return $h_0_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8GCMarker7pushXMLEP5JSXML($this, $xml) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 72 | 0;
    var $2 = __ZN2js9MarkStackIP5JSXMLE4pushES2_($1, $xml);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $xml;
    __ZN2js8GCMarker20delayMarkingChildrenEPKv($this, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPNS_5types10TypeObjectE($gcmarker, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $thing;
    var $gcmarker_idx_val = HEAP32[$gcmarker + 24 >> 2];
    var $2 = __ZNK2js8GCMarker12getMarkColorEv($gcmarker_idx_val);
    var $3 = __ZNK2js2gc4Cell14markIfUnmarkedEj($1, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js8GCMarker8pushTypeEPNS_5types10TypeObjectE($gcmarker, $thing);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8GCMarker8pushTypeEPNS_5types10TypeObjectE($this, $type) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 60 | 0;
    var $2 = __ZN2js9MarkStackIPNS_5types10TypeObjectEE4pushES3_($1, $type);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $type;
    __ZN2js8GCMarker20delayMarkingChildrenEPKv($this, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSScript($gcmarker, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $thing;
    var $gcmarker_idx_val = HEAP32[$gcmarker + 24 >> 2];
    var $2 = __ZNK2js8GCMarker12getMarkColorEv($gcmarker_idx_val);
    var $3 = __ZNK2js2gc4Cell14markIfUnmarkedEj($1, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $gcmarker | 0;
    __ZN2js2gc12MarkChildrenEP8JSTracerP8JSScript($5, $thing);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL9ScanValueEPNS_8GCMarkerERKN2JS5ValueE($gcmarker, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value10isMarkableEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value6gcKindEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if (($3 | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZNK2JS5Value8toStringEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSString($gcmarker, $6);
    __label__ = 5;
    break;
   case 4:
    var $8 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSObject($gcmarker, $8);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP10JSFunction($gcmarker, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $thing;
    var $gcmarker_idx_val = HEAP32[$gcmarker + 24 >> 2];
    var $2 = __ZNK2js8GCMarker12getMarkColorEv($gcmarker_idx_val);
    var $3 = __ZNK2js2gc4Cell14markIfUnmarkedEj($1, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $thing | 0;
    __ZN2js8GCMarker10pushObjectEP8JSObject($gcmarker, $5);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13LargeMarkItemC1EP8JSObject($this, $obj) {
  __ZN2js13LargeMarkItemC2EP8JSObject($this, $obj);
  return;
}

function __ZN8JSObject9scanSlotsEPN2js8GCMarkerE($this, $gcmarker) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx1_val_idx_val = HEAP32[HEAP32[$this >> 2] + 4 >> 2];
    var $1 = __ZNK8JSObject8slotSpanEv($this_idx1_val_idx_val);
    var $2 = $this + 32 | 0;
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 8 >> 2];
    var $6 = __ZNK8JSObject13numFixedSlotsEv($this_idx_val);
    if ($1 >>> 0 > $6 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 3:
    if (($6 | 0) == 0) {
      var $i_0_lcssa = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZNK8JSObject10fixedSlotsEv($this);
    var $i_03 = 0;
    var $vp_04 = $10;
    __label__ = 5;
    break;
   case 5:
    var $vp_04;
    var $i_03;
    var $vp_04_idx = $vp_04 | 0;
    var $st$3$0 = $vp_04_idx | 0;
    var $vp_04_idx_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $vp_04_idx + 4 | 0;
    var $vp_04_idx_val$1 = HEAP32[$st$3$1 >> 2];
    __ZN2js2gcL9ScanValueEPNS_8GCMarkerERKN2JS5ValueE($gcmarker, $vp_04_idx_val$0, $vp_04_idx_val$1);
    var $12 = $i_03 + 1 | 0;
    if (($12 | 0) == ($6 | 0)) {
      var $i_0_lcssa = $6;
      __label__ = 6;
      break;
    } else {
      var $i_03 = $12;
      var $vp_04 = $vp_04 + 8 | 0;
      __label__ = 5;
      break;
    }
   case 6:
    var $i_0_lcssa;
    if ($i_0_lcssa >>> 0 < $1 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 7:
    var $i_11 = $i_0_lcssa;
    var $vp_12 = HEAP32[$2 >> 2];
    __label__ = 8;
    break;
   case 8:
    var $vp_12;
    var $i_11;
    var $vp_12_idx = $vp_12 | 0;
    var $st$3$0 = $vp_12_idx | 0;
    var $vp_12_idx_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $vp_12_idx + 4 | 0;
    var $vp_12_idx_val$1 = HEAP32[$st$3$1 >> 2];
    __ZN2js2gcL9ScanValueEPNS_8GCMarkerERKN2JS5ValueE($gcmarker, $vp_12_idx_val$0, $vp_12_idx_val$1);
    var $17 = $i_11 + 1 | 0;
    if (($17 | 0) == ($1 | 0)) {
      __label__ = 12;
      break;
    } else {
      var $i_11 = $17;
      var $vp_12 = $vp_12 + 8 | 0;
      __label__ = 8;
      break;
    }
   case 9:
    if (($1 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $21 = __ZNK8JSObject10fixedSlotsEv($this);
    var $i_27 = 0;
    var $vp1_08 = $21;
    __label__ = 11;
    break;
   case 11:
    var $vp1_08;
    var $i_27;
    var $vp1_08_idx = $vp1_08 | 0;
    var $st$3$0 = $vp1_08_idx | 0;
    var $vp1_08_idx_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $vp1_08_idx + 4 | 0;
    var $vp1_08_idx_val$1 = HEAP32[$st$3$1 >> 2];
    __ZN2js2gcL9ScanValueEPNS_8GCMarkerERKN2JS5ValueE($gcmarker, $vp1_08_idx_val$0, $vp1_08_idx_val$1);
    var $23 = $i_27 + 1 | 0;
    if (($23 | 0) == ($1 | 0)) {
      __label__ = 12;
      break;
    } else {
      var $i_27 = $23;
      var $vp1_08 = $vp1_08 + 8 | 0;
      __label__ = 11;
      break;
    }
   case 12:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject9scanSlotsEPN2js8GCMarkerE["X"] = 1;

function __ZN2js8GCMarker8pushRopeEP6JSRope($this, $rope) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 48 | 0;
    var $2 = __ZN2js9MarkStackIP6JSRopeE4pushES2_($1, $rope);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $rope;
    __ZN2js8GCMarker20delayMarkingChildrenEPKv($this, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5typesL15HashSetCapacityEj1539($count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 < 9) {
      var $_0 = 8;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $count | 1;
    var $4 = _llvm_ctlz_i32($3);
    var $_0 = 1 << 33 - $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc4MarkI6JSAtomEEvP8JSTracerPT_($trc, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $6 = HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $thing;
    var $10 = __ZNK2js2gc4Cell11compartmentEv($9);
    if (($10 | 0) == ($6 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $14 = HEAP32[$trc + 4 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = $trc;
    var $18 = $thing | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSString($17, $18);
    __label__ = 6;
    break;
   case 5:
    var $20 = $thing;
    var $21 = __ZN2js2gc19GetGCThingTraceKindEPKv($20);
    FUNCTION_TABLE[$14]($trc, $20, $21);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSVAL_TRACE_KIND_IMPL1545($l_0$0, $l_0$1) {
  var $1 = _JSVAL_IS_STRING_IMPL1546($l_0$0, $l_0$1);
  return $1;
}

function __ZN2js7GCTimerC2EP9JSRuntimeP13JSCompartment($this, $rt, $comp) {
  HEAP32[$this >> 2] = $rt;
  HEAP8[$this + 76 | 0] = ($comp | 0) != 0 & 1;
  var $5 = $this + 77 | 0;
  var $_idx_val = HEAP8[$rt + 229041 | 0];
  var $6 = __ZN9JSRuntime6GCData14isTimerEnabledEv($_idx_val);
  var $7 = $6 & 1;
  HEAP8[$5] = $7;
  __ZN2js7GCTimer15clearTimestampsEv($this);
  var $8 = __ZN2js7GCTimer13getFirstEnterEv($rt, $7);
  var $9 = _PRMJ_Now();
  var $9$1 = $9[1];
  var $10 = $this + 4 | 0;
  HEAP32[$10 >> 2] = $9[0];
  HEAP32[$10 + 4 >> 2] = $9$1;
  return;
}

function __ZN2js7GCTimer15clearTimestampsEv($this) {
  var $1 = $this + 4 | 0;
  var $2 = $1;
  var $8 = ($this + 68 - $1 >> 3) + 8 | 0;
  _memset($2, 0, $8, 1);
  return;
}

function __ZN2js7GCTimer13getFirstEnterEv($this_0_0_val, $this_0_11_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this_0_0_val + 229032 | 0;
    if (($this_0_11_val & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP8[$this_0_0_val + 229040 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = _PRMJ_Now();
    var $10$0 = $10[0];
    var $10$1 = $10[1];
    __ZN9JSRuntime6GCData13setFirstEnterEy($1, $10$0, $10$1);
    __label__ = 4;
    break;
   case 4:
    var $12 = $1 | 0;
    return [ HEAP32[$12 >> 2], HEAP32[$12 + 4 >> 2] ];
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7GCTimer6finishEb($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 77 | 0;
    if ((HEAP8[$1] & 1) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = _PRMJ_Now();
    var $6$1 = $6[1];
    var $7 = $this + 68 | 0;
    HEAP32[$7 >> 2] = $6[0];
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $8 = $this + 12 | 0;
    if (HEAP32[$8 >> 2] == 0 && HEAP32[$8 + 4 >> 2] == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $this + 4 | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    var $this_idx = $this | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $this_idx1_val = HEAP8[$1];
    var $14 = __ZN2js7GCTimer13getFirstEnterEv($this_idx_val, $this_idx1_val);
    var $14$0 = $14[0];
    var $14$1 = $14[1];
    var $15$0 = (i64Math.subtract($13$0, $13$1, $14$0, $14$1), i64Math.result[0]);
    var $15$1 = i64Math.result[1];
    var $17 = ($15$0 + $15$1 * 4294967296) / 1e3;
    var $18$0 = HEAP32[$7 >> 2];
    var $18$1 = HEAP32[$7 + 4 >> 2];
    var $19$0 = HEAP32[$12 >> 2];
    var $19$1 = HEAP32[$12 + 4 >> 2];
    var $20$0 = (i64Math.subtract($18$0, $18$1, $19$0, $19$1), i64Math.result[0]);
    var $20$1 = i64Math.result[1];
    var $22 = ($20$0 + $20$1 * 4294967296) / 1e3;
    var $23$0 = HEAP32[$8 >> 2];
    var $23$1 = HEAP32[$8 + 4 >> 2];
    var $24$0 = (i64Math.subtract($23$0, $23$1, $19$0, $19$1), i64Math.result[0]);
    var $24$1 = i64Math.result[1];
    var $26 = ($24$0 + $24$1 * 4294967296) / 1e3;
    var $27 = $this + 20 | 0;
    var $28$0 = HEAP32[$27 >> 2];
    var $28$1 = HEAP32[$27 + 4 >> 2];
    var $29$0 = (i64Math.subtract($28$0, $28$1, $23$0, $23$1), i64Math.result[0]);
    var $29$1 = i64Math.result[1];
    var $31 = ($29$0 + $29$1 * 4294967296) / 1e3;
    var $32 = $this + 60 | 0;
    var $33$0 = HEAP32[$32 >> 2];
    var $33$1 = HEAP32[$32 + 4 >> 2];
    var $34$0 = (i64Math.subtract($33$0, $33$1, $28$0, $28$1), i64Math.result[0]);
    var $34$1 = i64Math.result[1];
    var $36 = ($34$0 + $34$1 * 4294967296) / 1e3;
    var $37 = $this + 28 | 0;
    var $38$0 = HEAP32[$37 >> 2];
    var $38$1 = HEAP32[$37 + 4 >> 2];
    var $39$0 = (i64Math.subtract($38$0, $38$1, $28$0, $28$1), i64Math.result[0]);
    var $39$1 = i64Math.result[1];
    var $41 = ($39$0 + $39$1 * 4294967296) / 1e3;
    var $42 = $this + 36 | 0;
    var $43$0 = HEAP32[$42 >> 2];
    var $43$1 = HEAP32[$42 + 4 >> 2];
    var $44$0 = (i64Math.subtract($43$0, $43$1, $38$0, $38$1), i64Math.result[0]);
    var $44$1 = i64Math.result[1];
    var $46 = ($44$0 + $44$1 * 4294967296) / 1e3;
    var $47 = $this + 44 | 0;
    var $48$0 = HEAP32[$47 >> 2];
    var $48$1 = HEAP32[$47 + 4 >> 2];
    var $49$0 = (i64Math.subtract($48$0, $48$1, $43$0, $43$1), i64Math.result[0]);
    var $49$1 = i64Math.result[1];
    var $51 = ($49$0 + $49$1 * 4294967296) / 1e3;
    var $52 = $this + 52 | 0;
    var $53$0 = HEAP32[$52 >> 2];
    var $53$1 = HEAP32[$52 + 4 >> 2];
    var $54$0 = (i64Math.subtract($53$0, $53$1, $48$0, $48$1), i64Math.result[0]);
    var $54$1 = i64Math.result[1];
    var $56 = ($54$0 + $54$1 * 4294967296) / 1e3;
    var $57$0 = (i64Math.subtract($33$0, $33$1, $53$0, $53$1), i64Math.result[0]);
    var $57$1 = i64Math.result[1];
    var $59 = ($57$0 + $57$1 * 4294967296) / 1e3;
    var $60$0 = (i64Math.subtract($18$0, $18$1, $33$0, $33$1), i64Math.result[0]);
    var $60$1 = i64Math.result[1];
    var $62 = ($60$0 + $60$1 * 4294967296) / 1e3;
    var $63 = HEAPU32[$this_idx >> 2];
    var $66 = $63 + 234936 | 0;
    var $67 = HEAP32[$66 >> 2];
    var $69 = $67 + HEAP32[$63 + 234932 >> 2] & 63;
    var $70 = $67 + 1 | 0;
    HEAP32[$66 >> 2] = $70;
    var $71 = $63 + 229044 + $69 * 92 | 0;
    tempDoubleF64[0] = $17, HEAP32[$71 >> 2] = tempDoubleI32[0], HEAP32[$71 + 4 >> 2] = tempDoubleI32[1];
    var $72 = $63 + 229044 + $69 * 92 + 8 | 0;
    tempDoubleF64[0] = $22, HEAP32[$72 >> 2] = tempDoubleI32[0], HEAP32[$72 + 4 >> 2] = tempDoubleI32[1];
    var $73 = $63 + 229044 + $69 * 92 + 16 | 0;
    tempDoubleF64[0] = $26, HEAP32[$73 >> 2] = tempDoubleI32[0], HEAP32[$73 + 4 >> 2] = tempDoubleI32[1];
    var $74 = $63 + 229044 + $69 * 92 + 24 | 0;
    tempDoubleF64[0] = $31, HEAP32[$74 >> 2] = tempDoubleI32[0], HEAP32[$74 + 4 >> 2] = tempDoubleI32[1];
    var $75 = $63 + 229044 + $69 * 92 + 32 | 0;
    tempDoubleF64[0] = $36, HEAP32[$75 >> 2] = tempDoubleI32[0], HEAP32[$75 + 4 >> 2] = tempDoubleI32[1];
    var $76 = $63 + 229044 + $69 * 92 + 40 | 0;
    tempDoubleF64[0] = $41, HEAP32[$76 >> 2] = tempDoubleI32[0], HEAP32[$76 + 4 >> 2] = tempDoubleI32[1];
    var $77 = $63 + 229044 + $69 * 92 + 48 | 0;
    tempDoubleF64[0] = $46, HEAP32[$77 >> 2] = tempDoubleI32[0], HEAP32[$77 + 4 >> 2] = tempDoubleI32[1];
    var $78 = $63 + 229044 + $69 * 92 + 56 | 0;
    tempDoubleF64[0] = $51, HEAP32[$78 >> 2] = tempDoubleI32[0], HEAP32[$78 + 4 >> 2] = tempDoubleI32[1];
    var $79 = $63 + 229044 + $69 * 92 + 64 | 0;
    tempDoubleF64[0] = $56, HEAP32[$79 >> 2] = tempDoubleI32[0], HEAP32[$79 + 4 >> 2] = tempDoubleI32[1];
    var $80 = $63 + 229044 + $69 * 92 + 72 | 0;
    tempDoubleF64[0] = $59, HEAP32[$80 >> 2] = tempDoubleI32[0], HEAP32[$80 + 4 >> 2] = tempDoubleI32[1];
    var $81 = $63 + 229044 + $69 * 92 + 80 | 0;
    tempDoubleF64[0] = $62, HEAP32[$81 >> 2] = tempDoubleI32[0], HEAP32[$81 + 4 >> 2] = tempDoubleI32[1];
    var $84 = HEAP8[$this + 76 | 0] & 1;
    HEAP8[$63 + 229044 + $69 * 92 + 88 | 0] = $84;
    __label__ = 4;
    break;
   case 4:
    HEAP32[__ZN2js8gcReasonE >> 2] = 10;
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7GCTimer6finishEb["X"] = 1;

function _JS_NewHashTable() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[__ZL19defaultHashAllocOps >> 2];
    var $2 = FUNCTION_TABLE[$1](0, 32);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _memset($2, 0, 32, 1);
    var $7 = $2 + 8 | 0;
    HEAP32[$7 >> 2] = 28;
    var $8 = HEAP32[__ZL19defaultHashAllocOps >> 2];
    var $9 = FUNCTION_TABLE[$8](0, 64);
    var $10 = $9;
    var $11 = $2;
    HEAP32[$11 >> 2] = $10;
    if (($9 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $14 = HEAP32[__ZL19defaultHashAllocOps + 4 >> 2];
    FUNCTION_TABLE[$14](0, $2, 64);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    _memset($9, 0, 64, 1);
    var $17 = $2 + 12 | 0;
    HEAP32[$17 >> 2] = 126;
    var $19 = $2 + 16 | 0;
    HEAP32[$19 >> 2] = 128;
    var $21 = $2 + 20 | 0;
    HEAP32[$21 >> 2] = 128;
    var $23 = $2 + 24 | 0;
    HEAP32[$23 >> 2] = __ZL19defaultHashAllocOps;
    var $25 = $2 + 28 | 0;
    HEAP32[$25 >> 2] = 0;
    var $_0 = $3;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_HashTableDestroy($ht) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$ht + 24 >> 2];
    var $4 = HEAPU32[$ht + 28 >> 2];
    var $8 = 1 << 32 - HEAP32[$ht + 8 >> 2];
    var $9 = $ht | 0;
    var $10 = $2 + 12 | 0;
    var $i_01 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_01;
    var $12 = HEAP32[$9 >> 2] + ($i_01 << 2) | 0;
    var $13 = HEAP32[$12 >> 2];
    if (($13 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $15 = $13;
      __label__ = 3;
      break;
    }
   case 3:
    var $15;
    var $17 = HEAP32[$15 >> 2];
    HEAP32[$12 >> 2] = $17;
    var $18 = HEAP32[$10 >> 2];
    FUNCTION_TABLE[$18]($4, $15, 1);
    var $19 = HEAPU32[$12 >> 2];
    if (($19 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $15 = $19;
      __label__ = 3;
      break;
    }
   case 4:
    var $21 = $i_01 + 1 | 0;
    if ($21 >>> 0 < $8 >>> 0) {
      var $i_01 = $21;
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = $2 + 4 | 0;
    var $25 = HEAP32[$24 >> 2];
    var $27 = HEAP32[$9 >> 2];
    var $28 = $8 << 2;
    FUNCTION_TABLE[$25]($4, $27, $28);
    var $29 = HEAP32[$24 >> 2];
    var $30 = $ht;
    FUNCTION_TABLE[$29]($4, $30, 32);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_HashTableRawLookup($ht, $keyHash, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $7 = HEAP32[$ht >> 2] + (($keyHash * -1640531527 | 0) >>> (HEAPU32[$ht + 8 >> 2] >>> 0) << 2) | 0;
    var $8 = $ht + 16 | 0;
    var $hep_0 = $7;
    __label__ = 2;
    break;
   case 2:
    var $hep_0;
    var $10 = HEAPU32[$hep_0 >> 2];
    if (($10 | 0) == 0) {
      var $_0 = $hep_0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$10 + 4 >> 2] | 0) == ($keyHash | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $17 = HEAP32[$8 >> 2];
    var $19 = HEAP32[$10 + 8 >> 2];
    var $20 = FUNCTION_TABLE[$17]($key, $19);
    if (($20 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($hep_0 | 0) == ($7 | 0)) {
      var $_0 = $7;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $25 = $10 | 0;
    var $26 = HEAP32[$25 >> 2];
    HEAP32[$hep_0 >> 2] = $26;
    var $27 = HEAP32[$7 >> 2];
    HEAP32[$25 >> 2] = $27;
    HEAP32[$7 >> 2] = $10;
    var $_0 = $7;
    __label__ = 8;
    break;
   case 7:
    var $hep_0 = $10 | 0;
    __label__ = 2;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_HashTableRawAdd($ht, $hep, $keyHash, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$ht + 8 >> 2];
    var $4 = 1 << 32 - $2;
    var $5 = $ht + 4 | 0;
    if (HEAPU32[$5 >> 2] >>> 0 < ($4 - ($4 >>> 3) | 0) >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = $2 - 1 | 0;
    var $12 = __ZL6ResizeP11JSHashTablej($ht, $11);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = _JS_HashTableRawLookup($ht, $keyHash, $key);
    HEAP32[$hep >> 2] = $15;
    __label__ = 4;
    break;
   case 4:
    var $20 = HEAP32[HEAP32[$ht + 24 >> 2] + 8 >> 2];
    var $22 = HEAP32[$ht + 28 >> 2];
    var $23 = FUNCTION_TABLE[$20]($22, $key);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $26 = $23 + 4 | 0;
    HEAP32[$26 >> 2] = $keyHash;
    var $27 = $23 + 8 | 0;
    HEAP32[$27 >> 2] = $key;
    var $28 = $23 + 12 | 0;
    HEAP32[$28 >> 2] = 0;
    var $30 = HEAP32[HEAP32[$hep >> 2] >> 2];
    var $31 = $23 | 0;
    HEAP32[$31 >> 2] = $30;
    var $32 = HEAP32[$hep >> 2];
    HEAP32[$32 >> 2] = $23;
    var $34 = HEAP32[$5 >> 2] + 1 | 0;
    HEAP32[$5 >> 2] = $34;
    var $_0 = $23;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL6ResizeP11JSHashTablej($ht, $newshift) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $ht + 8 | 0;
    var $3 = 32 - HEAP32[$1 >> 2] | 0;
    var $5 = 1 << 32 - $newshift;
    if ($5 >>> 0 > 1073741823) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5 << 2;
    var $9 = $ht | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $11 = $ht + 24 | 0;
    var $14 = HEAP32[HEAP32[$11 >> 2] >> 2];
    var $15 = $ht + 28 | 0;
    var $16 = HEAP32[$15 >> 2];
    var $17 = FUNCTION_TABLE[$14]($16, $8);
    var $18 = $17;
    HEAP32[$9 >> 2] = $18;
    if (($17 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[$9 >> 2] = $10;
    var $_0 = 0;
    __label__ = 13;
    break;
   case 4:
    _memset($17, 0, $8, 1);
    HEAP32[$1 >> 2] = $newshift;
    var $23 = HEAP32[$ht + 4 >> 2];
    if (($23 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $i_07_ph = 0;
      var $nentries_08_ph = $23;
      __label__ = 5;
      break;
    }
   case 5:
    var $nentries_08_ph;
    var $i_07_ph;
    var $i_07 = $i_07_ph;
    __label__ = 6;
    break;
   case 6:
    var $i_07;
    var $26 = HEAP32[$10 + ($i_07 << 2) >> 2];
    if (($26 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $nentries_11 = $nentries_08_ph;
      var $he_02 = $26;
      __label__ = 8;
      break;
    }
   case 7:
    var $i_07 = $i_07 + 1 | 0;
    __label__ = 6;
    break;
   case 8:
    var $he_02;
    var $nentries_11;
    var $29 = $nentries_11 - 1 | 0;
    var $30 = $he_02 | 0;
    var $31 = HEAPU32[$30 >> 2];
    var $38 = HEAP32[$9 >> 2] + ((HEAP32[$he_02 + 4 >> 2] * -1640531527 | 0) >>> (HEAPU32[$1 >> 2] >>> 0) << 2) | 0;
    var $39 = HEAPU32[$38 >> 2];
    if (($39 | 0) == 0) {
      var $hep_0_lcssa = $38;
      __label__ = 10;
      break;
    } else {
      var $41 = $39;
      __label__ = 9;
      break;
    }
   case 9:
    var $41;
    var $42 = $41 | 0;
    var $43 = HEAP32[$42 >> 2];
    if (($43 | 0) == 0) {
      var $hep_0_lcssa = $42;
      __label__ = 10;
      break;
    } else {
      var $41 = $43;
      __label__ = 9;
      break;
    }
   case 10:
    var $hep_0_lcssa;
    HEAP32[$30 >> 2] = 0;
    HEAP32[$hep_0_lcssa >> 2] = $he_02;
    if (($31 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $nentries_11 = $29;
      var $he_02 = $31;
      __label__ = 8;
      break;
    }
   case 11:
    if (($29 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $i_07_ph = $i_07 + 1 | 0;
      var $nentries_08_ph = $29;
      __label__ = 5;
      break;
    }
   case 12:
    var $50 = HEAP32[HEAP32[$11 >> 2] + 4 >> 2];
    var $51 = HEAP32[$15 >> 2];
    var $52 = $10;
    var $53 = 4 << $3;
    FUNCTION_TABLE[$50]($51, $52, $53);
    var $_0 = 1;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL6ResizeP11JSHashTablej["X"] = 1;

function _JS_HashTableEnumerateEntries($ht, $arg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $ht + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $5 = $ht + 24 | 0;
    var $6 = $ht + 28 | 0;
    var $n_0 = 0;
    var $bucket_0 = HEAP32[$ht >> 2];
    __label__ = 2;
    break;
   case 2:
    var $bucket_0;
    var $n_0;
    if (($n_0 | 0) == ($2 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $n_1 = $n_0;
      var $hep_0 = $bucket_0;
      __label__ = 3;
      break;
    }
   case 3:
    var $hep_0;
    var $n_1;
    var $9 = HEAP32[$hep_0 >> 2];
    if (($9 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$9 + 8 >> 2];
    var $12 = __ZL27gc_sharp_table_entry_markerP11JSHashEntryiPv($_idx_val, $n_1, $arg);
    var $13 = $n_1 + 1 | 0;
    var $16 = $9 | 0;
    if (($12 & 2 | 0) == 0) {
      var $hep_1 = $16;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = HEAP32[$16 >> 2];
    HEAP32[$hep_0 >> 2] = $18;
    var $21 = HEAP32[HEAP32[$5 >> 2] + 12 >> 2];
    var $22 = HEAP32[$6 >> 2];
    FUNCTION_TABLE[$21]($22, $9, 1);
    var $24 = HEAP32[$1 >> 2] - 1 | 0;
    HEAP32[$1 >> 2] = $24;
    var $hep_1 = $hep_0;
    __label__ = 6;
    break;
   case 6:
    var $hep_1;
    if (($12 & 1 | 0) == 0) {
      var $n_1 = $13;
      var $hep_0 = $hep_1;
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $n_0 = $n_1;
    var $bucket_0 = $bucket_0 + 4 | 0;
    __label__ = 2;
    break;
   case 8:
    var $30 = HEAPU32[$1 >> 2];
    if (($30 | 0) == ($2 | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $36 = 1 << 32 - HEAP32[$ht + 8 >> 2];
    if ($36 >>> 0 > 16 & $30 >>> 0 < $36 >>> 2 >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $41 = _JS_CeilingLog2($30);
    var $43 = $41 >>> 0 < 4 ? 28 : 32 - $41 | 0;
    var $44 = __ZL6ResizeP11JSHashTablej($ht, $43);
    __label__ = 11;
    break;
   case 11:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_HashTableEnumerateEntries["X"] = 1;

function __ZL17DefaultAllocTablePvj($pool, $size) {
  var $1 = __ZN2js11OffTheBooks7malloc_Ej($size);
  return $1;
}

function __ZL16DefaultFreeTablePvS_j($pool, $item, $size) {
  __ZN2js10Foreground5free_EPv($item);
  return;
}

function __ZL17DefaultAllocEntryPvPKv($pool, $key) {
  var $1 = __ZN2js11OffTheBooks7malloc_Ej(16);
  return $1;
}

function __ZL16DefaultFreeEntryPvP11JSHashEntryj($pool, $he, $flag) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($flag | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $he;
    __ZN2js10Foreground5free_EPv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5types7TypeSet18isDefinitePropertyEv($this_0_0_val) {
  return ($this_0_0_val & 1048576 | 0) != 0;
}

function __ZNK2js5types7TypeSet12definiteSlotEv($this_0_0_val) {
  return $this_0_0_val >>> 24;
}

function __ZN2js5types11TypeFailureEP9JSContextPKcz($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 2052;
  var $msgbuf = __stackBase__;
  var $errbuf = __stackBase__ + 1024;
  var $ap = __stackBase__ + 2048;
  HEAP32[$ap >> 2] = arguments[__ZN2js5types11TypeFailureEP9JSContextPKcz.length];
  var $2 = $errbuf | 0;
  var $3 = HEAP32[$ap >> 2];
  var $4 = _JS_vsnprintf($2, 1024, STRING_TABLE.__str481618 | 0, $3);
  var $5 = $msgbuf | 0;
  var $6 = _JS_snprintf($5, 1024, STRING_TABLE.__str1568 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $2, tempInt));
  var $9 = HEAP32[$cx + 56 >> 2] + 376 | 0;
  __ZN2js5types15TypeCompartment5printEP9JSContextb($9, $cx, 1);
  _JS_Assert($5, STRING_TABLE.__str11569 | 0, 341);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js5types15TypeCompartment5printEP9JSContextb($this, $cx, $force) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $1 = __ZN2js5types15TypeCompartment11compartmentEv($this);
    if ($force) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL15InferSpewActiveN2js5types11SpewChannelE();
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    __ZN2js2gc8CellIterC1EP9JSContextP13JSCompartmentNS0_9AllocKindE($i, $1, 13);
    var $5 = $i | 0;
    var $_idx1 = $i + 28 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $6 = __ZNK2js2gc12CellIterImpl4doneEv($_idx1_val);
    if ($6) {
      __label__ = 9;
      break;
    } else {
      var $_idx2_val = $_idx1_val;
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx2_val;
    var $7 = __ZNK2js2gc12CellIterImpl3getI8JSScriptEEPT_v($_idx2_val);
    var $_idx3_val = HEAP32[$7 + 100 >> 2];
    var $8 = __ZN8JSScript11hasAnalysisEv($_idx3_val);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $_idx4_val_idx_val = HEAP32[$_idx3_val >> 2];
    var $10 = __ZN8JSScript8analysisEv($_idx4_val_idx_val);
    var $_idx5_val = HEAP8[$10 + 23 | 0];
    var $11 = __ZN2js7analyze14ScriptAnalysis12ranInferenceEv($_idx5_val);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js7analyze14ScriptAnalysis10printTypesEP9JSContext($10, $cx);
    __label__ = 7;
    break;
   case 7:
    __ZN2js2gc12CellIterImpl4nextEv($5);
    var $_idx_val = HEAP32[$_idx1 >> 2];
    var $14 = __ZNK2js2gc12CellIterImpl4doneEv($_idx_val);
    if ($14) {
      __label__ = 9;
      break;
    } else {
      var $_idx2_val = $_idx_val;
      __label__ = 4;
      break;
    }
   case 8:
    STACKTOP = __stackBase__;
    return;
   case 9:
    __ZN2js2gc8CellIterD1Ev($i);
    var $16 = _printf(STRING_TABLE.__str231593 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $18 = HEAP32[$this + 56 >> 2];
    var $19 = _printf(STRING_TABLE.__str544300 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $18, tempInt));
    var $putchar_1 = _putchar(47);
    var $21 = HEAP32[$this + 60 >> 2];
    var $22 = _printf(STRING_TABLE.__str544300 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $21, tempInt));
    var $putchar_2 = _putchar(47);
    var $24 = HEAP32[$this + 64 >> 2];
    var $25 = _printf(STRING_TABLE.__str544300 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $24, tempInt));
    var $putchar_3 = _putchar(47);
    var $27 = HEAP32[$this + 68 >> 2];
    var $28 = _printf(STRING_TABLE.__str544300 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $27, tempInt));
    var $30 = HEAP32[$this + 72 >> 2];
    var $31 = _printf(STRING_TABLE.__str261596 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $30, tempInt));
    var $33 = HEAP32[$this + 16 >> 2];
    var $34 = _printf(STRING_TABLE.__str271597 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $33, tempInt));
    __label__ = 8;
    break;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types15TypeCompartment5printEP9JSContextb["X"] = 1;

function __ZN2js5types7TypeSet4makeEP9JSContextPKc($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 56 | 0;
    var $3 = HEAP32[$1 >> 2] + 344 | 0;
    var $4 = __ZN2js8ArenaNewINS_5types7TypeSetEEEPT_R11JSArenaPool($3);
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $4;
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = HEAP32[$1 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($8, $cx);
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8ArenaNewINS_5types7TypeSetEEEPT_R11JSArenaPool($pool) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 12 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $25 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    __ZN2js5types7TypeSetC1Ev($23);
    var $25 = $23;
    __label__ = 6;
    break;
   case 6:
    var $25;
    return $25;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 8 | 0;
    if ((HEAP8[$1] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    if ((HEAP32[$cx + 56 >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    __label__ = 4;
    break;
   case 4:
    HEAP8[$1] = 1;
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet14getObjectCountEv($this_0_0_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5types7TypeSet15baseObjectCountEv($this_0_0_val);
    if ($1 >>> 0 > 8) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js5typesL15HashSetCapacityEj1739($1);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet9getObjectEj($this_0_0_val, $this_0_1_val, $i) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5types7TypeSet15baseObjectCountEv($this_0_0_val);
    if (($1 | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $this_0_1_val;
    __label__ = 4;
    break;
   case 3:
    var $_0 = HEAP32[$this_0_1_val + ($i << 2) >> 2];
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types4Type10ObjectTypeEPNS0_13TypeObjectKeyE($agg_result, $obj) {
  var $1 = $obj;
  __ZN2js5types4TypeC1Ej($agg_result, $1);
  return;
}

function __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($this, $cx, $target) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$1 >> 2] = $target;
  var $4 = HEAP32[$cx + 56 >> 2] + 344 | 0;
  var $5 = __ZN2js8ArenaNewI20TypeConstraintSubsetPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_($4, $1);
  var $6 = $5 | 0;
  __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $6, 1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $constraint, $callExisting) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 12;
    if (($constraint | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($9, $cx);
    __label__ = 19;
    break;
   case 3:
    var $11 = $this + 8 | 0;
    var $12 = HEAP32[$11 >> 2];
    HEAP32[$constraint + 4 >> 2] = $12;
    HEAP32[$11 >> 2] = $constraint;
    if ($callExisting) {
      __label__ = 4;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 4:
    var $15 = $this | 0;
    var $16 = HEAP32[$15 >> 2];
    var $19 = $cx + 56 | 0;
    if (($16 & 65536 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $_02 = $2 | 0;
    var $flag_02 = 1;
    var $26 = $16;
    __label__ = 7;
    break;
   case 6:
    var $22 = HEAP32[$19 >> 2] + 376 | 0;
    __ZN2js5types4Type11UnknownTypeEv($1);
    var $_03_val = HEAP32[$1 >> 2];
    __ZN2js5types15TypeCompartment10addPendingEP9JSContextPNS0_14TypeConstraintEPNS0_7TypeSetENS0_4TypeE($22, $cx, $constraint, $this, $_03_val);
    var $24 = HEAP32[$19 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment14resolvePendingEP9JSContext($24, $cx);
    __label__ = 19;
    break;
   case 7:
    var $26;
    var $flag_02;
    if (($26 & $flag_02 | 0) == 0) {
      var $this_idx_val = $26;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $30 = __ZN2js5types17TypeFlagPrimitiveEj($flag_02);
    __ZN2js5types4Type13PrimitiveTypeE11JSValueType($2, $30);
    var $32 = HEAP32[$19 >> 2] + 376 | 0;
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js5types15TypeCompartment10addPendingEP9JSContextPNS0_14TypeConstraintEPNS0_7TypeSetENS0_4TypeE($32, $cx, $constraint, $this, $_02_val);
    var $this_idx_val = HEAP32[$15 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $this_idx_val;
    var $34 = $flag_02 << 1;
    if ($34 >>> 0 < 128) {
      var $flag_02 = $34;
      var $26 = $this_idx_val;
      __label__ = 7;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if (($this_idx_val & 128 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $41 = HEAP32[$19 >> 2] + 376 | 0;
    __ZN2js5types4Type13AnyObjectTypeEv($3);
    var $_01_val = HEAP32[$3 >> 2];
    __ZN2js5types15TypeCompartment10addPendingEP9JSContextPNS0_14TypeConstraintEPNS0_7TypeSetENS0_4TypeE($41, $cx, $constraint, $this, $_01_val);
    var $43 = HEAP32[$19 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment14resolvePendingEP9JSContext($43, $cx);
    __label__ = 19;
    break;
   case 12:
    var $45 = __ZN2js5types7TypeSet14getObjectCountEv($this_idx_val);
    if (($45 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $this_idx5 = $this + 4 | 0;
    var $_0 = $4 | 0;
    var $i_01 = 0;
    var $this_idx4_val = $this_idx_val;
    __label__ = 14;
    break;
   case 14:
    var $this_idx4_val;
    var $i_01;
    var $this_idx5_val = HEAP32[$this_idx5 >> 2];
    var $48 = __ZN2js5types7TypeSet9getObjectEj($this_idx4_val, $this_idx5_val, $i_01);
    if (($48 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $52 = HEAP32[$19 >> 2] + 376 | 0;
    __ZN2js5types4Type10ObjectTypeEPNS0_13TypeObjectKeyE($4, $48);
    var $_0_val = HEAP32[$_0 >> 2];
    __ZN2js5types15TypeCompartment10addPendingEP9JSContextPNS0_14TypeConstraintEPNS0_7TypeSetENS0_4TypeE($52, $cx, $constraint, $this, $_0_val);
    __label__ = 16;
    break;
   case 16:
    var $54 = $i_01 + 1 | 0;
    if (($54 | 0) == ($45 | 0)) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $i_01 = $54;
    var $this_idx4_val = HEAP32[$15 >> 2];
    __label__ = 14;
    break;
   case 18:
    var $56 = HEAP32[$19 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment14resolvePendingEP9JSContext($56, $cx);
    __label__ = 19;
    break;
   case 19:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb["X"] = 1;

function __ZN2js8ArenaNewI20TypeConstraintSubsetPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_($pool, $a) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 12 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $26 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    __ZN20TypeConstraintSubsetC1EPN2js5types7TypeSetE($23, $24);
    var $26 = $23;
    __label__ = 6;
    break;
   case 6:
    var $26;
    return $26;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet14addGetPropertyEP9JSContextP8JSScriptPhPS1_i($this, $cx, $script, $pc, $target, $id) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __stackBase__ + 8;
  var $4 = __stackBase__ + 12;
  var $5 = __stackBase__ + 16;
  HEAP32[$1 >> 2] = $script;
  HEAP32[$2 >> 2] = $pc;
  HEAP32[$3 >> 2] = $target;
  HEAP32[$4 >> 2] = $id;
  var $8 = HEAP32[$cx + 56 >> 2] + 344 | 0;
  HEAP8[$5] = 0;
  var $9 = __ZN2js8ArenaNewI18TypeConstraintPropP8JSScriptPhPNS_5types7TypeSetEibEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_RKT4_($8, $1, $2, $3, $4, $5);
  var $10 = $9 | 0;
  __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $10, 1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js8ArenaNewI18TypeConstraintPropP8JSScriptPhPNS_5types7TypeSetEibEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_RKT4_($pool, $a, $b, $c, $d, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 28 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $32 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    var $26 = HEAP32[$c >> 2];
    var $27 = HEAP32[$d >> 2];
    var $30 = (HEAP8[$e] & 1) << 24 >> 24 != 0;
    __ZN18TypeConstraintPropC1EP8JSScriptPhPN2js5types7TypeSetEib($23, $24, $25, $26, $27, $30);
    var $32 = $23;
    __label__ = 6;
    break;
   case 6:
    var $32;
    return $32;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet14addSetPropertyEP9JSContextP8JSScriptPhPS1_i($this, $cx, $script, $pc, $target, $id) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __stackBase__ + 8;
  var $4 = __stackBase__ + 12;
  var $5 = __stackBase__ + 16;
  HEAP32[$1 >> 2] = $script;
  HEAP32[$2 >> 2] = $pc;
  HEAP32[$3 >> 2] = $target;
  HEAP32[$4 >> 2] = $id;
  var $8 = HEAP32[$cx + 56 >> 2] + 344 | 0;
  HEAP8[$5] = 1;
  var $9 = __ZN2js8ArenaNewI18TypeConstraintPropP8JSScriptPhPNS_5types7TypeSetEibEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_RKT4_($8, $1, $2, $3, $4, $5);
  var $10 = $9 | 0;
  __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $10, 1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js5types7TypeSet15addCallPropertyEP9JSContextP8JSScriptPhi($this, $cx, $script, $pc, $id) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $callpc = __stackBase__ + 8;
    var $untrap = __stackBase__ + 12;
    HEAP32[$1 >> 2] = $script;
    HEAP32[$2 >> 2] = $id;
    var $script_idx_val_idx_val = HEAP32[HEAP32[$script + 100 >> 2] >> 2];
    var $3 = __ZN8JSScript8analysisEv($script_idx_val_idx_val);
    var $4 = __ZN2js7analyze14ScriptAnalysis9getCallPCEPh($3, $pc);
    HEAP32[$callpc >> 2] = $4;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $script, $4);
    if (HEAP8[$4] << 24 >> 24 == 82) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    var $11 = __ZN2js8ArenaNewI22TypeConstraintCallPropP8JSScriptPhiEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($10, $1, $callpc, $2);
    var $12 = $11 | 0;
    __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $12, 1);
    __label__ = 3;
    break;
   case 3:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis9getCallPCEPh($this, $pc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $8 = $pc - HEAP32[HEAP32[$2 >> 2] >> 2] | 0;
  __ZN2js7analyze8SSAValue11PushedValueEjj($1, $8, 1);
  var $9 = __ZN2js7analyze14ScriptAnalysis8useChainERKNS0_8SSAValueE($this, $1);
  var $17 = HEAP32[HEAP32[$2 >> 2] >> 2] + (HEAPU32[HEAP32[$9 >> 2] >> 2] >>> 1) | 0;
  STACKTOP = __stackBase__;
  return $17;
}

function __ZN2js8ArenaNewI22TypeConstraintCallPropP8JSScriptPhiEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($pool, $a, $b, $c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 20 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $28 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    var $26 = HEAP32[$c >> 2];
    __ZN22TypeConstraintCallPropC1EP8JSScriptPhi($23, $24, $25, $26);
    var $28 = $23;
    __label__ = 6;
    break;
   case 6:
    var $28;
    return $28;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet13addSetElementEP9JSContextP8JSScriptPhPS1_S7_($this, $cx, $script, $pc, $objectTypes, $valueTypes) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __stackBase__ + 8;
  var $4 = __stackBase__ + 12;
  HEAP32[$1 >> 2] = $script;
  HEAP32[$2 >> 2] = $pc;
  HEAP32[$3 >> 2] = $objectTypes;
  HEAP32[$4 >> 2] = $valueTypes;
  var $7 = HEAP32[$cx + 56 >> 2] + 344 | 0;
  var $8 = __ZN2js8ArenaNewI24TypeConstraintSetElementP8JSScriptPhPNS_5types7TypeSetES7_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_($7, $1, $2, $3, $4);
  var $9 = $8 | 0;
  __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $9, 1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js8ArenaNewI24TypeConstraintSetElementP8JSScriptPhPNS_5types7TypeSetES7_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_($pool, $a, $b, $c, $d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 24 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $29 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    var $26 = HEAP32[$c >> 2];
    var $27 = HEAP32[$d >> 2];
    __ZN24TypeConstraintSetElementC1EP8JSScriptPhPN2js5types7TypeSetES6_($23, $24, $25, $26, $27);
    var $29 = $23;
    __label__ = 6;
    break;
   case 6:
    var $29;
    return $29;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet7addCallEP9JSContextPNS0_12TypeCallsiteE($this, $cx, $site) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$1 >> 2] = $site;
  var $4 = HEAP32[$cx + 56 >> 2] + 344 | 0;
  var $5 = __ZN2js8ArenaNewI18TypeConstraintCallPNS_5types12TypeCallsiteEEEPT_R11JSArenaPoolRKT0_($4, $1);
  var $6 = $5 | 0;
  __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $6, 1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js8ArenaNewI18TypeConstraintCallPNS_5types12TypeCallsiteEEEPT_R11JSArenaPoolRKT0_($pool, $a) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 12 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $26 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    __ZN18TypeConstraintCallC1EPN2js5types12TypeCallsiteE($23, $24);
    var $26 = $23;
    __label__ = 6;
    break;
   case 6:
    var $26;
    return $26;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet8addArithEP9JSContextPS1_S4_($this, $cx, $target, $other) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  HEAP32[$1 >> 2] = $target;
  HEAP32[$2 >> 2] = $other;
  var $5 = HEAP32[$cx + 56 >> 2] + 344 | 0;
  var $6 = __ZN2js8ArenaNewI19TypeConstraintArithPNS_5types7TypeSetES4_EEPT_R11JSArenaPoolRKT0_RKT1_($5, $1, $2);
  var $7 = $6 | 0;
  __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $7, 1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js8ArenaNewI19TypeConstraintArithPNS_5types7TypeSetES4_EEPT_R11JSArenaPoolRKT0_RKT1_($pool, $a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 16 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $27 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    __ZN19TypeConstraintArithC1EPN2js5types7TypeSetES3_($23, $24, $25);
    var $27 = $23;
    __label__ = 6;
    break;
   case 6:
    var $27;
    return $27;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet16addTransformThisEP9JSContextP8JSScriptPS1_($this, $cx, $script, $target) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  HEAP32[$1 >> 2] = $script;
  HEAP32[$2 >> 2] = $target;
  var $5 = HEAP32[$cx + 56 >> 2] + 344 | 0;
  var $6 = __ZN2js8ArenaNewI27TypeConstraintTransformThisP8JSScriptPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_RKT1_($5, $1, $2);
  var $7 = $6 | 0;
  __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $7, 1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js8ArenaNewI27TypeConstraintTransformThisP8JSScriptPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_RKT1_($pool, $a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 16 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $27 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    __ZN27TypeConstraintTransformThisC1EP8JSScriptPN2js5types7TypeSetE($23, $24, $25);
    var $27 = $23;
    __label__ = 6;
    break;
   case 6:
    var $27;
    return $27;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet16addPropagateThisEP9JSContextP8JSScriptPhNS0_4TypeEPS1_($this, $cx, $script, $pc, $type_0, $types) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $type = __stackBase__;
    HEAP32[$type >> 2] = $type_0;
    var $1 = STACKTOP;
    STACKTOP += 4;
    var $2 = STACKTOP;
    STACKTOP += 4;
    var $callpc = STACKTOP;
    STACKTOP += 4;
    var $untrap = STACKTOP;
    STACKTOP += 8;
    HEAP32[$1 >> 2] = $script;
    HEAP32[$2 >> 2] = $types;
    var $script_idx_val_idx_val = HEAP32[HEAP32[$script + 100 >> 2] >> 2];
    var $3 = __ZN8JSScript8analysisEv($script_idx_val_idx_val);
    var $4 = __ZN2js7analyze14ScriptAnalysis9getCallPCEPh($3, $pc);
    HEAP32[$callpc >> 2] = $4;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $script, $4);
    if (HEAP8[$4] << 24 >> 24 == 82) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    var $11 = __ZN2js8ArenaNewI27TypeConstraintPropagateThisP8JSScriptPhNS_5types4TypeEPNS5_7TypeSetEEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_($10, $1, $callpc, $type, $2);
    var $12 = $11 | 0;
    __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $12, 1);
    __label__ = 3;
    break;
   case 3:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8ArenaNewI27TypeConstraintPropagateThisP8JSScriptPhNS_5types4TypeEPNS5_7TypeSetEEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_($pool, $a, $b, $c, $d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 24 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $30 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    var $27 = HEAP32[$c >> 2];
    var $28 = HEAP32[$d >> 2];
    __ZN27TypeConstraintPropagateThisC1EP8JSScriptPhN2js5types4TypeEPNS4_7TypeSetE($23, $24, $25, $27, $28);
    var $30 = $23;
    __label__ = 6;
    break;
   case 6:
    var $30;
    return $30;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet19addFilterPrimitivesEP9JSContextPS1_NS1_10FilterKindE($this, $cx, $target, $filter) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  HEAP32[$1 >> 2] = $target;
  HEAP32[$2 >> 2] = $filter;
  var $5 = HEAP32[$cx + 56 >> 2] + 344 | 0;
  var $6 = __ZN2js8ArenaNewI29TypeConstraintFilterPrimitivePNS_5types7TypeSetENS3_10FilterKindEEEPT_R11JSArenaPoolRKT0_RKT1_($5, $1, $2);
  var $7 = $6 | 0;
  __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $7, 1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js8ArenaNewI29TypeConstraintFilterPrimitivePNS_5types7TypeSetENS3_10FilterKindEEEPT_R11JSArenaPoolRKT0_RKT1_($pool, $a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 16 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $27 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    __ZN29TypeConstraintFilterPrimitiveC1EPN2js5types7TypeSetENS2_10FilterKindE($23, $24, $25);
    var $27 = $23;
    __label__ = 6;
    break;
   case 6:
    var $27;
    return $27;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5types4Type11isPrimitiveE11JSValueType($this_0_0_val, $type) {
  return ($type & 255 | 0) == ($this_0_0_val | 0);
}

function __ZN2js5types7TypeSet21hasPropagatedPropertyEv($this_0_0_val) {
  return ($this_0_0_val & 131072 | 0) != 0;
}

function __ZN2js7analyze14ScriptAnalysis17pruneTypeBarriersEP9JSContextj($this_0_1_val, $cx, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_0_1_val, $offset);
    var $pbarrier_0_ph = $1 + 40 | 0;
    __label__ = 2;
    break;
   case 2:
    var $pbarrier_0_ph;
    var $4 = HEAP32[$pbarrier_0_ph >> 2];
    __label__ = 3;
    break;
   case 3:
    var $4;
    if (($4 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = HEAP32[$4 + 4 >> 2];
    var $10 = HEAP32[$4 + 8 >> 2];
    var $11 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($8, $10);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $storemerge = HEAP32[$4 >> 2];
    HEAP32[$pbarrier_0_ph >> 2] = $storemerge;
    var $4 = $storemerge;
    __label__ = 3;
    break;
   case 6:
    var $13 = $4 + 12 | 0;
    var $14 = HEAP32[$13 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = HEAP32[$4 + 16 >> 2];
    var $19 = __ZL17GetSingletonShapeP9JSContextP8JSObjecti($cx, $14, $18);
    if (($19 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = HEAP32[$13 >> 2];
    var $24 = HEAP32[$19 + 24 >> 2];
    var $25 = __ZNK8JSObject13nativeGetSlotEj($22, $24);
    var $_idx = $25 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $26 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 9:
    var $pbarrier_0_ph = $4 | 0;
    __label__ = 2;
    break;
   case 10:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17GetSingletonShapeP9JSContextP8JSObjecti($cx, $obj, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject12nativeLookupEP9JSContexti($obj, $cx, $id);
    if (($1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2js5Shape26hasDefaultGetterOrIsMethodEv($1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    if ((HEAP32[$1 + 24 >> 2] | 0) == -1) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis17breakTypeBarriersEP9JSContextjb($this, $cx, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx2 = $this + 4 | 0;
    var $this_idx2_val = HEAP32[$this_idx2 >> 2];
    __ZN2js7analyze14ScriptAnalysis17pruneTypeBarriersEP9JSContextj($this_idx2_val, $cx, $offset);
    var $this_idx_val = HEAP32[$this_idx2 >> 2];
    var $0 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_idx_val, $offset);
    var $1 = $0 + 40 | 0;
    var $2 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $2;
    if (($2 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = HEAP32[$2 + 4 >> 2];
    var $8 = HEAP32[$2 + 8 >> 2];
    var $9 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($6, $8);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $storemerge = HEAP32[$2 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $storemerge;
    HEAP32[$1 >> 2] = $storemerge;
    var $2 = $storemerge;
    __label__ = 2;
    break;
   case 6:
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($6, $cx, $8);
    var $storemerge = HEAP32[$2 >> 2];
    __label__ = 5;
    break;
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis20breakTypeBarriersSSAEP9JSContextRKNS0_8SSAValueE($this, $cx, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js7analyze8SSAValue4kindEv($v);
    if (($1 | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = __ZNK2js7analyze8SSAValue12pushedOffsetEv($v);
    if (HEAP8[HEAP32[HEAP32[$this >> 2] >> 2] + $4 | 0] << 24 >> 24 == 53) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $13 = __ZN2js7analyze14ScriptAnalysis11poppedValueEjj($this_idx_val, $4, 0);
    __ZN2js7analyze14ScriptAnalysis20breakTypeBarriersSSAEP9JSContextRKNS0_8SSAValueE($this, $cx, $13);
    __label__ = 4;
    break;
   case 4:
    __ZN2js7analyze14ScriptAnalysis17breakTypeBarriersEP9JSContextjb($this, $cx, $4);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet16addSubsetBarrierEP9JSContextP8JSScriptPhPS1_($this, $cx, $script, $pc, $target) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __stackBase__ + 8;
  HEAP32[$1 >> 2] = $script;
  HEAP32[$2 >> 2] = $pc;
  HEAP32[$3 >> 2] = $target;
  var $6 = HEAP32[$cx + 56 >> 2] + 344 | 0;
  var $7 = __ZN2js8ArenaNewI27TypeConstraintSubsetBarrierP8JSScriptPhPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($6, $1, $2, $3);
  var $8 = $7 | 0;
  __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $8, 1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js8ArenaNewI27TypeConstraintSubsetBarrierP8JSScriptPhPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($pool, $a, $b, $c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 20 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $28 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    var $26 = HEAP32[$c >> 2];
    __ZN27TypeConstraintSubsetBarrierC1EP8JSScriptPhPN2js5types7TypeSetE($23, $24, $25, $26);
    var $28 = $23;
    __label__ = 6;
    break;
   case 6:
    var $28;
    return $28;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet16addLazyArgumentsEP9JSContextPS1_($this, $cx, $target) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$1 >> 2] = $target;
  var $4 = HEAP32[$cx + 56 >> 2] + 344 | 0;
  var $5 = __ZN2js8ArenaNewI27TypeConstraintLazyArgumentsPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_($4, $1);
  var $6 = $5 | 0;
  __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $6, 1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js8ArenaNewI27TypeConstraintLazyArgumentsPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_($pool, $a) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 12 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $26 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    __ZN27TypeConstraintLazyArgumentsC1EPN2js5types7TypeSetE($23, $24);
    var $26 = $23;
    __label__ = 6;
    break;
   case 6:
    var $26;
    return $26;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypeConstraintProp7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $untrap = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = $this + 8 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $4 = $this + 12 | 0;
    var $5 = HEAP32[$4 >> 2];
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $3, $5);
    var $6 = HEAP32[$2 >> 2];
    var $8 = HEAP32[$type >> 2];
    var $9 = __ZL21UnknownPropertyAccessP8JSScriptN2js5types4TypeE($6, $8);
    if ($9) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $15 = HEAP32[$4 >> 2];
    if ((HEAP8[$this + 16 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $21 = $15 - HEAP32[$6 >> 2] | 0;
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb($cx, $6, $21, 0);
    __label__ = 13;
    break;
   case 4:
    var $24 = HEAP32[$this + 20 >> 2];
    __ZL25MarkPropertyAccessUnknownP9JSContextP8JSScriptPhPN2js5types7TypeSetE($cx, $6, $15, $24);
    __label__ = 13;
    break;
   case 5:
    var $26 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($8, 4);
    if ($26) {
      __label__ = 6;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 6:
    if ((HEAP8[$this + 16 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 7:
    var $34 = HEAP32[$this + 24 >> 2];
    if (($34 | 0) == 2) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $cx_idx_val_idx_val = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2];
    var $37 = __ZL9id_lengthP9JSContext($cx_idx_val_idx_val);
    if (($34 | 0) == ($37 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 9:
    var $39 = HEAP32[$4 >> 2];
    var $41 = HEAP32[$this + 20 >> 2];
    __ZL25MarkPropertyAccessUnknownP9JSContextP8JSScriptPhPN2js5types7TypeSetE($cx, $6, $39, $41);
    __label__ = 13;
    break;
   case 10:
    var $44 = HEAP32[$this + 20 >> 2];
    __ZN2js5types4Type9Int32TypeEv($1);
    var $_0_val = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($44, $cx, $_0_val);
    __label__ = 13;
    break;
   case 11:
    var $46 = __ZL17GetPropertyObjectP9JSContextP8JSScriptN2js5types4TypeE($cx, $6, $8);
    if (($46 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $49 = HEAP32[$2 >> 2];
    var $50 = HEAP32[$4 >> 2];
    var $54 = (HEAP8[$this + 16 | 0] & 1) << 24 >> 24 != 0;
    var $56 = HEAP32[$this + 20 >> 2];
    var $58 = HEAP32[$this + 24 >> 2];
    __ZL14PropertyAccessP9JSContextP8JSScriptPhPN2js5types10TypeObjectEbPNS5_7TypeSetEi($cx, $49, $50, $46, $54, $56, $58);
    __label__ = 13;
    break;
   case 13:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypeConstraintProp7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE["X"] = 1;

function __ZL21UnknownPropertyAccessP8JSScriptN2js5types4TypeE($script, $type_0) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5types4Type9isUnknownEv($type_0);
    if ($1) {
      var $10 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js5types4Type11isAnyObjectEv($type_0);
    if ($3) {
      var $10 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK2js5types4Type8isObjectEv($type_0);
    if ($5) {
      var $10 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $script_idx_val_idx_val = HEAP32[HEAP32[$script + 100 >> 2] + 8 >> 2];
    var $7 = __ZNK8JSScript9hasGlobalEv($script_idx_val_idx_val);
    var $10 = $7 ^ 1;
    __label__ = 5;
    break;
   case 5:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb($cx, $script, $offset, $returnOnly) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $untrap = __stackBase__;
    var $script_idx2 = $script + 100 | 0;
    var $script_idx2_val_idx_val = HEAP32[HEAP32[$script_idx2 >> 2] >> 2];
    var $1 = __ZN8JSScript8analysisEv($script_idx2_val_idx_val);
    var $4 = HEAP32[$script >> 2] + $offset | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $script, $4);
    var $_idx4_val = HEAP32[$1 + 4 >> 2];
    var $_idx3_val_idx_val = HEAP32[HEAP32[$1 >> 2] >> 2];
    var $5 = __ZN2js7analyze14ScriptAnalysis7getCodeEPKh($_idx3_val_idx_val, $_idx4_val, $4);
    var $7 = $5 + 1 | 0;
    var $8 = HEAPU8[$7];
    var $9 = $returnOnly ? 8 : 4;
    if (($8 & $9) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    if ((HEAP32[_js_CodeSpec + ((HEAPU8[$4] & 255) << 3) + 4 >> 2] & 2097152 | 0) == 0) {
      var $21 = $8;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $19 = $8 | 8;
    HEAP8[$7] = $19;
    var $21 = $19;
    __label__ = 4;
    break;
   case 4:
    var $21;
    if ($returnOnly) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP8[$7] = $21 | 4;
    __label__ = 6;
    break;
   case 6:
    if ((HEAP8[$script + 37 | 0] & 4) << 24 >> 24 == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $script_idx_val_idx_val = HEAP32[HEAP32[$script_idx2 >> 2] + 4 >> 2];
    var $30 = __ZNK8JSScript8functionEv($script_idx_val_idx_val);
    var $_idx_val = HEAP32[$30 + 8 >> 2];
    var $31 = __ZNK8JSObject11hasLazyTypeEv($_idx_val);
    if ($31) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx1_val = HEAP32[$30 + 36 >> 2];
    var $33 = __ZNK8JSObject4typeEv($_idx1_val);
    __ZL17ObjectStateChangeP9JSContextPN2js5types10TypeObjectEbb($cx, $33, 0, 1);
    __label__ = 9;
    break;
   case 9:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb["X"] = 1;

function __ZL25MarkPropertyAccessUnknownP9JSContextP8JSScriptPhPN2js5types7TypeSetE($cx, $script, $pc, $target) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $pc_val = HEAP8[$pc];
    var $3 = __ZL22UsePropertyTypeBarrierPh($pc_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $script_idx_val_idx_val = HEAP32[HEAP32[$script + 100 >> 2] >> 2];
    var $5 = __ZN8JSScript8analysisEv($script_idx_val_idx_val);
    __ZN2js5types4Type11UnknownTypeEv($1);
    var $_idx_val = HEAP32[$5 >> 2];
    var $_idx1_val = HEAP32[$5 + 4 >> 2];
    var $_02_val = HEAP32[$1 >> 2];
    __ZN2js7analyze14ScriptAnalysis14addTypeBarrierEP9JSContextPKhPNS_5types7TypeSetENS6_4TypeE($_idx_val, $_idx1_val, $cx, $pc, $target, $_02_val);
    __label__ = 4;
    break;
   case 3:
    __ZN2js5types4Type11UnknownTypeEv($2);
    var $_0_val = HEAP32[$2 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($target, $cx, $_0_val);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9id_lengthP9JSContext($cx_0_11_val_0_70_28_val) {
  var $1 = $cx_0_11_val_0_70_28_val | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom1694($1);
  return $2;
}

function __ZN2js5types4Type9Int32TypeEv($agg_result) {
  __ZN2js5types4TypeC1Ej($agg_result, 1);
  return;
}

function __ZL17GetPropertyObjectP9JSContextP8JSScriptN2js5types4TypeE($cx, $script, $type_0) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5types4Type12isTypeObjectEv($type_0);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2js5types4Type10typeObjectEv($type_0);
    var $_0 = $3;
    __label__ = 11;
    break;
   case 3:
    var $5 = __ZNK2js5types4Type14isSingleObjectEv($type_0);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZNK2js5types4Type12singleObjectEv($type_0);
    var $8 = $7;
    var $9 = $cx;
    var $10 = __ZN8JSObject7getTypeEP9JSContext($8, $9);
    var $_0 = $10;
    __label__ = 11;
    break;
   case 5:
    var $13 = __ZNK2js5types4Type9primitiveEv($type_0);
    var $14 = $13 & 255;
    if (($14 | 0) == 1 || ($14 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($14 | 0) == 3) {
      __label__ = 7;
      break;
    } else if (($14 | 0) == 5) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 6:
    var $script_idx4_val_idx_val = HEAP32[HEAP32[$script + 100 >> 2] + 8 >> 2];
    var $16 = __ZN2js5types10TypeScript12StandardTypeEP9JSContextP8JSScript10JSProtoKey($cx, $script_idx4_val_idx_val, 8);
    var $object_0 = $16;
    __label__ = 9;
    break;
   case 7:
    var $script_idx3_val_idx_val = HEAP32[HEAP32[$script + 100 >> 2] + 8 >> 2];
    var $18 = __ZN2js5types10TypeScript12StandardTypeEP9JSContextP8JSScript10JSProtoKey($cx, $script_idx3_val_idx_val, 4);
    var $object_0 = $18;
    __label__ = 9;
    break;
   case 8:
    var $script_idx_val_idx_val = HEAP32[HEAP32[$script + 100 >> 2] + 8 >> 2];
    var $20 = __ZN2js5types10TypeScript12StandardTypeEP9JSContextP8JSScript10JSProtoKey($cx, $script_idx_val_idx_val, 9);
    var $object_0 = $20;
    __label__ = 9;
    break;
   case 9:
    var $object_0;
    if (($object_0 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = $object_0;
      __label__ = 11;
      break;
    }
   case 10:
    var $26 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($26, $cx);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14PropertyAccessP9JSContextP8JSScriptPhPN2js5types10TypeObjectEbPNS5_7TypeSetEi($cx, $script, $pc, $object, $assign, $target, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $object_idx_val = HEAP32[$object + 12 >> 2];
    var $1 = __ZN2js5types10TypeObject17unknownPropertiesEv($object_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    if ($assign) {
      __label__ = 16;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZL25MarkPropertyAccessUnknownP9JSContextP8JSScriptPhPN2js5types7TypeSetE($cx, $script, $pc, $target);
    __label__ = 16;
    break;
   case 4:
    var $5 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($object, $cx, $id, $assign);
    if (($5 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ($assign) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($target, $cx, $5);
    __label__ = 16;
    break;
   case 7:
    var $_idx1_val = HEAP32[$5 >> 2];
    var $10 = __ZN2js5types7TypeSet21hasPropagatedPropertyEv($_idx1_val);
    if ($10) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2js5types10TypeObject17getFromPrototypesEP9JSContextiPNS0_7TypeSetEb($object, $cx, $id, $5, 0);
    __label__ = 9;
    break;
   case 9:
    var $pc_val = HEAP8[$pc];
    var $13 = __ZL22UsePropertyTypeBarrierPh($pc_val);
    if ($13) {
      __label__ = 10;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 10:
    __ZN2js5types7TypeSet16addSubsetBarrierEP9JSContextP8JSScriptPhPS1_($5, $cx, $script, $pc, $target);
    var $15 = $object + 4 | 0;
    var $16 = HEAP32[$15 >> 2];
    if (($16 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $19 = _JSID_IS_VOID1691($id);
    if (($19 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 12:
    var $22 = __ZL17GetSingletonShapeP9JSContextP8JSObjecti($cx, $16, $id);
    if (($22 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $25 = HEAP32[$15 >> 2];
    var $27 = HEAP32[$22 + 24 >> 2];
    var $28 = __ZNK8JSObject13nativeGetSlotEj($25, $27);
    var $_idx = $28 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $29 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($29) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    var $script_idx_val_idx_val = HEAP32[HEAP32[$script + 100 >> 2] >> 2];
    var $31 = __ZN8JSScript8analysisEv($script_idx_val_idx_val);
    var $_idx2_val = HEAP32[$31 >> 2];
    var $_idx3_val = HEAP32[$31 + 4 >> 2];
    __ZN2js7analyze14ScriptAnalysis23addSingletonTypeBarrierEP9JSContextPKhPNS_5types7TypeSetEP8JSObjecti($_idx2_val, $_idx3_val, $cx, $pc, $target, $25, $id);
    __label__ = 16;
    break;
   case 15:
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($5, $cx, $target);
    __label__ = 16;
    break;
   case 16:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14PropertyAccessP9JSContextP8JSScriptPhPN2js5types10TypeObjectEbPNS5_7TypeSetEi["X"] = 1;

function __ZN22TypeConstraintCallProp7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $untrap = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = $this + 8 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $4 = $this + 12 | 0;
    var $5 = HEAP32[$4 >> 2];
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $3, $5);
    var $6 = HEAP32[$2 >> 2];
    var $8 = HEAP32[$type >> 2];
    var $9 = __ZL21UnknownPropertyAccessP8JSScriptN2js5types4TypeE($6, $8);
    if ($9) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = HEAP32[$4 >> 2] - HEAP32[$6 >> 2] | 0;
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb($cx, $6, $16, 0);
    __label__ = 10;
    break;
   case 3:
    var $18 = __ZL17GetPropertyObjectP9JSContextP8JSScriptN2js5types4TypeE($cx, $6, $8);
    if (($18 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$18 + 12 >> 2];
    var $21 = __ZN2js5types10TypeObject17unknownPropertiesEv($_idx_val);
    if ($21) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $23 = HEAP32[$2 >> 2];
    var $29 = HEAP32[$4 >> 2] - HEAP32[$23 >> 2] | 0;
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb($cx, $23, $29, 0);
    __label__ = 10;
    break;
   case 6:
    var $31 = $this + 16 | 0;
    var $32 = HEAP32[$31 >> 2];
    var $33 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($18, $cx, $32, 0);
    if (($33 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx1_val = HEAP32[$33 >> 2];
    var $36 = __ZN2js5types7TypeSet21hasPropagatedPropertyEv($_idx1_val);
    if ($36) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $38 = HEAP32[$31 >> 2];
    __ZN2js5types10TypeObject17getFromPrototypesEP9JSContextiPNS0_7TypeSetEb($18, $cx, $38, $33, 0);
    __label__ = 9;
    break;
   case 9:
    var $42 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    HEAP32[$1 >> 2] = 0;
    var $43 = __ZN2js8ArenaNewI27TypeConstraintPropagateThisP8JSScriptPhNS_5types4TypeEPNS5_7TypeSetEEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_($42, $2, $4, $type, $1);
    var $44 = $43 | 0;
    __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($33, $cx, $44, 1);
    __label__ = 10;
    break;
   case 10:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN22TypeConstraintCallProp7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE["X"] = 1;

function __ZN2js5types10TypeObject17getFromPrototypesEP9JSContextiPNS0_7TypeSetEb($this, $cx, $id, $types, $force) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if ($force) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $types_idx_val = HEAP32[$types >> 2];
    var $3 = __ZN2js5types7TypeSet21hasPropagatedPropertyEv($types_idx_val);
    if ($3) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js5types7TypeSet21setPropagatedPropertyEv($types);
    var $5 = $this | 0;
    var $6 = HEAP32[$5 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $6;
    var $10 = $cx;
    var $11 = __ZN8JSObject7getTypeEP9JSContext($9, $10);
    var $_idx2_val = HEAP32[$11 + 12 >> 2];
    var $13 = __ZN2js5types10TypeObject17unknownPropertiesEv($_idx2_val);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js5types4Type11UnknownTypeEv($1);
    var $_0_val = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($types, $cx, $_0_val);
    __label__ = 8;
    break;
   case 6:
    var $_idx1_val = HEAP32[HEAP32[$5 >> 2] + 36 >> 2];
    var $17 = __ZNK8JSObject4typeEv($_idx1_val);
    var $18 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($17, $cx, $id, 0);
    if (($18 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($18, $cx, $types);
    var $_idx_val = HEAP32[HEAP32[$5 >> 2] + 36 >> 2];
    var $22 = __ZNK8JSObject4typeEv($_idx_val);
    __ZN2js5types10TypeObject17getFromPrototypesEP9JSContextiPNS0_7TypeSetEb($22, $cx, $id, $18, 0);
    __label__ = 8;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN24TypeConstraintSetElement7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $type_idx_val = HEAP32[$type >> 2];
    var $1 = __ZNK2js5types4Type9isUnknownEv($type_idx_val);
    if ($1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($type_idx_val, 1);
    if ($3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($type_idx_val, 0);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = HEAP32[$this + 16 >> 2];
    var $10 = HEAP32[$this + 8 >> 2];
    var $12 = HEAP32[$this + 12 >> 2];
    var $14 = HEAP32[$this + 20 >> 2];
    __ZN2js5types7TypeSet14addSetPropertyEP9JSContextP8JSScriptPhPS1_i($8, $cx, $10, $12, $14, 2);
    __label__ = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5types4Type12singleObjectEv($this_0_0_val) {
  return $this_0_0_val ^ 1;
}

function __ZN2js5types10TypeObject11hasAnyFlagsEj($this_0_3_val, $flags) {
  return ($this_0_3_val & $flags | 0) != 0;
}

function __ZN18TypeConstraintCall7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = $this + 8 | 0;
    var $4 = HEAP32[$3 >> 2];
    var $6 = HEAPU32[$4 >> 2];
    var $8 = HEAPU32[$4 + 4 >> 2];
    var $type_idx_val = HEAPU32[$type >> 2];
    var $9 = __ZNK2js5types4Type9isUnknownEv($type_idx_val);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = __ZNK2js5types4Type11isAnyObjectEv($type_idx_val);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $17 = $8 - HEAP32[$6 >> 2] | 0;
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb($cx, $6, $17, 0);
    __label__ = 29;
    break;
   case 4:
    var $19 = __ZNK2js5types4Type14isSingleObjectEv($type_idx_val);
    if ($19) {
      __label__ = 5;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 5:
    var $21 = __ZNK2js5types4Type12singleObjectEv($type_idx_val);
    var $_idx_val = HEAP32[$21 + 4 >> 2];
    var $22 = __ZNK8JSObject10isFunctionEv($_idx_val);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 6:
    var $_idx2 = $21 + 24 | 0;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $24 = __ZNK8JSObject18getFunctionPrivateEv($_idx2_val);
    var $25 = $24;
    var $26 = __ZNK10JSFunction8isNativeEv($25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $callee_0 = $24;
      __label__ = 19;
      break;
    }
   case 7:
    var $32 = $8 - HEAP32[$6 >> 2] | 0;
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb($cx, $6, $32, 1);
    var $_idx1_val = HEAP32[$_idx2 >> 2];
    var $33 = __ZNK8JSObject18getFunctionPrivateEv($_idx1_val);
    var $_idx14_val = HEAP32[$33 + 60 >> 2];
    var $35 = __ZNK10JSFunction6nativeEv($_idx14_val);
    if (($35 | 0) == 130) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $37 = HEAP32[$3 >> 2];
    if ((HEAP32[$37 + 16 >> 2] | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      var $i_011 = 0;
      var $41 = $37;
      __label__ = 9;
      break;
    }
   case 9:
    var $41;
    var $i_011;
    var $43 = HEAP32[$41 + 20 >> 2];
    var $47 = HEAP32[HEAP32[$41 + 12 >> 2] + ($i_011 << 2) >> 2];
    __ZN2js5types7TypeSet14addSetPropertyEP9JSContextP8JSScriptPhPS1_i($43, $cx, $6, $8, $47, 2);
    var $48 = $i_011 + 1 | 0;
    var $49 = HEAPU32[$3 >> 2];
    if ($48 >>> 0 < HEAPU32[$49 + 16 >> 2] >>> 0) {
      var $i_011 = $48;
      var $41 = $49;
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if (($35 | 0) == 132) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $54 = HEAP32[$3 >> 2];
    var $56 = HEAP32[$54 + 20 >> 2];
    var $58 = HEAP32[$54 + 24 >> 2];
    __ZN2js5types7TypeSet14addGetPropertyEP9JSContextP8JSScriptPhPS1_i($56, $cx, $6, $8, $58, 2);
    __label__ = 29;
    break;
   case 12:
    if (($35 | 0) == 66) {
      __label__ = 13;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 13:
    var $62 = __ZN2js5types10TypeScript10InitObjectEP9JSContextP8JSScriptPKh10JSProtoKey($cx, $6, $8, 3);
    if (($62 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $67 = HEAP32[HEAP32[$3 >> 2] + 24 >> 2];
    __ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE($1, $62);
    var $_06_val = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($67, $cx, $_06_val);
    var $68 = HEAPU32[$3 >> 2];
    if (HEAPU32[$68 + 16 >> 2] >>> 0 > 1) {
      __label__ = 15;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 15:
    var $i1_07 = 0;
    var $73 = $68;
    __label__ = 16;
    break;
   case 16:
    var $73;
    var $i1_07;
    var $77 = HEAP32[HEAP32[$73 + 12 >> 2] + ($i1_07 << 2) >> 2];
    __ZL14PropertyAccessP9JSContextP8JSScriptPhPN2js5types10TypeObjectEbPNS5_7TypeSetEi($cx, $6, $8, $62, 1, $77, 2);
    var $78 = $i1_07 + 1 | 0;
    var $79 = HEAPU32[$3 >> 2];
    if ($78 >>> 0 < HEAPU32[$79 + 16 >> 2] >>> 0) {
      var $i1_07 = $78;
      var $73 = $79;
      __label__ = 16;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 17:
    var $84 = __ZNK2js5types4Type12isTypeObjectEv($type_idx_val);
    if ($84) {
      __label__ = 18;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 18:
    var $86 = __ZNK2js5types4Type10typeObjectEv($type_idx_val);
    var $88 = HEAP32[$86 + 28 >> 2];
    if (($88 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      var $callee_0 = $88;
      __label__ = 19;
      break;
    }
   case 19:
    var $callee_0;
    var $91 = __ZNK10JSFunction6scriptEv($callee_0);
    var $92 = __ZN8JSScript14ensureHasTypesEP9JSContextP10JSFunction($91, $cx, $callee_0);
    if ($92) {
      __label__ = 20;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 20:
    var $95 = HEAPU16[$callee_0 + 56 >> 1];
    var $96 = $95 & 65535;
    var $97 = HEAPU32[$3 >> 2];
    var $99 = HEAPU32[$97 + 16 >> 2];
    if (($99 | 0) != 0 & $95 << 16 >> 16 != 0) {
      var $i2_04 = 0;
      var $105 = $97;
      __label__ = 23;
      break;
    } else {
      var $_lcssa2 = $99;
      var $102 = $97;
      __label__ = 21;
      break;
    }
   case 21:
    var $102;
    var $_lcssa2;
    var $103 = $_lcssa2 >>> 0 < $96 >>> 0;
    var $104 = __ZNK10JSFunction6scriptEv($callee_0);
    if ($103) {
      __label__ = 22;
      break;
    } else {
      var $_lcssa = $104;
      var $122 = $102;
      __label__ = 26;
      break;
    }
   case 22:
    var $_0 = $2 | 0;
    var $i3_01 = $_lcssa2;
    var $118 = $104;
    __label__ = 24;
    break;
   case 23:
    var $105;
    var $i2_04;
    var $109 = HEAP32[HEAP32[$105 + 12 >> 2] + ($i2_04 << 2) >> 2];
    var $110 = __ZNK10JSFunction6scriptEv($callee_0);
    var $_idx12_val = HEAP16[$110 + 22 >> 1];
    var $_idx13_val = HEAP32[$110 + 100 >> 2];
    var $111 = __ZN2js5types10TypeScript8ArgTypesEP8JSScriptj($_idx12_val, $_idx13_val, $i2_04);
    __ZN2js5types7TypeSet16addSubsetBarrierEP9JSContextP8JSScriptPhPS1_($109, $cx, $6, $8, $111);
    var $112 = $i2_04 + 1 | 0;
    var $113 = HEAPU32[$3 >> 2];
    var $115 = HEAPU32[$113 + 16 >> 2];
    if ($112 >>> 0 < $115 >>> 0 & $112 >>> 0 < $96 >>> 0) {
      var $i2_04 = $112;
      var $105 = $113;
      __label__ = 23;
      break;
    } else {
      var $_lcssa2 = $115;
      var $102 = $113;
      __label__ = 21;
      break;
    }
   case 24:
    var $118;
    var $i3_01;
    var $_idx10_val = HEAP16[$118 + 22 >> 1];
    var $_idx11_val = HEAP32[$118 + 100 >> 2];
    var $119 = __ZN2js5types10TypeScript8ArgTypesEP8JSScriptj($_idx10_val, $_idx11_val, $i3_01);
    __ZN2js5types4Type13UndefinedTypeEv($2);
    var $_0_val = HEAP32[$_0 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($119, $cx, $_0_val);
    var $120 = $i3_01 + 1 | 0;
    var $121 = __ZNK10JSFunction6scriptEv($callee_0);
    if (($120 | 0) == ($96 | 0)) {
      __label__ = 25;
      break;
    } else {
      var $i3_01 = $120;
      var $118 = $121;
      __label__ = 24;
      break;
    }
   case 25:
    var $_lcssa = $121;
    var $122 = HEAP32[$3 >> 2];
    __label__ = 26;
    break;
   case 26:
    var $122;
    var $_lcssa;
    var $_lcssa_idx_val = HEAP16[$_lcssa + 22 >> 1];
    var $_lcssa_idx7_val = HEAP32[$_lcssa + 100 >> 2];
    var $123 = __ZN2js5types10TypeScript11ReturnTypesEP8JSScript($_lcssa_idx_val, $_lcssa_idx7_val);
    var $129 = HEAP32[$122 + 24 >> 2];
    if ((HEAP8[$122 + 8 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $131 = __ZN2js5types10TypeScript9ThisTypesEP8JSScript($_lcssa_idx_val, $_lcssa_idx7_val);
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($131, $cx, $129);
    var $134 = HEAP32[HEAP32[$3 >> 2] + 24 >> 2];
    __ZN2js5types7TypeSet19addFilterPrimitivesEP9JSContextPS1_NS1_10FilterKindE($123, $cx, $134, 0);
    __label__ = 29;
    break;
   case 28:
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($123, $cx, $129);
    __label__ = 29;
    break;
   case 29:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypeConstraintCall7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE["X"] = 1;

function __ZNK2js5types4Type14isSingleObjectEv($this_0_0_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5types4Type8isObjectEv($this_0_0_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = ($this_0_0_val & 1 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE($agg_result, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$obj + 4 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $2 | 1;
    __ZN2js5types4TypeC1Ej($agg_result, $6);
    __label__ = 4;
    break;
   case 3:
    var $8 = $obj;
    __ZN2js5types4TypeC1Ej($agg_result, $8);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript9ThisTypesEP8JSScript($script_0_11_val, $script_0_32_val) {
  var $1 = __ZN2js5types10TypeScript9typeArrayEv($script_0_32_val);
  return $1 + (($script_0_11_val & 65535) + 1) * 12 | 0;
}

function __ZN2js5types10TypeScript11ReturnTypesEP8JSScript($script_0_11_val, $script_0_32_val) {
  var $1 = __ZN2js5types10TypeScript9typeArrayEv($script_0_32_val);
  return $1 + ($script_0_11_val & 65535) * 12 | 0;
}

function __ZN27TypeConstraintPropagateThis7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $type_idx_val = HEAP32[$type >> 2];
    var $1 = __ZNK2js5types4Type9isUnknownEv($type_idx_val);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js5types4Type11isAnyObjectEv($type_idx_val);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = HEAP32[$this + 8 >> 2];
    var $13 = HEAP32[$this + 12 >> 2] - HEAP32[$6 >> 2] | 0;
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb($cx, $6, $13, 0);
    __label__ = 13;
    break;
   case 4:
    var $15 = __ZNK2js5types4Type14isSingleObjectEv($type_idx_val);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $17 = __ZNK2js5types4Type12singleObjectEv($type_idx_val);
    var $_idx_val = HEAP32[$17 + 4 >> 2];
    var $18 = __ZNK8JSObject10isFunctionEv($_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 6:
    var $_idx1_val = HEAP32[$17 + 24 >> 2];
    var $20 = __ZNK8JSObject18getFunctionPrivateEv($_idx1_val);
    var $_idx2_val = HEAP16[$20 + 58 >> 1];
    var $21 = __ZNK10JSFunction13isInterpretedEv($_idx2_val);
    if ($21) {
      var $callee_0 = $20;
      __label__ = 9;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 7:
    var $23 = __ZNK2js5types4Type12isTypeObjectEv($type_idx_val);
    if ($23) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $25 = __ZNK2js5types4Type10typeObjectEv($type_idx_val);
    var $27 = HEAP32[$25 + 28 >> 2];
    if (($27 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $callee_0 = $27;
      __label__ = 9;
      break;
    }
   case 9:
    var $callee_0;
    var $30 = __ZNK10JSFunction6scriptEv($callee_0);
    var $31 = __ZN8JSScript14ensureHasTypesEP9JSContextP10JSFunction($30, $cx, $callee_0);
    if ($31) {
      __label__ = 10;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 10:
    var $33 = __ZNK10JSFunction6scriptEv($callee_0);
    var $_idx6_val = HEAP16[$33 + 22 >> 1];
    var $_idx7_val = HEAP32[$33 + 100 >> 2];
    var $34 = __ZN2js5types10TypeScript9ThisTypesEP8JSScript($_idx6_val, $_idx7_val);
    var $36 = HEAP32[$this + 20 >> 2];
    if (($36 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($36, $cx, $34);
    __label__ = 13;
    break;
   case 12:
    var $41 = HEAP32[$this + 16 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($34, $cx, $41);
    __label__ = 13;
    break;
   case 13:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN27TypeConstraintPropagateThis7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE["X"] = 1;

function __ZN19TypeConstraintArith7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 12;
    var $5 = __stackBase__ + 16;
    var $6 = __stackBase__ + 20;
    var $7 = __stackBase__ + 24;
    var $8 = __stackBase__ + 28;
    var $9 = $this + 12 | 0;
    var $10 = HEAP32[$9 >> 2];
    var $11 = ($10 | 0) == 0;
    var $type_idx_val = HEAP32[$type >> 2];
    var $12 = __ZNK2js5types4Type9isUnknownEv($type_idx_val);
    if ($11) {
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$10 >> 2];
    var $15 = __ZNK2js5types7TypeSet7unknownEv($_idx_val);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $18 = HEAP32[$this + 8 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($1);
    var $_07_val = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($18, $cx, $_07_val);
    __label__ = 21;
    break;
   case 5:
    var $20 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($type_idx_val, 0);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $22 = __ZNK2js5types7TypeSet10hasAnyFlagEj($_idx_val, 159);
    if ($22) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = __ZN2js5types7TypeSet14getObjectCountEv($_idx_val);
    if (($24 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $28 = HEAP32[$this + 8 >> 2];
    __ZN2js5types4Type10DoubleTypeEv($2);
    var $_06_val = HEAP32[$2 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($28, $cx, $_06_val);
    __label__ = 21;
    break;
   case 9:
    var $30 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($type_idx_val, 5);
    if ($30) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $33 = HEAP32[$this + 8 >> 2];
    __ZN2js5types4Type10StringTypeEv($3);
    var $_05_val = HEAP32[$3 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($33, $cx, $_05_val);
    __label__ = 21;
    break;
   case 11:
    var $35 = __ZNK2js5types7TypeSet10hasAnyFlagEj($_idx_val, 143);
    if ($35) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $37 = __ZN2js5types7TypeSet14getObjectCountEv($_idx_val);
    if (($37 | 0) == 0) {
      var $_idx10_val = $_idx_val;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $41 = HEAP32[$this + 8 >> 2];
    __ZN2js5types4Type9Int32TypeEv($4);
    var $_04_val = HEAP32[$4 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($41, $cx, $_04_val);
    var $_idx10_val = HEAP32[HEAP32[$9 >> 2] >> 2];
    __label__ = 14;
    break;
   case 14:
    var $_idx10_val;
    var $43 = __ZNK2js5types7TypeSet10hasAnyFlagEj($_idx10_val, 16);
    if ($43) {
      __label__ = 15;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 15:
    var $46 = HEAP32[$this + 8 >> 2];
    __ZN2js5types4Type10DoubleTypeEv($5);
    var $_03_val = HEAP32[$5 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($46, $cx, $_03_val);
    __label__ = 21;
    break;
   case 16:
    if ($12) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $50 = HEAP32[$this + 8 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($6);
    var $_02_val = HEAP32[$6 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($50, $cx, $_02_val);
    __label__ = 21;
    break;
   case 18:
    var $52 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($type_idx_val, 0);
    var $54 = HEAP32[$this + 8 >> 2];
    if ($52) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    __ZN2js5types4Type10DoubleTypeEv($7);
    var $_01_val = HEAP32[$7 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($54, $cx, $_01_val);
    __label__ = 21;
    break;
   case 20:
    __ZN2js5types4Type9Int32TypeEv($8);
    var $_0_val = HEAP32[$8 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($54, $cx, $_0_val);
    __label__ = 21;
    break;
   case 21:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN19TypeConstraintArith7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE["X"] = 1;

function __ZNK2js5types7TypeSet10hasAnyFlagEj($this_0_0_val, $flags) {
  var $1 = __ZNK2js5types7TypeSet9baseFlagsEv($this_0_0_val);
  return ($1 & $flags | 0) != 0;
}

function __ZN2js5types4Type10StringTypeEv($agg_result) {
  __ZN2js5types4TypeC1Ej($agg_result, 5);
  return;
}

function __ZN27TypeConstraintTransformThis7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $type_idx_val = HEAP32[$type >> 2];
    var $3 = __ZNK2js5types4Type9isUnknownEv($type_idx_val);
    if ($3) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2js5types4Type11isAnyObjectEv($type_idx_val);
    if ($5) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js5types4Type8isObjectEv($type_idx_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = HEAP32[$this + 8 >> 2];
    if ((HEAP8[$10 + 36 | 0] & 8) << 24 >> 24 == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = HEAP32[$this + 12 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($17, $cx, $type_idx_val);
    __label__ = 17;
    break;
   case 6:
    var $_idx_val_idx_val = HEAPU32[HEAP32[$10 + 100 >> 2] + 8 >> 2];
    var $19 = __ZNK8JSScript9hasGlobalEv($_idx_val_idx_val);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $21 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($type_idx_val, 6);
    if ($21) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $23 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($type_idx_val, 2);
    if ($23) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $26 = HEAP32[$this + 12 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($1);
    var $_04_val = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($26, $cx, $_04_val);
    __label__ = 17;
    break;
   case 10:
    var $28 = __ZNK2js5types4Type9primitiveEv($type_idx_val);
    var $29 = $28 & 255;
    if (($29 | 0) == 1 || ($29 | 0) == 0) {
      __label__ = 11;
      break;
    } else if (($29 | 0) == 3) {
      __label__ = 12;
      break;
    } else if (($29 | 0) == 5) {
      __label__ = 13;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 11:
    var $31 = __ZN2js5types10TypeScript12StandardTypeEP9JSContextP8JSScript10JSProtoKey($cx, $_idx_val_idx_val, 8);
    var $object_0 = $31;
    __label__ = 14;
    break;
   case 12:
    var $33 = __ZN2js5types10TypeScript12StandardTypeEP9JSContextP8JSScript10JSProtoKey($cx, $_idx_val_idx_val, 4);
    var $object_0 = $33;
    __label__ = 14;
    break;
   case 13:
    var $35 = __ZN2js5types10TypeScript12StandardTypeEP9JSContextP8JSScript10JSProtoKey($cx, $_idx_val_idx_val, 9);
    var $object_0 = $35;
    __label__ = 14;
    break;
   case 14:
    var $object_0;
    if (($object_0 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $41 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($41, $cx);
    __label__ = 17;
    break;
   case 16:
    var $44 = HEAP32[$this + 12 >> 2];
    __ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE($2, $object_0);
    var $_0_val = HEAP32[$2 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($44, $cx, $_0_val);
    __label__ = 17;
    break;
   case 17:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN27TypeConstraintTransformThis7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE["X"] = 1;

function __ZN2js5types10TypeScript12StandardTypeEP9JSContextP8JSScript10JSProtoKey($cx, $script_0_32_val_0_2_val, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $proto = __stackBase__;
    var $1 = __ZNK8JSScript6globalEv($script_0_32_val_0_2_val);
    var $2 = $cx;
    var $3 = $1;
    var $4 = $proto;
    var $5 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, $key, $4, 0);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$proto >> 2];
    var $9 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($8, $cx, 0, 0);
    var $_0 = $9;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet15getSingleObjectEj($this_0_0_val, $this_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js5types7TypeSet9getObjectEj($this_0_0_val, $this_0_1_val, 0);
    var $2 = $1;
    if (($2 & 1 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $2 ^ 1;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types20MarkArgumentsCreatedEP9JSContextP8JSScript($cx, $script) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $iter = __stackBase__ + 8;
    var $1 = $script + 38 | 0;
    var $3 = HEAP8[$1] | 6;
    HEAP8[$1] = $3;
    var $script_idx = $script + 100 | 0;
    var $script_idx_val_idx_val = HEAP32[HEAP32[$script_idx >> 2] + 4 >> 2];
    var $4 = __ZNK8JSScript8functionEv($script_idx_val_idx_val);
    var $5 = $4 | 0;
    __ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj($cx, $5, 1572864);
    if ((HEAP8[$1] & 1) << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    var $10 = __ZN8JSScript17ensureRanAnalysisEP9JSContextP10JSFunctionP8JSObject($script, $cx, 0, 0);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 3:
    var $script_idx1_val_idx_val = HEAP32[HEAP32[$script_idx >> 2] >> 2];
    var $12 = __ZN8JSScript8analysisEv($script_idx1_val_idx_val);
    __ZN2js13FrameRegsIterC1EP9JSContextNS_9StackIter11SavedOptionE($iter, $cx);
    var $13 = __ZNK2js13FrameRegsIter4doneEv($iter);
    if ($13) {
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx2 = $12 | 0;
    var $_idx3 = $12 + 4 | 0;
    __label__ = 5;
    break;
   case 5:
    var $14 = __ZNK2js13FrameRegsIter2fpEv($iter);
    var $_idx_val = HEAP32[$14 >> 2];
    var $15 = __ZNK2js10StackFrame13isScriptFrameEv($_idx_val);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 6:
    var $17 = __ZNK2js10StackFrame6scriptEv($14);
    if (($17 | 0) == ($script | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 7:
    var $20 = $14;
    var $21 = __ZNK2js10StackFrame4baseEv($20);
    var $22 = __ZNK2js13FrameRegsIter2pcEv($iter);
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $_idx2_val_idx_val = HEAP32[HEAP32[$_idx2 >> 2] >> 2];
    var $23 = __ZN2js7analyze14ScriptAnalysis7getCodeEPKh($_idx2_val_idx_val, $_idx3_val, $22);
    var $26 = $21 + (HEAP32[$23 + 4 >> 2] << 3) | 0;
    var $27 = __ZNK2js10StackFrame5slotsEv($20);
    if ($27 >>> 0 < $26 >>> 0) {
      var $vp_01 = $27;
      __label__ = 8;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 8:
    var $vp_01;
    var $29 = __ZNK2JS5Value12isMagicCheckE10JSWhyMagic($vp_01);
    if ($29) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $31 = __Z15js_GetArgsValueP9JSContextPN2js10StackFrameEPN2JS5ValueE($cx, $14, $vp_01);
    if (($31 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    __ZN2JS5Value7setNullEv($vp_01);
    __label__ = 11;
    break;
   case 11:
    var $35 = $vp_01 + 8 | 0;
    if ($35 >>> 0 < $26 >>> 0) {
      var $vp_01 = $35;
      __label__ = 8;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN2js13FrameRegsIterppEv($iter);
    var $37 = __ZNK2js13FrameRegsIter4doneEv($iter);
    if ($37) {
      __label__ = 13;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 13:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    __label__ = 14;
    break;
   case 14:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types20MarkArgumentsCreatedEP9JSContextP8JSScript["X"] = 1;

function __ZN8JSScript17ensureRanAnalysisEP9JSContextP10JSFunctionP8JSObject($this, $cx, $fun, $scope) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSScript14ensureHasTypesEP9JSContextP10JSFunction($this, $cx, $fun);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    var $3 = $this + 100 | 0;
    var $4 = HEAP32[$3 >> 2];
    var $_idx_val = HEAP32[$4 + 8 >> 2];
    var $5 = __ZN2js5types10TypeScript8hasScopeEv($_idx_val);
    if ($5) {
      var $this_idx_val = $4;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZN2js5types10TypeScript8SetScopeEP9JSContextP8JSScriptP8JSObject($cx, $this, $scope);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $this_idx_val = HEAP32[$3 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $this_idx_val;
    var $9 = __ZN8JSScript11hasAnalysisEv($this_idx_val);
    if ($9) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $11 = __ZN8JSScript12makeAnalysisEP9JSContext($this, $cx);
    if ($11) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis7getCodeEPKh($this_0_0_val_0_0_val, $this_0_1_val, $pc) {
  var $3 = $pc - $this_0_0_val_0_0_val | 0;
  var $4 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_0_1_val, $3);
  return $4;
}

function __ZNK2JS5Value12isMagicCheckE10JSWhyMagic($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx = $this | 0;
    var $this_idx_val$0 = HEAP32[$this_idx >> 2];
    var $this_idx_val$1 = HEAP32[$this_idx + 4 >> 2];
    var $1 = __ZNK2JS5Value7isMagicEv($this_idx_val$0, $this_idx_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = ($this_idx_val$0 | 0) == 9;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSScript6globalEv($this_0_32_val_0_2_val) {
  return $this_0_32_val_0_2_val;
}

function __ZNK2js5types7TypeSet13isOwnPropertyEb($this_0_0_val, $configurable) {
  var $1 = $configurable ? 524288 : 262144;
  return ($1 & $this_0_0_val | 0) != 0;
}

function __ZN2jsL3MaxIjEET_S1_S1_1674($t2) {
  var $2 = $t2 >>> 0 < 100 ? 100 : $t2;
  return $2;
}

function __ZL24CheckNewScriptPropertiesP9JSContextPN2js5types10TypeObjectEP10JSFunction($cx, $type, $fun) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $baseobj = __stackBase__;
    var $initializerList = __stackBase__ + 4;
    var $1 = __stackBase__ + 28;
    var $done = __stackBase__ + 32;
    var $type_idx = $type + 12 | 0;
    var $type_idx_val = HEAP32[$type_idx >> 2];
    var $2 = __ZN2js5types10TypeObject17unknownPropertiesEv($type_idx_val);
    if ($2) {
      __label__ = 22;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK10JSFunction6scriptEv($fun);
    if ((HEAP8[$4 + 37 | 0] & 32) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 3:
    var $10 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1751($cx);
    HEAP32[$baseobj >> 2] = $10;
    if (($10 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    if ((HEAP32[$type + 16 >> 2] | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js5types10TypeObject14clearNewScriptEP9JSContext($type, $cx);
    __label__ = 22;
    break;
   case 6:
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
    var $_0_val = HEAP32[$1 >> 2];
    __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEEC1ES4_($initializerList, $_0_val);
    var $18 = __ZL26AnalyzeNewScriptPropertiesP9JSContextPN2js5types10TypeObjectEP10JSFunctionPP8JSObjectPNS1_6VectorINS2_13TypeNewScript11InitializerELj0ENS1_15TempAllocPolicyEEE($cx, $type, $fun, $baseobj, $initializerList);
    var $19 = HEAP32[$baseobj >> 2];
    if (($19 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx3_val_idx_val = HEAP32[HEAP32[$19 >> 2] + 4 >> 2];
    var $22 = __ZNK8JSObject8slotSpanEv($_idx3_val_idx_val);
    if (($22 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((HEAP32[$type_idx >> 2] & 2 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ((HEAP32[$type + 16 >> 2] | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2js5types10TypeObject14clearNewScriptEP9JSContext($type, $cx);
    __label__ = 21;
    break;
   case 11:
    var $34 = $type + 16 | 0;
    if ((HEAP32[$34 >> 2] | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $38 = __ZN2js5types10TypeObject23matchDefinitePropertiesEP8JSObject($type, $19);
    if ($38) {
      __label__ = 21;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    __ZN2js5types10TypeObject14clearNewScriptEP9JSContext($type, $cx);
    __label__ = 21;
    break;
   case 14:
    var $41 = __ZN2js2gcL15GetGCObjectKindEjb1752($22);
    __ZN2js5types13TypeNewScript11InitializerC1ENS2_4KindEj($done, 3, 0);
    var $42 = HEAP32[$baseobj >> 2];
    var $_idx2_val = HEAP32[$42 + 20 >> 2];
    var $43 = __ZNK8JSObject9getParentEv($_idx2_val);
    var $_idx1_val = HEAP32[$42 >> 2];
    var $44 = __ZNK8JSObject12lastPropertyEv($_idx1_val);
    var $45 = $cx;
    var $46 = $type;
    var $47 = $43;
    var $48 = $44;
    var $49 = __ZN2js17NewReshapedObjectEP9JSContextPNS_5types10TypeObjectEP8JSObjectNS_2gc9AllocKindEPKNS_5ShapeE($45, $46, $47, $41, $48);
    var $50 = $49;
    HEAP32[$baseobj >> 2] = $50;
    if (($49 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $53 = __ZN2js5types10TypeObject21addDefinitePropertiesEP9JSContextP8JSObject($type, $cx, $50);
    if ($53) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $55 = $done;
    var $57 = HEAP32[$55 >> 2];
    var $58 = HEAP32[$55 + 4 >> 2];
    var $59 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_($initializerList, $57, $58);
    if ($59) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $63 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($63, $cx);
    __label__ = 21;
    break;
   case 18:
    var $initializerList_idx4 = $initializerList + 8 | 0;
    var $initializerList_idx4_val = HEAP32[$initializerList_idx4 >> 2];
    var $65 = __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE6lengthEv($initializerList_idx4_val);
    var $67 = ($65 << 3) + 16 | 0;
    var $68 = __ZN9JSContext7calloc_Ej($cx, $67);
    var $69 = $68;
    HEAP32[$34 >> 2] = $69;
    if (($68 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $74 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($74, $cx);
    __label__ = 21;
    break;
   case 20:
    var $76 = $68;
    HEAP32[$76 >> 2] = $fun;
    var $78 = HEAP32[$34 >> 2] + 4 | 0;
    HEAP32[$78 >> 2] = $41;
    var $_idx_val = HEAP32[HEAP32[$baseobj >> 2] >> 2];
    var $80 = __ZNK8JSObject12lastPropertyEv($_idx_val);
    var $82 = HEAP32[$34 >> 2] + 8 | 0;
    HEAP32[$82 >> 2] = $80;
    var $83 = HEAP32[$34 >> 2];
    var $85 = $83 + 16 | 0;
    var $86 = $83 + 12 | 0;
    HEAP32[$86 >> 2] = $85;
    var $89 = HEAP32[HEAP32[$34 >> 2] + 12 >> 2];
    var $initializerList_idx5_val = HEAP32[$initializerList + 4 >> 2];
    var $90 = __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE5beginEv($initializerList_idx5_val);
    var $initializerList_idx_val = HEAP32[$initializerList_idx4 >> 2];
    var $91 = __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE6lengthEv($initializerList_idx_val);
    __ZN2jsL7PodCopyINS_5types13TypeNewScript11InitializerEEEvPT_PKS4_j($89, $90, $91);
    __label__ = 21;
    break;
   case 21:
    __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEED1Ev($initializerList);
    __label__ = 22;
    break;
   case 22:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL24CheckNewScriptPropertiesP9JSContextPN2js5types10TypeObjectEP10JSFunction["X"] = 1;

function __ZN2js5types7TypeSet12getSingletonEP9JSContextb($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx1_val = HEAP32[$this >> 2];
    var $1 = __ZNK2js5types7TypeSet9baseFlagsEv($this_idx1_val);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZNK2js5types7TypeSet15baseObjectCountEv($this_idx1_val);
    if (($4 | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $this_idx3_val = HEAP32[$this + 4 >> 2];
    var $7 = __ZN2js5types7TypeSet15getSingleObjectEj($this_idx1_val, $this_idx3_val);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObjectC1EP8JSObjectbb($this, $proto, $function, $unknown) {
  __ZN2js5types10TypeObjectC2EP8JSObjectbb($this, $proto, $function, $unknown);
  return;
}

function __ZN2js5types15TypeCompartment4initEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __ZN2jsL7PodZeroINS_5types15TypeCompartmentEEEvPT_($this);
    if (($cx | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $cx_idx_val = HEAP32[$cx + 32 >> 2];
    var $3 = __ZNK9JSContext13getRunOptionsEv($cx_idx_val);
    if (($3 & 262144 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP8[$this | 0] = 1;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodZeroINS_5types15TypeCompartmentEEEvPT_($t) {
  var $1 = $t | 0;
  _memset($1, 0, 76, 1);
  return;
}

function __ZN2js5types15TypeCompartment13newTypeObjectEP9JSContextP8JSScript10JSProtoKeyP8JSObjectb($cx, $key, $proto, $unknown) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z10NewGCThingIN2js5types10TypeObjectEEPT_P9JSContextNS0_2gc9AllocKindEj($cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = ($key | 0) == 2;
    __ZN2js5types10TypeObjectC1EP8JSObjectbb($1, $proto, $4, $unknown);
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $5 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $1 + 12 | 0;
    var $9 = HEAP32[$7 >> 2] | 33488904;
    HEAP32[$7 >> 2] = $9;
    var $_0 = $1;
    __label__ = 5;
    break;
   case 4:
    __ZN2js5types10TypeObject15setFlagsFromKeyEP9JSContext10JSProtoKey($1, $cx, $key);
    var $_0 = $1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z10NewGCThingIN2js5types10TypeObjectEEPT_P9JSContextNS0_2gc9AllocKindEj($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$cx + 56 >> 2] + 8 | 0;
    var $4 = __ZN2js2gc10ArenaLists20allocateFromFreeListENS0_9AllocKindEj($3, 15, 32);
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $9 = $4;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js2gc10ArenaLists14refillFreeListEP9JSContextNS0_9AllocKindE($cx, 15);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObject15setFlagsFromKeyEP9JSContext10JSProtoKey($this, $cx, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($key | 0) == 3) {
      __label__ = 2;
      break;
    } else if (($key | 0) == 2 || ($key | 0) == 1) {
      var $flags_0 = 458752;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $flags_0 = 262144;
    __label__ = 4;
    break;
   case 3:
    var $flags_0 = 196608;
    __label__ = 4;
    break;
   case 4:
    var $flags_0;
    var $this_idx_val = HEAP32[$this + 12 >> 2];
    var $4 = __ZN2js5types10TypeObject11hasAllFlagsEj($this_idx_val, $flags_0);
    if ($4) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js5types10TypeObject8setFlagsEP9JSContextj($this, $cx, $flags_0);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15TypeCompartment27newAllocationSiteTypeObjectEP9JSContextRKNS0_17AllocationSiteKeyE($this, $cx, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $p = __stackBase__ + 8;
    var $proto = __stackBase__ + 16;
    var $res = __stackBase__ + 20;
    var $untrap = __stackBase__ + 24;
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    var $1 = $this + 28 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $14 = $2;
      __label__ = 6;
      break;
    }
   case 2:
    var $5 = __ZN9JSContext4new_IN2js7HashMapINS1_5types17AllocationSiteKeyEPNS3_10TypeObjectES4_NS1_17SystemAllocPolicyEEEEEPT_v($cx);
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE4initEj($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = HEAP32[$1 >> 2];
    __label__ = 6;
    break;
   case 5:
    var $12 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($12, $cx);
    var $_1 = 0;
    __label__ = 15;
    break;
   case 6:
    var $14;
    __ZNK2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE12lookupForAddERKS2_($p, $14, $key);
    var $15 = $key | 0;
    var $_idx2_val_idx_val = HEAP32[HEAP32[HEAP32[$15 >> 2] + 100 >> 2] + 8 >> 2];
    var $17 = __ZNK8JSScript6globalEv($_idx2_val_idx_val);
    var $19 = $key + 4 | 0;
    var $21 = HEAPU32[$19 >> 2] >>> 24;
    var $22 = $cx;
    var $23 = $17;
    var $24 = $proto;
    var $25 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($22, $23, $21, $24, 0);
    if (($25 | 0) == 0) {
      var $_1 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $29 = HEAPU32[$19 >> 2] >>> 24;
    var $30 = HEAP32[$proto >> 2];
    var $31 = __ZN2js5types15TypeCompartment13newTypeObjectEP9JSContextP8JSScript10JSProtoKeyP8JSObjectb($cx, $29, $30, 0);
    HEAP32[$res >> 2] = $31;
    if (($31 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $36 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($36, $cx);
    var $_1 = 0;
    __label__ = 15;
    break;
   case 9:
    var $38 = HEAP32[$15 >> 2];
    var $40 = HEAPU32[$38 >> 2];
    var $42 = HEAP32[$19 >> 2] & 16777215;
    var $43 = $40 + $42 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $38, $43);
    if (HEAP8[$43] << 24 >> 24 == 91) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $47 = HEAP32[$15 >> 2];
    var $55 = (HEAPU8[$42 + ($40 + 1) | 0] & 255) << 8 | HEAPU8[$42 + ($40 + 2) | 0] & 255;
    var $_idx_val = HEAP32[$47 + 4 >> 2];
    var $_idx1_val = HEAP8[$47 + 16 | 0];
    var $56 = __ZN8JSScript9getObjectEj($_idx_val, $_idx1_val, $55);
    var $57 = __ZN2js5types10TypeObject21addDefinitePropertiesEP9JSContextP8JSObject($31, $cx, $56);
    if ($57) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 11:
    var $59 = HEAP32[$1 >> 2];
    var $60 = __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKS4_($59, $p, $key, $res);
    if ($60) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $64 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($64, $cx);
    var $_0 = 0;
    __label__ = 14;
    break;
   case 13:
    var $_0 = HEAP32[$res >> 2];
    __label__ = 14;
    break;
   case 14:
    var $_0;
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_1 = $_0;
    __label__ = 15;
    break;
   case 15:
    var $_1;
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types15TypeCompartment27newAllocationSiteTypeObjectEP9JSContextRKNS0_17AllocationSiteKeyE["X"] = 1;

function __ZN9JSContext4new_IN2js7HashMapINS1_5types17AllocationSiteKeyEPNS3_10TypeObjectES4_NS1_17SystemAllocPolicyEEEEEPT_v($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 24);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC1ES5_($4);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj($1);
  return $2;
}

function __ZNK2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZN2js5types10TypeObject21addDefinitePropertiesEP9JSContextP8JSObject($this, $cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $this_idx_val = HEAP32[$this + 12 >> 2];
    var $1 = __ZN2js5types10TypeObject17unknownPropertiesEv($this_idx_val);
    if ($1) {
      var $_1 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    var $obj_idx_val = HEAP32[$obj >> 2];
    var $3 = __ZNK8JSObject12lastPropertyEv($obj_idx_val);
    var $obj_idx1 = $obj + 8 | 0;
    var $shape_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $shape_0;
    var $6 = HEAP32[$shape_0 + 12 >> 2];
    var $7 = _JSID_IS_EMPTY($6);
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 4:
    var $10 = __ZN2js5types10MakeTypeIdEP9JSContexti($cx, $6);
    var $11 = _JSID_IS_VOID1691($10);
    if (($11 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $14 = $shape_0 + 24 | 0;
    var $15 = HEAPU32[$14 >> 2];
    var $obj_idx1_val = HEAP32[$obj_idx1 >> 2];
    var $16 = __ZN8JSObject11isFixedSlotEj($obj_idx1_val, $15);
    if ($16 & $15 >>> 0 < 16) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $19 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($this, $cx, $10, 1);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = HEAP32[$14 >> 2];
    __ZN2js5types7TypeSet11setDefiniteEj($19, $22);
    __label__ = 8;
    break;
   case 8:
    var $shape_0_idx_val = HEAP32[$shape_0 + 32 >> 2];
    var $24 = __ZNK2js5Shape8previousEv($shape_0_idx_val);
    var $shape_0 = $24;
    __label__ = 3;
    break;
   case 9:
    var $_0;
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    var $_1 = $_0;
    __label__ = 10;
    break;
   case 10:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKS4_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS7_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$pentry >> 2];
    var $5 = $k;
    var $6 = $4;
    var $7$0 = HEAP32[$5 >> 2];
    var $7$1 = HEAP32[$5 + 4 >> 2];
    var $st$7$0 = $6 | 0;
    HEAP32[$st$7$0 >> 2] = $7$0;
    var $st$7$1 = $6 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $7$1;
    var $8 = HEAP32[$v >> 2];
    var $9 = $4 + 8 | 0;
    HEAP32[$9 >> 2] = $8;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10UseNewTypeEP9JSContextP8JSScriptPh($cx, $script, $pc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $untrap = __stackBase__;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $script, $pc);
    if (HEAP8[$pc] << 24 >> 24 == 82) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = $pc + 3 | 0;
    if (HEAP8[$4] << 24 >> 24 == 54) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZL9GetAtomIdP9JSContextP8JSScriptPKhj($cx, $script, $4);
    var $cx_idx_val_idx_val = HEAP32[HEAP32[$cx + 52 >> 2] + 210200 >> 2];
    var $9 = __ZL12id_prototypeP9JSContext($cx_idx_val_idx_val);
    if (($8 | 0) == ($9 | 0)) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9GetAtomIdP9JSContextP8JSScriptPKhj($cx, $script, $pc) {
  var $1 = _js_GetIndexFromBytecode($script, $pc, 0);
  var $script_idx_val = HEAP32[$script + 56 >> 2];
  var $2 = __ZN8JSScript7getAtomEj($script_idx_val, $1);
  var $3 = __ZL12ATOM_TO_JSIDP6JSAtom1694($2);
  var $4 = __ZN2js5types10MakeTypeIdEP9JSContexti($cx, $3);
  return $4;
}

function __ZL12id_prototypeP9JSContext($cx_0_11_val_0_70_14_val) {
  var $1 = $cx_0_11_val_0_70_14_val | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom1694($1);
  return $2;
}

function __ZN2js5types15TypeCompartment16growPendingArrayEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 48 | 0;
    var $3 = HEAP32[$1 >> 2] << 1;
    var $4 = __ZN2jsL3MaxIjEET_S1_S1_1674($3);
    var $5 = $4 * 12 | 0;
    var $6 = __ZN2js11OffTheBooks7calloc_Ej($5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($11, $cx);
    __label__ = 4;
    break;
   case 3:
    var $13 = $6;
    var $14 = $this + 40 | 0;
    var $16 = HEAP32[$14 >> 2];
    var $19 = HEAP32[$this + 44 >> 2] * 12 | 0;
    _memcpy($6, $16, $19, 1);
    var $21 = HEAP32[$14 >> 2];
    __ZN9JSContext5free_EPv($21);
    HEAP32[$14 >> 2] = $13;
    HEAP32[$1 >> 2] = $4;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15TypeCompartment24processPendingRecompilesEP9JSContext($this) {
  var $1 = $this + 12 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$1 >> 2] = 0;
  __ZN9JSContext7delete_IN2js6VectorIP8JSScriptLj0ENS1_15TempAllocPolicyEEEEEvPT_($2);
  return;
}

function __ZN9JSContext7delete_IN2js6VectorIP8JSScriptLj0ENS1_15TempAllocPolicyEEEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEED1Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15TypeCompartment9nukeTypesEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN9JSContext5free_EPv($5);
    HEAP32[$1 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    HEAP8[$this | 0] = 0;
    var $8 = $cx + 52 | 0;
    var $9 = HEAP32[$8 >> 2];
    var $cl_01 = HEAP32[$9 + 144140 >> 2];
    if (($cl_01 | 0) == ($9 + 144140 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $cl_02 = $cl_01;
      __label__ = 4;
      break;
    }
   case 4:
    var $cl_02;
    var $13 = __ZN9JSContext13fromLinkFieldEP10JSCListStr($cl_02);
    var $16 = $13;
    var $17 = HEAP32[$13 + 56 >> 2];
    __ZN9JSContext14setCompartmentEP13JSCompartment($16, $17);
    var $cl_0 = HEAP32[$cl_02 >> 2];
    if (($cl_0 | 0) == (HEAP32[$8 >> 2] + 144140 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $cl_02 = $cl_0;
      __label__ = 4;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17ObjectStateChangeP9JSContextPN2js5types10TypeObjectEbb($cx, $object, $markingUnknown, $force) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $object_idx = $object + 12 | 0;
    var $object_idx_val = HEAP32[$object_idx >> 2];
    var $1 = __ZN2js5types10TypeObject17unknownPropertiesEv($object_idx_val);
    if ($1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $object_idx2_val = HEAP32[$object + 24 >> 2];
    var $3 = __ZN2js5types10TypeObject16maybeGetPropertyEP9JSContexti($object_idx_val, $object_idx2_val, 4);
    if ($markingUnknown) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = $object_idx_val | 33488896;
    HEAP32[$object_idx >> 2] = $5;
    __label__ = 4;
    break;
   case 4:
    if (($3 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $constraint_01 = HEAP32[$3 + 8 >> 2];
    if (($constraint_01 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $constraint_02 = $constraint_01;
      __label__ = 6;
      break;
    }
   case 6:
    var $constraint_02;
    var $14 = HEAP32[HEAP32[$constraint_02 >> 2] + 8 >> 2];
    FUNCTION_TABLE[$14]($constraint_02, $cx, $object, $force);
    var $constraint_0 = HEAP32[$constraint_02 + 4 >> 2];
    if (($constraint_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $constraint_02 = $constraint_0;
      __label__ = 6;
      break;
    }
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE6lengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZN2js7analyze14ScriptAnalysis12ranInferenceEv($this_0_9_val) {
  return ($this_0_9_val & 1) << 24 >> 24 != 0;
}

function __ZN2js7analyzeL11ExtendedDefEPh1682($pc_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $pc_val & 255;
    if (($1 | 0) == 85 || ($1 | 0) == 97 || ($1 | 0) == 98 || ($1 | 0) == 99 || ($1 | 0) == 100 || ($1 | 0) == 87 || ($1 | 0) == 132 || ($1 | 0) == 140 || ($1 | 0) == 223 || ($1 | 0) == 101 || ($1 | 0) == 102 || ($1 | 0) == 103 || ($1 | 0) == 104) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5types4TypeeqES1_($this_0_0_val, $o_0) {
  return ($this_0_0_val | 0) == ($o_0 | 0);
}

function __ZN8JSScript11hasAnalysisEv($this_0_32_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_32_val | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = (HEAP32[$this_0_32_val >> 2] | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15TypeCompartment11compartmentEv($this) {
  return $this - 376 | 0;
}

function __ZN2js5types15TypeCompartment15markSetsUnknownEP9JSContextPNS0_10TypeObjectE($cx, $target) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 148;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $pending = __stackBase__ + 8;
    var $1 = __stackBase__ + 32;
    var $i = __stackBase__ + 36;
    var $2 = __stackBase__ + 76;
    var $3 = __stackBase__ + 80;
    var $i3 = __stackBase__ + 84;
    var $4 = __stackBase__ + 124;
    var $5 = __stackBase__ + 128;
    var $untrap = __stackBase__ + 132;
    var $6 = __stackBase__ + 140;
    var $7 = __stackBase__ + 144;
    var $8 = $target + 12 | 0;
    var $10 = HEAP32[$8 >> 2] | 8;
    HEAP32[$8 >> 2] = $10;
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
    var $_014_val = HEAP32[$1 >> 2];
    __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEEC1ES4_($pending, $_014_val);
    var $11 = $cx + 56 | 0;
    var $12 = HEAP32[$11 >> 2];
    __ZN2js2gc8CellIterC1EP9JSContextP13JSCompartmentNS0_9AllocKindE($i, $12, 15);
    var $13 = $i | 0;
    var $_idx3 = $i + 28 | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $14 = __ZNK2js2gc12CellIterImpl4doneEv($_idx3_val);
    if ($14) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_013 = $2 | 0;
    var $_idx5_val = $_idx3_val;
    __label__ = 5;
    break;
   case 3:
    __ZN2js2gc8CellIterD1Ev($i);
    var $pending_idx15 = $pending + 8 | 0;
    var $pending_idx15_val = HEAP32[$pending_idx15 >> 2];
    var $15 = __ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE6lengthEv($pending_idx15_val);
    if (($15 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $pending_idx16 = $pending + 4 | 0;
    var $_010 = $3 | 0;
    var $i2_09 = 0;
    __label__ = 14;
    break;
   case 5:
    var $_idx5_val;
    var $17 = __ZNK2js2gc12CellIterImpl3getINS_5types10TypeObjectEEEPT_v($_idx5_val);
    var $_idx6 = $17 + 12 | 0;
    var $_idx6_val = HEAP32[$_idx6 >> 2];
    var $18 = __ZN2js5types10TypeObject16getPropertyCountEv($_idx6_val);
    if (($18 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx8 = $17 + 24 | 0;
    var $i1_013 = 0;
    var $_idx7_val = $_idx6_val;
    __label__ = 7;
    break;
   case 7:
    var $_idx7_val;
    var $i1_013;
    var $_idx8_val = HEAP32[$_idx8 >> 2];
    var $20 = __ZN2js5types10TypeObject11getPropertyEj($_idx7_val, $_idx8_val, $i1_013);
    if (($20 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $23 = $20 + 4 | 0;
    __ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE($2, $target);
    var $_013_val = HEAP32[$_013 >> 2];
    var $24 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($23, $_013_val);
    if ($24) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $26 = __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_($pending, $23);
    if ($26) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $29 = HEAP32[$11 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($29, $cx);
    __label__ = 11;
    break;
   case 11:
    var $31 = $i1_013 + 1 | 0;
    if (($31 | 0) == ($18 | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $i1_013 = $31;
    var $_idx7_val = HEAP32[$_idx6 >> 2];
    __label__ = 7;
    break;
   case 13:
    __ZN2js2gc12CellIterImpl4nextEv($13);
    var $_idx2_val = HEAPU32[$_idx3 >> 2];
    var $32 = __ZNK2js2gc12CellIterImpl4doneEv($_idx2_val);
    if ($32) {
      __label__ = 3;
      break;
    } else {
      var $_idx5_val = $_idx2_val;
      __label__ = 5;
      break;
    }
   case 14:
    var $i2_09;
    var $pending_idx16_val = HEAP32[$pending_idx16 >> 2];
    var $33 = __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEEixEj($pending_idx16_val, $i2_09);
    var $34 = HEAP32[$33 >> 2];
    __ZN2js5types4Type13AnyObjectTypeEv($3);
    var $_010_val = HEAP32[$_010 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($34, $cx, $_010_val);
    var $35 = $i2_09 + 1 | 0;
    var $pending_idx_val = HEAP32[$pending_idx15 >> 2];
    var $36 = __ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE6lengthEv($pending_idx_val);
    if ($35 >>> 0 < $36 >>> 0) {
      var $i2_09 = $35;
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $38 = HEAP32[$11 >> 2];
    __ZN2js2gc8CellIterC1EP9JSContextP13JSCompartmentNS0_9AllocKindE($i3, $38, 13);
    var $39 = $i3 | 0;
    var $_idx1 = $i3 + 28 | 0;
    var $_idx1_val = HEAPU32[$_idx1 >> 2];
    var $40 = __ZNK2js2gc12CellIterImpl4doneEv($_idx1_val);
    if ($40) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $_011 = $6 | 0;
    var $_0 = $7 | 0;
    var $_012 = $4 | 0;
    var $_09 = $5 | 0;
    var $_idx4_val = $_idx1_val;
    __label__ = 18;
    break;
   case 17:
    __ZN2js2gc8CellIterD1Ev($i3);
    __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEED1Ev($pending);
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    STACKTOP = __stackBase__;
    return;
   case 18:
    var $_idx4_val;
    var $41 = __ZNK2js2gc12CellIterImpl3getI8JSScriptEEPT_v($_idx4_val);
    var $42 = $41 + 100 | 0;
    var $43 = HEAPU32[$42 >> 2];
    if (($43 | 0) == 0) {
      var $_idx20_val = $43;
      __label__ = 24;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $46 = __ZN2js5types10TypeScript11NumTypeSetsEP8JSScript($41);
    var $47 = __ZN2js5types10TypeScript9typeArrayEv($43);
    if (($46 | 0) == 0) {
      var $_idx20_val = $43;
      __label__ = 24;
      break;
    } else {
      var $i5_01 = 0;
      __label__ = 20;
      break;
    }
   case 20:
    var $i5_01;
    var $49 = $47 + $i5_01 * 12 | 0;
    __ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE($4, $target);
    var $_012_val = HEAP32[$_012 >> 2];
    var $50 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($49, $_012_val);
    if ($50) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    __ZN2js5types4Type13AnyObjectTypeEv($5);
    var $_09_val = HEAP32[$_09 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($49, $cx, $_09_val);
    __label__ = 22;
    break;
   case 22:
    var $53 = $i5_01 + 1 | 0;
    if (($53 | 0) == ($46 | 0)) {
      __label__ = 23;
      break;
    } else {
      var $i5_01 = $53;
      __label__ = 20;
      break;
    }
   case 23:
    var $_idx20_val = HEAP32[$42 >> 2];
    __label__ = 24;
    break;
   case 24:
    var $_idx20_val;
    var $54 = __ZN8JSScript11hasAnalysisEv($_idx20_val);
    if ($54) {
      __label__ = 25;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 25:
    var $_idx20_val_idx_val = HEAP32[$_idx20_val >> 2];
    var $56 = __ZN8JSScript8analysisEv($_idx20_val_idx_val);
    var $_idx21_val = HEAP8[$56 + 23 | 0];
    var $57 = __ZN2js7analyze14ScriptAnalysis12ranInferenceEv($_idx21_val);
    if ($57) {
      __label__ = 26;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 26:
    var $58 = $41 + 8 | 0;
    var $59 = HEAP32[$58 >> 2];
    if (($59 | 0) == 0) {
      __label__ = 38;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $61 = $41 | 0;
    var $i6_06 = 0;
    var $63 = $59;
    var $_idx19_val_idx_val = $_idx20_val_idx_val;
    __label__ = 28;
    break;
   case 28:
    var $_idx19_val_idx_val;
    var $63;
    var $i6_06;
    var $64 = __ZN8JSScript8analysisEv($_idx19_val_idx_val);
    var $_idx22_val = HEAP32[$64 + 4 >> 2];
    var $65 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEj($_idx22_val, $i6_06);
    if (($65 | 0) == 0) {
      var $90 = $63;
      __label__ = 36;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $69 = HEAP32[$61 >> 2] + $i6_06 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $41, $69);
    if ((HEAP32[_js_CodeSpec + ((HEAPU8[$69] & 255) << 3) + 4 >> 2] & 134217728 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 30:
    var $77 = __ZN2js7analyzeL11GetDefCountEP8JSScriptj1681($41, $i6_06);
    var $_val = HEAP8[$69];
    var $78 = __ZN2js7analyzeL11ExtendedDefEPh1682($_val);
    var $79 = $78 & 1;
    if (($79 | 0) == (-$77 | 0)) {
      __label__ = 35;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $81 = $77 + $79 | 0;
    var $j_03 = 0;
    __label__ = 32;
    break;
   case 32:
    var $j_03;
    var $_idx18_val_idx_val = HEAP32[HEAP32[$42 >> 2] >> 2];
    var $83 = __ZN8JSScript8analysisEv($_idx18_val_idx_val);
    var $_idx24_val = HEAP32[$83 + 4 >> 2];
    var $_idx23_val_idx_val = HEAP32[HEAP32[$83 >> 2] >> 2];
    var $84 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEPKhj($_idx23_val_idx_val, $_idx24_val, $69, $j_03);
    __ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE($6, $target);
    var $_011_val = HEAP32[$_011 >> 2];
    var $85 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($84, $_011_val);
    if ($85) {
      __label__ = 33;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 33:
    __ZN2js5types4Type13AnyObjectTypeEv($7);
    var $_0_val = HEAP32[$_0 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($84, $cx, $_0_val);
    __label__ = 34;
    break;
   case 34:
    var $88 = $j_03 + 1 | 0;
    if (($88 | 0) == ($81 | 0)) {
      __label__ = 35;
      break;
    } else {
      var $j_03 = $88;
      __label__ = 32;
      break;
    }
   case 35:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $90 = HEAP32[$58 >> 2];
    __label__ = 36;
    break;
   case 36:
    var $90;
    var $91 = $i6_06 + 1 | 0;
    if ($91 >>> 0 < $90 >>> 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 37:
    var $i6_06 = $91;
    var $63 = $90;
    var $_idx19_val_idx_val = HEAP32[HEAP32[$42 >> 2] >> 2];
    __label__ = 28;
    break;
   case 38:
    __ZN2js2gc12CellIterImpl4nextEv($39);
    var $_idx_val = HEAPU32[$_idx1 >> 2];
    var $93 = __ZNK2js2gc12CellIterImpl4doneEv($_idx_val);
    if ($93) {
      __label__ = 17;
      break;
    } else {
      var $_idx4_val = $_idx_val;
      __label__ = 18;
      break;
    }
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types15TypeCompartment15markSetsUnknownEP9JSContextPNS0_10TypeObjectE["X"] = 1;

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEEC1ES4_($this, $ap_01) {
  __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEEC2ES4_($this, $ap_01);
  return;
}

function __ZN2js2gc8CellIterC1EP9JSContextP13JSCompartmentNS0_9AllocKindE($this, $comp, $kind) {
  __ZN2js2gc8CellIterC2EP9JSContextP13JSCompartmentNS0_9AllocKindE($this, $comp, $kind);
  return;
}

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE13growStorageByEj($this);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc8CellIterD1Ev($this) {
  __ZN2js2gc8CellIterD2Ev($this);
  return;
}

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEEixEj($this_0_1_val, $i) {
  var $1 = __ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE5beginEv($this_0_1_val);
  return $1 + ($i << 2) | 0;
}

function __ZN2js5types10TypeScript11NumTypeSetsEP8JSScript($script) {
  var $3 = HEAPU16[$script + 22 >> 1] & 65535;
  var $4 = __ZN2js7analyzeL10TotalSlotsEP8JSScript1710($script);
  return $3 + $4 | 0;
}

function __ZN2js7analyzeL11GetDefCountEP8JSScriptj1681($script, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$script >> 2];
    var $3 = $2 + $offset | 0;
    var $5 = HEAPU8[$3] & 255;
    var $7 = HEAPU8[_js_CodeSpec + ($5 << 3) + 2 | 0];
    var $8 = $7 << 24 >> 24;
    if ($7 << 24 >> 24 == -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = _js_GetEnterBlockStackDefs($script, $3);
    var $_0 = $11;
    __label__ = 7;
    break;
   case 3:
    if (($5 | 0) == 176) {
      __label__ = 4;
      break;
    } else if (($5 | 0) == 133) {
      __label__ = 5;
      break;
    } else if (($5 | 0) == 68 || ($5 | 0) == 144 || ($5 | 0) == 69 || ($5 | 0) == 145) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $_0 = 2;
    __label__ = 7;
    break;
   case 5:
    var $_0 = (HEAPU8[$offset + ($2 + 1) | 0] & 255) + 1 | 0;
    __label__ = 7;
    break;
   case 6:
    var $_0 = $8;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis11pushedTypesEPKhj($this_0_0_val_0_0_val, $this_0_1_val, $pc, $which) {
  var $3 = $pc - $this_0_0_val_0_0_val | 0;
  var $4 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEjj($this_0_1_val, $3, $which);
  return $4;
}

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7analyze14ScriptAnalysis14addTypeBarrierEP9JSContextPKhPNS_5types7TypeSetENS6_4TypeE($this_0_0_val, $this_0_1_val, $cx, $pc, $target, $type_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $type = __stackBase__;
    HEAP32[$type >> 2] = $type_0;
    var $1 = STACKTOP;
    STACKTOP += 4;
    var $2 = STACKTOP;
    STACKTOP += 4;
    var $3 = STACKTOP;
    STACKTOP += 4;
    HEAP32[$1 >> 2] = $target;
    var $this_idx_val_idx_val = HEAP32[$this_0_0_val >> 2];
    var $4 = __ZN2js7analyze14ScriptAnalysis7getCodeEPKh($this_idx_val_idx_val, $this_0_1_val, $pc);
    var $5 = __ZNK2js5types4Type9isUnknownEv($type_0);
    if ($5) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK2js5types4Type11isAnyObjectEv($type_0);
    if ($7) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZNK2js5types4Type8isObjectEv($type_0);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $target_idx_val = HEAP32[$target >> 2];
    var $11 = __ZN2js5types7TypeSet14getObjectCountEv($target_idx_val);
    if ($11 >>> 0 > 9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($target, $cx, $type_0);
    __label__ = 16;
    break;
   case 6:
    var $15 = $4 + 40 | 0;
    if ((HEAP32[$15 >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $barrier_0_in = $15;
      __label__ = 10;
      break;
    }
   case 7:
    if ((HEAP8[$this_0_0_val + 37 | 0] & 4) << 24 >> 24 == 0) {
      var $barrier_0_in = $15;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx_val_idx_val = HEAP32[HEAP32[$this_0_0_val + 100 >> 2] + 4 >> 2];
    var $24 = __ZNK8JSScript8functionEv($_idx_val_idx_val);
    var $_idx3_val = HEAP32[$24 + 8 >> 2];
    var $25 = __ZNK8JSObject11hasLazyTypeEv($_idx3_val);
    if ($25) {
      var $barrier_0_in = $15;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_idx4_val = HEAP32[$24 + 36 >> 2];
    var $27 = __ZNK8JSObject4typeEv($_idx4_val);
    __ZL17ObjectStateChangeP9JSContextPN2js5types10TypeObjectEbb($cx, $27, 0, 1);
    var $barrier_0_in = $15;
    __label__ = 10;
    break;
   case 10:
    var $barrier_0_in;
    var $barrier_0 = HEAP32[$barrier_0_in >> 2];
    if (($barrier_0 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    if ((HEAP32[$barrier_0 + 4 >> 2] | 0) == ($target | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $_idx6_val = HEAP32[$barrier_0 + 8 >> 2];
    var $34 = __ZNK2js5types4TypeeqES1_($_idx6_val, $type_0);
    if ($34) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    if ((HEAP32[$barrier_0 + 12 >> 2] | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $barrier_0_in = $barrier_0 | 0;
    __label__ = 10;
    break;
   case 15:
    var $44 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    HEAP32[$2 >> 2] = 0;
    HEAP32[$3 >> 2] = 2;
    var $45 = __ZN2js8ArenaNewINS_5types11TypeBarrierEPNS1_7TypeSetENS1_4TypeEP8JSObjectiEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_($44, $1, $type, $2, $3);
    var $46 = HEAP32[$15 >> 2];
    var $47 = $45 | 0;
    HEAP32[$47 >> 2] = $46;
    HEAP32[$15 >> 2] = $45;
    __label__ = 16;
    break;
   case 16:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis14addTypeBarrierEP9JSContextPKhPNS_5types7TypeSetENS6_4TypeE["X"] = 1;

function __ZN2js8ArenaNewINS_5types11TypeBarrierEPNS1_7TypeSetENS1_4TypeEP8JSObjectiEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_($pool, $a, $b, $c, $d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 20 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $30 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $26 = HEAP32[$b >> 2];
    var $27 = HEAP32[$c >> 2];
    var $28 = HEAP32[$d >> 2];
    __ZN2js5types11TypeBarrierC1EPNS0_7TypeSetENS0_4TypeEP8JSObjecti($23, $24, $26, $27, $28);
    var $30 = $23;
    __label__ = 6;
    break;
   case 6:
    var $30;
    return $30;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis23addSingletonTypeBarrierEP9JSContextPKhPNS_5types7TypeSetEP8JSObjecti($this_0_0_val, $this_0_1_val, $cx, $pc, $target, $singleton, $singletonId) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 12;
    HEAP32[$1 >> 2] = $target;
    HEAP32[$2 >> 2] = $singleton;
    HEAP32[$3 >> 2] = $singletonId;
    var $this_idx_val_idx_val = HEAP32[$this_0_0_val >> 2];
    var $5 = __ZN2js7analyze14ScriptAnalysis7getCodeEPKh($this_idx_val_idx_val, $this_0_1_val, $pc);
    var $6 = $5 + 40 | 0;
    if ((HEAP32[$6 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    if ((HEAP8[$this_0_0_val + 37 | 0] & 4) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val_idx_val = HEAP32[HEAP32[$this_0_0_val + 100 >> 2] + 4 >> 2];
    var $15 = __ZNK8JSScript8functionEv($_idx_val_idx_val);
    var $_idx1_val = HEAP32[$15 + 8 >> 2];
    var $16 = __ZNK8JSObject11hasLazyTypeEv($_idx1_val);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx2_val = HEAP32[$15 + 36 >> 2];
    var $18 = __ZNK8JSObject4typeEv($_idx2_val);
    __ZL17ObjectStateChangeP9JSContextPN2js5types10TypeObjectEbb($cx, $18, 0, 1);
    __label__ = 5;
    break;
   case 5:
    var $22 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    __ZN2js5types4Type13UndefinedTypeEv($4);
    var $23 = __ZN2js8ArenaNewINS_5types11TypeBarrierEPNS1_7TypeSetENS1_4TypeEP8JSObjectiEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_($22, $1, $4, $2, $3);
    var $24 = HEAP32[$6 >> 2];
    var $25 = $23 | 0;
    HEAP32[$25 >> 2] = $24;
    HEAP32[$6 >> 2] = $23;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15InferSpewActiveN2js5types11SpewChannelE() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU8[__ZZL15InferSpewActiveN2js5types11SpewChannelEE7checked_b]) {
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP8[__ZZL15InferSpewActiveN2js5types11SpewChannelEE7checked_b] = 1;
    __ZN2jsL12PodArrayZeroIbLj2EEEvRAT0__T_();
    var $2 = _getenv(STRING_TABLE.__str741644 | 0);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = _strstr($2, STRING_TABLE.__str751645 | 0);
    if (($5 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP8[__ZZL15InferSpewActiveN2js5types11SpewChannelEE6active | 0] = 1;
    __label__ = 5;
    break;
   case 5:
    var $9 = _strstr($2, STRING_TABLE.__str761646 | 0);
    if (($9 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    HEAP8[__ZZL15InferSpewActiveN2js5types11SpewChannelEE6active + 1 | 0] = 1;
    __label__ = 7;
    break;
   case 7:
    var $13 = _strstr($2, STRING_TABLE.__str771647 | 0);
    if (($13 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP16[__ZZL15InferSpewActiveN2js5types11SpewChannelEE6active >> 1] = 257;
    __label__ = 9;
    break;
   case 9:
    var $_0 = (HEAP8[__ZZL15InferSpewActiveN2js5types11SpewChannelEE6active + 1 | 0] & 1) << 24 >> 24 != 0;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis10printTypesEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $untrap = __stackBase__ + 8;
    __ZN2js7analyze17AutoEnterAnalysisC1EP9JSContext($enter, $cx);
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $2;
    var $4 = __ZNK2js2gc4Cell11compartmentEv($3);
    if ((HEAP32[$2 + 8 >> 2] | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $4 + 448 | 0;
    var $this_idx = $this + 4 | 0;
    var $offset_06 = 0;
    var $9 = $2;
    __label__ = 3;
    break;
   case 3:
    var $9;
    var $offset_06;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $10 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEj($this_idx_val, $offset_06);
    if (($10 | 0) == 0) {
      var $66 = $9;
      __label__ = 17;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = HEAP32[$9 >> 2] + $offset_06 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $9, $15);
    if ((HEAP32[_js_CodeSpec + ((HEAPU8[$15] & 255) << 3) + 4 >> 2] & 134217728 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 5:
    var $23 = HEAP32[$1 >> 2];
    var $24 = __ZN2js7analyzeL11GetDefCountEP8JSScriptj1681($23, $offset_06);
    if (($24 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      var $i_05 = 0;
      __label__ = 6;
      break;
    }
   case 6:
    var $i_05;
    var $this_idx2_val = HEAP32[$this_idx >> 2];
    var $26 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEjj($this_idx2_val, $offset_06, $i_05);
    var $_idx_val = HEAPU32[$26 >> 2];
    var $27 = __ZNK2js5types7TypeSet7unknownEv($_idx_val);
    if ($27) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $30 = HEAP32[$8 >> 2] + 1 | 0;
    HEAP32[$8 >> 2] = $30;
    __label__ = 15;
    break;
   case 8:
    var $32 = __ZNK2js5types7TypeSet10hasAnyFlagEj($_idx_val, 128);
    if ($32) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $34 = __ZN2js5types7TypeSet14getObjectCountEv($_idx_val);
    if (($34 | 0) == 0) {
      var $typeCount_1_ph = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $typeCount_1_ph = 1;
    __label__ = 11;
    break;
   case 11:
    var $typeCount_1_ph;
    var $37 = __ZNK2js5types7TypeSet10hasAnyFlagEj($_idx_val, 1);
    var $_typeCount_1 = ($37 & 1) + $typeCount_1_ph | 0;
    var $39 = __ZNK2js5types7TypeSet10hasAnyFlagEj($_idx_val, 2);
    var $_typeCount_1_1 = ($39 & 1) + $_typeCount_1 | 0;
    var $41 = __ZNK2js5types7TypeSet10hasAnyFlagEj($_idx_val, 4);
    var $_typeCount_1_2 = ($41 & 1) + $_typeCount_1_1 | 0;
    var $43 = __ZNK2js5types7TypeSet10hasAnyFlagEj($_idx_val, 8);
    var $_typeCount_1_3 = ($43 & 1) + $_typeCount_1_2 | 0;
    var $45 = __ZNK2js5types7TypeSet10hasAnyFlagEj($_idx_val, 16);
    var $_typeCount_1_4 = ($45 & 1) + $_typeCount_1_3 | 0;
    var $47 = __ZNK2js5types7TypeSet10hasAnyFlagEj($_idx_val, 32);
    var $_typeCount_1_5 = ($47 & 1) + $_typeCount_1_4 | 0;
    var $49 = __ZNK2js5types7TypeSet10hasAnyFlagEj($_idx_val, 64);
    var $_typeCount_11 = ($45 << 31 >> 31) + (($49 & 1) + $_typeCount_1_5) | 0;
    if ($_typeCount_11 >>> 0 > 4) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $55 = HEAP32[$8 >> 2] + 1 | 0;
    HEAP32[$8 >> 2] = $55;
    __label__ = 15;
    break;
   case 13:
    if (($_typeCount_11 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $60 = $4 + 432 + ($_typeCount_11 - 1 << 2) | 0;
    var $62 = HEAP32[$60 >> 2] + 1 | 0;
    HEAP32[$60 >> 2] = $62;
    __label__ = 15;
    break;
   case 15:
    var $64 = $i_05 + 1 | 0;
    if (($64 | 0) == ($24 | 0)) {
      __label__ = 16;
      break;
    } else {
      var $i_05 = $64;
      __label__ = 6;
      break;
    }
   case 16:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $66 = HEAP32[$1 >> 2];
    __label__ = 17;
    break;
   case 17:
    var $66;
    var $67 = $offset_06 + 1 | 0;
    if ($67 >>> 0 < HEAPU32[$66 + 8 >> 2] >>> 0) {
      var $offset_06 = $67;
      var $9 = $66;
      __label__ = 3;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZN2js7analyze17AutoEnterAnalysisD1Ev($enter);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis10printTypesEP9JSContext["X"] = 1;

function __ZN2js5types15TypeCompartment12fixArrayTypeEP9JSContextP8JSObject($this, $cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $type = __stackBase__ + 8;
    var $ntype = __stackBase__ + 12;
    var $key = __stackBase__ + 16;
    var $p = __stackBase__ + 24;
    var $1 = __stackBase__ + 32;
    var $objType = __stackBase__ + 40;
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    var $2 = $this + 32 | 0;
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $6 = __ZN9JSContext4new_IN2js7HashMapINS1_5types13ArrayTableKeyEPNS3_10TypeObjectES4_NS1_17SystemAllocPolicyEEEEEPT_v($cx);
    HEAP32[$2 >> 2] = $6;
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE4initEj($6);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$2 >> 2] = 0;
    var $13 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($13, $cx);
    __label__ = 20;
    break;
   case 5:
    var $15 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
    if (($15 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $obj_idx1 = $obj + 32 | 0;
    var $obj_idx1_val = HEAP32[$obj_idx1 >> 2];
    var $18 = __ZN8JSObject20getDenseArrayElementEj($obj_idx1_val, 0);
    var $_idx4 = $18 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    __ZL20GetValueTypeForTableP9JSContextRKN2JS5ValueE($type, $_idx4_val$0, $_idx4_val$1);
    var $19 = $type | 0;
    var $20 = $ntype | 0;
    var $i_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $i_0;
    if ($i_0 >>> 0 < $15 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 8:
    var $obj_idx_val = HEAP32[$obj_idx1 >> 2];
    var $24 = __ZN8JSObject20getDenseArrayElementEj($obj_idx_val, $i_0);
    var $_idx5 = $24 | 0;
    var $_idx5_val$0 = HEAP32[$_idx5 >> 2];
    var $_idx5_val$1 = HEAP32[$_idx5 + 4 >> 2];
    __ZL20GetValueTypeForTableP9JSContextRKN2JS5ValueE($ntype, $_idx5_val$0, $_idx5_val$1);
    var $25 = HEAP32[$19 >> 2];
    var $ntype_idx_val = HEAP32[$20 >> 2];
    var $26 = __ZNK2js5types4TypeneES1_($ntype_idx_val, $25);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $28 = __ZL11NumberTypesN2js5types4TypeES1_($25, $ntype_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 10:
    __ZN2js5types4Type10DoubleTypeEv($type);
    __label__ = 11;
    break;
   case 11:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 7;
    break;
   case 12:
    __ZN2js5types13ArrayTableKeyC1Ev($key);
    var $33 = HEAPU32[$19 >> 2];
    HEAP32[$key >> 2] = $33;
    var $obj_idx3 = $obj + 36 | 0;
    var $obj_idx3_val_idx_val = HEAP32[HEAP32[$obj_idx3 >> 2] >> 2];
    var $35 = __ZNK8JSObject8getProtoEv($obj_idx3_val_idx_val);
    HEAP32[$key + 4 >> 2] = $35;
    var $37 = HEAP32[$2 >> 2];
    __ZNK2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE12lookupForAddERKS2_($p, $37, $key);
    var $_idx9_val = HEAP32[$p >> 2];
    var $_idx9_val_idx_val = HEAP32[$_idx9_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($1, $_idx9_val_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $42 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($_idx9_val);
    var $44 = HEAP32[$42 + 8 >> 2];
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($obj, $44);
    __label__ = 20;
    break;
   case 14:
    var $obj_idx2_val_idx_val = HEAP32[HEAP32[$obj_idx3 >> 2] >> 2];
    var $46 = __ZNK8JSObject8getProtoEv($obj_idx2_val_idx_val);
    var $47 = __ZN2js5types15TypeCompartment13newTypeObjectEP9JSContextP8JSScript10JSProtoKeyP8JSObjectb($cx, 3, $46, 0);
    HEAP32[$objType >> 2] = $47;
    if (($47 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $52 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($52, $cx);
    __label__ = 20;
    break;
   case 16:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($obj, $47);
    var $_idx_val = HEAP32[$47 + 12 >> 2];
    var $54 = __ZN2js5types10TypeObject17unknownPropertiesEv($_idx_val);
    if ($54) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextiNS0_4TypeE($47, $cx, 2, $33);
    __label__ = 18;
    break;
   case 18:
    var $57 = HEAP32[$2 >> 2];
    var $58 = __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13relookupOrAddERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKS4_($57, $p, $key, $objType);
    if ($58) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $62 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($62, $cx);
    __label__ = 20;
    break;
   case 20:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types15TypeCompartment12fixArrayTypeEP9JSContextP8JSObject["X"] = 1;

function __ZNK2js5types4TypeneES1_($this_0_0_val, $o_0) {
  return ($this_0_0_val | 0) != ($o_0 | 0);
}

function _JSID_IS_EMPTY($iden) {
  return ($iden | 0) == 4 & 1;
}

function _JSID_IS_VOID1691($iden) {
  return ($iden | 0) == 2 & 1;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN2js5types7TypeSet21setPropagatedPropertyEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 131072;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js5types7TypeSet11setDefiniteEj($this, $slot) {
  var $2 = $this | 0;
  var $5 = $slot << 24 | HEAP32[$2 >> 2] | 1048576;
  HEAP32[$2 >> 2] = $5;
  return;
}

function __ZN9JSContext4new_IN2js7HashMapINS1_5types13ArrayTableKeyEPNS3_10TypeObjectES4_NS1_17SystemAllocPolicyEEEEEPT_v($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 24);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC1ES5_($4);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj($1);
  return $2;
}

function __ZL20GetValueTypeForTableP9JSContextRKN2JS5ValueE($agg_result, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  __ZN2js5types12GetValueTypeEP9JSContextRKN2JS5ValueE($agg_result, $v_0_0_0_val$0, $v_0_0_0_val$1);
  return;
}

function __ZL11NumberTypesN2js5types4TypeES1_($a_0, $b_0) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($a_0, 1);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($a_0, 0);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $9 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $5 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($b_0, 1);
    if ($5) {
      var $9 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($b_0, 0);
    var $9 = $7;
    __label__ = 5;
    break;
   case 5:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types13ArrayTableKeyC1Ev($this) {
  __ZN2js5types13ArrayTableKeyC2Ev($this);
  return;
}

function __ZNK2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 134,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextiNS0_4TypeE($this, $cx, $id, $type_0) {
  __Z21InlineAddTypePropertyP9JSContextPN2js5types10TypeObjectEiNS2_4TypeE($cx, $this, $id, $type_0);
  return;
}

function __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13relookupOrAddERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKS4_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC1ERKS2_RKS4_($1, $k, $v);
  var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13relookupOrAddERNSC_6AddPtrERKS4_RKS7_($2, $p, $k, $1);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN2js5types15TypeCompartment13fixObjectTypeEP9JSContextP8JSObject($this, $cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 68;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $enter = __stackBase__ + 4;
    var $p = __stackBase__ + 12;
    var $2 = __stackBase__ + 20;
    var $ntype = __stackBase__ + 28;
    var $3 = __stackBase__ + 32;
    var $type = __stackBase__ + 36;
    var $4 = __stackBase__ + 40;
    var $key = __stackBase__ + 44;
    var $entry = __stackBase__ + 60;
    HEAP32[$1 >> 2] = $obj;
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    var $5 = $this + 36 | 0;
    if ((HEAP32[$5 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $9 = __ZN9JSContext4new_IN2js7HashMapINS1_5types14ObjectTableKeyENS3_16ObjectTableEntryES4_NS1_17SystemAllocPolicyEEEEEPT_v($cx);
    HEAP32[$5 >> 2] = $9;
    if (($9 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE4initEj($9);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$5 >> 2] = 0;
    var $16 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($16, $cx);
    __label__ = 36;
    break;
   case 5:
    var $_idx6_val = HEAP32[$obj >> 2];
    var $_idx6_val_idx_val = HEAP32[$_idx6_val + 4 >> 2];
    var $18 = __ZNK8JSObject8slotSpanEv($_idx6_val_idx_val);
    if (($18 | 0) == 0) {
      __label__ = 36;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = __ZNK8JSObject16inDictionaryModeEv($_idx6_val);
    if ($21) {
      __label__ = 36;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = HEAP32[$5 >> 2];
    __ZNK2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE12lookupForAddERKP8JSObject($p, $23, $1);
    var $24 = HEAPU32[$1 >> 2];
    var $_idx1 = $24 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $25 = __ZNK8JSObject12lastPropertyEv($_idx1_val);
    var $_idx19_val = HEAP32[$p >> 2];
    var $_idx19_val_idx_val = HEAP32[$_idx19_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($2, $_idx19_val_idx_val);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $30 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($_idx19_val);
    var $32 = HEAP32[$30 + 20 >> 2];
    var $33 = $ntype | 0;
    var $34 = $3 | 0;
    var $35 = $type | 0;
    var $i_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $i_0;
    var $_idx5_val_idx_val = HEAP32[HEAP32[$_idx1 >> 2] + 4 >> 2];
    var $37 = __ZNK8JSObject8slotSpanEv($_idx5_val_idx_val);
    if ($i_0 >>> 0 < $37 >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 10:
    var $40 = __ZNK8JSObject7getSlotEj($24, $i_0);
    var $_idx13 = $40 | 0;
    var $_idx13_val$0 = HEAP32[$_idx13 >> 2];
    var $_idx13_val$1 = HEAP32[$_idx13 + 4 >> 2];
    __ZL20GetValueTypeForTableP9JSContextRKN2JS5ValueE($ntype, $_idx13_val$0, $_idx13_val$1);
    var $41 = $32 + ($i_0 << 2) | 0;
    var $42 = HEAP32[$41 >> 2];
    var $ntype_idx_val = HEAP32[$33 >> 2];
    var $43 = __ZNK2js5types4TypeneES1_($ntype_idx_val, $42);
    if ($43) {
      __label__ = 11;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 11:
    var $45 = __ZL11NumberTypesN2js5types4TypeES1_($ntype_idx_val, $42);
    if ($45) {
      __label__ = 12;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 12:
    var $47 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($42, 1);
    if ($47) {
      __label__ = 13;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 13:
    __ZN2js5types4Type10DoubleTypeEv($3);
    var $49 = HEAP32[$34 >> 2];
    HEAP32[$41 >> 2] = $49;
    var $shape_0 = $25;
    __label__ = 14;
    break;
   case 14:
    var $shape_0;
    var $51 = $shape_0 + 12 | 0;
    var $52 = HEAP32[$51 >> 2];
    var $53 = _JSID_IS_EMPTY($52);
    if (($53 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 15:
    if ((HEAP32[$shape_0 + 24 >> 2] | 0) == ($i_0 | 0)) {
      __label__ = 16;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 16:
    __ZN2js5types4Type10DoubleTypeEv($type);
    var $60 = $30 + 16 | 0;
    var $_idx10_val = HEAP32[HEAP32[$60 >> 2] + 12 >> 2];
    var $62 = __ZN2js5types10TypeObject17unknownPropertiesEv($_idx10_val);
    if ($62) {
      __label__ = 19;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $64 = HEAP32[$51 >> 2];
    var $65 = __ZN2js5types10MakeTypeIdEP9JSContexti($cx, $64);
    var $66 = HEAP32[$60 >> 2];
    var $67 = HEAP32[$35 >> 2];
    __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextiNS0_4TypeE($66, $cx, $65, $67);
    __label__ = 19;
    break;
   case 18:
    var $shape_0_idx_val = HEAP32[$shape_0 + 32 >> 2];
    var $69 = __ZNK2js5Shape8previousEv($shape_0_idx_val);
    var $shape_0 = $69;
    __label__ = 14;
    break;
   case 19:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 9;
    break;
   case 20:
    var $73 = HEAP32[$30 + 16 >> 2];
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($24, $73);
    __label__ = 36;
    break;
   case 21:
    var $_idx8 = $24 + 36 | 0;
    var $_idx8_val_idx_val = HEAP32[HEAP32[$_idx8 >> 2] >> 2];
    var $75 = __ZNK8JSObject8getProtoEv($_idx8_val_idx_val);
    var $76 = __ZN2js5types15TypeCompartment13newTypeObjectEP9JSContextP8JSScript10JSProtoKeyP8JSObjectb($cx, 1, $75, 0);
    if (($76 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $79 = __ZN2js5types10TypeObject21addDefinitePropertiesEP9JSContextP8JSObject($76, $cx, $24);
    if ($79) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $83 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($83, $cx);
    __label__ = 36;
    break;
   case 24:
    var $_idx4_val_idx_val = HEAP32[HEAP32[$_idx1 >> 2] + 4 >> 2];
    var $85 = __ZNK8JSObject8slotSpanEv($_idx4_val_idx_val);
    var $86 = $85 << 2;
    var $87 = __ZN9JSContext7calloc_Ej($cx, $86);
    var $88 = $87;
    if (($87 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    var $93 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($93, $cx);
    __label__ = 36;
    break;
   case 26:
    var $_idx3_val_idx_val = HEAP32[HEAP32[$_idx1 >> 2] + 4 >> 2];
    var $95 = __ZNK8JSObject8slotSpanEv($_idx3_val_idx_val);
    var $96 = $95 << 2;
    var $97 = __ZN9JSContext7calloc_Ej($cx, $96);
    var $98 = $97;
    if (($97 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $100 = $25 + 12 | 0;
    var $101 = HEAP32[$100 >> 2];
    var $102 = _JSID_IS_EMPTY($101);
    if (($102 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 28:
    var $104 = $4 | 0;
    var $_idx9 = $76 + 12 | 0;
    var $shape2_04 = $25;
    var $111 = $100;
    var $110 = $101;
    __label__ = 30;
    break;
   case 29:
    var $108 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($108, $cx);
    __label__ = 36;
    break;
   case 30:
    var $110;
    var $111;
    var $shape2_04;
    var $112 = $shape2_04 + 24 | 0;
    var $114 = $88 + (HEAP32[$112 >> 2] << 2) | 0;
    HEAP32[$114 >> 2] = $110;
    var $115 = HEAP32[$112 >> 2];
    var $116 = __ZNK8JSObject7getSlotEj($24, $115);
    var $_idx14 = $116 | 0;
    var $_idx14_val$0 = HEAP32[$_idx14 >> 2];
    var $_idx14_val$1 = HEAP32[$_idx14 + 4 >> 2];
    __ZL20GetValueTypeForTableP9JSContextRKN2JS5ValueE($4, $_idx14_val$0, $_idx14_val$1);
    var $117 = HEAP32[$104 >> 2];
    var $118 = $98 + ($115 << 2) | 0;
    HEAP32[$118 >> 2] = $117;
    var $_idx9_val = HEAP32[$_idx9 >> 2];
    var $119 = __ZN2js5types10TypeObject17unknownPropertiesEv($_idx9_val);
    if ($119) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $121 = HEAP32[$111 >> 2];
    var $122 = __ZN2js5types10MakeTypeIdEP9JSContexti($cx, $121);
    var $125 = HEAP32[$98 + (HEAP32[$112 >> 2] << 2) >> 2];
    __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextiNS0_4TypeE($76, $cx, $122, $125);
    __label__ = 32;
    break;
   case 32:
    var $shape2_04_idx_val = HEAP32[$shape2_04 + 32 >> 2];
    var $127 = __ZNK2js5Shape8previousEv($shape2_04_idx_val);
    var $128 = $127 + 12 | 0;
    var $129 = HEAP32[$128 >> 2];
    var $130 = _JSID_IS_EMPTY($129);
    if (($130 | 0) == 0) {
      var $shape2_04 = $127;
      var $111 = $128;
      var $110 = $129;
      __label__ = 30;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    HEAP32[$key >> 2] = $88;
    var $_idx2_val_idx_val = HEAP32[HEAP32[$_idx1 >> 2] + 4 >> 2];
    var $133 = __ZNK8JSObject8slotSpanEv($_idx2_val_idx_val);
    HEAP32[$key + 4 >> 2] = $133;
    var $_idx_val = HEAP32[$24 + 8 >> 2];
    var $135 = __ZNK8JSObject13numFixedSlotsEv($_idx_val);
    HEAP32[$key + 8 >> 2] = $135;
    var $_idx7_val_idx_val = HEAP32[HEAP32[$_idx8 >> 2] >> 2];
    var $137 = __ZNK8JSObject8getProtoEv($_idx7_val_idx_val);
    HEAP32[$key + 12 >> 2] = $137;
    HEAP32[$entry >> 2] = $76;
    HEAP32[$entry + 4 >> 2] = $98;
    var $141 = HEAP32[$5 >> 2];
    __ZNK2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE12lookupForAddERKP8JSObject($p, $141, $1);
    var $142 = HEAP32[$5 >> 2];
    var $143 = __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS5_13MapHashPolicyES4_E6AddPtrERKS2_RKS3_($142, $p, $key, $entry);
    if ($143) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $147 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($147, $cx);
    __label__ = 36;
    break;
   case 35:
    var $149 = HEAP32[$1 >> 2];
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($149, $76);
    __label__ = 36;
    break;
   case 36:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types15TypeCompartment13fixObjectTypeEP9JSContextP8JSObject["X"] = 1;

function __ZN9JSContext4new_IN2js7HashMapINS1_5types14ObjectTableKeyENS3_16ObjectTableEntryES4_NS1_17SystemAllocPolicyEEEEEPT_v($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 24);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEEC1ES4_($4);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj($1);
  return $2;
}

function __ZNK2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE12lookupForAddERKP8JSObject($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E12lookupForAddERKP8JSObject($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 136,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS5_13MapHashPolicyES4_E6AddPtrERKS2_RKS3_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrEPPS6_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$pentry >> 2];
    var $5 = $4;
    var $6 = $k;
    HEAP32[$5 >> 2] = HEAP32[$6 >> 2];
    HEAP32[$5 + 4 >> 2] = HEAP32[$6 + 4 >> 2];
    HEAP32[$5 + 8 >> 2] = HEAP32[$6 + 8 >> 2];
    HEAP32[$5 + 12 >> 2] = HEAP32[$6 + 12 >> 2];
    var $8 = $v;
    var $9 = $4 + 16 | 0;
    var $10$0 = HEAP32[$8 >> 2];
    var $10$1 = HEAP32[$8 + 4 >> 2];
    var $st$11$0 = $9 | 0;
    HEAP32[$st$11$0 >> 2] = $10$0;
    var $st$11$1 = $9 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $10$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObject11addPropertyEP9JSContextiPPNS0_8PropertyE($this, $cx, $id, $pprop) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $id;
    var $2 = $cx + 56 | 0;
    var $4 = HEAP32[$2 >> 2] + 344 | 0;
    var $5 = __ZN2js8ArenaNewINS_5types8PropertyEiEEPT_R11JSArenaPoolRKT0_($4, $1);
    if (($5 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = HEAP32[$2 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($9, $cx);
    var $_0 = 0;
    __label__ = 13;
    break;
   case 3:
    var $11 = $this + 4 | 0;
    var $12 = HEAP32[$11 >> 2];
    if (($12 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = HEAP32[$1 >> 2];
    var $16 = _JSID_IS_VOID1691($15);
    if (($16 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx_val = HEAP32[$12 >> 2];
    var $19 = __ZNK8JSObject12lastPropertyEv($_idx_val);
    var $21 = HEAP32[$19 + 12 >> 2];
    var $22 = _JSID_IS_EMPTY($21);
    if (($22 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 6:
    var $24 = $5 + 4 | 0;
    var $shape_01 = $19;
    var $26 = $21;
    __label__ = 7;
    break;
   case 7:
    var $26;
    var $shape_01;
    var $27 = __ZN2js5types10MakeTypeIdEP9JSContexti($cx, $26);
    var $28 = _JSID_IS_VOID1691($27);
    if (($28 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAP32[$11 >> 2];
    __ZL18UpdatePropertyTypeP9JSContextPN2js5types7TypeSetEP8JSObjectPKNS1_5ShapeEb($cx, $24, $31, $shape_01, 1);
    __label__ = 9;
    break;
   case 9:
    var $shape_01_idx_val = HEAP32[$shape_01 + 32 >> 2];
    var $33 = __ZNK2js5Shape8previousEv($shape_01_idx_val);
    var $35 = HEAP32[$33 + 12 >> 2];
    var $36 = _JSID_IS_EMPTY($35);
    if (($36 | 0) == 0) {
      var $shape_01 = $33;
      var $26 = $35;
      __label__ = 7;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $39 = __ZN8JSObject12nativeLookupEP9JSContexti($12, $cx, $15);
    if (($39 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $42 = $5 + 4 | 0;
    var $43 = HEAP32[$11 >> 2];
    __ZL18UpdatePropertyTypeP9JSContextPN2js5types7TypeSetEP8JSObjectPKNS1_5ShapeEb($cx, $42, $43, $39, 0);
    __label__ = 12;
    break;
   case 12:
    HEAP32[$pprop >> 2] = $5;
    var $_0 = 1;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types10TypeObject11addPropertyEP9JSContextiPPNS0_8PropertyE["X"] = 1;

function __ZN2js8ArenaNewINS_5types8PropertyEiEEPT_R11JSArenaPoolRKT0_($pool, $a) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 16 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $26 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    __ZN2js5types8PropertyC1Ei($23, $24);
    var $26 = $23;
    __label__ = 6;
    break;
   case 6:
    var $26;
    return $26;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18UpdatePropertyTypeP9JSContextPN2js5types7TypeSetEP8JSObjectPKNS1_5ShapeEb($cx, $types, $obj, $shape, $force) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $shape_idx_val = HEAP8[$shape + 28 | 0];
    var $3 = __ZNK2js5Shape14hasGetterValueEv($shape_idx_val);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2js5Shape14hasSetterValueEv($shape_idx_val);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js5types4Type11UnknownTypeEv($1);
    var $_03_val = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($types, $cx, $_03_val);
    __label__ = 9;
    break;
   case 4:
    var $8 = __ZNK2js5Shape26hasDefaultGetterOrIsMethodEv($shape);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = HEAP32[$shape + 24 >> 2];
    if (($11 | 0) == -1) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = __ZNK8JSObject13nativeGetSlotEj($obj, $11);
    var $_idx2_phi_trans_insert = $14 | 0;
    var $_idx2_val_pre$0 = HEAP32[$_idx2_phi_trans_insert >> 2];
    var $_idx2_val_pre$1 = HEAP32[$_idx2_phi_trans_insert + 4 >> 2];
    if ($force) {
      var $_idx2_val$1 = $_idx2_val_pre$1;
      var $_idx2_val$0 = $_idx2_val_pre$0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $16 = __ZNK2JS5Value11isUndefinedEv($_idx2_val_pre$0, $_idx2_val_pre$1);
    if ($16) {
      __label__ = 9;
      break;
    } else {
      var $_idx2_val$1 = $_idx2_val_pre$1;
      var $_idx2_val$0 = $_idx2_val_pre$0;
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx2_val$0;
    var $_idx2_val$1;
    __ZN2js5types12GetValueTypeEP9JSContextRKN2JS5ValueE($2, $_idx2_val$0, $_idx2_val$1);
    var $_0_val = HEAP32[$2 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($types, $cx, $_0_val);
    __label__ = 9;
    break;
   case 9:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject11isFixedSlotEj($this_0_2_val, $slot) {
  var $1 = __ZNK8JSObject13numFixedSlotsEv($this_0_2_val);
  return $1 >>> 0 > $slot >>> 0;
}

function __ZN2js5types10TypeObject23matchDefinitePropertiesEP8JSObject($this, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAPU32[$this + 12 >> 2];
    var $1 = __ZN2js5types10TypeObject16getPropertyCountEv($this_idx_val);
    var $this_idx2 = $this + 24 | 0;
    var $obj_idx = $obj | 0;
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if ($i_0 >>> 0 < $1 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 3:
    var $this_idx2_val = HEAP32[$this_idx2 >> 2];
    var $5 = __ZN2js5types10TypeObject11getPropertyEj($this_idx_val, $this_idx2_val, $i_0);
    if (($5 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$5 + 4 >> 2];
    var $8 = __ZNK2js5types7TypeSet18isDefinitePropertyEv($_idx_val);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 5:
    var $10 = __ZNK2js5types7TypeSet12definiteSlotEv($_idx_val);
    var $obj_idx_val = HEAP32[$obj_idx >> 2];
    var $11 = __ZNK8JSObject12lastPropertyEv($obj_idx_val);
    var $12 = $5 | 0;
    var $shape_0 = $11;
    __label__ = 6;
    break;
   case 6:
    var $shape_0;
    var $15 = HEAP32[$shape_0 + 12 >> 2];
    var $16 = _JSID_IS_EMPTY($15);
    if (($16 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    if ((HEAP32[$shape_0 + 24 >> 2] | 0) == ($10 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    if (($15 | 0) == (HEAP32[$12 >> 2] | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $shape_0_idx_val = HEAP32[$shape_0 + 32 >> 2];
    var $26 = __ZNK2js5Shape8previousEv($shape_0_idx_val);
    var $shape_0 = $26;
    __label__ = 6;
    break;
   case 10:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z21InlineAddTypePropertyP9JSContextPN2js5types10TypeObjectEiNS2_4TypeE($cx, $obj, $id, $type_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    var $1 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($obj, $cx, $id, 1);
    if (($1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($1, $type_0);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($1, $cx, $type_0);
    __label__ = 4;
    break;
   case 4:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextiRKN2JS5ValueE($this, $cx, $id, $value_0_0_0_val$0, $value_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  __ZN2js5types12GetValueTypeEP9JSContextRKN2JS5ValueE($1, $value_0_0_0_val$0, $value_0_0_0_val$1);
  var $_0_val = HEAP32[$1 >> 2];
  __Z21InlineAddTypePropertyP9JSContextPN2js5types10TypeObjectEiNS2_4TypeE($cx, $this, $id, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextPKcNS0_4TypeE($this, $cx, $name, $type_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    if (($name | 0) == 0) {
      var $id_0 = 2;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = _strlen($name);
    var $4 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $3, 0);
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    var $9 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($9, $cx);
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    __label__ = 6;
    break;
   case 4:
    var $11 = __ZL12ATOM_TO_JSIDP6JSAtom1694($4);
    var $id_0 = $11;
    __label__ = 5;
    break;
   case 5:
    var $id_0;
    __Z21InlineAddTypePropertyP9JSContextPN2js5types10TypeObjectEiNS2_4TypeE($cx, $this, $id_0, $type_0);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12ATOM_TO_JSIDP6JSAtom1694($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj1765($1);
  return $2;
}

function __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextPKcRKN2JS5ValueE($this, $cx, $value_0_0_0_val$0, $value_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  __ZN2js5types12GetValueTypeEP9JSContextRKN2JS5ValueE($1, $value_0_0_0_val$0, $value_0_0_0_val$1);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextPKcNS0_4TypeE($this, $cx, 0, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js5types10TypeObject22markPropertyConfiguredEP9JSContexti($this, $cx, $id) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    var $1 = __ZN2js5types10MakeTypeIdEP9JSContexti($cx, $id);
    var $2 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($this, $cx, $1, 1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js5types7TypeSet14setOwnPropertyEP9JSContextb($2, $cx, 1);
    __label__ = 3;
    break;
   case 3:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObject15markStateChangeEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $this_idx = $this + 12 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $1 = __ZN2js5types10TypeObject17unknownPropertiesEv($this_idx_val);
    if ($1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    var $this_idx1_val = HEAP32[$this_idx >> 2];
    var $this_idx2_val = HEAP32[$this + 24 >> 2];
    var $3 = __ZN2js5types10TypeObject16maybeGetPropertyEP9JSContexti($this_idx1_val, $this_idx2_val, 4);
    if (($3 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $constraint_01 = HEAP32[$3 + 8 >> 2];
    if (($constraint_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $constraint_02 = $constraint_01;
      __label__ = 4;
      break;
    }
   case 4:
    var $constraint_02;
    var $11 = HEAP32[HEAP32[$constraint_02 >> 2] + 8 >> 2];
    FUNCTION_TABLE[$11]($constraint_02, $cx, $this, 1);
    var $constraint_0 = HEAP32[$constraint_02 + 4 >> 2];
    if (($constraint_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $constraint_02 = $constraint_0;
      __label__ = 4;
      break;
    }
   case 5:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObject8setFlagsEP9JSContextj($this, $cx, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $1 = $this + 12 | 0;
    if ((HEAP32[$1 >> 2] & $flags | 0) == ($flags | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    var $7 = HEAP32[$1 >> 2] | $flags;
    HEAP32[$1 >> 2] = $7;
    __ZL17ObjectStateChangeP9JSContextPN2js5types10TypeObjectEbb($cx, $this, 0, 0);
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObject11markUnknownEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    var $2 = $this + 12 | 0;
    if ((HEAP32[$2 >> 2] & 2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js5types10TypeObject14clearNewScriptEP9JSContext($this, $cx);
    __label__ = 3;
    break;
   case 3:
    __ZL17ObjectStateChangeP9JSContextPN2js5types10TypeObjectEbb($cx, $this, 1, 1);
    var $this_idx_val = HEAP32[$2 >> 2];
    var $8 = __ZN2js5types10TypeObject16getPropertyCountEv($this_idx_val);
    if (($8 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $this_idx2 = $this + 24 | 0;
    var $_0 = $1 | 0;
    var $i_01 = 0;
    var $this_idx1_val = $this_idx_val;
    __label__ = 5;
    break;
   case 5:
    var $this_idx1_val;
    var $i_01;
    var $this_idx2_val = HEAP32[$this_idx2 >> 2];
    var $10 = __ZN2js5types10TypeObject11getPropertyEj($this_idx1_val, $this_idx2_val, $i_01);
    if (($10 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $13 = $10 + 4 | 0;
    __ZN2js5types4Type11UnknownTypeEv($1);
    var $_0_val = HEAP32[$_0 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($13, $cx, $_0_val);
    __ZN2js5types7TypeSet14setOwnPropertyEP9JSContextb($13, $cx, 1);
    __label__ = 7;
    break;
   case 7:
    var $15 = $i_01 + 1 | 0;
    if (($15 | 0) == ($8 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $i_01 = $15;
    var $this_idx1_val = HEAP32[$2 >> 2];
    __label__ = 5;
    break;
   case 9:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis16addsScopeObjectsEv($this_0_10_val) {
  return ($this_0_10_val & 64) << 24 >> 24 != 0;
}

function __ZN2js7analyzeL7ArgSlotEj1706($arg) {
  return $arg + 2 | 0;
}

function __ZN2jsL20CallObjectLambdaNameEP10JSFunction1708($fun) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP16[$fun + 58 >> 1] & 8) << 16 >> 16 == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$fun + 72 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObject14clearNewScriptEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $iter = __stackBase__ + 8;
    var $1 = $this + 12 | 0;
    var $3 = HEAP32[$1 >> 2] | 2;
    HEAP32[$1 >> 2] = $3;
    var $4 = $this + 16 | 0;
    if ((HEAP32[$4 >> 2] | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    var $this_idx6_val = HEAP32[$1 >> 2];
    var $8 = __ZN2js5types10TypeObject16getPropertyCountEv($this_idx6_val);
    if (($8 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx8 = $this + 24 | 0;
    var $i_05 = 0;
    var $this_idx7_val = $this_idx6_val;
    __label__ = 4;
    break;
   case 4:
    var $this_idx7_val;
    var $i_05;
    var $this_idx8_val = HEAP32[$this_idx8 >> 2];
    var $10 = __ZN2js5types10TypeObject11getPropertyEj($this_idx7_val, $this_idx8_val, $i_05);
    if (($10 | 0) == 0) {
      var $this_idx_val = $this_idx7_val;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = $10 + 4 | 0;
    var $_idx11_val = HEAP32[$13 >> 2];
    var $14 = __ZNK2js5types7TypeSet18isDefinitePropertyEv($_idx11_val);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      var $this_idx_val = $this_idx7_val;
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js5types7TypeSet14setOwnPropertyEP9JSContextb($13, $cx, 1);
    var $this_idx_val = HEAP32[$1 >> 2];
    __label__ = 7;
    break;
   case 7:
    var $this_idx_val;
    var $17 = $i_05 + 1 | 0;
    var $18 = __ZN2js5types10TypeObject16getPropertyCountEv($this_idx_val);
    if ($17 >>> 0 < $18 >>> 0) {
      var $i_05 = $17;
      var $this_idx7_val = $this_idx_val;
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2js13FrameRegsIterC1EP9JSContextNS_9StackIter11SavedOptionE($iter, $cx);
    var $20 = __ZNK2js13FrameRegsIter4doneEv($iter);
    if ($20) {
      __label__ = 32;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $22 = $cx + 60 | 0;
    var $_idx4 = $cx + 64 | 0;
    __label__ = 10;
    break;
   case 10:
    var $24 = __ZNK2js13FrameRegsIter2fpEv($iter);
    var $_idx3_val = HEAP32[$24 >> 2];
    var $25 = __ZNK2js10StackFrame13isScriptFrameEv($_idx3_val);
    if ($25) {
      __label__ = 11;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 11:
    var $27 = __ZNK2js10StackFrame14isConstructingEv($_idx3_val);
    if ($27) {
      __label__ = 12;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 12:
    var $29 = __ZNK2js10StackFrame3funEv($24);
    var $30 = HEAPU32[$4 >> 2];
    if (($29 | 0) == (HEAP32[$30 >> 2] | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 13:
    var $35 = __ZNK2js10StackFrame9thisValueEv($24);
    var $_idx1 = $35 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $36 = __ZNK2JS5Value8isObjectEv($_idx1_val$0, $_idx1_val$1);
    if ($36) {
      __label__ = 14;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 14:
    var $38 = __ZNK2JS5Value8toObjectEv($_idx1_val$0, $_idx1_val$1);
    var $_idx9_val = HEAP32[$38 + 8 >> 2];
    var $39 = __ZNK8JSObject11hasLazyTypeEv($_idx9_val);
    if ($39) {
      __label__ = 31;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $_idx10_val = HEAP32[$38 + 36 >> 2];
    var $41 = __ZNK8JSObject4typeEv($_idx10_val);
    if (($41 | 0) == ($this | 0)) {
      __label__ = 16;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 16:
    var $44 = __ZNK2js13FrameRegsIter2pcEv($iter);
    var $init_0 = HEAP32[$30 + 12 >> 2];
    var $depth_0 = 0;
    var $numProperties_0 = 0;
    var $fp_0 = $24;
    var $pc_0 = $44;
    __label__ = 17;
    break;
   case 17:
    var $pc_0;
    var $fp_0;
    var $numProperties_0;
    var $depth_0;
    var $init_0;
    var $48 = __ZNK2js10StackFrame6scriptEv($fp_0);
    var $53 = $pc_0 - HEAP32[$48 >> 2] | 0;
    var $55 = HEAP32[$init_0 >> 2];
    if (($55 | 0) == 0) {
      __label__ = 18;
      break;
    } else if (($55 | 0) == 1) {
      __label__ = 21;
      break;
    } else if (($55 | 0) == 2) {
      __label__ = 27;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 18:
    if (($depth_0 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    if (HEAPU32[$init_0 + 4 >> 2] >>> 0 > $53 >>> 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $depth_1 = $depth_0;
    var $numProperties_1 = $numProperties_0 + 1 | 0;
    var $fp_1 = $fp_0;
    var $pc_1 = $pc_0;
    __label__ = 29;
    break;
   case 21:
    if (($depth_0 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $depth_1 = $depth_0 + 1 | 0;
    var $numProperties_1 = $numProperties_0;
    var $fp_1 = $fp_0;
    var $pc_1 = $pc_0;
    __label__ = 29;
    break;
   case 23:
    var $70 = HEAPU32[$init_0 + 4 >> 2];
    if ($70 >>> 0 > $53 >>> 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    if (($70 | 0) == ($53 | 0)) {
      __label__ = 25;
      break;
    } else {
      var $depth_1 = 1;
      var $numProperties_1 = $numProperties_0;
      var $fp_1 = $fp_0;
      var $pc_1 = $pc_0;
      __label__ = 29;
      break;
    }
   case 25:
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $75 = __ZNK2js12ContextStack5spaceEv($_idx4_val);
    var $76 = $fp_0;
    var $_idx5_val = HEAP32[$75 >> 2];
    var $77 = __ZNK2js10StackSpace17containingSegmentEPKNS_10StackFrameE($_idx5_val, $76);
    var $_idx_val = HEAP32[$77 + 8 >> 2];
    var $78 = __ZNK2js12StackSegment7maybefpEv($_idx_val);
    if (($78 | 0) == ($fp_0 | 0)) {
      __label__ = 30;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $82 = __ZNK2js12StackSegment16computeNextFrameEPKNS_10StackFrameE($77, $76);
    var $83 = $82;
    var $84 = __ZN2js10StackFrame11pcQuadraticERKNS_12ContextStackEPS0_PPNS_13JSInlinedSiteE($82, $22, 0);
    var $depth_1 = $depth_0;
    var $numProperties_1 = $numProperties_0;
    var $fp_1 = $83;
    var $pc_1 = $84;
    __label__ = 29;
    break;
   case 27:
    if (($depth_0 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $depth_1 = $depth_0 - 1 | 0;
    var $numProperties_1 = $numProperties_0;
    var $fp_1 = $fp_0;
    var $pc_1 = $pc_0;
    __label__ = 29;
    break;
   case 29:
    var $pc_1;
    var $fp_1;
    var $numProperties_1;
    var $depth_1;
    var $init_0 = $init_0 + 8 | 0;
    var $depth_0 = $depth_1;
    var $numProperties_0 = $numProperties_1;
    var $fp_0 = $fp_1;
    var $pc_0 = $pc_1;
    __label__ = 17;
    break;
   case 30:
    __ZN8JSObject18rollbackPropertiesEP9JSContextj($38, $cx, $numProperties_0);
    __label__ = 31;
    break;
   case 31:
    __ZN2js13FrameRegsIterppEv($iter);
    var $91 = __ZNK2js13FrameRegsIter4doneEv($iter);
    if ($91) {
      __label__ = 32;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 32:
    var $93 = HEAP32[$4 >> 2];
    __ZN9JSContext5free_EPv($93);
    HEAP32[$4 >> 2] = 0;
    __ZN2js5types10TypeObject15markStateChangeEP9JSContext($this, $cx);
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    __label__ = 33;
    break;
   case 33:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types10TypeObject14clearNewScriptEP9JSContext["X"] = 1;

function __ZN2js7analyze14ScriptAnalysis17resolveNameAccessEP9JSContextib($agg_result, $this, $cx, $id) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    __ZN2jsL7PodZeroINS_7analyze14ScriptAnalysis10NameAccessEEEvPT_($agg_result);
    var $1 = __ZL12JSID_IS_ATOMi1703($id);
    if (($1 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZL12JSID_TO_ATOMi1704($id);
    var $6 = $cx;
    var $script_0 = HEAP32[$this >> 2];
    __label__ = 3;
    break;
   case 3:
    var $script_0;
    if ((HEAP8[$script_0 + 37 | 0] & 4) << 24 >> 24 == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx3 = $script_0 + 100 | 0;
    var $_idx3_val_idx_val = HEAP32[HEAP32[$_idx3 >> 2] + 12 >> 2];
    var $15 = __ZNK8JSScript7nestingEv($_idx3_val_idx_val);
    if (($15 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = __ZN8JSScript18ensureRanInferenceEP9JSContext($script_0, $cx);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 6:
    var $script_0_idx4_val_idx_val = HEAP32[HEAP32[$_idx3 >> 2] >> 2];
    var $20 = __ZN8JSScript8analysisEv($script_0_idx4_val_idx_val);
    var $_idx5_val = HEAP8[$20 + 24 | 0];
    var $21 = __ZN2js7analyze14ScriptAnalysis16addsScopeObjectsEv($_idx5_val);
    if ($21) {
      __label__ = 16;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = HEAP32[$script_0 >> 2];
    var $25 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh1705($script_0, $24);
    if (($25 | 0) == 205) {
      __label__ = 16;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $30 = __ZNK2js8Bindings6lookupEP9JSContextP6JSAtomPj($script_0 + 64 | 0, $6, $4, $index);
    if (($30 - 1 | 0) >>> 0 < 2) {
      __label__ = 9;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 9:
    var $33 = ($30 | 0) == 1;
    var $script_0_idx1_val_idx_val = HEAP32[HEAP32[$_idx3 >> 2] + 4 >> 2];
    var $34 = __ZNK8JSScript8functionEv($script_0_idx1_val_idx_val);
    var $35 = $34;
    var $36 = $cx;
    var $37 = __ZN8JSObject7getTypeEP9JSContext($35, $36);
    HEAP32[$agg_result >> 2] = $script_0;
    var $_idx2_val_idx_val = HEAP32[HEAP32[$_idx3 >> 2] + 12 >> 2];
    var $41 = __ZNK8JSScript7nestingEv($_idx2_val_idx_val);
    var $42 = $41;
    HEAP32[$agg_result + 4 >> 2] = $42;
    var $44 = HEAPU32[$index >> 2];
    if ($33) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $46 = __ZN2js7analyzeL7ArgSlotEj1706($44);
    var $50 = $46;
    __label__ = 12;
    break;
   case 11:
    var $48 = __ZN2js7analyzeL9LocalSlotEP8JSScriptj1707($script_0, $44);
    var $50 = $48;
    __label__ = 12;
    break;
   case 12:
    var $50;
    HEAP32[$agg_result + 8 >> 2] = $50;
    HEAP8[$agg_result + 12 | 0] = $33 & 1;
    HEAP32[$agg_result + 16 >> 2] = $44;
    __label__ = 16;
    break;
   case 13:
    if (($30 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    var $script_0_idx_val = HEAPU32[$_idx3 >> 2];
    var $script_0_idx_val_idx_val = HEAP32[$script_0_idx_val + 4 >> 2];
    var $58 = __ZNK8JSScript8functionEv($script_0_idx_val_idx_val);
    var $59 = __ZN2jsL20CallObjectLambdaNameEP10JSFunction1708($58);
    if (($4 | 0) == ($59 | 0)) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $_idx_val_idx_val = HEAP32[$script_0_idx_val + 12 >> 2];
    var $63 = __ZNK8JSScript7nestingEv($_idx_val_idx_val);
    var $65 = HEAPU32[$63 >> 2];
    if (($65 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      var $script_0 = $65;
      __label__ = 3;
      break;
    }
   case 16:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis17resolveNameAccessEP9JSContextib["X"] = 1;

function __ZN2jsL7PodZeroINS_7analyze14ScriptAnalysis10NameAccessEEEvPT_($t) {
  var $1 = $t;
  _memset($1, 0, 20, 1);
  return;
}

function __ZL12JSID_IS_ATOMi1703($id) {
  var $1 = _JSID_IS_STRING1730($id);
  return $1;
}

function __ZL12JSID_TO_ATOMi1704($id) {
  var $1 = _JSID_TO_STRING1731($id);
  return $1;
}

function __ZN8JSScript18ensureRanInferenceEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $1 = __ZN8JSScript17ensureRanAnalysisEP9JSContextP10JSFunctionP8JSObject($this, $cx, 0, 0);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $this_idx2 = $this + 100 | 0;
    var $this_idx2_val_idx_val = HEAP32[HEAP32[$this_idx2 >> 2] >> 2];
    var $3 = __ZN8JSScript8analysisEv($this_idx2_val_idx_val);
    var $_idx_val = HEAP8[$3 + 23 | 0];
    var $4 = __ZN2js7analyze14ScriptAnalysis12ranInferenceEv($_idx_val);
    if ($4) {
      var $this_idx_val_idx_val = $this_idx2_val_idx_val;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    var $this_idx1_val_idx_val = HEAP32[HEAP32[$this_idx2 >> 2] >> 2];
    var $6 = __ZN8JSScript8analysisEv($this_idx1_val_idx_val);
    __ZN2js7analyze14ScriptAnalysis12analyzeTypesEP9JSContext($6, $cx);
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    var $this_idx_val_idx_val = HEAP32[HEAP32[$this_idx2 >> 2] >> 2];
    __label__ = 4;
    break;
   case 4:
    var $this_idx_val_idx_val;
    var $8 = __ZN8JSScript8analysisEv($this_idx_val_idx_val);
    var $_idx3_val = HEAP8[$8 + 12 | 0];
    var $9 = __ZN2js7analyze14ScriptAnalysis3OOMEv($_idx3_val);
    var $_0 = $9 ^ 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12js_GetOpcodeP9JSContextP8JSScriptPh1705($script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU8[$pc];
    var $2 = $1 & 255;
    if ($1 << 24 >> 24 == 83) {
      __label__ = 2;
      break;
    } else {
      var $op_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $script;
    var $6 = _JS_GetTrapOpcode($5, $pc);
    var $op_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $op_0;
    return $op_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyzeL9LocalSlotEP8JSScriptj1707($script, $local) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$script + 37 | 0] & 4) << 24 >> 24 == 0) {
      var $11 = 2;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $script_idx_val_idx_val = HEAP32[HEAP32[$script + 100 >> 2] + 4 >> 2];
    var $6 = __ZNK8JSScript8functionEv($script_idx_val_idx_val);
    var $11 = (HEAPU16[$6 + 56 >> 1] & 65535) + 2 | 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11 + $local | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis20analyzeTypesBytecodeEP9JSContextjRNS1_18TypeInferenceStateE($this, $cx, $offset, $state) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 280;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $pc = __stackBase__ + 4;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 12;
    var $4 = __stackBase__ + 16;
    var $5 = __stackBase__ + 20;
    var $6 = __stackBase__ + 24;
    var $7 = __stackBase__ + 28;
    var $8 = __stackBase__ + 32;
    var $9 = __stackBase__ + 36;
    var $10 = __stackBase__ + 40;
    var $11 = __stackBase__ + 44;
    var $12 = __stackBase__ + 48;
    var $13 = __stackBase__ + 52;
    var $14 = __stackBase__ + 56;
    var $15 = __stackBase__ + 60;
    var $16 = __stackBase__ + 64;
    var $17 = __stackBase__ + 68;
    var $access = __stackBase__ + 72;
    var $18 = __stackBase__ + 92;
    var $19 = __stackBase__ + 96;
    var $20 = __stackBase__ + 100;
    var $access7 = __stackBase__ + 104;
    var $21 = __stackBase__ + 124;
    var $22 = __stackBase__ + 128;
    var $23 = __stackBase__ + 132;
    var $24 = __stackBase__ + 136;
    var $25 = __stackBase__ + 140;
    var $26 = __stackBase__ + 144;
    var $27 = __stackBase__ + 148;
    var $28 = __stackBase__ + 152;
    var $29 = __stackBase__ + 156;
    var $30 = __stackBase__ + 160;
    var $31 = __stackBase__ + 164;
    var $32 = __stackBase__ + 168;
    var $33 = __stackBase__ + 172;
    var $34 = __stackBase__ + 176;
    var $35 = __stackBase__ + 180;
    var $argCount = __stackBase__ + 184;
    var $36 = __stackBase__ + 188;
    var $37 = __stackBase__ + 192;
    var $38 = __stackBase__ + 196;
    var $39 = __stackBase__ + 200;
    var $40 = __stackBase__ + 204;
    var $41 = __stackBase__ + 208;
    var $42 = __stackBase__ + 212;
    var $43 = __stackBase__ + 216;
    var $44 = __stackBase__ + 220;
    var $45 = __stackBase__ + 224;
    var $46 = __stackBase__ + 228;
    var $47 = __stackBase__ + 232;
    var $48 = __stackBase__ + 236;
    var $49 = __stackBase__ + 240;
    var $50 = __stackBase__ + 244;
    var $51 = __stackBase__ + 248;
    var $52 = __stackBase__ + 252;
    var $53 = __stackBase__ + 256;
    var $54 = __stackBase__ + 260;
    var $55 = __stackBase__ + 264;
    var $56 = __stackBase__ + 268;
    var $57 = __stackBase__ + 272;
    var $58 = __stackBase__ + 276;
    HEAP32[$1 >> 2] = $cx;
    var $59 = $this | 0;
    var $60 = HEAPU32[$59 >> 2];
    var $63 = HEAP32[$60 >> 2] + $offset | 0;
    HEAP32[$pc >> 2] = $63;
    var $64 = HEAPU8[$63];
    var $65 = $64 & 255;
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $66 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this_idx_val, $offset);
    var $67 = __ZN2js7analyzeL11GetDefCountEP8JSScriptj1681($60, $offset);
    var $_val = HEAP8[HEAP32[$pc >> 2]];
    var $69 = __ZN2js7analyzeL11ExtendedDefEPh1682($_val);
    var $defCount_0 = ($69 & 1) + $67 | 0;
    var $74 = HEAP32[HEAP32[$1 >> 2] + 56 >> 2] + 344 | 0;
    var $75 = __ZN2js10ArenaArrayINS_5types7TypeSetEEEPT_R11JSArenaPoolj($74, $defCount_0);
    if (($75 | 0) == 0) {
      var $_0 = 0;
      __label__ = 176;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2jsL7PodZeroINS_5types7TypeSetEEEvPT_j($75, $defCount_0);
    var $78 = $66 + 36 | 0;
    HEAP32[$78 >> 2] = $75;
    var $80 = HEAP32[$66 + 32 >> 2];
    if (($80 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $82 = $state | 0;
    var $newv_0 = $80;
    __label__ = 4;
    break;
   case 4:
    var $newv_0;
    if ((HEAP32[$newv_0 >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $88 = $newv_0 + 4 | 0;
    var $89 = __ZNK2js7analyze8SSAValue4kindEv($88);
    if (($89 | 0) == 3) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $92 = __ZNK2js7analyze8SSAValue9phiOffsetEv($88);
    if (($92 | 0) == ($offset | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $newv_0 = $newv_0 + 12 | 0;
    __label__ = 4;
    break;
   case 8:
    var $95 = __ZNK2js7analyze8SSAValue7phiNodeEv($88);
    var $96 = __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_($82, $95);
    if ($96) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 176;
      break;
    }
   case 9:
    var $97 = HEAPU32[$pc >> 2];
    if ((HEAP32[_js_CodeSpec + ((HEAPU8[$97] & 255) << 3) + 4 >> 2] & 134217728 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 176;
      break;
    }
   case 10:
    if (($65 | 0) == 40 || ($65 | 0) == 1) {
      __label__ = 11;
      break;
    } else if (($65 | 0) == 62 || ($65 | 0) == 63 || ($65 | 0) == 218 || ($65 | 0) == 219 || ($65 | 0) == 88 || ($65 | 0) == 190 || ($65 | 0) == 17 || ($65 | 0) == 15 || ($65 | 0) == 16 || ($65 | 0) == 33 || ($65 | 0) == 25 || ($65 | 0) == 24 || ($65 | 0) == 26) {
      __label__ = 12;
      break;
    } else if (($65 | 0) == 66 || ($65 | 0) == 67 || ($65 | 0) == 18 || ($65 | 0) == 19 || ($65 | 0) == 20 || ($65 | 0) == 21 || ($65 | 0) == 22 || ($65 | 0) == 23 || ($65 | 0) == 32 || ($65 | 0) == 72 || ($65 | 0) == 73 || ($65 | 0) == 113 || ($65 | 0) == 114 || ($65 | 0) == 186) {
      __label__ = 13;
      break;
    } else if (($65 | 0) == 60) {
      __label__ = 14;
      break;
    } else if (($65 | 0) == 61 || ($65 | 0) == 39 || ($65 | 0) == 200 || ($65 | 0) == 165 || ($65 | 0) == 180 || ($65 | 0) == 169 || ($65 | 0) == 170 || ($65 | 0) == 171 || ($65 | 0) == 181) {
      __label__ = 15;
      break;
    } else if (($65 | 0) == 64) {
      __label__ = 16;
      break;
    } else if (($65 | 0) == 162) {
      __label__ = 17;
      break;
    } else if (($65 | 0) == 80) {
      __label__ = 21;
      break;
    } else if (($65 | 0) == 197) {
      __label__ = 22;
      break;
    } else if (($65 | 0) == 68 || ($65 | 0) == 144 || ($65 | 0) == 69 || ($65 | 0) == 145) {
      __label__ = 24;
      break;
    } else if (($65 | 0) == 12) {
      __label__ = 25;
      break;
    } else if (($65 | 0) == 13) {
      __label__ = 26;
      break;
    } else if (($65 | 0) == 10 || ($65 | 0) == 133) {
      __label__ = 27;
      break;
    } else if (($65 | 0) == 156 || ($65 | 0) == 214) {
      __label__ = 32;
      break;
    } else if (($65 | 0) == 59 || ($65 | 0) == 57) {
      __label__ = 42;
      break;
    } else if (($65 | 0) == 157) {
      __label__ = 48;
      break;
    } else if (($65 | 0) == 111) {
      __label__ = 49;
      break;
    } else if (($65 | 0) == 14) {
      __label__ = 53;
      break;
    } else if (($65 | 0) == 198 || ($65 | 0) == 136 || ($65 | 0) == 137) {
      __label__ = 54;
      break;
    } else if (($65 | 0) == 84 || ($65 | 0) == 216 || ($65 | 0) == 86 || ($65 | 0) == 215) {
      __label__ = 56;
      break;
    } else if (($65 | 0) == 85 || ($65 | 0) == 87 || ($65 | 0) == 132) {
      __label__ = 63;
      break;
    } else if (($65 | 0) == 97 || ($65 | 0) == 98 || ($65 | 0) == 99 || ($65 | 0) == 100 || ($65 | 0) == 101 || ($65 | 0) == 102 || ($65 | 0) == 103 || ($65 | 0) == 104) {
      __label__ = 67;
      break;
    } else if (($65 | 0) == 9) {
      __label__ = 72;
      break;
    } else if (($65 | 0) == 54 || ($65 | 0) == 226) {
      __label__ = 77;
      break;
    } else if (($65 | 0) == 220 || ($65 | 0) == 53 || ($65 | 0) == 187) {
      __label__ = 78;
      break;
    } else if (($65 | 0) == 55 || ($65 | 0) == 196) {
      __label__ = 83;
      break;
    } else if (($65 | 0) == 56) {
      __label__ = 87;
      break;
    } else if (($65 | 0) == 231) {
      __label__ = 88;
      break;
    } else if (($65 | 0) == 65) {
      __label__ = 89;
      break;
    } else if (($65 | 0) == 5 || ($65 | 0) == 154) {
      __label__ = 90;
      break;
    } else if (($65 | 0) == 27) {
      __label__ = 92;
      break;
    } else if (($65 | 0) == 28 || ($65 | 0) == 29 || ($65 | 0) == 31 || ($65 | 0) == 30) {
      __label__ = 93;
      break;
    } else if (($65 | 0) == 34 || ($65 | 0) == 35) {
      __label__ = 94;
      break;
    } else if (($65 | 0) == 130 || ($65 | 0) == 224 || ($65 | 0) == 127 || ($65 | 0) == 222 || ($65 | 0) == 140 || ($65 | 0) == 223) {
      __label__ = 95;
      break;
    } else if (($65 | 0) == 58 || ($65 | 0) == 123 || ($65 | 0) == 108 || ($65 | 0) == 79 || ($65 | 0) == 82) {
      __label__ = 105;
      break;
    } else if (($65 | 0) == 89 || ($65 | 0) == 90 || ($65 | 0) == 91) {
      __label__ = 116;
      break;
    } else if (($65 | 0) == 94) {
      __label__ = 120;
      break;
    } else if (($65 | 0) == 125 || ($65 | 0) == 126) {
      __label__ = 131;
      break;
    } else if (($65 | 0) == 221) {
      __label__ = 132;
      break;
    } else if (($65 | 0) == 93 || ($65 | 0) == 227) {
      __label__ = 133;
      break;
    } else if (($65 | 0) == 75) {
      __label__ = 144;
      break;
    } else if (($65 | 0) == 77) {
      __label__ = 150;
      break;
    } else if (($65 | 0) == 76) {
      __label__ = 151;
      break;
    } else if (($65 | 0) == 124 || ($65 | 0) == 209 || ($65 | 0) == 207) {
      __label__ = 152;
      break;
    } else if (($65 | 0) == 118) {
      __label__ = 153;
      break;
    } else if (($65 | 0) == 37 || ($65 | 0) == 38 || ($65 | 0) == 36) {
      __label__ = 154;
      break;
    } else if (($65 | 0) == 210) {
      __label__ = 155;
      break;
    } else if (($65 | 0) == 121 || ($65 | 0) == 147) {
      __label__ = 156;
      break;
    } else if (($65 | 0) == 228) {
      __label__ = 157;
      break;
    } else if (($65 | 0) == 205) {
      __label__ = 158;
      break;
    } else if (($65 | 0) == 206) {
      __label__ = 164;
      break;
    } else if (($65 | 0) == 199) {
      __label__ = 165;
      break;
    } else if (($65 | 0) == 174) {
      __label__ = 166;
      break;
    } else if (($65 | 0) == 173) {
      __label__ = 167;
      break;
    } else if (($65 | 0) == 178 || ($65 | 0) == 179 || ($65 | 0) == 185 || ($65 | 0) == 183 || ($65 | 0) == 184 || ($65 | 0) == 175 || ($65 | 0) == 168 || ($65 | 0) == 166 || ($65 | 0) == 167 || ($65 | 0) == 164 || ($65 | 0) == 208) {
      __label__ = 168;
      break;
    } else if (($65 | 0) == 176) {
      __label__ = 169;
      break;
    } else if (($65 | 0) == 177) {
      __label__ = 170;
      break;
    } else if (($65 | 0) == 96) {
      __label__ = 171;
      break;
    } else if (($65 | 0) == 131) {
      __label__ = 172;
      break;
    } else if (($65 | 0) == 81 || ($65 | 0) == 0 || ($65 | 0) == 109 || ($65 | 0) == 182 || ($65 | 0) == 6 || ($65 | 0) == 141 || ($65 | 0) == 7 || ($65 | 0) == 142 || ($65 | 0) == 8 || ($65 | 0) == 143 || ($65 | 0) == 119 || ($65 | 0) == 128 || ($65 | 0) == 4 || ($65 | 0) == 202 || ($65 | 0) == 155 || ($65 | 0) == 78 || ($65 | 0) == 153 || ($65 | 0) == 116 || ($65 | 0) == 146 || ($65 | 0) == 117 || ($65 | 0) == 120 || ($65 | 0) == 122 || ($65 | 0) == 148 || ($65 | 0) == 11 || ($65 | 0) == 229 || ($65 | 0) == 194 || ($65 | 0) == 195 || ($65 | 0) == 163 || ($65 | 0) == 230 || ($65 | 0) == 191 || ($65 | 0) == 211 || ($65 | 0) == 212 || ($65 | 0) == 213 || ($65 | 0) == 192 || ($65 | 0) == 193 || ($65 | 0) == 188 || ($65 | 0) == 189 || ($65 | 0) == 2 || ($65 | 0) == 115 || ($65 | 0) == 74 || ($65 | 0) == 70 || ($65 | 0) == 149 || ($65 | 0) == 71 || ($65 | 0) == 150 || ($65 | 0) == 134 || ($65 | 0) == 217 || ($65 | 0) == 110 || ($65 | 0) == 129 || ($65 | 0) == 92 || ($65 | 0) == 3 || ($65 | 0) == 201 || ($65 | 0) == 112 || ($65 | 0) == 135 || ($65 | 0) == 172 || ($65 | 0) == 95) {
      var $_0 = 1;
      __label__ = 176;
      break;
    } else {
      __label__ = 175;
      break;
    }
   case 11:
    var $105 = HEAP32[$1 >> 2];
    __ZN2js5types4Type13UndefinedTypeEv($2);
    var $_054_val = HEAP32[$2 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $105, $_054_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 12:
    var $107 = HEAP32[$1 >> 2];
    __ZN2js5types4Type9Int32TypeEv($3);
    var $_053_val = HEAP32[$3 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $107, $_053_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 13:
    var $109 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11BooleanTypeEv($4);
    var $_052_val = HEAP32[$4 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $109, $_052_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 14:
    var $111 = HEAP32[$1 >> 2];
    __ZN2js5types4Type10DoubleTypeEv($5);
    var $_051_val = HEAP32[$5 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $111, $_051_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 15:
    var $113 = HEAP32[$1 >> 2];
    __ZN2js5types4Type10StringTypeEv($6);
    var $_050_val = HEAP32[$6 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $113, $_050_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 16:
    var $115 = HEAP32[$1 >> 2];
    __ZN2js5types4Type8NullTypeEv($7);
    var $_049_val = HEAP32[$7 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $115, $_049_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 17:
    var $_idx62_val_idx_val = HEAP32[HEAP32[HEAP32[$59 >> 2] + 100 >> 2] + 8 >> 2];
    var $118 = __ZNK8JSScript9hasGlobalEv($_idx62_val_idx_val);
    var $119 = HEAP32[$1 >> 2];
    if ($118) {
      __label__ = 18;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 18:
    var $121 = __ZN2js5types10TypeScript12StandardTypeEP9JSContextP8JSScript10JSProtoKey($119, $_idx62_val_idx_val, 10);
    if (($121 | 0) == 0) {
      var $_0 = 0;
      __label__ = 176;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $124 = HEAP32[$1 >> 2];
    __ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE($8, $121);
    var $_048_val = HEAP32[$8 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $124, $_048_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 20:
    __ZN2js5types4Type11UnknownTypeEv($9);
    var $_047_val = HEAP32[$9 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $119, $_047_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 21:
    var $127 = HEAP32[$59 >> 2];
    var $128 = __ZL15GetScriptObjectP9JSContextP8JSScriptPKhj($127, $97, 0);
    var $129 = HEAP32[$1 >> 2];
    __ZN2js5types4Type10ObjectTypeEP8JSObject($10, $128);
    var $_046_val = HEAP32[$10 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $129, $_046_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 22:
    var $131 = HEAP32[$59 >> 2];
    if ((HEAP8[$131 + 37 | 0] & 4) << 24 >> 24 == 0) {
      var $_0 = 1;
      __label__ = 176;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $_idx72_val = HEAP16[$131 + 22 >> 1];
    var $_idx73_val = HEAP32[$131 + 100 >> 2];
    var $137 = __ZN2js5types10TypeScript11ReturnTypesEP8JSScript($_idx72_val, $_idx73_val);
    var $138 = HEAP32[$1 >> 2];
    __ZN2js5types4Type13UndefinedTypeEv($11);
    var $_045_val = HEAP32[$11 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($137, $138, $_045_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 24:
    var $140 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $141 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($140, $141, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 25:
    var $143 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $144 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($143, $144, $75);
    var $145 = HEAP32[$pc >> 2];
    var $146 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $145, 0);
    var $147 = HEAP32[$1 >> 2];
    var $148 = $75 + 12 | 0;
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($146, $147, $148);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 26:
    var $150 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 1);
    var $151 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($150, $151, $75);
    var $152 = HEAP32[$pc >> 2];
    var $153 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $152, 0);
    var $154 = HEAP32[$1 >> 2];
    var $155 = $75 + 12 | 0;
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($153, $154, $155);
    var $156 = HEAP32[$pc >> 2];
    var $157 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $156, 1);
    var $158 = HEAP32[$1 >> 2];
    var $159 = $75 + 24 | 0;
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($157, $158, $159);
    var $160 = HEAP32[$pc >> 2];
    var $161 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $160, 0);
    var $162 = HEAP32[$1 >> 2];
    var $163 = $75 + 36 | 0;
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($161, $162, $163);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 27:
    if ($64 << 24 >> 24 == 10) {
      var $171 = 1;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $171 = HEAPU8[$97 + 1 | 0] & 255;
    __label__ = 29;
    break;
   case 29:
    var $171;
    var $172 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, $171);
    var $173 = HEAP32[$1 >> 2];
    var $174 = $75 + $171 * 12 | 0;
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($172, $173, $174);
    if (($171 | 0) == 0) {
      var $_0 = 1;
      __label__ = 176;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $176 = $171 - 1 | 0;
    var $i1_013 = 0;
    __label__ = 31;
    break;
   case 31:
    var $i1_013;
    var $178 = HEAP32[$pc >> 2];
    var $179 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $178, $i1_013);
    var $180 = HEAP32[$1 >> 2];
    var $182 = $75 + ($176 - $i1_013) * 12 | 0;
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($179, $180, $182);
    var $183 = $i1_013 + 1 | 0;
    if (($183 | 0) == ($171 | 0)) {
      var $_0 = 1;
      __label__ = 176;
      break;
    } else {
      var $i1_013 = $183;
      __label__ = 31;
      break;
    }
   case 32:
    var $185 = HEAP32[$1 >> 2];
    var $186 = HEAP32[$59 >> 2];
    var $187 = __ZL9GetAtomIdP9JSContextP8JSScriptPKhj($185, $186, $97);
    var $188 = HEAP32[$pc >> 2];
    var $this_idx101_val = HEAP32[$this_idx >> 2];
    var $this_idx100_val_idx_val = HEAP32[HEAP32[$59 >> 2] >> 2];
    var $189 = __ZN2js7analyze14ScriptAnalysis13bytecodeTypesEPKh($this_idx100_val_idx_val, $this_idx101_val, $188);
    var $190 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($189, $190, $75);
    var $191 = HEAP32[$1 >> 2];
    var $193 = HEAP32[$191 + 52 >> 2];
    var $196 = HEAP32[$193 + 209984 >> 2] | 0;
    var $197 = __ZL12ATOM_TO_JSIDP6JSAtom1694($196);
    if (($187 | 0) == ($197 | 0)) {
      __label__ = 33;
      break;
    } else {
      var $202 = $191;
      var $201 = $193;
      __label__ = 34;
      break;
    }
   case 33:
    __ZN2js5types4Type13UndefinedTypeEv($12);
    var $_044_val = HEAP32[$12 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($189, $191, $_044_val);
    var $_pre = HEAP32[$1 >> 2];
    var $202 = $_pre;
    var $201 = HEAP32[$_pre + 52 >> 2];
    __label__ = 34;
    break;
   case 34:
    var $201;
    var $202;
    var $205 = HEAP32[$201 + 210380 >> 2] | 0;
    var $206 = __ZL12ATOM_TO_JSIDP6JSAtom1694($205);
    if (($187 | 0) == ($206 | 0)) {
      __label__ = 35;
      break;
    } else {
      var $211 = $202;
      var $210 = $201;
      __label__ = 36;
      break;
    }
   case 35:
    __ZN2js5types4Type10DoubleTypeEv($13);
    var $_043_val = HEAP32[$13 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($189, $202, $_043_val);
    var $_pre122 = HEAP32[$1 >> 2];
    var $211 = $_pre122;
    var $210 = HEAP32[$_pre122 + 52 >> 2];
    __label__ = 36;
    break;
   case 36:
    var $210;
    var $211;
    var $214 = HEAP32[$210 + 210376 >> 2] | 0;
    var $215 = __ZL12ATOM_TO_JSIDP6JSAtom1694($214);
    if (($187 | 0) == ($215 | 0)) {
      __label__ = 37;
      break;
    } else {
      var $219 = $211;
      __label__ = 38;
      break;
    }
   case 37:
    __ZN2js5types4Type10DoubleTypeEv($14);
    var $_042_val = HEAP32[$14 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($189, $211, $_042_val);
    var $219 = HEAP32[$1 >> 2];
    __label__ = 38;
    break;
   case 38:
    var $219;
    var $220 = HEAP32[$59 >> 2];
    var $221 = HEAP32[$pc >> 2];
    var $_idx65_val_idx_val = HEAP32[HEAP32[$220 + 100 >> 2] + 8 >> 2];
    var $222 = __ZNK8JSScript6globalEv($_idx65_val_idx_val);
    var $223 = $222;
    var $225 = __ZN8JSObject7getTypeEP9JSContext($223, $219);
    var $226 = $225;
    __ZL14PropertyAccessP9JSContextP8JSScriptPhPN2js5types10TypeObjectEbPNS5_7TypeSetEi($219, $220, $221, $226, 0, $189, $187);
    if ($64 << 24 >> 24 == -42) {
      __label__ = 39;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 39:
    var $229 = $75 + 12 | 0;
    var $230 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($15);
    var $_041_val = HEAP32[$15 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($229, $230, $_041_val);
    var $231 = HEAP32[$1 >> 2];
    var $232 = HEAP32[$59 >> 2];
    var $233 = HEAP32[$pc >> 2];
    __ZN2js5types4Type11UnknownTypeEv($16);
    var $_0112_val = HEAP32[$16 >> 2];
    __ZN2js5types7TypeSet16addPropagateThisEP9JSContextP8JSScriptPhNS0_4TypeEPS1_($75, $231, $232, $233, $_0112_val, 0);
    __label__ = 40;
    break;
   case 40:
    var $235 = HEAP32[$pc >> 2];
    var $236 = __ZL13CheckNextTestPh($235);
    if ($236) {
      __label__ = 41;
      break;
    } else {
      var $_0 = 1;
      __label__ = 176;
      break;
    }
   case 41:
    var $238 = HEAP32[$1 >> 2];
    __ZN2js5types4Type13UndefinedTypeEv($17);
    var $_040_val = HEAP32[$17 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $238, $_040_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 42:
    var $this_idx99_val = HEAP32[$this_idx >> 2];
    var $this_idx98_val_idx_val = HEAP32[HEAP32[$59 >> 2] >> 2];
    var $240 = __ZN2js7analyze14ScriptAnalysis13bytecodeTypesEPKh($this_idx98_val_idx_val, $this_idx99_val, $97);
    var $241 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($240, $241, $75);
    var $242 = HEAP32[$1 >> 2];
    var $243 = HEAP32[$59 >> 2];
    var $244 = HEAP32[$pc >> 2];
    var $245 = __ZL9GetAtomIdP9JSContextP8JSScriptPKhj($242, $243, $244);
    var $246 = HEAP32[$1 >> 2];
    __ZN2js7analyze14ScriptAnalysis17resolveNameAccessEP9JSContextib($access, $this, $246, $245);
    var $248 = HEAP32[$access >> 2];
    if (($248 | 0) == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    if ((HEAP8[$248 + 38 | 0] & 16) << 24 >> 24 == 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 44:
    var $257 = HEAP32[$access + 8 >> 2];
    var $_idx88_val = HEAP16[$248 + 22 >> 1];
    var $_idx89_val = HEAP32[$248 + 100 >> 2];
    var $258 = __ZN2js5types10TypeScript9SlotTypesEP8JSScriptj($_idx88_val, $_idx89_val, $257);
    var $259 = HEAP32[$1 >> 2];
    var $260 = HEAP32[$59 >> 2];
    var $261 = HEAP32[$pc >> 2];
    __ZN2js5types7TypeSet16addSubsetBarrierEP9JSContextP8JSScriptPhPS1_($258, $259, $260, $261, $240);
    __label__ = 46;
    break;
   case 45:
    var $263 = HEAP32[$1 >> 2];
    var $264 = HEAP32[$pc >> 2];
    __ZN2js5types4Type11UnknownTypeEv($18);
    var $this_idx105_val = HEAP32[$59 >> 2];
    var $this_idx106_val = HEAP32[$this_idx >> 2];
    var $_0107_val = HEAP32[$18 >> 2];
    __ZN2js7analyze14ScriptAnalysis14addTypeBarrierEP9JSContextPKhPNS_5types7TypeSetENS6_4TypeE($this_idx105_val, $this_idx106_val, $263, $264, $240, $_0107_val);
    __label__ = 46;
    break;
   case 46:
    if ($64 << 24 >> 24 == 57) {
      __label__ = 47;
      break;
    } else {
      var $_0 = 1;
      __label__ = 176;
      break;
    }
   case 47:
    var $268 = $75 + 12 | 0;
    var $269 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($19);
    var $_039_val = HEAP32[$19 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($268, $269, $_039_val);
    var $270 = HEAP32[$1 >> 2];
    var $271 = HEAP32[$59 >> 2];
    var $272 = HEAP32[$pc >> 2];
    __ZN2js5types4Type11UnknownTypeEv($20);
    var $_0111_val = HEAP32[$20 >> 2];
    __ZN2js5types7TypeSet16addPropagateThisEP9JSContextP8JSScriptPhNS0_4TypeEPS1_($75, $270, $271, $272, $_0111_val, 0);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 48:
    var $274 = HEAP32[$1 >> 2];
    var $275 = HEAP32[$59 >> 2];
    var $276 = __ZL9GetAtomIdP9JSContextP8JSScriptPKhj($274, $275, $97);
    var $277 = HEAP32[$1 >> 2];
    var $278 = HEAP32[$59 >> 2];
    var $279 = HEAP32[$pc >> 2];
    var $_idx64_val_idx_val = HEAP32[HEAP32[$278 + 100 >> 2] + 8 >> 2];
    var $280 = __ZNK8JSScript6globalEv($_idx64_val_idx_val);
    var $281 = $280;
    var $282 = $277;
    var $283 = __ZN8JSObject7getTypeEP9JSContext($281, $282);
    var $284 = $283;
    var $285 = HEAP32[$pc >> 2];
    var $286 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $285, 0);
    __ZL14PropertyAccessP9JSContextP8JSScriptPhPN2js5types10TypeObjectEbPNS5_7TypeSetEi($277, $278, $279, $284, 1, $286, $276);
    var $287 = HEAP32[$pc >> 2];
    var $288 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $287, 0);
    var $289 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($288, $289, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 49:
    var $291 = HEAP32[$1 >> 2];
    var $292 = HEAP32[$59 >> 2];
    var $293 = __ZL9GetAtomIdP9JSContextP8JSScriptPKhj($291, $292, $97);
    var $294 = HEAP32[$1 >> 2];
    __ZN2js7analyze14ScriptAnalysis17resolveNameAccessEP9JSContextib($access7, $this, $294, $293);
    var $296 = HEAP32[$access7 >> 2];
    if (($296 | 0) == 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    var $300 = HEAP32[$access7 + 8 >> 2];
    var $_idx86_val = HEAP16[$296 + 22 >> 1];
    var $_idx87_val = HEAP32[$296 + 100 >> 2];
    var $301 = __ZN2js5types10TypeScript9SlotTypesEP8JSScriptj($_idx86_val, $_idx87_val, $300);
    var $302 = HEAP32[$pc >> 2];
    var $303 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $302, 0);
    var $304 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($303, $304, $301);
    __label__ = 52;
    break;
   case 51:
    var $306 = HEAP32[$1 >> 2];
    var $307 = HEAP32[$59 >> 2];
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb($306, $307, $offset, 0);
    __label__ = 52;
    break;
   case 52:
    var $309 = HEAP32[$pc >> 2];
    var $310 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $309, 0);
    var $311 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($310, $311, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 53:
    var $313 = HEAP32[$1 >> 2];
    var $314 = HEAP32[$59 >> 2];
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb($313, $314, $offset, 0);
    var $315 = HEAP32[$pc >> 2];
    var $316 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $315, 0);
    var $317 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($316, $317, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 54:
    var $this_idx97_val = HEAP32[$this_idx >> 2];
    var $this_idx96_val_idx_val = HEAP32[HEAP32[$59 >> 2] >> 2];
    var $319 = __ZN2js7analyze14ScriptAnalysis13bytecodeTypesEPKh($this_idx96_val_idx_val, $this_idx97_val, $97);
    var $320 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($21);
    var $this_idx102_val = HEAP32[$59 >> 2];
    var $this_idx103_val = HEAP32[$this_idx >> 2];
    var $_0104_val = HEAP32[$21 >> 2];
    __ZN2js7analyze14ScriptAnalysis14addTypeBarrierEP9JSContextPKhPNS_5types7TypeSetENS6_4TypeE($this_idx102_val, $this_idx103_val, $320, $97, $319, $_0104_val);
    var $321 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($319, $321, $75);
    if ($64 << 24 >> 24 == -119) {
      __label__ = 55;
      break;
    } else {
      var $_0 = 1;
      __label__ = 176;
      break;
    }
   case 55:
    var $324 = $75 + 12 | 0;
    var $325 = HEAP32[$1 >> 2];
    __ZN2js5types4Type13UndefinedTypeEv($22);
    var $_038_val = HEAP32[$22 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($324, $325, $_038_val);
    var $326 = HEAP32[$1 >> 2];
    var $327 = HEAP32[$59 >> 2];
    var $328 = HEAP32[$pc >> 2];
    __ZN2js5types4Type13UndefinedTypeEv($23);
    var $_0110_val = HEAP32[$23 >> 2];
    __ZN2js5types7TypeSet16addPropagateThisEP9JSContextP8JSScriptPhNS0_4TypeEPS1_($75, $326, $327, $328, $_0110_val, 0);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 56:
    var $330 = HEAPU32[$59 >> 2];
    var $331 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh1709($330, $97);
    var $332 = __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $331);
    if ($332) {
      __label__ = 57;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 57:
    var $334 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $335 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($334, $335, $75);
    __label__ = 61;
    break;
   case 58:
    var $337 = __ZN2js7analyzeL10TotalSlotsEP8JSScript1710($330);
    if ($331 >>> 0 < $337 >>> 0) {
      __label__ = 59;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 59:
    var $_idx84_val = HEAP16[$330 + 22 >> 1];
    var $_idx85_val = HEAP32[$330 + 100 >> 2];
    var $340 = __ZN2js5types10TypeScript9SlotTypesEP8JSScriptj($_idx84_val, $_idx85_val, $331);
    var $341 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($340, $341, $75);
    __label__ = 61;
    break;
   case 60:
    var $343 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($24);
    var $_037_val = HEAP32[$24 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $343, $_037_val);
    __label__ = 61;
    break;
   case 61:
    if (($64 + 41 & 255 & 255) < 2) {
      __label__ = 62;
      break;
    } else {
      var $_0 = 1;
      __label__ = 176;
      break;
    }
   case 62:
    var $347 = $75 + 12 | 0;
    var $348 = HEAP32[$1 >> 2];
    __ZN2js5types4Type13UndefinedTypeEv($25);
    var $_036_val = HEAP32[$25 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($347, $348, $_036_val);
    var $349 = HEAP32[$1 >> 2];
    var $350 = HEAP32[$59 >> 2];
    var $351 = HEAP32[$pc >> 2];
    __ZN2js5types4Type13UndefinedTypeEv($26);
    var $_0109_val = HEAP32[$26 >> 2];
    __ZN2js5types7TypeSet16addPropagateThisEP9JSContextP8JSScriptPhNS0_4TypeEPS1_($75, $349, $350, $351, $_0109_val, 0);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 63:
    var $353 = HEAPU32[$59 >> 2];
    var $354 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh1709($353, $97);
    var $355 = __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $354);
    if ($355) {
      var $364 = $97;
      __label__ = 66;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    var $357 = __ZN2js7analyzeL10TotalSlotsEP8JSScript1710($353);
    if ($354 >>> 0 < $357 >>> 0) {
      __label__ = 65;
      break;
    } else {
      var $364 = $97;
      __label__ = 66;
      break;
    }
   case 65:
    var $_idx82_val = HEAP16[$353 + 22 >> 1];
    var $_idx83_val = HEAP32[$353 + 100 >> 2];
    var $360 = __ZN2js5types10TypeScript9SlotTypesEP8JSScriptj($_idx82_val, $_idx83_val, $354);
    var $361 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $362 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($361, $362, $360);
    var $364 = HEAP32[$pc >> 2];
    __label__ = 66;
    break;
   case 66:
    var $364;
    var $365 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $364, 0);
    var $366 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($365, $366, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 67:
    var $368 = HEAPU32[$59 >> 2];
    var $369 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh1709($368, $97);
    var $370 = __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $369);
    if ($370) {
      __label__ = 68;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 68:
    var $372 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $373 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet8addArithEP9JSContextPS1_S4_($372, $373, $75, 0);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 69:
    var $375 = __ZN2js7analyzeL10TotalSlotsEP8JSScript1710($368);
    if ($369 >>> 0 < $375 >>> 0) {
      __label__ = 70;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 70:
    var $_idx80_val = HEAP16[$368 + 22 >> 1];
    var $_idx81_val = HEAP32[$368 + 100 >> 2];
    var $378 = __ZN2js5types10TypeScript9SlotTypesEP8JSScriptj($_idx80_val, $_idx81_val, $369);
    var $379 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet8addArithEP9JSContextPS1_S4_($378, $379, $378, 0);
    var $380 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($378, $380, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 71:
    var $382 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($27);
    var $_035_val = HEAP32[$27 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $382, $_035_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 72:
    var $_idx1_val_idx_val = HEAP32[HEAP32[HEAP32[$59 >> 2] + 100 >> 2] + 4 >> 2];
    var $385 = __ZNK8JSScript8functionEv($_idx1_val_idx_val);
    var $387 = $385;
    var $388 = HEAP32[$1 >> 2];
    var $389 = __ZN8JSObject7getTypeEP9JSContext($387, $388);
    var $390 = $389;
    var $_idx5_val = HEAP32[$389 + 12 >> 2];
    var $392 = __ZN2js5types10TypeObject17unknownPropertiesEv($_idx5_val);
    if ($392) {
      __label__ = 74;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    var $394 = __ZN2js5types10TypeObject11hasAnyFlagsEj($_idx5_val, 524288);
    if ($394) {
      __label__ = 74;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 74:
    var $396 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($28);
    var $_034_val = HEAP32[$28 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $396, $_034_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 75:
    var $398 = HEAP32[$1 >> 2];
    var $399 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($390, $398, 4, 0);
    if (($399 | 0) == 0) {
      var $_0 = 1;
      __label__ = 176;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 76:
    var $402 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet16addLazyArgumentsEP9JSContextPS1_($399, $402, $75);
    var $403 = HEAP32[$1 >> 2];
    __ZN2js5types4Type12LazyArgsTypeEv($29);
    var $_033_val = HEAP32[$29 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $403, $_033_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 77:
    var $405 = HEAP32[$1 >> 2];
    var $406 = HEAP32[$59 >> 2];
    var $407 = __ZL9GetAtomIdP9JSContextP8JSScriptPKhj($405, $406, $97);
    var $408 = HEAP32[$pc >> 2];
    var $409 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $408, 1);
    var $410 = HEAP32[$1 >> 2];
    var $411 = HEAP32[$59 >> 2];
    var $412 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $408, 0);
    __ZN2js5types7TypeSet14addSetPropertyEP9JSContextP8JSScriptPhPS1_i($409, $410, $411, $408, $412, $407);
    var $413 = HEAP32[$pc >> 2];
    var $414 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $413, 0);
    var $415 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($414, $415, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 78:
    var $417 = HEAP32[$1 >> 2];
    var $418 = HEAP32[$59 >> 2];
    var $419 = __ZL9GetAtomIdP9JSContextP8JSScriptPKhj($417, $418, $97);
    var $420 = HEAP32[$59 >> 2];
    var $_idx57_val_idx_val = HEAP32[HEAP32[$420 + 100 >> 2] >> 2];
    var $421 = __ZN8JSScript8analysisEv($_idx57_val_idx_val);
    var $422 = HEAP32[$pc >> 2];
    var $_idx95_val = HEAP32[$421 + 4 >> 2];
    var $_idx94_val_idx_val = HEAP32[HEAP32[$421 >> 2] >> 2];
    var $423 = __ZN2js7analyze14ScriptAnalysis13bytecodeTypesEPKh($_idx94_val_idx_val, $_idx95_val, $422);
    var $424 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $422, 0);
    var $425 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet14addGetPropertyEP9JSContextP8JSScriptPhPS1_i($424, $425, $420, $422, $423, $419);
    if ($64 << 24 >> 24 == -69) {
      __label__ = 79;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 79:
    var $428 = HEAP32[$pc >> 2];
    var $429 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $428, 0);
    var $430 = HEAP32[$1 >> 2];
    var $431 = HEAP32[$59 >> 2];
    __ZN2js5types7TypeSet15addCallPropertyEP9JSContextP8JSScriptPhi($429, $430, $431, $428, $419);
    var $432 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($423, $432, $75);
    var $433 = HEAP32[$pc >> 2];
    var $434 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $433, 0);
    var $435 = HEAP32[$1 >> 2];
    var $436 = $75 + 12 | 0;
    __ZN2js5types7TypeSet19addFilterPrimitivesEP9JSContextPS1_NS1_10FilterKindE($434, $435, $436, 1);
    __label__ = 81;
    break;
   case 80:
    var $437 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($423, $437, $75);
    __label__ = 81;
    break;
   case 81:
    var $439 = HEAP32[$pc >> 2];
    var $440 = __ZL13CheckNextTestPh($439);
    if ($440) {
      __label__ = 82;
      break;
    } else {
      var $_0 = 1;
      __label__ = 176;
      break;
    }
   case 82:
    var $442 = HEAP32[$1 >> 2];
    __ZN2js5types4Type13UndefinedTypeEv($30);
    var $_032_val = HEAP32[$30 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $442, $_032_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 83:
    var $444 = HEAP32[$59 >> 2];
    var $_idx56_val_idx_val = HEAP32[HEAP32[$444 + 100 >> 2] >> 2];
    var $445 = __ZN8JSScript8analysisEv($_idx56_val_idx_val);
    var $_idx93_val = HEAP32[$445 + 4 >> 2];
    var $_idx92_val_idx_val = HEAP32[HEAP32[$445 >> 2] >> 2];
    var $446 = __ZN2js7analyze14ScriptAnalysis13bytecodeTypesEPKh($_idx92_val_idx_val, $_idx93_val, $97);
    var $447 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 1);
    var $448 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet14addGetPropertyEP9JSContextP8JSScriptPhPS1_i($447, $448, $444, $97, $446, 2);
    var $449 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($446, $449, $75);
    if ($64 << 24 >> 24 == -60) {
      __label__ = 84;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 84:
    var $452 = HEAP32[$pc >> 2];
    var $453 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $452, 1);
    var $454 = HEAP32[$1 >> 2];
    var $455 = $75 + 12 | 0;
    __ZN2js5types7TypeSet19addFilterPrimitivesEP9JSContextPS1_NS1_10FilterKindE($453, $454, $455, 1);
    var $456 = HEAP32[$1 >> 2];
    var $457 = HEAP32[$59 >> 2];
    var $458 = HEAP32[$pc >> 2];
    __ZN2js5types4Type13UndefinedTypeEv($31);
    var $_0108_val = HEAP32[$31 >> 2];
    __ZN2js5types7TypeSet16addPropagateThisEP9JSContextP8JSScriptPhNS0_4TypeEPS1_($75, $456, $457, $458, $_0108_val, $455);
    __label__ = 85;
    break;
   case 85:
    var $460 = HEAP32[$pc >> 2];
    var $461 = __ZL13CheckNextTestPh($460);
    if ($461) {
      __label__ = 86;
      break;
    } else {
      var $_0 = 1;
      __label__ = 176;
      break;
    }
   case 86:
    var $463 = HEAP32[$1 >> 2];
    __ZN2js5types4Type13UndefinedTypeEv($32);
    var $_031_val = HEAP32[$32 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $463, $_031_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 87:
    var $465 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 1);
    var $466 = HEAP32[$1 >> 2];
    var $467 = HEAP32[$59 >> 2];
    var $468 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 2);
    var $469 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    __ZN2js5types7TypeSet13addSetElementEP9JSContextP8JSScriptPhPS1_S7_($465, $466, $467, $97, $468, $469);
    var $470 = HEAP32[$pc >> 2];
    var $471 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $470, 0);
    var $472 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($471, $472, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 88:
    var $474 = HEAP32[$1 >> 2];
    __ZN2js5types4Type9Int32TypeEv($33);
    var $_030_val = HEAP32[$33 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $474, $_030_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 89:
    var $476 = HEAP32[$59 >> 2];
    var $_idx114_val = HEAP16[$476 + 22 >> 1];
    var $_idx115_val = HEAP32[$476 + 100 >> 2];
    var $477 = __ZN2js5types10TypeScript9ThisTypesEP8JSScript($_idx114_val, $_idx115_val);
    var $478 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet16addTransformThisEP9JSContextP8JSScriptPS1_($477, $478, $476, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 90:
    var $480 = HEAP32[$59 >> 2];
    if ((HEAP8[$480 + 37 | 0] & 4) << 24 >> 24 == 0) {
      var $_0 = 1;
      __label__ = 176;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 91:
    var $486 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $487 = HEAP32[$1 >> 2];
    var $_idx70_val = HEAP16[$480 + 22 >> 1];
    var $_idx71_val = HEAP32[$480 + 100 >> 2];
    var $488 = __ZN2js5types10TypeScript11ReturnTypesEP8JSScript($_idx70_val, $_idx71_val);
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($486, $487, $488);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 92:
    var $490 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $491 = HEAP32[$1 >> 2];
    var $492 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 1);
    __ZN2js5types7TypeSet8addArithEP9JSContextPS1_S4_($490, $491, $75, $492);
    var $493 = HEAP32[$pc >> 2];
    var $494 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $493, 1);
    var $495 = HEAP32[$1 >> 2];
    var $496 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $493, 0);
    __ZN2js5types7TypeSet8addArithEP9JSContextPS1_S4_($494, $495, $75, $496);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 93:
    var $498 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $499 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet8addArithEP9JSContextPS1_S4_($498, $499, $75, 0);
    var $500 = HEAP32[$pc >> 2];
    var $501 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $500, 1);
    var $502 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet8addArithEP9JSContextPS1_S4_($501, $502, $75, 0);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 94:
    var $504 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $505 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet8addArithEP9JSContextPS1_S4_($504, $505, $75, 0);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 95:
    if ($64 << 24 >> 24 == -116) {
      __label__ = 96;
      break;
    } else {
      __label__ = 97;
      break;
    }
   case 96:
    var $508 = HEAP32[$59 >> 2];
    var $509 = __ZL15GetScriptObjectP9JSContextP8JSScriptPKhj($508, $97, 2);
    var $515 = $509;
    __label__ = 98;
    break;
   case 97:
    var $phitmp = $64 << 24 >> 24 == -33 ? 2 : 0;
    var $512 = HEAP32[$59 >> 2];
    var $513 = __ZL15GetScriptObjectP9JSContextP8JSScriptPKhj($512, $97, $phitmp);
    if ($64 << 24 >> 24 == -33) {
      var $515 = $513;
      __label__ = 98;
      break;
    } else if ($64 << 24 >> 24 == -32 || $64 << 24 >> 24 == -126) {
      var $res_0 = $75;
      var $523 = $513;
      __label__ = 100;
      break;
    } else {
      __label__ = 104;
      break;
    }
   case 98:
    var $515;
    var $516 = HEAP32[$59 >> 2];
    var $517 = HEAP32[$pc >> 2];
    var $518 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh1709($516, $517);
    var $519 = __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $518);
    if ($519) {
      var $res_0 = $75;
      var $523 = $515;
      __label__ = 100;
      break;
    } else {
      __label__ = 99;
      break;
    }
   case 99:
    var $_idx78_val = HEAP16[$516 + 22 >> 1];
    var $_idx79_val = HEAP32[$516 + 100 >> 2];
    var $521 = __ZN2js5types10TypeScript9SlotTypesEP8JSScriptj($_idx78_val, $_idx79_val, $518);
    var $res_0 = $521;
    var $523 = $515;
    __label__ = 100;
    break;
   case 100:
    var $523;
    var $res_0;
    if (($res_0 | 0) == 0) {
      __label__ = 104;
      break;
    } else {
      __label__ = 101;
      break;
    }
   case 101:
    var $_idx61_val_idx_val = HEAP32[HEAP32[HEAP32[$59 >> 2] + 100 >> 2] + 8 >> 2];
    var $527 = __ZNK8JSScript9hasGlobalEv($_idx61_val_idx_val);
    var $528 = HEAP32[$1 >> 2];
    if ($527) {
      __label__ = 102;
      break;
    } else {
      __label__ = 103;
      break;
    }
   case 102:
    __ZN2js5types4Type10ObjectTypeEP8JSObject($34, $523);
    var $_029_val = HEAP32[$34 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($res_0, $528, $_029_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 103:
    __ZN2js5types4Type11UnknownTypeEv($35);
    var $_028_val = HEAP32[$35 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($res_0, $528, $_028_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 104:
    var $531 = HEAP32[$1 >> 2];
    var $532 = HEAP32[$59 >> 2];
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb($531, $532, $offset, 0);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 105:
    var $_idx55_val_idx_val = HEAP32[HEAP32[HEAP32[$59 >> 2] + 100 >> 2] >> 2];
    var $535 = __ZN8JSScript8analysisEv($_idx55_val_idx_val);
    var $_idx91_val = HEAP32[$535 + 4 >> 2];
    var $_idx90_val_idx_val = HEAP32[HEAP32[$535 >> 2] >> 2];
    var $536 = __ZN2js7analyze14ScriptAnalysis13bytecodeTypesEPKh($_idx90_val_idx_val, $_idx91_val, $97);
    var $537 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($536, $537, $75);
    var $_idx116_val = HEAP32[HEAP32[$59 >> 2] >> 2];
    var $539 = __ZN2js7analyzeL11GetUseCountEP8JSScriptj1711($_idx116_val, $offset);
    var $540 = $539 - 2 | 0;
    HEAP32[$argCount >> 2] = $540;
    var $544 = HEAP32[HEAP32[$1 >> 2] + 56 >> 2] + 344 | 0;
    HEAP8[$36] = $64 << 24 >> 24 == 82 & 1;
    var $547 = __ZN2js8ArenaNewINS_5types12TypeCallsiteEP9JSContextP8JSScriptPhbjEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_RKT4_($544, $1, $59, $pc, $36, $argCount);
    if (($547 | 0) == 0) {
      __label__ = 108;
      break;
    } else {
      __label__ = 106;
      break;
    }
   case 106:
    var $550 = HEAPU32[$argCount >> 2];
    var $551 = ($550 | 0) == 0;
    if ($551) {
      __label__ = 112;
      break;
    } else {
      __label__ = 107;
      break;
    }
   case 107:
    if ((HEAP32[$547 + 12 >> 2] | 0) == 0) {
      __label__ = 108;
      break;
    } else {
      __label__ = 109;
      break;
    }
   case 108:
    var $557 = HEAP32[$1 >> 2];
    var $560 = HEAP32[$557 + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($560, $557);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 109:
    var $562 = HEAP32[$pc >> 2];
    var $563 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $562, $550);
    var $564 = $547 + 20 | 0;
    HEAP32[$564 >> 2] = $563;
    var $565 = $547 + 24 | 0;
    HEAP32[$565 >> 2] = $536;
    if ($551) {
      __label__ = 113;
      break;
    } else {
      __label__ = 110;
      break;
    }
   case 110:
    var $566 = $547 + 12 | 0;
    var $i23_011 = 0;
    __label__ = 111;
    break;
   case 111:
    var $i23_011;
    var $567 = HEAP32[$pc >> 2];
    var $569 = $550 + ($i23_011 ^ -1) | 0;
    var $570 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $567, $569);
    var $572 = HEAP32[$566 >> 2] + ($i23_011 << 2) | 0;
    HEAP32[$572 >> 2] = $570;
    var $573 = $i23_011 + 1 | 0;
    if ($573 >>> 0 < $550 >>> 0) {
      var $i23_011 = $573;
      __label__ = 111;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 112:
    var $575 = HEAP32[$pc >> 2];
    var $576 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $575, $550);
    var $577 = $547 + 20 | 0;
    HEAP32[$577 >> 2] = $576;
    var $578 = $547 + 24 | 0;
    HEAP32[$578 >> 2] = $536;
    __label__ = 113;
    break;
   case 113:
    if ($64 << 24 >> 24 == 108 || $64 << 24 >> 24 == 79) {
      __label__ = 114;
      break;
    } else {
      __label__ = 115;
      break;
    }
   case 114:
    var $580 = HEAP32[$1 >> 2];
    var $581 = HEAP32[$59 >> 2];
    var $587 = HEAP32[$pc >> 2] - HEAP32[$581 >> 2] | 0;
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb($580, $581, $587, 0);
    __label__ = 115;
    break;
   case 115:
    var $589 = HEAP32[$pc >> 2];
    var $590 = $550 + 1 | 0;
    var $591 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $589, $590);
    var $592 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet7addCallEP9JSContextPNS0_12TypeCallsiteE($591, $592, $547);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 116:
    var $594 = HEAP32[$1 >> 2];
    var $595 = HEAP32[$59 >> 2];
    var $596 = __ZL18GetInitializerTypeP9JSContextP8JSScriptPh($594, $595, $97);
    var $_idx60_val_idx_val = HEAP32[HEAP32[HEAP32[$59 >> 2] + 100 >> 2] + 8 >> 2];
    var $598 = __ZNK8JSScript9hasGlobalEv($_idx60_val_idx_val);
    if ($598) {
      __label__ = 117;
      break;
    } else {
      __label__ = 119;
      break;
    }
   case 117:
    if (($596 | 0) == 0) {
      var $_0 = 0;
      __label__ = 176;
      break;
    } else {
      __label__ = 118;
      break;
    }
   case 118:
    var $602 = HEAP32[$1 >> 2];
    __ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE($37, $596);
    var $_027_val = HEAP32[$37 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $602, $_027_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 119:
    var $604 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($38);
    var $_026_val = HEAP32[$38 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $604, $_026_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 120:
    var $this_idx76_val = HEAP32[$59 >> 2];
    var $this_idx77_val = HEAP32[$this_idx >> 2];
    var $this_idx76_val_idx_val = HEAP32[$this_idx76_val >> 2];
    var $606 = __ZN2js7analyze14ScriptAnalysis11poppedValueEPKhj($this_idx76_val_idx_val, $this_idx77_val, $97, 2);
    var $607 = __ZNK2js7analyze8SSAValue12pushedOffsetEv($606);
    var $608 = $this_idx76_val_idx_val + $607 | 0;
    var $609 = HEAP32[$1 >> 2];
    var $610 = __ZL18GetInitializerTypeP9JSContextP8JSScriptPh($609, $this_idx76_val, $608);
    var $612 = HEAP32[$1 >> 2];
    if (($610 | 0) == 0) {
      __label__ = 129;
      break;
    } else {
      __label__ = 121;
      break;
    }
   case 121:
    __ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE($39, $610);
    var $_025_val = HEAP32[$39 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $612, $_025_val);
    var $_idx4 = $610 + 12 | 0;
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $614 = __ZN2js5types10TypeObject17unknownPropertiesEv($_idx4_val);
    if ($614) {
      __label__ = 130;
      break;
    } else {
      __label__ = 122;
      break;
    }
   case 122:
    var $616 = HEAP32[$1 >> 2];
    var $617 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($610, $616, 2, 1);
    if (($617 | 0) == 0) {
      var $_0 = 0;
      __label__ = 176;
      break;
    } else {
      __label__ = 123;
      break;
    }
   case 123:
    if ((HEAP8[$state + 24 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 125;
      break;
    } else {
      __label__ = 124;
      break;
    }
   case 124:
    var $625 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($40);
    var $_024_val = HEAP32[$40 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($617, $625, $_024_val);
    __label__ = 130;
    break;
   case 125:
    if ((HEAP8[$state + 25 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 128;
      break;
    } else {
      __label__ = 126;
      break;
    }
   case 126:
    var $_idx3_val = HEAP32[$_idx4 >> 2];
    var $632 = __ZN2js5types10TypeObject17unknownPropertiesEv($_idx3_val);
    if ($632) {
      __label__ = 130;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 127:
    var $634 = HEAP32[$1 >> 2];
    __ZN2js5types10TypeObject8setFlagsEP9JSContextj($610, $634, 131072);
    __label__ = 130;
    break;
   case 128:
    var $636 = HEAP32[$pc >> 2];
    var $637 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $636, 0);
    var $638 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($637, $638, $617);
    __label__ = 130;
    break;
   case 129:
    __ZN2js5types4Type11UnknownTypeEv($41);
    var $_023_val = HEAP32[$41 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $612, $_023_val);
    __label__ = 130;
    break;
   case 130:
    HEAP8[$state + 24 | 0] = 0;
    HEAP8[$state + 25 | 0] = 0;
    var $_0 = 1;
    __label__ = 176;
    break;
   case 131:
    HEAP8[$state + 24 | 0] = 1;
    var $_0 = 1;
    __label__ = 176;
    break;
   case 132:
    HEAP8[$state + 25 | 0] = 1;
    var $_0 = 1;
    __label__ = 176;
    break;
   case 133:
    var $this_idx74_val = HEAP32[$59 >> 2];
    var $this_idx75_val = HEAP32[$this_idx >> 2];
    var $this_idx74_val_idx_val = HEAP32[$this_idx74_val >> 2];
    var $648 = __ZN2js7analyze14ScriptAnalysis11poppedValueEPKhj($this_idx74_val_idx_val, $this_idx75_val, $97, 1);
    var $649 = __ZNK2js7analyze8SSAValue12pushedOffsetEv($648);
    var $650 = $this_idx74_val_idx_val + $649 | 0;
    var $651 = HEAP32[$1 >> 2];
    var $652 = __ZL18GetInitializerTypeP9JSContextP8JSScriptPh($651, $this_idx74_val, $650);
    var $654 = HEAP32[$1 >> 2];
    if (($652 | 0) == 0) {
      __label__ = 142;
      break;
    } else {
      __label__ = 134;
      break;
    }
   case 134:
    __ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE($42, $652);
    var $_022_val = HEAP32[$42 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $654, $_022_val);
    var $_idx2_val = HEAP32[$652 + 12 >> 2];
    var $656 = __ZN2js5types10TypeObject17unknownPropertiesEv($_idx2_val);
    if ($656) {
      __label__ = 143;
      break;
    } else {
      __label__ = 135;
      break;
    }
   case 135:
    var $658 = HEAP32[$1 >> 2];
    var $659 = HEAP32[$59 >> 2];
    var $660 = HEAP32[$pc >> 2];
    var $661 = __ZL9GetAtomIdP9JSContextP8JSScriptPKhj($658, $659, $660);
    var $662 = HEAP32[$1 >> 2];
    var $663 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($652, $662, $661, 1);
    if (($663 | 0) == 0) {
      var $_0 = 0;
      __label__ = 176;
      break;
    } else {
      __label__ = 136;
      break;
    }
   case 136:
    var $666 = HEAP32[$1 >> 2];
    var $_idx117_val = HEAP32[$666 + 52 >> 2];
    var $_idx117_val_idx_val = HEAP32[$_idx117_val + 210292 >> 2];
    var $667 = __ZL12id___proto__P9JSContext($_idx117_val_idx_val);
    if (($661 | 0) == ($667 | 0)) {
      __label__ = 138;
      break;
    } else {
      __label__ = 137;
      break;
    }
   case 137:
    var $_idx118_val_idx_val = HEAP32[$_idx117_val + 210200 >> 2];
    var $670 = __ZL12id_prototypeP9JSContext($_idx118_val_idx_val);
    if (($661 | 0) == ($670 | 0)) {
      __label__ = 138;
      break;
    } else {
      __label__ = 139;
      break;
    }
   case 138:
    var $673 = HEAP32[$59 >> 2];
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb($666, $673, $offset, 0);
    __label__ = 143;
    break;
   case 139:
    if ((HEAP8[$state + 24 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 141;
      break;
    } else {
      __label__ = 140;
      break;
    }
   case 140:
    __ZN2js5types4Type11UnknownTypeEv($43);
    var $_021_val = HEAP32[$43 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($663, $666, $_021_val);
    __label__ = 143;
    break;
   case 141:
    var $681 = HEAP32[$pc >> 2];
    var $682 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $681, 0);
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($682, $666, $663);
    __label__ = 143;
    break;
   case 142:
    __ZN2js5types4Type11UnknownTypeEv($44);
    var $_020_val = HEAP32[$44 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $654, $_020_val);
    __label__ = 143;
    break;
   case 143:
    HEAP8[$state + 24 | 0] = 0;
    var $_0 = 1;
    __label__ = 176;
    break;
   case 144:
    var $687 = $state + 28 | 0;
    var $688 = HEAP32[$687 >> 2];
    if (($688 | 0) == 0) {
      __label__ = 145;
      break;
    } else {
      var $696 = $688;
      var $695 = $97;
      __label__ = 147;
      break;
    }
   case 145:
    var $691 = HEAP32[$1 >> 2];
    var $692 = __ZN2js5types7TypeSet4makeEP9JSContextPKc($691);
    HEAP32[$687 >> 2] = $692;
    if (($692 | 0) == 0) {
      var $_0 = 0;
      __label__ = 176;
      break;
    } else {
      __label__ = 146;
      break;
    }
   case 146:
    var $696 = $692;
    var $695 = HEAP32[$pc >> 2];
    __label__ = 147;
    break;
   case 147:
    var $695;
    var $696;
    var $701 = HEAP32[$1 >> 2];
    if ((HEAP8[$695 + 1 | 0] & 2) << 24 >> 24 == 0) {
      __label__ = 149;
      break;
    } else {
      __label__ = 148;
      break;
    }
   case 148:
    __ZN2js5types4Type11UnknownTypeEv($45);
    var $_019_val = HEAP32[$45 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($696, $701, $_019_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 149:
    __ZN2js5types4Type10StringTypeEv($46);
    var $_018_val = HEAP32[$46 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($696, $701, $_018_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 150:
    var $706 = HEAP32[$state + 28 >> 2];
    var $707 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($706, $707, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 151:
    var $709 = $75 + 12 | 0;
    var $710 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11BooleanTypeEv($47);
    var $_017_val = HEAP32[$47 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($709, $710, $_017_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 152:
    var $712 = HEAP32[$1 >> 2];
    var $713 = HEAP32[$59 >> 2];
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb($712, $713, $offset, 0);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 153:
    var $715 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($48);
    var $_016_val = HEAP32[$48 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $715, $_016_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 154:
    var $717 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11BooleanTypeEv($49);
    var $_015_val = HEAP32[$49 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $717, $_015_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 155:
    var $719 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $720 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($719, $720, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 156:
    var $722 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 1);
    var $723 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($722, $723, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 157:
    var $725 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $726 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($725, $726, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 158:
    var $728 = HEAP32[$59 >> 2];
    if ((HEAP8[$728 + 37 | 0] & 4) << 24 >> 24 == 0) {
      var $_0 = 1;
      __label__ = 176;
      break;
    } else {
      __label__ = 159;
      break;
    }
   case 159:
    var $_idx59_val = HEAP32[$728 + 100 >> 2];
    var $_idx59_val_idx_val = HEAP32[$_idx59_val + 8 >> 2];
    var $734 = __ZNK8JSScript9hasGlobalEv($_idx59_val_idx_val);
    if ($734) {
      __label__ = 160;
      break;
    } else {
      __label__ = 163;
      break;
    }
   case 160:
    var $736 = __ZNK8JSScript6globalEv($_idx59_val_idx_val);
    var $737 = HEAP32[$1 >> 2];
    var $738 = __ZN2js12GlobalObject29getOrCreateGeneratorPrototypeEP9JSContext($736, $737);
    if (($738 | 0) == 0) {
      var $_0 = 0;
      __label__ = 176;
      break;
    } else {
      __label__ = 161;
      break;
    }
   case 161:
    var $741 = HEAP32[$1 >> 2];
    var $742 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($738, $741, 0, 0);
    if (($742 | 0) == 0) {
      var $_0 = 0;
      __label__ = 176;
      break;
    } else {
      __label__ = 162;
      break;
    }
   case 162:
    var $745 = HEAP32[$59 >> 2];
    var $_idx68_val = HEAP16[$745 + 22 >> 1];
    var $_idx69_val = HEAP32[$745 + 100 >> 2];
    var $746 = __ZN2js5types10TypeScript11ReturnTypesEP8JSScript($_idx68_val, $_idx69_val);
    var $747 = HEAP32[$1 >> 2];
    __ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE($50, $742);
    var $_014_val = HEAP32[$50 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($746, $747, $_014_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 163:
    var $_idx66_val = HEAP16[$728 + 22 >> 1];
    var $749 = __ZN2js5types10TypeScript11ReturnTypesEP8JSScript($_idx66_val, $_idx59_val);
    var $750 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($51);
    var $_013_val = HEAP32[$51 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($749, $750, $_013_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 164:
    var $752 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($52);
    var $_012_val = HEAP32[$52 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $752, $_012_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 165:
    var $754 = $75 + 12 | 0;
    var $755 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($53);
    var $_011_val = HEAP32[$53 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($754, $755, $_011_val);
    __label__ = 166;
    break;
   case 166:
    var $757 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($54);
    var $_010_val = HEAP32[$54 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $757, $_010_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 167:
    var $759 = HEAP32[$1 >> 2];
    var $760 = HEAP32[$59 >> 2];
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb($759, $760, $offset, 0);
    var $761 = HEAP32[$pc >> 2];
    var $762 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $761, 0);
    var $763 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($762, $763, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 168:
    var $765 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($55);
    var $_09_val = HEAP32[$55 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $765, $_09_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 169:
    var $767 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $768 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($767, $768, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 170:
    var $770 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 1);
    var $771 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($770, $771, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 171:
    var $773 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($56);
    var $_08_val = HEAP32[$56 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $773, $_08_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 172:
    var $_idx58_val = HEAP32[HEAP32[$59 >> 2] + 100 >> 2];
    var $_idx58_val_idx_val = HEAP32[$_idx58_val + 8 >> 2];
    var $776 = __ZNK8JSScript9hasGlobalEv($_idx58_val_idx_val);
    var $777 = HEAP32[$1 >> 2];
    if ($776) {
      __label__ = 173;
      break;
    } else {
      __label__ = 174;
      break;
    }
   case 173:
    var $_idx_val_idx_val = HEAP32[$_idx58_val + 4 >> 2];
    var $779 = __ZNK8JSScript8functionEv($_idx_val_idx_val);
    var $780 = $779 | 0;
    __ZN2js5types4Type10ObjectTypeEP8JSObject($57, $780);
    var $_07_val = HEAP32[$57 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $777, $_07_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 174:
    __ZN2js5types4Type11UnknownTypeEv($58);
    var $_06_val = HEAP32[$58 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $777, $_06_val);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 175:
    var $783 = HEAP32[_stderr >> 2];
    var $784 = _fprintf($783, STRING_TABLE.__str471617 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $65, HEAP32[tempInt + 4 >> 2] = 0, HEAP32[tempInt + 8 >> 2] = $offset, tempInt));
    var $785 = HEAP32[$1 >> 2];
    __ZN2js5types11TypeFailureEP9JSContextPKcz($785, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $65, tempInt));
    var $_0 = 1;
    __label__ = 176;
    break;
   case 176:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis20analyzeTypesBytecodeEP9JSContextjRNS1_18TypeInferenceStateE["X"] = 1;

function __ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE6lengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE6lengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZN2js7analyze14ScriptAnalysis3OOMEv($this_0_3_val) {
  return ($this_0_3_val & 1) << 24 >> 24 != 0;
}

function __ZN2js7analyze14ScriptAnalysis6ranSSAEv($this_0_7_val) {
  return ($this_0_7_val & 1) << 24 >> 24 != 0;
}

function __ZNK2js7analyze14ScriptAnalysis14usesScopeChainEv($this_0_10_val) {
  return ($this_0_10_val & 2) << 24 >> 24 != 0;
}

function __ZN2js7analyze14ScriptAnalysis12extendsScopeEv($this_0_10_val) {
  return ($this_0_10_val & 32) << 24 >> 24 != 0;
}

function __ZN2js7analyze14ScriptAnalysis16localsAliasStackEv($this_0_10_val) {
  return $this_0_10_val << 24 >> 24 < 0;
}

function __ZN2js10ArenaArrayINS_5types7TypeSetEEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + $count * 12 & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodZeroINS_5types7TypeSetEEEvPT_j($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem * 12 | 0;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE13growStorageByEj($this);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types4Type11BooleanTypeEv($agg_result) {
  __ZN2js5types4TypeC1Ej($agg_result, 3);
  return;
}

function __ZN2js5types4Type8NullTypeEv($agg_result) {
  __ZN2js5types4TypeC1Ej($agg_result, 6);
  return;
}

function __ZL15GetScriptObjectP9JSContextP8JSScriptPKhj($script, $pc, $offset) {
  var $1 = _js_GetIndexFromBytecode($script, $pc, $offset);
  var $script_idx_val = HEAP32[$script + 4 >> 2];
  var $script_idx1_val = HEAP8[$script + 16 | 0];
  var $2 = __ZN8JSScript9getObjectEj($script_idx_val, $script_idx1_val, $1);
  return $2;
}

function __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $pc, $which) {
  var $this_idx1_val = HEAP32[$this + 4 >> 2];
  var $this_idx_val_idx_val = HEAP32[HEAP32[$this >> 2] >> 2];
  var $1 = __ZN2js7analyze14ScriptAnalysis11poppedValueEPKhj($this_idx_val_idx_val, $this_idx1_val, $pc, $which);
  var $2 = __ZN2js7analyze14ScriptAnalysis13getValueTypesERKNS0_8SSAValueE($this, $1);
  return $2;
}

function __ZN2js7analyze14ScriptAnalysis13bytecodeTypesEPKh($this_0_0_val_0_0_val, $this_0_1_val, $pc) {
  var $1 = __ZN2js7analyze14ScriptAnalysis7getCodeEPKh($this_0_0_val_0_0_val, $this_0_1_val, $pc);
  return HEAP32[$1 + 16 >> 2];
}

function __ZL13CheckNextTestPh($pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js7analyzeL17GetBytecodeLengthEPh1712($pc);
    var $4 = HEAPU8[$pc + $1 | 0] & 255;
    if (($4 | 0) == 7 || ($4 | 0) == 8 || ($4 | 0) == 32 || ($4 | 0) == 68 || ($4 | 0) == 144 || ($4 | 0) == 69 || ($4 | 0) == 145 || ($4 | 0) == 39 || ($4 | 0) == 200) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh1709($script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU8[$pc] & 255;
    if (($2 | 0) == 84 || ($2 | 0) == 216 || ($2 | 0) == 85 || ($2 | 0) == 97 || ($2 | 0) == 98 || ($2 | 0) == 99 || ($2 | 0) == 100) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 86 || ($2 | 0) == 215 || ($2 | 0) == 87 || ($2 | 0) == 132 || ($2 | 0) == 140 || ($2 | 0) == 223 || ($2 | 0) == 101 || ($2 | 0) == 102 || ($2 | 0) == 103 || ($2 | 0) == 104) {
      __label__ = 3;
      break;
    } else if (($2 | 0) == 65) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $11 = (HEAPU8[$pc + 1 | 0] & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255;
    var $12 = __ZN2js7analyzeL7ArgSlotEj1706($11);
    var $_0 = $12;
    __label__ = 5;
    break;
   case 3:
    var $21 = (HEAPU8[$pc + 1 | 0] & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255;
    var $22 = __ZN2js7analyzeL9LocalSlotEP8JSScriptj1707($script, $21);
    var $_0 = $22;
    __label__ = 5;
    break;
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyzeL10TotalSlotsEP8JSScript1710($script) {
  var $1 = __ZN2js7analyzeL9LocalSlotEP8JSScriptj1707($script, 0);
  return (HEAPU16[$script + 14 >> 1] & 65535) + $1 | 0;
}

function __ZN2js5types4Type12LazyArgsTypeEv($agg_result) {
  __ZN2js5types4TypeC1Ej($agg_result, 4);
  return;
}

function __ZN2js7analyzeL11GetUseCountEP8JSScriptj1711($script_0_0_val, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $script_0_0_val + $offset | 0;
    var $2 = HEAPU8[$1];
    var $3 = $2 & 255;
    if ($2 << 24 >> 24 == -123) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = (HEAPU8[$offset + ($script_0_0_val + 1) | 0] & 255) + 1 | 0;
    __label__ = 6;
    break;
   case 3:
    var $12 = HEAPU8[_js_CodeSpec + ($3 << 3) + 1 | 0];
    if ($12 << 24 >> 24 == -1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = _js_GetVariableStackUses($3, $1);
    var $_0 = $15;
    __label__ = 6;
    break;
   case 5:
    var $_0 = $12 << 24 >> 24;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8ArenaNewINS_5types12TypeCallsiteEP9JSContextP8JSScriptPhbjEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_RKT4_($pool, $a, $b, $c, $d, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 28 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $32 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    var $26 = HEAP32[$c >> 2];
    var $29 = (HEAP8[$d] & 1) << 24 >> 24 != 0;
    var $30 = HEAP32[$e >> 2];
    __ZN2js5types12TypeCallsiteC1EP9JSContextP8JSScriptPhbj($23, $24, $25, $26, $29, $30);
    var $32 = $23;
    __label__ = 6;
    break;
   case 6:
    var $32;
    return $32;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18GetInitializerTypeP9JSContextP8JSScriptPh($cx, $script, $pc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $untrap = __stackBase__;
    var $script_idx_val_idx_val = HEAP32[HEAP32[$script + 100 >> 2] + 8 >> 2];
    var $1 = __ZNK8JSScript9hasGlobalEv($script_idx_val_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $script, $pc);
    var $3 = HEAP8[$pc];
    if ($3 << 24 >> 24 == 90) {
      var $12 = 3;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($3 << 24 >> 24 == 89) {
      __label__ = 4;
      break;
    } else {
      var $12 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $phitmp = HEAP8[$pc + 1 | 0] << 24 >> 24 == 3 ? 3 : 1;
    var $12 = $phitmp;
    __label__ = 5;
    break;
   case 5:
    var $12;
    var $13 = __ZN2js5types10TypeScript10InitObjectEP9JSContextP8JSScriptPKh10JSProtoKey($cx, $script, $pc, $12);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_0 = $13;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12id___proto__P9JSContext($cx_0_11_val_0_70_37_val) {
  var $1 = $cx_0_11_val_0_70_37_val | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom1694($1);
  return $2;
}

function __ZN2js12GlobalObject29getOrCreateGeneratorPrototypeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZN8JSObject10getSlotRefEj($1, 112);
    var $_idx = $2 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $3 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($3) {
      var $_idx1_val$1 = $_idx_val$1;
      var $_idx1_val$0 = $_idx_val$0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $cx;
    var $6 = $this;
    var $7 = __Z22js_InitIteratorClassesP9JSContextP8JSObject($5, $6);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx1_val$1 = HEAP32[$_idx + 4 >> 2];
    var $_idx1_val$0 = HEAP32[$_idx >> 2];
    __label__ = 4;
    break;
   case 4:
    var $_idx1_val$0;
    var $_idx1_val$1;
    var $10 = __ZNK2JS5Value8toObjectEv($_idx1_val$0, $_idx1_val$1);
    var $_0 = $10;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis12analyzeTypesEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 84;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $state = __stackBase__ + 4;
    var $untrap = __stackBase__ + 36;
    var $2 = __stackBase__ + 44;
    var $seen = __stackBase__ + 48;
    var $3 = __stackBase__ + 72;
    var $4 = __stackBase__ + 76;
    var $this_idx9_val = HEAP8[$this + 12 | 0];
    var $5 = __ZN2js7analyze14ScriptAnalysis3OOMEv($this_idx9_val);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($9, $cx);
    __label__ = 58;
    break;
   case 3:
    var $11 = $this | 0;
    var $12 = HEAP32[$11 >> 2];
    var $_idx10_val_idx_val = HEAP32[HEAP32[$12 + 100 >> 2] + 8 >> 2];
    var $13 = __ZNK8JSScript16hasClearedGlobalEv($_idx10_val_idx_val);
    if ($13) {
      __label__ = 58;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $this_idx11_val = HEAP8[$this + 21 | 0];
    var $15 = __ZN2js7analyze14ScriptAnalysis6ranSSAEv($this_idx11_val);
    if ($15) {
      var $19 = $12;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js7analyze14ScriptAnalysis10analyzeSSAEP9JSContext($this, $cx);
    var $this_idx12_val = HEAP8[$this + 13 | 0];
    var $17 = __ZN2js7analyze14ScriptAnalysis6failedEv($this_idx12_val);
    if ($17) {
      __label__ = 58;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = HEAP32[$11 >> 2];
    __label__ = 7;
    break;
   case 7:
    var $19;
    HEAP8[$this + 23 | 0] = 1;
    if (HEAP16[$19 + 14 >> 1] << 16 >> 16 == 0) {
      var $_lcssa18 = $19;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_04 = $1 | 0;
    var $i_019 = 0;
    var $24 = $19;
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $i_019;
    var $25 = __ZN2js5types10TypeScript10LocalTypesEP8JSScriptj($24, $i_019);
    __ZN2js5types4Type13UndefinedTypeEv($1);
    var $_04_val = HEAP32[$_04 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($25, $cx, $_04_val);
    var $26 = $i_019 + 1 | 0;
    var $27 = HEAPU32[$11 >> 2];
    if ($26 >>> 0 < (HEAPU16[$27 + 14 >> 1] & 65535) >>> 0) {
      var $i_019 = $26;
      var $24 = $27;
      __label__ = 9;
      break;
    } else {
      var $_lcssa18 = $27;
      __label__ = 10;
      break;
    }
   case 10:
    var $_lcssa18;
    if ((HEAP8[$_lcssa18 + 37 | 0] & 4) << 24 >> 24 == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_idx2_val_idx_val = HEAP32[HEAP32[$_lcssa18 + 100 >> 2] + 12 >> 2];
    var $39 = __ZNK8JSScript7nestingEv($_idx2_val_idx_val);
    if (($39 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $42 = $39;
    var $43 = HEAP32[$42 >> 2];
    if (($43 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $46 = __ZN8JSScript18ensureRanInferenceEP9JSContext($43, $cx);
    if ($46) {
      __label__ = 14;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 14:
    var $this_idx13_val = HEAP8[$this + 24 | 0];
    var $48 = __ZNK2js7analyze14ScriptAnalysis14usesScopeChainEv($this_idx13_val);
    if ($48) {
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $50 = HEAP32[$11 >> 2];
    if ((HEAP8[$50 + 37 | 0] & 16) << 24 >> 24 == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    __ZL19DetachNestingParentP8JSScript($50);
    __label__ = 22;
    break;
   case 17:
    var $57 = __ZN2js7analyze14ScriptAnalysis12extendsScopeEv($this_idx13_val);
    if ($57) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $59 = HEAP32[$11 >> 2];
    __ZL19DetachNestingParentP8JSScript($59);
    __label__ = 22;
    break;
   case 19:
    var $61 = HEAP32[$42 >> 2];
    var $_idx6_val_idx_val = HEAP32[HEAP32[$61 + 100 >> 2] >> 2];
    var $62 = __ZN8JSScript8analysisEv($_idx6_val_idx_val);
    var $_idx15_val = HEAP8[$62 + 24 | 0];
    var $63 = __ZN2js7analyze14ScriptAnalysis16addsScopeObjectsEv($_idx15_val);
    if ($63) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $66 = HEAP32[$61 >> 2];
    var $67 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh1705($61, $66);
    if (($67 | 0) == 205) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    var $69 = HEAP32[$11 >> 2];
    __ZL19DetachNestingParentP8JSScript($69);
    __label__ = 22;
    break;
   case 22:
    __ZN2js7analyze14ScriptAnalysis18TypeInferenceStateC1EP9JSContext($state, $cx);
    var $this_idx7 = $this + 4 | 0;
    var $offset_0 = 0;
    __label__ = 23;
    break;
   case 23:
    var $offset_0;
    var $71 = HEAPU32[$11 >> 2];
    if ($offset_0 >>> 0 < HEAPU32[$71 + 8 >> 2] >>> 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $_idx17 = $state + 8 | 0;
    var $_idx17_val = HEAPU32[$_idx17 >> 2];
    var $75 = __ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE6lengthEv($_idx17_val);
    if (($75 | 0) == 0) {
      var $108 = $71;
      __label__ = 36;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $_idx18 = $state + 4 | 0;
    var $i1_015 = 0;
    var $_idx16_val24 = $_idx17_val;
    __label__ = 30;
    break;
   case 26:
    var $this_idx7_val = HEAP32[$this_idx7 >> 2];
    var $78 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEj($this_idx7_val, $offset_0);
    var $81 = HEAP32[$71 >> 2] + $offset_0 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $71, $81);
    if (($78 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $84 = __ZN2js7analyze14ScriptAnalysis20analyzeTypesBytecodeEP9JSContextjRNS1_18TypeInferenceStateE($this, $cx, $offset_0, $state);
    if ($84) {
      __label__ = 28;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 28:
    var $85 = __ZN2js7analyzeL17GetBytecodeLengthEPh1712($81);
    var $86 = $85 + $offset_0 | 0;
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $offset_0 = $86;
    __label__ = 23;
    break;
   case 29:
    var $90 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($90, $cx);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    __label__ = 57;
    break;
   case 30:
    var $_idx16_val24;
    var $i1_015;
    var $_idx18_val = HEAP32[$_idx18 >> 2];
    var $91 = __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEEixEj($_idx18_val, $i1_015);
    var $92 = HEAP32[$91 >> 2];
    var $93 = $92 + 16 | 0;
    if ((HEAP32[$93 >> 2] | 0) == 0) {
      var $_idx16_val = $_idx16_val24;
      __label__ = 34;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $96 = $92 + 20 | 0;
    var $97 = $92 | 0;
    var $j_010 = 0;
    __label__ = 32;
    break;
   case 32:
    var $j_010;
    var $100 = HEAP32[$96 >> 2] + ($j_010 << 3) | 0;
    var $101 = __ZN2js7analyze14ScriptAnalysis13getValueTypesERKNS0_8SSAValueE($this, $100);
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($101, $cx, $97);
    var $102 = $j_010 + 1 | 0;
    if ($102 >>> 0 < HEAPU32[$93 >> 2] >>> 0) {
      var $j_010 = $102;
      __label__ = 32;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $_idx16_val = HEAP32[$_idx17 >> 2];
    __label__ = 34;
    break;
   case 34:
    var $_idx16_val;
    var $105 = $i1_015 + 1 | 0;
    var $106 = __ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE6lengthEv($_idx16_val);
    if ($105 >>> 0 < $106 >>> 0) {
      var $i1_015 = $105;
      var $_idx16_val24 = $_idx16_val;
      __label__ = 30;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $108 = HEAP32[$11 >> 2];
    __label__ = 36;
    break;
   case 36:
    var $108;
    var $result_08 = HEAP32[HEAP32[$108 + 100 >> 2] + 16 >> 2];
    if (($result_08 | 0) == 0) {
      var $127 = $108;
      __label__ = 43;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $113 = $state + 28 | 0;
    var $_0 = $2 | 0;
    var $result_09 = $result_08;
    __label__ = 38;
    break;
   case 38:
    var $result_09;
    var $116 = HEAP32[$result_09 >> 2];
    if (($116 | 0) == -1) {
      __label__ = 40;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $this_idx8_val = HEAP32[$this_idx7 >> 2];
    var $119 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEjj($this_idx8_val, $116, 0);
    var $121 = HEAP32[$result_09 + 4 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($119, $cx, $121);
    __label__ = 41;
    break;
   case 40:
    var $123 = HEAP32[$113 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($2);
    var $_0_val = HEAP32[$_0 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($123, $cx, $_0_val);
    __label__ = 41;
    break;
   case 41:
    var $result_0 = HEAP32[$result_09 + 8 >> 2];
    if (($result_0 | 0) == 0) {
      __label__ = 42;
      break;
    } else {
      var $result_09 = $result_0;
      __label__ = 38;
      break;
    }
   case 42:
    var $127 = HEAP32[$11 >> 2];
    __label__ = 43;
    break;
   case 43:
    var $127;
    var $130 = HEAP32[$127 + 36 >> 2];
    if (($130 & 64 | 0) != 0 & ($130 & 131072 | 0) == 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 44:
    var $_idx1_val_idx_val = HEAP32[HEAP32[$127 + 100 >> 2] + 4 >> 2];
    var $136 = __ZNK8JSScript8functionEv($_idx1_val_idx_val);
    var $_idx5_val = HEAP16[$136 + 58 >> 1];
    var $137 = __ZNK10JSFunction13isHeavyweightEv($_idx5_val);
    if ($137) {
      __label__ = 48;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $_idx_val = HEAP32[HEAP32[$cx + 56 >> 2] + 804 >> 2];
    var $141 = __ZNK13JSCompartment9debugModeEv($_idx_val);
    if ($141) {
      __label__ = 48;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $this_idx19_val = HEAP8[$this + 24 | 0];
    var $143 = __ZN2js7analyze14ScriptAnalysis16localsAliasStackEv($this_idx19_val);
    if ($143) {
      __label__ = 48;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $_020 = $3 | 0;
    var $offset_2 = 0;
    var $145 = $127;
    __label__ = 49;
    break;
   case 48:
    __ZN2js5types20MarkArgumentsCreatedEP9JSContextP8JSScript($cx, $127);
    __label__ = 57;
    break;
   case 49:
    var $145;
    var $offset_2;
    if ($offset_2 >>> 0 < HEAPU32[$145 + 8 >> 2] >>> 0) {
      __label__ = 50;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 50:
    var $this_idx_val = HEAP32[$this_idx7 >> 2];
    var $150 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEj($this_idx_val, $offset_2);
    var $153 = HEAP32[$145 >> 2] + $offset_2 | 0;
    if (($150 | 0) == 0) {
      var $_pre22 = $145;
      __label__ = 55;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    if (HEAP8[$153] << 24 >> 24 == 9) {
      __label__ = 52;
      break;
    } else {
      var $_pre22 = $145;
      __label__ = 55;
      break;
    }
   case 52:
    __ZN2js15TempAllocPolicyC1EP9JSContext($3, $cx);
    var $_020_val = HEAP32[$_020 >> 2];
    __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEEC1ES3_($seen, $_020_val);
    __ZN2js7analyze8SSAValue11PushedValueEjj($4, $offset_2, 0);
    var $159 = __ZN2js7analyze14ScriptAnalysis23followEscapingArgumentsEP9JSContextRKNS0_8SSAValueEPNS_6VectorIS4_Lj0ENS_15TempAllocPolicyEEE($this, $cx, $4, $seen);
    if ($159) {
      __label__ = 54;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    var $160 = HEAP32[$11 >> 2];
    __ZN2js5types20MarkArgumentsCreatedEP9JSContextP8JSScript($cx, $160);
    __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEED1Ev($seen);
    __label__ = 57;
    break;
   case 54:
    __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEED1Ev($seen);
    var $_pre22 = HEAP32[$11 >> 2];
    __label__ = 55;
    break;
   case 55:
    var $_pre22;
    var $163 = __ZN2js7analyzeL17GetBytecodeLengthEPh1712($153);
    var $offset_2 = $163 + $offset_2 | 0;
    var $145 = $_pre22;
    __label__ = 49;
    break;
   case 56:
    var $166 = $145 + 38 | 0;
    var $168 = HEAP8[$166] | 1;
    HEAP8[$166] = $168;
    __label__ = 57;
    break;
   case 57:
    __ZN2js7analyze14ScriptAnalysis18TypeInferenceStateD1Ev($state);
    __label__ = 58;
    break;
   case 58:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis12analyzeTypesEP9JSContext["X"] = 1;

function __ZNK8JSScript16hasClearedGlobalEv($this_0_32_val_0_2_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_32_val_0_2_val | 0) == 0) {
      var $5 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js12GlobalObject9isClearedEv($this_0_32_val_0_2_val);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19DetachNestingParentP8JSScript($script) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx1_val_idx_val = HEAP32[HEAP32[$script + 100 >> 2] + 12 >> 2];
    var $3 = __ZNK8JSScript7nestingEv($_idx1_val_idx_val);
    if (($3 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$3 >> 2];
    if (($7 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val_idx_val = HEAP32[HEAP32[$7 + 100 >> 2] + 12 >> 2];
    var $12 = __ZNK8JSScript7nestingEv($_idx_val_idx_val);
    var $13 = $12 + 4 | 0;
    var $pscript_023_idx_val_idx_val = HEAP32[HEAP32[HEAP32[$13 >> 2] + 100 >> 2] + 12 >> 2];
    var $14 = __ZNK8JSScript7nestingEv($pscript_023_idx_val_idx_val);
    if (($14 | 0) == ($3 | 0)) {
      var $pscript_0_in_lcssa = $13;
      __label__ = 5;
      break;
    } else {
      var $16 = $14;
      __label__ = 4;
      break;
    }
   case 4:
    var $16;
    var $17 = $16 + 8 | 0;
    var $pscript_02_idx_val_idx_val = HEAP32[HEAP32[HEAP32[$17 >> 2] + 100 >> 2] + 12 >> 2];
    var $18 = __ZNK8JSScript7nestingEv($pscript_02_idx_val_idx_val);
    if (($18 | 0) == ($3 | 0)) {
      var $pscript_0_in_lcssa = $17;
      __label__ = 5;
      break;
    } else {
      var $16 = $18;
      __label__ = 4;
      break;
    }
   case 5:
    var $pscript_0_in_lcssa;
    var $21 = HEAP32[$3 + 8 >> 2];
    HEAP32[$pscript_0_in_lcssa >> 2] = $21;
    var $22 = $3 | 0;
    HEAP32[$22 >> 2] = 0;
    if ((HEAP8[$script + 37 | 0] & 16) << 24 >> 24 == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN8JSScript12clearNestingEv($script);
    __label__ = 7;
    break;
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19DetachNestingParentP8JSScript["X"] = 1;

function __ZN2js7analyze14ScriptAnalysis18TypeInferenceStateC1EP9JSContext($this, $cx) {
  __ZN2js7analyze14ScriptAnalysis18TypeInferenceStateC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js7analyzeL17GetBytecodeLengthEPh1712($pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAPU8[_js_CodeSpec + ((HEAPU8[$pc] & 255) << 3) | 0];
    if ($4 << 24 >> 24 == -1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = $4 << 24 >> 24;
    __label__ = 4;
    break;
   case 3:
    var $9 = __Z28js_GetVariableBytecodeLengthPh($pc);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEEixEj($this_0_1_val, $i) {
  var $1 = __ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE5beginEv($this_0_1_val);
  return $1 + ($i << 2) | 0;
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEEC1ES3_($this, $ap_01) {
  __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap_01);
  return;
}

function __ZN2js7analyze14ScriptAnalysis23followEscapingArgumentsEP9JSContextRKNS0_8SSAValueEPNS_6VectorIS4_Lj0ENS_15TempAllocPolicyEEE($this, $cx, $v, $seen) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN2js7analyze14ScriptAnalysis13trackUseChainERKNS0_8SSAValueE($v);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 2:
    var $seen_idx_val = HEAP32[$seen + 8 >> 2];
    var $3 = __ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE6lengthEv($seen_idx_val);
    var $seen_idx1 = $seen + 4 | 0;
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    if ($i_0 >>> 0 < $3 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $seen_idx1_val = HEAP32[$seen_idx1 >> 2];
    var $7 = __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEEixEj($seen_idx1_val, $i_0);
    var $8 = __ZNK2js7analyze8SSAValue6equalsERKS1_($v, $7);
    if ($8) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 3;
    break;
   case 6:
    var $12 = $v;
    var $13 = $1;
    var $14$0 = HEAP32[$12 >> 2];
    var $14$1 = HEAP32[$12 + 4 >> 2];
    HEAP32[$13 >> 2] = $14$0;
    HEAP32[$13 + 4 >> 2] = $14$1;
    var $15 = __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($seen, $1);
    if ($15) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($19, $cx);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 8:
    var $21 = __ZN2js7analyze14ScriptAnalysis8useChainERKNS0_8SSAValueE($this, $v);
    var $use_0_in = $21;
    __label__ = 9;
    break;
   case 9:
    var $use_0_in;
    var $use_0 = HEAP32[$use_0_in >> 2];
    if (($use_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $25 = __ZN2js7analyze14ScriptAnalysis23followEscapingArgumentsEP9JSContextPNS0_11SSAUseChainEPNS_6VectorINS0_8SSAValueELj0ENS_15TempAllocPolicyEEE($this, $cx, $use_0, $seen);
    if ($25) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 11:
    var $use_0_in = $use_0 + 8 | 0;
    __label__ = 9;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze8SSAValue11PushedValueEjj($agg_result, $offset, $index) {
  __ZN2js7analyze8SSAValue10initPushedEjj($agg_result, $offset, $index);
  return;
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7analyze14ScriptAnalysis18TypeInferenceStateD1Ev($this) {
  __ZN2js7analyze14ScriptAnalysis18TypeInferenceStateD2Ev($this);
  return;
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEEixEj($this_0_1_val, $i) {
  var $1 = __ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE5beginEv($this_0_1_val);
  return $1 + ($i << 3) | 0;
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $t;
  $t = STACKTOP;
  STACKTOP += 8;
  HEAP32[$t >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$t + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE13growStorageByEj($this);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = $t;
    var $11 = $1;
    var $12$0 = HEAP32[$10 >> 2];
    var $12$1 = HEAP32[$10 + 4 >> 2];
    HEAP32[$11 >> 2] = $12$0;
    HEAP32[$11 + 4 >> 2] = $12$1;
    __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $1);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis23followEscapingArgumentsEP9JSContextPNS0_11SSAUseChainEPNS_6VectorINS0_8SSAValueELj0ENS_15TempAllocPolicyEEE($this, $cx, $use, $seen) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    if ((HEAP8[$use | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $12 = HEAPU32[$use >> 2] >>> 1;
    var $15 = HEAP32[$use + 4 >> 2];
    __ZN2js7analyze8SSAValue8PhiValueEjPNS0_10SSAPhiNodeE($1, $12, $15);
    var $16 = __ZN2js7analyze14ScriptAnalysis23followEscapingArgumentsEP9JSContextRKNS0_8SSAValueEPNS_6VectorIS4_Lj0ENS_15TempAllocPolicyEEE($this, $cx, $1, $seen);
    var $_0 = $16;
    __label__ = 10;
    break;
   case 3:
    var $19 = HEAPU32[$this >> 2];
    var $22 = $use;
    var $24 = HEAPU32[$22 >> 2] >>> 1;
    var $25 = HEAP32[$19 >> 2] + $24 | 0;
    var $26 = HEAP8[$25];
    if ($26 << 24 >> 24 == 55) {
      __label__ = 4;
      break;
    } else if ($26 << 24 >> 24 == 87) {
      __label__ = 5;
      break;
    } else if ($26 << 24 >> 24 == 86) {
      __label__ = 8;
      break;
    } else if ($26 << 24 >> 24 == 81 || $26 << 24 >> 24 == 11 || $26 << 24 >> 24 == -36) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    if ((HEAP32[$use + 4 >> 2] | 0) == 1) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 5:
    var $32 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh1709($19, $25);
    var $33 = __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $32);
    if ($33) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    __ZN2js7analyze8SSAValue11PushedValueEjj($2, $24, 0);
    var $35 = __ZN2js7analyze14ScriptAnalysis23followEscapingArgumentsEP9JSContextRKNS0_8SSAValueEPNS_6VectorIS4_Lj0ENS_15TempAllocPolicyEEE($this, $cx, $2, $seen);
    if ($35) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    var $38 = HEAPU32[$22 >> 2] >>> 1;
    __ZN2js7analyze8SSAValue10WrittenVarEjj($3, $32, $38);
    var $39 = __ZN2js7analyze14ScriptAnalysis23followEscapingArgumentsEP9JSContextRKNS0_8SSAValueEPNS_6VectorIS4_Lj0ENS_15TempAllocPolicyEEE($this, $cx, $3, $seen);
    var $_0 = $39;
    __label__ = 10;
    break;
   case 8:
    __ZN2js7analyze8SSAValue11PushedValueEjj($4, $24, 0);
    var $41 = __ZN2js7analyze14ScriptAnalysis23followEscapingArgumentsEP9JSContextRKNS0_8SSAValueEPNS_6VectorIS4_Lj0ENS_15TempAllocPolicyEEE($this, $cx, $4, $seen);
    var $_0 = $41;
    __label__ = 10;
    break;
   case 9:
    var $_0 = 0;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze8SSAValue8PhiValueEjPNS0_10SSAPhiNodeE($agg_result, $offset, $node) {
  __ZN2js7analyze8SSAValue7initPhiEjPNS0_10SSAPhiNodeE($agg_result, $offset, $node);
  return;
}

function __ZN2js7analyze8SSAValue10WrittenVarEjj($agg_result, $slot, $offset) {
  __ZN2js7analyze8SSAValue11initWrittenEjj($agg_result, $slot, $offset);
  return;
}

function __ZN2js7analyze17AutoEnterAnalysisC1EP9JSContext($this, $cx) {
  __ZN2js7analyze17AutoEnterAnalysisC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js7analyze17AutoEnterAnalysisD1Ev($this) {
  __ZN2js7analyze17AutoEnterAnalysisD2Ev($this);
  return;
}

function __ZN2js5types23MarkIteratorUnknownSlowEP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pc = __stackBase__;
    var $untrap = __stackBase__ + 4;
    var $enter = __stackBase__ + 12;
    var $1 = __stackBase__ + 20;
    var $2 = __stackBase__ + 24;
    var $3 = $cx + 60 | 0;
    var $4 = __ZNK2js12ContextStack13currentScriptEPPh($3, $pc);
    if (($4 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$pc >> 2];
    if (($7 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $4, $7);
    if (HEAP8[HEAP32[$pc >> 2]] << 24 >> 24 == 75) {
      __label__ = 4;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 4:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    var $14 = $4 + 100 | 0;
    var $result_0_in = HEAP32[$14 >> 2] + 16 | 0;
    __label__ = 5;
    break;
   case 5:
    var $result_0_in;
    var $result_0 = HEAP32[$result_0_in >> 2];
    if (($result_0 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$result_0 >> 2] | 0) == -1) {
      __label__ = 21;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $result_0_in = $result_0 + 8 | 0;
    __label__ = 5;
    break;
   case 8:
    __ZN2js5types4Type11UnknownTypeEv($1);
    var $_010_val = HEAP32[$1 >> 2];
    var $26 = __ZN9JSContext4new_IN2js5types10TypeResultEjNS2_4TypeEEEPT_T0_T1_($cx, $_010_val);
    if (($26 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $31 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($31, $cx);
    __label__ = 21;
    break;
   case 10:
    var $35 = HEAP32[HEAP32[$14 >> 2] + 16 >> 2];
    var $36 = $26 + 8 | 0;
    HEAP32[$36 >> 2] = $35;
    var $38 = HEAP32[$14 >> 2] + 16 | 0;
    HEAP32[$38 >> 2] = $26;
    var $_idx3_val = HEAP32[$14 >> 2];
    var $39 = __ZN8JSScript11hasAnalysisEv($_idx3_val);
    if ($39) {
      __label__ = 11;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 11:
    var $_idx4_val_idx_val = HEAP32[$_idx3_val >> 2];
    var $41 = __ZN8JSScript8analysisEv($_idx4_val_idx_val);
    var $_idx5_val = HEAP8[$41 + 23 | 0];
    var $42 = __ZN2js7analyze14ScriptAnalysis12ranInferenceEv($_idx5_val);
    if ($42) {
      __label__ = 12;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 12:
    var $43 = $4 + 8 | 0;
    if ((HEAP32[$43 >> 2] | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $46 = $4 | 0;
    var $_idx8 = $41 | 0;
    var $_idx9 = $41 + 4 | 0;
    var $_0 = $2 | 0;
    var $i_01 = 0;
    __label__ = 14;
    break;
   case 14:
    var $i_01;
    var $48 = HEAP32[$46 >> 2] + $i_01 | 0;
    var $_idx9_val = HEAP32[$_idx9 >> 2];
    var $_idx8_val_idx_val = HEAP32[HEAP32[$_idx8 >> 2] >> 2];
    var $49 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEPKh($_idx8_val_idx_val, $_idx9_val, $48);
    if (($49 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $52 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh1705($4, $48);
    if (($52 | 0) == 77) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $_idx7_val = HEAP32[$_idx9 >> 2];
    var $_idx6_val_idx_val = HEAP32[HEAP32[$_idx8 >> 2] >> 2];
    var $55 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEPKhj($_idx6_val_idx_val, $_idx7_val, $48, 0);
    __ZN2js5types4Type11UnknownTypeEv($2);
    var $_0_val = HEAP32[$_0 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($55, $cx, $_0_val);
    __label__ = 17;
    break;
   case 17:
    var $56 = $i_01 + 1 | 0;
    if ($56 >>> 0 < HEAPU32[$43 >> 2] >>> 0) {
      var $i_01 = $56;
      __label__ = 14;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if ((HEAP8[$4 + 37 | 0] & 4) << 24 >> 24 == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $_idx_val_idx_val = HEAP32[HEAP32[$14 >> 2] + 4 >> 2];
    var $64 = __ZNK8JSScript8functionEv($_idx_val_idx_val);
    var $_idx1_val = HEAP32[$64 + 8 >> 2];
    var $65 = __ZNK8JSObject11hasLazyTypeEv($_idx1_val);
    if ($65) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $_idx2_val = HEAP32[$64 + 36 >> 2];
    var $67 = __ZNK8JSObject4typeEv($_idx2_val);
    __ZL17ObjectStateChangeP9JSContextPN2js5types10TypeObjectEbb($cx, $67, 0, 1);
    __label__ = 21;
    break;
   case 21:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    __label__ = 22;
    break;
   case 22:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    __label__ = 23;
    break;
   case 23:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types23MarkIteratorUnknownSlowEP9JSContext["X"] = 1;

function __ZN9JSContext4new_IN2js5types10TypeResultEjNS2_4TypeEEEPT_T0_T1_($this, $p2_0) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 12);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js5types10TypeResultC1EjNS0_4TypeE($4, -1, $p2_0);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types19TypeMonitorCallSlowEP9JSContextP8JSObjectRKNS_8CallArgsEb($cx, $callee_0_6_val, $args, $constructing) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK8JSObject18getFunctionPrivateEv($callee_0_6_val);
    var $4 = HEAPU16[$2 + 56 >> 1];
    var $5 = $4 & 65535;
    var $6 = __ZNK10JSFunction6scriptEv($2);
    if ($constructing) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$args >> 2];
    var $8 = __ZNK2js12CallReceiver5thisvEv($_idx_val);
    __ZN2js5types10TypeScript7SetThisEP9JSContextP8JSScriptRKN2JS5ValueE($cx, $6, $8);
    __label__ = 3;
    break;
   case 3:
    var $args_idx1 = $args + 4 | 0;
    var $args_idx1_val = HEAP32[$args_idx1 >> 2];
    var $9 = __ZNK2js8CallArgs4argcEv($args_idx1_val);
    if (($9 | 0) != 0 & $4 << 16 >> 16 != 0) {
      __label__ = 4;
      break;
    } else {
      var $arg_0_lcssa = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $args_idx2 = $args | 0;
    var $arg_03 = 0;
    __label__ = 6;
    break;
   case 5:
    var $arg_0_lcssa;
    if ($arg_0_lcssa >>> 0 < $5 >>> 0) {
      var $arg_11 = $arg_0_lcssa;
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $arg_03;
    var $args_idx2_val = HEAP32[$args_idx2 >> 2];
    var $13 = __ZNK2js8CallArgsixEj($args_idx2_val, $arg_03);
    __ZN2js5types10TypeScript11SetArgumentEP9JSContextP8JSScriptjRKN2JS5ValueE($cx, $6, $arg_03, $13);
    var $14 = $arg_03 + 1 | 0;
    var $args_idx_val = HEAP32[$args_idx1 >> 2];
    var $15 = __ZNK2js8CallArgs4argcEv($args_idx_val);
    if ($14 >>> 0 < $15 >>> 0 & $14 >>> 0 < $5 >>> 0) {
      var $arg_03 = $14;
      __label__ = 6;
      break;
    } else {
      var $arg_0_lcssa = $14;
      __label__ = 5;
      break;
    }
   case 7:
    var $arg_11;
    __ZN2JSL14UndefinedValueEv1713($1);
    __ZN2js5types10TypeScript11SetArgumentEP9JSContextP8JSScriptjRKN2JS5ValueE($cx, $6, $arg_11, $1);
    var $18 = $arg_11 + 1 | 0;
    if (($18 | 0) == ($5 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $arg_11 = $18;
      __label__ = 7;
      break;
    }
   case 8:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript7SetThisEP9JSContextP8JSScriptRKN2JS5ValueE($cx, $script, $value) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $2 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $value_idx = $value | 0;
    var $value_idx_val$0 = HEAP32[$value_idx >> 2];
    var $value_idx_val$1 = HEAP32[$value_idx + 4 >> 2];
    __ZN2js5types12GetValueTypeEP9JSContextRKN2JS5ValueE($1, $value_idx_val$0, $value_idx_val$1);
    var $_0_val = HEAP32[$1 >> 2];
    __ZN2js5types10TypeScript7SetThisEP9JSContextP8JSScriptNS0_4TypeE($cx, $script, $_0_val);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL14UndefinedValueEv1713($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2js5types17TypeDynamicResultEP9JSContextP8JSScriptPhNS0_4TypeE($cx, $script, $pc, $type_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $untrap = __stackBase__ + 8;
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $script, $pc);
    var $2 = HEAPU8[$pc] & 255;
    var $4 = HEAPU32[_js_CodeSpec + ($2 << 3) + 4 >> 2];
    if (($4 & 67108864 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZN8JSScript17ensureRanAnalysisEP9JSContextP10JSFunctionP8JSObject($script, $cx, 0, 0);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($12, $cx);
    __label__ = 29;
    break;
   case 4:
    var $script_idx10_val_idx_val = HEAP32[HEAP32[$script + 100 >> 2] >> 2];
    var $14 = __ZN8JSScript8analysisEv($script_idx10_val_idx_val);
    var $_idx20_val = HEAP32[$14 + 4 >> 2];
    var $_idx19_val_idx_val = HEAP32[HEAP32[$14 >> 2] >> 2];
    var $15 = __ZN2js7analyze14ScriptAnalysis13bytecodeTypesEPKh($_idx19_val_idx_val, $_idx20_val, $pc);
    var $16 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($15, $type_0);
    if ($16) {
      __label__ = 29;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($15, $cx, $type_0);
    __label__ = 29;
    break;
   case 6:
    if (($4 & 3072 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($2 - 97 | 0) >>> 0 < 8) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $23 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh1709($script, $pc);
    var $24 = __ZN2js7analyzeL10TotalSlotsEP8JSScript1710($script);
    if ($23 >>> 0 < $24 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $script_idx17_val = HEAP16[$script + 22 >> 1];
    var $script_idx18_val = HEAP32[$script + 100 >> 2];
    var $27 = __ZN2js5types10TypeScript9SlotTypesEP8JSScriptj($script_idx17_val, $script_idx18_val, $23);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($27, $cx, $type_0);
    __label__ = 10;
    break;
   case 10:
    var $script_idx7 = $script + 100 | 0;
    var $script_idx7_val = HEAPU32[$script_idx7 >> 2];
    var $29 = __ZN8JSScript11hasAnalysisEv($script_idx7_val);
    if ($29) {
      __label__ = 11;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 11:
    var $script_idx9_val_idx_val = HEAP32[$script_idx7_val >> 2];
    var $31 = __ZN8JSScript8analysisEv($script_idx9_val_idx_val);
    var $_idx12_val = HEAP8[$31 + 23 | 0];
    var $32 = __ZN2js7analyze14ScriptAnalysis12ranInferenceEv($_idx12_val);
    if ($32) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $_idx16_val = HEAP32[$31 + 4 >> 2];
    var $_idx15_val_idx_val = HEAP32[HEAP32[$31 >> 2] >> 2];
    var $34 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEPKhj($_idx15_val_idx_val, $_idx16_val, $pc, 0);
    var $35 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($34, $type_0);
    if ($35) {
      __label__ = 29;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $_pre_phi = $script | 0;
    var $_pre_phi10 = $pc;
    __label__ = 21;
    break;
   case 14:
    var $37 = $script_idx7_val + 16 | 0;
    var $38 = $script | 0;
    var $39 = $pc;
    var $presult_0 = $37;
    __label__ = 15;
    break;
   case 15:
    var $presult_0;
    var $41 = HEAP32[$presult_0 >> 2];
    if (($41 | 0) == 0) {
      var $_pre_phi = $38;
      var $_pre_phi10 = $39;
      __label__ = 21;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if ((HEAP32[$41 >> 2] | 0) == ($39 - HEAP32[$38 >> 2] | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 17:
    var $_idx21_val = HEAP32[$41 + 4 >> 2];
    var $51 = __ZNK2js5types4TypeeqES1_($_idx21_val, $type_0);
    if ($51) {
      __label__ = 18;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 18:
    if (($presult_0 | 0) == ($37 | 0)) {
      __label__ = 29;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $55 = $41 + 8 | 0;
    var $56 = HEAP32[$55 >> 2];
    HEAP32[$presult_0 >> 2] = $56;
    var $57 = HEAP32[$37 >> 2];
    HEAP32[$55 >> 2] = $57;
    HEAP32[$37 >> 2] = $41;
    __label__ = 29;
    break;
   case 20:
    var $presult_0 = $41 + 8 | 0;
    __label__ = 15;
    break;
   case 21:
    var $_pre_phi10;
    var $_pre_phi;
    var $62 = $_pre_phi10 - HEAP32[$_pre_phi >> 2] | 0;
    var $63 = __ZN9JSContext4new_IN2js5types10TypeResultEiNS2_4TypeEEEPT_T0_T1_($cx, $62, $type_0);
    if (($63 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    var $68 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($68, $cx);
    __label__ = 29;
    break;
   case 23:
    var $72 = HEAP32[HEAP32[$script_idx7 >> 2] + 16 >> 2];
    var $73 = $63 + 8 | 0;
    HEAP32[$73 >> 2] = $72;
    var $75 = HEAP32[$script_idx7 >> 2] + 16 | 0;
    HEAP32[$75 >> 2] = $63;
    var $script_idx6_val = HEAP32[$script_idx7 >> 2];
    var $76 = __ZN8JSScript11hasAnalysisEv($script_idx6_val);
    if ($76) {
      __label__ = 24;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 24:
    var $script_idx8_val_idx_val = HEAP32[$script_idx6_val >> 2];
    var $78 = __ZN8JSScript8analysisEv($script_idx8_val_idx_val);
    var $_idx11_val = HEAP8[$78 + 23 | 0];
    var $79 = __ZN2js7analyze14ScriptAnalysis12ranInferenceEv($_idx11_val);
    if ($79) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    var $_idx14_val = HEAP32[$78 + 4 >> 2];
    var $_idx13_val_idx_val = HEAP32[HEAP32[$78 >> 2] >> 2];
    var $81 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEPKhj($_idx13_val_idx_val, $_idx14_val, $pc, 0);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($81, $cx, $type_0);
    __label__ = 26;
    break;
   case 26:
    if ((HEAP8[$script + 37 | 0] & 4) << 24 >> 24 == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $script_idx_val_idx_val = HEAP32[HEAP32[$script_idx7 >> 2] + 4 >> 2];
    var $88 = __ZNK8JSScript8functionEv($script_idx_val_idx_val);
    var $_idx_val = HEAP32[$88 + 8 >> 2];
    var $89 = __ZNK8JSObject11hasLazyTypeEv($_idx_val);
    if ($89) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $_idx1_val = HEAP32[$88 + 36 >> 2];
    var $91 = __ZNK8JSObject4typeEv($_idx1_val);
    __ZL17ObjectStateChangeP9JSContextPN2js5types10TypeObjectEbb($cx, $91, 0, 1);
    __label__ = 29;
    break;
   case 29:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types17TypeDynamicResultEP9JSContextP8JSScriptPhNS0_4TypeE["X"] = 1;

function __ZN9JSContext4new_IN2js5types10TypeResultEiNS2_4TypeEEEPT_T0_T1_($this, $p1, $p2_0) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 12);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js5types10TypeResultC1EjNS0_4TypeE($4, $p1, $p2_0);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types17TypeMonitorResultEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script, $pc, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $untrap = __stackBase__;
    var $enter = __stackBase__ + 8;
    var $type = __stackBase__ + 16;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $script, $pc);
    if ((HEAP32[_js_CodeSpec + ((HEAPU8[$pc] & 255) << 3) + 4 >> 2] & 67108864 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    var $8 = __ZN8JSScript17ensureRanAnalysisEP9JSContextP10JSFunctionP8JSObject($script, $cx, 0, 0);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($12, $cx);
    __label__ = 6;
    break;
   case 4:
    var $rval_idx = $rval | 0;
    var $rval_idx_val$0 = HEAP32[$rval_idx >> 2];
    var $rval_idx_val$1 = HEAP32[$rval_idx + 4 >> 2];
    __ZN2js5types12GetValueTypeEP9JSContextRKN2JS5ValueE($type, $rval_idx_val$0, $rval_idx_val$1);
    var $script_idx_val_idx_val = HEAP32[HEAP32[$script + 100 >> 2] >> 2];
    var $14 = __ZN8JSScript8analysisEv($script_idx_val_idx_val);
    var $_idx2_val = HEAP32[$14 + 4 >> 2];
    var $_idx_val_idx_val = HEAP32[HEAP32[$14 >> 2] >> 2];
    var $15 = __ZN2js7analyze14ScriptAnalysis13bytecodeTypesEPKh($_idx_val_idx_val, $_idx2_val, $pc);
    var $17 = HEAP32[$type >> 2];
    var $18 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($15, $17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($15, $cx, $17);
    __label__ = 6;
    break;
   case 6:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    __label__ = 7;
    break;
   case 7:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript8SetScopeEP9JSContextP8JSScriptP8JSObject($cx, $script, $scope) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $script + 100 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $4 = HEAP32[$2 + 4 >> 2];
    if ((HEAP8[$script + 36 | 0] & 16) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = $2 + 8 | 0;
    HEAP32[$10 >> 2] = 0;
    var $_0 = 1;
    __label__ = 22;
    break;
   case 3:
    if (($4 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $4;
    var $15 = __ZNK8JSObject9getGlobalEv($14);
    var $_in = $15;
    __label__ = 6;
    break;
   case 5:
    var $17 = $scope;
    var $18 = __ZNK8JSObject9getGlobalEv($17);
    var $_in = $18;
    __label__ = 6;
    break;
   case 6:
    var $_in;
    var $21 = $2 + 8 | 0;
    HEAP32[$21 >> 2] = $_in;
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $22 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($22) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 22;
      break;
    }
   case 7:
    var $25 = HEAP8[$script + 37 | 0];
    if (($25 & 32) << 24 >> 24 == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx10_val = HEAP16[$4 + 58 >> 1];
    var $29 = __ZNK10JSFunction13isNullClosureEv($_idx10_val);
    if ($29) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_idx8_val = HEAP32[$scope + 4 >> 2];
    var $31 = __ZNK8JSObject6isCallEv($_idx8_val);
    if ($31) {
      var $_lcssa_in = $scope;
      __label__ = 14;
      break;
    } else {
      var $_013 = $scope;
      __label__ = 13;
      break;
    }
   case 10:
    if (($25 & 16) << 24 >> 24 == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $36 = __ZN9JSContext4new_IN2js5types17TypeScriptNestingEEEPT_v($cx);
    var $38 = HEAP32[$1 >> 2] + 12 | 0;
    HEAP32[$38 >> 2] = $36;
    if ((HEAP32[HEAP32[$1 >> 2] + 12 >> 2] | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $_0 = 1;
    __label__ = 22;
    break;
   case 13:
    var $_013;
    var $_013_idx_val = HEAP32[$_013 + 20 >> 2];
    var $44 = __ZNK8JSObject9getParentEv($_013_idx_val);
    var $_idx7_val = HEAP32[$44 + 4 >> 2];
    var $46 = __ZNK8JSObject6isCallEv($_idx7_val);
    if ($46) {
      var $_lcssa_in = $44;
      __label__ = 14;
      break;
    } else {
      var $_013 = $44;
      __label__ = 13;
      break;
    }
   case 14:
    var $_lcssa_in;
    var $_lcssa = $_lcssa_in;
    var $47 = __ZN8JSObject6asCallEv($_lcssa_in);
    var $48 = $47;
    var $49 = __ZNK2js10CallObject17getCalleeFunctionEv($48);
    if (($49 | 0) == 0) {
      var $_0 = 1;
      __label__ = 22;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $_idx9_val = HEAP16[$49 + 58 >> 1];
    var $52 = __ZNK10JSFunction13isHeavyweightEv($_idx9_val);
    if ($52) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 1;
      __label__ = 22;
      break;
    }
   case 16:
    var $54 = __ZNK10JSFunction6scriptEv($49);
    var $55 = __ZN8JSScript14ensureHasTypesEP9JSContextP10JSFunction($54, $cx, $49);
    if ($55) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 17:
    var $57 = $54 + 100 | 0;
    var $_idx_val = HEAP32[HEAP32[$57 >> 2] + 8 >> 2];
    var $59 = __ZN2js5types10TypeScript8hasScopeEv($_idx_val);
    if ($59) {
      __label__ = 20;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $_01_lcssa_idx_val = HEAP32[$_lcssa_in + 20 >> 2];
    var $61 = __ZNK8JSObject9getParentEv($_01_lcssa_idx_val);
    var $62 = __ZN2js5types10TypeScript8SetScopeEP9JSContextP8JSScriptP8JSObject($cx, $54, $61);
    if ($62) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 19:
    var $_idx6_val_idx_val = HEAP32[HEAP32[$57 >> 2] + 12 >> 2];
    var $66 = __ZNK8JSScript7nestingEv($_idx6_val_idx_val);
    var $67 = $66 + 12 | 0;
    HEAP32[$67 >> 2] = $_lcssa;
    var $68 = __ZN2js10CallObject8argArrayEv($48);
    var $_idx5_val_idx_val = HEAP32[HEAP32[$57 >> 2] + 12 >> 2];
    var $71 = __ZNK8JSScript7nestingEv($_idx5_val_idx_val);
    var $72 = $71 + 16 | 0;
    HEAP32[$72 >> 2] = $68;
    var $73 = __ZN2js10CallObject8varArrayEv($48);
    var $_idx4_val_idx_val = HEAP32[HEAP32[$57 >> 2] + 12 >> 2];
    var $76 = __ZNK8JSScript7nestingEv($_idx4_val_idx_val);
    var $77 = $76 + 20 | 0;
    HEAP32[$77 >> 2] = $73;
    __label__ = 20;
    break;
   case 20:
    var $79 = __ZN9JSContext4new_IN2js5types17TypeScriptNestingEEEPT_v($cx);
    var $81 = HEAP32[$1 >> 2] + 12 | 0;
    HEAP32[$81 >> 2] = $79;
    var $84 = HEAP32[HEAP32[$1 >> 2] + 12 >> 2];
    if (($84 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $87 = $script;
    var $_idx3_val_idx_val = $84;
    var $88 = __ZNK8JSScript7nestingEv($_idx3_val_idx_val);
    var $89 = $88 | 0;
    HEAP32[$89 >> 2] = $54;
    var $_c_idx2_val_idx_val = HEAP32[HEAP32[$57 >> 2] + 12 >> 2];
    var $92 = __ZNK8JSScript7nestingEv($_c_idx2_val_idx_val);
    var $94 = HEAP32[$92 + 4 >> 2];
    var $_idx1_val_idx_val = HEAP32[HEAP32[$1 >> 2] + 12 >> 2];
    var $97 = __ZNK8JSScript7nestingEv($_idx1_val_idx_val);
    var $98 = $97 + 8 | 0;
    HEAP32[$98 >> 2] = $94;
    var $_c_idx_val_idx_val = HEAP32[HEAP32[$57 >> 2] + 12 >> 2];
    var $101 = __ZNK8JSScript7nestingEv($_c_idx_val_idx_val);
    var $102 = $101 + 4 | 0;
    HEAP32[$102 >> 2] = $87;
    var $_0 = 1;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types10TypeScript8SetScopeEP9JSContextP8JSScriptP8JSObject["X"] = 1;

function __ZNK10JSFunction13isNullClosureEv($this_0_2_val) {
  var $1 = __ZNK10JSFunction4kindEv($this_0_2_val);
  return $1 << 16 >> 16 == -16384;
}

function __ZN9JSContext4new_IN2js5types17TypeScriptNestingEEEPT_v($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 28);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js5types17TypeScriptNestingC1Ev($4);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types17TypeScriptNestingD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    if (($2 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val_idx_val = HEAP32[HEAP32[$2 + 100 >> 2] + 12 >> 2];
    var $7 = __ZNK8JSScript7nestingEv($_idx1_val_idx_val);
    var $8 = $7 + 4 | 0;
    var $pscript_023_idx_val_idx_val = HEAP32[HEAP32[HEAP32[$8 >> 2] + 100 >> 2] + 12 >> 2];
    var $9 = __ZNK8JSScript7nestingEv($pscript_023_idx_val_idx_val);
    if (($9 | 0) == ($this | 0)) {
      var $pscript_0_in_lcssa = $8;
      __label__ = 4;
      break;
    } else {
      var $12 = $9;
      __label__ = 3;
      break;
    }
   case 3:
    var $12;
    var $13 = $12 + 8 | 0;
    var $pscript_02_idx_val_idx_val = HEAP32[HEAP32[HEAP32[$13 >> 2] + 100 >> 2] + 12 >> 2];
    var $14 = __ZNK8JSScript7nestingEv($pscript_02_idx_val_idx_val);
    if (($14 | 0) == ($this | 0)) {
      var $pscript_0_in_lcssa = $13;
      __label__ = 4;
      break;
    } else {
      var $12 = $14;
      __label__ = 3;
      break;
    }
   case 4:
    var $pscript_0_in_lcssa;
    var $_c = HEAP32[$this + 8 >> 2];
    HEAP32[$pscript_0_in_lcssa >> 2] = $_c;
    __label__ = 5;
    break;
   case 5:
    var $19 = $this + 4 | 0;
    var $20 = HEAP32[$19 >> 2];
    if (($20 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $22 = $20;
      __label__ = 6;
      break;
    }
   case 6:
    var $22;
    var $_idx_val_idx_val = HEAP32[HEAP32[$22 + 100 >> 2] + 12 >> 2];
    var $25 = __ZNK8JSScript7nestingEv($_idx_val_idx_val);
    var $26 = $25 + 8 | 0;
    var $28 = HEAP32[$26 >> 2];
    HEAP32[$19 >> 2] = $28;
    var $29 = $25 | 0;
    HEAP32[$29 >> 2] = 0;
    HEAP32[$26 >> 2] = 0;
    var $30 = HEAP32[$19 >> 2];
    if (($30 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $22 = $30;
      __label__ = 6;
      break;
    }
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types17TypeScriptNestingD2Ev["X"] = 1;

function __ZNK8JSObject18hasSpecialEqualityEv($this_0_2_val) {
  return ($this_0_2_val & 2048 | 0) != 0;
}

function __ZN2js5types18ClearActiveNestingEP8JSScript($start) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $traverseChildren_0_ph = 0;
    var $script_0_ph = $start;
    __label__ = 2;
    break;
   case 2:
    var $script_0_ph;
    var $traverseChildren_0_ph;
    var $script_0 = $script_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $script_0;
    var $_idx_val_idx_val = HEAP32[HEAP32[$script_0 + 100 >> 2] + 12 >> 2];
    var $4 = __ZNK8JSScript7nestingEv($_idx_val_idx_val);
    var $6 = HEAP32[$4 + 4 >> 2];
    var $7 = $6;
    if (($6 | 0) == 0 | $traverseChildren_0_ph) {
      __label__ = 4;
      break;
    } else {
      var $script_0 = $7;
      __label__ = 3;
      break;
    }
   case 4:
    if ((HEAP32[$4 + 24 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    if ((HEAP8[$script_0 + 37 | 0] & 16) << 24 >> 24 == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = $4 + 12 | 0;
    HEAP32[$19 >> 2] = 0;
    var $20 = $4 + 16 | 0;
    HEAP32[$20 >> 2] = 0;
    var $21 = $4 + 20 | 0;
    HEAP32[$21 >> 2] = 0;
    __label__ = 7;
    break;
   case 7:
    if (($script_0 | 0) == ($start | 0)) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $26 = HEAP32[$4 + 8 >> 2];
    if (($26 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $traverseChildren_0_ph = 0;
    var $script_0_ph = $26;
    __label__ = 2;
    break;
   case 10:
    var $traverseChildren_0_ph = 1;
    var $script_0_ph = HEAP32[$4 >> 2];
    __label__ = 2;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15NestingPrologueEP9JSContextPNS_10StackFrameE($cx, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame3funEv($fp);
    var $2 = __ZNK10JSFunction6scriptEv($1);
    var $_idx_val_idx_val = HEAP32[HEAP32[$2 + 100 >> 2] + 12 >> 2];
    var $5 = __ZNK8JSScript7nestingEv($_idx_val_idx_val);
    if ((HEAP32[$5 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZNK2js10StackFrame10scopeChainEv($fp);
    __ZN2js5typesL18CheckNestingParentEP9JSContextP8JSObjectP8JSScript($cx, $10, $2);
    __label__ = 3;
    break;
   case 3:
    if ((HEAP8[$2 + 37 | 0] & 16) << 24 >> 24 == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = __ZN2js5types18ClearActiveNestingEP8JSScript($2);
    if ($17) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = $2 + 38 | 0;
    var $21 = HEAP8[$19] | 8;
    HEAP8[$19] = $21;
    var $22 = __ZNK2js10StackFrame3funEv($fp);
    var $23 = $22 | 0;
    __ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj($cx, $23, 8388608);
    __label__ = 6;
    break;
   case 6:
    var $25 = $fp;
    var $26 = __ZNK2js10StackFrame7callObjEv($25);
    var $27 = $5 + 12 | 0;
    HEAP32[$27 >> 2] = $26 | 0;
    var $28 = __ZNK2js10StackFrame10formalArgsEv($fp);
    var $29 = $5 + 16 | 0;
    HEAP32[$29 >> 2] = $28;
    var $30 = __ZNK2js10StackFrame5slotsEv($25);
    var $31 = $5 + 20 | 0;
    HEAP32[$31 >> 2] = $30;
    __label__ = 7;
    break;
   case 7:
    var $33 = $5 + 24 | 0;
    var $35 = HEAP32[$33 >> 2] + 1 | 0;
    HEAP32[$33 >> 2] = $35;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5typesL18CheckNestingParentEP9JSContextP8JSObjectP8JSScript($cx, $scope, $script) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $scope;
    var $2 = HEAP32[HEAP32[$script + 100 >> 2] + 12 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $2;
    var $_01;
    var $3 = __ZNK8JSScript7nestingEv($2);
    var $5 = HEAP32[$3 >> 2];
    var $_1 = $_01;
    __label__ = 3;
    break;
   case 3:
    var $_1;
    var $_idx5_val = HEAP32[$_1 + 4 >> 2];
    var $8 = __ZNK8JSObject6isCallEv($_idx5_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = __ZN8JSObject6asCallEv($_1);
    var $11 = $10;
    var $12 = __ZNK2js10CallObject17getCalleeFunctionEv($11);
    var $13 = __ZNK10JSFunction6scriptEv($12);
    if (($13 | 0) == ($5 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_1_idx1_val = HEAP32[$_1 + 20 >> 2];
    var $15 = __ZNK8JSObject9getParentEv($_1_idx1_val);
    var $_1 = $15;
    __label__ = 3;
    break;
   case 6:
    var $_idx3 = $5 + 100 | 0;
    var $17 = HEAP32[$_idx3 >> 2];
    var $_idx3_val_idx_val = HEAP32[$17 + 12 >> 2];
    var $19 = __ZNK8JSScript7nestingEv($_idx3_val_idx_val);
    if (($_1 | 0) == (HEAP32[$19 + 12 >> 2] | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = $5 + 38 | 0;
    var $27 = HEAP8[$25] | 8;
    HEAP8[$25] = $27;
    var $_idx_val_idx_val = HEAP32[$17 + 4 >> 2];
    var $28 = __ZNK8JSScript8functionEv($_idx_val_idx_val);
    var $29 = $28 | 0;
    __ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj($cx, $29, 8388608);
    var $31 = HEAP32[HEAP32[$_idx3 >> 2] + 12 >> 2];
    var $_idx2_val_idx_val = $31;
    var $32 = __ZNK8JSScript7nestingEv($_idx2_val_idx_val);
    if ((HEAP32[$32 >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_1_idx_val = HEAP32[$_1 + 20 >> 2];
    var $37 = __ZNK8JSObject9getParentEv($_1_idx_val);
    var $_01 = $37;
    var $2 = $31;
    __label__ = 2;
    break;
   case 9:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5typesL18CheckNestingParentEP9JSContextP8JSObjectP8JSScript["X"] = 1;

function __ZN2js5types15NestingEpilogueEPNS_10StackFrameE($fp) {
  var $1 = __ZNK2js10StackFrame3funEv($fp);
  var $2 = __ZNK10JSFunction6scriptEv($1);
  var $_idx_val_idx_val = HEAP32[HEAP32[$2 + 100 >> 2] + 12 >> 2];
  var $5 = __ZNK8JSScript7nestingEv($_idx_val_idx_val);
  var $6 = $5 + 24 | 0;
  var $8 = HEAP32[$6 >> 2] - 1 | 0;
  HEAP32[$6 >> 2] = $8;
  return;
}

function __ZN8JSScript9makeTypesEP9JSContextP10JSFunction($this, $cx, $fun) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN9JSContext7calloc_Ej($cx, 20);
    var $4 = $3;
    HEAP32[$this + 100 >> 2] = $4;
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js5types10TypeScriptC1EP10JSFunction($4, $fun);
    var $_1 = 1;
    __label__ = 10;
    break;
   case 4:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    if (($fun | 0) == 0) {
      var $15 = 2;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = (HEAPU16[$fun + 56 >> 1] & 65535) + 2 | 0;
    __label__ = 6;
    break;
   case 6:
    var $15;
    var $25 = ((HEAPU16[$this + 14 >> 1] & 65535) + $15 + (HEAPU16[$this + 22 >> 1] & 65535)) * 12 + 20 | 0;
    var $26 = __ZN9JSContext7calloc_Ej($cx, $25);
    var $27 = $26;
    HEAP32[$this + 100 >> 2] = $27;
    if (($26 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $33 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($33, $cx);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 8:
    __ZN2js5types10TypeScriptC1EP10JSFunction($27, $fun);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    var $_1 = $_0;
    __label__ = 10;
    break;
   case 10:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSScript9makeTypesEP9JSContextP10JSFunction["X"] = 1;

function __ZN2js5types10TypeScriptC1EP10JSFunction($this, $fun) {
  __ZN2js5types10TypeScriptC2EP10JSFunction($this, $fun);
  return;
}

function __ZN8JSScript12makeAnalysisEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZN2js7analyze17AutoEnterAnalysisC1EP9JSContext($enter, $cx);
    var $4 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    HEAP32[$1 >> 2] = $this;
    var $5 = __ZN2js8ArenaNewINS_7analyze14ScriptAnalysisEP8JSScriptEEPT_R11JSArenaPoolRKT0_($4, $1);
    var $6 = $this + 100 | 0;
    var $8 = HEAP32[$6 >> 2] | 0;
    HEAP32[$8 >> 2] = $5;
    var $11 = HEAP32[HEAP32[$6 >> 2] >> 2];
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7analyze14ScriptAnalysis15analyzeBytecodeEP9JSContext($11, $cx);
    var $15 = HEAP32[$6 >> 2] | 0;
    var $_idx_val = HEAP8[HEAP32[$15 >> 2] + 12 | 0];
    var $17 = __ZN2js7analyze14ScriptAnalysis3OOMEv($_idx_val);
    if ($17) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[$15 >> 2] = 0;
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js7analyze17AutoEnterAnalysisD1Ev($enter);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8ArenaNewINS_7analyze14ScriptAnalysisEP8JSScriptEEPT_R11JSArenaPoolRKT0_($pool, $a) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 40 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $26 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    __ZN2js7analyze14ScriptAnalysisC1EP8JSScript($23, $24);
    var $26 = $23;
    __label__ = 6;
    break;
   case 6:
    var $26;
    return $26;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSScript15typeSetFunctionEP9JSContextP10JSFunctionb($this, $cx, $fun, $singleton) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 37 | 0;
    var $2 = HEAP8[$1];
    var $3 = $2 | 4;
    HEAP8[$1] = $3;
    var $fun_idx_val = HEAP16[$fun + 58 >> 1];
    var $4 = __ZNK10JSFunction13isHeavyweightEv($fun_idx_val);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = $2 | 12;
    HEAP8[$1] = $6;
    __label__ = 3;
    break;
   case 3:
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $8 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 4:
    if ($singleton) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = $fun;
    var $12 = $cx;
    __ZN8JSObject16setSingletonTypeEP9JSContext($11, $12);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 6:
    var $_idx_val_idx_val = HEAP32[HEAP32[$fun + 36 >> 2] >> 2];
    var $14 = __ZNK8JSObject8getProtoEv($_idx_val_idx_val);
    var $15 = __ZN2js5types15TypeCompartment13newTypeObjectEP9JSContextP8JSScript10JSProtoKeyP8JSObjectb($cx, 2, $14, 0);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = $fun | 0;
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($18, $15);
    var $19 = $15 + 28 | 0;
    HEAP32[$19 >> 2] = $fun;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject21shouldSplicePrototypeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx1_val_idx_val = HEAP32[HEAP32[$this + 36 >> 2] >> 2];
    var $1 = __ZNK8JSObject8getProtoEv($this_idx1_val_idx_val);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $4 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $this_idx_val = HEAP32[$this + 8 >> 2];
    var $6 = __ZNK8JSObject16hasSingletonTypeEv($this_idx_val);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject15splicePrototypeEP9JSContextPS_($this, $cx, $proto) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $1 = $this;
    var $2 = $cx;
    var $3 = __ZN8JSObject7getTypeEP9JSContext($1, $2);
    var $4 = $3;
    var $5 = ($proto | 0) != 0;
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $protoType_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $proto;
    var $8 = __ZN8JSObject7getTypeEP9JSContext($7, $2);
    var $9 = $8;
    var $10 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($10 | 0) == 0) {
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      var $protoType_0 = $9;
      __label__ = 3;
      break;
    }
   case 3:
    var $protoType_0;
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $13 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ($5) {
      __label__ = 5;
      break;
    } else {
      var $18 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($16 | 0) == 0) {
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      var $18 = $16;
      __label__ = 6;
      break;
    }
   case 6:
    var $18;
    HEAP32[$this + 36 >> 2] = $18;
    var $_1 = 1;
    __label__ = 20;
    break;
   case 7:
    HEAP32[$3 >> 2] = $proto;
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    if (($protoType_0 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $protoType_0_idx_val = HEAP32[$protoType_0 + 12 >> 2];
    var $24 = __ZN2js5types10TypeObject17unknownPropertiesEv($protoType_0_idx_val);
    if ($24) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $_idx4_val = HEAP32[$3 + 12 >> 2];
    var $27 = __ZN2js5types10TypeObject17unknownPropertiesEv($_idx4_val);
    if ($27) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2js5types10TypeObject11markUnknownEP9JSContext($4, $cx);
    __label__ = 19;
    break;
   case 11:
    var $29 = $3 + 12 | 0;
    var $_idx3_val = HEAP32[$29 >> 2];
    var $30 = __ZN2js5types10TypeObject17unknownPropertiesEv($_idx3_val);
    if ($30) {
      __label__ = 19;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $32 = __ZN2js5types10TypeObject16getPropertyCountEv($_idx3_val);
    if (($32 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $_idx2 = $3 + 24 | 0;
    var $i_01 = 0;
    var $_idx1_val = $_idx3_val;
    __label__ = 14;
    break;
   case 14:
    var $_idx1_val;
    var $i_01;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $35 = __ZN2js5types10TypeObject11getPropertyEj($_idx1_val, $_idx2_val, $i_01);
    if (($35 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $38 = $35 + 4 | 0;
    var $_idx5_val = HEAP32[$38 >> 2];
    var $39 = __ZN2js5types7TypeSet21hasPropagatedPropertyEv($_idx5_val);
    if ($39) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $42 = HEAP32[$35 >> 2];
    __ZN2js5types10TypeObject17getFromPrototypesEP9JSContextiPNS0_7TypeSetEb($4, $cx, $42, $38, 1);
    __label__ = 17;
    break;
   case 17:
    var $44 = $i_01 + 1 | 0;
    if (($44 | 0) == ($32 | 0)) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $i_01 = $44;
    var $_idx1_val = HEAP32[$29 >> 2];
    __label__ = 14;
    break;
   case 19:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    var $_1 = 1;
    __label__ = 20;
    break;
   case 20:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject15splicePrototypeEP9JSContextPS_["X"] = 1;

function __ZN8JSObject12makeLazyTypeEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    var $this_idx2 = $this + 36 | 0;
    var $this_idx2_val_idx_val = HEAP32[HEAP32[$this_idx2 >> 2] >> 2];
    var $1 = __ZNK8JSObject8getProtoEv($this_idx2_val_idx_val);
    var $2 = __ZN2js5types15TypeCompartment13newTypeObjectEP9JSContextP8JSScript10JSProtoKeyP8JSObjectb($cx, 1, $1, 0);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($7, $cx);
    __label__ = 22;
    break;
   case 3:
    var $9 = $2 + 4 | 0;
    HEAP32[$9 >> 2] = $this;
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $10 = __ZNK8JSObject10isFunctionEv($this_idx_val);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 4:
    var $this_idx1_val = HEAP32[$this + 24 >> 2];
    var $12 = __ZNK8JSObject18getFunctionPrivateEv($this_idx1_val);
    if (($12 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx_val = HEAP16[$12 + 58 >> 1];
    var $15 = __ZNK10JSFunction13isInterpretedEv($_idx_val);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 6:
    var $17 = $2 + 28 | 0;
    HEAP32[$17 >> 2] = $12;
    var $18 = __ZNK10JSFunction6scriptEv($12);
    var $19 = $18 + 38 | 0;
    var $20 = HEAP8[$19];
    if (($20 & 2) << 24 >> 24 == 0) {
      var $28 = $20;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = $2 + 12 | 0;
    var $26 = HEAP32[$24 >> 2] | 524288;
    HEAP32[$24 >> 2] = $26;
    var $28 = HEAP8[$19];
    __label__ = 8;
    break;
   case 8:
    var $28;
    if (($28 & 4) << 24 >> 24 == 0) {
      var $36 = $28;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = $2 + 12 | 0;
    var $34 = HEAP32[$32 >> 2] | 1048576;
    HEAP32[$32 >> 2] = $34;
    var $36 = HEAP8[$19];
    __label__ = 10;
    break;
   case 10:
    var $36;
    if (($36 & 8) << 24 >> 24 == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $40 = $2 + 12 | 0;
    var $42 = HEAP32[$40 >> 2] | 8388608;
    HEAP32[$40 >> 2] = $42;
    __label__ = 12;
    break;
   case 12:
    var $44 = $this + 8 | 0;
    if ((HEAP32[$44 >> 2] & 32768 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $49 = $2 + 12 | 0;
    var $51 = HEAP32[$49 >> 2] | 4194304;
    HEAP32[$49 >> 2] = $51;
    __label__ = 14;
    break;
   case 14:
    var $this_idx5_val = HEAP32[$this_idx >> 2];
    var $52 = __ZNK8JSObject5isXMLEv($this_idx5_val);
    if ($52) {
      __label__ = 15;
      break;
    } else {
      var $57 = $this_idx5_val;
      __label__ = 17;
      break;
    }
   case 15:
    var $_idx4_val = HEAP32[$2 + 12 >> 2];
    var $54 = __ZN2js5types10TypeObject17unknownPropertiesEv($_idx4_val);
    if ($54) {
      var $57 = $this_idx5_val;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN2js5types10TypeObject11markUnknownEP9JSContext($2, $cx);
    var $57 = HEAP32[$this_idx >> 2];
    __label__ = 17;
    break;
   case 17:
    var $57;
    var $_idx3_phi_trans_insert = $2 + 12 | 0;
    var $_idx3_val_pre = HEAP32[$_idx3_phi_trans_insert >> 2];
    if ((HEAP32[$57 + 68 >> 2] | 0) == 0) {
      var $_idx3_val = $_idx3_val_pre;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $62 = $_idx3_val_pre | 2097152;
    HEAP32[$_idx3_phi_trans_insert >> 2] = $62;
    var $_idx3_val = $62;
    __label__ = 19;
    break;
   case 19:
    var $_idx3_val;
    var $63 = __ZN2js5types10TypeObject17unknownPropertiesEv($_idx3_val);
    if ($63) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[$this_idx2 >> 2] = $2;
    var $66 = HEAP32[$44 >> 2] & -131073;
    HEAP32[$44 >> 2] = $66;
    __label__ = 22;
    break;
   case 21:
    var $_idx3 = $2 + 12 | 0;
    HEAP32[$_idx3 >> 2] = $_idx3_val | 458752;
    HEAP32[$this_idx2 >> 2] = $2;
    var $70 = HEAP32[$44 >> 2] & -131073;
    HEAP32[$44 >> 2] = $70;
    __label__ = 22;
    break;
   case 22:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject12makeLazyTypeEP9JSContext["X"] = 1;

function __ZN8JSObject11makeNewTypeEP9JSContextP10JSFunctionb($this, $cx, $fun, $unknown) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $1 = __ZN2js5types15TypeCompartment13newTypeObjectEP9JSContextP8JSScript10JSProtoKeyP8JSObjectb($cx, 1, $this, $unknown);
    if (($1 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$this + 16 >> 2] = $1;
    __ZN8JSObject11setDelegateEv($this);
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $5 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 3:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    var $this_idx2_val = HEAP32[$this + 8 >> 2];
    var $7 = __ZNK8JSObject18hasSpecialEqualityEv($this_idx2_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = $1 + 12 | 0;
    var $11 = HEAP32[$9 >> 2] | 2097152;
    HEAP32[$9 >> 2] = $11;
    __label__ = 5;
    break;
   case 5:
    if (($fun | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZL24CheckNewScriptPropertiesP9JSContextPN2js5types10TypeObjectEP10JSFunction($cx, $1, $fun);
    __label__ = 7;
    break;
   case 7:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $16 = __ZNK8JSObject5isXMLEv($this_idx_val);
    if ($16) {
      __label__ = 8;
      break;
    } else {
      var $22 = $this_idx_val;
      __label__ = 10;
      break;
    }
   case 8:
    var $_idx1 = $1 + 12 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $18 = __ZN2js5types10TypeObject17unknownPropertiesEv($_idx1_val);
    if ($18) {
      var $22 = $this_idx_val;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $20 = $_idx1_val | 33488904;
    HEAP32[$_idx1 >> 2] = $20;
    var $22 = HEAP32[$this_idx >> 2];
    __label__ = 10;
    break;
   case 10:
    var $22;
    var $_idx_phi_trans_insert = $1 + 12 | 0;
    var $_idx_val_pre = HEAP32[$_idx_phi_trans_insert >> 2];
    if ((HEAP32[$22 + 68 >> 2] | 0) == 0) {
      var $_idx_val = $_idx_val_pre;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $27 = $_idx_val_pre | 2097152;
    HEAP32[$_idx_phi_trans_insert >> 2] = $27;
    var $_idx_val = $27;
    __label__ = 12;
    break;
   case 12:
    var $_idx_val;
    var $28 = __ZN2js5types10TypeObject17unknownPropertiesEv($_idx_val);
    if ($28) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    HEAP32[$1 + 12 >> 2] = $_idx_val | 8;
    __label__ = 14;
    break;
   case 14:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    __label__ = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject11makeNewTypeEP9JSContextP10JSFunctionb["X"] = 1;

function __Z16SweepTypeObjectsP9JSContextP13JSCompartment($cx, $compartment) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  __ZN17SweepTypeObjectOpC1EP9JSContext($1, $cx);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js2gc19ForEachArenaAndCellIPFvPNS0_5ArenaEE17SweepTypeObjectOpEEvP13JSCompartmentNS0_9AllocKindET_T0_($compartment, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN17SweepTypeObjectOpC1EP9JSContext($this, $cx) {
  __ZN17SweepTypeObjectOpC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js2gc19ForEachArenaAndCellIPFvPNS0_5ArenaEE17SweepTypeObjectOpEEvP13JSCompartmentNS0_9AllocKindET_T0_($compartment, $cellOp_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $firstSpan = __stackBase__;
    var $1 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE(15);
    var $2 = $compartment + 8 | 0;
    var $3 = __ZNK2js2gc10ArenaLists13getFirstArenaENS0_9AllocKindE($2, 15);
    if (($3 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $aheader_01 = $3;
      __label__ = 2;
      break;
    }
   case 2:
    var $aheader_01;
    var $5 = __ZN2js2gc11ArenaHeader8getArenaEv($aheader_01);
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($firstSpan, $aheader_01);
    var $6 = __ZN2js2gc5Arena11thingsStartENS0_9AllocKindE($5, 15);
    var $thing_0 = $6;
    var $span_0 = $firstSpan;
    __label__ = 3;
    break;
   case 3:
    var $span_0;
    var $thing_0;
    if (($thing_0 | 0) == (HEAP32[$span_0 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $span_0_idx1_val = HEAP32[$span_0 + 4 >> 2];
    var $12 = __ZNK2js2gc8FreeSpan7hasNextEv($span_0_idx1_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $14 = __ZNK2js2gc8FreeSpan8nextSpanEv($span_0_idx1_val);
    var $thing_1 = $span_0_idx1_val;
    var $span_1 = $14;
    __label__ = 7;
    break;
   case 6:
    __ZN17SweepTypeObjectOpclEPN2js2gc4CellE($cellOp_0, $thing_0);
    var $thing_1 = $thing_0;
    var $span_1 = $span_0;
    __label__ = 7;
    break;
   case 7:
    var $span_1;
    var $thing_1;
    var $thing_0 = $thing_1 + $1 | 0;
    var $span_0 = $span_1;
    __label__ = 3;
    break;
   case 8:
    var $21 = HEAP32[$aheader_01 + 4 >> 2];
    if (($21 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $aheader_01 = $21;
      __label__ = 2;
      break;
    }
   case 9:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types14TypeConstraint16newPropertyStateEP9JSContextPNS0_7TypeSetE($this, $cx, $source) {
  return;
}

function __ZN2js5types14TypeConstraint14newObjectStateEP9JSContextPNS0_10TypeObjectEb($this, $cx, $object, $force) {
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($this_0_0_val, $this_0_1_val) {
  return ($this_0_0_val | 0) == ($this_0_1_val | 0);
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5emptyEv($this_0_0_val, $this_0_1_val) {
  return ($this_0_0_val | 0) == ($this_0_1_val | 0);
}

function _JSID_IS_STRING1730($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_TO_STRING1731($iden) {
  return $iden;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($this_0_0_val, $this_0_1_val) {
  return ($this_0_0_val | 0) == ($this_0_1_val | 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE12hasCollisionEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5frontEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEaSERKS5_($this, $rhs) {
  var $1 = $rhs;
  var $2 = $this;
  var $3$0 = HEAP32[$1 >> 2];
  var $3$1 = HEAP32[$1 + 4 >> 2];
  HEAP32[$2 >> 2] = $3$0;
  HEAP32[$2 + 4 >> 2] = $3$1;
  var $5 = HEAP32[$rhs + 8 >> 2];
  HEAP32[$this + 8 >> 2] = $5;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15TypeCompartment5sweepEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e = __stackBase__;
    var $e1 = __stackBase__ + 16;
    var $e4 = __stackBase__ + 32;
    var $1 = __ZN2js5types15TypeCompartment11compartmentEv($this);
    __Z16SweepTypeObjectsP9JSContextP13JSCompartment($cx, $1);
    var $3 = HEAP32[$this + 32 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC1ISA_EERT_($e, $3);
    var $6 = $e | 0;
    var $_idx2 = $e | 0;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $_idx3 = $e + 4 | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $7 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($_idx2_val, $_idx3_val);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_idx4_val = $_idx2_val;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev($e);
    __label__ = 10;
    break;
   case 4:
    var $_idx4_val;
    var $8 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($_idx4_val);
    var $10 = HEAP32[$8 + 8 >> 2];
    var $_idx6_val = HEAP32[$8 >> 2];
    var $11 = __ZNK2js5types4Type12isTypeObjectEv($_idx6_val);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $13 = __ZNK2js5types4Type10typeObjectEv($_idx6_val);
    var $14 = $13;
    var $15 = __ZNK2js2gc4Cell8isMarkedEj($14);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = $10;
    var $17 = __ZNK2js2gc4Cell8isMarkedEj($16);
    __label__ = 8;
    break;
   case 7:
    var $19 = $10;
    var $20 = __ZNK2js2gc4Cell8isMarkedEj($19);
    if ($20) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv($e);
    __label__ = 9;
    break;
   case 9:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($6);
    var $_idx_val = HEAP32[$_idx2 >> 2];
    var $_idx1_val = HEAP32[$_idx3 >> 2];
    var $23 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($_idx_val, $_idx1_val);
    if ($23) {
      __label__ = 3;
      break;
    } else {
      var $_idx4_val = $_idx_val;
      __label__ = 4;
      break;
    }
   case 10:
    var $26 = HEAP32[$this + 36 >> 2];
    if (($26 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC1IS9_EERT_($e1, $26);
    var $29 = $e1 | 0;
    var $_idx11 = $e1 | 0;
    var $_idx11_val = HEAP32[$_idx11 >> 2];
    var $_idx12 = $e1 + 4 | 0;
    var $_idx12_val = HEAP32[$_idx12 >> 2];
    var $30 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5emptyEv($_idx11_val, $_idx12_val);
    if ($30) {
      __label__ = 12;
      break;
    } else {
      var $_idx13_val = $_idx11_val;
      __label__ = 13;
      break;
    }
   case 12:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD1Ev($e1);
    __label__ = 25;
    break;
   case 13:
    var $_idx13_val;
    var $31 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5frontEv($_idx13_val);
    var $34 = HEAP32[$31 + 16 >> 2];
    var $35 = __ZNK2js2gc4Cell8isMarkedEj($34);
    var $37 = $31 + 4 | 0;
    var $38 = $31 | 0;
    var $39 = $31 + 20 | 0;
    var $i_0 = 0;
    var $remove3_1 = $35 & 1 ^ 1;
    __label__ = 14;
    break;
   case 14:
    var $remove3_1;
    var $i_0;
    if (($remove3_1 & 1) << 24 >> 24 == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 15:
    if ($i_0 >>> 0 < HEAPU32[$37 >> 2] >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 16:
    var $49 = HEAPU32[HEAP32[$38 >> 2] + ($i_0 << 2) >> 2];
    var $50 = _JSID_IS_STRING1730($49);
    if (($50 | 0) == 0) {
      var $remove3_2 = $remove3_1;
      __label__ = 19;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $53 = _JSID_TO_STRING1731($49);
    var $54 = $53;
    var $55 = __ZNK2js2gc4Cell8isMarkedEj($54);
    if ($55) {
      var $remove3_2 = $remove3_1;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $remove3_2 = 1;
    __label__ = 19;
    break;
   case 19:
    var $remove3_2;
    var $_idx5_val = HEAP32[HEAP32[$39 >> 2] + ($i_0 << 2) >> 2];
    var $58 = __ZNK2js5types4Type12isTypeObjectEv($_idx5_val);
    if ($58) {
      __label__ = 20;
      break;
    } else {
      var $remove3_3 = $remove3_2;
      __label__ = 22;
      break;
    }
   case 20:
    var $60 = __ZNK2js5types4Type10typeObjectEv($_idx5_val);
    var $61 = $60;
    var $62 = __ZNK2js2gc4Cell8isMarkedEj($61);
    if ($62) {
      var $remove3_3 = $remove3_2;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $remove3_3 = 1;
    __label__ = 22;
    break;
   case 22:
    var $remove3_3;
    var $i_0 = $i_0 + 1 | 0;
    var $remove3_1 = $remove3_3;
    __label__ = 14;
    break;
   case 23:
    var $67 = HEAP32[$38 >> 2];
    __ZN2js10Foreground5free_EPv($67);
    var $69 = HEAP32[$39 >> 2];
    __ZN2js10Foreground5free_EPv($69);
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4Enum11removeFrontEv($e1);
    __label__ = 24;
    break;
   case 24:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range8popFrontEv($29);
    var $_idx9_val = HEAPU32[$_idx11 >> 2];
    var $_idx10_val = HEAP32[$_idx12 >> 2];
    var $70 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5emptyEv($_idx9_val, $_idx10_val);
    if ($70) {
      __label__ = 12;
      break;
    } else {
      var $_idx13_val = $_idx9_val;
      __label__ = 13;
      break;
    }
   case 25:
    var $73 = HEAP32[$this + 28 >> 2];
    if (($73 | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC1ISA_EERT_($e4, $73);
    var $76 = $e4 | 0;
    var $_idx16 = $e4 | 0;
    var $_idx16_val = HEAP32[$_idx16 >> 2];
    var $_idx17 = $e4 + 4 | 0;
    var $_idx17_val = HEAP32[$_idx17 >> 2];
    var $77 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($_idx16_val, $_idx17_val);
    if ($77) {
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $cx_idx = $cx + 52 | 0;
    var $_idx18_val = $_idx16_val;
    __label__ = 29;
    break;
   case 28:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev($e4);
    __label__ = 33;
    break;
   case 29:
    var $_idx18_val;
    var $78 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($_idx18_val);
    var $80 = HEAP32[$78 + 8 >> 2];
    var $83 = HEAP32[$78 >> 2];
    var $cx_idx_val_idx_val = HEAP32[HEAP32[$cx_idx >> 2] + 144080 >> 2];
    var $84 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx_idx_val_idx_val, $83);
    if ($84) {
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $86 = $80;
    var $87 = __ZNK2js2gc4Cell8isMarkedEj($86);
    if ($87) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv($e4);
    __label__ = 32;
    break;
   case 32:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($76);
    var $_idx14_val = HEAP32[$_idx16 >> 2];
    var $_idx15_val = HEAP32[$_idx17 >> 2];
    var $90 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($_idx14_val, $_idx15_val);
    if ($90) {
      __label__ = 28;
      break;
    } else {
      var $_idx18_val = $_idx14_val;
      __label__ = 29;
      break;
    }
   case 33:
    var $92 = $this + 40 | 0;
    var $93 = HEAP32[$92 >> 2];
    if (($93 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $96 = $93;
    __ZN9JSContext5free_EPv($96);
    __label__ = 35;
    break;
   case 35:
    HEAP32[$92 >> 2] = 0;
    HEAP32[$this + 48 >> 2] = 0;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types15TypeCompartment5sweepEP9JSContext["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC1ISA_EERT_($this, $map) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC2ISA_EERT_($this, $map);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS7_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 16 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$5 >> 2];
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isLiveEv($_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC1IS9_EERT_($this, $map) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC2IS9_EERT_($this, $map);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6removeERNS0_14HashTableEntryIS6_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 28 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$5 >> 2];
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isLiveEv($_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC1ISA_EERT_($this, $map) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC2ISA_EERT_($this, $map);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS7_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 16 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$5 >> 2];
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isLiveEv($_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev($this);
  return;
}

function __ZN2js5types15TypeCompartmentD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 40 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN2js10Foreground5free_EPv($5);
    __label__ = 3;
    break;
   case 3:
    var $8 = HEAP32[$this + 32 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js10Foreground7delete_INS_7HashMapINS_5types13ArrayTableKeyEPNS3_10TypeObjectES4_NS_17SystemAllocPolicyEEEEEvPT_($8);
    __label__ = 5;
    break;
   case 5:
    var $13 = HEAP32[$this + 36 >> 2];
    if (($13 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js10Foreground7delete_INS_7HashMapINS_5types14ObjectTableKeyENS3_16ObjectTableEntryES4_NS_17SystemAllocPolicyEEEEEvPT_($13);
    __label__ = 7;
    break;
   case 7:
    var $18 = HEAP32[$this + 28 >> 2];
    if (($18 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2js10Foreground7delete_INS_7HashMapINS_5types17AllocationSiteKeyEPNS3_10TypeObjectES4_NS_17SystemAllocPolicyEEEEEvPT_($18);
    __label__ = 9;
    break;
   case 9:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Foreground7delete_INS_7HashMapINS_5types13ArrayTableKeyEPNS3_10TypeObjectES4_NS_17SystemAllocPolicyEEEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED1Ev($p);
    var $3 = $p;
    _js_free1736($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Foreground7delete_INS_7HashMapINS_5types14ObjectTableKeyENS3_16ObjectTableEntryES4_NS_17SystemAllocPolicyEEEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEED1Ev($p);
    var $3 = $p;
    _js_free1736($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Foreground7delete_INS_7HashMapINS_5types17AllocationSiteKeyEPNS3_10TypeObjectES4_NS_17SystemAllocPolicyEEEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED1Ev($p);
    var $3 = $p;
    _js_free1736($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript5SweepEP9JSContextP8JSScript($cx, $script) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $script;
    var $2 = __ZNK2js2gc4Cell11compartmentEv($1);
    var $3 = __ZN2js5types10TypeScript11NumTypeSetsEP8JSScript($script);
    var $4 = $script + 100 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = __ZN2js5types10TypeScript9typeArrayEv($5);
    if (($3 | 0) == 0) {
      var $10 = $5;
      __label__ = 4;
      break;
    } else {
      var $i_02 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $i_02;
    var $8 = $6 + $i_02 * 12 | 0;
    __ZN2js5types7TypeSet5sweepEP9JSContextP13JSCompartment($8, $cx, $2);
    var $9 = $i_02 + 1 | 0;
    if (($9 | 0) == ($3 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $i_02 = $9;
      __label__ = 2;
      break;
    }
   case 3:
    var $10 = HEAP32[$4 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $10;
    var $presult_0_ph = $10 + 16 | 0;
    __label__ = 5;
    break;
   case 5:
    var $presult_0_ph;
    __label__ = 6;
    break;
   case 6:
    var $13 = HEAP32[$presult_0_ph >> 2];
    if (($13 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $17 = HEAP32[$13 + 4 >> 2];
    var $18 = __ZNK2js5types4Type9isUnknownEv($17);
    if ($18) {
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = __ZNK2js5types4Type11isAnyObjectEv($17);
    if ($20) {
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $22 = __ZNK2js5types4Type8isObjectEv($17);
    if ($22) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $24 = __ZNK2js5types4Type9objectKeyEv($17);
    var $25 = __ZN2js5typesL20IsAboutToBeFinalizedEP9JSContextPNS0_13TypeObjectKeyE($24);
    if ($25) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $28 = HEAP32[$13 + 8 >> 2];
    HEAP32[$presult_0_ph >> 2] = $28;
    __ZN9JSContext7delete_IN2js5types10TypeResultEEEvPT_($13);
    __label__ = 6;
    break;
   case 12:
    var $presult_0_ph = $13 + 8 | 0;
    __label__ = 5;
    break;
   case 13:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet5sweepEP9JSContextP13JSCompartment($this, $cx, $compartment) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $objectCount = __stackBase__;
    var $this_idx = $this | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $1 = __ZNK2js5types7TypeSet15baseObjectCountEv($this_idx_val);
    HEAP32[$objectCount >> 2] = $1;
    if ($1 >>> 0 > 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    var $4 = __ZN2js5typesL15HashSetCapacityEj1739($1);
    var $5 = $this + 4 | 0;
    var $6 = HEAP32[$5 >> 2];
    __ZN2js5types7TypeSet12clearObjectsEv($this);
    HEAP32[$objectCount >> 2] = 0;
    if (($4 | 0) == 0) {
      var $22 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $compartment + 376 | 0;
    var $i_01 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_01;
    var $11 = HEAP32[$6 + ($i_01 << 2) >> 2];
    if (($11 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = __ZN2js5typesL20IsAboutToBeFinalizedEP9JSContextPNS0_13TypeObjectKeyE($11);
    if ($14) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = __ZN2js5typesL13HashSetInsertIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_1745($compartment, $5, $objectCount, $11);
    if (($16 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$16 >> 2] = $11;
    __label__ = 9;
    break;
   case 8:
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($8, $cx);
    __label__ = 9;
    break;
   case 9:
    var $21 = $i_01 + 1 | 0;
    if (($21 | 0) == ($4 | 0)) {
      __label__ = 10;
      break;
    } else {
      var $i_01 = $21;
      __label__ = 4;
      break;
    }
   case 10:
    var $22 = HEAP32[$objectCount >> 2];
    __label__ = 11;
    break;
   case 11:
    var $22;
    __ZN2js5types7TypeSet18setBaseObjectCountEj($this, $22);
    __label__ = 15;
    break;
   case 12:
    if (($1 | 0) == 1) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $26 = $this + 4 | 0;
    var $28 = HEAP32[$26 >> 2];
    var $29 = __ZN2js5typesL20IsAboutToBeFinalizedEP9JSContextPNS0_13TypeObjectKeyE($28);
    if ($29) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    HEAP32[$26 >> 2] = 0;
    __ZN2js5types7TypeSet18setBaseObjectCountEj($this, 0);
    __label__ = 15;
    break;
   case 15:
    HEAP32[$this + 8 >> 2] = 0;
    var $33 = HEAP32[$this_idx >> 2] & -131073;
    HEAP32[$this_idx >> 2] = $33;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types7TypeSet5sweepEP9JSContextP13JSCompartment["X"] = 1;

function __ZN2js5typesL20IsAboutToBeFinalizedEP9JSContextPNS0_13TypeObjectKeyE($key) {
  var $3 = $key & -2;
  var $4 = __ZNK2js2gc4Cell8isMarkedEj($3);
  return $4 ^ 1;
}

function __ZN9JSContext7delete_IN2js5types10TypeResultEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $p;
    __ZN9JSContext5free_EPv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript7destroyEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 16 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $4 = $2;
      __label__ = 2;
      break;
    }
   case 2:
    var $4;
    var $6 = HEAP32[$4 + 8 >> 2];
    __ZN2js10Foreground7delete_INS_5types10TypeResultEEEvPT_($4);
    HEAP32[$1 >> 2] = $6;
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $4 = $6;
      __label__ = 2;
      break;
    }
   case 3:
    var $9 = HEAP32[$this + 12 >> 2];
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js10Foreground7delete_INS_5types17TypeScriptNestingEEEvPT_($9);
    __label__ = 5;
    break;
   case 5:
    var $13 = $this;
    __ZN2js10Foreground5free_EPv($13);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Foreground7delete_INS_5types10TypeResultEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $p;
    _js_free1736($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Foreground7delete_INS_5types17TypeScriptNestingEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js5types17TypeScriptNestingD2Ev($p);
    var $3 = $p;
    _js_free1736($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_free1736($p) {
  _free($p);
  return;
}

function __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev($this_0_5_val) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev($this_0_5_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev($this_0_5_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_5_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS7_EEj($this_0_5_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS7_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv($0);
  return;
}

function __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev($this_0_5_val) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev($this_0_5_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev($this_0_5_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_5_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS6_EEj($this_0_5_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS6_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv($0);
  return;
}

function __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev($this_0_5_val) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev($this_0_5_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev($this_0_5_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_5_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS7_EEj($this_0_5_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS7_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv($0);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS7_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e_idx_val = HEAP32[$e >> 2];
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE12hasCollisionEv($e_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEC1Ev($1);
  __ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEC1Ev($1);
  __ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEC1Ev($this) {
  __ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEC2Ev($this);
  return;
}

function __ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEC2Ev($this) {
  var $1 = $this | 0;
  __ZN2js5types17AllocationSiteKeyC1Ev($1);
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + ($5 << 4) | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 5;
    break;
   case 5:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $22 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isLiveEv($src_01_idx_val);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE10getKeyHashEv($src_01_idx1_val);
    var $25 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEENS_7MoveRefIT_EERSB_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEEaSENS_7MoveRefIS8_EE($25, $_02_val);
    __label__ = 7;
    break;
   case 7:
    var $27 = $src_01 + 16 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS7_EEj($3);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_5types17AllocationSiteKeyEEcvRS2_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefIPNS_5types10TypeObjectEEcvRS3_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_5types14ObjectTableKeyEEcvRS2_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_5types16ObjectTableEntryEEcvRS2_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE12hasCollisionEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE12hasCollisionEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEC2ERS9_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefIPNS_5types10TypeObjectEEC2ERS3_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_5types17AllocationSiteKeyEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEC2ERS8_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEC2ERS5_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_5types16ObjectTableEntryEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_5types14ObjectTableKeyEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEaSERKS5_($this, $rhs) {
  var $1 = $rhs;
  var $2 = $this;
  var $3$0 = HEAP32[$1 >> 2];
  var $3$1 = HEAP32[$1 + 4 >> 2];
  HEAP32[$2 >> 2] = $3$0;
  HEAP32[$2 + 4 >> 2] = $3$1;
  var $5 = HEAP32[$rhs + 8 >> 2];
  HEAP32[$this + 8 >> 2] = $5;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 4;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej($1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + ($capacity << 4) | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 16 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 4) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + ($15 << 4) | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEEaSENS_7MoveRefIS8_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = $2 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEENS_7MoveRefIT_EERS8_($1, $7);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEaSENS_7MoveRefIS5_EE($6, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEENS_7MoveRefIT_EERSB_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEC1ERS9_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEC1ERS9_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEC2ERS9_($this, $t);
  return;
}

function __ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEaSENS_7MoveRefIS5_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEptEv($rhs_0);
  var $4 = $3 | 0;
  __ZN2js4MoveINS_5types17AllocationSiteKeyEEENS_7MoveRefIT_EERKS4_($1, $4);
  var $_idx2_val = HEAP32[$1 >> 2];
  var $5 = __ZNK2js7MoveRefINS_5types17AllocationSiteKeyEEcvRS2_Ev($_idx2_val);
  var $6 = $5;
  var $7 = $this;
  var $8$0 = HEAP32[$6 >> 2];
  var $8$1 = HEAP32[$6 + 4 >> 2];
  HEAP32[$7 >> 2] = $8$0;
  HEAP32[$7 + 4 >> 2] = $8$1;
  var $9 = $3 + 8 | 0;
  __ZN2js4MoveIPNS_5types10TypeObjectEEENS_7MoveRefIT_EERS5_($2, $9);
  var $_idx_val = HEAP32[$2 >> 2];
  var $10 = __ZNK2js7MoveRefIPNS_5types10TypeObjectEEcvRS3_Ev($_idx_val);
  var $11 = HEAP32[$10 >> 2];
  HEAP32[$this + 8 >> 2] = $11;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js4MoveINS_5types17AllocationSiteKeyEEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_5types17AllocationSiteKeyEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js4MoveIPNS_5types10TypeObjectEEENS_7MoveRefIT_EERS5_($agg_result, $t) {
  __ZN2js7MoveRefIPNS_5types10TypeObjectEEC1ERS3_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIPNS_5types10TypeObjectEEC1ERS3_($this, $t) {
  __ZN2js7MoveRefIPNS_5types10TypeObjectEEC2ERS3_($this, $t);
  return;
}

function __ZN2js7MoveRefINS_5types17AllocationSiteKeyEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefINS_5types17AllocationSiteKeyEEC2ERS2_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEC1Ev($2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC2ISA_EERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZNK2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE3allEv($1, $map);
  var $2 = $1;
  var $3 = $this;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  HEAP32[$this + 8 >> 2] = $map | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE3allEv($agg_result, $this) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $_idx1_val = HEAP32[$this + 20 >> 2];
  __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $_idx_val, $_idx1_val);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $this_0_1_val, $this_0_5_val) {
  var $1 = $this_0_5_val + ($this_0_1_val << 4) | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS7_EESG_($agg_result, $this_0_5_val, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS7_EESG_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS7_EESG_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS7_EESG_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$4 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isLiveEv($_idx_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 16 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6removeERNS0_14HashTableEntryIS6_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e_idx_val = HEAP32[$e >> 2];
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE12hasCollisionEv($e_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEC1Ev($1);
  __ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEaSERKS4_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEC1Ev($1);
  __ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEaSERKS4_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEaSERKS4_($this, $rhs) {
  var $1 = $this;
  var $2 = $rhs;
  HEAP32[$1 >> 2] = HEAP32[$2 >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[$2 + 4 >> 2];
  HEAP32[$1 + 8 >> 2] = HEAP32[$2 + 8 >> 2];
  HEAP32[$1 + 12 >> 2] = HEAP32[$2 + 12 >> 2];
  var $5 = $rhs + 16 | 0;
  var $6 = $this + 16 | 0;
  var $7$0 = HEAP32[$5 >> 2];
  var $7$1 = HEAP32[$5 + 4 >> 2];
  HEAP32[$6 >> 2] = $7$0;
  HEAP32[$6 + 4 >> 2] = $7$1;
  return;
}

function __ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEC1Ev($this) {
  __ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEC2Ev($this);
  return;
}

function __ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEC2Ev($this) {
  var $1 = $this;
  HEAP32[$1 >> 2] = 0;
  HEAP32[$1 + 4 >> 2] = 0;
  HEAP32[$1 + 8 >> 2] = 0;
  HEAP32[$1 + 12 >> 2] = 0;
  HEAP32[$1 + 16 >> 2] = 0;
  HEAP32[$1 + 20 >> 2] = 0;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j($10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + $5 * 28 | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 5;
    break;
   case 5:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $22 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isLiveEv($src_01_idx_val);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE10getKeyHashEv($src_01_idx1_val);
    var $25 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEENS_7MoveRefIT_EERSA_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEEaSENS_7MoveRefIS7_EE($25, $_02_val);
    __label__ = 7;
    break;
   case 7:
    var $27 = $src_01 + 28 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS6_EEj($3);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j($capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 28 | 0;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej($1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 28 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 28 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 28 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 28 | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEEaSENS_7MoveRefIS7_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = $2 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEENS_7MoveRefIT_EERS7_($1, $7);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEaSENS_7MoveRefIS4_EE($6, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEENS_7MoveRefIT_EERSA_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEC1ERS8_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEC1ERS8_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEC2ERS8_($this, $t);
  return;
}

function __ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEaSENS_7MoveRefIS4_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEptEv($rhs_0);
  var $4 = $3 | 0;
  __ZN2js4MoveINS_5types14ObjectTableKeyEEENS_7MoveRefIT_EERKS4_($1, $4);
  var $_idx_val = HEAP32[$1 >> 2];
  var $5 = __ZNK2js7MoveRefINS_5types14ObjectTableKeyEEcvRS2_Ev($_idx_val);
  var $6 = $this;
  var $7 = $5;
  HEAP32[$6 >> 2] = HEAP32[$7 >> 2];
  HEAP32[$6 + 4 >> 2] = HEAP32[$7 + 4 >> 2];
  HEAP32[$6 + 8 >> 2] = HEAP32[$7 + 8 >> 2];
  HEAP32[$6 + 12 >> 2] = HEAP32[$7 + 12 >> 2];
  var $8 = $this + 16 | 0;
  var $9 = $3 + 16 | 0;
  __ZN2js4MoveINS_5types16ObjectTableEntryEEENS_7MoveRefIT_EERS4_($2, $9);
  var $_idx2_val = HEAP32[$2 >> 2];
  var $10 = __ZNK2js7MoveRefINS_5types16ObjectTableEntryEEcvRS2_Ev($_idx2_val);
  var $11 = $10;
  var $12 = $8;
  var $13$0 = HEAP32[$11 >> 2];
  var $13$1 = HEAP32[$11 + 4 >> 2];
  HEAP32[$12 >> 2] = $13$0;
  HEAP32[$12 + 4 >> 2] = $13$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEENS_7MoveRefIT_EERS7_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEC1ERS5_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEC1ERS5_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEC2ERS5_($this, $t);
  return;
}

function __ZN2js4MoveINS_5types14ObjectTableKeyEEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_5types14ObjectTableKeyEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js4MoveINS_5types16ObjectTableEntryEEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_5types16ObjectTableEntryEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_5types16ObjectTableEntryEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefINS_5types16ObjectTableEntryEEC2ERS2_($this, $t);
  return;
}

function __ZN2js7MoveRefINS_5types14ObjectTableKeyEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefINS_5types14ObjectTableKeyEEC2ERS2_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEC1Ev($2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC2IS9_EERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZNK2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE3allEv($1, $map);
  var $2 = $1;
  var $3 = $this;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  HEAP32[$this + 8 >> 2] = $map | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE3allEv($agg_result, $this) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $_idx1_val = HEAP32[$this + 20 >> 2];
  __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3allEv($agg_result, $_idx_val, $_idx1_val);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3allEv($agg_result, $this_0_1_val, $this_0_5_val) {
  var $1 = $this_0_5_val + $this_0_1_val * 28 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC1EPNS0_14HashTableEntryIS6_EESF_($agg_result, $this_0_5_val, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC1EPNS0_14HashTableEntryIS6_EESF_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC2EPNS0_14HashTableEntryIS6_EESF_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC2EPNS0_14HashTableEntryIS6_EESF_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$4 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isLiveEv($_idx_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 28 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS7_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e_idx_val = HEAP32[$e >> 2];
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE12hasCollisionEv($e_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC1Ev($1);
  __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC1Ev($1);
  __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC1Ev($this) {
  __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC2Ev($this);
  return;
}

function __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC2Ev($this) {
  var $1 = $this | 0;
  __ZN2js5types13ArrayTableKeyC1Ev($1);
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + ($5 << 4) | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 5;
    break;
   case 5:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $22 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isLiveEv($src_01_idx_val);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE10getKeyHashEv($src_01_idx1_val);
    var $25 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEENS_7MoveRefIT_EERSB_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEEaSENS_7MoveRefIS8_EE($25, $_02_val);
    __label__ = 7;
    break;
   case 7:
    var $27 = $src_01 + 16 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS7_EEj($3);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 4;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej($1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + ($capacity << 4) | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 16 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 4) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + ($15 << 4) | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_5types13ArrayTableKeyEEcvRS2_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js7MoveRefINS_7analyze8SSAValueEEcvRS2_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEC2ERS9_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_5types13ArrayTableKeyEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN8JSObject14revertLazyTypeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 8 | 0;
    var $3 = HEAP32[$1 >> 2] | 131072;
    HEAP32[$1 >> 2] = $3;
    var $4 = $this + 36 | 0;
    var $7 = HEAP32[HEAP32[$4 >> 2] >> 2];
    if (($7 | 0) == 0) {
      var $13 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = HEAP32[$7 + 16 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $13;
    HEAP32[$4 >> 2] = $13;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeResultC2EjNS0_4TypeE($this, $offset, $type_0) {
  HEAP32[$this >> 2] = $offset;
  HEAP32[$this + 4 >> 2] = $type_0;
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 3) | 0;
}

function __ZN2js7MoveRefINS_7analyze8SSAValueEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEEaSENS_7MoveRefIS8_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = $2 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEENS_7MoveRefIT_EERS8_($1, $7);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEaSENS_7MoveRefIS5_EE($6, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEENS_7MoveRefIT_EERSB_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEC1ERS9_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEC1ERS9_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEC2ERS9_($this, $t);
  return;
}

function __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEaSENS_7MoveRefIS5_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEptEv($rhs_0);
  var $4 = $3 | 0;
  __ZN2js4MoveINS_5types13ArrayTableKeyEEENS_7MoveRefIT_EERKS4_($1, $4);
  var $_idx_val = HEAP32[$1 >> 2];
  var $5 = __ZNK2js7MoveRefINS_5types13ArrayTableKeyEEcvRS2_Ev($_idx_val);
  var $6 = $5;
  var $7 = $this;
  var $8$0 = HEAP32[$6 >> 2];
  var $8$1 = HEAP32[$6 + 4 >> 2];
  HEAP32[$7 >> 2] = $8$0;
  HEAP32[$7 + 4 >> 2] = $8$1;
  var $9 = $3 + 8 | 0;
  __ZN2js4MoveIPNS_5types10TypeObjectEEENS_7MoveRefIT_EERS5_($2, $9);
  var $_idx2_val = HEAP32[$2 >> 2];
  var $10 = __ZNK2js7MoveRefIPNS_5types10TypeObjectEEcvRS3_Ev($_idx2_val);
  var $11 = HEAP32[$10 >> 2];
  HEAP32[$this + 8 >> 2] = $11;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js4MoveINS_5types13ArrayTableKeyEEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_5types13ArrayTableKeyEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_5types13ArrayTableKeyEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefINS_5types13ArrayTableKeyEEC2ERS2_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC1Ev($2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC2ISA_EERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZNK2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE3allEv($1, $map);
  var $2 = $1;
  var $3 = $this;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  HEAP32[$this + 8 >> 2] = $map | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE3allEv($agg_result, $this) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $_idx1_val = HEAP32[$this + 20 >> 2];
  __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $_idx_val, $_idx1_val);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $this_0_1_val, $this_0_5_val) {
  var $1 = $this_0_5_val + ($this_0_1_val << 4) | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS7_EESG_($agg_result, $this_0_5_val, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS7_EESG_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS7_EESG_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS7_EESG_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$4 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isLiveEv($_idx_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 16 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN17SweepTypeObjectOpclEPN2js2gc4CellE($this_0_0_val, $cell) {
  var $1 = $cell;
  __ZN2js5types10TypeObject5sweepEP9JSContext($1, $this_0_0_val);
  return;
}

function __ZN2js5types10TypeObject5sweepEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $propertyCount = __stackBase__;
    HEAP32[$this + 20 >> 2] = 0;
    var $2 = $this + 4 | 0;
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js5types10TypeObject15clearPropertiesEv($this);
    var $6 = $this;
    var $7 = __ZNK2js2gc4Cell8isMarkedEj($6);
    if ($7) {
      __label__ = 30;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAP32[$2 >> 2];
    __ZN8JSObject14revertLazyTypeEv($9);
    __label__ = 30;
    break;
   case 4:
    var $11 = $this;
    var $12 = __ZNK2js2gc4Cell8isMarkedEj($11);
    if ($12) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = HEAP32[$this + 8 >> 2];
    if (($15 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = $15;
    __ZN2js10Foreground5free_EPv($18);
    __label__ = 7;
    break;
   case 7:
    var $21 = HEAP32[$this + 16 >> 2];
    if (($21 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $24 = $21;
    __ZN2js10Foreground5free_EPv($24);
    __label__ = 30;
    break;
   case 9:
    var $26 = __ZNK2js2gc4Cell11compartmentEv($11);
    var $this_idx = $this + 12 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $27 = __ZNK2js5types10TypeObject17basePropertyCountEv($this_idx_val);
    HEAP32[$propertyCount >> 2] = $27;
    if ($27 >>> 0 > 1) {
      __label__ = 10;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 10:
    var $30 = __ZN2js5typesL15HashSetCapacityEj1739($27);
    var $31 = $this + 24 | 0;
    var $32 = HEAP32[$31 >> 2];
    __ZN2js5types10TypeObject15clearPropertiesEv($this);
    HEAP32[$propertyCount >> 2] = 0;
    if (($30 | 0) == 0) {
      var $56 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $34 = $26 + 344 | 0;
    var $35 = $26 + 376 | 0;
    var $i_02 = 0;
    __label__ = 12;
    break;
   case 12:
    var $i_02;
    var $38 = HEAP32[$32 + ($i_02 << 2) >> 2];
    if (($38 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $_idx1_val = HEAP32[$38 + 4 >> 2];
    var $41 = __ZNK2js5types7TypeSet13isOwnPropertyEb($_idx1_val, 0);
    if ($41) {
      __label__ = 14;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 14:
    var $43 = __ZN2js8ArenaNewINS_5types8PropertyES2_EEPT_R11JSArenaPoolRKT0_($34, $38);
    if (($43 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $47 = HEAP32[$38 >> 2];
    var $48 = __ZN2js5typesL13HashSetInsertIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_1740($26, $31, $propertyCount, $47);
    if (($48 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    HEAP32[$48 >> 2] = $43;
    var $51 = $43 + 4 | 0;
    __ZN2js5types7TypeSet5sweepEP9JSContextP13JSCompartment($51, $cx, $26);
    __label__ = 19;
    break;
   case 17:
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($35, $cx);
    __label__ = 19;
    break;
   case 18:
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($35, $cx);
    __label__ = 19;
    break;
   case 19:
    var $55 = $i_02 + 1 | 0;
    if (($55 | 0) == ($30 | 0)) {
      __label__ = 20;
      break;
    } else {
      var $i_02 = $55;
      __label__ = 12;
      break;
    }
   case 20:
    var $56 = HEAP32[$propertyCount >> 2];
    __label__ = 21;
    break;
   case 21:
    var $56;
    __ZN2js5types10TypeObject20setBasePropertyCountEj($this, $56);
    __label__ = 28;
    break;
   case 22:
    if (($27 | 0) == 1) {
      __label__ = 23;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 23:
    var $60 = $this + 24 | 0;
    var $61 = HEAP32[$60 >> 2];
    var $_idx_val = HEAP32[$61 + 4 >> 2];
    var $63 = __ZNK2js5types7TypeSet13isOwnPropertyEb($_idx_val, 0);
    if ($63) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $65 = $61;
    var $66 = $26 + 344 | 0;
    var $67 = __ZN2js8ArenaNewINS_5types8PropertyES2_EEPT_R11JSArenaPoolRKT0_($66, $65);
    if (($67 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $70 = $67;
    HEAP32[$60 >> 2] = $70;
    var $71 = $67 + 4 | 0;
    __ZN2js5types7TypeSet5sweepEP9JSContextP13JSCompartment($71, $cx, $26);
    __label__ = 28;
    break;
   case 26:
    var $73 = $26 + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($73, $cx);
    __label__ = 28;
    break;
   case 27:
    HEAP32[$60 >> 2] = 0;
    __ZN2js5types10TypeObject20setBasePropertyCountEj($this, 0);
    __label__ = 28;
    break;
   case 28:
    if ((HEAP32[$this + 16 >> 2] | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $80 = HEAP32[$this_idx >> 2] | 4;
    HEAP32[$this_idx >> 2] = $80;
    __label__ = 30;
    break;
   case 30:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types10TypeObject5sweepEP9JSContext["X"] = 1;

function __ZN2js5types10TypeObject15clearPropertiesEv($this) {
  __ZN2js5types10TypeObject20setBasePropertyCountEj($this, 0);
  HEAP32[$this + 24 >> 2] = 0;
  return;
}

function __ZN2js5typesL15HashSetCapacityEj1739($count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 < 9) {
      var $_0 = 8;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $count | 1;
    var $4 = _llvm_ctlz_i32($3);
    var $_0 = 1 << 33 - $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8ArenaNewINS_5types8PropertyES2_EEPT_R11JSArenaPoolRKT0_($pool, $a) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 16 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $25 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    __ZN2js5types8PropertyC1ERKS1_($23, $a);
    var $25 = $23;
    __label__ = 6;
    break;
   case 6:
    var $25;
    return $25;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5typesL13HashSetInsertIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_1740($compartment, $values, $count, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[$count >> 2];
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    HEAP32[$count >> 2] = 1;
    var $_0 = $values;
    __label__ = 15;
    break;
   case 3:
    var $5 = HEAP32[$values >> 2];
    var $6 = $5;
    var $_idx1_val = HEAP32[$5 >> 2];
    var $7 = __ZN2js5types8Property6getKeyEPS1_($_idx1_val);
    if (($7 | 0) == ($key | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = $values;
    __label__ = 15;
    break;
   case 5:
    var $12 = $compartment + 344 | 0;
    var $13 = __ZN2js10ArenaArrayIPNS_5types8PropertyEEEPT_R11JSArenaPoolj($12, 8);
    HEAP32[$values >> 2] = $13;
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$values >> 2] = $5;
    var $_0 = 0;
    __label__ = 15;
    break;
   case 7:
    __ZN2jsL7PodZeroIPNS_5types8PropertyEEEvPT_j1741($13, 8);
    var $18 = HEAP32[$count >> 2] + 1 | 0;
    HEAP32[$count >> 2] = $18;
    var $19 = HEAP32[$values >> 2];
    HEAP32[$19 >> 2] = $6;
    var $_0 = HEAP32[$values >> 2] + 4 | 0;
    __label__ = 15;
    break;
   case 8:
    if ($1 >>> 0 < 9) {
      var $i_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 9:
    var $i_0;
    if ($i_0 >>> 0 < $1 >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $27 = HEAP32[$values >> 2] + ($i_0 << 2) | 0;
    var $_idx_val = HEAP32[HEAP32[$27 >> 2] >> 2];
    var $29 = __ZN2js5types8Property6getKeyEPS1_($_idx_val);
    if (($29 | 0) == ($key | 0)) {
      var $_0 = $27;
      __label__ = 15;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 9;
    break;
   case 12:
    if ($1 >>> 0 < 8) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    HEAP32[$count >> 2] = $1 + 1 | 0;
    var $_0 = HEAP32[$values >> 2] + ($1 << 2) | 0;
    __label__ = 15;
    break;
   case 14:
    var $40 = __ZN2js5typesL16HashSetInsertTryIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_1742($compartment, $values, $count, $key);
    var $_0 = $40;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5typesL13HashSetInsertIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_1740["X"] = 1;

function __ZN2jsL7PodZeroIPNS_5types8PropertyEEEvPT_j1741($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem << 2;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js5typesL16HashSetInsertTryIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_1742($compartment, $values, $count, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$count >> 2];
    var $2 = __ZN2js5typesL15HashSetCapacityEj1739($1);
    var $3 = __ZN2js5typesL7HashKeyIiNS0_8PropertyEEEjT_1743($key);
    var $4 = $2 - 1 | 0;
    var $5 = $3 & $4;
    if (($1 | 0) == 8) {
      var $insertpos_1 = $5;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$values >> 2];
    var $insertpos_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $insertpos_0;
    var $9 = $7 + ($insertpos_0 << 2) | 0;
    var $10 = HEAP32[$9 >> 2];
    if (($10 | 0) == 0) {
      var $insertpos_1 = $insertpos_0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx1_val = HEAP32[$10 >> 2];
    var $13 = __ZN2js5types8Property6getKeyEPS1_($_idx1_val);
    if (($13 | 0) == ($key | 0)) {
      var $_0 = $9;
      __label__ = 17;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $insertpos_0 = $insertpos_0 + 1 & $4;
    __label__ = 3;
    break;
   case 6:
    var $insertpos_1;
    var $18 = $1 + 1 | 0;
    HEAP32[$count >> 2] = $18;
    var $19 = __ZN2js5typesL15HashSetCapacityEj1739($18);
    if (($19 | 0) == ($2 | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $_0 = HEAP32[$values >> 2] + ($insertpos_1 << 2) | 0;
    __label__ = 17;
    break;
   case 8:
    var $25 = $compartment + 344 | 0;
    var $26 = __ZN2js10ArenaArrayIPNS_5types8PropertyEEEPT_R11JSArenaPoolj($25, $19);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2jsL7PodZeroIPNS_5types8PropertyEEEvPT_j1741($26, $19);
    var $_pre = $19 - 1 | 0;
    if (($2 | 0) == 0) {
      var $_pre_phi = $_pre;
      __label__ = 15;
      break;
    } else {
      var $i_013 = 0;
      __label__ = 10;
      break;
    }
   case 10:
    var $i_013;
    var $32 = HEAP32[HEAP32[$values >> 2] + ($i_013 << 2) >> 2];
    if (($32 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_idx_val = HEAP32[$32 >> 2];
    var $35 = __ZN2js5types8Property6getKeyEPS1_($_idx_val);
    var $36 = __ZN2js5typesL7HashKeyIiNS0_8PropertyEEEjT_1743($35);
    var $pos_09 = $36 & $_pre;
    var $37 = $26 + ($pos_09 << 2) | 0;
    if ((HEAP32[$37 >> 2] | 0) == 0) {
      var $_lcssa8 = $37;
      __label__ = 13;
      break;
    } else {
      var $pos_010 = $pos_09;
      __label__ = 12;
      break;
    }
   case 12:
    var $pos_010;
    var $pos_0 = $pos_010 + 1 & $_pre;
    var $41 = $26 + ($pos_0 << 2) | 0;
    if ((HEAP32[$41 >> 2] | 0) == 0) {
      var $_lcssa8 = $41;
      __label__ = 13;
      break;
    } else {
      var $pos_010 = $pos_0;
      __label__ = 12;
      break;
    }
   case 13:
    var $_lcssa8;
    HEAP32[$_lcssa8 >> 2] = $32;
    __label__ = 14;
    break;
   case 14:
    var $45 = $i_013 + 1 | 0;
    if (($45 | 0) == ($2 | 0)) {
      var $_pre_phi = $_pre;
      __label__ = 15;
      break;
    } else {
      var $i_013 = $45;
      __label__ = 10;
      break;
    }
   case 15:
    var $_pre_phi;
    HEAP32[$values >> 2] = $26;
    var $insertpos_26 = $3 & $_pre_phi;
    var $46 = $26 + ($insertpos_26 << 2) | 0;
    if ((HEAP32[$46 >> 2] | 0) == 0) {
      var $_0 = $46;
      __label__ = 17;
      break;
    } else {
      var $insertpos_27 = $insertpos_26;
      __label__ = 16;
      break;
    }
   case 16:
    var $insertpos_27;
    var $insertpos_2 = $insertpos_27 + 1 & $_pre_phi;
    var $50 = $26 + ($insertpos_2 << 2) | 0;
    if ((HEAP32[$50 >> 2] | 0) == 0) {
      var $_0 = $50;
      __label__ = 17;
      break;
    } else {
      var $insertpos_27 = $insertpos_2;
      __label__ = 16;
      break;
    }
   case 17:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5typesL16HashSetInsertTryIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_1742["X"] = 1;

function __ZN2js5typesL7HashKeyIiNS0_8PropertyEEEjT_1743($v) {
  var $1 = __ZN2js5types8Property7keyBitsEi($v);
  return ((($1 & 255 ^ 84696351) * 16777619 ^ $1 >>> 8 & 255) * 16777619 ^ $1 >>> 16 & 255) * 16777619 ^ $1 >>> 24;
}

function __ZN2js5types8PropertyC1ERKS1_($this, $o) {
  __ZN2js5types8PropertyC2ERKS1_($this, $o);
  return;
}

function __ZN2js5types8PropertyC2ERKS1_($this, $o) {
  var $3 = HEAP32[$o >> 2];
  HEAP32[$this >> 2] = $3;
  var $6 = $this + 4 | 0;
  var $7 = $o + 4 | 0;
  HEAP32[$6 >> 2] = HEAP32[$7 >> 2];
  HEAP32[$6 + 4 >> 2] = HEAP32[$7 + 4 >> 2];
  HEAP32[$6 + 8 >> 2] = HEAP32[$7 + 8 >> 2];
  return;
}

function __ZN2js7analyze14ScriptAnalysisC1EP8JSScript($this, $script) {
  __ZN2js7analyze14ScriptAnalysisC2EP8JSScript($this, $script);
  return;
}

function __ZN2js7analyze14ScriptAnalysisC2EP8JSScript($this, $script) {
  __ZN2jsL7PodZeroINS_7analyze14ScriptAnalysisEEEvPT_($this);
  HEAP32[$this >> 2] = $script;
  return;
}

function __ZN2jsL7PodZeroINS_7analyze14ScriptAnalysisEEEvPT_($t) {
  var $1 = $t;
  _memset($1, 0, 40, 1);
  return;
}

function __ZN2js5types17TypeScriptNestingC1Ev($this) {
  __ZN2js5types17TypeScriptNestingC2Ev($this);
  return;
}

function __ZN2js5types17TypeScriptNestingC2Ev($this) {
  __ZN2jsL7PodZeroINS_5types17TypeScriptNestingEEEvPT_($this);
  return;
}

function __ZN2jsL7PodZeroINS_5types17TypeScriptNestingEEEvPT_($t) {
  var $1 = $t;
  _memset($1, 0, 28, 1);
  return;
}

function __ZN2js5types10TypeResultC1EjNS0_4TypeE($this, $offset, $type_01) {
  __ZN2js5types10TypeResultC2EjNS0_4TypeE($this, $offset, $type_01);
  return;
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE13growStorageByEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __stackBase__ = STACKTOP;
  var tempParam = $t;
  $t = STACKTOP;
  STACKTOP += 8;
  HEAP32[$t >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$t + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $8 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    var $5 = $t;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $st$6$0 = $4 | 0;
    HEAP32[$st$6$0 >> 2] = $6$0;
    var $st$6$1 = $4 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $6$1;
    var $8 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $8;
    HEAP32[$this_idx1 >> 2] = $8 + 1 | 0;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 3;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj0ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, 1);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 268435455) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 268435455) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj0ES3_EEj($v, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $v | 0;
    var $3 = $newcap << 3;
    var $4 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $v_idx = $v + 4 | 0;
    var $v_idx_val = HEAP32[$v_idx >> 2];
    var $8 = __ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($v_idx_val);
    var $v_idx4 = $v + 8 | 0;
    var $v_idx4_val = HEAP32[$v_idx4 >> 2];
    var $9 = __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($v_idx_val, $v_idx4_val);
    if (($8 | 0) == ($9 | 0)) {
      var $22 = $v_idx_val;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx = $1 | 0;
    var $dst_01 = $5;
    var $src_02 = $8;
    var $v_idx1_val5 = $v_idx_val;
    var $v_idx2_val7 = $v_idx4_val;
    __label__ = 4;
    break;
   case 4:
    var $v_idx2_val7;
    var $v_idx1_val5;
    var $src_02;
    var $dst_01;
    if (($dst_01 | 0) == 0) {
      var $v_idx1_val = $v_idx1_val5;
      var $v_idx2_val = $v_idx2_val7;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = $dst_01;
    HEAP32[$13 >> 2] = 0;
    HEAP32[$13 + 4 >> 2] = 0;
    __ZN2js4MoveINS_7analyze8SSAValueEEENS_7MoveRefIT_EERS4_($1, $src_02);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $14 = __ZNK2js7MoveRefINS_7analyze8SSAValueEEcvRS2_Ev($_idx_val);
    var $15 = $14;
    var $16$0 = HEAP32[$15 >> 2];
    var $16$1 = HEAP32[$15 + 4 >> 2];
    HEAP32[$13 >> 2] = $16$0;
    HEAP32[$13 + 4 >> 2] = $16$1;
    var $v_idx1_val = HEAP32[$v_idx >> 2];
    var $v_idx2_val = HEAP32[$v_idx4 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $v_idx2_val;
    var $v_idx1_val;
    var $18 = $dst_01 + 8 | 0;
    var $19 = $src_02 + 8 | 0;
    var $20 = __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($v_idx1_val, $v_idx2_val);
    if (($19 | 0) == ($20 | 0)) {
      var $22 = $v_idx1_val;
      __label__ = 7;
      break;
    } else {
      var $dst_01 = $18;
      var $src_02 = $19;
      var $v_idx1_val5 = $v_idx1_val;
      var $v_idx2_val7 = $v_idx2_val;
      __label__ = 4;
      break;
    }
   case 7:
    var $22;
    __ZN2js15TempAllocPolicy5free_EPv($22 | 0);
    HEAP32[$v_idx >> 2] = $5;
    HEAP32[$v + 12 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js10VectorImplINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj0ES3_EEj["X"] = 1;

function __ZN2js4MoveINS_7analyze8SSAValueEEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_7analyze8SSAValueEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_7analyze8SSAValueEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefINS_7analyze8SSAValueEEC2ERS2_($this, $t);
  return;
}

function __ZN2js10VectorImplINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx = $1 | 0;
    var $p_01 = $srcbeg;
    var $_02 = $dst;
    __label__ = 3;
    break;
   case 3:
    var $_02;
    var $p_01;
    if (($_02 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $5 = $_02;
    HEAP32[$5 >> 2] = 0;
    HEAP32[$5 + 4 >> 2] = 0;
    __ZN2js4MoveINS_7analyze8SSAValueEEENS_7MoveRefIT_EERKS4_($1, $p_01);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $6 = __ZNK2js7MoveRefINS_7analyze8SSAValueEEcvRS2_Ev($_idx_val);
    var $7 = $6;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    HEAP32[$5 >> 2] = $8$0;
    HEAP32[$5 + 4 >> 2] = $8$1;
    __label__ = 5;
    break;
   case 5:
    var $10 = $p_01 + 8 | 0;
    if (($10 | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      var $p_01 = $10;
      var $_02 = $_02 + 8 | 0;
      __label__ = 3;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_7analyze8SSAValueEEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_7analyze8SSAValueEEC1ERS2_($agg_result, $t);
  return;
}

function __ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv($this) {
  return;
}

function __ZNK2js5types4Type3rawEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E10overloadedEv($this_0_1_val, $this_0_2_val, $this_0_4_val) {
  return ($this_0_4_val + $this_0_2_val | 0) >>> 0 >= ($this_0_1_val * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this_0_1_val, $this_0_2_val, $this_0_4_val) {
  return ($this_0_4_val + $this_0_2_val | 0) >>> 0 >= ($this_0_1_val * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZN2js10VectorImplIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyELb1EE13copyConstructIS3_EEvPS3_PKT_SA_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS6_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE12setCollisionEj($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S3_EE($e) {
  return $e | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_($this) {
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  return;
}

function __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC2ERKS2_RKS4_($this, $k, $v) {
  var $1 = $k;
  var $2 = $this;
  var $3$0 = HEAP32[$1 >> 2];
  var $3$1 = HEAP32[$1 + 4 >> 2];
  HEAP32[$2 >> 2] = $3$0;
  HEAP32[$2 + 4 >> 2] = $3$1;
  var $5 = HEAP32[$v >> 2];
  HEAP32[$this + 8 >> 2] = $5;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE12setCollisionEj($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($e) {
  return $e | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this) {
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  return;
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3 | 0;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZN2js5types12TypeCallsiteC1EP9JSContextP8JSScriptPhbj($this, $cx, $script, $pc, $isNew, $argumentCount) {
  __ZN2js5types12TypeCallsiteC2EP9JSContextP8JSScriptPhbj($this, $cx, $script, $pc, $isNew, $argumentCount);
  return;
}

function __ZN2js5types12TypeCallsiteC2EP9JSContextP8JSScriptPhbj($this, $cx, $script, $pc, $isNew, $argumentCount) {
  HEAP32[$this >> 2] = $script;
  HEAP32[$this + 4 >> 2] = $pc;
  HEAP8[$this + 8 | 0] = $isNew & 1;
  HEAP32[$this + 16 >> 2] = $argumentCount;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  var $10 = HEAP32[$cx + 56 >> 2] + 344 | 0;
  var $11 = __ZN2js10ArenaArrayIPNS_5types7TypeSetEEEPT_R11JSArenaPoolj($10, $argumentCount);
  HEAP32[$this + 12 >> 2] = $11;
  return;
}

function __ZN2js10ArenaArrayIPNS_5types7TypeSetEEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + ($count << 2) & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE13growStorageByEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $5 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    var $5 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    HEAP32[$this_idx1 >> 2] = $5 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 2;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyELb1EE13moveConstructIS3_EEvPS3_PKT_SA_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS3_Lj0ES4_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, 1);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS3_Lj0ES4_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $3 = $v + 4 | 0;
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($2, $5, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    var $10 = $v + 12 | 0;
    HEAP32[$3 >> 2] = $9;
    HEAP32[$10 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyELb1EE13moveConstructIS3_EEvPS3_PKT_SA_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyELb1EE13copyConstructIS3_EEvPS3_PKT_SA_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js5types8PropertyC1Ei($this, $id) {
  __ZN2js5types8PropertyC2Ei($this, $id);
  return;
}

function __ZN2js5types8PropertyC2Ei($this, $id) {
  HEAP32[$this >> 2] = $id;
  var $2 = $this + 4 | 0;
  __ZN2js5types7TypeSetC1Ev($2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrEPPS6_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 8 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 16 >> 2];
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E12lookupForAddERKP8JSObject($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $l_val_idx_val = HEAP32[$l_val >> 2];
  var $l_val_idx1_val = HEAP32[$l_val + 8 >> 2];
  var $l_val_idx2_val_idx_val = HEAP32[HEAP32[$l_val + 36 >> 2] >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKP8JSObject($l_val_idx_val, $l_val_idx1_val, $l_val_idx2_val_idx_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKP8JSObjectjj($this, $l, $1);
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC1ERNS0_14HashTableEntryIS6_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKP8JSObject($l_val_0_0_val, $l_val_0_2_val, $l_val_0_9_val_0_0_val) {
  var $1 = __ZN2js5types14ObjectTableKey4hashEP8JSObject($l_val_0_0_val, $l_val_0_2_val, $l_val_0_9_val_0_0_val);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKP8JSObjectjj($this, $l, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 28 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $l_val4 = HEAP32[$l >> 2];
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS6_EERKP8JSObject($6, $l_val4);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE12setCollisionEj($entry_0);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 28 | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $l_val = HEAP32[$l >> 2];
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS6_EERKP8JSObject($27, $l_val);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKP8JSObjectjj["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC1ERNS0_14HashTableEntryIS6_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC2ERNS0_14HashTableEntryIS6_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC2ERNS0_14HashTableEntryIS6_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS6_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS6_EERKP8JSObject($e, $l_val) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S3_EE($1);
  var $3 = __ZN2js5types14ObjectTableKey5matchERKS1_P8JSObject($2, $l_val);
  return $3;
}

function __ZN2js5types14ObjectTableKey5matchERKS1_P8JSObject($v, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj_idx2_val = HEAP32[$obj >> 2];
    var $obj_idx2_val_idx_val = HEAP32[$obj_idx2_val + 4 >> 2];
    var $1 = __ZNK8JSObject8slotSpanEv($obj_idx2_val_idx_val);
    if (($1 | 0) == (HEAP32[$v + 4 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    var $obj_idx_val = HEAP32[$obj + 8 >> 2];
    var $6 = __ZNK8JSObject13numFixedSlotsEv($obj_idx_val);
    if (($6 | 0) == (HEAP32[$v + 8 >> 2] | 0)) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $obj_idx3_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $11 = __ZNK8JSObject8getProtoEv($obj_idx3_val_idx_val);
    if (($11 | 0) == (HEAP32[$v + 12 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $16 = __ZNK8JSObject12lastPropertyEv($obj_idx2_val);
    var $17 = $v | 0;
    var $shape_0 = $16;
    __label__ = 5;
    break;
   case 5:
    var $shape_0;
    var $20 = HEAP32[$shape_0 + 12 >> 2];
    var $21 = _JSID_IS_EMPTY($20);
    if (($21 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 6:
    if (($20 | 0) == (HEAP32[HEAP32[$17 >> 2] + (HEAP32[$shape_0 + 24 >> 2] << 2) >> 2] | 0)) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $shape_0_idx_val = HEAP32[$shape_0 + 32 >> 2];
    var $31 = __ZNK2js5Shape8previousEv($shape_0_idx_val);
    var $shape_0 = $31;
    __label__ = 5;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types14ObjectTableKey4hashEP8JSObject($obj_0_0_val, $obj_0_2_val, $obj_0_9_val_0_0_val) {
  var $1 = __ZNK8JSObject12lastPropertyEv($obj_0_0_val);
  var $3 = HEAP32[$1 + 12 >> 2];
  var $obj_idx2_val_idx_val = HEAP32[$obj_0_0_val + 4 >> 2];
  var $4 = __ZNK8JSObject8slotSpanEv($obj_idx2_val_idx_val);
  var $5 = __ZNK8JSObject13numFixedSlotsEv($obj_0_2_val);
  var $6 = __ZNK8JSObject8getProtoEv($obj_0_9_val_0_0_val);
  return $4 ^ $3 ^ $5 ^ $6 >>> 2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $0 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j(16);
    HEAP32[$this + 20 >> 2] = $0;
    if (($0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej($this, 4);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEEC1ES4_($this) {
  __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEEC2ES4_($this);
  return;
}

function __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEEC2ES4_($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13relookupOrAddERNSC_6AddPtrERKS4_RKS7_($this, $p, $l, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$p + 4 >> 2];
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $2);
    HEAP32[$p >> 2] = $3;
    var $_idx_val_idx_val = HEAP32[$3 >> 2];
    var $5 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($_idx_val_idx_val);
    if ($5) {
      var $9 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrERKS7_($this, $p, $t);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC1ERKS2_RKS4_($this, $k, $v) {
  __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC2ERKS2_RKS4_($this, $k, $v);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 4) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS7_EERKS4_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE12setCollisionEj($entry_0);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + ($26 << 4) | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS7_EERKS4_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj["X"] = 1;

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrERKS7_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEaSERKS5_($5, $t);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 8 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 16 >> 2];
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS7_EERKS4_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($1);
  var $3 = __ZN2js5types13ArrayTableKey5matchERKS1_S3_($2, $l);
  return $3;
}

function __ZN2js5types13ArrayTableKey5matchERKS1_S3_($v1, $v2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$v2 >> 2];
    var $_idx_val = HEAP32[$v1 >> 2];
    var $3 = __ZNK2js5types4TypeeqES1_($_idx_val, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = (HEAP32[$v1 + 4 >> 2] | 0) == (HEAP32[$v2 + 4 >> 2] | 0);
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $1);
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l) {
  var $1 = __ZN2js5types13ArrayTableKey4hashERKS1_($l);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS7_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js5types13ArrayTableKey4hashERKS1_($v) {
  var $_idx_val = HEAP32[$v >> 2];
  var $1 = __ZNK2js5types4Type3rawEv($_idx_val);
  return HEAP32[$v + 4 >> 2] >>> 2 ^ $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $0 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j(16);
    HEAP32[$this + 20 >> 2] = $0;
    if (($0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, 4);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC1ES5_($this) {
  __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC2ES5_($this);
  return;
}

function __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC2ES5_($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this);
  return;
}

function __ZN2js5types11TypeBarrierC1EPNS0_7TypeSetENS0_4TypeEP8JSObjecti($this, $target, $type_01, $singleton, $singletonId) {
  __ZN2js5types11TypeBarrierC2EPNS0_7TypeSetENS0_4TypeEP8JSObjecti($this, $target, $type_01, $singleton, $singletonId);
  return;
}

function __ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZN27TypeConstraintLazyArguments7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this_0_1_val, $this_0_2_val, $this_0_4_val) {
  return ($this_0_4_val + $this_0_2_val | 0) >>> 0 >= ($this_0_1_val * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js5types11TypeBarrierC2EPNS0_7TypeSetENS0_4TypeEP8JSObjecti($this, $target, $type_0, $singleton, $singletonId) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = $target;
  HEAP32[$this + 8 >> 2] = $type_0;
  HEAP32[$this + 12 >> 2] = $singleton;
  HEAP32[$this + 16 >> 2] = $singletonId;
  return;
}

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZN2js10VectorImplIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyELb1EE13copyConstructIS3_EEvPS3_PKT_SA_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this) {
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  return;
}

function __ZN2js5types14TypeConstraintC2EPKc($this) {
  HEAP32[$this >> 2] = __ZTVN2js5types14TypeConstraintE + 8 | 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN17SweepTypeObjectOpC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  return;
}

function __ZN2js5types10TypeScriptC2EP10JSFunction($this, $fun) {
  HEAP32[$this + 4 >> 2] = $fun;
  HEAP32[$this + 8 >> 2] = 1;
  return;
}

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE13growStorageByEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $5 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    var $5 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    HEAP32[$this_idx1 >> 2] = $5 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 2;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyELb1EE13moveConstructIS3_EEvPS3_PKT_SA_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS3_Lj0ES4_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, 1);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS3_Lj0ES4_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $3 = $v + 4 | 0;
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($2, $5, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    var $10 = $v + 12 | 0;
    HEAP32[$3 >> 2] = $9;
    HEAP32[$10 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyELb1EE13moveConstructIS3_EEvPS3_PKT_SA_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyELb1EE13copyConstructIS3_EEvPS3_PKT_SA_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEEC2ES4_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZN2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS7_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 8 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 16 >> 2];
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS7_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $0 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j(16);
    HEAP32[$this + 20 >> 2] = $0;
    if (($0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, 4);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC1ES5_($this) {
  __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC2ES5_($this);
  return;
}

function __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC2ES5_($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this);
  return;
}

function __ZN27TypeConstraintLazyArgumentsC1EPN2js5types7TypeSetE($this, $target) {
  __ZN27TypeConstraintLazyArgumentsC2EPN2js5types7TypeSetE($this, $target);
  return;
}

function __ZN27TypeConstraintLazyArgumentsC2EPN2js5types7TypeSetE($this, $target) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1);
  HEAP32[$this >> 2] = __ZTV27TypeConstraintLazyArguments + 8 | 0;
  HEAP32[$this + 8 >> 2] = $target;
  return;
}

function __ZN27TypeConstraintLazyArguments14newObjectStateEP9JSContextPN2js5types10TypeObjectEb($this, $cx, $object, $force) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $object_idx_val = HEAP32[$object + 12 >> 2];
    var $2 = __ZN2js5types10TypeObject11hasAnyFlagsEj($object_idx_val, 524288);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$this + 8 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($1);
    var $_0_val = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($5, $cx, $_0_val);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN27TypeConstraintSubsetBarrierC1EP8JSScriptPhPN2js5types7TypeSetE($this, $script, $pc, $target) {
  __ZN27TypeConstraintSubsetBarrierC2EP8JSScriptPhPN2js5types7TypeSetE($this, $script, $pc, $target);
  return;
}

function __ZN27TypeConstraintSubsetBarrierC2EP8JSScriptPhPN2js5types7TypeSetE($this, $script, $pc, $target) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1);
  HEAP32[$this >> 2] = __ZTV27TypeConstraintSubsetBarrier + 8 | 0;
  HEAP32[$this + 8 >> 2] = $script;
  HEAP32[$this + 12 >> 2] = $pc;
  HEAP32[$this + 16 >> 2] = $target;
  return;
}

function __ZN27TypeConstraintSubsetBarrier7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 16 >> 2];
    var $4 = HEAP32[$type >> 2];
    var $5 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($2, $4);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val_idx_val = HEAP32[HEAP32[HEAP32[$this + 8 >> 2] + 100 >> 2] >> 2];
    var $9 = __ZN8JSScript8analysisEv($_idx_val_idx_val);
    var $11 = HEAP32[$this + 12 >> 2];
    var $_idx2_val = HEAP32[$9 >> 2];
    var $_idx3_val = HEAP32[$9 + 4 >> 2];
    __ZN2js7analyze14ScriptAnalysis14addTypeBarrierEP9JSContextPKhPNS_5types7TypeSetENS6_4TypeE($_idx2_val, $_idx3_val, $cx, $11, $2, $4);
    __label__ = 4;
    break;
   case 3:
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($2, $cx, $4);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN29TypeConstraintFilterPrimitiveC1EPN2js5types7TypeSetENS2_10FilterKindE($this, $target, $filter) {
  __ZN29TypeConstraintFilterPrimitiveC2EPN2js5types7TypeSetENS2_10FilterKindE($this, $target, $filter);
  return;
}

function __ZN29TypeConstraintFilterPrimitiveC2EPN2js5types7TypeSetENS2_10FilterKindE($this, $target, $filter) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1);
  HEAP32[$this >> 2] = __ZTV29TypeConstraintFilterPrimitive + 8 | 0;
  HEAP32[$this + 8 >> 2] = $target;
  HEAP32[$this + 12 >> 2] = $filter;
  return;
}

function __ZN29TypeConstraintFilterPrimitive7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 12 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else if (($2 | 0) == 1) {
      __label__ = 4;
      break;
    } else if (($2 | 0) == 2) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = HEAP32[$type >> 2];
    __label__ = 7;
    break;
   case 3:
    var $type_idx_val = HEAP32[$type >> 2];
    var $4 = __ZNK2js5types4Type11isPrimitiveEv($type_idx_val);
    if ($4) {
      __label__ = 8;
      break;
    } else {
      var $12 = $type_idx_val;
      __label__ = 7;
      break;
    }
   case 4:
    var $type_idx3_val = HEAP32[$type >> 2];
    var $6 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($type_idx3_val, 6);
    if ($6) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $8 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($type_idx3_val, 2);
    if ($8) {
      __label__ = 8;
      break;
    } else {
      var $12 = $type_idx3_val;
      __label__ = 7;
      break;
    }
   case 6:
    var $type_idx1_val = HEAP32[$type >> 2];
    var $10 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($type_idx1_val, 2);
    if ($10) {
      __label__ = 8;
      break;
    } else {
      var $12 = $type_idx1_val;
      __label__ = 7;
      break;
    }
   case 7:
    var $12;
    var $14 = HEAP32[$this + 8 >> 2];
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($14, $cx, $12);
    __label__ = 8;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN27TypeConstraintPropagateThisC1EP8JSScriptPhN2js5types4TypeEPNS4_7TypeSetE($this, $script, $callpc, $type_01, $types) {
  __ZN27TypeConstraintPropagateThisC2EP8JSScriptPhN2js5types4TypeEPNS4_7TypeSetE($this, $script, $callpc, $type_01, $types);
  return;
}

function __ZN27TypeConstraintPropagateThisC2EP8JSScriptPhN2js5types4TypeEPNS4_7TypeSetE($this, $script, $callpc, $type_0, $types) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1);
  HEAP32[$this >> 2] = __ZTV27TypeConstraintPropagateThis + 8 | 0;
  HEAP32[$this + 8 >> 2] = $script;
  HEAP32[$this + 12 >> 2] = $callpc;
  HEAP32[$this + 16 >> 2] = $type_0;
  HEAP32[$this + 20 >> 2] = $types;
  return;
}

function __ZN27TypeConstraintTransformThisC1EP8JSScriptPN2js5types7TypeSetE($this, $script, $target) {
  __ZN27TypeConstraintTransformThisC2EP8JSScriptPN2js5types7TypeSetE($this, $script, $target);
  return;
}

function __ZN27TypeConstraintTransformThisC2EP8JSScriptPN2js5types7TypeSetE($this, $script, $target) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1);
  HEAP32[$this >> 2] = __ZTV27TypeConstraintTransformThis + 8 | 0;
  HEAP32[$this + 8 >> 2] = $script;
  HEAP32[$this + 12 >> 2] = $target;
  return;
}

function __ZN19TypeConstraintArithC1EPN2js5types7TypeSetES3_($this, $target, $other) {
  __ZN19TypeConstraintArithC2EPN2js5types7TypeSetES3_($this, $target, $other);
  return;
}

function __ZN19TypeConstraintArithC2EPN2js5types7TypeSetES3_($this, $target, $other) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1);
  HEAP32[$this >> 2] = __ZTV19TypeConstraintArith + 8 | 0;
  HEAP32[$this + 8 >> 2] = $target;
  HEAP32[$this + 12 >> 2] = $other;
  return;
}

function __ZN18TypeConstraintCallC1EPN2js5types12TypeCallsiteE($this, $callsite) {
  __ZN18TypeConstraintCallC2EPN2js5types12TypeCallsiteE($this, $callsite);
  return;
}

function __ZN18TypeConstraintCallC2EPN2js5types12TypeCallsiteE($this, $callsite) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1);
  HEAP32[$this >> 2] = __ZTV18TypeConstraintCall + 8 | 0;
  HEAP32[$this + 8 >> 2] = $callsite;
  return;
}

function __ZN24TypeConstraintSetElementC1EP8JSScriptPhPN2js5types7TypeSetES6_($this, $script, $pc, $objectTypes, $valueTypes) {
  __ZN24TypeConstraintSetElementC2EP8JSScriptPhPN2js5types7TypeSetES6_($this, $script, $pc, $objectTypes, $valueTypes);
  return;
}

function __ZN24TypeConstraintSetElementC2EP8JSScriptPhPN2js5types7TypeSetES6_($this, $script, $pc, $objectTypes, $valueTypes) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1);
  HEAP32[$this >> 2] = __ZTV24TypeConstraintSetElement + 8 | 0;
  HEAP32[$this + 8 >> 2] = $script;
  HEAP32[$this + 12 >> 2] = $pc;
  HEAP32[$this + 16 >> 2] = $objectTypes;
  HEAP32[$this + 20 >> 2] = $valueTypes;
  return;
}

function __ZN22TypeConstraintCallPropC1EP8JSScriptPhi($this, $script, $callpc, $id) {
  __ZN22TypeConstraintCallPropC2EP8JSScriptPhi($this, $script, $callpc, $id);
  return;
}

function __ZN22TypeConstraintCallPropC2EP8JSScriptPhi($this, $script, $callpc, $id) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1);
  HEAP32[$this >> 2] = __ZTV22TypeConstraintCallProp + 8 | 0;
  HEAP32[$this + 8 >> 2] = $script;
  HEAP32[$this + 12 >> 2] = $callpc;
  HEAP32[$this + 16 >> 2] = $id;
  return;
}

function __ZN18TypeConstraintPropC1EP8JSScriptPhPN2js5types7TypeSetEib($this, $script, $pc, $target, $id, $assign) {
  __ZN18TypeConstraintPropC2EP8JSScriptPhPN2js5types7TypeSetEib($this, $script, $pc, $target, $id, $assign);
  return;
}

function __ZN18TypeConstraintPropC2EP8JSScriptPhPN2js5types7TypeSetEib($this, $script, $pc, $target, $id, $assign) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1);
  HEAP32[$this >> 2] = __ZTV18TypeConstraintProp + 8 | 0;
  HEAP32[$this + 8 >> 2] = $script;
  HEAP32[$this + 12 >> 2] = $pc;
  HEAP8[$this + 16 | 0] = $assign & 1;
  HEAP32[$this + 20 >> 2] = $target;
  HEAP32[$this + 24 >> 2] = $id;
  return;
}

function __ZN20TypeConstraintSubsetC1EPN2js5types7TypeSetE($this, $target) {
  __ZN20TypeConstraintSubsetC2EPN2js5types7TypeSetE($this, $target);
  return;
}

function __ZN20TypeConstraintSubsetC2EPN2js5types7TypeSetE($this, $target) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1);
  HEAP32[$this >> 2] = __ZTV20TypeConstraintSubset + 8 | 0;
  HEAP32[$this + 8 >> 2] = $target;
  return;
}

function __ZN20TypeConstraintSubset7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$type >> 2];
  __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($2, $cx, $4);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js5typesL13HashSetInsertIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_1745($compartment, $values, $count, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[$count >> 2];
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    HEAP32[$count >> 2] = 1;
    var $_0 = $values;
    __label__ = 15;
    break;
   case 3:
    var $5 = HEAP32[$values >> 2];
    var $6 = $5;
    var $7 = __ZN2js5types13TypeObjectKey6getKeyEPS1_($6);
    if (($7 | 0) == ($key | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = $values;
    __label__ = 15;
    break;
   case 5:
    var $12 = $compartment + 344 | 0;
    var $13 = __ZN2js10ArenaArrayIPNS_5types13TypeObjectKeyEEEPT_R11JSArenaPoolj($12, 8);
    HEAP32[$values >> 2] = $13;
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$values >> 2] = $5;
    var $_0 = 0;
    __label__ = 15;
    break;
   case 7:
    __ZN2jsL7PodZeroIPNS_5types13TypeObjectKeyEEEvPT_j1746($13, 8);
    var $18 = HEAP32[$count >> 2] + 1 | 0;
    HEAP32[$count >> 2] = $18;
    var $19 = HEAP32[$values >> 2];
    HEAP32[$19 >> 2] = $6;
    var $_0 = HEAP32[$values >> 2] + 4 | 0;
    __label__ = 15;
    break;
   case 8:
    if ($1 >>> 0 < 9) {
      var $i_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 9:
    var $i_0;
    if ($i_0 >>> 0 < $1 >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $27 = HEAP32[$values >> 2] + ($i_0 << 2) | 0;
    var $28 = HEAP32[$27 >> 2];
    var $29 = __ZN2js5types13TypeObjectKey6getKeyEPS1_($28);
    if (($29 | 0) == ($key | 0)) {
      var $_0 = $27;
      __label__ = 15;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 9;
    break;
   case 12:
    if ($1 >>> 0 < 8) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    HEAP32[$count >> 2] = $1 + 1 | 0;
    var $_0 = HEAP32[$values >> 2] + ($1 << 2) | 0;
    __label__ = 15;
    break;
   case 14:
    var $40 = __ZN2js5typesL16HashSetInsertTryIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_1747($compartment, $values, $count, $key);
    var $_0 = $40;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5typesL13HashSetInsertIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_1745["X"] = 1;

function __ZN2jsL7PodZeroIPNS_5types13TypeObjectKeyEEEvPT_j1746($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem << 2;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js5typesL16HashSetInsertTryIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_1747($compartment, $values, $count, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$count >> 2];
    var $2 = __ZN2js5typesL15HashSetCapacityEj1739($1);
    var $3 = __ZN2js5typesL7HashKeyIPNS0_13TypeObjectKeyES2_EEjT_1748($key);
    var $4 = $2 - 1 | 0;
    var $5 = $3 & $4;
    if (($1 | 0) == 8) {
      var $insertpos_1 = $5;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$values >> 2];
    var $insertpos_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $insertpos_0;
    var $9 = $7 + ($insertpos_0 << 2) | 0;
    var $10 = HEAP32[$9 >> 2];
    if (($10 | 0) == 0) {
      var $insertpos_1 = $insertpos_0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = __ZN2js5types13TypeObjectKey6getKeyEPS1_($10);
    if (($13 | 0) == ($key | 0)) {
      var $_0 = $9;
      __label__ = 17;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $insertpos_0 = $insertpos_0 + 1 & $4;
    __label__ = 3;
    break;
   case 6:
    var $insertpos_1;
    var $18 = $1 + 1 | 0;
    HEAP32[$count >> 2] = $18;
    var $19 = __ZN2js5typesL15HashSetCapacityEj1739($18);
    if (($19 | 0) == ($2 | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $_0 = HEAP32[$values >> 2] + ($insertpos_1 << 2) | 0;
    __label__ = 17;
    break;
   case 8:
    var $25 = $compartment + 344 | 0;
    var $26 = __ZN2js10ArenaArrayIPNS_5types13TypeObjectKeyEEEPT_R11JSArenaPoolj($25, $19);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2jsL7PodZeroIPNS_5types13TypeObjectKeyEEEvPT_j1746($26, $19);
    var $_pre = $19 - 1 | 0;
    if (($2 | 0) == 0) {
      var $_pre_phi = $_pre;
      __label__ = 15;
      break;
    } else {
      var $i_013 = 0;
      __label__ = 10;
      break;
    }
   case 10:
    var $i_013;
    var $32 = HEAP32[HEAP32[$values >> 2] + ($i_013 << 2) >> 2];
    if (($32 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $35 = __ZN2js5types13TypeObjectKey6getKeyEPS1_($32);
    var $36 = __ZN2js5typesL7HashKeyIPNS0_13TypeObjectKeyES2_EEjT_1748($35);
    var $pos_09 = $36 & $_pre;
    var $37 = $26 + ($pos_09 << 2) | 0;
    if ((HEAP32[$37 >> 2] | 0) == 0) {
      var $_lcssa8 = $37;
      __label__ = 13;
      break;
    } else {
      var $pos_010 = $pos_09;
      __label__ = 12;
      break;
    }
   case 12:
    var $pos_010;
    var $pos_0 = $pos_010 + 1 & $_pre;
    var $41 = $26 + ($pos_0 << 2) | 0;
    if ((HEAP32[$41 >> 2] | 0) == 0) {
      var $_lcssa8 = $41;
      __label__ = 13;
      break;
    } else {
      var $pos_010 = $pos_0;
      __label__ = 12;
      break;
    }
   case 13:
    var $_lcssa8;
    HEAP32[$_lcssa8 >> 2] = $32;
    __label__ = 14;
    break;
   case 14:
    var $45 = $i_013 + 1 | 0;
    if (($45 | 0) == ($2 | 0)) {
      var $_pre_phi = $_pre;
      __label__ = 15;
      break;
    } else {
      var $i_013 = $45;
      __label__ = 10;
      break;
    }
   case 15:
    var $_pre_phi;
    HEAP32[$values >> 2] = $26;
    var $insertpos_26 = $3 & $_pre_phi;
    var $46 = $26 + ($insertpos_26 << 2) | 0;
    if ((HEAP32[$46 >> 2] | 0) == 0) {
      var $_0 = $46;
      __label__ = 17;
      break;
    } else {
      var $insertpos_27 = $insertpos_26;
      __label__ = 16;
      break;
    }
   case 16:
    var $insertpos_27;
    var $insertpos_2 = $insertpos_27 + 1 & $_pre_phi;
    var $50 = $26 + ($insertpos_2 << 2) | 0;
    if ((HEAP32[$50 >> 2] | 0) == 0) {
      var $_0 = $50;
      __label__ = 17;
      break;
    } else {
      var $insertpos_27 = $insertpos_2;
      __label__ = 16;
      break;
    }
   case 17:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5typesL16HashSetInsertTryIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_1747["X"] = 1;

function __ZN2js5typesL7HashKeyIPNS0_13TypeObjectKeyES2_EEjT_1748($v) {
  var $1 = __ZN2js5types13TypeObjectKey7keyBitsEPS1_($v);
  return ((($1 & 255 ^ 84696351) * 16777619 ^ $1 >>> 8 & 255) * 16777619 ^ $1 >>> 16 & 255) * 16777619 ^ $1 >>> 24;
}

function __ZN2js5types10TypeScript7SetThisEP9JSContextP8JSScriptNS0_4TypeE($cx, $script, $type_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $cx_idx1_val = HEAP8[$cx + 232 | 0];
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx1_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $cx_idx_val = HEAP32[$cx + 32 >> 2];
    var $3 = __ZNK9JSContext12hasRunOptionEj($cx_idx_val, 65536);
    var $script_idx4 = $script + 22 | 0;
    var $script_idx4_val = HEAP16[$script_idx4 >> 1];
    var $script_idx5 = $script + 100 | 0;
    var $script_idx5_val = HEAP32[$script_idx5 >> 2];
    var $4 = __ZN2js5types10TypeScript9ThisTypesEP8JSScript($script_idx4_val, $script_idx5_val);
    var $5 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($4, $type_0);
    if ($3 | $5 ^ 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx);
    var $script_idx_val = HEAP16[$script_idx4 >> 1];
    var $script_idx3_val = HEAP32[$script_idx5 >> 2];
    var $7 = __ZN2js5types10TypeScript9ThisTypesEP8JSScript($script_idx_val, $script_idx3_val);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($7, $cx, $type_0);
    if ($3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[HEAP32[$script_idx5 >> 2] + 8 >> 2];
    var $10 = __ZN2js5types10TypeScript8hasScopeEv($_idx_val);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $12 = __ZN8JSScript18ensureRanInferenceEP9JSContext($script, $cx);
    __label__ = 6;
    break;
   case 6:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    __label__ = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze17AutoEnterAnalysisD2Ev($this) {
  __ZN2js7analyze17AutoEnterAnalysis5leaveEv($this);
  return;
}

function __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE6lengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js7MoveRefINS_5types13TypeNewScript11InitializerEEcvRS3_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js7analyze17AutoEnterAnalysis5leaveEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 5 | 0;
    if ((HEAP8[$1] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP8[$1] = 1;
    var $8 = HEAP8[$this + 4 | 0] & 1;
    HEAP8[HEAP32[HEAP32[$this >> 2] + 56 >> 2] + 372 | 0] = $8;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze17AutoEnterAnalysisC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  var $3 = $cx + 56 | 0;
  var $7 = HEAP8[HEAP32[$3 >> 2] + 372 | 0] & 1;
  HEAP8[$this + 4 | 0] = $7;
  HEAP8[$this + 5 | 0] = 0;
  HEAP8[HEAP32[$3 >> 2] + 372 | 0] = 1;
  return;
}

function __ZN2js2gcL15GetGCObjectKindEjb1752($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 3) | 0;
}

function __ZN2js7MoveRefINS_5types13TypeNewScript11InitializerEEC2ERS3_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js5types13TypeNewScript11InitializerC2ENS2_4KindEj($this, $kind, $offset) {
  HEAP32[$this >> 2] = $kind;
  HEAP32[$this + 4 >> 2] = $offset;
  return;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1751($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 24;
    var $4 = __ZNK9JSContext5hasfpEv($cx);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $7;
    var $8 = $cx;
    var $9 = $global;
    var $10 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($8, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $18 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZNK9JSContext2fpEv($cx);
    var $13 = __ZNK2js10StackFrame10scopeChainEv($12);
    var $14 = $13;
    var $15 = __ZNK8JSObject9getGlobalEv($14);
    var $16 = $15;
    HEAP32[$global >> 2] = $16;
    var $18 = $16;
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $18, $19);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $20 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    HEAP32[$proto >> 2] = $22;
    var $29 = $22;
    __label__ = 9;
    break;
   case 7:
    var $24 = $cx;
    var $26 = $proto;
    var $27 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($24, $18, $3, $26, __ZN2js11ObjectClassE);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $29 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $29;
    var $30 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1753($cx, $29, $18);
    var $_0 = $30;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEEC1ES4_($this, $ap_01) {
  __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEEC2ES4_($this, $ap_01);
  return;
}

function __ZL26AnalyzeNewScriptPropertiesP9JSContextPN2js5types10TypeObjectEP10JSFunctionPP8JSObjectPNS1_6VectorINS2_13TypeNewScript11InitializerELj0ENS1_15TempAllocPolicyEEE($cx, $type, $fun, $pbaseobj, $initializerList) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 76;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $untrap = __stackBase__ + 4;
    var $thisv = __stackBase__ + 12;
    var $untrapUse = __stackBase__ + 20;
    var $2 = __stackBase__ + 28;
    var $3 = __stackBase__ + 36;
    var $calleev = __stackBase__ + 44;
    var $untrapCallee = __stackBase__ + 52;
    var $4 = __stackBase__ + 60;
    var $5 = __stackBase__ + 68;
    HEAP32[$1 >> 2] = $type;
    var $initializerList_idx_val = HEAP32[$initializerList + 8 >> 2];
    var $6 = __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE6lengthEv($initializerList_idx_val);
    if ($6 >>> 0 > 50) {
      var $_5 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZNK10JSFunction6scriptEv($fun);
    var $10 = __ZN8JSScript17ensureRanAnalysisEP9JSContextP10JSFunctionP8JSObject($9, $cx, $fun, 0);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = __ZN8JSScript18ensureRanInferenceEP9JSContext($9, $cx);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$pbaseobj >> 2] = 0;
    var $16 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($16, $cx);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 5:
    var $_idx20_val = HEAP32[$9 + 100 >> 2];
    var $_idx20_val_idx_val = HEAP32[$_idx20_val + 8 >> 2];
    var $18 = __ZNK8JSScript16hasClearedGlobalEv($_idx20_val_idx_val);
    if ($18) {
      var $_5 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx10_val_idx_val = HEAP32[$_idx20_val >> 2];
    var $20 = __ZN8JSScript8analysisEv($_idx10_val_idx_val);
    var $21 = $9 + 8 | 0;
    var $22 = $9 | 0;
    var $23 = $cx;
    var $24 = $cx + 56 | 0;
    var $25 = $cx;
    var $26 = $calleev;
    var $_idx18 = $20 | 0;
    var $_idx19 = $20 + 4 | 0;
    var $_idx6 = $9 + 56 | 0;
    var $cx_idx25 = $cx + 52 | 0;
    var $_029 = $3 | 0;
    var $_130 = $3 + 4 | 0;
    var $_027 = $4 | 0;
    var $_128 = $4 + 4 | 0;
    var $_0 = $5 | 0;
    var $_1 = $5 + 4 | 0;
    var $nextOffset_0_ph = 0;
    var $lastThisPopped_0_ph = 0;
    __label__ = 7;
    break;
   case 7:
    var $lastThisPopped_0_ph;
    var $nextOffset_0_ph;
    var $nextOffset_0 = $nextOffset_0_ph;
    __label__ = 8;
    break;
   case 8:
    var $nextOffset_0;
    if ($nextOffset_0 >>> 0 < HEAPU32[$21 >> 2] >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $_5 = 1;
      __label__ = 69;
      break;
    }
   case 9:
    var $32 = HEAP32[$22 >> 2] + $nextOffset_0 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $9, $32);
    var $33 = __ZN2js7analyzeL17GetBytecodeLengthEPh1712($32);
    var $34 = $33 + $nextOffset_0 | 0;
    var $_idx19_val = HEAP32[$_idx19 >> 2];
    var $_idx18_val_idx_val = HEAP32[HEAP32[$_idx18 >> 2] >> 2];
    var $35 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEPKh($_idx18_val_idx_val, $_idx19_val, $32);
    if (($35 | 0) == 0) {
      __label__ = 55;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = HEAP8[$32];
    if ($38 << 24 >> 24 == -59 || $38 << 24 >> 24 == -101 || $38 << 24 >> 24 == 5) {
      __label__ = 11;
      break;
    } else if ($38 << 24 >> 24 == 123) {
      __label__ = 14;
      break;
    } else if ($38 << 24 >> 24 == 65) {
      __label__ = 16;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 11:
    if ($nextOffset_0 >>> 0 < $lastThisPopped_0_ph >>> 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    HEAP32[$pbaseobj >> 2] = 0;
    var $_4_ph = 0;
    __label__ = 54;
    break;
   case 13:
    var $_4_ph = (HEAP8[$35 | 0] & 32) << 24 >> 24 != 0;
    __label__ = 54;
    break;
   case 14:
    if ($nextOffset_0 >>> 0 < $lastThisPopped_0_ph >>> 0) {
      __label__ = 15;
      break;
    } else {
      var $_4_ph = 0;
      __label__ = 54;
      break;
    }
   case 15:
    HEAP32[$pbaseobj >> 2] = 0;
    var $_4_ph = 0;
    __label__ = 54;
    break;
   case 16:
    __ZN2js7analyze8SSAValue11PushedValueEjj($thisv, $nextOffset_0, 0);
    var $51 = __ZN2js7analyze14ScriptAnalysis8useChainERKNS0_8SSAValueE($20, $thisv);
    var $52 = HEAPU32[$51 >> 2];
    if ((HEAP32[$52 + 8 >> 2] | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $_4_ph = 0;
      __label__ = 54;
      break;
    }
   case 17:
    if ((HEAP8[$52 | 0] & 1) << 24 >> 24 == 0) {
      var $_4_ph = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if ($nextOffset_0 >>> 0 < $lastThisPopped_0_ph >>> 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    HEAP32[$pbaseobj >> 2] = 0;
    var $_4_ph = 0;
    __label__ = 54;
    break;
   case 20:
    var $65 = $52;
    var $67 = HEAPU32[$65 >> 2] >>> 1;
    var $_idx11_val = HEAP32[$_idx19 >> 2];
    var $68 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEj($_idx11_val, $67);
    if (($68 | 0) == 0) {
      var $_4_ph = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    if ((HEAP8[$68 | 0] & 32) << 24 >> 24 == 0) {
      var $_4_ph = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $76 = HEAPU32[$22 >> 2];
    var $77 = $76 + $67 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrapUse, $9, $77);
    var $78 = HEAP8[$77];
    var $79 = HEAP32[$pbaseobj >> 2];
    if ($78 << 24 >> 24 == 54) {
      __label__ = 23;
      break;
    } else if ($78 << 24 >> 24 == 108) {
      __label__ = 40;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 23:
    if ((HEAP32[$52 + 4 >> 2] | 0) == 1) {
      __label__ = 24;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 24:
    var $85 = _js_GetIndexFromBytecode($9, $77, 0);
    var $_idx6_val = HEAP32[$_idx6 >> 2];
    var $86 = __ZN8JSScript7getAtomEj($_idx6_val, $85);
    var $87 = __ZL12ATOM_TO_JSIDP6JSAtom1694($86);
    var $88 = __ZN2js5types10MakeTypeIdEP9JSContexti($cx, $87);
    if (($88 | 0) == ($87 | 0)) {
      __label__ = 25;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 25:
    var $cx_idx25_val = HEAP32[$cx_idx25 >> 2];
    var $cx_idx25_val_idx_val = HEAP32[$cx_idx25_val + 210200 >> 2];
    var $91 = __ZL12id_prototypeP9JSContext($cx_idx25_val_idx_val);
    if (($87 | 0) == ($91 | 0)) {
      __label__ = 60;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $cx_idx_val_idx_val = HEAP32[$cx_idx25_val + 210292 >> 2];
    var $94 = __ZL12id___proto__P9JSContext($cx_idx_val_idx_val);
    if (($87 | 0) == ($94 | 0)) {
      __label__ = 59;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $cx_idx26_val_idx_val = HEAP32[$cx_idx25_val + 210204 >> 2];
    var $97 = __ZL14id_constructorP9JSContext($cx_idx26_val_idx_val);
    if (($87 | 0) == ($97 | 0)) {
      __label__ = 58;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $_idx5 = $79 | 0;
    var $_idx5_val_idx_val = HEAP32[HEAP32[$_idx5 >> 2] + 4 >> 2];
    var $100 = __ZNK8JSObject8slotSpanEv($_idx5_val_idx_val);
    __ZN2JSL14UndefinedValueEv1713($2);
    var $101 = $79;
    var $102 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($23, $101, $87, $2, 0, 0, 1, 0, 0, 16);
    if (($102 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 29:
    var $105 = HEAP32[$24 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($105, $cx);
    HEAP32[$pbaseobj >> 2] = 0;
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 30:
    var $_idx9_val = HEAP32[$_idx5 >> 2];
    var $107 = __ZNK8JSObject16inDictionaryModeEv($_idx9_val);
    if ($107) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    HEAP32[$pbaseobj >> 2] = 0;
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 32:
    var $_idx4_val_idx_val = HEAP32[$_idx9_val + 4 >> 2];
    var $109 = __ZNK8JSObject8slotSpanEv($_idx4_val_idx_val);
    if (($109 | 0) == ($100 | 0)) {
      __label__ = 61;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $113 = HEAPU32[$65 >> 2] >>> 1;
    __ZN2js5types13TypeNewScript11InitializerC1ENS2_4KindEj($3, 0, $113);
    var $_029_val = HEAP32[$_029 >> 2];
    var $_130_val = HEAP32[$_130 >> 2];
    var $114 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_($initializerList, $_029_val, $_130_val);
    if ($114) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $116 = HEAP32[$24 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($116, $cx);
    HEAP32[$pbaseobj >> 2] = 0;
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 35:
    var $_idx3_val_idx_val = HEAP32[HEAP32[$_idx5 >> 2] + 4 >> 2];
    var $118 = __ZNK8JSObject8slotSpanEv($_idx3_val_idx_val);
    if ($118 >>> 0 > 14) {
      __label__ = 62;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $124 = HEAP32[HEAP32[$1 >> 2] >> 2];
    var $125 = __ZN8JSObject7getTypeEP9JSContext($124, $25);
    var $126 = $125;
    var $_idx7_val = HEAP32[$125 + 12 >> 2];
    var $128 = __ZN2js5types10TypeObject17unknownPropertiesEv($_idx7_val);
    if ($128) {
      __label__ = 63;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $130 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($126, $cx, $87, 0);
    if (($130 | 0) == 0) {
      __label__ = 64;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $_idx8_val = HEAP32[$130 >> 2];
    var $133 = __ZNK2js5types7TypeSet7unknownEv($_idx8_val);
    if ($133) {
      __label__ = 65;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    __ZN2js5types10TypeObject17getFromPrototypesEP9JSContextiPNS0_7TypeSetEb($126, $cx, $87, $130, 0);
    var $135 = HEAP32[$24 >> 2] + 344 | 0;
    var $136 = __ZN2js8ArenaNewI33TypeConstraintClearDefiniteSetterPNS_5types10TypeObjectEEEPT_R11JSArenaPoolRKT0_($135, $1);
    var $137 = $136 | 0;
    __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($130, $cx, $137, 1);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $nextOffset_0_ph = $34;
    var $lastThisPopped_0_ph = $67;
    __label__ = 7;
    break;
   case 40:
    var $148 = (HEAPU8[$67 + ($76 + 1) | 0] & 255) << 8 | HEAPU8[$67 + ($76 + 2) | 0] & 255;
    if ((HEAP32[$52 + 4 >> 2] | 0) == ($148 - 1 | 0)) {
      __label__ = 41;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 41:
    var $152 = $148 + 1 | 0;
    var $_idx24_val = HEAP32[$_idx19 >> 2];
    var $_idx23_val_idx_val = HEAP32[HEAP32[$_idx18 >> 2] >> 2];
    var $153 = __ZN2js7analyze14ScriptAnalysis11poppedValueEPKhj($_idx23_val_idx_val, $_idx24_val, $77, $152);
    var $154 = $153;
    var $155$0 = HEAP32[$154 >> 2];
    var $155$1 = HEAP32[$154 + 4 >> 2];
    HEAP32[$26 >> 2] = $155$0;
    HEAP32[$26 + 4 >> 2] = $155$1;
    var $156 = __ZNK2js7analyze8SSAValue4kindEv($calleev);
    var $159 = $155$1;
    if (($156 | 0) == 1) {
      __label__ = 42;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 42:
    var $161 = HEAP32[$22 >> 2];
    var $162 = __ZNK2js7analyze8SSAValue12pushedOffsetEv($calleev);
    var $163 = $161 + $162 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrapCallee, $9, $163);
    if (HEAP8[$163] << 24 >> 24 == -69) {
      __label__ = 43;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 43:
    var $167 = __ZNK2js7analyze8SSAValue11pushedIndexEv($159);
    if (($167 | 0) == 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 44:
    var $_idx22_val = HEAP32[$_idx19 >> 2];
    var $_idx21_val_idx_val = HEAP32[HEAP32[$_idx18 >> 2] >> 2];
    var $170 = __ZN2js7analyze14ScriptAnalysis11poppedValueEPKhj($_idx21_val_idx_val, $_idx22_val, $163, 0);
    __ZN2js7analyze14ScriptAnalysis20breakTypeBarriersSSAEP9JSContextRKNS0_8SSAValueE($20, $cx, $170);
    var $174 = $163 - HEAP32[$22 >> 2] | 0;
    __ZN2js7analyze14ScriptAnalysis17breakTypeBarriersEP9JSContextjb($20, $cx, $174);
    var $_idx17_val = HEAP32[$_idx19 >> 2];
    var $_idx16_val_idx_val = HEAP32[HEAP32[$_idx18 >> 2] >> 2];
    var $175 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEPKhj($_idx16_val_idx_val, $_idx17_val, $163, 0);
    var $176 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEPKhj($_idx16_val_idx_val, $_idx17_val, $163, 1);
    var $177 = __ZN2js5types7TypeSet12getSingletonEP9JSContextb($175);
    var $178 = __ZN2js5types7TypeSet12getSingletonEP9JSContextb($176);
    if (($177 | 0) == 0 | ($178 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $_idx_val = HEAP32[$178 + 4 >> 2];
    var $182 = __ZNK8JSObject10isFunctionEv($_idx_val);
    if ($182) {
      __label__ = 46;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 46:
    var $_idx1_val = HEAP32[$178 + 24 >> 2];
    var $184 = __ZNK8JSObject18getFunctionPrivateEv($_idx1_val);
    var $_idx2_val = HEAP16[$184 + 58 >> 1];
    var $185 = __ZNK10JSFunction13isInterpretedEv($_idx2_val);
    if ($185) {
      __label__ = 47;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 47:
    var $187 = __ZNK2js7analyze8SSAValue12pushedOffsetEv($calleev);
    var $188 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEjj($_idx17_val, $187, 0);
    var $190 = HEAP32[$24 >> 2] + 344 | 0;
    var $191 = __ZN2js8ArenaNewI33TypeConstraintClearDefiniteSinglePNS_5types10TypeObjectEEEPT_R11JSArenaPoolRKT0_($190, $1);
    var $192 = $191 | 0;
    __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($188, $cx, $192, 1);
    var $193 = __ZNK2js7analyze8SSAValue12pushedOffsetEv($calleev);
    var $_idx12_val = HEAP32[$_idx19 >> 2];
    var $194 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEjj($_idx12_val, $193, 1);
    var $196 = HEAP32[$24 >> 2] + 344 | 0;
    var $197 = __ZN2js8ArenaNewI33TypeConstraintClearDefiniteSinglePNS_5types10TypeObjectEEEPT_R11JSArenaPoolRKT0_($196, $1);
    var $198 = $197 | 0;
    __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($194, $cx, $198, 1);
    var $200 = HEAPU32[$65 >> 2] >>> 1;
    __ZN2js5types13TypeNewScript11InitializerC1ENS2_4KindEj($4, 1, $200);
    var $_027_val = HEAP32[$_027 >> 2];
    var $_128_val = HEAP32[$_128 >> 2];
    var $201 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_($initializerList, $_027_val, $_128_val);
    if ($201) {
      __label__ = 49;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    var $204 = HEAP32[$24 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($204, $cx);
    HEAP32[$pbaseobj >> 2] = 0;
    __label__ = 53;
    break;
   case 49:
    var $206 = HEAP32[$1 >> 2];
    var $207 = __ZL26AnalyzeNewScriptPropertiesP9JSContextPN2js5types10TypeObjectEP10JSFunctionPP8JSObjectPNS1_6VectorINS2_13TypeNewScript11InitializerELj0ENS1_15TempAllocPolicyEEE($cx, $206, $184, $pbaseobj, $initializerList);
    if ($207) {
      __label__ = 50;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 50:
    __ZN2js5types13TypeNewScript11InitializerC1ENS2_4KindEj($5, 2, 0);
    var $_0_val = HEAP32[$_0 >> 2];
    var $_1_val = HEAP32[$_1 >> 2];
    var $209 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_($initializerList, $_0_val, $_1_val);
    if ($209) {
      __label__ = 51;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 51:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapCallee);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $nextOffset_0_ph = $34;
    var $lastThisPopped_0_ph = $67;
    __label__ = 7;
    break;
   case 52:
    var $212 = HEAP32[$24 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($212, $cx);
    HEAP32[$pbaseobj >> 2] = 0;
    __label__ = 53;
    break;
   case 53:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapCallee);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 54:
    var $_4_ph;
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = $_4_ph;
    __label__ = 69;
    break;
   case 55:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $nextOffset_0 = $34;
    __label__ = 8;
    break;
   case 56:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 57:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 58:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 59:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 60:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 61:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 62:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 63:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 64:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 65:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 66:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 67:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 68:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 69:
    var $_5;
    STACKTOP = __stackBase__;
    return $_5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL26AnalyzeNewScriptPropertiesP9JSContextPN2js5types10TypeObjectEP10JSFunctionPP8JSObjectPNS1_6VectorINS2_13TypeNewScript11InitializerELj0ENS1_15TempAllocPolicyEEE["X"] = 1;

function __ZN2js5types13TypeNewScript11InitializerC1ENS2_4KindEj($this, $kind, $offset) {
  __ZN2js5types13TypeNewScript11InitializerC2ENS2_4KindEj($this, $kind, $offset);
  return;
}

function __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_($this, $t_0, $t_1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE13growStorageByEj($this);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_($this, $t_0, $t_1);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodCopyINS_5types13TypeNewScript11InitializerEEEvPT_PKS4_j($dst, $src, $nelem) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($nelem >>> 0 < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $src + ($nelem << 3) | 0;
    if (($nelem | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $src;
      var $_03 = $dst;
      __label__ = 3;
      break;
    }
   case 3:
    var $_03;
    var $_012;
    var $5 = $_012;
    var $6 = $_03;
    var $7$0 = HEAP32[$5 >> 2];
    var $7$1 = HEAP32[$5 + 4 >> 2];
    HEAP32[$6 >> 2] = $7$0;
    HEAP32[$6 + 4 >> 2] = $7$1;
    var $8 = $_012 + 8 | 0;
    if (($8 | 0) == ($3 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $8;
      var $_03 = $_03 + 8 | 0;
      __label__ = 3;
      break;
    }
   case 4:
    var $12 = $dst;
    var $13 = $src;
    var $14 = $nelem << 3;
    _memcpy($12, $13, $14, 1);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE13growStorageByEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_($this, $t_0, $t_1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $10 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    var $8$1 = $t_1 | 0;
    var $st$9$0 = $4 | 0;
    HEAP32[$st$9$0 >> 2] = 0 | $t_0;
    var $st$9$1 = $4 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $8$1;
    var $10 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $10;
    HEAP32[$this_idx1 >> 2] = $10 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 3;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS3_EEvPS3_PKT_SA_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS3_Lj0ES4_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, 1);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 268435455) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 268435455) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS3_Lj0ES4_EEj($v, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $v | 0;
    var $3 = $newcap << 3;
    var $4 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $v_idx = $v + 4 | 0;
    var $v_idx_val = HEAP32[$v_idx >> 2];
    var $8 = __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($v_idx_val);
    var $v_idx4 = $v + 8 | 0;
    var $v_idx4_val = HEAP32[$v_idx4 >> 2];
    var $9 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE10endNoCheckEv($v_idx_val, $v_idx4_val);
    if (($8 | 0) == ($9 | 0)) {
      var $22 = $v_idx_val;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx = $1 | 0;
    var $dst_01 = $5;
    var $src_02 = $8;
    var $v_idx1_val5 = $v_idx_val;
    var $v_idx2_val7 = $v_idx4_val;
    __label__ = 4;
    break;
   case 4:
    var $v_idx2_val7;
    var $v_idx1_val5;
    var $src_02;
    var $dst_01;
    if (($dst_01 | 0) == 0) {
      var $v_idx1_val = $v_idx1_val5;
      var $v_idx2_val = $v_idx2_val7;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js4MoveINS_5types13TypeNewScript11InitializerEEENS_7MoveRefIT_EERS5_($1, $src_02);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $13 = __ZNK2js7MoveRefINS_5types13TypeNewScript11InitializerEEcvRS3_Ev($_idx_val);
    var $14 = $13;
    var $15 = $dst_01;
    var $16$0 = HEAP32[$14 >> 2];
    var $16$1 = HEAP32[$14 + 4 >> 2];
    HEAP32[$15 >> 2] = $16$0;
    HEAP32[$15 + 4 >> 2] = $16$1;
    var $v_idx1_val = HEAP32[$v_idx >> 2];
    var $v_idx2_val = HEAP32[$v_idx4 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $v_idx2_val;
    var $v_idx1_val;
    var $18 = $dst_01 + 8 | 0;
    var $19 = $src_02 + 8 | 0;
    var $20 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE10endNoCheckEv($v_idx1_val, $v_idx2_val);
    if (($19 | 0) == ($20 | 0)) {
      var $22 = $v_idx1_val;
      __label__ = 7;
      break;
    } else {
      var $dst_01 = $18;
      var $src_02 = $19;
      var $v_idx1_val5 = $v_idx1_val;
      var $v_idx2_val7 = $v_idx2_val;
      __label__ = 4;
      break;
    }
   case 7:
    var $22;
    __ZN2js15TempAllocPolicy5free_EPv($22);
    HEAP32[$v_idx >> 2] = $5;
    HEAP32[$v + 12 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js10VectorImplINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS3_Lj0ES4_EEj["X"] = 1;

function __ZN2js4MoveINS_5types13TypeNewScript11InitializerEEENS_7MoveRefIT_EERS5_($agg_result, $t) {
  __ZN2js7MoveRefINS_5types13TypeNewScript11InitializerEEC1ERS3_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_5types13TypeNewScript11InitializerEEC1ERS3_($this, $t) {
  __ZN2js7MoveRefINS_5types13TypeNewScript11InitializerEEC2ERS3_($this, $t);
  return;
}

function __ZN2js10VectorImplINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS3_EEvPS3_PKT_SA_($dst, $srcbeg, $srcend) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx = $1 | 0;
    var $p_01 = $srcbeg;
    var $_02 = $dst;
    __label__ = 3;
    break;
   case 3:
    var $_02;
    var $p_01;
    if (($_02 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js4MoveINS_5types13TypeNewScript11InitializerEEENS_7MoveRefIT_EERKS5_($1, $p_01);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $5 = __ZNK2js7MoveRefINS_5types13TypeNewScript11InitializerEEcvRS3_Ev($_idx_val);
    var $6 = $5;
    var $7 = $_02;
    var $8$0 = HEAP32[$6 >> 2];
    var $8$1 = HEAP32[$6 + 4 >> 2];
    HEAP32[$7 >> 2] = $8$0;
    HEAP32[$7 + 4 >> 2] = $8$1;
    __label__ = 5;
    break;
   case 5:
    var $10 = $p_01 + 8 | 0;
    if (($10 | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      var $p_01 = $10;
      var $_02 = $_02 + 8 | 0;
      __label__ = 3;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_5types13TypeNewScript11InitializerEEENS_7MoveRefIT_EERKS5_($agg_result, $t) {
  __ZN2js7MoveRefINS_5types13TypeNewScript11InitializerEEC1ERS3_($agg_result, $t);
  return;
}

function __ZL14JSID_FROM_BITSj1765($bits) {
  return $bits;
}

function __ZN2jsL12PodArrayZeroIbLj2EEEvRAT0__T_() {
  HEAP16[__ZZL15InferSpewActiveN2js5types11SpewChannelEE6active >> 1] = 0;
  return;
}

function __ZN2js5types17TypeFlagPrimitiveEj($flags) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($flags | 0) == 2) {
      __label__ = 2;
      break;
    } else if (($flags | 0) == 4) {
      __label__ = 3;
      break;
    } else if (($flags | 0) == 8) {
      __label__ = 4;
      break;
    } else if (($flags | 0) == 16) {
      __label__ = 5;
      break;
    } else if (($flags | 0) == 32) {
      __label__ = 6;
      break;
    } else if (($flags | 0) == 64) {
      __label__ = 7;
      break;
    } else if (($flags | 0) == 1) {
      var $_0 = 2;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $_0 = 6;
    __label__ = 9;
    break;
   case 3:
    var $_0 = 3;
    __label__ = 9;
    break;
   case 4:
    var $_0 = 1;
    __label__ = 9;
    break;
   case 5:
    var $_0 = 0;
    __label__ = 9;
    break;
   case 6:
    var $_0 = 5;
    __label__ = 9;
    break;
   case 7:
    var $_0 = 4;
    __label__ = 9;
    break;
   case 8:
    var $_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL22UsePropertyTypeBarrierPh($pc_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAPU32[_js_CodeSpec + (($pc_val & 255) << 3) + 4 >> 2];
    if (($3 & 67108864 | 0) == 0) {
      var $10 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = ($3 & 2097152 | 0) == 0;
    __label__ = 3;
    break;
   case 3:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14id_constructorP9JSContext($cx_0_11_val_0_70_15_val) {
  var $1 = $cx_0_11_val_0_70_15_val | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom1694($1);
  return $2;
}

function __ZN2js8ArenaNewI33TypeConstraintClearDefiniteSetterPNS_5types10TypeObjectEEEPT_R11JSArenaPoolRKT0_($pool, $a) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 12 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $26 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    __ZN33TypeConstraintClearDefiniteSetterC1EPN2js5types10TypeObjectE($23, $24);
    var $26 = $23;
    __label__ = 6;
    break;
   case 6:
    var $26;
    return $26;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8ArenaNewI33TypeConstraintClearDefiniteSinglePNS_5types10TypeObjectEEEPT_R11JSArenaPoolRKT0_($pool, $a) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 12 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $26 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    __ZN33TypeConstraintClearDefiniteSingleC1EPN2js5types10TypeObjectE($23, $24);
    var $26 = $23;
    __label__ = 6;
    break;
   case 6:
    var $26;
    return $26;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN33TypeConstraintClearDefiniteSingleC1EPN2js5types10TypeObjectE($this, $object) {
  __ZN33TypeConstraintClearDefiniteSingleC2EPN2js5types10TypeObjectE($this, $object);
  return;
}

function __ZN33TypeConstraintClearDefiniteSingleC2EPN2js5types10TypeObjectE($this, $object) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1);
  HEAP32[$this >> 2] = __ZTV33TypeConstraintClearDefiniteSingle + 8 | 0;
  HEAP32[$this + 8 >> 2] = $object;
  return;
}

function __ZN33TypeConstraintClearDefiniteSingle7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 8 >> 2];
    if ((HEAP32[$2 + 12 >> 2] & 2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $source_idx_val = HEAP32[$source >> 2];
    var $8 = __ZNK2js5types7TypeSet9baseFlagsEv($source_idx_val);
    if (($8 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js5types7TypeSet14getObjectCountEv($source_idx_val);
    if ($11 >>> 0 > 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js5types10TypeObject14clearNewScriptEP9JSContext($2, $cx);
    __label__ = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN33TypeConstraintClearDefiniteSetterC1EPN2js5types10TypeObjectE($this, $object) {
  __ZN33TypeConstraintClearDefiniteSetterC2EPN2js5types10TypeObjectE($this, $object);
  return;
}

function __ZN33TypeConstraintClearDefiniteSetterC2EPN2js5types10TypeObjectE($this, $object) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1);
  HEAP32[$this >> 2] = __ZTV33TypeConstraintClearDefiniteSetter + 8 | 0;
  HEAP32[$this + 8 >> 2] = $object;
  return;
}

function __ZN33TypeConstraintClearDefiniteSetter7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 8 >> 2];
    if ((HEAP32[$2 + 16 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$2 + 12 >> 2] & 2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $type_idx_val = HEAP32[$type >> 2];
    var $12 = __ZNK2js5types4Type9isUnknownEv($type_idx_val);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js5types10TypeObject14clearNewScriptEP9JSContext($2, $cx);
    __label__ = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEEC2ES4_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1753($cx, $proto, $parent) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, 10);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, __ZN2js11ObjectClassE, $1, $parent, 0, (__ZN2js11ObjectClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $7 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, __ZN2js11ObjectClassE, 10);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $10);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis18TypeInferenceStateD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEED1Ev($1);
  return;
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis18TypeInferenceStateC2EP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEEC1ES4_($2, $_0_val);
  HEAP8[$this + 24 | 0] = 0;
  HEAP8[$this + 25 | 0] = 0;
  HEAP32[$this + 28 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEEC1ES4_($this, $ap_01) {
  __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEEC2ES4_($this, $ap_01);
  return;
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEEC2ES4_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZN8JSScript12clearNestingEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx = $this + 100 | 0;
    var $_idx_val_idx_val = HEAP32[HEAP32[$_idx >> 2] + 12 >> 2];
    var $3 = __ZNK8JSScript7nestingEv($_idx_val_idx_val);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    __ZN2js10Foreground7delete_INS_5types17TypeScriptNestingEEEvPT_($6);
    var $8 = HEAP32[$_idx >> 2] + 12 | 0;
    HEAP32[$8 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5Shape26hasDefaultGetterOrIsMethodEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx1_val = HEAP32[$this + 16 >> 2];
    var $1 = __ZNK2js5Shape16hasDefaultGetterEv($this_idx1_val);
    if ($1) {
      var $5 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP8[$this + 29 | 0];
    var $3 = __ZNK2js5Shape8isMethodEv($this_idx_val);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types13ArrayTableKeyC2Ev($this) {
  var $1 = $this | 0;
  __ZN2js5types4Type13UndefinedTypeEv($1);
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js2gc8CellIterD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 32 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$this + 36 >> 2];
    __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($2, $6);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc8CellIterC2EP9JSContextP13JSCompartmentNS0_9AllocKindE($this, $comp, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = $this + 32 | 0;
    var $3 = $comp + 8 | 0;
    HEAP32[$2 >> 2] = $3;
    HEAP32[$this + 36 >> 2] = $kind;
    var $5 = __ZN2js2gc10ArenaLists22isSynchronizedFreeListENS0_9AllocKindE($3, $kind);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$2 >> 2] = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($3, $kind);
    __label__ = 4;
    break;
   case 4:
    __ZN2js2gc12CellIterImpl4initEP13JSCompartmentNS0_9AllocKindE($1, $comp, $kind);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc10ArenaLists22isSynchronizedFreeListENS0_9AllocKindE($this, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this + ($kind << 3) >> 2];
    var $_idx1_val = HEAP32[$this + ($kind << 3) + 4 >> 2];
    var $1 = __ZNK2js2gc8FreeSpan7isEmptyEv($_idx_val, $_idx1_val);
    if ($1) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js2gc8FreeSpan11arenaHeaderEv($_idx1_val);
    var $_idx3_val = HEAP32[$3 + 8 >> 2];
    var $4 = __ZNK2js2gc11ArenaHeader13hasFreeThingsEv($_idx3_val);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObjectC2EP8JSObjectbb($this, $proto, $function, $unknown) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __ZN2jsL7PodZeroINS_5types10TypeObjectEEEvPT_($this);
    HEAP32[$this >> 2] = $proto;
    if ($function) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this + 12 | 0;
    var $5 = HEAP32[$3 >> 2] | 1;
    HEAP32[$3 >> 2] = $5;
    __label__ = 3;
    break;
   case 3:
    if ($unknown) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = $this + 12 | 0;
    var $10 = HEAP32[$8 >> 2] | 33488904;
    HEAP32[$8 >> 2] = $10;
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodZeroINS_5types10TypeObjectEEEvPT_($t) {
  var $1 = $t;
  _memset($1, 0, 32, 1);
  return;
}

function __ZN2js13GetScopeChainEP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind1790($cx);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $5 = HEAP32[$cx + 132 >> 2];
    HEAP32[$obj >> 2] = $5;
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 4, 2, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    __Z19OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($cx, $obj);
    var $_0 = HEAP32[$obj >> 2];
    __label__ = 6;
    break;
   case 5:
    var $11 = __ZN2js13GetScopeChainEP9JSContextPNS_10StackFrameE($cx, $1);
    var $_0 = $11;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind1790($cx) {
  var $1 = __ZNK9JSContext7maybefpEv($cx);
  return $1;
}

function __ZN2js13GetScopeChainEP9JSContextPNS_10StackFrameE($cx, $fp) {
  var $1 = __ZN2js13GetBlockChainEP9JSContextPNS_10StackFrameE($cx, $fp);
  var $2 = __ZL17GetScopeChainFullP9JSContextPN2js10StackFrameEP8JSObject($cx, $fp, $1);
  return $2;
}

function __ZN2js13GetBlockChainEP9JSContextPNS_10StackFrameE($cx, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fp_idx_val = HEAP32[$fp >> 2];
    var $1 = __ZNK2js10StackFrame13isScriptFrameEv($fp_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 2:
    var $3 = __ZNK2js10StackFrame11hasImacropcEv($fp_idx_val);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $fp_idx5_val = HEAP32[$fp + 40 >> 2];
    var $5 = __ZNK2js10StackFrame8imacropcEv($fp_idx5_val);
    var $12 = $5;
    __label__ = 5;
    break;
   case 4:
    var $8 = $fp;
    var $9 = $cx + 60 | 0;
    var $10 = __ZN2js10StackFrame11pcQuadraticERKNS_12ContextStackEPS0_PPNS_13JSInlinedSiteE($8, $9, 0);
    var $12 = $10;
    __label__ = 5;
    break;
   case 5:
    var $12;
    var $13 = __ZNK2js10StackFrame6scriptEv($fp);
    var $15 = HEAPU32[$13 >> 2];
    var $16 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh1793($13, $12);
    var $target_0 = $12;
    var $op_0 = $16;
    __label__ = 6;
    break;
   case 6:
    var $op_0;
    var $target_0;
    if (($op_0 | 0) == 213 || ($op_0 | 0) == 212 || ($op_0 | 0) == 211 || ($op_0 | 0) == 191 || ($op_0 | 0) == 189 || ($op_0 | 0) == 188 || ($op_0 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ($15 >>> 0 < $target_0 >>> 0) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 8:
    var $_idx2 = $13 + 4 | 0;
    var $_idx3 = $13 + 16 | 0;
    var $blockChain_021 = 0;
    var $indexBase_022 = 0;
    var $pc_023 = $15;
    __label__ = 10;
    break;
   case 9:
    var $22 = $target_0 + (HEAP8[_js_CodeSpec + ($op_0 << 3) | 0] << 24 >> 24) | 0;
    var $23 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh1793($13, $22);
    var $target_0 = $22;
    var $op_0 = $23;
    __label__ = 6;
    break;
   case 10:
    var $pc_023;
    var $indexBase_022;
    var $blockChain_021;
    var $24 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh1793($13, $pc_023);
    var $26 = HEAP8[_js_CodeSpec + ($24 << 3) | 0];
    var $27 = $26 << 24 >> 24;
    if ($26 << 24 >> 24 < 0) {
      __label__ = 11;
      break;
    } else {
      var $oplen_0 = $27;
      __label__ = 12;
      break;
    }
   case 11:
    var $30 = __Z28js_GetVariableBytecodeLengthPh($pc_023);
    var $oplen_0 = $30;
    __label__ = 12;
    break;
   case 12:
    var $oplen_0;
    if (($24 | 0) == 191) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $indexBase_1 = (HEAPU8[$pc_023 + 1 | 0] & 255) << 16;
    var $blockChain_1 = $blockChain_021;
    __label__ = 22;
    break;
   case 14:
    if (($24 - 211 | 0) >>> 0 < 3) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $indexBase_1 = ($24 << 16) - 13762560 | 0;
    var $blockChain_1 = $blockChain_021;
    __label__ = 22;
    break;
   case 16:
    if (($24 - 192 | 0) >>> 0 < 2) {
      var $indexBase_1 = 0;
      var $blockChain_1 = $blockChain_021;
      __label__ = 22;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    if (($24 | 0) == 201) {
      __label__ = 18;
      break;
    } else if (($24 | 0) == 210 || ($24 | 0) == 202) {
      __label__ = 19;
      break;
    } else if (($24 | 0) == 188) {
      __label__ = 20;
      break;
    } else if (($24 | 0) == 189) {
      __label__ = 21;
      break;
    } else {
      var $indexBase_1 = $indexBase_022;
      var $blockChain_1 = $blockChain_021;
      __label__ = 22;
      break;
    }
   case 18:
    var $55 = ((HEAPU8[$pc_023 + 1 | 0] & 255) << 8 | HEAPU8[$pc_023 + 2 | 0] & 255) + $indexBase_022 | 0;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $_idx3_val = HEAP8[$_idx3];
    var $56 = __ZN8JSScript9getObjectEj($_idx2_val, $_idx3_val, $55);
    var $indexBase_1 = $indexBase_022;
    var $blockChain_1 = $56;
    __label__ = 22;
    break;
   case 19:
    var $blockChain_021_idx_val = HEAP32[$blockChain_021 + 20 >> 2];
    var $58 = __ZNK8JSObject9getParentEv($blockChain_021_idx_val);
    var $indexBase_1 = $indexBase_022;
    var $blockChain_1 = $58;
    __label__ = 22;
    break;
   case 20:
    var $68 = ((HEAPU8[$pc_023 + 1 | 0] & 255) << 8 | HEAPU8[$pc_023 + 2 | 0] & 255) + $indexBase_022 | 0;
    var $_idx_val = HEAP32[$_idx2 >> 2];
    var $_idx1_val = HEAP8[$_idx3];
    var $69 = __ZN8JSScript9getObjectEj($_idx_val, $_idx1_val, $68);
    var $indexBase_1 = $indexBase_022;
    var $blockChain_1 = $69;
    __label__ = 22;
    break;
   case 21:
    var $indexBase_1 = $indexBase_022;
    var $blockChain_1 = 0;
    __label__ = 22;
    break;
   case 22:
    var $blockChain_1;
    var $indexBase_1;
    var $72 = $pc_023 + $oplen_0 | 0;
    if ($72 >>> 0 < $target_0 >>> 0) {
      var $blockChain_021 = $blockChain_1;
      var $indexBase_022 = $indexBase_1;
      var $pc_023 = $72;
      __label__ = 10;
      break;
    } else {
      var $_0 = $blockChain_1;
      __label__ = 23;
      break;
    }
   case 23:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13GetBlockChainEP9JSContextPNS_10StackFrameE["X"] = 1;

function __ZL12js_GetOpcodeP9JSContextP8JSScriptPh1793($script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU8[$pc];
    var $2 = $1 & 255;
    if ($1 << 24 >> 24 == 83) {
      __label__ = 2;
      break;
    } else {
      var $op_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $script;
    var $6 = _JS_GetTrapOpcode($5, $pc);
    var $op_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $op_0;
    return $op_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17GetBlockChainFastEP9JSContextPNS_10StackFrameE4JSOpj($cx, $fp, $oplen) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $fp;
    var $3 = $cx + 60 | 0;
    var $4 = __ZN2js10StackFrame11pcQuadraticERKNS_12ContextStackEPS0_PPNS_13JSInlinedSiteE($2, $3, 0);
    var $6 = HEAP8[$4 + $oplen | 0];
    if ($6 << 24 >> 24 == -68) {
      __label__ = 2;
      break;
    } else if ($6 << 24 >> 24 == -67) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = __ZNK2js10StackFrame6scriptEv($fp);
    var $16 = (HEAPU8[$oplen + ($4 + 1) | 0] & 255) << 8 | HEAPU8[$oplen + ($4 + 2) | 0] & 255;
    var $_idx_val = HEAP32[$8 + 4 >> 2];
    var $_idx1_val = HEAP8[$8 + 16 | 0];
    var $17 = __ZN8JSScript9getObjectEj($_idx_val, $_idx1_val, $16);
    var $_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $19 = __ZN2js13GetBlockChainEP9JSContextPNS_10StackFrameE($cx, $fp);
    var $_0 = $19;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17GetScopeChainFullP9JSContextPN2js10StackFrameEP8JSObject($cx, $fp, $blockChain) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    if (($blockChain | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2js10StackFrame10scopeChainEv($fp);
    var $_1 = $3;
    __label__ = 17;
    break;
   case 3:
    var $fp_idx_val = HEAP32[$fp >> 2];
    var $5 = __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($fp_idx_val);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $7 = __ZNK2js10StackFrame10hasCallObjEv($fp_idx_val);
    if ($7) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZN2js19CreateFunCallObjectEP9JSContextPNS_10StackFrameE($cx, $fp);
    if (($9 | 0) == 0) {
      var $_1 = 0;
      __label__ = 17;
      break;
    } else {
      var $limitBlock_0 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $12 = __ZNK2js10StackFrame10scopeChainEv($fp);
    var $_idx2_val = HEAP32[$12 + 4 >> 2];
    var $13 = __ZNK8JSObject6isWithEv($_idx2_val);
    if ($13) {
      var $limitClone_03 = $12;
      __label__ = 7;
      break;
    } else {
      var $limitClone_0_lcssa = $12;
      __label__ = 8;
      break;
    }
   case 7:
    var $limitClone_03;
    var $limitClone_03_idx_val = HEAP32[$limitClone_03 + 20 >> 2];
    var $14 = __ZNK8JSObject9getParentEv($limitClone_03_idx_val);
    var $_idx_val = HEAP32[$14 + 4 >> 2];
    var $15 = __ZNK8JSObject6isWithEv($_idx_val);
    if ($15) {
      var $limitClone_03 = $14;
      __label__ = 7;
      break;
    } else {
      var $limitClone_0_lcssa = $14;
      __label__ = 8;
      break;
    }
   case 8:
    var $limitClone_0_lcssa;
    var $limitClone_0_lcssa_idx_val_idx_val = HEAP32[HEAP32[$limitClone_0_lcssa + 36 >> 2] >> 2];
    var $16 = __ZNK8JSObject8getProtoEv($limitClone_0_lcssa_idx_val_idx_val);
    if (($16 | 0) == ($blockChain | 0)) {
      __label__ = 9;
      break;
    } else {
      var $limitBlock_0 = $16;
      __label__ = 10;
      break;
    }
   case 9:
    var $19 = __ZNK2js10StackFrame10scopeChainEv($fp);
    var $_1 = $19;
    __label__ = 17;
    break;
   case 10:
    var $limitBlock_0;
    var $21 = $cx;
    var $22 = $blockChain;
    var $23 = $fp;
    var $24 = __Z19js_CloneBlockObjectP9JSContextP8JSObjectPN2js10StackFrameE($21, $22, $23);
    var $25 = $24;
    if (($24 | 0) == 0) {
      var $_1 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($tvr, $cx, $25);
    var $newChild_0 = $25;
    var $sharedBlock_0 = $blockChain;
    __label__ = 12;
    break;
   case 12:
    var $sharedBlock_0;
    var $newChild_0;
    var $sharedBlock_0_idx_val = HEAP32[$sharedBlock_0 + 20 >> 2];
    var $29 = __ZNK8JSObject9getParentEv($sharedBlock_0_idx_val);
    if (($29 | 0) != ($limitBlock_0 | 0) & ($29 | 0) != 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $33 = $29;
    var $34 = __Z19js_CloneBlockObjectP9JSContextP8JSObjectPN2js10StackFrameE($21, $33, $23);
    var $35 = $34;
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZN8JSObject9setParentEPS_($newChild_0, $35);
    var $newChild_0 = $35;
    var $sharedBlock_0 = $29;
    __label__ = 12;
    break;
   case 15:
    var $39 = __ZNK2js10StackFrame10scopeChainEv($fp);
    __ZN8JSObject9setParentEPS_($newChild_0, $39);
    var $40 = $fp;
    var $41 = $24;
    __ZN2js10StackFrame22setScopeChainNoCallObjER8JSObject($40, $41);
    var $_0 = $25;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    __ZN2js16AutoObjectRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 17;
    break;
   case 17:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17GetScopeChainFullP9JSContextPN2js10StackFrameEP8JSObject["X"] = 1;

function __ZN2js17GetScopeChainFastEP9JSContextPNS_10StackFrameE4JSOpj($cx, $fp, $oplen) {
  var $1 = __ZN2js17GetBlockChainFastEP9JSContextPNS_10StackFrameE4JSOpj($cx, $fp, $oplen);
  var $2 = __ZL17GetScopeChainFullP9JSContextPN2js10StackFrameEP8JSObject($cx, $fp, $1);
  return $2;
}

function __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, $clasp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $funNameBytes = __stackBase__;
    var $1 = __Z18js_ValueToFunctionP9JSContextPKN2JS5ValueEj($cx, $vp, 0);
    if (($1 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN16JSAutoByteStringC1Ev($funNameBytes);
    var $_idx1_val = HEAP32[$1 + 72 >> 2];
    var $4 = __ZN2js20GetFunctionNameBytesEP9JSContextP10JSFunctionP16JSAutoByteString($cx, $_idx1_val, $funNameBytes);
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = HEAP32[$clasp >> 2];
    var $_idx = $vp + 8 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $9 = __ZN2js21InformalValueTypeNameERKN2JS5ValueE($_idx_val$0, $_idx_val$1);
    _JS_ReportErrorNumber($cx, 4, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $8, HEAP32[tempInt + 4 >> 2] = $4, HEAP32[tempInt + 8 >> 2] = $9, tempInt));
    __label__ = 4;
    break;
   case 4:
    var $funNameBytes_idx_val = HEAP32[$funNameBytes >> 2];
    __ZN16JSAutoByteStringD1Ev($funNameBytes_idx_val);
    __label__ = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16BoxNonStrictThisEP9JSContextRKNS_12CallReceiverE($cx, $call) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call_idx1 = $call | 0;
    var $call_idx1_val = HEAP32[$call_idx1 >> 2];
    var $1 = __ZNK2js12CallReceiver5thisvEv($call_idx1_val);
    var $_idx3 = $1 | 0;
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    var $2 = __ZNK2JS5Value17isNullOrUndefinedEv($_idx3_val$0, $_idx3_val$1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZNK2js12CallReceiver6calleeEv($call_idx1_val);
    var $5 = $4;
    var $6 = __ZNK8JSObject9getGlobalEv($5);
    var $7 = $6;
    var $8 = __ZN8JSObject10thisObjectEP9JSContext($7, $cx);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $call_idx_val = HEAP32[$call_idx1 >> 2];
    var $11 = __ZNK2js12CallReceiver5thisvEv($call_idx_val);
    __ZN2JS5Value9setObjectER8JSObject($11, $8);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 4:
    var $13 = __ZNK2JS5Value8isObjectEv($_idx3_val$0, $_idx3_val$1);
    if ($13) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = $cx;
    var $16 = __Z20js_PrimitiveToObjectP9JSContextPN2JS5ValueE($15, $1);
    var $_0 = ($16 | 0) != 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject10thisObjectEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $1 = __ZNK8JSObject6getOpsEv($this_idx_val);
    var $3 = HEAP32[$1 + 124 >> 2];
    if (($3 | 0) == 0) {
      var $8 = $this;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = FUNCTION_TABLE[$3]($cx, $this);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20no_such_method_traceP8JSTracerP8JSObject($trc, $obj) {
  var $1 = __ZNK8JSObject7getSlotEj($obj, 0);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $_idx_val$0, $_idx_val$1);
  var $2 = __ZNK8JSObject7getSlotEj($obj, 1);
  var $_idx1 = $2 | 0;
  var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
  var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
  __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $_idx1_val$0, $_idx1_val$1);
  return;
}

function __ZN2js15OnUnknownMethodEP9JSContextPN2JS5ValueE($cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $tvr = __stackBase__ + 4;
    var $1 = __stackBase__ + 28;
    var $_idx = $vp + 8 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $2 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $7 = HEAP32[HEAP32[$cx + 52 >> 2] + 210280 >> 2] | 0;
    var $8 = __ZL12ATOM_TO_JSIDP6JSAtom1798($7);
    HEAP32[$id >> 2] = $8;
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $9 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $10 = $cx;
    var $11 = $2;
    var $12 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($10, $11, $8, 2, $9);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $15 = __ZNK9JSContext2fpEv($cx);
    var $16 = __ZNK2js10StackFrame6scriptEv($15);
    var $17 = __ZNK9JSContext4regsEv($cx);
    var $19 = HEAP32[$17 + 4 >> 2];
    __ZN2js5types10TypeScript14MonitorUnknownEP9JSContextP8JSScriptPh($cx, $16, $19);
    var $20 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $_idx2 = $20 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    var $21 = __ZNK2JS5Value11isPrimitiveEv($_idx2_val$0, $_idx2_val$1);
    var $22 = $vp | 0;
    if ($21) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $st$0$0 = $22 | 0;
    HEAP32[$st$0$0 >> 2] = $_idx2_val$0;
    var $st$0$1 = $22 + 4 | 0;
    HEAP32[$st$0$1 >> 2] = $_idx2_val$1;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 4:
    var $st$0$0 = $22 | 0;
    var $vp_idx_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $22 + 4 | 0;
    var $vp_idx_val$1 = HEAP32[$st$0$1 >> 2];
    var $25 = __ZNK2JS5Value8isObjectEv($vp_idx_val$0, $vp_idx_val$1);
    if ($25) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $27 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
    var $28 = $27;
    var $29 = $cx;
    var $30 = __Z32js_GetLocalNameFromFunctionQNameP8JSObjectPiP9JSContext($28, $id, $29);
    if ($30) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $32 = HEAP32[$id >> 2];
    __ZN2jsL9IdToValueEi1799($1, $32);
    var $33 = $1 | 0;
    var $34$0 = HEAP32[$33 >> 2];
    var $34$1 = HEAP32[$33 + 4 >> 2];
    var $st$7$0 = $22 | 0;
    HEAP32[$st$7$0 >> 2] = $34$0;
    var $st$7$1 = $22 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $34$1;
    __label__ = 7;
    break;
   case 7:
    var $36 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, 2);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($36, _js_NoSuchMethodClass, __ZN2js5types15emptyTypeObjectE, 0, 0, 0);
    __ZN8JSObject21setSharedNonNativeMapEv($36);
    var $_idx4_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($36, 0, $_idx4_val$0, $_idx4_val$1);
    var $st$7$0 = $22 | 0;
    var $vp_idx3_val$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $22 + 4 | 0;
    var $vp_idx3_val$1 = HEAP32[$st$7$1 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($36, 1, $vp_idx3_val$0, $vp_idx3_val$1);
    __ZN2JS5Value9setObjectER8JSObject($vp, $36);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js15OnUnknownMethodEP9JSContextPN2JS5ValueE["X"] = 1;

function __ZL12ATOM_TO_JSIDP6JSAtom1798($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj1904($1);
  return $2;
}

function __ZN2js5types10TypeScript14MonitorUnknownEP9JSContextP8JSScriptPh($cx, $script, $pc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $2 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js5types4Type11UnknownTypeEv($1);
    var $_0_val = HEAP32[$1 >> 2];
    __ZN2js5types17TypeDynamicResultEP9JSContextP8JSScriptPhNS0_4TypeE($cx, $script, $pc, $_0_val);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9IdToValueEi1799($agg_result, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_STRING1834($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_STRING1867($id);
    __ZN2JSL11StringValueEP8JSString1846($agg_result, $4);
    __label__ = 8;
    break;
   case 3:
    var $6 = _JSID_IS_INT1835($id);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _JSID_TO_INT1836($id);
    __ZN2JSL10Int32ValueEi1832($agg_result, $9);
    __label__ = 8;
    break;
   case 5:
    var $11 = _JSID_IS_OBJECT1900($id);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = _JSID_TO_OBJECT1901($id);
    __ZN2JSL11ObjectValueER8JSObject1804($agg_result, $14);
    __label__ = 8;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv1839($agg_result);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9RunScriptEP9JSContextP8JSScriptPNS_10StackFrameE($cx, $script_0_15_val, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($script_0_15_val & 16) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2js10StackFrame10scopeChainEv($fp);
    var $5 = $4;
    var $6 = __ZNK8JSObject9getGlobalEv($5);
    var $7 = $6;
    var $8 = __ZNK2js12GlobalObject9isClearedEv($7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 4, 269, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $11 = __ZN2js9InterpretEP9JSContextPNS_10StackFrameENS_10InterpModeE($cx, $fp);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InterpretEP9JSContextPNS_10StackFrameENS_10InterpModeE($cx, $entryFrame) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 1220;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $rf = __stackBase__;
    var $switchMask = __stackBase__ + 8;
    var $interruptEnabler = __stackBase__ + 12;
    var $regs = __stackBase__ + 24;
    var $interpGuard = __stackBase__ + 40;
    var $interpreterFrame = __stackBase__ + 52;
    var $stackDummy_ = __stackBase__ + 68;
    var $rval = __stackBase__ + 72;
    var $id = __stackBase__ + 80;
    var $i_ = __stackBase__ + 84;
    var $obj2 = __stackBase__ + 88;
    var $prop = __stackBase__ + 92;
    var $cond15 = __stackBase__ + 96;
    var $id23 = __stackBase__ + 100;
    var $i_25 = __stackBase__ + 104;
    var $obj26 = __stackBase__ + 108;
    var $entry = __stackBase__ + 112;
    var $obj227 = __stackBase__ + 116;
    var $atom28 = __stackBase__ + 120;
    var $i30 = __stackBase__ + 124;
    var $j = __stackBase__ + 128;
    var $i31 = __stackBase__ + 132;
    var $j32 = __stackBase__ + 136;
    var $i33 = __stackBase__ + 140;
    var $j34 = __stackBase__ + 144;
    var $rval35 = __stackBase__ + 148;
    var $lval36 = __stackBase__ + 156;
    var $cond37 = __stackBase__ + 164;
    var $rval39 = __stackBase__ + 168;
    var $lval40 = __stackBase__ + 176;
    var $cond41 = __stackBase__ + 184;
    var $equal = __stackBase__ + 188;
    var $equal49 = __stackBase__ + 192;
    var $equal53 = __stackBase__ + 196;
    var $equal57 = __stackBase__ + 200;
    var $result = __stackBase__ + 204;
    var $l61 = __stackBase__ + 208;
    var $r62 = __stackBase__ + 216;
    var $result69 = __stackBase__ + 224;
    var $l70 = __stackBase__ + 228;
    var $r71 = __stackBase__ + 236;
    var $result78 = __stackBase__ + 244;
    var $l79 = __stackBase__ + 248;
    var $r80 = __stackBase__ + 256;
    var $result87 = __stackBase__ + 264;
    var $l88 = __stackBase__ + 268;
    var $r89 = __stackBase__ + 276;
    var $i91 = __stackBase__ + 284;
    var $j92 = __stackBase__ + 288;
    var $i93 = __stackBase__ + 292;
    var $j94 = __stackBase__ + 296;
    var $u = __stackBase__ + 300;
    var $j95 = __stackBase__ + 304;
    var $rval96 = __stackBase__ + 308;
    var $lval97 = __stackBase__ + 316;
    var $l100 = __stackBase__ + 324;
    var $r101 = __stackBase__ + 332;
    var $rval102 = __stackBase__ + 340;
    var $lval103 = __stackBase__ + 348;
    var $d1 = __stackBase__ + 356;
    var $d2 = __stackBase__ + 364;
    var $rval104 = __stackBase__ + 372;
    var $lval105 = __stackBase__ + 380;
    var $d1106 = __stackBase__ + 388;
    var $d2107 = __stackBase__ + 396;
    var $rval109 = __stackBase__ + 404;
    var $lval110 = __stackBase__ + 412;
    var $d1111 = __stackBase__ + 420;
    var $d2112 = __stackBase__ + 428;
    var $d1117 = __stackBase__ + 436;
    var $d2118 = __stackBase__ + 444;
    var $i121 = __stackBase__ + 452;
    var $d124 = __stackBase__ + 456;
    var $obj127 = __stackBase__ + 464;
    var $obj2128 = __stackBase__ + 468;
    var $prop129 = __stackBase__ + 472;
    var $rval134 = __stackBase__ + 476;
    var $id137 = __stackBase__ + 484;
    var $i_139 = __stackBase__ + 488;
    var $id142 = __stackBase__ + 492;
    var $i_144 = __stackBase__ + 496;
    var $obj147 = __stackBase__ + 500;
    var $atom148 = __stackBase__ + 504;
    var $id149 = __stackBase__ + 508;
    var $i_153 = __stackBase__ + 512;
    var $obj2154 = __stackBase__ + 516;
    var $entry155 = __stackBase__ + 520;
    var $1 = __stackBase__ + 524;
    var $prop157 = __stackBase__ + 532;
    var $rf160 = __stackBase__ + 536;
    var $rf161 = __stackBase__ + 544;
    var $rval168 = __stackBase__ + 552;
    var $2 = __stackBase__ + 560;
    var $3 = __stackBase__ + 568;
    var $4 = __stackBase__ + 576;
    var $5 = __stackBase__ + 584;
    var $6 = __stackBase__ + 592;
    var $aobj = __stackBase__ + 600;
    var $entry173 = __stackBase__ + 604;
    var $obj2174 = __stackBase__ + 608;
    var $atom175 = __stackBase__ + 612;
    var $lval178 = __stackBase__ + 616;
    var $objv = __stackBase__ + 624;
    var $pobj = __stackBase__ + 632;
    var $aobj179 = __stackBase__ + 636;
    var $rval180 = __stackBase__ + 640;
    var $entry181 = __stackBase__ + 648;
    var $obj2182 = __stackBase__ + 652;
    var $atom183 = __stackBase__ + 656;
    var $rval187 = __stackBase__ + 660;
    var $entry190 = __stackBase__ + 668;
    var $obj2191 = __stackBase__ + 672;
    var $atom192 = __stackBase__ + 676;
    var $slot194 = __stackBase__ + 680;
    var $rval201 = __stackBase__ + 684;
    var $id202 = __stackBase__ + 692;
    var $i205 = __stackBase__ + 696;
    var $thisv206 = __stackBase__ + 700;
    var $id207 = __stackBase__ + 708;
    var $i_209 = __stackBase__ + 712;
    var $id212 = __stackBase__ + 716;
    var $i_214 = __stackBase__ + 720;
    var $rval215 = __stackBase__ + 724;
    var $id221 = __stackBase__ + 732;
    var $i_223 = __stackBase__ + 736;
    var $rval224 = __stackBase__ + 740;
    var $args = __stackBase__ + 748;
    var $args225 = __stackBase__ + 756;
    var $callee = __stackBase__ + 764;
    var $fun = __stackBase__ + 768;
    var $obj226 = __stackBase__ + 772;
    var $rval229 = __stackBase__ + 776;
    var $entry230 = __stackBase__ + 784;
    var $obj2231 = __stackBase__ + 788;
    var $atom232 = __stackBase__ + 792;
    var $v = __stackBase__ + 796;
    var $prop235 = __stackBase__ + 804;
    var $v236 = __stackBase__ + 808;
    var $proto = __stackBase__ + 816;
    var $lval251 = __stackBase__ + 820;
    var $rval254 = __stackBase__ + 828;
    var $rval256 = __stackBase__ + 836;
    var $rval258 = __stackBase__ + 844;
    var $7 = __stackBase__ + 852;
    var $rval260 = __stackBase__ + 860;
    var $rval262 = __stackBase__ + 868;
    var $prop274 = __stackBase__ + 876;
    var $obj2275 = __stackBase__ + 880;
    var $8 = __stackBase__ + 884;
    var $prop281 = __stackBase__ + 892;
    var $pobj282 = __stackBase__ + 896;
    var $rval283 = __stackBase__ + 900;
    var $bytes = __stackBase__ + 908;
    var $9 = __stackBase__ + 912;
    var $rval287 = __stackBase__ + 920;
    var $callee304 = __stackBase__ + 928;
    var $id308 = __stackBase__ + 932;
    var $i_317 = __stackBase__ + 936;
    var $rtmp = __stackBase__ + 940;
    var $attrs318 = __stackBase__ + 948;
    var $10 = __stackBase__ + 952;
    var $rval326 = __stackBase__ + 960;
    var $entry328 = __stackBase__ + 968;
    var $shape329 = __stackBase__ + 972;
    var $slot330 = __stackBase__ + 976;
    var $id337 = __stackBase__ + 980;
    var $i_339 = __stackBase__ + 984;
    var $numBuf = __stackBase__ + 988;
    var $rval349 = __stackBase__ + 1e3;
    var $numBuf352 = __stackBase__ + 1008;
    var $rval355 = __stackBase__ + 1020;
    var $11 = __stackBase__ + 1028;
    var $cond367 = __stackBase__ + 1036;
    var $rval368 = __stackBase__ + 1040;
    var $id369 = __stackBase__ + 1048;
    var $12 = __stackBase__ + 1052;
    var $rval372 = __stackBase__ + 1060;
    var $rval375 = __stackBase__ + 1068;
    var $rval378 = __stackBase__ + 1076;
    var $obj386 = __stackBase__ + 1084;
    var $id387 = __stackBase__ + 1088;
    var $13 = __stackBase__ + 1092;
    var $rval389 = __stackBase__ + 1100;
    var $id390 = __stackBase__ + 1108;
    var $i_392 = __stackBase__ + 1112;
    var $obj394 = __stackBase__ + 1116;
    var $id395 = __stackBase__ + 1120;
    var $rval396 = __stackBase__ + 1124;
    var $v397 = __stackBase__ + 1132;
    var $rval400 = __stackBase__ + 1140;
    var $rval421 = __stackBase__ + 1148;
    var $14 = __stackBase__ + 1156;
    var $numBuf429 = __stackBase__ + 1164;
    var $rval432 = __stackBase__ + 1176;
    var $15 = __stackBase__ + 1184;
    var $16 = __stackBase__ + 1192;
    var $v435 = __stackBase__ + 1200;
    var $17 = __stackBase__ + 1208;
    var $printable = __stackBase__ + 1216;
    __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $cx, 65535);
    HEAP32[$switchMask >> 2] = 0;
    __ZN23GenericInterruptEnablerIiEC1EPii($interruptEnabler, $switchMask);
    var $18 = __ZNK9JSContext4regsEv($cx);
    var $19 = $regs;
    var $20 = $18;
    HEAP32[$19 >> 2] = HEAP32[$20 >> 2];
    HEAP32[$19 + 4 >> 2] = HEAP32[$20 + 4 >> 2];
    HEAP32[$19 + 8 >> 2] = HEAP32[$20 + 8 >> 2];
    HEAP32[$19 + 12 >> 2] = HEAP32[$20 + 12 >> 2];
    __ZN2js17PreserveRegsGuardC1EP9JSContextRNS_9FrameRegsE($interpGuard, $cx, $regs);
    var $21 = $interruptEnabler | 0;
    __ZN2js17InterpreterFramesC1EP9JSContextPNS_9FrameRegsERKNS0_20InterruptEnablerBaseE($interpreterFrame, $cx, $regs, $21);
    var $22 = $cx + 52 | 0;
    var $23 = HEAPU32[$22 >> 2];
    var $regs_idx73 = $regs + 12 | 0;
    var $regs_idx73_val = HEAP32[$regs_idx73 >> 2];
    var $24 = __ZNK2js9FrameRegs2fpEv($regs_idx73_val);
    var $25 = __ZNK2js10StackFrame6scriptEv($24);
    var $_idx384_val = HEAP32[$25 + 24 >> 2];
    var $26 = __ZN8JSScript15stepModeEnabledEv($_idx384_val);
    if ($26) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 3;
    break;
   case 3:
    var $_idx385_val = HEAP32[$25 + 96 >> 2];
    var $29 = __ZN12JSPCCounters3getEi($_idx385_val);
    if (($29 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 5;
    break;
   case 5:
    var $regs_idx72_val = HEAP32[$regs_idx73 >> 2];
    var $32 = __ZNK2js9FrameRegs2fpEv($regs_idx72_val);
    var $33 = __ZNK2js10StackFrame15maybeFormalArgsEv($32);
    var $34 = $cx + 200 | 0;
    if ((HEAP32[HEAP32[$34 >> 2] >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 7;
    break;
   case 7:
    var $regs_idx71_val = HEAP32[$regs_idx73 >> 2];
    if (($entryFrame | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $_08 = $entryFrame;
      __label__ = 9;
      break;
    }
   case 8:
    var $43 = __ZNK2js9FrameRegs2fpEv($regs_idx71_val);
    var $_08 = $43;
    __label__ = 9;
    break;
   case 9:
    var $_08;
    var $45 = HEAP32[$25 + 56 >> 2];
    var $46 = __ZNK2js9FrameRegs2fpEv($regs_idx71_val);
    var $_idx_val = HEAP32[$46 >> 2];
    var $47 = __ZNK2js10StackFrame16isGeneratorFrameEv($_idx_val);
    if ($47) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $cx_idx197_val = HEAP32[$cx + 20 >> 2];
    var $49 = __ZN9JSContext18isExceptionPendingEv($cx_idx197_val);
    if ($49) {
      var $script_2_ph1347 = $25;
      var $pcCounts_2_ph1346 = $29;
      var $argv_2_ph1345 = $33;
      __label__ = 1016;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $51 = __ZN2js5types17UseNewTypeAtEntryEP9JSContextPNS_10StackFrameE($cx, $46);
    var $52 = __ZN2js31ScriptPrologueOrGeneratorResumeEP9JSContextPNS_10StackFrameEb($cx, $46, $51);
    if ($52) {
      __label__ = 12;
      break;
    } else {
      var $script_2_ph1347 = $25;
      var $pcCounts_2_ph1346 = $29;
      var $argv_2_ph1345 = $33;
      __label__ = 1016;
      break;
    }
   case 12:
    if ((HEAP32[HEAP32[$34 >> 2] >> 2] | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 14;
    break;
   case 14:
    if ($stackDummy_ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $script_0_ph = $25;
    var $pcCounts_0_ph = $29;
    var $argv_0_ph = $33;
    var $atoms_0_ph = $45;
    var $len_0_ph1296 = 0;
    var $_pre_phi = $regs + 4 | 0;
    var $_pre_phi580 = $regs | 0;
    __label__ = 1036;
    break;
   case 16:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $script_2_ph1347 = $25;
    var $pcCounts_2_ph1346 = $29;
    var $argv_2_ph1345 = $33;
    __label__ = 1016;
    break;
   case 17:
    var $len_0;
    var $atoms_0;
    var $argv_0;
    var $pcCounts_0;
    var $script_0;
    var $66 = HEAP32[$_pre_phi >> 2] + $len_0 | 0;
    HEAP32[$_pre_phi >> 2] = $66;
    var $script_1 = $script_0;
    var $pcCounts_1 = $pcCounts_0;
    var $argv_1 = $argv_0;
    var $atoms_1 = $atoms_0;
    var $op_0 = HEAPU8[$66] & 255;
    __label__ = 18;
    break;
   case 18:
    var $op_0;
    var $atoms_1;
    var $argv_1;
    var $pcCounts_1;
    var $script_1;
    var $71 = ($pcCounts_1 | 0) == 0;
    var $72 = $script_1 | 0;
    var $script_1_idx383 = $script_1 + 24 | 0;
    var $switchOp_0 = HEAP32[$switchMask >> 2] | $op_0;
    __label__ = 19;
    break;
   case 19:
    var $switchOp_0;
    if (($switchOp_0 | 0) == 0 || ($switchOp_0 | 0) == 120 || ($switchOp_0 | 0) == 134 || ($switchOp_0 | 0) == 194 || ($switchOp_0 | 0) == 195 || ($switchOp_0 | 0) == 189 || ($switchOp_0 | 0) == 92) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    } else if (($switchOp_0 | 0) == -1) {
      __label__ = 20;
      break;
    } else if (($switchOp_0 | 0) == 109 || ($switchOp_0 | 0) == 182) {
      __label__ = 33;
      break;
    } else if (($switchOp_0 | 0) == 119) {
      __label__ = 36;
      break;
    } else if (($switchOp_0 | 0) == 188) {
      __label__ = 37;
      break;
    } else if (($switchOp_0 | 0) == 1) {
      __label__ = 38;
      break;
    } else if (($switchOp_0 | 0) == 81) {
      __label__ = 39;
      break;
    } else if (($switchOp_0 | 0) == 11) {
      __label__ = 40;
      break;
    } else if (($switchOp_0 | 0) == 154 || ($switchOp_0 | 0) == 2) {
      __label__ = 41;
      break;
    } else if (($switchOp_0 | 0) == 3) {
      __label__ = 42;
      break;
    } else if (($switchOp_0 | 0) == 4) {
      __label__ = 44;
      break;
    } else if (($switchOp_0 | 0) == 5) {
      __label__ = 45;
      break;
    } else if (($switchOp_0 | 0) == 155 || ($switchOp_0 | 0) == 197) {
      __label__ = 46;
      break;
    } else if (($switchOp_0 | 0) == 122) {
      __label__ = 57;
      break;
    } else if (($switchOp_0 | 0) == 6) {
      __label__ = 58;
      break;
    } else if (($switchOp_0 | 0) == 7) {
      __label__ = 59;
      break;
    } else if (($switchOp_0 | 0) == 8) {
      __label__ = 66;
      break;
    } else if (($switchOp_0 | 0) == 68) {
      __label__ = 73;
      break;
    } else if (($switchOp_0 | 0) == 69) {
      __label__ = 80;
      break;
    } else if (($switchOp_0 | 0) == 148) {
      __label__ = 87;
      break;
    } else if (($switchOp_0 | 0) == 141) {
      __label__ = 88;
      break;
    } else if (($switchOp_0 | 0) == 142) {
      __label__ = 89;
      break;
    } else if (($switchOp_0 | 0) == 143) {
      __label__ = 96;
      break;
    } else if (($switchOp_0 | 0) == 144) {
      __label__ = 103;
      break;
    } else if (($switchOp_0 | 0) == 145) {
      __label__ = 110;
      break;
    } else if (($switchOp_0 | 0) == 113) {
      __label__ = 117;
      break;
    } else if (($switchOp_0 | 0) == 75) {
      __label__ = 129;
      break;
    } else if (($switchOp_0 | 0) == 76) {
      __label__ = 132;
      break;
    } else if (($switchOp_0 | 0) == 77) {
      __label__ = 136;
      break;
    } else if (($switchOp_0 | 0) == 78) {
      __label__ = 137;
      break;
    } else if (($switchOp_0 | 0) == 12) {
      __label__ = 138;
      break;
    } else if (($switchOp_0 | 0) == 13) {
      __label__ = 139;
      break;
    } else if (($switchOp_0 | 0) == 10) {
      __label__ = 140;
      break;
    } else if (($switchOp_0 | 0) == 133) {
      __label__ = 141;
      break;
    } else if (($switchOp_0 | 0) == 14) {
      __label__ = 142;
      break;
    } else if (($switchOp_0 | 0) == 209) {
      __label__ = 145;
      break;
    } else if (($switchOp_0 | 0) == 217) {
      __label__ = 156;
      break;
    } else if (($switchOp_0 | 0) == 110) {
      __label__ = 157;
      break;
    } else if (($switchOp_0 | 0) == 105) {
      __label__ = 162;
      break;
    } else if (($switchOp_0 | 0) == 15) {
      __label__ = 163;
      break;
    } else if (($switchOp_0 | 0) == 16) {
      __label__ = 166;
      break;
    } else if (($switchOp_0 | 0) == 17) {
      __label__ = 169;
      break;
    } else if (($switchOp_0 | 0) == 18) {
      __label__ = 172;
      break;
    } else if (($switchOp_0 | 0) == 19) {
      __label__ = 177;
      break;
    } else if (($switchOp_0 | 0) == 72) {
      __label__ = 182;
      break;
    } else if (($switchOp_0 | 0) == 73) {
      __label__ = 184;
      break;
    } else if (($switchOp_0 | 0) == 121) {
      __label__ = 186;
      break;
    } else if (($switchOp_0 | 0) == 147) {
      __label__ = 189;
      break;
    } else if (($switchOp_0 | 0) == 20) {
      __label__ = 192;
      break;
    } else if (($switchOp_0 | 0) == 21) {
      __label__ = 208;
      break;
    } else if (($switchOp_0 | 0) == 22) {
      __label__ = 224;
      break;
    } else if (($switchOp_0 | 0) == 23) {
      __label__ = 240;
      break;
    } else if (($switchOp_0 | 0) == 24) {
      __label__ = 256;
      break;
    } else if (($switchOp_0 | 0) == 25) {
      __label__ = 259;
      break;
    } else if (($switchOp_0 | 0) == 26) {
      __label__ = 262;
      break;
    } else if (($switchOp_0 | 0) == 27) {
      __label__ = 266;
      break;
    } else if (($switchOp_0 | 0) == 28) {
      __label__ = 299;
      break;
    } else if (($switchOp_0 | 0) == 29) {
      __label__ = 305;
      break;
    } else if (($switchOp_0 | 0) == 30) {
      __label__ = 311;
      break;
    } else if (($switchOp_0 | 0) == 31) {
      __label__ = 318;
      break;
    } else if (($switchOp_0 | 0) == 32) {
      __label__ = 329;
      break;
    } else if (($switchOp_0 | 0) == 33) {
      __label__ = 334;
      break;
    } else if (($switchOp_0 | 0) == 34) {
      __label__ = 336;
      break;
    } else if (($switchOp_0 | 0) == 35) {
      __label__ = 343;
      break;
    } else if (($switchOp_0 | 0) == 36) {
      __label__ = 346;
      break;
    } else if (($switchOp_0 | 0) == 37) {
      __label__ = 349;
      break;
    } else if (($switchOp_0 | 0) == 38) {
      __label__ = 355;
      break;
    } else if (($switchOp_0 | 0) == 231) {
      __label__ = 366;
      break;
    } else if (($switchOp_0 | 0) == 200 || ($switchOp_0 | 0) == 39) {
      __label__ = 376;
      break;
    } else if (($switchOp_0 | 0) == 40) {
      __label__ = 377;
      break;
    } else if (($switchOp_0 | 0) == 43 || ($switchOp_0 | 0) == 46 || ($switchOp_0 | 0) == 49 || ($switchOp_0 | 0) == 52) {
      __label__ = 378;
      break;
    } else if (($switchOp_0 | 0) == 42 || ($switchOp_0 | 0) == 45 || ($switchOp_0 | 0) == 48 || ($switchOp_0 | 0) == 51) {
      __label__ = 379;
      break;
    } else if (($switchOp_0 | 0) == 41 || ($switchOp_0 | 0) == 44 || ($switchOp_0 | 0) == 47 || ($switchOp_0 | 0) == 50 || ($switchOp_0 | 0) == 158 || ($switchOp_0 | 0) == 159 || ($switchOp_0 | 0) == 160 || ($switchOp_0 | 0) == 161) {
      __label__ = 391;
      break;
    } else if (($switchOp_0 | 0) == 99) {
      __label__ = 415;
      break;
    } else if (($switchOp_0 | 0) == 98) {
      __label__ = 416;
      break;
    } else if (($switchOp_0 | 0) == 100) {
      __label__ = 417;
      break;
    } else if (($switchOp_0 | 0) == 97) {
      var $incr2_0 = 1;
      var $incr163_0 = 1;
      __label__ = 418;
      break;
    } else if (($switchOp_0 | 0) == 103) {
      __label__ = 419;
      break;
    } else if (($switchOp_0 | 0) == 102) {
      __label__ = 420;
      break;
    } else if (($switchOp_0 | 0) == 104) {
      __label__ = 421;
      break;
    } else if (($switchOp_0 | 0) == 101) {
      var $incr2_1 = 1;
      var $incr163_1 = 1;
      __label__ = 422;
      break;
    } else if (($switchOp_0 | 0) == 65) {
      __label__ = 430;
      break;
    } else if (($switchOp_0 | 0) == 229) {
      __label__ = 432;
      break;
    } else if (($switchOp_0 | 0) == 53 || ($switchOp_0 | 0) == 198 || ($switchOp_0 | 0) == 220) {
      __label__ = 436;
      break;
    } else if (($switchOp_0 | 0) == 187) {
      __label__ = 470;
      break;
    } else if (($switchOp_0 | 0) == 228) {
      __label__ = 499;
      break;
    } else if (($switchOp_0 | 0) == 157 || ($switchOp_0 | 0) == 111 || ($switchOp_0 | 0) == 54 || ($switchOp_0 | 0) == 226) {
      __label__ = 500;
      break;
    } else if (($switchOp_0 | 0) == 55) {
      __label__ = 536;
      break;
    } else if (($switchOp_0 | 0) == 196) {
      __label__ = 572;
      break;
    } else if (($switchOp_0 | 0) == 56) {
      __label__ = 584;
      break;
    } else if (($switchOp_0 | 0) == 124) {
      __label__ = 608;
      break;
    } else if (($switchOp_0 | 0) == 123) {
      __label__ = 619;
      break;
    } else if (($switchOp_0 | 0) == 82 || ($switchOp_0 | 0) == 58 || ($switchOp_0 | 0) == 108 || ($switchOp_0 | 0) == 79) {
      __label__ = 625;
      break;
    } else if (($switchOp_0 | 0) == 74) {
      __label__ = 644;
      break;
    } else if (($switchOp_0 | 0) == 156 || ($switchOp_0 | 0) == 214 || ($switchOp_0 | 0) == 59 || ($switchOp_0 | 0) == 57) {
      __label__ = 645;
      break;
    } else if (($switchOp_0 | 0) == 88) {
      __label__ = 681;
      break;
    } else if (($switchOp_0 | 0) == 190) {
      __label__ = 682;
      break;
    } else if (($switchOp_0 | 0) == 218) {
      __label__ = 683;
      break;
    } else if (($switchOp_0 | 0) == 219) {
      __label__ = 684;
      break;
    } else if (($switchOp_0 | 0) == 191) {
      __label__ = 685;
      break;
    } else if (($switchOp_0 | 0) == 211 || ($switchOp_0 | 0) == 212 || ($switchOp_0 | 0) == 213) {
      __label__ = 686;
      break;
    } else if (($switchOp_0 | 0) == 193 || ($switchOp_0 | 0) == 192) {
      __label__ = 687;
      break;
    } else if (($switchOp_0 | 0) == 60) {
      __label__ = 688;
      break;
    } else if (($switchOp_0 | 0) == 61) {
      __label__ = 689;
      break;
    } else if (($switchOp_0 | 0) == 80) {
      __label__ = 690;
      break;
    } else if (($switchOp_0 | 0) == 162) {
      __label__ = 691;
      break;
    } else if (($switchOp_0 | 0) == 62) {
      __label__ = 694;
      break;
    } else if (($switchOp_0 | 0) == 63) {
      __label__ = 695;
      break;
    } else if (($switchOp_0 | 0) == 64) {
      __label__ = 696;
      break;
    } else if (($switchOp_0 | 0) == 66) {
      __label__ = 697;
      break;
    } else if (($switchOp_0 | 0) == 67) {
      __label__ = 698;
      break;
    } else if (($switchOp_0 | 0) == 70) {
      __label__ = 699;
      break;
    } else if (($switchOp_0 | 0) == 149) {
      __label__ = 706;
      break;
    } else if (($switchOp_0 | 0) == 71) {
      __label__ = 713;
      break;
    } else if (($switchOp_0 | 0) == 150) {
      var $off249_0 = 4;
      __label__ = 714;
      break;
    } else if (($switchOp_0 | 0) == 83) {
      __label__ = 734;
      break;
    } else if (($switchOp_0 | 0) == 9) {
      __label__ = 740;
      break;
    } else if (($switchOp_0 | 0) == 138) {
      __label__ = 748;
      break;
    } else if (($switchOp_0 | 0) == 139) {
      __label__ = 750;
      break;
    } else if (($switchOp_0 | 0) == 84 || ($switchOp_0 | 0) == 216) {
      __label__ = 752;
      break;
    } else if (($switchOp_0 | 0) == 85) {
      __label__ = 754;
      break;
    } else if (($switchOp_0 | 0) == 86) {
      __label__ = 756;
      break;
    } else if (($switchOp_0 | 0) == 215) {
      __label__ = 757;
      break;
    } else if (($switchOp_0 | 0) == 87) {
      __label__ = 758;
      break;
    } else if (($switchOp_0 | 0) == 136 || ($switchOp_0 | 0) == 137) {
      __label__ = 760;
      break;
    } else if (($switchOp_0 | 0) == 106 || ($switchOp_0 | 0) == 107 || ($switchOp_0 | 0) == 128 || ($switchOp_0 | 0) == 129) {
      __label__ = 762;
      break;
    } else if (($switchOp_0 | 0) == 127) {
      __label__ = 768;
      break;
    } else if (($switchOp_0 | 0) == 222) {
      __label__ = 787;
      break;
    } else if (($switchOp_0 | 0) == 140) {
      __label__ = 792;
      break;
    } else if (($switchOp_0 | 0) == 223) {
      __label__ = 798;
      break;
    } else if (($switchOp_0 | 0) == 130) {
      __label__ = 800;
      break;
    } else if (($switchOp_0 | 0) == 224) {
      __label__ = 816;
      break;
    } else if (($switchOp_0 | 0) == 131) {
      __label__ = 818;
      break;
    } else if (($switchOp_0 | 0) == 125 || ($switchOp_0 | 0) == 126) {
      var $atoms_2 = $atoms_1;
      __label__ = 819;
      break;
    } else if (($switchOp_0 | 0) == 221) {
      __label__ = 848;
      break;
    } else if (($switchOp_0 | 0) == 89) {
      __label__ = 849;
      break;
    } else if (($switchOp_0 | 0) == 90) {
      __label__ = 856;
      break;
    } else if (($switchOp_0 | 0) == 91) {
      __label__ = 860;
      break;
    } else if (($switchOp_0 | 0) == 93 || ($switchOp_0 | 0) == 227) {
      __label__ = 864;
      break;
    } else if (($switchOp_0 | 0) == 94) {
      __label__ = 874;
      break;
    } else if (($switchOp_0 | 0) == 95) {
      __label__ = 883;
      break;
    } else if (($switchOp_0 | 0) == 96) {
      __label__ = 890;
      break;
    } else if (($switchOp_0 | 0) == 230) {
      __label__ = 896;
      break;
    } else if (($switchOp_0 | 0) == 116) {
      __label__ = 903;
      break;
    } else if (($switchOp_0 | 0) == 146) {
      __label__ = 904;
      break;
    } else if (($switchOp_0 | 0) == 117) {
      __label__ = 905;
      break;
    } else if (($switchOp_0 | 0) == 118) {
      __label__ = 908;
      break;
    } else if (($switchOp_0 | 0) == 135) {
      __label__ = 910;
      break;
    } else if (($switchOp_0 | 0) == 153) {
      __label__ = 912;
      break;
    } else if (($switchOp_0 | 0) == 112) {
      __label__ = 913;
      break;
    } else if (($switchOp_0 | 0) == 132) {
      __label__ = 916;
      break;
    } else if (($switchOp_0 | 0) == 203) {
      __label__ = 917;
      break;
    } else if (($switchOp_0 | 0) == 204) {
      __label__ = 919;
      break;
    } else if (($switchOp_0 | 0) == 225) {
      __label__ = 923;
      break;
    } else if (($switchOp_0 | 0) == 114) {
      __label__ = 925;
      break;
    } else if (($switchOp_0 | 0) == 115) {
      __label__ = 929;
      break;
    } else if (($switchOp_0 | 0) == 163) {
      __label__ = 937;
      break;
    } else if (($switchOp_0 | 0) == 164) {
      __label__ = 939;
      break;
    } else if (($switchOp_0 | 0) == 165) {
      __label__ = 941;
      break;
    } else if (($switchOp_0 | 0) == 166) {
      __label__ = 942;
      break;
    } else if (($switchOp_0 | 0) == 167) {
      __label__ = 944;
      break;
    } else if (($switchOp_0 | 0) == 168) {
      __label__ = 946;
      break;
    } else if (($switchOp_0 | 0) == 169) {
      __label__ = 948;
      break;
    } else if (($switchOp_0 | 0) == 170 || ($switchOp_0 | 0) == 171) {
      __label__ = 950;
      break;
    } else if (($switchOp_0 | 0) == 172) {
      __label__ = 952;
      break;
    } else if (($switchOp_0 | 0) == 173) {
      __label__ = 954;
      break;
    } else if (($switchOp_0 | 0) == 199 || ($switchOp_0 | 0) == 174) {
      __label__ = 961;
      break;
    } else if (($switchOp_0 | 0) == 175 || ($switchOp_0 | 0) == 186) {
      __label__ = 966;
      break;
    } else if (($switchOp_0 | 0) == 176) {
      __label__ = 975;
      break;
    } else if (($switchOp_0 | 0) == 177) {
      __label__ = 976;
      break;
    } else if (($switchOp_0 | 0) == 178) {
      __label__ = 983;
      break;
    } else if (($switchOp_0 | 0) == 179) {
      __label__ = 985;
      break;
    } else if (($switchOp_0 | 0) == 180) {
      __label__ = 987;
      break;
    } else if (($switchOp_0 | 0) == 181) {
      __label__ = 989;
      break;
    } else if (($switchOp_0 | 0) == 183) {
      __label__ = 995;
      break;
    } else if (($switchOp_0 | 0) == 184) {
      __label__ = 997;
      break;
    } else if (($switchOp_0 | 0) == 185) {
      __label__ = 999;
      break;
    } else if (($switchOp_0 | 0) == 208) {
      __label__ = 1001;
      break;
    } else if (($switchOp_0 | 0) == 201) {
      __label__ = 1003;
      break;
    } else if (($switchOp_0 | 0) == 210 || ($switchOp_0 | 0) == 202) {
      __label__ = 1004;
      break;
    } else if (($switchOp_0 | 0) == 205) {
      __label__ = 1008;
      break;
    } else if (($switchOp_0 | 0) == 206) {
      __label__ = 1010;
      break;
    } else if (($switchOp_0 | 0) == 207) {
      __label__ = 1013;
      break;
    } else {
      __label__ = 1015;
      break;
    }
   case 20:
    if ($71) {
      var $moreInterrupts_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $regs_idx68_val = HEAP32[$regs_idx73 >> 2];
    var $76 = __ZNK2js9FrameRegs2fpEv($regs_idx68_val);
    var $_idx167_val = HEAP32[$76 >> 2];
    var $77 = __ZNK2js10StackFrame11hasImacropcEv($_idx167_val);
    if ($77) {
      var $moreInterrupts_0 = -128;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $84 = $pcCounts_1 + (HEAP32[$_pre_phi >> 2] - HEAP32[$72 >> 2] << 3) | 0;
    var $85 = (tempDoubleI32[0] = HEAP32[$84 >> 2], tempDoubleI32[1] = HEAP32[$84 + 4 >> 2], tempDoubleF64[0]);
    var $86 = $85 + 1;
    tempDoubleF64[0] = $86, HEAP32[$84 >> 2] = tempDoubleI32[0], HEAP32[$84 + 4 >> 2] = tempDoubleI32[1];
    var $moreInterrupts_0 = -128;
    __label__ = 23;
    break;
   case 23:
    var $moreInterrupts_0;
    var $88 = HEAP32[$34 >> 2];
    var $90 = HEAP32[$88 >> 2];
    if (($90 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $script_1_idx383_val = HEAP32[$script_1_idx383 >> 2];
    var $93 = __ZN8JSScript15stepModeEnabledEv($script_1_idx383_val);
    if ($93) {
      var $script_1_idx382_val = $script_1_idx383_val;
      __label__ = 27;
      break;
    } else {
      var $moreInterrupts_1 = $moreInterrupts_0;
      __label__ = 32;
      break;
    }
   case 25:
    var $95 = HEAP32[$_pre_phi >> 2];
    var $97 = HEAP32[$88 + 4 >> 2];
    var $98 = FUNCTION_TABLE[$90]($cx, $script_1, $95, $rval, $97);
    if (($98 | 0) == 1) {
      __label__ = 26;
      break;
    } else {
      var $status_1 = $98;
      __label__ = 29;
      break;
    }
   case 26:
    var $script_1_idx382_val = HEAP32[$script_1_idx383 >> 2];
    __label__ = 27;
    break;
   case 27:
    var $script_1_idx382_val;
    var $100 = __ZN8JSScript15stepModeEnabledEv($script_1_idx382_val);
    if ($100) {
      __label__ = 28;
      break;
    } else {
      var $moreInterrupts_1 = -128;
      __label__ = 32;
      break;
    }
   case 28:
    var $102 = __ZN2js8Debugger12onSingleStepEP9JSContextPN2JS5ValueE($cx, $rval);
    var $status_1 = $102;
    __label__ = 29;
    break;
   case 29:
    var $status_1;
    if (($status_1 | 0) == 2) {
      __label__ = 30;
      break;
    } else if (($status_1 | 0) == 3) {
      __label__ = 31;
      break;
    } else if (($status_1 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $moreInterrupts_1 = -128;
      __label__ = 32;
      break;
    }
   case 30:
    var $regs_idx67_val = HEAP32[$regs_idx73 >> 2];
    var $105 = __ZNK2js9FrameRegs2fpEv($regs_idx67_val);
    var $106 = $105;
    var $rval_idx = $rval | 0;
    var $st$4$0 = $rval_idx | 0;
    var $rval_idx_val$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $rval_idx + 4 | 0;
    var $rval_idx_val$1 = HEAP32[$st$4$1 >> 2];
    __ZN2js10StackFrame14setReturnValueERKN2JS5ValueE($106, $rval_idx_val$0, $rval_idx_val$1);
    var $interpReturnOK_1 = 1;
    __label__ = 1044;
    break;
   case 31:
    var $108 = $rval | 0;
    var $st$1$0 = $108 | 0;
    var $109$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $108 + 4 | 0;
    var $109$1 = HEAP32[$st$1$1 >> 2];
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($cx, $109$0, $109$1);
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 32:
    var $moreInterrupts_1;
    HEAP32[$switchMask >> 2] = $moreInterrupts_1 << 24 >> 24 >> 7 << 24 >> 24;
    var $switchOp_0 = $op_0;
    __label__ = 19;
    break;
   case 33:
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 34:
    var $op_1;
    if ((HEAP32[HEAP32[$22 >> 2] + 144280 >> 2] | 0) == 0) {
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $op_1;
      __label__ = 18;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $118 = __Z27js_HandleExecutionInterruptP9JSContext($cx);
    if (($118 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $op_1;
      __label__ = 18;
      break;
    }
   case 36:
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 37:
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 38:
    var $123 = HEAP32[$_pre_phi580 >> 2];
    var $124 = $123 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $124;
    __ZN2JS5Value12setUndefinedEv($123);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 39:
    var $127 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $127;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 40:
    var $129 = HEAPU32[$_pre_phi >> 2];
    var $140 = HEAP32[$_pre_phi580 >> 2] + (-((HEAPU8[$129 + 1 | 0] & 255) << 8 | HEAPU8[$129 + 2 | 0] & 255) << 3) | 0;
    HEAP32[$_pre_phi580 >> 2] = $140;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 41:
    var $regs_idx66_val = HEAP32[$regs_idx73 >> 2];
    var $142 = __ZNK2js9FrameRegs2fpEv($regs_idx66_val);
    var $144 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $144;
    var $145 = $142;
    var $_idx392 = $144 | 0;
    var $st$7$0 = $_idx392 | 0;
    var $_idx392_val$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $_idx392 + 4 | 0;
    var $_idx392_val$1 = HEAP32[$st$7$1 >> 2];
    __ZN2js10StackFrame14setReturnValueERKN2JS5ValueE($145, $_idx392_val$0, $_idx392_val$1);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 42:
    var $147 = __ZL9EnterWithP9JSContexti4JSOpj($cx, -1, 1);
    if ($147) {
      __label__ = 43;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 43:
    var $150 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $regs_idx65_val = HEAP32[$regs_idx73 >> 2];
    var $151 = __ZNK2js9FrameRegs2fpEv($regs_idx65_val);
    var $152 = __ZNK2js10StackFrame10scopeChainEv($151);
    __ZN2JS5Value9setObjectER8JSObject($150, $152);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 44:
    var $155 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $155;
    __ZL9LeaveWithP9JSContext($cx);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 45:
    var $regs_idx64_val = HEAP32[$regs_idx73 >> 2];
    var $157 = __ZNK2js9FrameRegs2fpEv($regs_idx64_val);
    var $159 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $159;
    var $160 = $157;
    var $_idx391 = $159 | 0;
    var $st$7$0 = $_idx391 | 0;
    var $_idx391_val$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $_idx391 + 4 | 0;
    var $_idx391_val$1 = HEAP32[$st$7$1 >> 2];
    __ZN2js10StackFrame14setReturnValueERKN2JS5ValueE($160, $_idx391_val$0, $_idx391_val$1);
    __label__ = 46;
    break;
   case 46:
    if ((HEAP32[HEAP32[$22 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 48;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $166 = __Z27js_HandleExecutionInterruptP9JSContext($cx);
    if (($166 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    var $regs_idx63_val = HEAPU32[$regs_idx73 >> 2];
    var $169 = __ZNK2js9FrameRegs2fpEv($regs_idx63_val);
    if (($_08 | 0) == ($169 | 0)) {
      var $interpReturnOK_2 = 1;
      var $regs_idx1_val = $regs_idx63_val;
      __label__ = 1047;
      break;
    } else {
      var $interpReturnOK_0 = 1;
      var $regs_idx62_val = $regs_idx63_val;
      __label__ = 49;
      break;
    }
   case 49:
    var $regs_idx62_val;
    var $interpReturnOK_0;
    var $172 = __ZNK2js9FrameRegs2fpEv($regs_idx62_val);
    var $174 = __ZN2js14ScriptEpilogueEP9JSContextPNS_10StackFrameEb($cx, $172, ($interpReturnOK_0 | 0) != 0);
    var $regs_idx61_val = HEAP32[$regs_idx73 >> 2];
    var $175 = __ZNK2js9FrameRegs2fpEv($regs_idx61_val);
    var $_idx393_val = HEAP32[$175 >> 2];
    var $176 = __ZNK2js10StackFrame18loweredCallOrApplyEv($_idx393_val);
    __ZN2js12ContextStack14popInlineFrameERNS_9FrameRegsE($regs);
    var $regs_idx60_val = HEAP32[$regs_idx73 >> 2];
    var $177 = __ZNK2js9FrameRegs2fpEv($regs_idx60_val);
    var $178 = __ZNK2js10StackFrame6scriptEv($177);
    var $_idx381_val = HEAP32[$178 + 24 >> 2];
    var $179 = __ZN8JSScript15stepModeEnabledEv($_idx381_val);
    if ($179) {
      __label__ = 50;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 50:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 51;
    break;
   case 51:
    var $_idx386_val = HEAP32[$178 + 96 >> 2];
    var $182 = __ZN12JSPCCounters3getEi($_idx386_val);
    if (($182 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 52:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 53;
    break;
   case 53:
    var $regs_idx59_val = HEAP32[$regs_idx73 >> 2];
    var $185 = __ZNK2js9FrameRegs2fpEv($regs_idx59_val);
    var $186 = __ZNK2js10StackFrame15maybeFormalArgsEv($185);
    var $187 = __ZN2jsL13FrameAtomBaseEP9JSContextPNS_10StackFrameE($cx, $185);
    var $188 = $regs + 4 | 0;
    var $189 = HEAP32[$188 >> 2];
    if ($174) {
      __label__ = 54;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 54:
    var $191 = $regs | 0;
    var $193 = HEAP32[$191 >> 2] - 8 | 0;
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $178, $189, $193);
    if ($176) {
      __label__ = 55;
      break;
    } else {
      var $script_0_ph = $178;
      var $pcCounts_0_ph = $182;
      var $argv_0_ph = $186;
      var $atoms_0_ph = $187;
      var $len_0_ph1296 = 3;
      var $_pre_phi = $188;
      var $_pre_phi580 = $191;
      __label__ = 1036;
      break;
    }
   case 55:
    var $195 = HEAP32[$191 >> 2];
    var $196 = $195 - 8 | 0;
    var $st$2$0 = $196 | 0;
    var $197$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $196 + 4 | 0;
    var $197$1 = HEAP32[$st$2$1 >> 2];
    var $198 = $195 - 16 | 0;
    var $st$7$0 = $198 | 0;
    HEAP32[$st$7$0 >> 2] = $197$0;
    var $st$7$1 = $198 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $197$1;
    var $200 = HEAP32[$191 >> 2] - 8 | 0;
    HEAP32[$191 >> 2] = $200;
    var $script_0_ph = $178;
    var $pcCounts_0_ph = $182;
    var $argv_0_ph = $186;
    var $atoms_0_ph = $187;
    var $len_0_ph1296 = 3;
    var $_pre_phi = $188;
    var $_pre_phi580 = $191;
    __label__ = 1036;
    break;
   case 56:
    var $202 = $189 + 3 | 0;
    HEAP32[$188 >> 2] = $202;
    var $script_2_ph1347 = $178;
    var $pcCounts_2_ph1346 = $182;
    var $argv_2_ph1345 = $186;
    __label__ = 1016;
    break;
   case 57:
    var $205 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $205;
    __label__ = 58;
    break;
   case 58:
    var $206 = HEAPU32[$_pre_phi >> 2];
    var $214 = (HEAPU8[$206 + 1 | 0] & 255) << 8 | HEAPU8[$206 + 2 | 0] & 255;
    var $216 = $206 + ($214 << 16 >> 16) | 0;
    HEAP32[$_pre_phi >> 2] = $216;
    var $218 = HEAPU8[$216] & 255;
    if ($214 << 16 >> 16 < 1) {
      var $op_1 = $218;
      __label__ = 34;
      break;
    } else {
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $218;
      __label__ = 18;
      break;
    }
   case 59:
    var $222 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $_idx326 = $222 | 0;
    var $st$3$0 = $_idx326 | 0;
    var $_idx326_val$0 = HEAPU32[$st$3$0 >> 2];
    var $st$3$1 = $_idx326 + 4 | 0;
    var $_idx326_val$1 = HEAPU32[$st$3$1 >> 2];
    var $223 = __ZNK2JS5Value6isNullEv($_idx326_val$0, $_idx326_val$1);
    if ($223) {
      __label__ = 60;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 60:
    HEAP32[$_pre_phi580 >> 2] = $222;
    __label__ = 65;
    break;
   case 61:
    var $225 = __ZNK2JS5Value9isBooleanEv($_idx326_val$0, $_idx326_val$1);
    if ($225) {
      __label__ = 62;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 62:
    var $227 = __ZNK2JS5Value9toBooleanEv($_idx326_val$0, $_idx326_val$1);
    var $cond_0 = $227 & 1;
    __label__ = 64;
    break;
   case 63:
    var $230 = __Z17js_ValueToBooleanRKN2JS5ValueE($222);
    var $cond_0 = ($230 | 0) != 0 & 1;
    __label__ = 64;
    break;
   case 64:
    var $cond_0;
    HEAP32[$_pre_phi580 >> 2] = $222;
    if (($cond_0 | 0) == 0) {
      __label__ = 65;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    }
   case 65:
    var $235 = HEAPU32[$_pre_phi >> 2];
    var $243 = (HEAPU8[$235 + 1 | 0] & 255) << 8 | HEAPU8[$235 + 2 | 0] & 255;
    var $245 = $235 + ($243 << 16 >> 16) | 0;
    HEAP32[$_pre_phi >> 2] = $245;
    var $247 = HEAPU8[$245] & 255;
    if ($243 << 16 >> 16 < 1) {
      var $op_1 = $247;
      __label__ = 34;
      break;
    } else {
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $247;
      __label__ = 18;
      break;
    }
   case 66:
    var $251 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $_idx325 = $251 | 0;
    var $st$3$0 = $_idx325 | 0;
    var $_idx325_val$0 = HEAPU32[$st$3$0 >> 2];
    var $st$3$1 = $_idx325 + 4 | 0;
    var $_idx325_val$1 = HEAPU32[$st$3$1 >> 2];
    var $252 = __ZNK2JS5Value6isNullEv($_idx325_val$0, $_idx325_val$1);
    if ($252) {
      __label__ = 67;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 67:
    HEAP32[$_pre_phi580 >> 2] = $251;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 68:
    var $254 = __ZNK2JS5Value9isBooleanEv($_idx325_val$0, $_idx325_val$1);
    if ($254) {
      __label__ = 69;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 69:
    var $256 = __ZNK2JS5Value9toBooleanEv($_idx325_val$0, $_idx325_val$1);
    var $cond1_0 = $256 & 1;
    __label__ = 71;
    break;
   case 70:
    var $259 = __Z17js_ValueToBooleanRKN2JS5ValueE($251);
    var $cond1_0 = ($259 | 0) != 0 & 1;
    __label__ = 71;
    break;
   case 71:
    var $cond1_0;
    HEAP32[$_pre_phi580 >> 2] = $251;
    if ($cond1_0 << 24 >> 24 == 0) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    } else {
      __label__ = 72;
      break;
    }
   case 72:
    var $265 = HEAPU32[$_pre_phi >> 2];
    var $273 = (HEAPU8[$265 + 1 | 0] & 255) << 8 | HEAPU8[$265 + 2 | 0] & 255;
    var $275 = $265 + ($273 << 16 >> 16) | 0;
    HEAP32[$_pre_phi >> 2] = $275;
    var $277 = HEAPU8[$275] & 255;
    if ($273 << 16 >> 16 < 1) {
      var $op_1 = $277;
      __label__ = 34;
      break;
    } else {
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $277;
      __label__ = 18;
      break;
    }
   case 73:
    var $280 = HEAPU32[$_pre_phi580 >> 2];
    var $281 = $280 - 8 | 0;
    var $_idx324 = $281 | 0;
    var $st$3$0 = $_idx324 | 0;
    var $_idx324_val$0 = HEAPU32[$st$3$0 >> 2];
    var $st$3$1 = $_idx324 + 4 | 0;
    var $_idx324_val$1 = HEAPU32[$st$3$1 >> 2];
    var $282 = __ZNK2JS5Value6isNullEv($_idx324_val$0, $_idx324_val$1);
    if ($282) {
      __label__ = 74;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 74:
    HEAP32[$_pre_phi580 >> 2] = $281;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 75:
    var $284 = __ZNK2JS5Value9isBooleanEv($_idx324_val$0, $_idx324_val$1);
    if ($284) {
      __label__ = 76;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 76:
    var $286 = __ZNK2JS5Value9toBooleanEv($_idx324_val$0, $_idx324_val$1);
    var $cond3_0 = $286 & 1;
    __label__ = 78;
    break;
   case 77:
    var $289 = __Z17js_ValueToBooleanRKN2JS5ValueE($281);
    var $cond3_0 = ($289 | 0) != 0 & 1;
    __label__ = 78;
    break;
   case 78:
    var $cond3_0;
    HEAP32[$_pre_phi580 >> 2] = $281;
    if ($cond3_0 << 24 >> 24 == 0) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 79:
    var $295 = HEAPU32[$_pre_phi >> 2];
    var $304 = ((HEAPU8[$295 + 1 | 0] & 255) << 8 | HEAPU8[$295 + 2 | 0] & 255) << 16 >> 16;
    HEAP32[$_pre_phi580 >> 2] = $280;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = $304;
    __label__ = 17;
    break;
   case 80:
    var $306 = HEAPU32[$_pre_phi580 >> 2];
    var $307 = $306 - 8 | 0;
    var $_idx323 = $307 | 0;
    var $st$3$0 = $_idx323 | 0;
    var $_idx323_val$0 = HEAPU32[$st$3$0 >> 2];
    var $st$3$1 = $_idx323 + 4 | 0;
    var $_idx323_val$1 = HEAP32[$st$3$1 >> 2];
    var $308 = __ZNK2JS5Value6isNullEv($_idx323_val$0, $_idx323_val$1);
    if ($308) {
      __label__ = 81;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 81:
    HEAP32[$_pre_phi580 >> 2] = $307;
    __label__ = 86;
    break;
   case 82:
    var $310 = __ZNK2JS5Value9isBooleanEv($_idx323_val$0, $_idx323_val$1);
    if ($310) {
      __label__ = 83;
      break;
    } else {
      __label__ = 84;
      break;
    }
   case 83:
    var $312 = __ZNK2JS5Value9toBooleanEv($_idx323_val$0, $_idx323_val$1);
    var $cond4_0 = $312 & 1;
    __label__ = 85;
    break;
   case 84:
    var $315 = __Z17js_ValueToBooleanRKN2JS5ValueE($307);
    var $cond4_0 = ($315 | 0) != 0 & 1;
    __label__ = 85;
    break;
   case 85:
    var $cond4_0;
    HEAP32[$_pre_phi580 >> 2] = $307;
    if (($cond4_0 | 0) == 0) {
      __label__ = 86;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    }
   case 86:
    var $320 = HEAPU32[$_pre_phi >> 2];
    var $329 = ((HEAPU8[$320 + 1 | 0] & 255) << 8 | HEAPU8[$320 + 2 | 0] & 255) << 16 >> 16;
    HEAP32[$_pre_phi580 >> 2] = $306;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = $329;
    __label__ = 17;
    break;
   case 87:
    var $332 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $332;
    __label__ = 88;
    break;
   case 88:
    var $333 = HEAPU32[$_pre_phi >> 2];
    var $351 = (HEAPU8[$333 + 2 | 0] & 255) << 16 | (HEAPU8[$333 + 1 | 0] & 255) << 24 | HEAPU8[$333 + 4 | 0] & 255 | (HEAPU8[$333 + 3 | 0] & 255) << 8;
    var $352 = $333 + $351 | 0;
    HEAP32[$_pre_phi >> 2] = $352;
    var $354 = HEAPU8[$352] & 255;
    if (($351 | 0) < 1) {
      var $op_1 = $354;
      __label__ = 34;
      break;
    } else {
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $354;
      __label__ = 18;
      break;
    }
   case 89:
    var $358 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $_idx322 = $358 | 0;
    var $st$3$0 = $_idx322 | 0;
    var $_idx322_val$0 = HEAPU32[$st$3$0 >> 2];
    var $st$3$1 = $_idx322 + 4 | 0;
    var $_idx322_val$1 = HEAPU32[$st$3$1 >> 2];
    var $359 = __ZNK2JS5Value6isNullEv($_idx322_val$0, $_idx322_val$1);
    if ($359) {
      __label__ = 90;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 90:
    HEAP32[$_pre_phi580 >> 2] = $358;
    __label__ = 95;
    break;
   case 91:
    var $361 = __ZNK2JS5Value9isBooleanEv($_idx322_val$0, $_idx322_val$1);
    if ($361) {
      __label__ = 92;
      break;
    } else {
      __label__ = 93;
      break;
    }
   case 92:
    var $363 = __ZNK2JS5Value9toBooleanEv($_idx322_val$0, $_idx322_val$1);
    var $cond6_0 = $363 & 1;
    __label__ = 94;
    break;
   case 93:
    var $366 = __Z17js_ValueToBooleanRKN2JS5ValueE($358);
    var $cond6_0 = ($366 | 0) != 0 & 1;
    __label__ = 94;
    break;
   case 94:
    var $cond6_0;
    HEAP32[$_pre_phi580 >> 2] = $358;
    if (($cond6_0 | 0) == 0) {
      __label__ = 95;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 5;
      __label__ = 17;
      break;
    }
   case 95:
    var $371 = HEAPU32[$_pre_phi >> 2];
    var $389 = (HEAPU8[$371 + 2 | 0] & 255) << 16 | (HEAPU8[$371 + 1 | 0] & 255) << 24 | HEAPU8[$371 + 4 | 0] & 255 | (HEAPU8[$371 + 3 | 0] & 255) << 8;
    var $390 = $371 + $389 | 0;
    HEAP32[$_pre_phi >> 2] = $390;
    var $392 = HEAPU8[$390] & 255;
    if (($389 | 0) < 1) {
      var $op_1 = $392;
      __label__ = 34;
      break;
    } else {
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $392;
      __label__ = 18;
      break;
    }
   case 96:
    var $396 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $_idx321 = $396 | 0;
    var $st$3$0 = $_idx321 | 0;
    var $_idx321_val$0 = HEAPU32[$st$3$0 >> 2];
    var $st$3$1 = $_idx321 + 4 | 0;
    var $_idx321_val$1 = HEAPU32[$st$3$1 >> 2];
    var $397 = __ZNK2JS5Value6isNullEv($_idx321_val$0, $_idx321_val$1);
    if ($397) {
      __label__ = 97;
      break;
    } else {
      __label__ = 98;
      break;
    }
   case 97:
    HEAP32[$_pre_phi580 >> 2] = $396;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 5;
    __label__ = 17;
    break;
   case 98:
    var $399 = __ZNK2JS5Value9isBooleanEv($_idx321_val$0, $_idx321_val$1);
    if ($399) {
      __label__ = 99;
      break;
    } else {
      __label__ = 100;
      break;
    }
   case 99:
    var $401 = __ZNK2JS5Value9toBooleanEv($_idx321_val$0, $_idx321_val$1);
    var $cond8_0 = $401 & 1;
    __label__ = 101;
    break;
   case 100:
    var $404 = __Z17js_ValueToBooleanRKN2JS5ValueE($396);
    var $cond8_0 = ($404 | 0) != 0 & 1;
    __label__ = 101;
    break;
   case 101:
    var $cond8_0;
    HEAP32[$_pre_phi580 >> 2] = $396;
    if ($cond8_0 << 24 >> 24 == 0) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 5;
      __label__ = 17;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 102:
    var $410 = HEAPU32[$_pre_phi >> 2];
    var $428 = (HEAPU8[$410 + 2 | 0] & 255) << 16 | (HEAPU8[$410 + 1 | 0] & 255) << 24 | HEAPU8[$410 + 4 | 0] & 255 | (HEAPU8[$410 + 3 | 0] & 255) << 8;
    var $429 = $410 + $428 | 0;
    HEAP32[$_pre_phi >> 2] = $429;
    var $431 = HEAPU8[$429] & 255;
    if (($428 | 0) < 1) {
      var $op_1 = $431;
      __label__ = 34;
      break;
    } else {
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $431;
      __label__ = 18;
      break;
    }
   case 103:
    var $434 = HEAPU32[$_pre_phi580 >> 2];
    var $435 = $434 - 8 | 0;
    var $_idx320 = $435 | 0;
    var $st$3$0 = $_idx320 | 0;
    var $_idx320_val$0 = HEAPU32[$st$3$0 >> 2];
    var $st$3$1 = $_idx320 + 4 | 0;
    var $_idx320_val$1 = HEAPU32[$st$3$1 >> 2];
    var $436 = __ZNK2JS5Value6isNullEv($_idx320_val$0, $_idx320_val$1);
    if ($436) {
      __label__ = 104;
      break;
    } else {
      __label__ = 105;
      break;
    }
   case 104:
    HEAP32[$_pre_phi580 >> 2] = $435;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 5;
    __label__ = 17;
    break;
   case 105:
    var $438 = __ZNK2JS5Value9isBooleanEv($_idx320_val$0, $_idx320_val$1);
    if ($438) {
      __label__ = 106;
      break;
    } else {
      __label__ = 107;
      break;
    }
   case 106:
    var $440 = __ZNK2JS5Value9toBooleanEv($_idx320_val$0, $_idx320_val$1);
    var $cond10_0 = $440 & 1;
    __label__ = 108;
    break;
   case 107:
    var $443 = __Z17js_ValueToBooleanRKN2JS5ValueE($435);
    var $cond10_0 = ($443 | 0) != 0 & 1;
    __label__ = 108;
    break;
   case 108:
    var $cond10_0;
    HEAP32[$_pre_phi580 >> 2] = $435;
    if ($cond10_0 << 24 >> 24 == 0) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 5;
      __label__ = 17;
      break;
    } else {
      __label__ = 109;
      break;
    }
   case 109:
    var $449 = HEAPU32[$_pre_phi >> 2];
    var $467 = (HEAPU8[$449 + 2 | 0] & 255) << 16 | (HEAPU8[$449 + 1 | 0] & 255) << 24 | HEAPU8[$449 + 4 | 0] & 255 | (HEAPU8[$449 + 3 | 0] & 255) << 8;
    HEAP32[$_pre_phi580 >> 2] = $434;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = $467;
    __label__ = 17;
    break;
   case 110:
    var $469 = HEAPU32[$_pre_phi580 >> 2];
    var $470 = $469 - 8 | 0;
    var $_idx319 = $470 | 0;
    var $st$3$0 = $_idx319 | 0;
    var $_idx319_val$0 = HEAPU32[$st$3$0 >> 2];
    var $st$3$1 = $_idx319 + 4 | 0;
    var $_idx319_val$1 = HEAP32[$st$3$1 >> 2];
    var $471 = __ZNK2JS5Value6isNullEv($_idx319_val$0, $_idx319_val$1);
    if ($471) {
      __label__ = 111;
      break;
    } else {
      __label__ = 112;
      break;
    }
   case 111:
    HEAP32[$_pre_phi580 >> 2] = $470;
    __label__ = 116;
    break;
   case 112:
    var $473 = __ZNK2JS5Value9isBooleanEv($_idx319_val$0, $_idx319_val$1);
    if ($473) {
      __label__ = 113;
      break;
    } else {
      __label__ = 114;
      break;
    }
   case 113:
    var $475 = __ZNK2JS5Value9toBooleanEv($_idx319_val$0, $_idx319_val$1);
    var $cond12_0 = $475 & 1;
    __label__ = 115;
    break;
   case 114:
    var $478 = __Z17js_ValueToBooleanRKN2JS5ValueE($470);
    var $cond12_0 = ($478 | 0) != 0 & 1;
    __label__ = 115;
    break;
   case 115:
    var $cond12_0;
    HEAP32[$_pre_phi580 >> 2] = $470;
    if (($cond12_0 | 0) == 0) {
      __label__ = 116;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 5;
      __label__ = 17;
      break;
    }
   case 116:
    var $483 = HEAPU32[$_pre_phi >> 2];
    var $501 = (HEAPU8[$483 + 2 | 0] & 255) << 16 | (HEAPU8[$483 + 1 | 0] & 255) << 24 | HEAPU8[$483 + 4 | 0] & 255 | (HEAPU8[$483 + 3 | 0] & 255) << 8;
    HEAP32[$_pre_phi580 >> 2] = $469;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = $501;
    __label__ = 17;
    break;
   case 117:
    var $503 = HEAPU32[$_pre_phi580 >> 2];
    var $_idx117 = $503 - 8 | 0;
    var $st$2$0 = $_idx117 | 0;
    var $_idx117_val$0 = HEAPU32[$st$2$0 >> 2];
    var $st$2$1 = $_idx117 + 4 | 0;
    var $_idx117_val$1 = HEAP32[$st$2$1 >> 2];
    var $504 = __ZNK2JS5Value8isObjectEv($_idx117_val$0, $_idx117_val$1);
    if ($504) {
      __label__ = 119;
      break;
    } else {
      __label__ = 118;
      break;
    }
   case 118:
    var $506 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, 27, -1, $_idx117_val$0, $_idx117_val$1, 0, 0);
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 119:
    var $508 = __ZNK2JS5Value8toObjectEv($_idx117_val$0, $_idx117_val$1);
    var $509 = $503 - 16 | 0;
    var $510 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($509, $i_);
    if ($510) {
      __label__ = 120;
      break;
    } else {
      __label__ = 122;
      break;
    }
   case 120:
    var $512 = HEAP32[$i_ >> 2];
    var $513 = _INT_FITS_IN_JSID1825($512);
    if (($513 | 0) == 0) {
      __label__ = 122;
      break;
    } else {
      __label__ = 121;
      break;
    }
   case 121:
    var $516 = _INT_TO_JSID1826($512);
    HEAP32[$id >> 2] = $516;
    var $522 = $516;
    __label__ = 124;
    break;
   case 122:
    var $519 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    var $520 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $508, $509, $id, $519);
    if ($520) {
      __label__ = 123;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 123:
    var $522 = HEAP32[$id >> 2];
    __label__ = 124;
    break;
   case 124:
    var $522;
    var $523 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($508, $cx, $522, $obj2, $prop);
    if (($523 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 125;
      break;
    }
   case 125:
    var $527 = (HEAP32[$prop >> 2] | 0) != 0;
    var $528 = HEAPU32[$_pre_phi >> 2];
    var $529 = $528 + 1 | 0;
    var $532 = (HEAPU8[$529] & 255) - 7 | 0;
    var $534 = HEAPU32[$_pre_phi580 >> 2];
    if ($532 >>> 0 < 2) {
      __label__ = 126;
      break;
    } else {
      __label__ = 128;
      break;
    }
   case 126:
    HEAP32[$_pre_phi580 >> 2] = $534 - 16 | 0;
    if ($527 ^ ($532 | 0) != 0) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 4;
      __label__ = 17;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 127:
    HEAP32[$_pre_phi >> 2] = $529;
    var $546 = (HEAPU8[$528 + 2 | 0] & 255) << 8 | HEAPU8[$528 + 3 | 0] & 255;
    var $548 = $528 + (($546 << 16 >> 16) + 1) | 0;
    HEAP32[$_pre_phi >> 2] = $548;
    var $550 = HEAPU8[$548] & 255;
    if ($546 << 16 >> 16 < 1) {
      var $op_1 = $550;
      __label__ = 34;
      break;
    } else {
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $550;
      __label__ = 18;
      break;
    }
   case 128:
    HEAP32[$_pre_phi580 >> 2] = $534 - 8 | 0;
    var $554 = $534 - 16 | 0;
    __ZN2JS5Value10setBooleanEb($554, $527);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 129:
    var $559 = HEAPU8[HEAP32[$_pre_phi >> 2] + 1 | 0] & 255;
    var $561 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $562 = __Z18js_ValueToIteratorP9JSContextjPN2JS5ValueE($5084, $559, $561);
    if (($562 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 130;
      break;
    }
   case 130:
    if ((HEAP32[HEAP32[$34 >> 2] >> 2] | 0) == 0) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 2;
      __label__ = 17;
      break;
    } else {
      __label__ = 131;
      break;
    }
   case 131:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 2;
    __label__ = 17;
    break;
   case 132:
    var $571 = HEAP32[$_pre_phi580 >> 2];
    var $572 = $571 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $572;
    __ZN2JS5Value7setNullEv($571);
    var $573 = HEAP32[$_pre_phi580 >> 2];
    var $_idx150 = $573 - 16 | 0;
    var $st$6$0 = $_idx150 | 0;
    var $_idx150_val$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $_idx150 + 4 | 0;
    var $_idx150_val$1 = HEAP32[$st$6$1 >> 2];
    var $574 = __ZNK2JS5Value8toObjectEv($_idx150_val$0, $_idx150_val$1);
    var $575 = $573 - 8 | 0;
    var $576 = __ZL12IteratorMoreP9JSContextP8JSObjectPbPN2JS5ValueE($cx, $574, $cond15, $575);
    if ($576) {
      __label__ = 133;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 133:
    if ((HEAP32[HEAP32[$34 >> 2] >> 2] | 0) == 0) {
      __label__ = 135;
      break;
    } else {
      __label__ = 134;
      break;
    }
   case 134:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 135;
    break;
   case 135:
    var $585 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $588 = (HEAP8[$cond15] & 1) << 24 >> 24 != 0;
    __ZN2JS5Value10setBooleanEb($585, $588);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 136:
    var $590 = HEAP32[$_pre_phi580 >> 2];
    var $595 = -(HEAP8[HEAP32[$_pre_phi >> 2] + 1 | 0] << 24 >> 24) | 0;
    var $596 = $590 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $596;
    __ZN2JS5Value7setNullEv($590);
    var $_idx149 = $590 + ($595 << 3) | 0;
    var $st$10$0 = $_idx149 | 0;
    var $_idx149_val$0 = HEAP32[$st$10$0 >> 2];
    var $st$10$1 = $_idx149 + 4 | 0;
    var $_idx149_val$1 = HEAP32[$st$10$1 >> 2];
    var $597 = __ZNK2JS5Value8toObjectEv($_idx149_val$0, $_idx149_val$1);
    var $599 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $600 = __ZL12IteratorNextP9JSContextP8JSObjectPN2JS5ValueE($cx, $597, $599);
    if ($600) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 2;
      __label__ = 17;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 137:
    var $_idx148 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$2$0 = $_idx148 | 0;
    var $_idx148_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx148 + 4 | 0;
    var $_idx148_val$1 = HEAP32[$st$2$1 >> 2];
    var $603 = __ZNK2JS5Value8toObjectEv($_idx148_val$0, $_idx148_val$1);
    var $604 = $603;
    var $605 = __Z16js_CloseIteratorP9JSContextP8JSObject($5084, $604);
    var $606 = ($605 | 0) == 0;
    var $608 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $608;
    if ($606) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    }
   case 138:
    var $610 = HEAP32[$_pre_phi580 >> 2];
    var $611 = $610 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $611;
    var $612 = $610 - 8 | 0;
    var $st$4$0 = $612 | 0;
    var $613$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $612 + 4 | 0;
    var $613$1 = HEAP32[$st$4$1 >> 2];
    var $614 = $610 | 0;
    var $st$9$0 = $614 | 0;
    HEAP32[$st$9$0 >> 2] = $613$0;
    var $st$9$1 = $614 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $613$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 139:
    var $616 = HEAP32[$_pre_phi580 >> 2];
    var $617 = $616 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $617;
    var $618 = $616 - 16 | 0;
    var $st$4$0 = $618 | 0;
    var $619$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $618 + 4 | 0;
    var $619$1 = HEAP32[$st$4$1 >> 2];
    var $620 = $616 | 0;
    var $st$9$0 = $620 | 0;
    HEAP32[$st$9$0 >> 2] = $619$0;
    var $st$9$1 = $620 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $619$1;
    var $621 = HEAP32[$_pre_phi580 >> 2];
    var $622 = $621 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $622;
    var $623 = $616 - 8 | 0;
    var $st$17$0 = $623 | 0;
    var $624$0 = HEAP32[$st$17$0 >> 2];
    var $st$17$1 = $623 + 4 | 0;
    var $624$1 = HEAP32[$st$17$1 >> 2];
    var $625 = $621 | 0;
    var $st$22$0 = $625 | 0;
    HEAP32[$st$22$0 >> 2] = $624$0;
    var $st$22$1 = $625 + 4 | 0;
    HEAP32[$st$22$1 >> 2] = $624$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 140:
    var $627 = HEAP32[$_pre_phi580 >> 2];
    var $628 = $627 - 16 | 0;
    var $629 = $627 - 8 | 0;
    __ZN2JS5Value4swapERS0_($628, $629);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 141:
    var $634 = HEAPU8[HEAP32[$_pre_phi >> 2] + 1 | 0] & 255;
    var $635 = $634 ^ -1;
    var $636 = HEAPU32[$_pre_phi580 >> 2];
    var $_025 = $636 + ($635 << 3) | 0;
    var $st$7$0 = $_025 | 0;
    var $tmp26$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $_025 + 4 | 0;
    var $tmp26$1 = HEAP32[$st$7$1 >> 2];
    var $638 = $636 + ($635 << 3) | 0;
    var $641 = $636 + (-$634 << 3) | 0;
    var $642 = $634 << 3;
    _llvm_memmove_p0i8_p0i8_i32($638, $641, $642, 1, 0);
    var $_027 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$20$0 = $_027 | 0;
    HEAP32[$st$20$0 >> 2] = $tmp26$0;
    var $st$20$1 = $_027 + 4 | 0;
    HEAP32[$st$20$1 >> 2] = $tmp26$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 2;
    __label__ = 17;
    break;
   case 142:
    var $645 = HEAPU32[$_pre_phi >> 2];
    var $655 = HEAP32[$atoms_1 + (((HEAPU8[$645 + 1 | 0] & 255) << 8 | HEAPU8[$645 + 2 | 0] & 255) << 2) >> 2];
    var $regs_idx58_val = HEAP32[$regs_idx73 >> 2];
    var $656 = __ZNK2js9FrameRegs2fpEv($regs_idx58_val);
    var $657 = __ZN2js10StackFrame6varObjEv($656);
    var $659 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $660 = __ZL12ATOM_TO_JSIDP6JSAtom1798($655);
    var $661 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($657, $cx, $660, $659, 10, 12, 7);
    if (($661 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 143:
    var $664 = HEAP32[$_pre_phi >> 2];
    if (HEAP8[$664 + 3 | 0] << 24 >> 24 == 81) {
      __label__ = 144;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    }
   case 144:
    var $670 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $670;
    var $671 = $664 + 4 | 0;
    HEAP32[$_pre_phi >> 2] = $671;
    var $script_1 = $script_1;
    var $pcCounts_1 = $pcCounts_1;
    var $argv_1 = $argv_1;
    var $atoms_1 = $atoms_1;
    var $op_0 = HEAPU8[$671] & 255;
    __label__ = 18;
    break;
   case 145:
    var $675 = HEAPU32[$_pre_phi580 >> 2];
    var $676 = $675 - 24 | 0;
    var $677 = $675 - 16 | 0;
    var $_idx116 = $677 | 0;
    var $st$4$0 = $_idx116 | 0;
    var $_idx116_val$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $_idx116 + 4 | 0;
    var $_idx116_val$1 = HEAP32[$st$4$1 >> 2];
    var $678 = __ZNK2JS5Value8isObjectEv($_idx116_val$0, $_idx116_val$1);
    if ($678) {
      __label__ = 146;
      break;
    } else {
      __label__ = 147;
      break;
    }
   case 146:
    var $680 = __ZNK2JS5Value8toObjectEv($_idx116_val$0, $_idx116_val$1);
    var $obj22_0 = $680;
    var $687 = $675;
    __label__ = 149;
    break;
   case 147:
    var $682 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5080, $677);
    var $683 = $682;
    if (($682 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 148;
      break;
    }
   case 148:
    __ZN2JS5Value9setObjectER8JSObject($677, $683);
    var $obj22_0 = $683;
    var $687 = HEAP32[$_pre_phi580 >> 2];
    __label__ = 149;
    break;
   case 149:
    var $687;
    var $obj22_0;
    var $688 = $687 - 8 | 0;
    var $689 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($688, $i_25);
    if ($689) {
      __label__ = 150;
      break;
    } else {
      __label__ = 152;
      break;
    }
   case 150:
    var $691 = HEAP32[$i_25 >> 2];
    var $692 = _INT_FITS_IN_JSID1825($691);
    if (($692 | 0) == 0) {
      __label__ = 152;
      break;
    } else {
      __label__ = 151;
      break;
    }
   case 151:
    var $695 = _INT_TO_JSID1826($691);
    HEAP32[$id23 >> 2] = $695;
    var $701 = $695;
    __label__ = 154;
    break;
   case 152:
    var $698 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $699 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $obj22_0, $688, $id23, $698);
    if ($699) {
      __label__ = 153;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 153:
    var $701 = HEAP32[$id23 >> 2];
    __label__ = 154;
    break;
   case 154:
    var $701;
    var $702 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj22_0, $cx, $701, $676, 10, 12, 7);
    if (($702 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 155;
      break;
    }
   case 155:
    var $706 = HEAP32[$_pre_phi580 >> 2] - 24 | 0;
    HEAP32[$_pre_phi580 >> 2] = $706;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 156:
    var $708 = HEAP32[$_pre_phi580 >> 2];
    var $709 = $708 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $709;
    var $regs_idx57_val = HEAP32[$regs_idx73 >> 2];
    var $710 = __ZNK2js9FrameRegs2fpEv($regs_idx57_val);
    var $711 = __ZNK2js10StackFrame10scopeChainEv($710);
    var $712 = $711;
    var $713 = __ZNK8JSObject9getGlobalEv($712);
    var $714 = $713;
    __ZN2JS5Value9setObjectER8JSObject($708, $714);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 157:
    var $regs_idx56_val = HEAP32[$regs_idx73 >> 2];
    var $716 = __ZNK2js9FrameRegs2fpEv($regs_idx56_val);
    var $717 = __ZNK2js10StackFrame10scopeChainEv($716);
    HEAP32[$obj26 >> 2] = $717;
    var $_idx187_val = HEAP32[$717 + 20 >> 2];
    var $718 = __ZNK8JSObject9getParentEv($_idx187_val);
    if (($718 | 0) == 0) {
      var $735 = $717;
      __label__ = 161;
      break;
    } else {
      __label__ = 158;
      break;
    }
   case 158:
    var $722 = HEAP32[$22 >> 2] + 144336 | 0;
    var $723 = HEAP32[$_pre_phi >> 2];
    __ZN2js13PropertyCache4testEP9JSContextPhRP8JSObjectS6_RPNS_18PropertyCacheEntryERP6JSAtom($722, $cx, $723, $obj26, $obj227, $entry, $atom28);
    var $724 = HEAP32[$atom28 >> 2];
    if (($724 | 0) == 0) {
      __label__ = 159;
      break;
    } else {
      __label__ = 160;
      break;
    }
   case 159:
    var $735 = HEAP32[$obj26 >> 2];
    __label__ = 161;
    break;
   case 160:
    var $727 = __ZL12ATOM_TO_JSIDP6JSAtom1798($724);
    var $regs_idx55_val = HEAP32[$regs_idx73 >> 2];
    var $728 = __ZNK2js9FrameRegs2fpEv($regs_idx55_val);
    var $729 = __ZNK2js10StackFrame10scopeChainEv($728);
    var $730 = $729;
    var $731 = __Z21js_FindIdentifierBaseP9JSContextP8JSObjecti($5080, $730, $727);
    var $732 = $731;
    HEAP32[$obj26 >> 2] = $732;
    if (($731 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $735 = $732;
      __label__ = 161;
      break;
    }
   case 161:
    var $735;
    var $736 = HEAP32[$_pre_phi580 >> 2];
    var $737 = $736 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $737;
    __ZN2JS5Value9setObjectER8JSObject($736, $735);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 162:
    var $regs_idx54_val = HEAP32[$regs_idx73 >> 2];
    var $739 = __ZNK2js9FrameRegs2fpEv($regs_idx54_val);
    var $_idx168_val = HEAP32[$739 + 40 >> 2];
    var $740 = __ZNK2js10StackFrame8imacropcEv($_idx168_val);
    var $script_1 = $script_1;
    var $pcCounts_1 = $pcCounts_1;
    var $argv_1 = $argv_1;
    var $atoms_1 = $atoms_1;
    var $op_0 = HEAPU8[$740] & 255;
    __label__ = 18;
    break;
   case 163:
    var $745 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    var $746 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $745, $i30);
    if ($746) {
      __label__ = 164;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 164:
    var $749 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $750 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $749, $j);
    if ($750) {
      __label__ = 165;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 165:
    var $754 = HEAP32[$j >> 2] | HEAP32[$i30 >> 2];
    HEAP32[$i30 >> 2] = $754;
    var $755 = HEAP32[$_pre_phi580 >> 2];
    var $756 = $755 - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $756;
    var $757 = $755 - 16 | 0;
    __ZN2JS5Value8setInt32Ei($757, $754);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 166:
    var $760 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    var $761 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $760, $i31);
    if ($761) {
      __label__ = 167;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 167:
    var $764 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $765 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $764, $j32);
    if ($765) {
      __label__ = 168;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 168:
    var $769 = HEAP32[$j32 >> 2] ^ HEAP32[$i31 >> 2];
    HEAP32[$i31 >> 2] = $769;
    var $770 = HEAP32[$_pre_phi580 >> 2];
    var $771 = $770 - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $771;
    var $772 = $770 - 16 | 0;
    __ZN2JS5Value8setInt32Ei($772, $769);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 169:
    var $775 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    var $776 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $775, $i33);
    if ($776) {
      __label__ = 170;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 170:
    var $779 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $780 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $779, $j34);
    if ($780) {
      __label__ = 171;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 171:
    var $784 = HEAP32[$j34 >> 2] & HEAP32[$i33 >> 2];
    HEAP32[$i33 >> 2] = $784;
    var $785 = HEAP32[$_pre_phi580 >> 2];
    var $786 = $785 - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $786;
    var $787 = $785 - 16 | 0;
    __ZN2JS5Value8setInt32Ei($787, $784);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 172:
    var $789 = HEAP32[$_pre_phi580 >> 2];
    var $790 = $789 - 8 | 0;
    var $st$2$0 = $790 | 0;
    var $791$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $790 + 4 | 0;
    var $791$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5073 | 0;
    HEAP32[$st$6$0 >> 2] = $791$0;
    var $st$6$1 = $5073 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $791$1;
    var $792 = $789 - 16 | 0;
    var $st$11$0 = $792 | 0;
    var $793$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $792 + 4 | 0;
    var $793$1 = HEAP32[$st$11$1 >> 2];
    var $st$15$0 = $5074 | 0;
    HEAP32[$st$15$0 >> 2] = $793$0;
    var $st$15$1 = $5074 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $793$1;
    var $794 = __ZN2js12LooselyEqualEP9JSContextRKN2JS5ValueES5_Pi($cx, $lval36, $rval35, $cond37);
    if ($794) {
      __label__ = 173;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 173:
    var $797 = (HEAP32[$cond37 >> 2] | 0) == 1;
    var $798 = $797 & 1;
    HEAP32[$cond37 >> 2] = $798;
    var $799 = HEAPU32[$_pre_phi >> 2];
    var $800 = $799 + 1 | 0;
    var $803 = (HEAPU8[$800] & 255) - 7 | 0;
    var $805 = HEAPU32[$_pre_phi580 >> 2];
    if ($803 >>> 0 < 2) {
      __label__ = 174;
      break;
    } else {
      __label__ = 176;
      break;
    }
   case 174:
    HEAP32[$_pre_phi580 >> 2] = $805 - 16 | 0;
    if ($797 ^ ($803 | 0) != 0) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 4;
      __label__ = 17;
      break;
    } else {
      __label__ = 175;
      break;
    }
   case 175:
    HEAP32[$_pre_phi >> 2] = $800;
    var $817 = (HEAPU8[$799 + 2 | 0] & 255) << 8 | HEAPU8[$799 + 3 | 0] & 255;
    var $819 = $799 + (($817 << 16 >> 16) + 1) | 0;
    HEAP32[$_pre_phi >> 2] = $819;
    var $821 = HEAPU8[$819] & 255;
    if ($817 << 16 >> 16 < 1) {
      var $op_1 = $821;
      __label__ = 34;
      break;
    } else {
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $821;
      __label__ = 18;
      break;
    }
   case 176:
    HEAP32[$_pre_phi580 >> 2] = $805 - 8 | 0;
    var $825 = $805 - 16 | 0;
    __ZN2JS5Value10setBooleanEb($825, $797);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 177:
    var $827 = HEAPU32[$_pre_phi580 >> 2];
    var $828 = $827 - 8 | 0;
    var $st$2$0 = $828 | 0;
    var $829$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $828 + 4 | 0;
    var $829$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5075 | 0;
    HEAP32[$st$6$0 >> 2] = $829$0;
    var $st$6$1 = $5075 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $829$1;
    var $830 = $827 - 16 | 0;
    var $st$11$0 = $830 | 0;
    var $831$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $830 + 4 | 0;
    var $831$1 = HEAP32[$st$11$1 >> 2];
    var $st$15$0 = $5076 | 0;
    HEAP32[$st$15$0 >> 2] = $831$0;
    var $st$15$1 = $5076 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $831$1;
    var $832 = __ZN2js12LooselyEqualEP9JSContextRKN2JS5ValueES5_Pi($cx, $lval40, $rval39, $cond41);
    if ($832) {
      __label__ = 178;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 178:
    var $835 = (HEAP32[$cond41 >> 2] | 0) != 1;
    var $836 = $835 & 1;
    HEAP32[$cond41 >> 2] = $836;
    var $837 = HEAPU32[$_pre_phi >> 2];
    var $838 = $837 + 1 | 0;
    var $841 = (HEAPU8[$838] & 255) - 7 | 0;
    var $843 = HEAPU32[$_pre_phi580 >> 2];
    if ($841 >>> 0 < 2) {
      __label__ = 179;
      break;
    } else {
      __label__ = 181;
      break;
    }
   case 179:
    HEAP32[$_pre_phi580 >> 2] = $843 - 16 | 0;
    if ($835 ^ ($841 | 0) != 0) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 4;
      __label__ = 17;
      break;
    } else {
      __label__ = 180;
      break;
    }
   case 180:
    HEAP32[$_pre_phi >> 2] = $838;
    var $855 = (HEAPU8[$837 + 2 | 0] & 255) << 8 | HEAPU8[$837 + 3 | 0] & 255;
    var $857 = $837 + (($855 << 16 >> 16) + 1) | 0;
    HEAP32[$_pre_phi >> 2] = $857;
    var $859 = HEAPU8[$857] & 255;
    if ($855 << 16 >> 16 < 1) {
      var $op_1 = $859;
      __label__ = 34;
      break;
    } else {
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $859;
      __label__ = 18;
      break;
    }
   case 181:
    HEAP32[$_pre_phi580 >> 2] = $843 - 8 | 0;
    var $863 = $843 - 16 | 0;
    __ZN2JS5Value10setBooleanEb($863, $835);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 182:
    var $865 = HEAP32[$_pre_phi580 >> 2];
    var $_idx403 = $865 - 16 | 0;
    var $st$2$0 = $_idx403 | 0;
    var $_idx403_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx403 + 4 | 0;
    var $_idx403_val$1 = HEAP32[$st$2$1 >> 2];
    var $_idx404 = $865 - 8 | 0;
    var $st$7$0 = $_idx404 | 0;
    var $_idx404_val$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $_idx404 + 4 | 0;
    var $_idx404_val$1 = HEAP32[$st$7$1 >> 2];
    var $866 = __ZN2js13StrictlyEqualEP9JSContextRKN2JS5ValueES5_Pi($cx, $_idx403_val$0, $_idx403_val$1, $_idx404_val$0, $_idx404_val$1, $equal);
    if ($866) {
      __label__ = 183;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 183:
    var $869 = (HEAP32[$equal >> 2] | 0) == 1;
    var $870 = HEAP32[$_pre_phi580 >> 2];
    var $871 = $870 - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $871;
    var $872 = $870 - 16 | 0;
    __ZN2JS5Value10setBooleanEb($872, $869);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 184:
    var $874 = HEAP32[$_pre_phi580 >> 2];
    var $_idx401 = $874 - 16 | 0;
    var $st$2$0 = $_idx401 | 0;
    var $_idx401_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx401 + 4 | 0;
    var $_idx401_val$1 = HEAP32[$st$2$1 >> 2];
    var $_idx402 = $874 - 8 | 0;
    var $st$7$0 = $_idx402 | 0;
    var $_idx402_val$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $_idx402 + 4 | 0;
    var $_idx402_val$1 = HEAP32[$st$7$1 >> 2];
    var $875 = __ZN2js13StrictlyEqualEP9JSContextRKN2JS5ValueES5_Pi($cx, $_idx401_val$0, $_idx401_val$1, $_idx402_val$0, $_idx402_val$1, $equal49);
    if ($875) {
      __label__ = 185;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 185:
    var $878 = (HEAP32[$equal49 >> 2] | 0) != 1;
    var $879 = HEAP32[$_pre_phi580 >> 2];
    var $880 = $879 - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $880;
    var $881 = $879 - 16 | 0;
    __ZN2JS5Value10setBooleanEb($881, $878);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 186:
    var $883 = HEAP32[$_pre_phi580 >> 2];
    var $_idx399 = $883 - 16 | 0;
    var $st$2$0 = $_idx399 | 0;
    var $_idx399_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx399 + 4 | 0;
    var $_idx399_val$1 = HEAP32[$st$2$1 >> 2];
    var $_idx400 = $883 - 8 | 0;
    var $st$7$0 = $_idx400 | 0;
    var $_idx400_val$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $_idx400 + 4 | 0;
    var $_idx400_val$1 = HEAP32[$st$7$1 >> 2];
    var $884 = __ZN2js13StrictlyEqualEP9JSContextRKN2JS5ValueES5_Pi($cx, $_idx399_val$0, $_idx399_val$1, $_idx400_val$0, $_idx400_val$1, $equal53);
    if ($884) {
      __label__ = 187;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 187:
    var $887 = (HEAP32[$equal53 >> 2] | 0) == 1;
    var $888 = HEAP32[$_pre_phi580 >> 2];
    var $889 = $888 - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $889;
    if ($887) {
      __label__ = 188;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    }
   case 188:
    var $891 = $888 - 16 | 0;
    HEAP32[$_pre_phi580 >> 2] = $891;
    var $892 = HEAPU32[$_pre_phi >> 2];
    var $900 = (HEAPU8[$892 + 1 | 0] & 255) << 8 | HEAPU8[$892 + 2 | 0] & 255;
    var $902 = $892 + ($900 << 16 >> 16) | 0;
    HEAP32[$_pre_phi >> 2] = $902;
    var $904 = HEAPU8[$902] & 255;
    if ($900 << 16 >> 16 < 1) {
      var $op_1 = $904;
      __label__ = 34;
      break;
    } else {
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $904;
      __label__ = 18;
      break;
    }
   case 189:
    var $907 = HEAPU32[$_pre_phi580 >> 2];
    var $_idx397 = $907 - 16 | 0;
    var $st$2$0 = $_idx397 | 0;
    var $_idx397_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx397 + 4 | 0;
    var $_idx397_val$1 = HEAP32[$st$2$1 >> 2];
    var $_idx398 = $907 - 8 | 0;
    var $st$7$0 = $_idx398 | 0;
    var $_idx398_val$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $_idx398 + 4 | 0;
    var $_idx398_val$1 = HEAP32[$st$7$1 >> 2];
    var $908 = __ZN2js13StrictlyEqualEP9JSContextRKN2JS5ValueES5_Pi($cx, $_idx397_val$0, $_idx397_val$1, $_idx398_val$0, $_idx398_val$1, $equal57);
    if ($908) {
      __label__ = 190;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 190:
    var $911 = (HEAP32[$equal57 >> 2] | 0) == 1;
    var $912 = HEAP32[$_pre_phi580 >> 2];
    var $913 = $912 - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $913;
    if ($911) {
      __label__ = 191;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 5;
      __label__ = 17;
      break;
    }
   case 191:
    var $915 = $912 - 16 | 0;
    HEAP32[$_pre_phi580 >> 2] = $915;
    var $916 = HEAPU32[$_pre_phi >> 2];
    var $934 = (HEAPU8[$916 + 2 | 0] & 255) << 16 | (HEAPU8[$916 + 1 | 0] & 255) << 24 | HEAPU8[$916 + 4 | 0] & 255 | (HEAPU8[$916 + 3 | 0] & 255) << 8;
    var $935 = $916 + $934 | 0;
    HEAP32[$_pre_phi >> 2] = $935;
    var $937 = HEAPU8[$935] & 255;
    if (($934 | 0) < 1) {
      var $op_1 = $937;
      __label__ = 34;
      break;
    } else {
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $937;
      __label__ = 18;
      break;
    }
   case 192:
    var $940 = HEAP32[$_pre_phi580 >> 2];
    var $941 = $940 - 8 | 0;
    var $942 = $940 - 16 | 0;
    var $_idx297 = $942 | 0;
    var $st$4$0 = $_idx297 | 0;
    var $_idx297_val$0 = HEAPU32[$st$4$0 >> 2];
    var $st$4$1 = $_idx297 + 4 | 0;
    var $_idx297_val$1 = HEAPU32[$st$4$1 >> 2];
    var $943 = __ZNK2JS5Value7isInt32Ev($_idx297_val$0, $_idx297_val$1);
    if ($943) {
      __label__ = 193;
      break;
    } else {
      __label__ = 195;
      break;
    }
   case 193:
    var $_idx296 = $941 | 0;
    var $st$1$0 = $_idx296 | 0;
    var $_idx296_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx296 + 4 | 0;
    var $_idx296_val$1 = HEAP32[$st$1$1 >> 2];
    var $945 = __ZNK2JS5Value7isInt32Ev($_idx296_val$0, $_idx296_val$1);
    if ($945) {
      __label__ = 194;
      break;
    } else {
      __label__ = 195;
      break;
    }
   case 194:
    var $947 = __ZNK2JS5Value7toInt32Ev($_idx297_val$0, $_idx297_val$1);
    var $948 = __ZNK2JS5Value7toInt32Ev($_idx296_val$0, $_idx296_val$1);
    var $cond60_0 = ($947 | 0) < ($948 | 0) & 1;
    __label__ = 204;
    break;
   case 195:
    var $952 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE1830($cx, $942);
    if ($952) {
      __label__ = 196;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 196:
    var $954 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE1830($cx, $941);
    if ($954) {
      __label__ = 197;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 197:
    var $st$0$0 = $_idx297 | 0;
    var $_idx274_val$0 = HEAPU32[$st$0$0 >> 2];
    var $st$0$1 = $_idx297 + 4 | 0;
    var $_idx274_val$1 = HEAPU32[$st$0$1 >> 2];
    var $956 = __ZNK2JS5Value8isStringEv($_idx274_val$0, $_idx274_val$1);
    if ($956) {
      __label__ = 198;
      break;
    } else {
      __label__ = 201;
      break;
    }
   case 198:
    var $_idx273 = $941 | 0;
    var $st$1$0 = $_idx273 | 0;
    var $_idx273_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx273 + 4 | 0;
    var $_idx273_val$1 = HEAP32[$st$1$1 >> 2];
    var $958 = __ZNK2JS5Value8isStringEv($_idx273_val$0, $_idx273_val$1);
    if ($958) {
      __label__ = 199;
      break;
    } else {
      __label__ = 201;
      break;
    }
   case 199:
    var $960 = __ZNK2JS5Value8toStringEv($_idx274_val$0, $_idx274_val$1);
    var $961 = __ZNK2JS5Value8toStringEv($_idx273_val$0, $_idx273_val$1);
    var $962 = __ZN2js14CompareStringsEP9JSContextP8JSStringS3_Pi($5077, $960, $961, $result);
    if ($962) {
      __label__ = 200;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 200:
    var $cond60_0 = HEAPU32[$result >> 2] >>> 31 & 255;
    __label__ = 204;
    break;
   case 201:
    var $967 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $942, $l61);
    if ($967) {
      __label__ = 202;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 202:
    var $969 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $941, $r62);
    if ($969) {
      __label__ = 203;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 203:
    var $971 = (tempDoubleI32[0] = HEAP32[$l61 >> 2], tempDoubleI32[1] = HEAP32[$l61 + 4 >> 2], tempDoubleF64[0]);
    var $972 = (tempDoubleI32[0] = HEAP32[$r62 >> 2], tempDoubleI32[1] = HEAP32[$r62 + 4 >> 2], tempDoubleF64[0]);
    var $cond60_0 = $971 < $972 & 1;
    __label__ = 204;
    break;
   case 204:
    var $cond60_0;
    var $976 = HEAPU32[$_pre_phi >> 2];
    var $977 = $976 + 1 | 0;
    var $980 = (HEAPU8[$977] & 255) - 7 | 0;
    var $983 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    if ($980 >>> 0 < 2) {
      __label__ = 205;
      break;
    } else {
      __label__ = 207;
      break;
    }
   case 205:
    HEAP32[$_pre_phi580 >> 2] = $983;
    if (($cond60_0 & 255 | 0) == (($980 | 0) != 0 & 1 | 0)) {
      __label__ = 206;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 4;
      __label__ = 17;
      break;
    }
   case 206:
    HEAP32[$_pre_phi >> 2] = $977;
    var $997 = (HEAPU8[$976 + 2 | 0] & 255) << 8 | HEAPU8[$976 + 3 | 0] & 255;
    var $999 = $976 + (($997 << 16 >> 16) + 1) | 0;
    HEAP32[$_pre_phi >> 2] = $999;
    var $1001 = HEAPU8[$999] & 255;
    if ($997 << 16 >> 16 < 1) {
      var $op_1 = $1001;
      __label__ = 34;
      break;
    } else {
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $1001;
      __label__ = 18;
      break;
    }
   case 207:
    __ZN2JS5Value10setBooleanEb($983, $cond60_0 << 24 >> 24 != 0);
    var $1006 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $1006;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 208:
    var $1008 = HEAP32[$_pre_phi580 >> 2];
    var $1009 = $1008 - 8 | 0;
    var $1010 = $1008 - 16 | 0;
    var $_idx295 = $1010 | 0;
    var $st$4$0 = $_idx295 | 0;
    var $_idx295_val$0 = HEAPU32[$st$4$0 >> 2];
    var $st$4$1 = $_idx295 + 4 | 0;
    var $_idx295_val$1 = HEAP32[$st$4$1 >> 2];
    var $1011 = __ZNK2JS5Value7isInt32Ev($_idx295_val$0, $_idx295_val$1);
    if ($1011) {
      __label__ = 209;
      break;
    } else {
      __label__ = 211;
      break;
    }
   case 209:
    var $_idx294 = $1009 | 0;
    var $st$1$0 = $_idx294 | 0;
    var $_idx294_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx294 + 4 | 0;
    var $_idx294_val$1 = HEAP32[$st$1$1 >> 2];
    var $1013 = __ZNK2JS5Value7isInt32Ev($_idx294_val$0, $_idx294_val$1);
    if ($1013) {
      __label__ = 210;
      break;
    } else {
      __label__ = 211;
      break;
    }
   case 210:
    var $1015 = __ZNK2JS5Value7toInt32Ev($_idx295_val$0, $_idx295_val$1);
    var $1016 = __ZNK2JS5Value7toInt32Ev($_idx294_val$0, $_idx294_val$1);
    var $cond66_0 = ($1015 | 0) <= ($1016 | 0) & 1;
    __label__ = 220;
    break;
   case 211:
    var $1020 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE1830($cx, $1010);
    if ($1020) {
      __label__ = 212;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 212:
    var $1022 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE1830($cx, $1009);
    if ($1022) {
      __label__ = 213;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 213:
    var $st$0$0 = $_idx295 | 0;
    var $_idx272_val$0 = HEAPU32[$st$0$0 >> 2];
    var $st$0$1 = $_idx295 + 4 | 0;
    var $_idx272_val$1 = HEAPU32[$st$0$1 >> 2];
    var $1024 = __ZNK2JS5Value8isStringEv($_idx272_val$0, $_idx272_val$1);
    if ($1024) {
      __label__ = 214;
      break;
    } else {
      __label__ = 217;
      break;
    }
   case 214:
    var $_idx271 = $1009 | 0;
    var $st$1$0 = $_idx271 | 0;
    var $_idx271_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx271 + 4 | 0;
    var $_idx271_val$1 = HEAP32[$st$1$1 >> 2];
    var $1026 = __ZNK2JS5Value8isStringEv($_idx271_val$0, $_idx271_val$1);
    if ($1026) {
      __label__ = 215;
      break;
    } else {
      __label__ = 217;
      break;
    }
   case 215:
    var $1028 = __ZNK2JS5Value8toStringEv($_idx272_val$0, $_idx272_val$1);
    var $1029 = __ZNK2JS5Value8toStringEv($_idx271_val$0, $_idx271_val$1);
    var $1030 = __ZN2js14CompareStringsEP9JSContextP8JSStringS3_Pi($5077, $1028, $1029, $result69);
    if ($1030) {
      __label__ = 216;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 216:
    var $cond66_0 = (HEAP32[$result69 >> 2] | 0) < 1 & 1;
    __label__ = 220;
    break;
   case 217:
    var $1036 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $1010, $l70);
    if ($1036) {
      __label__ = 218;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 218:
    var $1038 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $1009, $r71);
    if ($1038) {
      __label__ = 219;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 219:
    var $1040 = (tempDoubleI32[0] = HEAP32[$l70 >> 2], tempDoubleI32[1] = HEAP32[$l70 + 4 >> 2], tempDoubleF64[0]);
    var $1041 = (tempDoubleI32[0] = HEAP32[$r71 >> 2], tempDoubleI32[1] = HEAP32[$r71 + 4 >> 2], tempDoubleF64[0]);
    var $cond66_0 = $1040 <= $1041 & 1;
    __label__ = 220;
    break;
   case 220:
    var $cond66_0;
    var $1045 = HEAPU32[$_pre_phi >> 2];
    var $1046 = $1045 + 1 | 0;
    var $1049 = (HEAPU8[$1046] & 255) - 7 | 0;
    var $1052 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    if ($1049 >>> 0 < 2) {
      __label__ = 221;
      break;
    } else {
      __label__ = 223;
      break;
    }
   case 221:
    HEAP32[$_pre_phi580 >> 2] = $1052;
    if (($cond66_0 & 255 | 0) == (($1049 | 0) != 0 & 1 | 0)) {
      __label__ = 222;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 4;
      __label__ = 17;
      break;
    }
   case 222:
    HEAP32[$_pre_phi >> 2] = $1046;
    var $1066 = (HEAPU8[$1045 + 2 | 0] & 255) << 8 | HEAPU8[$1045 + 3 | 0] & 255;
    var $1068 = $1045 + (($1066 << 16 >> 16) + 1) | 0;
    HEAP32[$_pre_phi >> 2] = $1068;
    var $1070 = HEAPU8[$1068] & 255;
    if ($1066 << 16 >> 16 < 1) {
      var $op_1 = $1070;
      __label__ = 34;
      break;
    } else {
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $1070;
      __label__ = 18;
      break;
    }
   case 223:
    __ZN2JS5Value10setBooleanEb($1052, $cond66_0 << 24 >> 24 != 0);
    var $1075 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $1075;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 224:
    var $1077 = HEAP32[$_pre_phi580 >> 2];
    var $1078 = $1077 - 8 | 0;
    var $1079 = $1077 - 16 | 0;
    var $_idx293 = $1079 | 0;
    var $st$4$0 = $_idx293 | 0;
    var $_idx293_val$0 = HEAPU32[$st$4$0 >> 2];
    var $st$4$1 = $_idx293 + 4 | 0;
    var $_idx293_val$1 = HEAP32[$st$4$1 >> 2];
    var $1080 = __ZNK2JS5Value7isInt32Ev($_idx293_val$0, $_idx293_val$1);
    if ($1080) {
      __label__ = 225;
      break;
    } else {
      __label__ = 227;
      break;
    }
   case 225:
    var $_idx292 = $1078 | 0;
    var $st$1$0 = $_idx292 | 0;
    var $_idx292_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx292 + 4 | 0;
    var $_idx292_val$1 = HEAP32[$st$1$1 >> 2];
    var $1082 = __ZNK2JS5Value7isInt32Ev($_idx292_val$0, $_idx292_val$1);
    if ($1082) {
      __label__ = 226;
      break;
    } else {
      __label__ = 227;
      break;
    }
   case 226:
    var $1084 = __ZNK2JS5Value7toInt32Ev($_idx293_val$0, $_idx293_val$1);
    var $1085 = __ZNK2JS5Value7toInt32Ev($_idx292_val$0, $_idx292_val$1);
    var $cond75_0 = ($1084 | 0) > ($1085 | 0) & 1;
    __label__ = 236;
    break;
   case 227:
    var $1089 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE1830($cx, $1079);
    if ($1089) {
      __label__ = 228;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 228:
    var $1091 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE1830($cx, $1078);
    if ($1091) {
      __label__ = 229;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 229:
    var $st$0$0 = $_idx293 | 0;
    var $_idx270_val$0 = HEAPU32[$st$0$0 >> 2];
    var $st$0$1 = $_idx293 + 4 | 0;
    var $_idx270_val$1 = HEAPU32[$st$0$1 >> 2];
    var $1093 = __ZNK2JS5Value8isStringEv($_idx270_val$0, $_idx270_val$1);
    if ($1093) {
      __label__ = 230;
      break;
    } else {
      __label__ = 233;
      break;
    }
   case 230:
    var $_idx269 = $1078 | 0;
    var $st$1$0 = $_idx269 | 0;
    var $_idx269_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx269 + 4 | 0;
    var $_idx269_val$1 = HEAP32[$st$1$1 >> 2];
    var $1095 = __ZNK2JS5Value8isStringEv($_idx269_val$0, $_idx269_val$1);
    if ($1095) {
      __label__ = 231;
      break;
    } else {
      __label__ = 233;
      break;
    }
   case 231:
    var $1097 = __ZNK2JS5Value8toStringEv($_idx270_val$0, $_idx270_val$1);
    var $1098 = __ZNK2JS5Value8toStringEv($_idx269_val$0, $_idx269_val$1);
    var $1099 = __ZN2js14CompareStringsEP9JSContextP8JSStringS3_Pi($5077, $1097, $1098, $result78);
    if ($1099) {
      __label__ = 232;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 232:
    var $cond75_0 = (HEAP32[$result78 >> 2] | 0) > 0 & 1;
    __label__ = 236;
    break;
   case 233:
    var $1105 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $1079, $l79);
    if ($1105) {
      __label__ = 234;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 234:
    var $1107 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $1078, $r80);
    if ($1107) {
      __label__ = 235;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 235:
    var $1109 = (tempDoubleI32[0] = HEAP32[$l79 >> 2], tempDoubleI32[1] = HEAP32[$l79 + 4 >> 2], tempDoubleF64[0]);
    var $1110 = (tempDoubleI32[0] = HEAP32[$r80 >> 2], tempDoubleI32[1] = HEAP32[$r80 + 4 >> 2], tempDoubleF64[0]);
    var $cond75_0 = $1109 > $1110 & 1;
    __label__ = 236;
    break;
   case 236:
    var $cond75_0;
    var $1114 = HEAPU32[$_pre_phi >> 2];
    var $1115 = $1114 + 1 | 0;
    var $1118 = (HEAPU8[$1115] & 255) - 7 | 0;
    var $1121 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    if ($1118 >>> 0 < 2) {
      __label__ = 237;
      break;
    } else {
      __label__ = 239;
      break;
    }
   case 237:
    HEAP32[$_pre_phi580 >> 2] = $1121;
    if (($cond75_0 & 255 | 0) == (($1118 | 0) != 0 & 1 | 0)) {
      __label__ = 238;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 4;
      __label__ = 17;
      break;
    }
   case 238:
    HEAP32[$_pre_phi >> 2] = $1115;
    var $1135 = (HEAPU8[$1114 + 2 | 0] & 255) << 8 | HEAPU8[$1114 + 3 | 0] & 255;
    var $1137 = $1114 + (($1135 << 16 >> 16) + 1) | 0;
    HEAP32[$_pre_phi >> 2] = $1137;
    var $1139 = HEAPU8[$1137] & 255;
    if ($1135 << 16 >> 16 < 1) {
      var $op_1 = $1139;
      __label__ = 34;
      break;
    } else {
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $1139;
      __label__ = 18;
      break;
    }
   case 239:
    __ZN2JS5Value10setBooleanEb($1121, $cond75_0 << 24 >> 24 != 0);
    var $1144 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $1144;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 240:
    var $1146 = HEAP32[$_pre_phi580 >> 2];
    var $1147 = $1146 - 8 | 0;
    var $1148 = $1146 - 16 | 0;
    var $_idx291 = $1148 | 0;
    var $st$4$0 = $_idx291 | 0;
    var $_idx291_val$0 = HEAPU32[$st$4$0 >> 2];
    var $st$4$1 = $_idx291 + 4 | 0;
    var $_idx291_val$1 = HEAP32[$st$4$1 >> 2];
    var $1149 = __ZNK2JS5Value7isInt32Ev($_idx291_val$0, $_idx291_val$1);
    if ($1149) {
      __label__ = 241;
      break;
    } else {
      __label__ = 243;
      break;
    }
   case 241:
    var $_idx290 = $1147 | 0;
    var $st$1$0 = $_idx290 | 0;
    var $_idx290_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx290 + 4 | 0;
    var $_idx290_val$1 = HEAP32[$st$1$1 >> 2];
    var $1151 = __ZNK2JS5Value7isInt32Ev($_idx290_val$0, $_idx290_val$1);
    if ($1151) {
      __label__ = 242;
      break;
    } else {
      __label__ = 243;
      break;
    }
   case 242:
    var $1153 = __ZNK2JS5Value7toInt32Ev($_idx291_val$0, $_idx291_val$1);
    var $1154 = __ZNK2JS5Value7toInt32Ev($_idx290_val$0, $_idx290_val$1);
    var $cond84_0 = ($1153 | 0) >= ($1154 | 0) & 1;
    __label__ = 252;
    break;
   case 243:
    var $1158 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE1830($cx, $1148);
    if ($1158) {
      __label__ = 244;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 244:
    var $1160 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE1830($cx, $1147);
    if ($1160) {
      __label__ = 245;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 245:
    var $st$0$0 = $_idx291 | 0;
    var $_idx268_val$0 = HEAPU32[$st$0$0 >> 2];
    var $st$0$1 = $_idx291 + 4 | 0;
    var $_idx268_val$1 = HEAPU32[$st$0$1 >> 2];
    var $1162 = __ZNK2JS5Value8isStringEv($_idx268_val$0, $_idx268_val$1);
    if ($1162) {
      __label__ = 246;
      break;
    } else {
      __label__ = 249;
      break;
    }
   case 246:
    var $_idx267 = $1147 | 0;
    var $st$1$0 = $_idx267 | 0;
    var $_idx267_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx267 + 4 | 0;
    var $_idx267_val$1 = HEAP32[$st$1$1 >> 2];
    var $1164 = __ZNK2JS5Value8isStringEv($_idx267_val$0, $_idx267_val$1);
    if ($1164) {
      __label__ = 247;
      break;
    } else {
      __label__ = 249;
      break;
    }
   case 247:
    var $1166 = __ZNK2JS5Value8toStringEv($_idx268_val$0, $_idx268_val$1);
    var $1167 = __ZNK2JS5Value8toStringEv($_idx267_val$0, $_idx267_val$1);
    var $1168 = __ZN2js14CompareStringsEP9JSContextP8JSStringS3_Pi($5077, $1166, $1167, $result87);
    if ($1168) {
      __label__ = 248;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 248:
    var $cond84_0 = HEAPU32[$result87 >> 2] >>> 31 & 255 ^ 1;
    __label__ = 252;
    break;
   case 249:
    var $1173 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $1148, $l88);
    if ($1173) {
      __label__ = 250;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 250:
    var $1175 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $1147, $r89);
    if ($1175) {
      __label__ = 251;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 251:
    var $1177 = (tempDoubleI32[0] = HEAP32[$l88 >> 2], tempDoubleI32[1] = HEAP32[$l88 + 4 >> 2], tempDoubleF64[0]);
    var $1178 = (tempDoubleI32[0] = HEAP32[$r89 >> 2], tempDoubleI32[1] = HEAP32[$r89 + 4 >> 2], tempDoubleF64[0]);
    var $cond84_0 = $1177 >= $1178 & 1;
    __label__ = 252;
    break;
   case 252:
    var $cond84_0;
    var $1182 = HEAPU32[$_pre_phi >> 2];
    var $1183 = $1182 + 1 | 0;
    var $1186 = (HEAPU8[$1183] & 255) - 7 | 0;
    var $1189 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    if ($1186 >>> 0 < 2) {
      __label__ = 253;
      break;
    } else {
      __label__ = 255;
      break;
    }
   case 253:
    HEAP32[$_pre_phi580 >> 2] = $1189;
    if (($cond84_0 & 255 | 0) == (($1186 | 0) != 0 & 1 | 0)) {
      __label__ = 254;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 4;
      __label__ = 17;
      break;
    }
   case 254:
    HEAP32[$_pre_phi >> 2] = $1183;
    var $1203 = (HEAPU8[$1182 + 2 | 0] & 255) << 8 | HEAPU8[$1182 + 3 | 0] & 255;
    var $1205 = $1182 + (($1203 << 16 >> 16) + 1) | 0;
    HEAP32[$_pre_phi >> 2] = $1205;
    var $1207 = HEAPU8[$1205] & 255;
    if ($1203 << 16 >> 16 < 1) {
      var $op_1 = $1207;
      __label__ = 34;
      break;
    } else {
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $1207;
      __label__ = 18;
      break;
    }
   case 255:
    __ZN2JS5Value10setBooleanEb($1189, $cond84_0 << 24 >> 24 != 0);
    var $1212 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $1212;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 256:
    var $1215 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    var $1216 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $1215, $i91);
    if ($1216) {
      __label__ = 257;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 257:
    var $1219 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $1220 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $1219, $j92);
    if ($1220) {
      __label__ = 258;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 258:
    var $1225 = HEAP32[$i91 >> 2] << (HEAP32[$j92 >> 2] & 31);
    HEAP32[$i91 >> 2] = $1225;
    var $1226 = HEAP32[$_pre_phi580 >> 2];
    var $1227 = $1226 - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $1227;
    var $1228 = $1226 - 16 | 0;
    __ZN2JS5Value8setInt32Ei($1228, $1225);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 259:
    var $1231 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    var $1232 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $1231, $i93);
    if ($1232) {
      __label__ = 260;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 260:
    var $1235 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $1236 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $1235, $j94);
    if ($1236) {
      __label__ = 261;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 261:
    var $1241 = HEAP32[$i93 >> 2] >> (HEAP32[$j94 >> 2] & 31);
    HEAP32[$i93 >> 2] = $1241;
    var $1242 = HEAP32[$_pre_phi580 >> 2];
    var $1243 = $1242 - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $1243;
    var $1244 = $1242 - 16 | 0;
    __ZN2JS5Value8setInt32Ei($1244, $1241);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 262:
    var $1247 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    var $1248 = __ZN2js17ValueToECMAUint32EP9JSContextRKN2JS5ValueEPj($cx, $1247, $u);
    if ($1248) {
      __label__ = 263;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 263:
    var $1251 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $1252 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $1251, $j95);
    if ($1252) {
      __label__ = 264;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 264:
    var $1257 = HEAPU32[$u >> 2] >>> ((HEAP32[$j95 >> 2] & 31) >>> 0);
    HEAP32[$u >> 2] = $1257;
    var $1258 = HEAPU32[$_pre_phi580 >> 2];
    HEAP32[$_pre_phi580 >> 2] = $1258 - 8 | 0;
    var $1260 = $1258 - 16 | 0;
    var $1261 = __ZN2JS5Value9setNumberEj($1260, $1257);
    if ($1261) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 265;
      break;
    }
   case 265:
    var $1263 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh($cx, $script_1, $1263);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 266:
    var $1265 = HEAPU32[$_pre_phi580 >> 2];
    var $1266 = $1265 - 8 | 0;
    var $st$2$0 = $1266 | 0;
    var $1267$0 = HEAPU32[$st$2$0 >> 2];
    var $st$2$1 = $1266 + 4 | 0;
    var $1267$1 = HEAPU32[$st$2$1 >> 2];
    var $st$6$0 = $5085 | 0;
    HEAP32[$st$6$0 >> 2] = $1267$0;
    var $st$6$1 = $5085 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $1267$1;
    var $1268 = $1265 - 16 | 0;
    var $st$11$0 = $1268 | 0;
    var $1269$0 = HEAPU32[$st$11$0 >> 2];
    var $st$11$1 = $1268 + 4 | 0;
    var $1269$1 = HEAPU32[$st$11$1 >> 2];
    var $st$15$0 = $5086 | 0;
    HEAP32[$st$15$0 >> 2] = $1269$0;
    var $st$15$1 = $5086 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $1269$1;
    var $1270 = __ZNK2JS5Value7isInt32Ev($1269$0, $1269$1);
    if ($1270) {
      __label__ = 267;
      break;
    } else {
      __label__ = 272;
      break;
    }
   case 267:
    var $1272 = __ZNK2JS5Value7isInt32Ev($1267$0, $1267$1);
    if ($1272) {
      __label__ = 268;
      break;
    } else {
      __label__ = 272;
      break;
    }
   case 268:
    var $1274 = __ZNK2JS5Value7toInt32Ev($1269$0, $1269$1);
    var $1275 = __ZNK2JS5Value7toInt32Ev($1267$0, $1267$1);
    var $1276 = $1275 + $1274 | 0;
    var $1281 = $1265 - 16 | 0;
    if ((($1276 ^ $1274) & ($1276 ^ $1275) | 0) < 0) {
      __label__ = 269;
      break;
    } else {
      __label__ = 270;
      break;
    }
   case 269:
    var $1285 = ($1274 | 0) + ($1275 | 0);
    __ZN2JS5Value9setDoubleEd($1281, $1285);
    var $1286 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh($cx, $script_1, $1286);
    __label__ = 271;
    break;
   case 270:
    __ZN2JS5Value8setInt32Ei($1281, $1276);
    __label__ = 271;
    break;
   case 271:
    var $1290 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $1290;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 272:
    var $1292 = __ZL5IsXMLRKN2JS5ValueE($1269$0, $1269$1);
    if ($1292) {
      __label__ = 273;
      break;
    } else {
      __label__ = 276;
      break;
    }
   case 273:
    var $1294 = __ZL5IsXMLRKN2JS5ValueE($1267$0, $1267$1);
    if ($1294) {
      __label__ = 274;
      break;
    } else {
      __label__ = 276;
      break;
    }
   case 274:
    var $1296 = __ZNK2JS5Value8toObjectEv($1269$0, $1269$1);
    var $1297 = __ZNK2JS5Value8toObjectEv($1267$0, $1267$1);
    var $1298 = $1296;
    var $1299 = $1297;
    var $1300 = __Z17js_ConcatenateXMLP9JSContextP8JSObjectS2_PN2JS5ValueE($5083, $1298, $1299, $rval96);
    if (($1300 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 275;
      break;
    }
   case 275:
    var $st$1$0 = $5085 | 0;
    var $1304$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $5085 + 4 | 0;
    var $1304$1 = HEAP32[$st$1$1 >> 2];
    var $1305 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    var $st$6$0 = $1305 | 0;
    HEAP32[$st$6$0 >> 2] = $1304$0;
    var $st$6$1 = $1305 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $1304$1;
    var $1307 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $1307;
    var $1308 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript14MonitorUnknownEP9JSContextP8JSScriptPh($cx, $script_1, $1308);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 276:
    var $1310 = __ZNK2JS5Value8isObjectEv($1269$0, $1269$1);
    var $1311 = __ZNK2JS5Value8isObjectEv($1267$0, $1267$1);
    var $1312 = __ZN2jsL11ToPrimitiveEP9JSContextPN2JS5ValueE($cx, $lval97);
    if ($1312) {
      __label__ = 277;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 277:
    var $1314 = __ZN2jsL11ToPrimitiveEP9JSContextPN2JS5ValueE($cx, $rval96);
    if ($1314) {
      __label__ = 278;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 278:
    var $st$0$0 = $5086 | 0;
    var $lval97_idx266_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5086 + 4 | 0;
    var $lval97_idx266_val$1 = HEAP32[$st$0$1 >> 2];
    var $1316 = __ZNK2JS5Value8isStringEv($lval97_idx266_val$0, $lval97_idx266_val$1);
    var $st$6$0 = $5085 | 0;
    var $rval96_idx265_val$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $5085 + 4 | 0;
    var $rval96_idx265_val$1 = HEAP32[$st$6$1 >> 2];
    var $1317 = __ZNK2JS5Value8isStringEv($rval96_idx265_val$0, $rval96_idx265_val$1);
    if ($1316 | $1317) {
      __label__ = 279;
      break;
    } else {
      __label__ = 291;
      break;
    }
   case 279:
    if ($1316) {
      __label__ = 280;
      break;
    } else {
      __label__ = 281;
      break;
    }
   case 280:
    var $1321 = __ZNK2JS5Value8toStringEv($lval97_idx266_val$0, $lval97_idx266_val$1);
    var $lstr_0 = $1321;
    __label__ = 283;
    break;
   case 281:
    var $1323 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($5077, $lval97_idx266_val$0, $lval97_idx266_val$1);
    if (($1323 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 282;
      break;
    }
   case 282:
    var $1327 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    __ZN2JS5Value9setStringEP8JSString($1327, $1323);
    var $lstr_0 = $1323;
    __label__ = 283;
    break;
   case 283:
    var $lstr_0;
    var $st$1$0 = $5085 | 0;
    var $rval96_idx208_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $5085 + 4 | 0;
    var $rval96_idx208_val$1 = HEAP32[$st$1$1 >> 2];
    if ($1317) {
      __label__ = 284;
      break;
    } else {
      __label__ = 285;
      break;
    }
   case 284:
    var $1330 = __ZNK2JS5Value8toStringEv($rval96_idx208_val$0, $rval96_idx208_val$1);
    var $rstr_0 = $1330;
    __label__ = 287;
    break;
   case 285:
    var $1332 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($5077, $rval96_idx208_val$0, $rval96_idx208_val$1);
    if (($1332 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 286;
      break;
    }
   case 286:
    var $1336 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    __ZN2JS5Value9setStringEP8JSString($1336, $1332);
    var $rstr_0 = $1332;
    __label__ = 287;
    break;
   case 287:
    var $rstr_0;
    var $1338 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($cx, $lstr_0, $rstr_0);
    if (($1338 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 288;
      break;
    }
   case 288:
    if ($1310 | $1311) {
      __label__ = 289;
      break;
    } else {
      __label__ = 290;
      break;
    }
   case 289:
    var $1342 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript13MonitorStringEP9JSContextP8JSScriptPh($cx, $script_1, $1342);
    __label__ = 290;
    break;
   case 290:
    var $1345 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    __ZN2JS5Value9setStringEP8JSString($1345, $1338);
    var $1347 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $1347;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 291:
    var $1349 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $lval97, $l100);
    if ($1349) {
      __label__ = 292;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 292:
    var $1351 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $rval96, $r101);
    if ($1351) {
      __label__ = 293;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 293:
    var $1353 = (tempDoubleI32[0] = HEAP32[$r101 >> 2], tempDoubleI32[1] = HEAP32[$r101 + 4 >> 2], tempDoubleF64[0]);
    var $1354 = (tempDoubleI32[0] = HEAP32[$l100 >> 2], tempDoubleI32[1] = HEAP32[$l100 + 4 >> 2], tempDoubleF64[0]);
    var $1355 = $1354 + $1353;
    tempDoubleF64[0] = $1355, HEAP32[$l100 >> 2] = tempDoubleI32[0], HEAP32[$l100 + 4 >> 2] = tempDoubleI32[1];
    var $1357 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    var $1358 = __ZN2JS5Value9setNumberEd($1357, $1355);
    if ($1358) {
      __label__ = 298;
      break;
    } else {
      __label__ = 294;
      break;
    }
   case 294:
    if ($1310 | $1311) {
      __label__ = 297;
      break;
    } else {
      __label__ = 295;
      break;
    }
   case 295:
    var $st$0$0 = $5086 | 0;
    var $lval97_idx243_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5086 + 4 | 0;
    var $lval97_idx243_val$1 = HEAP32[$st$0$1 >> 2];
    var $1361 = __ZNK2JS5Value8isDoubleEv($lval97_idx243_val$0, $lval97_idx243_val$1);
    if ($1361) {
      __label__ = 298;
      break;
    } else {
      __label__ = 296;
      break;
    }
   case 296:
    var $st$0$0 = $5085 | 0;
    var $rval96_idx242_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5085 + 4 | 0;
    var $rval96_idx242_val$1 = HEAP32[$st$0$1 >> 2];
    var $1363 = __ZNK2JS5Value8isDoubleEv($rval96_idx242_val$0, $rval96_idx242_val$1);
    if ($1363) {
      __label__ = 298;
      break;
    } else {
      __label__ = 297;
      break;
    }
   case 297:
    var $1365 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh($cx, $script_1, $1365);
    __label__ = 298;
    break;
   case 298:
    var $1368 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $1368;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 299:
    var $1370 = HEAP32[$_pre_phi580 >> 2];
    var $1371 = $1370 - 8 | 0;
    var $st$2$0 = $1371 | 0;
    var $1372$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $1371 + 4 | 0;
    var $1372$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5087 | 0;
    HEAP32[$st$6$0 >> 2] = $1372$0;
    var $st$6$1 = $5087 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $1372$1;
    var $1373 = $1370 - 16 | 0;
    var $st$11$0 = $1373 | 0;
    var $1374$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $1373 + 4 | 0;
    var $1374$1 = HEAP32[$st$11$1 >> 2];
    var $st$15$0 = $5088 | 0;
    HEAP32[$st$15$0 >> 2] = $1374$0;
    var $st$15$1 = $5088 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $1374$1;
    var $1375 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $lval103, $d1);
    if ($1375) {
      __label__ = 300;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 300:
    var $1377 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $rval102, $d2);
    if ($1377) {
      __label__ = 301;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 301:
    var $1379 = (tempDoubleI32[0] = HEAP32[$d1 >> 2], tempDoubleI32[1] = HEAP32[$d1 + 4 >> 2], tempDoubleF64[0]);
    var $1380 = (tempDoubleI32[0] = HEAP32[$d2 >> 2], tempDoubleI32[1] = HEAP32[$d2 + 4 >> 2], tempDoubleF64[0]);
    var $1381 = $1379 - $1380;
    var $1382 = HEAP32[$_pre_phi580 >> 2];
    var $1383 = $1382 - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $1383;
    var $1384 = $1382 - 16 | 0;
    var $1385 = __ZN2JS5Value9setNumberEd($1384, $1381);
    if ($1385) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 302;
      break;
    }
   case 302:
    var $st$0$0 = $5088 | 0;
    var $lval103_idx_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5088 + 4 | 0;
    var $lval103_idx_val$1 = HEAP32[$st$0$1 >> 2];
    var $1387 = __ZNK2JS5Value8isDoubleEv($lval103_idx_val$0, $lval103_idx_val$1);
    if ($1387) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 303;
      break;
    }
   case 303:
    var $st$0$0 = $5087 | 0;
    var $rval102_idx_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5087 + 4 | 0;
    var $rval102_idx_val$1 = HEAP32[$st$0$1 >> 2];
    var $1389 = __ZNK2JS5Value8isDoubleEv($rval102_idx_val$0, $rval102_idx_val$1);
    if ($1389) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 304;
      break;
    }
   case 304:
    var $1391 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh($cx, $script_1, $1391);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 305:
    var $1393 = HEAP32[$_pre_phi580 >> 2];
    var $1394 = $1393 - 8 | 0;
    var $st$2$0 = $1394 | 0;
    var $1395$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $1394 + 4 | 0;
    var $1395$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5089 | 0;
    HEAP32[$st$6$0 >> 2] = $1395$0;
    var $st$6$1 = $5089 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $1395$1;
    var $1396 = $1393 - 16 | 0;
    var $st$11$0 = $1396 | 0;
    var $1397$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $1396 + 4 | 0;
    var $1397$1 = HEAP32[$st$11$1 >> 2];
    var $st$15$0 = $5090 | 0;
    HEAP32[$st$15$0 >> 2] = $1397$0;
    var $st$15$1 = $5090 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $1397$1;
    var $1398 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $lval105, $d1106);
    if ($1398) {
      __label__ = 306;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 306:
    var $1400 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $rval104, $d2107);
    if ($1400) {
      __label__ = 307;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 307:
    var $1402 = (tempDoubleI32[0] = HEAP32[$d1106 >> 2], tempDoubleI32[1] = HEAP32[$d1106 + 4 >> 2], tempDoubleF64[0]);
    var $1403 = (tempDoubleI32[0] = HEAP32[$d2107 >> 2], tempDoubleI32[1] = HEAP32[$d2107 + 4 >> 2], tempDoubleF64[0]);
    var $1404 = $1402 * $1403;
    var $1405 = HEAP32[$_pre_phi580 >> 2];
    var $1406 = $1405 - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $1406;
    var $1407 = $1405 - 16 | 0;
    var $1408 = __ZN2JS5Value9setNumberEd($1407, $1404);
    if ($1408) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 308;
      break;
    }
   case 308:
    var $st$0$0 = $5090 | 0;
    var $lval105_idx_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5090 + 4 | 0;
    var $lval105_idx_val$1 = HEAP32[$st$0$1 >> 2];
    var $1410 = __ZNK2JS5Value8isDoubleEv($lval105_idx_val$0, $lval105_idx_val$1);
    if ($1410) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 309;
      break;
    }
   case 309:
    var $st$0$0 = $5089 | 0;
    var $rval104_idx_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5089 + 4 | 0;
    var $rval104_idx_val$1 = HEAP32[$st$0$1 >> 2];
    var $1412 = __ZNK2JS5Value8isDoubleEv($rval104_idx_val$0, $rval104_idx_val$1);
    if ($1412) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 310;
      break;
    }
   case 310:
    var $1414 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh($cx, $script_1, $1414);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 311:
    var $1416 = HEAP32[$_pre_phi580 >> 2];
    var $1417 = $1416 - 8 | 0;
    var $st$2$0 = $1417 | 0;
    var $1418$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $1417 + 4 | 0;
    var $1418$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5091 | 0;
    HEAP32[$st$6$0 >> 2] = $1418$0;
    var $st$6$1 = $5091 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $1418$1;
    var $1419 = $1416 - 16 | 0;
    var $st$11$0 = $1419 | 0;
    var $1420$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $1419 + 4 | 0;
    var $1420$1 = HEAP32[$st$11$1 >> 2];
    var $st$15$0 = $5092 | 0;
    HEAP32[$st$15$0 >> 2] = $1420$0;
    var $st$15$1 = $5092 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $1420$1;
    var $1421 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $lval110, $d1111);
    if ($1421) {
      __label__ = 312;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 312:
    var $1423 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $rval109, $d2112);
    if ($1423) {
      __label__ = 313;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 313:
    var $1425 = HEAP32[$_pre_phi580 >> 2];
    var $1426 = $1425 - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $1426;
    var $1427 = $1425 - 16 | 0;
    var $1428 = (tempDoubleI32[0] = HEAP32[$d1111 >> 2], tempDoubleI32[1] = HEAP32[$d1111 + 4 >> 2], tempDoubleF64[0]);
    var $1429 = (tempDoubleI32[0] = HEAP32[$d2112 >> 2], tempDoubleI32[1] = HEAP32[$d2112 + 4 >> 2], tempDoubleF64[0]);
    var $1430 = __ZN2js9NumberDivEdd($1428, $1429);
    var $1431 = __ZN2JS5Value9setNumberEd($1427, $1430);
    if ($1429 == 0) {
      __label__ = 317;
      break;
    } else {
      __label__ = 314;
      break;
    }
   case 314:
    var $_idx241 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$2$0 = $_idx241 | 0;
    var $_idx241_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx241 + 4 | 0;
    var $_idx241_val$1 = HEAP32[$st$2$1 >> 2];
    var $1435 = __ZNK2JS5Value8isDoubleEv($_idx241_val$0, $_idx241_val$1);
    if ($1435) {
      __label__ = 315;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    }
   case 315:
    var $st$0$0 = $5092 | 0;
    var $lval110_idx_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5092 + 4 | 0;
    var $lval110_idx_val$1 = HEAP32[$st$0$1 >> 2];
    var $1437 = __ZNK2JS5Value8isDoubleEv($lval110_idx_val$0, $lval110_idx_val$1);
    if ($1437) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 316;
      break;
    }
   case 316:
    var $st$0$0 = $5091 | 0;
    var $rval109_idx_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5091 + 4 | 0;
    var $rval109_idx_val$1 = HEAP32[$st$0$1 >> 2];
    var $1439 = __ZNK2JS5Value8isDoubleEv($rval109_idx_val$0, $rval109_idx_val$1);
    if ($1439) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 317;
      break;
    }
   case 317:
    var $1441 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh($cx, $script_1, $1441);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 318:
    var $1443 = HEAP32[$_pre_phi580 >> 2];
    var $1444 = $1443 - 16 | 0;
    var $1445 = $1443 - 8 | 0;
    var $_idx287 = $1444 | 0;
    var $st$4$0 = $_idx287 | 0;
    var $_idx287_val$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $_idx287 + 4 | 0;
    var $_idx287_val$1 = HEAP32[$st$4$1 >> 2];
    var $1446 = __ZNK2JS5Value7isInt32Ev($_idx287_val$0, $_idx287_val$1);
    if ($1446) {
      __label__ = 319;
      break;
    } else {
      __label__ = 323;
      break;
    }
   case 319:
    var $_idx286 = $1445 | 0;
    var $st$1$0 = $_idx286 | 0;
    var $_idx286_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx286 + 4 | 0;
    var $_idx286_val$1 = HEAP32[$st$1$1 >> 2];
    var $1448 = __ZNK2JS5Value7isInt32Ev($_idx286_val$0, $_idx286_val$1);
    if ($1448) {
      __label__ = 320;
      break;
    } else {
      __label__ = 323;
      break;
    }
   case 320:
    var $1450 = __ZNK2JS5Value7toInt32Ev($_idx287_val$0, $_idx287_val$1);
    if (($1450 | 0) > -1) {
      __label__ = 321;
      break;
    } else {
      __label__ = 323;
      break;
    }
   case 321:
    var $1453 = __ZNK2JS5Value7toInt32Ev($_idx286_val$0, $_idx286_val$1);
    if (($1453 | 0) > 0) {
      __label__ = 322;
      break;
    } else {
      __label__ = 323;
      break;
    }
   case 322:
    var $1456 = ($1450 | 0) % ($1453 | 0);
    HEAP32[$_pre_phi580 >> 2] = $1445;
    __ZN2JS5Value8setInt32Ei($1444, $1456);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 323:
    var $1458 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $1444, $d1117);
    if ($1458) {
      __label__ = 324;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 324:
    var $1461 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $1462 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $1461, $d2118);
    if ($1462) {
      __label__ = 325;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 325:
    var $1464 = HEAP32[$_pre_phi580 >> 2];
    var $1465 = $1464 - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $1465;
    var $1466 = (tempDoubleI32[0] = HEAP32[$d2118 >> 2], tempDoubleI32[1] = HEAP32[$d2118 + 4 >> 2], tempDoubleF64[0]);
    if ($1466 == 0) {
      __label__ = 326;
      break;
    } else {
      __label__ = 327;
      break;
    }
   case 326:
    var $1469 = $1464 - 16 | 0;
    var $1470 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($1469, $1470);
    __label__ = 328;
    break;
   case 327:
    var $1472 = (tempDoubleI32[0] = HEAP32[$d1117 >> 2], tempDoubleI32[1] = HEAP32[$d1117 + 4 >> 2], tempDoubleF64[0]);
    var $1473 = __ZL7js_fmoddd($1472, $1466);
    tempDoubleF64[0] = $1473, HEAP32[$d1117 >> 2] = tempDoubleI32[0], HEAP32[$d1117 + 4 >> 2] = tempDoubleI32[1];
    var $1475 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    __ZN2JS5Value9setDoubleEd($1475, $1473);
    __label__ = 328;
    break;
   case 328:
    var $1477 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh($cx, $script_1, $1477);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 329:
    var $1480 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $_idx318 = $1480 | 0;
    var $st$3$0 = $_idx318 | 0;
    var $_idx318_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx318 + 4 | 0;
    var $_idx318_val$1 = HEAP32[$st$3$1 >> 2];
    var $1481 = __ZNK2JS5Value6isNullEv($_idx318_val$0, $_idx318_val$1);
    if ($1481) {
      var $cond120_0 = 0;
      __label__ = 333;
      break;
    } else {
      __label__ = 330;
      break;
    }
   case 330:
    var $1483 = __ZNK2JS5Value9isBooleanEv($_idx318_val$0, $_idx318_val$1);
    if ($1483) {
      __label__ = 331;
      break;
    } else {
      __label__ = 332;
      break;
    }
   case 331:
    var $1485 = __ZNK2JS5Value9toBooleanEv($_idx318_val$0, $_idx318_val$1);
    var $cond120_0 = $1485 & 1;
    __label__ = 333;
    break;
   case 332:
    var $1488 = __Z17js_ValueToBooleanRKN2JS5ValueE($1480);
    var $cond120_0 = ($1488 | 0) != 0 & 1;
    __label__ = 333;
    break;
   case 333:
    var $cond120_0;
    __ZN2JS5Value10setBooleanEb($1480, $cond120_0 << 24 >> 24 == 0);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 334:
    var $1495 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $1496 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $1495, $i121);
    if ($1496) {
      __label__ = 335;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 335:
    var $1499 = HEAP32[$i121 >> 2] ^ -1;
    HEAP32[$i121 >> 2] = $1499;
    var $1501 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    __ZN2JS5Value8setInt32Ei($1501, $1499);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 336:
    var $1503 = HEAP32[$_pre_phi580 >> 2];
    var $1504 = $1503 - 8 | 0;
    var $st$2$0 = $1504 | 0;
    var $1505$0 = HEAPU32[$st$2$0 >> 2];
    var $st$2$1 = $1504 + 4 | 0;
    var $1505$1 = HEAP32[$st$2$1 >> 2];
    var $1506 = __ZNK2JS5Value7isInt32Ev($1505$0, $1505$1);
    if ($1506) {
      __label__ = 337;
      break;
    } else {
      __label__ = 339;
      break;
    }
   case 337:
    var $1508 = __ZNK2JS5Value7toInt32Ev($1505$0, $1505$1);
    if (($1508 | 0) == 0 || ($1508 | 0) == -2147483648) {
      __label__ = 339;
      break;
    } else {
      __label__ = 338;
      break;
    }
   case 338:
    var $1510 = -$1508 | 0;
    var $1511 = $1503 - 8 | 0;
    __ZN2JS5Value8setInt32Ei($1511, $1510);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 339:
    var $1513 = $1503 - 8 | 0;
    var $1514 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $1513, $d124);
    if ($1514) {
      __label__ = 340;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 340:
    var $1516 = (tempDoubleI32[0] = HEAP32[$d124 >> 2], tempDoubleI32[1] = HEAP32[$d124 + 4 >> 2], tempDoubleF64[0]);
    var $1517 = -$1516;
    tempDoubleF64[0] = $1517, HEAP32[$d124 >> 2] = tempDoubleI32[0], HEAP32[$d124 + 4 >> 2] = tempDoubleI32[1];
    var $1519 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $1520 = __ZN2JS5Value9setNumberEd($1519, $1517);
    if ($1520) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 341;
      break;
    }
   case 341:
    var $1522 = __ZNK2JS5Value8isDoubleEv($1505$0, $1505$1);
    if ($1522) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 342;
      break;
    }
   case 342:
    var $1524 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh($cx, $script_1, $1524);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 343:
    var $1527 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $1528 = __ZN2js8ToNumberEP9JSContextPN2JS5ValueE($cx, $1527);
    if ($1528) {
      __label__ = 344;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 344:
    var $_idx284 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$2$0 = $_idx284 | 0;
    var $_idx284_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx284 + 4 | 0;
    var $_idx284_val$1 = HEAP32[$st$2$1 >> 2];
    var $1531 = __ZNK2JS5Value7isInt32Ev($_idx284_val$0, $_idx284_val$1);
    if ($1531) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 345;
      break;
    }
   case 345:
    var $1533 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh($cx, $script_1, $1533);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 346:
    var $1535 = HEAPU32[$_pre_phi >> 2];
    var $1545 = HEAP32[$atoms_1 + (((HEAPU8[$1535 + 1 | 0] & 255) << 8 | HEAPU8[$1535 + 2 | 0] & 255) << 2) >> 2];
    var $1546 = __ZL12ATOM_TO_JSIDP6JSAtom1798($1545);
    var $1547 = __Z15js_FindPropertyP9JSContextibPP8JSObjectS3_PP10JSProperty($5080, $1546, $5093, $obj2128, $5094);
    if (($1547 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 347;
      break;
    }
   case 347:
    var $1550 = HEAP32[$_pre_phi580 >> 2];
    var $1551 = $1550 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $1551;
    __ZN2JS5Value10setBooleanEb($1550, 1);
    if ((HEAP32[$prop129 >> 2] | 0) == 0) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    } else {
      __label__ = 348;
      break;
    }
   case 348:
    var $1555 = HEAP32[$obj127 >> 2];
    var $1557 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $1558 = __ZN8JSObject14deletePropertyEP9JSContextiPN2JS5ValueEi($1555, $cx, $1546, $1557, 0);
    if (($1558 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    }
   case 349:
    var $1561 = HEAPU32[$_pre_phi >> 2];
    var $1571 = HEAP32[$atoms_1 + (((HEAPU8[$1561 + 1 | 0] & 255) << 8 | HEAPU8[$1561 + 2 | 0] & 255) << 2) >> 2];
    var $1572 = __ZL12ATOM_TO_JSIDP6JSAtom1798($1571);
    var $1574 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $_idx113 = $1574 | 0;
    var $st$15$0 = $_idx113 | 0;
    var $_idx113_val$0 = HEAP32[$st$15$0 >> 2];
    var $st$15$1 = $_idx113 + 4 | 0;
    var $_idx113_val$1 = HEAP32[$st$15$1 >> 2];
    var $1575 = __ZNK2JS5Value8isObjectEv($_idx113_val$0, $_idx113_val$1);
    if ($1575) {
      __label__ = 350;
      break;
    } else {
      __label__ = 351;
      break;
    }
   case 350:
    var $1577 = __ZNK2JS5Value8toObjectEv($_idx113_val$0, $_idx113_val$1);
    var $obj132_0 = $1577;
    __label__ = 353;
    break;
   case 351:
    var $1579 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5080, $1574);
    var $1580 = $1579;
    if (($1579 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 352;
      break;
    }
   case 352:
    __ZN2JS5Value9setObjectER8JSObject($1574, $1580);
    var $obj132_0 = $1580;
    __label__ = 353;
    break;
   case 353:
    var $obj132_0;
    var $1588 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $1589 = __ZN8JSObject14deletePropertyEP9JSContextiPN2JS5ValueEi($obj132_0, $cx, $1572, $rval134, $1588);
    if (($1589 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 354;
      break;
    }
   case 354:
    var $st$1$0 = $5095 | 0;
    var $1593$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $5095 + 4 | 0;
    var $1593$1 = HEAP32[$st$1$1 >> 2];
    var $1594 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$6$0 = $1594 | 0;
    HEAP32[$st$6$0 >> 2] = $1593$0;
    var $st$6$1 = $1594 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $1593$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 355:
    var $1596 = HEAPU32[$_pre_phi580 >> 2];
    var $1597 = $1596 - 16 | 0;
    var $_idx112 = $1597 | 0;
    var $st$3$0 = $_idx112 | 0;
    var $_idx112_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx112 + 4 | 0;
    var $_idx112_val$1 = HEAP32[$st$3$1 >> 2];
    var $1598 = __ZNK2JS5Value8isObjectEv($_idx112_val$0, $_idx112_val$1);
    if ($1598) {
      __label__ = 356;
      break;
    } else {
      __label__ = 357;
      break;
    }
   case 356:
    var $1600 = __ZNK2JS5Value8toObjectEv($_idx112_val$0, $_idx112_val$1);
    var $obj135_0 = $1600;
    var $1607 = $1596;
    __label__ = 359;
    break;
   case 357:
    var $1602 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5080, $1597);
    var $1603 = $1602;
    if (($1602 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 358;
      break;
    }
   case 358:
    __ZN2JS5Value9setObjectER8JSObject($1597, $1603);
    var $obj135_0 = $1603;
    var $1607 = HEAP32[$_pre_phi580 >> 2];
    __label__ = 359;
    break;
   case 359:
    var $1607;
    var $obj135_0;
    var $1608 = $1607 - 8 | 0;
    var $1609 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($1608, $i_139);
    if ($1609) {
      __label__ = 360;
      break;
    } else {
      __label__ = 362;
      break;
    }
   case 360:
    var $1611 = HEAP32[$i_139 >> 2];
    var $1612 = _INT_FITS_IN_JSID1825($1611);
    if (($1612 | 0) == 0) {
      __label__ = 362;
      break;
    } else {
      __label__ = 361;
      break;
    }
   case 361:
    var $1615 = _INT_TO_JSID1826($1611);
    HEAP32[$id137 >> 2] = $1615;
    var $1621 = $1615;
    __label__ = 364;
    break;
   case 362:
    var $1618 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $1619 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $obj135_0, $1608, $id137, $1618);
    if ($1619) {
      __label__ = 363;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 363:
    var $1621 = HEAP32[$id137 >> 2];
    __label__ = 364;
    break;
   case 364:
    var $1621;
    var $1623 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    var $1628 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $1629 = __ZN8JSObject14deletePropertyEP9JSContextiPN2JS5ValueEi($obj135_0, $cx, $1621, $1623, $1628);
    if (($1629 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 365;
      break;
    }
   case 365:
    var $1633 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $1633;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 366:
    var $1635 = HEAPU32[$_pre_phi580 >> 2];
    var $1636 = $1635 - 16 | 0;
    var $_idx111 = $1636 | 0;
    var $st$3$0 = $_idx111 | 0;
    var $_idx111_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx111 + 4 | 0;
    var $_idx111_val$1 = HEAP32[$st$3$1 >> 2];
    var $1637 = __ZNK2JS5Value8isObjectEv($_idx111_val$0, $_idx111_val$1);
    if ($1637) {
      __label__ = 367;
      break;
    } else {
      __label__ = 368;
      break;
    }
   case 367:
    var $1639 = __ZNK2JS5Value8toObjectEv($_idx111_val$0, $_idx111_val$1);
    var $obj140_0 = $1639;
    var $1646 = $1635;
    __label__ = 370;
    break;
   case 368:
    var $1641 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5080, $1636);
    var $1642 = $1641;
    if (($1641 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 369;
      break;
    }
   case 369:
    __ZN2JS5Value9setObjectER8JSObject($1636, $1642);
    var $obj140_0 = $1642;
    var $1646 = HEAP32[$_pre_phi580 >> 2];
    __label__ = 370;
    break;
   case 370:
    var $1646;
    var $obj140_0;
    var $1647 = $1646 - 8 | 0;
    var $1648 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($1647, $i_144);
    if ($1648) {
      __label__ = 371;
      break;
    } else {
      __label__ = 373;
      break;
    }
   case 371:
    var $1650 = HEAP32[$i_144 >> 2];
    var $1651 = _INT_FITS_IN_JSID1825($1650);
    if (($1651 | 0) == 0) {
      __label__ = 373;
      break;
    } else {
      __label__ = 372;
      break;
    }
   case 372:
    var $1654 = _INT_TO_JSID1826($1650);
    HEAP32[$id142 >> 2] = $1654;
    __label__ = 374;
    break;
   case 373:
    var $1657 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $1658 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $obj140_0, $1647, $id142, $1657);
    if ($1658) {
      __label__ = 374;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 374:
    var $_idx283 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$2$0 = $_idx283 | 0;
    var $_idx283_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx283 + 4 | 0;
    var $_idx283_val$1 = HEAP32[$st$2$1 >> 2];
    var $1661 = __ZNK2JS5Value7isInt32Ev($_idx283_val$0, $_idx283_val$1);
    if ($1661) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 375;
      break;
    }
   case 375:
    var $1663 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript14MonitorUnknownEP9JSContextP8JSScriptPh($cx, $script_1, $1663);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 376:
    var $1666 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$2$0 = $1666 | 0;
    var $1667$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $1666 + 4 | 0;
    var $1667$1 = HEAP32[$st$2$1 >> 2];
    var $1668 = _JS_TypeOfValue($cx, $1667$0, $1667$1);
    var $1672 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $1673 = HEAP32[$23 + 209984 + ($1668 << 2) >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($1672, $1673);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 377:
    var $1676 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    __ZN2JS5Value12setUndefinedEv($1676);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 378:
    var $cx_idx237_val = HEAP8[$cx_idx234];
    var $1678 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx237_val);
    if ($1678) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 2;
      __label__ = 17;
      break;
    } else {
      var $i150_0 = -2;
      var $1695 = 2;
      __label__ = 381;
      break;
    }
   case 379:
    var $cx_idx236_val = HEAP8[$cx_idx234];
    var $1680 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx236_val);
    if ($1680) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 4;
      __label__ = 17;
      break;
    } else {
      __label__ = 380;
      break;
    }
   case 380:
    var $1682 = HEAPU32[$_pre_phi >> 2];
    var $1692 = HEAP32[$atoms_1 + (((HEAPU8[$1682 + 1 | 0] & 255) << 8 | HEAPU8[$1682 + 2 | 0] & 255) << 2) >> 2];
    HEAP32[$atom148 >> 2] = $1692;
    var $1693 = __ZL12ATOM_TO_JSIDP6JSAtom1798($1692);
    var $i150_0 = -1;
    var $1695 = $1693;
    __label__ = 381;
    break;
   case 381:
    var $1695;
    var $i150_0;
    HEAP32[$id149 >> 2] = $1695;
    var $1697 = HEAP32[$_pre_phi580 >> 2] + ($i150_0 << 3) | 0;
    var $_idx110 = $1697 | 0;
    var $st$6$0 = $_idx110 | 0;
    var $_idx110_val$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $_idx110 + 4 | 0;
    var $_idx110_val$1 = HEAP32[$st$6$1 >> 2];
    var $1698 = __ZNK2JS5Value8isObjectEv($_idx110_val$0, $_idx110_val$1);
    if ($1698) {
      __label__ = 382;
      break;
    } else {
      __label__ = 383;
      break;
    }
   case 382:
    var $1700 = __ZNK2JS5Value8toObjectEv($_idx110_val$0, $_idx110_val$1);
    HEAP32[$obj147 >> 2] = $1700;
    var $1707 = $1700;
    __label__ = 385;
    break;
   case 383:
    var $1702 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5080, $1697);
    var $1703 = $1702;
    HEAP32[$obj147 >> 2] = $1703;
    if (($1702 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 384;
      break;
    }
   case 384:
    __ZN2JS5Value9setObjectER8JSObject($1697, $1703);
    var $1707 = $1703;
    __label__ = 385;
    break;
   case 385:
    var $1707;
    var $1708 = _JSID_IS_VOID1831($1695);
    if (($1708 | 0) == 0) {
      var $1790 = $1707;
      var $1789 = $1695;
      __label__ = 404;
      break;
    } else {
      __label__ = 386;
      break;
    }
   case 386:
    var $1712 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $1713 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($1712, $i_153);
    if ($1713) {
      __label__ = 387;
      break;
    } else {
      __label__ = 389;
      break;
    }
   case 387:
    var $1715 = HEAP32[$i_153 >> 2];
    var $1716 = _INT_FITS_IN_JSID1825($1715);
    if (($1716 | 0) == 0) {
      __label__ = 389;
      break;
    } else {
      __label__ = 388;
      break;
    }
   case 388:
    var $1719 = _INT_TO_JSID1826($1715);
    HEAP32[$id149 >> 2] = $1719;
    var $1790 = $1707;
    var $1789 = $1719;
    __label__ = 404;
    break;
   case 389:
    var $1722 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $1723 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $1707, $1712, $id149, $1722);
    if ($1723) {
      __label__ = 390;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 390:
    var $1790 = $1707;
    var $1789 = HEAP32[$id149 >> 2];
    __label__ = 404;
    break;
   case 391:
    var $cx_idx235_val = HEAP8[$cx_idx234];
    var $1725 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx235_val);
    if ($1725) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 4;
      __label__ = 17;
      break;
    } else {
      __label__ = 392;
      break;
    }
   case 392:
    var $regs_idx53_val = HEAP32[$regs_idx73 >> 2];
    var $1727 = __ZNK2js9FrameRegs2fpEv($regs_idx53_val);
    var $1728 = __ZNK2js10StackFrame10scopeChainEv($1727);
    HEAP32[$obj147 >> 2] = $1728;
    var $1730 = HEAPU32[_js_CodeSpec + ($op_0 << 3) + 4 >> 2];
    var $1732 = ($1730 & 33554432 | 0) != 0;
    if ($1732) {
      __label__ = 393;
      break;
    } else {
      __label__ = 394;
      break;
    }
   case 393:
    var $1734 = $1728;
    var $1735 = __ZNK8JSObject9getGlobalEv($1734);
    var $1736 = $1735;
    HEAP32[$obj147 >> 2] = $1736;
    __label__ = 394;
    break;
   case 394:
    var $1739 = HEAP32[$22 >> 2] + 144336 | 0;
    var $1740 = HEAP32[$_pre_phi >> 2];
    __ZN2js13PropertyCache4testEP9JSContextPhRP8JSObjectS6_RPNS_18PropertyCacheEntryERP6JSAtom($1739, $cx, $1740, $obj147, $obj2154, $entry155, $atom148);
    var $1741 = HEAPU32[$atom148 >> 2];
    if (($1741 | 0) == 0) {
      __label__ = 395;
      break;
    } else {
      var $1782 = $1741;
      __label__ = 401;
      break;
    }
   case 395:
    var $1744 = HEAPU32[$obj147 >> 2];
    if (($1744 | 0) == (HEAP32[$obj2154 >> 2] | 0)) {
      __label__ = 396;
      break;
    } else {
      __label__ = 400;
      break;
    }
   case 396:
    var $_idx411_val = HEAP32[HEAP32[$entry155 >> 2] + 12 >> 2];
    var $1749 = __ZNK2js5PCVal6isSlotEv($_idx411_val);
    if ($1749) {
      __label__ = 397;
      break;
    } else {
      __label__ = 400;
      break;
    }
   case 397:
    var $1751 = __ZNK2js5PCVal6toSlotEv($_idx411_val);
    var $1752 = __ZNK8JSObject13nativeGetSlotEj($1744, $1751);
    var $_idx282 = $1752 | 0;
    var $st$3$0 = $_idx282 | 0;
    var $_idx282_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx282 + 4 | 0;
    var $_idx282_val$1 = HEAP32[$st$3$1 >> 2];
    var $1753 = __ZNK2JS5Value7isInt32Ev($_idx282_val$0, $_idx282_val$1);
    if ($1753) {
      __label__ = 398;
      break;
    } else {
      __label__ = 400;
      break;
    }
   case 398:
    var $1755 = __ZNK2JS5Value7toInt32Ev($_idx282_val$0, $_idx282_val$1);
    var $1756 = __ZL24CanIncDecWithoutOverflowi($1755);
    if ($1756) {
      __label__ = 399;
      break;
    } else {
      __label__ = 400;
      break;
    }
   case 399:
    var $1761 = $1755 - 1 + ($1730 >>> 10 & 2) | 0;
    var $tmp_0 = ($1730 & 4096 | 0) == 0 ? $1761 : $1755;
    __ZN2JSL10Int32ValueEi1832($1, $1761);
    var $st$8$0 = $_idx359 | 0;
    var $_idx359_val$0 = HEAP32[$st$8$0 >> 2];
    var $st$8$1 = $_idx359 + 4 | 0;
    var $_idx359_val$1 = HEAP32[$st$8$1 >> 2];
    __ZN8JSObject13nativeSetSlotEjRKN2JS5ValueE($1744, $1751, $_idx359_val$0, $_idx359_val$1);
    var $1764 = HEAP32[$_pre_phi580 >> 2];
    var $1765 = $1764 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $1765;
    __ZN2JS5Value8setInt32Ei($1764, $tmp_0);
    var $1766 = HEAP32[$_pre_phi >> 2];
    var $1767 = __ZN2jsL18GetDecomposeLengthEPhj($1766, 4);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = $1767 + 4 | 0;
    __label__ = 17;
    break;
   case 400:
    var $1770 = HEAPU32[$_pre_phi >> 2];
    var $1780 = HEAPU32[$atoms_1 + (((HEAPU8[$1770 + 1 | 0] & 255) << 8 | HEAPU8[$1770 + 2 | 0] & 255) << 2) >> 2];
    HEAP32[$atom148 >> 2] = $1780;
    var $1782 = $1780;
    __label__ = 401;
    break;
   case 401:
    var $1782;
    var $1783 = __ZL12ATOM_TO_JSIDP6JSAtom1798($1782);
    HEAP32[$id149 >> 2] = $1783;
    var $1784 = __Z21js_FindPropertyHelperP9JSContextibbPP8JSObjectS3_PP10JSProperty($5080, $1783, 1, $1732, $5096, $5097, $5098);
    if (($1784 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 402;
      break;
    }
   case 402:
    if ((HEAP32[$prop157 >> 2] | 0) == 0) {
      var $atomNotDefined_0 = $1782;
      __label__ = 1048;
      break;
    } else {
      __label__ = 403;
      break;
    }
   case 403:
    var $1790 = HEAP32[$obj147 >> 2];
    var $1789 = $1783;
    __label__ = 404;
    break;
   case 404:
    var $1789;
    var $1790;
    var $1791 = HEAP32[$_pre_phi580 >> 2];
    var $1792 = $1791 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $1792;
    __ZN2JS5Value7setNullEv($1791);
    var $1794 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $1795 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($1790, $cx, $1789, $1794);
    if (($1795 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 405;
      break;
    }
   case 405:
    var $1798 = _js_CodeSpec + ($op_0 << 3) | 0;
    var $1800 = HEAPU32[_js_CodeSpec + ($op_0 << 3) + 4 >> 2];
    var $1803 = ($1800 & 224 | 0) == 32 ? 2 : 3;
    var $1804 = HEAPU32[$_pre_phi580 >> 2];
    var $1805 = $1804 - 8 | 0;
    var $_idx281 = $1805 | 0;
    var $st$9$0 = $_idx281 | 0;
    var $_idx281_val$0 = HEAP32[$st$9$0 >> 2];
    var $st$9$1 = $_idx281 + 4 | 0;
    var $_idx281_val$1 = HEAP32[$st$9$1 >> 2];
    var $1806 = __ZNK2JS5Value7isInt32Ev($_idx281_val$0, $_idx281_val$1);
    if ($1806) {
      __label__ = 406;
      break;
    } else {
      __label__ = 409;
      break;
    }
   case 406:
    var $1808 = __ZNK2JS5Value7toInt32Ev($_idx281_val$0, $_idx281_val$1);
    var $1809 = __ZL24CanIncDecWithoutOverflowi($1808);
    if ($1809) {
      __label__ = 407;
      break;
    } else {
      __label__ = 409;
      break;
    }
   case 407:
    var $1814 = ($1800 >>> 10 & 2) - 1 + $1808 | 0;
    var $1815 = __ZN2JS5Value11getInt32RefEv($1805);
    HEAP32[$1815 >> 2] = $1814;
    __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf160, $cx, $1803);
    var $1820 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $1821 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($1790, $cx, $1789, $1805, $1820);
    var $1822 = ($1821 | 0) == 0;
    var $rf160_idx_val = HEAP32[$rf160_idx >> 2];
    var $rf160_idx329_val = HEAP32[$rf160_idx329 >> 2];
    __ZN18JSAutoResolveFlagsD1Ev($rf160_idx_val, $rf160_idx329_val);
    if ($1822) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 408;
      break;
    }
   case 408:
    var $_64 = ($1800 & 4096 | 0) == 0 ? $1814 : $1808;
    __ZN2JS5Value8setInt32Ei($1805, $_64);
    __label__ = 412;
    break;
   case 409:
    HEAP32[$_pre_phi580 >> 2] = $1804 + 8 | 0;
    __ZN2JS5Value7setNullEv($1804);
    var $1828 = HEAP32[$_pre_phi580 >> 2];
    var $1829 = $1828 - 16 | 0;
    var $1830 = $1828 - 8 | 0;
    var $1831 = __ZL8DoIncDecP9JSContextPK10JSCodeSpecPN2JS5ValueES6_($cx, $1798, $1829, $1830);
    if ($1831) {
      __label__ = 410;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 410:
    __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf161, $cx, $1803);
    var $1834 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $1839 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $1840 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($1790, $cx, $1789, $1834, $1839);
    var $1841 = ($1840 | 0) == 0;
    var $rf161_idx_val = HEAP32[$rf161_idx >> 2];
    var $rf161_idx328_val = HEAP32[$rf161_idx328 >> 2];
    __ZN18JSAutoResolveFlagsD1Ev($rf161_idx_val, $rf161_idx328_val);
    if ($1841) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 411;
      break;
    }
   case 411:
    var $1844 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $1844;
    __label__ = 412;
    break;
   case 412:
    var $1847 = HEAP8[_js_CodeSpec + ($op_0 << 3) + 1 | 0];
    if ($1847 << 24 >> 24 == 0) {
      __label__ = 414;
      break;
    } else {
      __label__ = 413;
      break;
    }
   case 413:
    var $1850 = $1847 << 24 >> 24;
    var $1852 = HEAP32[$_pre_phi580 >> 2];
    var $1853 = $1852 - 8 | 0;
    var $st$4$0 = $1853 | 0;
    var $1854$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $1853 + 4 | 0;
    var $1854$1 = HEAP32[$st$4$1 >> 2];
    var $1855 = $1852 + (($1850 ^ -1) << 3) | 0;
    var $st$9$0 = $1855 | 0;
    HEAP32[$st$9$0 >> 2] = $1854$0;
    var $st$9$1 = $1855 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $1854$1;
    var $1858 = HEAP32[$_pre_phi580 >> 2] + (-$1850 << 3) | 0;
    HEAP32[$_pre_phi580 >> 2] = $1858;
    __label__ = 414;
    break;
   case 414:
    var $1862 = HEAP8[$1798 | 0] << 24 >> 24;
    var $1863 = HEAP32[$_pre_phi >> 2];
    var $1864 = __ZN2jsL18GetDecomposeLengthEPhj($1863, $1862);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = $1864 + $1862 | 0;
    __label__ = 17;
    break;
   case 415:
    var $incr2_0 = 0;
    var $incr163_0 = 1;
    __label__ = 418;
    break;
   case 416:
    var $incr2_0 = -1;
    var $incr163_0 = -1;
    __label__ = 418;
    break;
   case 417:
    var $incr2_0 = 0;
    var $incr163_0 = -1;
    __label__ = 418;
    break;
   case 418:
    var $incr163_0;
    var $incr2_0;
    var $1868 = HEAPU32[$_pre_phi >> 2];
    var $vp165_0 = $argv_1 + (((HEAPU8[$1868 + 1 | 0] & 255) << 8 | HEAPU8[$1868 + 2 | 0] & 255) << 3) | 0;
    var $incr2_2 = $incr2_0;
    var $incr163_2 = $incr163_0;
    __label__ = 423;
    break;
   case 419:
    var $incr2_1 = 0;
    var $incr163_1 = 1;
    __label__ = 422;
    break;
   case 420:
    var $incr2_1 = -1;
    var $incr163_1 = -1;
    __label__ = 422;
    break;
   case 421:
    var $incr2_1 = 0;
    var $incr163_1 = -1;
    __label__ = 422;
    break;
   case 422:
    var $incr163_1;
    var $incr2_1;
    var $1880 = HEAPU32[$_pre_phi >> 2];
    var $1888 = (HEAPU8[$1880 + 1 | 0] & 255) << 8 | HEAPU8[$1880 + 2 | 0] & 255;
    var $regs_idx52_val = HEAP32[$regs_idx73 >> 2];
    var $1889 = __ZNK2js9FrameRegs2fpEv($regs_idx52_val);
    var $1890 = $1889;
    var $1891 = __ZNK2js10StackFrame5slotsEv($1890);
    var $vp165_0 = $1891 + ($1888 << 3) | 0;
    var $incr2_2 = $incr2_1;
    var $incr163_2 = $incr163_1;
    __label__ = 423;
    break;
   case 423:
    var $incr163_2;
    var $incr2_2;
    var $vp165_0;
    var $vp165_0_idx280 = $vp165_0 | 0;
    var $st$4$0 = $vp165_0_idx280 | 0;
    var $vp165_0_idx280_val$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $vp165_0_idx280 + 4 | 0;
    var $vp165_0_idx280_val$1 = HEAP32[$st$4$1 >> 2];
    var $1894 = __ZNK2JS5Value7isInt32Ev($vp165_0_idx280_val$0, $vp165_0_idx280_val$1);
    if ($1894) {
      __label__ = 424;
      break;
    } else {
      __label__ = 428;
      break;
    }
   case 424:
    var $1896 = __ZNK2JS5Value7toInt32Ev($vp165_0_idx280_val$0, $vp165_0_idx280_val$1);
    var $1897 = __ZL24CanIncDecWithoutOverflowi($1896);
    if ($1897) {
      __label__ = 425;
      break;
    } else {
      __label__ = 428;
      break;
    }
   case 425:
    var $1899 = $1896 + $incr163_2 | 0;
    var $1900 = __ZN2JS5Value11getInt32RefEv($vp165_0);
    HEAP32[$1900 >> 2] = $1899;
    var $1901 = HEAP32[$_pre_phi >> 2];
    var $1905 = HEAPU32[$_pre_phi580 >> 2];
    if (HEAP8[$1901 + 3 | 0] << 24 >> 24 == 81) {
      __label__ = 426;
      break;
    } else {
      __label__ = 427;
      break;
    }
   case 426:
    HEAP32[$_pre_phi580 >> 2] = $1905;
    var $1907 = $1901 + 4 | 0;
    HEAP32[$_pre_phi >> 2] = $1907;
    var $script_1 = $script_1;
    var $pcCounts_1 = $pcCounts_1;
    var $argv_1 = $argv_1;
    var $atoms_1 = $atoms_1;
    var $op_0 = HEAPU8[$1907] & 255;
    __label__ = 18;
    break;
   case 427:
    HEAP32[$_pre_phi580 >> 2] = $1905 + 8 | 0;
    var $1912 = $1896 + $incr2_2 | 0;
    __ZN2JS5Value8setInt32Ei($1905, $1912);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 428:
    var $1914 = HEAPU32[$_pre_phi580 >> 2];
    HEAP32[$_pre_phi580 >> 2] = $1914 + 8 | 0;
    var $st$3$0 = $vp165_0_idx280 | 0;
    var $1916$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $vp165_0_idx280 + 4 | 0;
    var $1916$1 = HEAP32[$st$3$1 >> 2];
    var $1917 = $1914 | 0;
    var $st$8$0 = $1917 | 0;
    HEAP32[$st$8$0 >> 2] = $1916$0;
    var $st$8$1 = $1917 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $1916$1;
    var $1918 = _js_CodeSpec + ($op_0 << 3) | 0;
    var $1920 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $1921 = __ZL8DoIncDecP9JSContextPK10JSCodeSpecPN2JS5ValueES6_($cx, $1918, $1920, $vp165_0);
    if ($1921) {
      __label__ = 429;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 429:
    var $1923 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh($cx, $script_1, $1923);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 430:
    var $regs_idx51_val = HEAP32[$regs_idx73 >> 2];
    var $1925 = __ZNK2js9FrameRegs2fpEv($regs_idx51_val);
    var $1926 = __ZN2js11ComputeThisEP9JSContextPNS_10StackFrameE($cx, $1925);
    if ($1926) {
      __label__ = 431;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 431:
    var $1928 = HEAP32[$_pre_phi580 >> 2];
    var $1929 = $1928 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $1929;
    var $regs_idx50_val = HEAP32[$regs_idx73 >> 2];
    var $1930 = __ZNK2js9FrameRegs2fpEv($regs_idx50_val);
    var $1931 = __ZNK2js10StackFrame9thisValueEv($1930);
    var $1932 = $1931 | 0;
    var $st$7$0 = $1932 | 0;
    var $1933$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $1932 + 4 | 0;
    var $1933$1 = HEAP32[$st$7$1 >> 2];
    var $1934 = $1928 | 0;
    var $st$12$0 = $1934 | 0;
    HEAP32[$st$12$0 >> 2] = $1933$0;
    var $st$12$1 = $1934 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $1933$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 432:
    var $regs_idx49_val = HEAP32[$regs_idx73 >> 2];
    var $1936 = __ZNK2js9FrameRegs2fpEv($regs_idx49_val);
    var $1937 = __ZN2js11ComputeThisEP9JSContextPNS_10StackFrameE($cx, $1936);
    if ($1937) {
      __label__ = 433;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 433:
    var $regs_idx48_val = HEAP32[$regs_idx73 >> 2];
    var $1939 = __ZNK2js9FrameRegs2fpEv($regs_idx48_val);
    var $1940 = __ZNK2js10StackFrame9thisValueEv($1939);
    var $_idx109 = $1940 | 0;
    var $st$4$0 = $_idx109 | 0;
    var $_idx109_val$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $_idx109 + 4 | 0;
    var $_idx109_val$1 = HEAP32[$st$4$1 >> 2];
    var $1941 = __ZNK2JS5Value8isObjectEv($_idx109_val$0, $_idx109_val$1);
    if ($1941) {
      __label__ = 434;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    }
   case 434:
    var $1943 = __ZNK2JS5Value8toObjectEv($_idx109_val$0, $_idx109_val$1);
    var $_idx205_val = HEAP32[$1943 >> 2];
    var $1944 = __ZNK8JSObject8isNativeEv($_idx205_val);
    if ($1944) {
      __label__ = 435;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    }
   case 435:
    var $1946 = $1943;
    __ZN8JSObject7unbrandEP9JSContext($1946, $5099);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 436:
    var $1949 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $_idx264 = $1949 | 0;
    var $st$4$0 = $_idx264 | 0;
    var $_idx264_val$0 = HEAPU32[$st$4$0 >> 2];
    var $st$4$1 = $_idx264 + 4 | 0;
    var $_idx264_val$1 = HEAPU32[$st$4$1 >> 2];
    if (($op_0 | 0) == 220) {
      __label__ = 437;
      break;
    } else {
      var $_idx107_val$1 = $_idx264_val$1;
      var $_idx107_val$0 = $_idx264_val$0;
      __label__ = 449;
      break;
    }
   case 437:
    var $1952 = __ZNK2JS5Value8isStringEv($_idx264_val$0, $_idx264_val$1);
    if ($1952) {
      __label__ = 438;
      break;
    } else {
      __label__ = 439;
      break;
    }
   case 438:
    var $1954 = __ZNK2JS5Value8toStringEv($_idx264_val$0, $_idx264_val$1);
    var $_idx192_val = HEAP32[$1954 >> 2];
    var $1955 = __ZNK8JSString6lengthEv($_idx192_val);
    __ZN2JSL10Int32ValueEi1832($2, $1955);
    var $st$5$0 = $5100 | 0;
    var $1956$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $5100 + 4 | 0;
    var $1956$1 = HEAP32[$st$5$1 >> 2];
    var $st$9$0 = $5101 | 0;
    HEAP32[$st$9$0 >> 2] = $1956$0;
    var $st$9$1 = $5101 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $1956$1;
    __label__ = 469;
    break;
   case 439:
    var $1958 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx264_val$0, $_idx264_val$1);
    if ($1958) {
      __label__ = 440;
      break;
    } else {
      __label__ = 441;
      break;
    }
   case 440:
    var $regs_idx47_val = HEAP32[$regs_idx73 >> 2];
    var $1960 = __ZNK2js9FrameRegs2fpEv($regs_idx47_val);
    var $1961 = __ZNK2js10StackFrame13numActualArgsEv($1960);
    __ZN2JSL10Int32ValueEi1832($3, $1961);
    var $st$4$0 = $5102 | 0;
    var $1962$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $5102 + 4 | 0;
    var $1962$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $5101 | 0;
    HEAP32[$st$8$0 >> 2] = $1962$0;
    var $st$8$1 = $5101 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $1962$1;
    __label__ = 469;
    break;
   case 441:
    var $1964 = __ZNK2JS5Value8isObjectEv($_idx264_val$0, $_idx264_val$1);
    if ($1964) {
      __label__ = 442;
      break;
    } else {
      var $_idx107_val$1 = $_idx264_val$1;
      var $_idx107_val$0 = $_idx264_val$0;
      __label__ = 449;
      break;
    }
   case 442:
    var $1966 = __ZNK2JS5Value8toObjectEv($_idx264_val$0, $_idx264_val$1);
    var $_idx418_val = HEAPU32[$1966 + 4 >> 2];
    var $1967 = __ZNK8JSObject7isArrayEv($_idx418_val);
    if ($1967) {
      __label__ = 443;
      break;
    } else {
      __label__ = 444;
      break;
    }
   case 443:
    var $_idx377_val = HEAP32[$1966 + 24 >> 2];
    var $1969 = __ZNK8JSObject14getArrayLengthEv($_idx377_val);
    var $1970 = $1969 >>> 0;
    __ZN2JSL11NumberValueEd1833($4, $1970);
    var $st$5$0 = $5103 | 0;
    var $1971$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $5103 + 4 | 0;
    var $1971$1 = HEAP32[$st$5$1 >> 2];
    var $st$9$0 = $5101 | 0;
    HEAP32[$st$9$0 >> 2] = $1971$0;
    var $st$9$1 = $5101 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $1971$1;
    __label__ = 469;
    break;
   case 444:
    var $1973 = __ZNK8JSObject11isArgumentsEv($1966);
    if ($1973) {
      __label__ = 445;
      break;
    } else {
      __label__ = 447;
      break;
    }
   case 445:
    var $1975 = __ZN8JSObject11asArgumentsEv($1966);
    var $1976 = __ZNK2js15ArgumentsObject19hasOverriddenLengthEv($1975);
    if ($1976) {
      __label__ = 447;
      break;
    } else {
      __label__ = 446;
      break;
    }
   case 446:
    var $1978 = __ZNK2js15ArgumentsObject13initialLengthEv($1975);
    __ZN2JSL10Int32ValueEi1832($5, $1978);
    var $st$2$0 = $5104 | 0;
    var $1979$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $5104 + 4 | 0;
    var $1979$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5101 | 0;
    HEAP32[$st$6$0 >> 2] = $1979$0;
    var $st$6$1 = $5101 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $1979$1;
    __label__ = 469;
    break;
   case 447:
    var $1981 = __Z15js_IsTypedArrayP8JSObject($_idx418_val);
    if (($1981 | 0) == 0) {
      var $_idx107_val$1 = $_idx264_val$1;
      var $_idx107_val$0 = $_idx264_val$0;
      __label__ = 449;
      break;
    } else {
      __label__ = 448;
      break;
    }
   case 448:
    var $1984 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($1966);
    var $1985 = __ZN2js10TypedArray9getLengthEP8JSObject($1984);
    __ZN2JSL10Int32ValueEi1832($6, $1985);
    var $st$3$0 = $5105 | 0;
    var $1986$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5105 + 4 | 0;
    var $1986$1 = HEAP32[$st$3$1 >> 2];
    var $st$7$0 = $5101 | 0;
    HEAP32[$st$7$0 >> 2] = $1986$0;
    var $st$7$1 = $5101 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $1986$1;
    __label__ = 469;
    break;
   case 449:
    var $_idx107_val$0;
    var $_idx107_val$1;
    var $1987 = __ZNK2JS5Value8isObjectEv($_idx107_val$0, $_idx107_val$1);
    if ($1987) {
      __label__ = 450;
      break;
    } else {
      __label__ = 451;
      break;
    }
   case 450:
    var $1989 = __ZNK2JS5Value8toObjectEv($_idx107_val$0, $_idx107_val$1);
    var $obj172_0 = $1989;
    __label__ = 453;
    break;
   case 451:
    var $1991 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5080, $1949);
    var $1992 = $1991;
    if (($1991 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 452;
      break;
    }
   case 452:
    __ZN2JS5Value9setObjectER8JSObject($1949, $1992);
    var $obj172_0 = $1992;
    __label__ = 453;
    break;
   case 453:
    var $obj172_0;
    var $1996 = __Z23js_GetProtoIfDenseArrayP8JSObject($obj172_0);
    HEAP32[$aobj >> 2] = $1996;
    var $1998 = HEAP32[$22 >> 2] + 144336 | 0;
    var $1999 = HEAP32[$_pre_phi >> 2];
    __ZN2js13PropertyCache4testEP9JSContextPhRP8JSObjectS6_RPNS_18PropertyCacheEntryERP6JSAtom($1998, $cx, $1999, $aobj, $obj2174, $entry173, $atom175);
    var $2000 = HEAPU32[$atom175 >> 2];
    if (($2000 | 0) == 0) {
      __label__ = 454;
      break;
    } else {
      __label__ = 464;
      break;
    }
   case 454:
    var $_idx422_val = HEAP32[HEAP32[$entry173 >> 2] + 12 >> 2];
    var $2004 = __ZNK2js5PCVal8isFunObjEv($_idx422_val);
    if ($2004) {
      __label__ = 455;
      break;
    } else {
      __label__ = 456;
      break;
    }
   case 455:
    var $2006 = __ZNK2js5PCVal8toFunObjEv($_idx422_val);
    __ZN2JS5Value9setObjectER8JSObject($rval168, $2006);
    __label__ = 469;
    break;
   case 456:
    var $2008 = __ZNK2js5PCVal6isSlotEv($_idx422_val);
    if ($2008) {
      __label__ = 457;
      break;
    } else {
      __label__ = 458;
      break;
    }
   case 457:
    var $2010 = __ZNK2js5PCVal6toSlotEv($_idx422_val);
    var $2011 = HEAP32[$obj2174 >> 2];
    var $2012 = __ZNK8JSObject13nativeGetSlotEj($2011, $2010);
    var $2013 = $2012 | 0;
    var $st$4$0 = $2013 | 0;
    var $2014$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $2013 + 4 | 0;
    var $2014$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $5101 | 0;
    HEAP32[$st$8$0 >> 2] = $2014$0;
    var $st$8$1 = $5101 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $2014$1;
    __label__ = 469;
    break;
   case 458:
    var $2016 = __ZNK2js5PCVal7toShapeEv($_idx422_val);
    var $_idx335_val = HEAP8[$2016 + 28 | 0];
    var $2017 = __ZNK2js5Shape16isDataDescriptorEv($_idx335_val);
    if ($2017) {
      __label__ = 459;
      break;
    } else {
      __label__ = 463;
      break;
    }
   case 459:
    var $_idx248_val = HEAP32[$2016 + 16 >> 2];
    var $2019 = __ZNK2js5Shape16hasDefaultGetterEv($_idx248_val);
    if ($2019) {
      __label__ = 460;
      break;
    } else {
      __label__ = 463;
      break;
    }
   case 460:
    var $2022 = HEAP32[$2016 + 24 >> 2];
    if (($2022 | 0) == -1) {
      __label__ = 462;
      break;
    } else {
      __label__ = 461;
      break;
    }
   case 461:
    var $2025 = HEAP32[$obj2174 >> 2];
    var $2026 = __ZNK8JSObject13nativeGetSlotEj($2025, $2022);
    var $2027 = $2026 | 0;
    var $st$3$0 = $2027 | 0;
    var $2028$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $2027 + 4 | 0;
    var $2028$1 = HEAP32[$st$3$1 >> 2];
    var $st$7$0 = $5101 | 0;
    HEAP32[$st$7$0 >> 2] = $2028$0;
    var $st$7$1 = $5101 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $2028$1;
    __label__ = 469;
    break;
   case 462:
    __ZN2JS5Value12setUndefinedEv($rval168);
    __label__ = 469;
    break;
   case 463:
    var $2031 = HEAP32[$obj2174 >> 2];
    var $regs_idx46_val = HEAP32[$regs_idx73 >> 2];
    var $2032 = __ZNK2js9FrameRegs2fpEv($regs_idx46_val);
    var $_idx166_val = HEAP32[$2032 >> 2];
    var $2033 = __ZNK2js10StackFrame11hasImacropcEv($_idx166_val);
    var $2034 = $2033 ? 2 : 0;
    var $2036 = $2031;
    var $2037 = $2016;
    var $2038 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($5080, $obj172_0, $2036, $2037, $2034, $rval168);
    if (($2038 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 469;
      break;
    }
   case 464:
    var $2041 = __ZL12ATOM_TO_JSIDP6JSAtom1798($2000);
    var $_idx224_val = HEAP32[HEAP32[$aobj >> 2] + 4 >> 2];
    var $2043 = __ZNK8JSObject6getOpsEv($_idx224_val);
    if ((HEAP32[$2043 + 36 >> 2] | 0) == 0) {
      __label__ = 465;
      break;
    } else {
      __label__ = 468;
      break;
    }
   case 465:
    var $regs_idx45_val = HEAP32[$regs_idx73 >> 2];
    var $2048 = __ZNK2js9FrameRegs2fpEv($regs_idx45_val);
    var $_idx165_val = HEAP32[$2048 >> 2];
    var $2049 = __ZNK2js10StackFrame11hasImacropcEv($_idx165_val);
    if ($2049) {
      var $2056 = 3;
      __label__ = 467;
      break;
    } else {
      __label__ = 466;
      break;
    }
   case 466:
    var $phitmp = HEAP8[HEAP32[$_pre_phi >> 2] + 3 | 0] << 24 >> 24 == 7 ? 3 : 1;
    var $2056 = $phitmp;
    __label__ = 467;
    break;
   case 467:
    var $2056;
    var $2058 = __Z20js_GetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueE($5080, $obj172_0, $2041, $2056, $rval168);
    if (($2058 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 469;
      break;
    }
   case 468:
    var $2061 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($obj172_0, $cx, $2041, $rval168);
    if (($2061 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 469;
      break;
    }
   case 469:
    var $2064 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $2064, $rval168);
    var $st$3$0 = $5101 | 0;
    var $2066$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5101 + 4 | 0;
    var $2066$1 = HEAP32[$st$3$1 >> 2];
    var $2067 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$8$0 = $2067 | 0;
    HEAP32[$st$8$0 >> 2] = $2066$0;
    var $st$8$1 = $2067 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $2066$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 470:
    var $2070 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$2$0 = $2070 | 0;
    var $2071$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $2070 + 4 | 0;
    var $2071$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5106 | 0;
    HEAP32[$st$6$0 >> 2] = $2071$0;
    var $st$6$1 = $5106 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $2071$1;
    var $2072 = __ZNK2JS5Value8isObjectEv($2071$0, $2071$1);
    if ($2072) {
      __label__ = 471;
      break;
    } else {
      __label__ = 472;
      break;
    }
   case 471:
    var $st$0$0 = $5107 | 0;
    HEAP32[$st$0$0 >> 2] = $2071$0;
    var $st$0$1 = $5107 + 4 | 0;
    HEAP32[$st$0$1 >> 2] = $2071$1;
    var $2087$1 = $2071$1;
    var $2087$0 = $2071$0;
    __label__ = 478;
    break;
   case 472:
    var $2075 = __ZNK2JS5Value8isStringEv($2071$0, $2071$1);
    if ($2075) {
      var $protoKey_0 = 9;
      __label__ = 476;
      break;
    } else {
      __label__ = 473;
      break;
    }
   case 473:
    var $2077 = __ZNK2JS5Value8isNumberEv($2071$0, $2071$1);
    if ($2077) {
      var $protoKey_0 = 8;
      __label__ = 476;
      break;
    } else {
      __label__ = 474;
      break;
    }
   case 474:
    var $2079 = __ZNK2JS5Value9isBooleanEv($2071$0, $2071$1);
    if ($2079) {
      var $protoKey_0 = 4;
      __label__ = 476;
      break;
    } else {
      __label__ = 475;
      break;
    }
   case 475:
    __Z26js_ReportIsNullOrUndefinedP9JSContextiRKN2JS5ValueEP8JSString($cx, -1, $lval178);
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 476:
    var $protoKey_0;
    var $2082 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($5080, 0, $protoKey_0, $5109, 0);
    if (($2082 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 477;
      break;
    }
   case 477:
    var $2085 = HEAP32[$pobj >> 2];
    __ZN2JS5Value9setObjectER8JSObject($objv, $2085);
    var $st$2$0 = $5107 | 0;
    var $st$2$1 = $5107 + 4 | 0;
    var $2087$1 = HEAP32[$st$2$1 >> 2];
    var $2087$0 = HEAP32[$st$2$0 >> 2];
    __label__ = 478;
    break;
   case 478:
    var $2087$0;
    var $2087$1;
    var $2088 = __ZNK2JS5Value8toObjectEv($2087$0, $2087$1);
    var $2089 = __Z23js_GetProtoIfDenseArrayP8JSObject($2088);
    HEAP32[$aobj179 >> 2] = $2089;
    var $2091 = HEAP32[$22 >> 2] + 144336 | 0;
    var $2092 = HEAP32[$_pre_phi >> 2];
    __ZN2js13PropertyCache4testEP9JSContextPhRP8JSObjectS6_RPNS_18PropertyCacheEntryERP6JSAtom($2091, $cx, $2092, $aobj179, $obj2182, $entry181, $atom183);
    var $2093 = HEAP32[$atom183 >> 2];
    if (($2093 | 0) == 0) {
      __label__ = 479;
      break;
    } else {
      __label__ = 490;
      break;
    }
   case 479:
    var $_idx421_val = HEAP32[HEAP32[$entry181 >> 2] + 12 >> 2];
    var $2097 = __ZNK2js5PCVal8isFunObjEv($_idx421_val);
    if ($2097) {
      __label__ = 480;
      break;
    } else {
      __label__ = 481;
      break;
    }
   case 480:
    var $2099 = __ZNK2js5PCVal8toFunObjEv($_idx421_val);
    __ZN2JS5Value9setObjectER8JSObject($rval180, $2099);
    __label__ = 489;
    break;
   case 481:
    var $2101 = __ZNK2js5PCVal6isSlotEv($_idx421_val);
    if ($2101) {
      __label__ = 482;
      break;
    } else {
      __label__ = 483;
      break;
    }
   case 482:
    var $2103 = __ZNK2js5PCVal6toSlotEv($_idx421_val);
    var $2104 = HEAP32[$obj2182 >> 2];
    var $2105 = __ZNK8JSObject13nativeGetSlotEj($2104, $2103);
    var $2106 = $2105 | 0;
    var $st$4$0 = $2106 | 0;
    var $2107$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $2106 + 4 | 0;
    var $2107$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $5108 | 0;
    HEAP32[$st$8$0 >> 2] = $2107$0;
    var $st$8$1 = $5108 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $2107$1;
    __label__ = 489;
    break;
   case 483:
    var $2109 = __ZNK2js5PCVal7toShapeEv($_idx421_val);
    var $_idx334_val = HEAP8[$2109 + 28 | 0];
    var $2110 = __ZNK2js5Shape16isDataDescriptorEv($_idx334_val);
    if ($2110) {
      __label__ = 484;
      break;
    } else {
      __label__ = 488;
      break;
    }
   case 484:
    var $_idx247_val = HEAP32[$2109 + 16 >> 2];
    var $2112 = __ZNK2js5Shape16hasDefaultGetterEv($_idx247_val);
    if ($2112) {
      __label__ = 485;
      break;
    } else {
      __label__ = 488;
      break;
    }
   case 485:
    var $2115 = HEAP32[$2109 + 24 >> 2];
    if (($2115 | 0) == -1) {
      __label__ = 487;
      break;
    } else {
      __label__ = 486;
      break;
    }
   case 486:
    var $2118 = HEAP32[$obj2182 >> 2];
    var $2119 = __ZNK8JSObject13nativeGetSlotEj($2118, $2115);
    var $2120 = $2119 | 0;
    var $st$3$0 = $2120 | 0;
    var $2121$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $2120 + 4 | 0;
    var $2121$1 = HEAP32[$st$3$1 >> 2];
    var $st$7$0 = $5108 | 0;
    HEAP32[$st$7$0 >> 2] = $2121$0;
    var $st$7$1 = $5108 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $2121$1;
    __label__ = 489;
    break;
   case 487:
    __ZN2JS5Value12setUndefinedEv($rval180);
    __label__ = 489;
    break;
   case 488:
    var $2125 = $2088;
    var $2126 = HEAP32[$obj2182 >> 2];
    var $2127 = $2109;
    var $2128 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($5080, $2125, $2126, $2127, 2, $rval180);
    if (($2128 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 489;
      break;
    }
   case 489:
    var $st$1$0 = $5108 | 0;
    var $2131$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $5108 + 4 | 0;
    var $2131$1 = HEAP32[$st$1$1 >> 2];
    var $2132 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$6$0 = $2132 | 0;
    HEAP32[$st$6$0 >> 2] = $2131$0;
    var $st$6$1 = $2132 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $2131$1;
    var $2133 = HEAP32[$_pre_phi580 >> 2];
    var $2134 = $2133 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $2134;
    var $2135 = $2133 | 0;
    var $st$14$0 = $2135 | 0;
    HEAP32[$st$14$0 >> 2] = $2071$0;
    var $st$14$1 = $2135 + 4 | 0;
    HEAP32[$st$14$1 >> 2] = $2071$1;
    __label__ = 495;
    break;
   case 490:
    var $2137 = __ZL12ATOM_TO_JSIDP6JSAtom1798($2093);
    var $2138 = HEAP32[$_pre_phi580 >> 2];
    var $2139 = $2138 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $2139;
    __ZN2JS5Value7setNullEv($2138);
    if ($2072) {
      __label__ = 491;
      break;
    } else {
      __label__ = 493;
      break;
    }
   case 491:
    var $_idx223_val = HEAP32[HEAP32[$aobj179 >> 2] + 4 >> 2];
    var $2142 = __ZNK8JSObject6getOpsEv($_idx223_val);
    var $2146 = (HEAP32[$2142 + 36 >> 2] | 0) == 0 ? 3 : 2;
    var $2147 = $2088;
    var $2148 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($5080, $2147, $2137, $2146, $rval180);
    if (($2148 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 492;
      break;
    }
   case 492:
    var $2152 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$2$0 = $2152 | 0;
    HEAP32[$st$2$0 >> 2] = $2087$0;
    var $st$2$1 = $2152 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $2087$1;
    var $st$7$0 = $5108 | 0;
    var $2154$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $5108 + 4 | 0;
    var $2154$1 = HEAP32[$st$7$1 >> 2];
    var $2155 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    var $st$12$0 = $2155 | 0;
    HEAP32[$st$12$0 >> 2] = $2154$0;
    var $st$12$1 = $2155 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $2154$1;
    __label__ = 495;
    break;
   case 493:
    var $2157 = $2088;
    var $2158 = __Z20js_GetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueE($5080, $2157, $2137, 3, $rval180);
    if (($2158 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 494;
      break;
    }
   case 494:
    var $2162 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$2$0 = $2162 | 0;
    HEAP32[$st$2$0 >> 2] = $2071$0;
    var $st$2$1 = $2162 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $2071$1;
    var $st$7$0 = $5108 | 0;
    var $2164$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $5108 + 4 | 0;
    var $2164$1 = HEAP32[$st$7$1 >> 2];
    var $2165 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    var $st$12$0 = $2165 | 0;
    HEAP32[$st$12$0 >> 2] = $2164$0;
    var $st$12$1 = $2165 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $2164$1;
    __label__ = 495;
    break;
   case 495:
    var $st$0$0 = $5108 | 0;
    var $rval180_idx_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5108 + 4 | 0;
    var $rval180_idx_val$1 = HEAP32[$st$0$1 >> 2];
    var $2167 = __ZNK2JS5Value11isPrimitiveEv($rval180_idx_val$0, $rval180_idx_val$1);
    if ($2167) {
      __label__ = 496;
      break;
    } else {
      __label__ = 498;
      break;
    }
   case 496:
    var $2169 = HEAPU32[$_pre_phi580 >> 2];
    var $_idx105 = $2169 - 8 | 0;
    var $st$2$0 = $_idx105 | 0;
    var $_idx105_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx105 + 4 | 0;
    var $_idx105_val$1 = HEAP32[$st$2$1 >> 2];
    var $2170 = __ZNK2JS5Value8isObjectEv($_idx105_val$0, $_idx105_val$1);
    if ($2170) {
      __label__ = 497;
      break;
    } else {
      __label__ = 498;
      break;
    }
   case 497:
    var $2172 = HEAPU32[$_pre_phi >> 2];
    var $2182 = HEAPU32[$atoms_1 + (((HEAPU8[$2172 + 1 | 0] & 255) << 8 | HEAPU8[$2172 + 2 | 0] & 255) << 2) >> 2];
    HEAP32[$atom183 >> 2] = $2182;
    var $2183 = $2169 - 16 | 0;
    var $2184 = $2182 | 0;
    __ZN2JS5Value9setStringEP8JSString($2183, $2184);
    var $2186 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    var $2187 = __ZN2js15OnUnknownMethodEP9JSContextPN2JS5ValueE($cx, $2186);
    if ($2187) {
      __label__ = 498;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 498:
    var $2189 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $2189, $rval180);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 499:
    var $_idx135 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$2$0 = $_idx135 | 0;
    var $_idx135_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx135 + 4 | 0;
    var $_idx135_val$1 = HEAP32[$st$2$1 >> 2];
    var $2192 = __ZNK2JS5Value8toObjectEv($_idx135_val$0, $_idx135_val$1);
    var $2193 = $2192;
    __ZN8JSObject7unbrandEP9JSContext($2193, $5099);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 500:
    var $2195 = HEAP32[$_pre_phi580 >> 2];
    var $2196 = $2195 - 8 | 0;
    var $st$2$0 = $2196 | 0;
    var $2197$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $2196 + 4 | 0;
    var $2197$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5078 | 0;
    HEAP32[$st$6$0 >> 2] = $2197$0;
    var $st$6$1 = $5078 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $2197$1;
    var $2198 = $2195 - 16 | 0;
    var $_idx104 = $2198 | 0;
    var $st$12$0 = $_idx104 | 0;
    var $_idx104_val$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $_idx104 + 4 | 0;
    var $_idx104_val$1 = HEAP32[$st$12$1 >> 2];
    var $2199 = __ZNK2JS5Value8isObjectEv($_idx104_val$0, $_idx104_val$1);
    if ($2199) {
      __label__ = 501;
      break;
    } else {
      __label__ = 502;
      break;
    }
   case 501:
    var $2201 = __ZNK2JS5Value8toObjectEv($_idx104_val$0, $_idx104_val$1);
    var $obj189_0 = $2201;
    __label__ = 504;
    break;
   case 502:
    var $2203 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5080, $2198);
    var $2204 = $2203;
    if (($2203 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 503;
      break;
    }
   case 503:
    __ZN2JS5Value9setObjectER8JSObject($2198, $2204);
    var $obj189_0 = $2204;
    __label__ = 504;
    break;
   case 504:
    var $obj189_0;
    var $2209 = HEAP32[$22 >> 2] + 144336 | 0;
    var $2210 = HEAP32[$_pre_phi >> 2];
    var $2211 = __ZN2js13PropertyCache10testForSetEP9JSContextPhP8JSObjectPPNS_18PropertyCacheEntryEPS5_PP6JSAtom($2209, $cx, $2210, $obj189_0, $entry190, $obj2191, $atom192);
    if ($2211) {
      __label__ = 506;
      break;
    } else {
      __label__ = 505;
      break;
    }
   case 505:
    var $2288 = HEAP32[$atom192 >> 2];
    var $2287 = HEAP32[$entry190 >> 2];
    __label__ = 526;
    break;
   case 506:
    var $2213 = HEAPU32[$entry190 >> 2];
    var $_idx427_val = HEAP32[$2213 + 12 >> 2];
    var $2214 = __ZNK2js5PCVal7toShapeEv($_idx427_val);
    var $2215 = __ZNK2js18PropertyCacheEntry6addingEv($2213);
    if ($2215) {
      __label__ = 515;
      break;
    } else {
      __label__ = 507;
      break;
    }
   case 507:
    var $_idx394_val = HEAP32[$2213 + 8 >> 2];
    var $2217 = __ZNK2js18PropertyCacheEntry7vcapTagEv($_idx394_val);
    if (($2217 | 0) == 0) {
      __label__ = 510;
      break;
    } else {
      __label__ = 508;
      break;
    }
   case 508:
    var $obj189_0_idx227_val_idx_val = HEAP32[HEAP32[$obj189_0 + 36 >> 2] >> 2];
    var $2220 = __ZNK8JSObject8getProtoEv($obj189_0_idx227_val_idx_val);
    HEAP32[$obj2191 >> 2] = $2220;
    if (($2220 | 0) == 0) {
      __label__ = 525;
      break;
    } else {
      __label__ = 509;
      break;
    }
   case 509:
    var $_idx363_val = HEAP32[$2220 + 12 >> 2];
    var $2223 = __ZNK8JSObject5shapeEv($_idx363_val);
    var $2224 = __ZNK2js18PropertyCacheEntry6vshapeEv($_idx394_val);
    if (($2223 | 0) == ($2224 | 0)) {
      __label__ = 510;
      break;
    } else {
      __label__ = 525;
      break;
    }
   case 510:
    var $_idx366_val = HEAP32[$2214 + 20 >> 2];
    var $2227 = __ZNK2js5Shape16hasDefaultSetterEv($_idx366_val);
    if ($2227) {
      __label__ = 511;
      break;
    } else {
      __label__ = 514;
      break;
    }
   case 511:
    if ((HEAP32[$2214 + 24 >> 2] | 0) == -1) {
      __label__ = 514;
      break;
    } else {
      __label__ = 512;
      break;
    }
   case 512:
    var $obj189_0_idx358_val = HEAP32[$obj189_0 + 8 >> 2];
    var $2233 = __ZN8JSObject25brandedOrHasMethodBarrierEv($obj189_0_idx358_val);
    if ($2233) {
      __label__ = 514;
      break;
    } else {
      __label__ = 513;
      break;
    }
   case 513:
    __ZN8JSObject21nativeSetSlotWithTypeEP9JSContextPKN2js5ShapeERKN2JS5ValueE($obj189_0, $cx, $2214, $rval187);
    __label__ = 533;
    break;
   case 514:
    var $2239 = (HEAP8[$script_1 + 36 | 0] & 8) << 24 >> 24 != 0;
    var $2241 = $2214;
    var $2242 = __Z12js_NativeSetP9JSContextP8JSObjectPKN2js5ShapeEbbPN2JS5ValueE($5080, $obj189_0, $2241, 0, $2239, $rval187);
    if (($2242 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 533;
      break;
    }
   case 515:
    var $obj189_0_idx225 = $obj189_0 | 0;
    var $obj189_0_idx225_val = HEAP32[$obj189_0_idx225 >> 2];
    var $2245 = __ZNK8JSObject11nativeEmptyEv($obj189_0_idx225_val);
    if ($2245) {
      __label__ = 516;
      break;
    } else {
      var $obj189_0_idx_val = $obj189_0_idx225_val;
      __label__ = 518;
      break;
    }
   case 516:
    var $2247 = __ZN8JSObject38ensureClassReservedSlotsForEmptyObjectEP9JSContext($obj189_0, $cx);
    if ($2247) {
      __label__ = 517;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 517:
    var $obj189_0_idx_val = HEAP32[$obj189_0_idx225 >> 2];
    __label__ = 518;
    break;
   case 518:
    var $obj189_0_idx_val;
    var $_idx194_val = HEAP32[$2214 + 32 >> 2];
    var $2249 = __ZNK2js5Shape8previousEv($_idx194_val);
    var $2250 = __ZNK8JSObject12lastPropertyEv($obj189_0_idx_val);
    if (($2249 | 0) == ($2250 | 0)) {
      __label__ = 519;
      break;
    } else {
      __label__ = 525;
      break;
    }
   case 519:
    var $_idx395_val = HEAP32[$2213 + 8 >> 2];
    var $2253 = __ZNK2js18PropertyCacheEntry6vshapeEv($_idx395_val);
    if (($2253 | 0) == (HEAP32[$5079 >> 2] | 0)) {
      __label__ = 520;
      break;
    } else {
      __label__ = 525;
      break;
    }
   case 520:
    var $_idx365_val = HEAP32[$2214 + 20 >> 2];
    var $2257 = __ZNK2js5Shape16hasDefaultSetterEv($_idx365_val);
    if ($2257) {
      __label__ = 521;
      break;
    } else {
      __label__ = 525;
      break;
    }
   case 521:
    var $obj189_0_idx189_val = HEAP32[$obj189_0 + 4 >> 2];
    var $2259 = __ZNK8JSObject8getClassEv($obj189_0_idx189_val);
    if ((HEAP32[$2259 + 8 >> 2] | 0) == 10) {
      __label__ = 522;
      break;
    } else {
      __label__ = 525;
      break;
    }
   case 522:
    var $2265 = HEAPU32[$2214 + 24 >> 2];
    HEAP32[$slot194 >> 2] = $2265;
    var $obj189_0_idx182_val = HEAP32[$obj189_0 + 28 >> 2];
    var $2266 = __ZNK8JSObject8numSlotsEv($obj189_0_idx182_val);
    if ($2265 >>> 0 < $2266 >>> 0) {
      __label__ = 524;
      break;
    } else {
      __label__ = 523;
      break;
    }
   case 523:
    var $2270 = __ZN8JSObject9allocSlotEP9JSContextPj($obj189_0, $5080, $slot194);
    if ($2270) {
      __label__ = 524;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 524:
    __ZN8JSObject6extendEP9JSContextPKN2js5ShapeEb($obj189_0, $cx, $2214);
    __ZN8JSObject21nativeSetSlotWithTypeEP9JSContextPKN2js5ShapeERKN2JS5ValueE($obj189_0, $cx, $2214, $rval187);
    var $2273 = HEAP32[$2214 + 12 >> 2];
    __Z18js_PurgeScopeChainP9JSContextP8JSObjecti($cx, $obj189_0, $2273);
    __label__ = 533;
    break;
   case 525:
    var $2275 = HEAPU32[$_pre_phi >> 2];
    var $2285 = HEAPU32[$atoms_1 + (((HEAPU8[$2275 + 1 | 0] & 255) << 8 | HEAPU8[$2275 + 2 | 0] & 255) << 2) >> 2];
    HEAP32[$atom192 >> 2] = $2285;
    var $2288 = $2285;
    var $2287 = $2213;
    __label__ = 526;
    break;
   case 526:
    var $2287;
    var $2288;
    var $2289 = __ZL12ATOM_TO_JSIDP6JSAtom1798($2288);
    if (($2287 | 0) == 0) {
      __label__ = 532;
      break;
    } else {
      __label__ = 527;
      break;
    }
   case 527:
    var $obj189_0_idx222_val = HEAP32[$obj189_0 + 4 >> 2];
    var $2292 = __ZNK8JSObject6getOpsEv($obj189_0_idx222_val);
    if ((HEAP32[$2292 + 52 >> 2] | 0) == 0) {
      __label__ = 528;
      break;
    } else {
      __label__ = 532;
      break;
    }
   case 528:
    if (($op_0 | 0) == 111) {
      __label__ = 529;
      break;
    } else if (($op_0 | 0) == 226) {
      var $defineHow_0 = 5;
      __label__ = 531;
      break;
    } else {
      __label__ = 530;
      break;
    }
   case 529:
    var $defineHow_0 = 9;
    __label__ = 531;
    break;
   case 530:
    var $defineHow_0 = 1;
    __label__ = 531;
    break;
   case 531:
    var $defineHow_0;
    var $2304 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $2306 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($5080, $obj189_0, $2289, $defineHow_0, $rval187, $2304);
    if (($2306 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 533;
      break;
    }
   case 532:
    var $2313 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $2314 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($obj189_0, $cx, $2289, $rval187, $2313);
    if (($2314 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 533;
      break;
    }
   case 533:
    var $2317 = HEAPU32[$_pre_phi >> 2];
    var $2321 = HEAPU32[$_pre_phi580 >> 2];
    if (HEAP8[$2317 + 3 | 0] << 24 >> 24 == 81) {
      __label__ = 534;
      break;
    } else {
      __label__ = 535;
      break;
    }
   case 534:
    HEAP32[$_pre_phi580 >> 2] = $2321 - 16 | 0;
    var $2324 = $2317 + 4 | 0;
    HEAP32[$_pre_phi >> 2] = $2324;
    var $script_1 = $script_1;
    var $pcCounts_1 = $pcCounts_1;
    var $argv_1 = $argv_1;
    var $atoms_1 = $atoms_1;
    var $op_0 = HEAPU8[$2324] & 255;
    __label__ = 18;
    break;
   case 535:
    var $2328 = $2321 - 8 | 0;
    var $2329 = $2328 | 0;
    var $st$2$0 = $2329 | 0;
    var $2330$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $2329 + 4 | 0;
    var $2330$1 = HEAP32[$st$2$1 >> 2];
    var $2331 = $2321 - 16 | 0;
    var $st$7$0 = $2331 | 0;
    HEAP32[$st$7$0 >> 2] = $2330$0;
    var $st$7$1 = $2331 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $2330$1;
    HEAP32[$_pre_phi580 >> 2] = $2328;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 536:
    var $2333 = HEAPU32[$_pre_phi580 >> 2];
    var $2334 = $2333 - 16 | 0;
    var $2335 = $2333 - 8 | 0;
    var $_idx262 = $2334 | 0;
    var $st$4$0 = $_idx262 | 0;
    var $_idx262_val$0 = HEAPU32[$st$4$0 >> 2];
    var $st$4$1 = $_idx262 + 4 | 0;
    var $_idx262_val$1 = HEAPU32[$st$4$1 >> 2];
    var $2336 = __ZNK2JS5Value8isStringEv($_idx262_val$0, $_idx262_val$1);
    if ($2336) {
      __label__ = 537;
      break;
    } else {
      __label__ = 541;
      break;
    }
   case 537:
    var $_idx279 = $2335 | 0;
    var $st$1$0 = $_idx279 | 0;
    var $_idx279_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx279 + 4 | 0;
    var $_idx279_val$1 = HEAP32[$st$1$1 >> 2];
    var $2338 = __ZNK2JS5Value7isInt32Ev($_idx279_val$0, $_idx279_val$1);
    if ($2338) {
      __label__ = 538;
      break;
    } else {
      __label__ = 541;
      break;
    }
   case 538:
    var $2340 = __ZNK2JS5Value8toStringEv($_idx262_val$0, $_idx262_val$1);
    var $2341 = __ZNK2JS5Value7toInt32Ev($_idx279_val$0, $_idx279_val$1);
    var $_idx191_val = HEAP32[$2340 >> 2];
    var $2342 = __ZNK8JSString6lengthEv($_idx191_val);
    if ($2341 >>> 0 < $2342 >>> 0) {
      __label__ = 539;
      break;
    } else {
      __label__ = 541;
      break;
    }
   case 539:
    var $2346 = HEAP32[$22 >> 2] + 210584 | 0;
    var $2347 = __ZN2js13StaticStrings23getUnitStringForElementEP9JSContextP8JSStringj($2346, $cx, $2340, $2341);
    if (($2347 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 540;
      break;
    }
   case 540:
    var $2350 = $2347 | 0;
    var $2351 = HEAP32[$_pre_phi580 >> 2];
    var $2352 = $2351 - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $2352;
    var $2353 = $2351 - 16 | 0;
    __ZN2JS5Value9setStringEP8JSString($2353, $2350);
    var $2354 = HEAP32[$_pre_phi >> 2];
    var $2356 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $2354, $2356);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 541:
    var $2358 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx262_val$0, $_idx262_val$1);
    if ($2358) {
      __label__ = 542;
      break;
    } else {
      var $_idx133_val$1 = $_idx262_val$1;
      var $_idx133_val$0 = $_idx262_val$0;
      __label__ = 546;
      break;
    }
   case 542:
    var $_idx278 = $2335 | 0;
    var $st$1$0 = $_idx278 | 0;
    var $_idx278_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx278 + 4 | 0;
    var $_idx278_val$1 = HEAP32[$st$1$1 >> 2];
    var $2360 = __ZNK2JS5Value7isInt32Ev($_idx278_val$0, $_idx278_val$1);
    if ($2360) {
      __label__ = 543;
      break;
    } else {
      __label__ = 545;
      break;
    }
   case 543:
    var $2362 = __ZNK2JS5Value7toInt32Ev($_idx278_val$0, $_idx278_val$1);
    var $regs_idx44_val = HEAP32[$regs_idx73 >> 2];
    var $2363 = __ZNK2js9FrameRegs2fpEv($regs_idx44_val);
    var $2364 = __ZNK2js10StackFrame13numActualArgsEv($2363);
    if ($2362 >>> 0 < $2364 >>> 0) {
      __label__ = 544;
      break;
    } else {
      __label__ = 545;
      break;
    }
   case 544:
    HEAP32[$_pre_phi580 >> 2] = $2335;
    var $st$1$0 = $_idx278 | 0;
    var $_idx78_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx278 + 4 | 0;
    var $_idx78_val$1 = HEAP32[$st$1$1 >> 2];
    var $2367 = __ZNK2JS5Value7toInt32Ev($_idx78_val$0, $_idx78_val$1);
    var $2368 = __ZNK2js10StackFrame18canonicalActualArgEj($2363, $2367);
    var $2369 = $2368 | 0;
    var $st$9$0 = $2369 | 0;
    var $2370$0 = HEAP32[$st$9$0 >> 2];
    var $st$9$1 = $2369 + 4 | 0;
    var $2370$1 = HEAP32[$st$9$1 >> 2];
    var $2371 = $2333 - 16 | 0;
    var $st$14$0 = $2371 | 0;
    HEAP32[$st$14$0 >> 2] = $2370$0;
    var $st$14$1 = $2371 + 4 | 0;
    HEAP32[$st$14$1 >> 2] = $2370$1;
    var $2372 = HEAP32[$_pre_phi >> 2];
    var $2374 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $2372, $2374);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 545:
    __ZN2js5types20MarkArgumentsCreatedEP9JSContextP8JSScript($cx, $script_1);
    var $st$1$0 = $_idx262 | 0;
    var $st$1$1 = $_idx262 + 4 | 0;
    var $_idx133_val$1 = HEAP32[$st$1$1 >> 2];
    var $_idx133_val$0 = HEAP32[$st$1$0 >> 2];
    __label__ = 546;
    break;
   case 546:
    var $_idx133_val$0;
    var $_idx133_val$1;
    var $2377 = __ZNK2JS5Value8isObjectEv($_idx133_val$0, $_idx133_val$1);
    if ($2377) {
      __label__ = 547;
      break;
    } else {
      __label__ = 548;
      break;
    }
   case 547:
    var $2379 = __ZNK2JS5Value8toObjectEv($_idx133_val$0, $_idx133_val$1);
    var $obj200_0 = $2379;
    __label__ = 550;
    break;
   case 548:
    var $2381 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5080, $2334);
    var $2382 = $2381;
    if (($2381 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 549;
      break;
    }
   case 549:
    __ZN2JS5Value9setObjectER8JSObject($2334, $2382);
    var $obj200_0 = $2382;
    __label__ = 550;
    break;
   case 550:
    var $obj200_0;
    var $_idx277 = $2335 | 0;
    var $st$2$0 = $_idx277 | 0;
    var $_idx277_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx277 + 4 | 0;
    var $_idx277_val$1 = HEAP32[$st$2$1 >> 2];
    var $2386 = __ZNK2JS5Value7isInt32Ev($_idx277_val$0, $_idx277_val$1);
    if ($2386) {
      __label__ = 551;
      break;
    } else {
      __label__ = 561;
      break;
    }
   case 551:
    var $2388 = __ZNK2JS5Value7toInt32Ev($_idx277_val$0, $_idx277_val$1);
    var $obj200_0_idx_val = HEAP32[$obj200_0 + 4 >> 2];
    var $2389 = __ZNK8JSObject12isDenseArrayEv($obj200_0_idx_val);
    if ($2389) {
      __label__ = 552;
      break;
    } else {
      __label__ = 554;
      break;
    }
   case 552:
    var $2391 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj200_0);
    if ($2388 >>> 0 < $2391 >>> 0) {
      __label__ = 553;
      break;
    } else {
      __label__ = 559;
      break;
    }
   case 553:
    var $obj200_0_idx219_val = HEAP32[$obj200_0 + 32 >> 2];
    var $2394 = __ZN8JSObject20getDenseArrayElementEj($obj200_0_idx219_val, $2388);
    var $_idx379 = $2394 | 0;
    var $st$4$0 = $_idx379 | 0;
    var $_idx379_val$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $_idx379 + 4 | 0;
    var $_idx379_val$1 = HEAP32[$st$4$1 >> 2];
    var $2395 = __ZNK2JS5Value7isMagicEv($_idx379_val$0, $_idx379_val$1);
    if ($2395) {
      __label__ = 559;
      break;
    } else {
      var $copyFrom_0 = $2394;
      __label__ = 571;
      break;
    }
   case 554:
    var $2397 = __ZNK8JSObject11isArgumentsEv($obj200_0);
    if ($2397) {
      __label__ = 555;
      break;
    } else {
      __label__ = 559;
      break;
    }
   case 555:
    var $2399 = __ZN8JSObject11asArgumentsEv($obj200_0);
    var $2400 = __ZNK2js15ArgumentsObject13initialLengthEv($2399);
    if ($2388 >>> 0 < $2400 >>> 0) {
      __label__ = 556;
      break;
    } else {
      __label__ = 559;
      break;
    }
   case 556:
    var $2403 = __ZNK2js15ArgumentsObject7elementEj($2399, $2388);
    var $_idx353 = $2403 | 0;
    var $st$2$0 = $_idx353 | 0;
    var $_idx353_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx353 + 4 | 0;
    var $_idx353_val$1 = HEAP32[$st$2$1 >> 2];
    var $2404 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx353_val$0, $_idx353_val$1);
    if ($2404) {
      __label__ = 559;
      break;
    } else {
      __label__ = 557;
      break;
    }
   case 557:
    var $2406 = __ZNK2js15ArgumentsObject15maybeStackFrameEv($2399);
    if (($2406 | 0) == 0) {
      var $copyFrom_0 = $2403;
      __label__ = 571;
      break;
    } else {
      __label__ = 558;
      break;
    }
   case 558:
    var $2409 = __ZNK2js10StackFrame18canonicalActualArgEj($2406, $2388);
    var $copyFrom_0 = $2409;
    __label__ = 571;
    break;
   case 559:
    var $2411 = _INT_FITS_IN_JSID1825($2388);
    if (($2411 | 0) == 0) {
      __label__ = 564;
      break;
    } else {
      __label__ = 560;
      break;
    }
   case 560:
    var $2414 = _INT_TO_JSID1826($2388);
    HEAP32[$id202 >> 2] = $2414;
    var $2426 = $2414;
    __label__ = 566;
    break;
   case 561:
    var $2416 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($2335, $i205);
    if ($2416) {
      __label__ = 562;
      break;
    } else {
      __label__ = 564;
      break;
    }
   case 562:
    var $2418 = HEAP32[$i205 >> 2];
    var $2419 = _INT_FITS_IN_JSID1825($2418);
    if (($2419 | 0) == 0) {
      __label__ = 564;
      break;
    } else {
      __label__ = 563;
      break;
    }
   case 563:
    var $2422 = _INT_TO_JSID1826($2418);
    HEAP32[$id202 >> 2] = $2422;
    var $2426 = $2422;
    __label__ = 566;
    break;
   case 564:
    var $2424 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPi($cx, $obj200_0, $2335, $id202);
    if ($2424) {
      __label__ = 565;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 565:
    var $2426 = HEAP32[$id202 >> 2];
    __label__ = 566;
    break;
   case 566:
    var $2426;
    var $2427 = _JSID_IS_STRING1834($2426);
    if (($2427 | 0) == 0) {
      __label__ = 570;
      break;
    } else {
      __label__ = 567;
      break;
    }
   case 567:
    var $script_1_idx340_val = HEAP32[$script_1 + 100 >> 2];
    var $2430 = __ZN8JSScript11hasAnalysisEv($script_1_idx340_val);
    if ($2430) {
      __label__ = 568;
      break;
    } else {
      __label__ = 570;
      break;
    }
   case 568:
    var $regs_idx42_val = HEAP32[$regs_idx73 >> 2];
    var $2432 = __ZNK2js9FrameRegs2fpEv($regs_idx42_val);
    var $_idx164_val = HEAP32[$2432 >> 2];
    var $2433 = __ZNK2js10StackFrame11hasImacropcEv($_idx164_val);
    if ($2433) {
      __label__ = 570;
      break;
    } else {
      __label__ = 569;
      break;
    }
   case 569:
    var $script_1_idx342_val_idx_val = HEAP32[$script_1_idx340_val >> 2];
    var $2435 = __ZN8JSScript8analysisEv($script_1_idx342_val_idx_val);
    var $2436 = HEAP32[$_pre_phi >> 2];
    var $_idx374_val = HEAP32[$2435 + 4 >> 2];
    var $_idx373_val_idx_val = HEAP32[HEAP32[$2435 >> 2] >> 2];
    var $2437 = __ZN2js7analyze14ScriptAnalysis7getCodeEPKh($_idx373_val_idx_val, $_idx374_val, $2436);
    var $2439 = $2437 + 1 | 0;
    var $2441 = HEAP8[$2439] | 32;
    HEAP8[$2439] = $2441;
    __label__ = 570;
    break;
   case 570:
    var $2443 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($obj200_0, $cx, $2426, $rval201);
    if (($2443 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $copyFrom_0 = $rval201;
      __label__ = 571;
      break;
    }
   case 571:
    var $copyFrom_0;
    var $2445 = HEAP32[$_pre_phi580 >> 2];
    var $2446 = $2445 - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $2446;
    var $2447 = $copyFrom_0 | 0;
    var $st$5$0 = $2447 | 0;
    var $2448$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $2447 + 4 | 0;
    var $2448$1 = HEAP32[$st$5$1 >> 2];
    var $2449 = $2445 - 16 | 0;
    var $st$10$0 = $2449 | 0;
    HEAP32[$st$10$0 >> 2] = $2448$0;
    var $st$10$1 = $2449 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $2448$1;
    var $2450 = HEAP32[$_pre_phi >> 2];
    var $2452 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $2450, $2452);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 572:
    var $2455 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    var $st$2$0 = $2455 | 0;
    var $2456$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $2455 + 4 | 0;
    var $2456$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5110 | 0;
    HEAP32[$st$6$0 >> 2] = $2456$0;
    var $st$6$1 = $5110 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $2456$1;
    var $2457 = __ZN2js19ValuePropertyBearerEP9JSContextRKN2JS5ValueEi($cx, $thisv206);
    if (($2457 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 573;
      break;
    }
   case 573:
    var $2461 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $2462 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($2461, $i_209);
    if ($2462) {
      __label__ = 574;
      break;
    } else {
      __label__ = 576;
      break;
    }
   case 574:
    var $2464 = HEAP32[$i_209 >> 2];
    var $2465 = _INT_FITS_IN_JSID1825($2464);
    if (($2465 | 0) == 0) {
      __label__ = 576;
      break;
    } else {
      __label__ = 575;
      break;
    }
   case 575:
    var $2468 = _INT_TO_JSID1826($2464);
    HEAP32[$id207 >> 2] = $2468;
    var $2474 = $2468;
    __label__ = 578;
    break;
   case 576:
    var $2471 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $2472 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $2457, $2461, $id207, $2471);
    if ($2472) {
      __label__ = 577;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 577:
    var $2474 = HEAP32[$id207 >> 2];
    __label__ = 578;
    break;
   case 578:
    var $2474;
    var $2476 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    var $2477 = $2457;
    var $2478 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($5080, $2477, $2474, 2, $2476);
    if (($2478 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 579;
      break;
    }
   case 579:
    var $2481 = HEAP32[$_pre_phi580 >> 2];
    var $_idx232 = $2481 - 16 | 0;
    var $st$2$0 = $_idx232 | 0;
    var $_idx232_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx232 + 4 | 0;
    var $_idx232_val$1 = HEAP32[$st$2$1 >> 2];
    var $2482 = __ZNK2JS5Value11isPrimitiveEv($_idx232_val$0, $_idx232_val$1);
    var $st$8$0 = $5110 | 0;
    var $thisv206_idx_val$0 = HEAP32[$st$8$0 >> 2];
    var $st$8$1 = $5110 + 4 | 0;
    var $thisv206_idx_val$1 = HEAP32[$st$8$1 >> 2];
    if ($2482) {
      __label__ = 580;
      break;
    } else {
      var $2493$1 = $thisv206_idx_val$1;
      var $2493$0 = $thisv206_idx_val$0;
      __label__ = 582;
      break;
    }
   case 580:
    var $2484 = __ZNK2JS5Value8isObjectEv($thisv206_idx_val$0, $thisv206_idx_val$1);
    if ($2484) {
      __label__ = 581;
      break;
    } else {
      var $2493$1 = $thisv206_idx_val$1;
      var $2493$0 = $thisv206_idx_val$0;
      __label__ = 582;
      break;
    }
   case 581:
    var $2486 = $2481 - 8 | 0;
    var $st$1$0 = $2486 | 0;
    var $2487$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $2486 + 4 | 0;
    var $2487$1 = HEAP32[$st$1$1 >> 2];
    var $st$5$0 = $_idx232 | 0;
    HEAP32[$st$5$0 >> 2] = $2487$0;
    var $st$5$1 = $_idx232 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $2487$1;
    var $2489 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    __ZN2JS5Value9setObjectER8JSObject($2489, $2457);
    var $2491 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    var $2492 = __ZN2js15OnUnknownMethodEP9JSContextPN2JS5ValueE($cx, $2491);
    if ($2492) {
      __label__ = 583;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 582:
    var $2493$0;
    var $2493$1;
    var $2494 = $2481 - 8 | 0;
    var $st$3$0 = $2494 | 0;
    HEAP32[$st$3$0 >> 2] = $2493$0;
    var $st$3$1 = $2494 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $2493$1;
    __label__ = 583;
    break;
   case 583:
    var $2496 = HEAP32[$_pre_phi >> 2];
    var $2498 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $2496, $2498);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 584:
    var $2500 = HEAP32[$_pre_phi580 >> 2];
    var $2501 = $2500 - 24 | 0;
    var $_idx102 = $2501 | 0;
    var $st$3$0 = $_idx102 | 0;
    var $_idx102_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx102 + 4 | 0;
    var $_idx102_val$1 = HEAP32[$st$3$1 >> 2];
    var $2502 = __ZNK2JS5Value8isObjectEv($_idx102_val$0, $_idx102_val$1);
    if ($2502) {
      __label__ = 585;
      break;
    } else {
      __label__ = 586;
      break;
    }
   case 585:
    var $2504 = __ZNK2JS5Value8toObjectEv($_idx102_val$0, $_idx102_val$1);
    var $obj210_0 = $2504;
    var $2511 = $2500;
    __label__ = 588;
    break;
   case 586:
    var $2506 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5080, $2501);
    var $2507 = $2506;
    if (($2506 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 587;
      break;
    }
   case 587:
    __ZN2JS5Value9setObjectER8JSObject($2501, $2507);
    var $obj210_0 = $2507;
    var $2511 = HEAP32[$_pre_phi580 >> 2];
    __label__ = 588;
    break;
   case 588:
    var $2511;
    var $obj210_0;
    var $2512 = $2511 - 16 | 0;
    var $2513 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($2512, $i_214);
    if ($2513) {
      __label__ = 589;
      break;
    } else {
      __label__ = 591;
      break;
    }
   case 589:
    var $2515 = HEAP32[$i_214 >> 2];
    var $2516 = _INT_FITS_IN_JSID1825($2515);
    if (($2516 | 0) == 0) {
      __label__ = 591;
      break;
    } else {
      __label__ = 590;
      break;
    }
   case 590:
    var $2519 = _INT_TO_JSID1826($2515);
    HEAP32[$id212 >> 2] = $2519;
    var $2525 = $2519;
    __label__ = 593;
    break;
   case 591:
    var $2522 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    var $2523 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $obj210_0, $2512, $id212, $2522);
    if ($2523) {
      __label__ = 592;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 592:
    var $2525 = HEAP32[$id212 >> 2];
    __label__ = 593;
    break;
   case 593:
    var $2525;
    __ZN2js5types10TypeScript13MonitorAssignEP9JSContextP8JSScriptPhP8JSObjectiRKN2JS5ValueE($cx, $obj210_0, $2525);
    var $obj210_0_idx_val = HEAP32[$obj210_0 + 4 >> 2];
    var $2526 = __ZNK8JSObject12isDenseArrayEv($obj210_0_idx_val);
    if ($2526) {
      __label__ = 594;
      break;
    } else {
      __label__ = 604;
      break;
    }
   case 594:
    var $2528 = _JSID_IS_INT1835($2525);
    if (($2528 | 0) == 0) {
      __label__ = 604;
      break;
    } else {
      __label__ = 595;
      break;
    }
   case 595:
    var $2531 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj210_0);
    var $2532 = _JSID_TO_INT1836($2525);
    if ($2532 >>> 0 < $2531 >>> 0) {
      __label__ = 596;
      break;
    } else {
      __label__ = 601;
      break;
    }
   case 596:
    var $obj210_0_idx218_val = HEAP32[$obj210_0 + 32 >> 2];
    var $2535 = __ZN8JSObject20getDenseArrayElementEj($obj210_0_idx218_val, $2532);
    var $_idx354 = $2535 | 0;
    var $st$4$0 = $_idx354 | 0;
    var $_idx354_val$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $_idx354 + 4 | 0;
    var $_idx354_val$1 = HEAP32[$st$4$1 >> 2];
    var $2536 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx354_val$0, $_idx354_val$1);
    if ($2536) {
      __label__ = 597;
      break;
    } else {
      __label__ = 600;
      break;
    }
   case 597:
    var $2538 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject($obj210_0);
    if (($2538 | 0) == 0) {
      __label__ = 598;
      break;
    } else {
      __label__ = 604;
      break;
    }
   case 598:
    var $obj210_0_idx376_val = HEAP32[$obj210_0 + 24 >> 2];
    var $2541 = __ZNK8JSObject14getArrayLengthEv($obj210_0_idx376_val);
    if ($2532 >>> 0 < $2541 >>> 0) {
      __label__ = 600;
      break;
    } else {
      __label__ = 599;
      break;
    }
   case 599:
    var $2544 = $2532 + 1 | 0;
    __ZN8JSObject14setArrayLengthEP9JSContextj($obj210_0, $cx, $2544);
    __label__ = 600;
    break;
   case 600:
    var $2547 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    __ZN8JSObject28setDenseArrayElementWithTypeEP9JSContextjRKN2JS5ValueE($obj210_0, $cx, $2532, $2547);
    __label__ = 605;
    break;
   case 601:
    var $script_1_idx339_val = HEAP32[$script_1 + 100 >> 2];
    var $2549 = __ZN8JSScript11hasAnalysisEv($script_1_idx339_val);
    if ($2549) {
      __label__ = 602;
      break;
    } else {
      __label__ = 604;
      break;
    }
   case 602:
    var $regs_idx41_val = HEAP32[$regs_idx73 >> 2];
    var $2551 = __ZNK2js9FrameRegs2fpEv($regs_idx41_val);
    var $_idx163_val = HEAP32[$2551 >> 2];
    var $2552 = __ZNK2js10StackFrame11hasImacropcEv($_idx163_val);
    if ($2552) {
      __label__ = 604;
      break;
    } else {
      __label__ = 603;
      break;
    }
   case 603:
    var $script_1_idx341_val_idx_val = HEAP32[$script_1_idx339_val >> 2];
    var $2554 = __ZN8JSScript8analysisEv($script_1_idx341_val_idx_val);
    var $2555 = HEAP32[$_pre_phi >> 2];
    var $_idx372_val = HEAP32[$2554 + 4 >> 2];
    var $_idx371_val_idx_val = HEAP32[HEAP32[$2554 >> 2] >> 2];
    var $2556 = __ZN2js7analyze14ScriptAnalysis7getCodeEPKh($_idx371_val_idx_val, $_idx372_val, $2555);
    var $2558 = $2556 + 1 | 0;
    var $2560 = HEAP8[$2558] | 16;
    HEAP8[$2558] = $2560;
    __label__ = 604;
    break;
   case 604:
    var $2563 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$2$0 = $2563 | 0;
    var $2564$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $2563 + 4 | 0;
    var $2564$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5081 | 0;
    HEAP32[$st$6$0 >> 2] = $2564$0;
    var $st$6$1 = $5081 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $2564$1;
    var $2569 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $2570 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($obj210_0, $cx, $2525, $rval215, $2569);
    if (($2570 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 605;
      break;
    }
   case 605:
    var $2573 = HEAPU32[$_pre_phi >> 2];
    var $2577 = HEAPU32[$_pre_phi580 >> 2];
    if (HEAP8[$2573 + 1 | 0] << 24 >> 24 == 81) {
      __label__ = 606;
      break;
    } else {
      __label__ = 607;
      break;
    }
   case 606:
    HEAP32[$_pre_phi580 >> 2] = $2577 - 24 | 0;
    var $2580 = $2573 + 2 | 0;
    HEAP32[$_pre_phi >> 2] = $2580;
    var $script_1 = $script_1;
    var $pcCounts_1 = $pcCounts_1;
    var $argv_1 = $argv_1;
    var $atoms_1 = $atoms_1;
    var $op_0 = HEAPU8[$2580] & 255;
    __label__ = 18;
    break;
   case 607:
    var $2584 = $2577 - 16 | 0;
    var $2585 = $2577 - 8 | 0;
    var $st$2$0 = $2585 | 0;
    var $2586$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $2585 + 4 | 0;
    var $2586$1 = HEAP32[$st$2$1 >> 2];
    var $2587 = $2577 - 24 | 0;
    var $st$7$0 = $2587 | 0;
    HEAP32[$st$7$0 >> 2] = $2586$0;
    var $st$7$1 = $2587 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $2586$1;
    HEAP32[$_pre_phi580 >> 2] = $2584;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 608:
    var $2589 = HEAPU32[$_pre_phi580 >> 2];
    var $2590 = $2589 - 16 | 0;
    var $_idx101 = $2590 | 0;
    var $st$3$0 = $_idx101 | 0;
    var $_idx101_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx101 + 4 | 0;
    var $_idx101_val$1 = HEAP32[$st$3$1 >> 2];
    var $2591 = __ZNK2JS5Value8isObjectEv($_idx101_val$0, $_idx101_val$1);
    if ($2591) {
      __label__ = 609;
      break;
    } else {
      __label__ = 610;
      break;
    }
   case 609:
    var $2593 = __ZNK2JS5Value8toObjectEv($_idx101_val$0, $_idx101_val$1);
    var $obj219_0 = $2593;
    var $2600 = $2589;
    __label__ = 612;
    break;
   case 610:
    var $2595 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5080, $2590);
    var $2596 = $2595;
    if (($2595 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 611;
      break;
    }
   case 611:
    __ZN2JS5Value9setObjectER8JSObject($2590, $2596);
    var $obj219_0 = $2596;
    var $2600 = HEAP32[$_pre_phi580 >> 2];
    __label__ = 612;
    break;
   case 612:
    var $2600;
    var $obj219_0;
    var $2601 = $2600 - 8 | 0;
    var $2602 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($2601, $i_223);
    if ($2602) {
      __label__ = 613;
      break;
    } else {
      __label__ = 615;
      break;
    }
   case 613:
    var $2604 = HEAP32[$i_223 >> 2];
    var $2605 = _INT_FITS_IN_JSID1825($2604);
    if (($2605 | 0) == 0) {
      __label__ = 615;
      break;
    } else {
      __label__ = 614;
      break;
    }
   case 614:
    var $2608 = _INT_TO_JSID1826($2604);
    HEAP32[$id221 >> 2] = $2608;
    var $2614 = $2608;
    __label__ = 617;
    break;
   case 615:
    var $2611 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $2612 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $obj219_0, $2601, $id221, $2611);
    if ($2612) {
      __label__ = 616;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 616:
    var $2614 = HEAP32[$id221 >> 2];
    __label__ = 617;
    break;
   case 617:
    var $2614;
    var $2616 = HEAP32[$_pre_phi580 >> 2] - 24 | 0;
    var $st$3$0 = $2616 | 0;
    var $2617$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $2616 + 4 | 0;
    var $2617$1 = HEAP32[$st$3$1 >> 2];
    var $st$7$0 = $5111 | 0;
    HEAP32[$st$7$0 >> 2] = $2617$0;
    var $st$7$1 = $5111 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $2617$1;
    var $2622 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $2623 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($obj219_0, $cx, $2614, $rval224, $2622);
    if (($2623 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 618;
      break;
    }
   case 618:
    var $2627 = HEAP32[$_pre_phi580 >> 2] - 24 | 0;
    HEAP32[$_pre_phi580 >> 2] = $2627;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 619:
    var $2629 = HEAPU32[$_pre_phi >> 2];
    var $2637 = (HEAPU8[$2629 + 1 | 0] & 255) << 8 | HEAPU8[$2629 + 2 | 0] & 255;
    var $2638 = HEAP32[$_pre_phi580 >> 2];
    __ZN2js14CallArgsFromSpEjPN2JS5ValueE($args, $2637, $2638);
    var $regs_idx40_val = HEAP32[$regs_idx73 >> 2];
    var $2639 = __ZNK2js9FrameRegs2fpEv($regs_idx40_val);
    var $2640 = __ZNK2js10StackFrame10scopeChainEv($2639);
    var $_idx162_val = HEAP32[$_idx162 >> 2];
    var $2641 = __ZNK2js12CallReceiver7calleevEv($_idx162_val);
    var $2642 = $2640;
    var $_idx430 = $2641 | 0;
    var $st$18$0 = $_idx430 | 0;
    var $_idx430_val$0 = HEAP32[$st$18$0 >> 2];
    var $st$18$1 = $_idx430 + 4 | 0;
    var $_idx430_val$1 = HEAP32[$st$18$1 >> 2];
    var $2643 = __ZN2js21IsBuiltinEvalForScopeEP8JSObjectRKN2JS5ValueE($2642, $_idx430_val$0, $_idx430_val$1);
    if ($2643) {
      __label__ = 620;
      break;
    } else {
      __label__ = 621;
      break;
    }
   case 620:
    var $2645 = __ZN2js10DirectEvalEP9JSContextRKNS_8CallArgsE($5080, $args);
    if ($2645) {
      __label__ = 622;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 621:
    var $2647 = __ZN2js12InvokeKernelEP9JSContextRKNS_8CallArgsENS_14MaybeConstructE($cx, $args, 0);
    if ($2647) {
      __label__ = 622;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 622:
    if ((HEAP32[HEAP32[$34 >> 2] >> 2] | 0) == 0) {
      __label__ = 624;
      break;
    } else {
      __label__ = 623;
      break;
    }
   case 623:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 624;
    break;
   case 624:
    var $_idx432_val = HEAP32[$_idx162 >> 2];
    var $2655 = __ZNK2js12CallReceiver11spAfterCallEv($_idx432_val);
    HEAP32[$_pre_phi580 >> 2] = $2655;
    var $2656 = HEAP32[$_pre_phi >> 2];
    var $2657 = $2655 - 8 | 0;
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $2656, $2657);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 625:
    var $2658 = HEAPU32[$_pre_phi >> 2];
    var $2666 = (HEAPU8[$2658 + 1 | 0] & 255) << 8 | HEAPU8[$2658 + 2 | 0] & 255;
    var $2667 = HEAP32[$_pre_phi580 >> 2];
    __ZN2js14CallArgsFromSpEjPN2JS5ValueE($args225, $2666, $2667);
    var $2670 = HEAP8[HEAP32[$_pre_phi >> 2]] << 24 >> 24 == 82;
    var $_idx161_val = HEAP32[$_idx161 >> 2];
    var $2671 = __ZNK2js12CallReceiver7calleevEv($_idx161_val);
    var $_idx434 = $2671 | 0;
    var $st$17$0 = $_idx434 | 0;
    var $_idx434_val$0 = HEAP32[$st$17$0 >> 2];
    var $st$17$1 = $_idx434 + 4 | 0;
    var $_idx434_val$1 = HEAP32[$st$17$1 >> 2];
    var $2672 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction1837($_idx434_val$0, $_idx434_val$1, $callee, $fun);
    if ($2672) {
      __label__ = 626;
      break;
    } else {
      __label__ = 627;
      break;
    }
   case 626:
    var $2674 = HEAPU32[$fun >> 2];
    var $_idx435_val = HEAP16[$2674 + 58 >> 1];
    var $2675 = __ZNK10JSFunction24isInterpretedConstructorEv($_idx435_val);
    if ($2675) {
      __label__ = 632;
      break;
    } else {
      __label__ = 627;
      break;
    }
   case 627:
    if ($2670) {
      __label__ = 628;
      break;
    } else {
      __label__ = 629;
      break;
    }
   case 628:
    var $2678 = __ZN2js23InvokeConstructorKernelEP9JSContextRKNS_8CallArgsE($cx, $args225);
    if ($2678) {
      __label__ = 630;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 629:
    var $2680 = __ZN2js12InvokeKernelEP9JSContextRKNS_8CallArgsENS_14MaybeConstructE($cx, $args225, 0);
    if ($2680) {
      __label__ = 630;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 630:
    var $_idx431_val = HEAP32[$_idx161 >> 2];
    var $2682 = __ZNK2js12CallReceiver11spAfterCallEv($_idx431_val);
    HEAP32[$_pre_phi580 >> 2] = $2682;
    var $2683 = HEAP32[$_pre_phi >> 2];
    var $2684 = $2682 - 8 | 0;
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $2683, $2684);
    if ((HEAP32[HEAP32[$34 >> 2] >> 2] | 0) == 0) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    } else {
      __label__ = 631;
      break;
    }
   case 631:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 632:
    __ZN2js5types15TypeMonitorCallEP9JSContextRKNS_8CallArgsEb($cx, $args225, $2670);
    var $2691 = $2670 ? 128 : 0;
    var $2692 = __ZNK10JSFunction6scriptEv($2674);
    var $2693 = HEAP32[$callee >> 2];
    var $2694 = __ZN2js12ContextStack15pushInlineFrameEP9JSContextRNS_9FrameRegsERKNS_8CallArgsER8JSObjectP10JSFunctionP8JSScriptNS_17InitialFrameFlagsE($5082, $cx, $regs, $args225, $2693, $2674, $2692, $2691);
    if ($2694) {
      __label__ = 633;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 633:
    var $regs_idx39_val = HEAP32[$regs_idx73 >> 2];
    var $2696 = __ZNK2js9FrameRegs2fpEv($regs_idx39_val);
    var $2697 = __ZNK2js10StackFrame6scriptEv($2696);
    var $_idx380_val = HEAP32[$2697 + 24 >> 2];
    var $2698 = __ZN8JSScript15stepModeEnabledEv($_idx380_val);
    if ($2698) {
      __label__ = 634;
      break;
    } else {
      __label__ = 635;
      break;
    }
   case 634:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 635;
    break;
   case 635:
    var $_idx387_val = HEAP32[$2697 + 96 >> 2];
    var $2701 = __ZN12JSPCCounters3getEi($_idx387_val);
    if (($2701 | 0) == 0) {
      __label__ = 637;
      break;
    } else {
      __label__ = 636;
      break;
    }
   case 636:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 637;
    break;
   case 637:
    var $regs_idx38_val = HEAP32[$regs_idx73 >> 2];
    var $2704 = __ZNK2js9FrameRegs2fpEv($regs_idx38_val);
    var $2705 = __ZNK2js10StackFrame15maybeFormalArgsEv($2704);
    var $2706 = __ZN2jsL13FrameAtomBaseEP9JSContextPNS_10StackFrameE($cx, $2704);
    var $2707 = __ZN2js10StackFrame16functionPrologueEP9JSContext($2704, $cx);
    if ($2707) {
      __label__ = 638;
      break;
    } else {
      var $script_2_ph1347 = $2697;
      var $pcCounts_2_ph1346 = $2701;
      var $argv_2_ph1345 = $2705;
      __label__ = 1016;
      break;
    }
   case 638:
    var $cx_idx234_val = HEAP8[$cx_idx234];
    var $2709 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx234_val);
    if ($2709) {
      __label__ = 639;
      break;
    } else {
      var $2714 = 0;
      __label__ = 640;
      break;
    }
   case 639:
    var $2711 = HEAP32[$_pre_phi >> 2];
    var $2712 = __ZN2js5types10UseNewTypeEP9JSContextP8JSScriptPh($cx, $2697, $2711);
    var $2714 = $2712;
    __label__ = 640;
    break;
   case 640:
    var $2714;
    var $regs_idx37_val = HEAP32[$regs_idx73 >> 2];
    var $2715 = __ZNK2js9FrameRegs2fpEv($regs_idx37_val);
    var $2716 = __ZN2js14ScriptPrologueEP9JSContextPNS_10StackFrameEb($cx, $2715, $2714);
    if ($2716) {
      __label__ = 641;
      break;
    } else {
      var $script_2_ph1347 = $2697;
      var $pcCounts_2_ph1346 = $2701;
      var $argv_2_ph1345 = $2705;
      __label__ = 1016;
      break;
    }
   case 641:
    if ((HEAP32[HEAP32[$34 >> 2] >> 2] | 0) == 0) {
      __label__ = 643;
      break;
    } else {
      __label__ = 642;
      break;
    }
   case 642:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 643;
    break;
   case 643:
    var $script_1 = $2697;
    var $pcCounts_1 = $2701;
    var $argv_1 = $2705;
    var $atoms_1 = $2706;
    var $op_0 = HEAPU8[HEAP32[$_pre_phi >> 2]] & 255;
    __label__ = 18;
    break;
   case 644:
    _JS_ReportErrorNumber($cx, 4, 129, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 645:
    var $regs_idx36_val = HEAP32[$regs_idx73 >> 2];
    var $2729 = __ZNK2js9FrameRegs2fpEv($regs_idx36_val);
    var $2730 = __ZNK2js10StackFrame10scopeChainEv($2729);
    HEAP32[$obj226 >> 2] = $2730;
    var $2734 = (HEAP32[_js_CodeSpec + ($op_0 << 3) + 4 >> 2] & 33554432 | 0) != 0;
    if ($2734) {
      __label__ = 646;
      break;
    } else {
      __label__ = 647;
      break;
    }
   case 646:
    var $2736 = $2730;
    var $2737 = __ZNK8JSObject9getGlobalEv($2736);
    var $2738 = $2737;
    HEAP32[$obj226 >> 2] = $2738;
    __label__ = 647;
    break;
   case 647:
    var $2741 = HEAP32[$22 >> 2] + 144336 | 0;
    var $2742 = HEAP32[$_pre_phi >> 2];
    __ZN2js13PropertyCache4testEP9JSContextPhRP8JSObjectS6_RPNS_18PropertyCacheEntryERP6JSAtom($2741, $cx, $2742, $obj226, $obj2231, $entry230, $atom232);
    var $2743 = HEAPU32[$atom232 >> 2];
    if (($2743 | 0) == 0) {
      __label__ = 648;
      break;
    } else {
      __label__ = 662;
      break;
    }
   case 648:
    var $2746 = HEAP32[$entry230 >> 2];
    var $_idx420_val = HEAPU32[$2746 + 12 >> 2];
    var $2747 = __ZNK2js5PCVal8isFunObjEv($_idx420_val);
    if ($2747) {
      __label__ = 649;
      break;
    } else {
      __label__ = 650;
      break;
    }
   case 649:
    var $2749 = HEAP32[$_pre_phi580 >> 2];
    var $2750 = $2749 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $2750;
    var $_idx423_val = HEAP32[$2746 + 12 >> 2];
    var $2751 = __ZNK2js5PCVal8toFunObjEv($_idx423_val);
    __ZN2JS5Value9setObjectER8JSObject($2749, $2751);
    __label__ = 659;
    break;
   case 650:
    var $2753 = __ZNK2js5PCVal6isSlotEv($_idx420_val);
    if ($2753) {
      __label__ = 651;
      break;
    } else {
      __label__ = 652;
      break;
    }
   case 651:
    var $2755 = __ZNK2js5PCVal6toSlotEv($_idx420_val);
    var $2756 = HEAP32[$_pre_phi580 >> 2];
    var $2757 = $2756 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $2757;
    var $2758 = HEAP32[$obj2231 >> 2];
    var $2759 = __ZNK8JSObject13nativeGetSlotEj($2758, $2755);
    var $2760 = $2759 | 0;
    var $st$7$0 = $2760 | 0;
    var $2761$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $2760 + 4 | 0;
    var $2761$1 = HEAP32[$st$7$1 >> 2];
    var $2762 = $2756 | 0;
    var $st$12$0 = $2762 | 0;
    HEAP32[$st$12$0 >> 2] = $2761$0;
    var $st$12$1 = $2762 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $2761$1;
    __label__ = 659;
    break;
   case 652:
    var $2764 = __ZNK2js5PCVal7toShapeEv($_idx420_val);
    var $_idx333_val = HEAP8[$2764 + 28 | 0];
    var $2765 = __ZNK2js5Shape16isDataDescriptorEv($_idx333_val);
    if ($2765) {
      __label__ = 653;
      break;
    } else {
      __label__ = 657;
      break;
    }
   case 653:
    var $_idx246_val = HEAP32[$2764 + 16 >> 2];
    var $2767 = __ZNK2js5Shape16hasDefaultGetterEv($_idx246_val);
    if ($2767) {
      __label__ = 654;
      break;
    } else {
      __label__ = 657;
      break;
    }
   case 654:
    var $2770 = HEAP32[$2764 + 24 >> 2];
    if (($2770 | 0) == -1) {
      __label__ = 656;
      break;
    } else {
      __label__ = 655;
      break;
    }
   case 655:
    var $2773 = HEAP32[$obj2231 >> 2];
    var $2774 = __ZNK8JSObject13nativeGetSlotEj($2773, $2770);
    var $2775 = $2774 | 0;
    var $st$3$0 = $2775 | 0;
    var $2776$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $2775 + 4 | 0;
    var $2776$1 = HEAP32[$st$3$1 >> 2];
    var $st$7$0 = $5113 | 0;
    HEAP32[$st$7$0 >> 2] = $2776$0;
    var $st$7$1 = $5113 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $2776$1;
    __label__ = 658;
    break;
   case 656:
    __ZN2JS5Value12setUndefinedEv($rval229);
    __label__ = 658;
    break;
   case 657:
    var $2781 = HEAP32[$obj226 >> 2];
    var $2782 = HEAP32[$obj2231 >> 2];
    var $2783 = $2764;
    var $2784 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($5080, $2781, $2782, $2783, 0, $rval229);
    if (($2784 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 658;
      break;
    }
   case 658:
    var $2786 = HEAP32[$_pre_phi580 >> 2];
    var $2787 = $2786 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $2787;
    var $st$3$0 = $5113 | 0;
    var $2788$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5113 + 4 | 0;
    var $2788$1 = HEAP32[$st$3$1 >> 2];
    var $2789 = $2786 | 0;
    var $st$8$0 = $2789 | 0;
    HEAP32[$st$8$0 >> 2] = $2788$0;
    var $st$8$1 = $2789 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $2788$1;
    __label__ = 659;
    break;
   case 659:
    var $2791 = HEAP32[$_pre_phi >> 2];
    var $2793 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $2791, $2793);
    if (($op_0 | 0) == 214 || ($op_0 | 0) == 57) {
      __label__ = 660;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    }
   case 660:
    var $2794 = HEAP32[$obj226 >> 2];
    var $2796 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $2797 = __ZN2js19ComputeImplicitThisEP9JSContextP8JSObjectRKN2JS5ValueEPS5_($cx, $2794, $2796, $v);
    if ($2797) {
      __label__ = 661;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 661:
    var $2799 = HEAP32[$_pre_phi580 >> 2];
    var $2800 = $2799 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $2800;
    var $st$3$0 = $5112 | 0;
    var $2801$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5112 + 4 | 0;
    var $2801$1 = HEAP32[$st$3$1 >> 2];
    var $2802 = $2799 | 0;
    var $st$8$0 = $2802 | 0;
    HEAP32[$st$8$0 >> 2] = $2801$0;
    var $st$8$1 = $2802 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $2801$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 662:
    var $2804 = __ZL12ATOM_TO_JSIDP6JSAtom1798($2743);
    var $2805 = __Z21js_FindPropertyHelperP9JSContextibbPP8JSObjectS3_PP10JSProperty($5080, $2804, 1, $2734, $5114, $5115, $5116);
    if (($2805 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 663;
      break;
    }
   case 663:
    var $2808 = HEAP32[$prop235 >> 2];
    if (($2808 | 0) == 0) {
      __label__ = 664;
      break;
    } else {
      __label__ = 666;
      break;
    }
   case 664:
    var $2812 = HEAP32[$_pre_phi >> 2] + 3 | 0;
    var $2813 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh1793($script_1, $2812);
    if (($2813 | 0) == 39) {
      __label__ = 665;
      break;
    } else {
      var $atomNotDefined_0 = $2743;
      __label__ = 1048;
      break;
    }
   case 665:
    var $2816 = HEAP32[$_pre_phi580 >> 2];
    var $2817 = $2816 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $2817;
    __ZN2JS5Value12setUndefinedEv($2816);
    var $2818 = HEAP32[$_pre_phi >> 2];
    var $2820 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $2818, $2820);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 666:
    var $2822 = HEAP32[$obj226 >> 2];
    var $_idx204_val = HEAP32[$2822 >> 2];
    var $2823 = __ZNK8JSObject8isNativeEv($_idx204_val);
    if ($2823) {
      __label__ = 667;
      break;
    } else {
      __label__ = 668;
      break;
    }
   case 667:
    var $2825 = HEAP32[$obj2231 >> 2];
    var $_idx203_val = HEAP32[$2825 >> 2];
    var $2826 = __ZNK8JSObject8isNativeEv($_idx203_val);
    if ($2826) {
      __label__ = 669;
      break;
    } else {
      __label__ = 668;
      break;
    }
   case 668:
    var $2828 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($2822, $cx, $2804, $rval229);
    if (($2828 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 678;
      break;
    }
   case 669:
    var $2831 = $2808;
    var $_idx188_val = HEAP32[$2822 + 4 >> 2];
    var $2832 = __ZNK8JSObject8getClassEv($_idx188_val);
    if (($2832 | 0) == (__ZN2js9WithClassE | 0)) {
      __label__ = 670;
      break;
    } else {
      var $normalized_0 = $2822;
      __label__ = 672;
      break;
    }
   case 670:
    var $_idx245_val = HEAP32[$2831 + 16 >> 2];
    var $2835 = __ZNK2js5Shape16hasDefaultGetterEv($_idx245_val);
    if ($2835) {
      var $normalized_0 = $2822;
      __label__ = 672;
      break;
    } else {
      __label__ = 671;
      break;
    }
   case 671:
    var $_idx416_val_idx_val = HEAP32[HEAP32[$2822 + 36 >> 2] >> 2];
    var $2837 = __Z19js_UnwrapWithObjectP9JSContextP8JSObject($_idx416_val_idx_val);
    var $normalized_0 = $2837;
    __label__ = 672;
    break;
   case 672:
    var $normalized_0;
    var $_idx332_val = HEAP8[$2831 + 28 | 0];
    var $2839 = __ZNK2js5Shape16isDataDescriptorEv($_idx332_val);
    if ($2839) {
      __label__ = 673;
      break;
    } else {
      __label__ = 677;
      break;
    }
   case 673:
    var $_idx244_val = HEAP32[$2831 + 16 >> 2];
    var $2841 = __ZNK2js5Shape16hasDefaultGetterEv($_idx244_val);
    if ($2841) {
      __label__ = 674;
      break;
    } else {
      __label__ = 677;
      break;
    }
   case 674:
    var $2844 = HEAP32[$2831 + 24 >> 2];
    if (($2844 | 0) == -1) {
      __label__ = 676;
      break;
    } else {
      __label__ = 675;
      break;
    }
   case 675:
    var $2847 = __ZNK8JSObject13nativeGetSlotEj($2825, $2844);
    var $2848 = $2847 | 0;
    var $st$2$0 = $2848 | 0;
    var $2849$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $2848 + 4 | 0;
    var $2849$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5113 | 0;
    HEAP32[$st$6$0 >> 2] = $2849$0;
    var $st$6$1 = $5113 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $2849$1;
    __label__ = 678;
    break;
   case 676:
    __ZN2JS5Value12setUndefinedEv($rval229);
    __label__ = 678;
    break;
   case 677:
    var $2853 = $2825;
    var $2854 = $2808;
    var $2855 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($5080, $normalized_0, $2853, $2854, 0, $rval229);
    if (($2855 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 678;
      break;
    }
   case 678:
    var $2857 = HEAP32[$_pre_phi580 >> 2];
    var $2858 = $2857 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $2858;
    var $st$3$0 = $5113 | 0;
    var $2859$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5113 + 4 | 0;
    var $2859$1 = HEAP32[$st$3$1 >> 2];
    var $2860 = $2857 | 0;
    var $st$8$0 = $2860 | 0;
    HEAP32[$st$8$0 >> 2] = $2859$0;
    var $st$8$1 = $2860 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $2859$1;
    var $2861 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $2861, $rval229);
    if (($op_0 | 0) == 214 || ($op_0 | 0) == 57) {
      __label__ = 679;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    }
   case 679:
    var $2863 = __ZN2js19ComputeImplicitThisEP9JSContextP8JSObjectRKN2JS5ValueEPS5_($cx, $2822, $rval229, $v236);
    if ($2863) {
      __label__ = 680;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 680:
    var $2865 = HEAP32[$_pre_phi580 >> 2];
    var $2866 = $2865 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $2866;
    var $st$3$0 = $5117 | 0;
    var $2867$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5117 + 4 | 0;
    var $2867$1 = HEAP32[$st$3$1 >> 2];
    var $2868 = $2865 | 0;
    var $st$8$0 = $2868 | 0;
    HEAP32[$st$8$0 >> 2] = $2867$0;
    var $st$8$1 = $2868 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $2867$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 681:
    var $2870 = HEAPU32[$_pre_phi580 >> 2];
    HEAP32[$_pre_phi580 >> 2] = $2870 + 8 | 0;
    var $2872 = HEAPU32[$_pre_phi >> 2];
    var $2880 = (HEAPU8[$2872 + 1 | 0] & 255) << 8 | HEAPU8[$2872 + 2 | 0] & 255;
    __ZN2JS5Value8setInt32Ei($2870, $2880);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 682:
    var $2882 = HEAPU32[$_pre_phi580 >> 2];
    HEAP32[$_pre_phi580 >> 2] = $2882 + 8 | 0;
    var $2884 = HEAPU32[$_pre_phi >> 2];
    var $2897 = HEAPU8[$2884 + 3 | 0] & 255 | (HEAPU8[$2884 + 1 | 0] & 255) << 16 | (HEAPU8[$2884 + 2 | 0] & 255) << 8;
    __ZN2JS5Value8setInt32Ei($2882, $2897);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 4;
    __label__ = 17;
    break;
   case 683:
    var $2899 = HEAPU32[$_pre_phi580 >> 2];
    HEAP32[$_pre_phi580 >> 2] = $2899 + 8 | 0;
    var $2904 = HEAP8[HEAP32[$_pre_phi >> 2] + 1 | 0] << 24 >> 24;
    __ZN2JS5Value8setInt32Ei($2899, $2904);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 2;
    __label__ = 17;
    break;
   case 684:
    var $2906 = HEAPU32[$_pre_phi580 >> 2];
    HEAP32[$_pre_phi580 >> 2] = $2906 + 8 | 0;
    var $2908 = HEAPU32[$_pre_phi >> 2];
    var $2926 = (HEAPU8[$2908 + 2 | 0] & 255) << 16 | (HEAPU8[$2908 + 1 | 0] & 255) << 24 | HEAPU8[$2908 + 4 | 0] & 255 | (HEAPU8[$2908 + 3 | 0] & 255) << 8;
    __ZN2JS5Value8setInt32Ei($2906, $2926);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 5;
    __label__ = 17;
    break;
   case 685:
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1 + ((HEAPU8[HEAP32[$_pre_phi >> 2] + 1 | 0] & 255) << 16 << 2) | 0;
    var $len_0 = 2;
    __label__ = 17;
    break;
   case 686:
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1 + (($op_0 << 16) - 13762560 << 2) | 0;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 687:
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = HEAP32[$script_1 + 56 >> 2];
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 688:
    var $2948 = HEAPU32[$_pre_phi >> 2];
    var $2957 = ((HEAPU8[$2948 + 1 | 0] & 255) << 8 | HEAPU8[$2948 + 2 | 0] & 255) + ($atoms_1 - HEAP32[$script_1 + 56 >> 2] >> 2) | 0;
    var $script_1_idx258_val = HEAP32[$script_1 + 4 >> 2];
    var $script_1_idx259_val = HEAP8[$script_1 + 21 | 0];
    var $2958 = __ZN8JSScript8getConstEj($script_1_idx258_val, $script_1_idx259_val, $2957);
    var $2959 = __ZNK2JS5Value8toDoubleEv($2958);
    var $2960 = HEAP32[$_pre_phi580 >> 2];
    var $2961 = $2960 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $2961;
    __ZN2JS5Value9setDoubleEd($2960, $2959);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 689:
    var $2963 = HEAPU32[$_pre_phi >> 2];
    var $2973 = HEAP32[$atoms_1 + (((HEAPU8[$2963 + 1 | 0] & 255) << 8 | HEAPU8[$2963 + 2 | 0] & 255) << 2) >> 2];
    var $2974 = HEAPU32[$_pre_phi580 >> 2];
    HEAP32[$_pre_phi580 >> 2] = $2974 + 8 | 0;
    var $2976 = $2973 | 0;
    __ZN2JS5Value9setStringEP8JSString($2974, $2976);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 690:
    var $2984 = HEAPU32[$_pre_phi >> 2];
    var $2993 = ((HEAPU8[$2984 + 1 | 0] & 255) << 8 | HEAPU8[$2984 + 2 | 0] & 255) + ($atoms_1 - HEAP32[$script_1 + 56 >> 2] >> 2) | 0;
    var $script_1_idx158_val = HEAP32[$script_1 + 4 >> 2];
    var $script_1_idx159_val = HEAP8[$script_1 + 16 | 0];
    var $2994 = __ZN8JSScript9getObjectEj($script_1_idx158_val, $script_1_idx159_val, $2993);
    var $2995 = HEAP32[$_pre_phi580 >> 2];
    var $2996 = $2995 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $2996;
    __ZN2JS5Value9setObjectER8JSObject($2995, $2994);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 691:
    var $2999 = HEAP32[$script_1 + 56 >> 2];
    var $3000 = HEAP32[$_pre_phi >> 2];
    var $3002 = HEAPU8[$3000 + 1 | 0];
    var $3004 = HEAPU8[$3000 + 2 | 0];
    var $regs_idx35_val = HEAP32[$regs_idx73 >> 2];
    var $3005 = __ZNK2js9FrameRegs2fpEv($regs_idx35_val);
    var $3006 = __ZNK2js10StackFrame10scopeChainEv($3005);
    var $3007 = $3006;
    var $3008 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($5080, $3007, 10, $5118, 0);
    if (($3008 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 692;
      break;
    }
   case 692:
    var $3019 = (($3002 & 255) << 8 | $3004 & 255) + ($atoms_1 - $2999 >> 2) | 0;
    var $3020 = __ZN8JSScript9getRegExpEj($script_1, $3019);
    var $3022 = $3020;
    var $3023 = HEAP32[$proto >> 2];
    var $3024 = __Z20js_CloneRegExpObjectP9JSContextP8JSObjectS2_($5083, $3022, $3023);
    if (($3024 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 693;
      break;
    }
   case 693:
    var $3027 = $3024;
    var $3028 = HEAP32[$_pre_phi580 >> 2];
    var $3029 = $3028 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $3029;
    __ZN2JS5Value9setObjectER8JSObject($3028, $3027);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 694:
    var $3031 = HEAP32[$_pre_phi580 >> 2];
    var $3032 = $3031 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $3032;
    __ZN2JS5Value8setInt32Ei($3031, 0);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 695:
    var $3034 = HEAP32[$_pre_phi580 >> 2];
    var $3035 = $3034 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $3035;
    __ZN2JS5Value8setInt32Ei($3034, 1);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 696:
    var $3037 = HEAP32[$_pre_phi580 >> 2];
    var $3038 = $3037 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $3038;
    __ZN2JS5Value7setNullEv($3037);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 697:
    var $3040 = HEAP32[$_pre_phi580 >> 2];
    var $3041 = $3040 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $3041;
    __ZN2JS5Value10setBooleanEb($3040, 0);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 698:
    var $3043 = HEAP32[$_pre_phi580 >> 2];
    var $3044 = $3043 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $3044;
    __ZN2JS5Value10setBooleanEb($3043, 1);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 699:
    var $3046 = HEAPU32[$_pre_phi >> 2];
    var $3055 = ((HEAPU8[$3046 + 1 | 0] & 255) << 8 | HEAPU8[$3046 + 2 | 0] & 255) << 16 >> 16;
    var $3057 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $3057;
    var $_idx276 = $3057 | 0;
    var $st$14$0 = $_idx276 | 0;
    var $_idx276_val$0 = HEAPU32[$st$14$0 >> 2];
    var $st$14$1 = $_idx276 + 4 | 0;
    var $_idx276_val$1 = HEAP32[$st$14$1 >> 2];
    var $3058 = __ZNK2JS5Value7isInt32Ev($_idx276_val$0, $_idx276_val$1);
    if ($3058) {
      __label__ = 700;
      break;
    } else {
      __label__ = 701;
      break;
    }
   case 700:
    var $3060 = __ZNK2JS5Value7toInt32Ev($_idx276_val$0, $_idx276_val$1);
    var $i241_0 = $3060;
    __label__ = 703;
    break;
   case 701:
    var $3062 = __ZNK2JS5Value8isDoubleEv($_idx276_val$0, $_idx276_val$1);
    if ($3062) {
      __label__ = 702;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = $3055;
      __label__ = 17;
      break;
    }
   case 702:
    var $3064 = __ZNK2JS5Value8toDoubleEv($3057);
    var $3065 = $3064 & -1;
    if ($3064 != ($3065 | 0)) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = $3055;
      __label__ = 17;
      break;
    } else {
      var $i241_0 = $3065;
      __label__ = 703;
      break;
    }
   case 703:
    var $i241_0;
    var $3077 = ((HEAPU8[$3046 + 3 | 0] & 255) << 8 | HEAPU8[$3046 + 4 | 0] & 255) << 16 >> 16;
    var $3087 = $i241_0 - $3077 | 0;
    if ($3087 >>> 0 < (1 - $3077 + (((HEAPU8[$3046 + 5 | 0] & 255) << 8 | HEAPU8[$3046 + 6 | 0] & 255) << 16 >> 16) | 0) >>> 0) {
      __label__ = 704;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = $3055;
      __label__ = 17;
      break;
    }
   case 704:
    var $3092 = $3087 << 1;
    var $3100 = (HEAPU8[$3092 + ($3046 + 7) | 0] & 255) << 8 | HEAPU8[$3092 + ($3046 + 8) | 0] & 255;
    if ($3100 << 16 >> 16 == 0) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = $3055;
      __label__ = 17;
      break;
    } else {
      __label__ = 705;
      break;
    }
   case 705:
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = $3100 << 16 >> 16;
    __label__ = 17;
    break;
   case 706:
    var $3105 = HEAPU32[$_pre_phi >> 2];
    var $3123 = (HEAPU8[$3105 + 2 | 0] & 255) << 16 | (HEAPU8[$3105 + 1 | 0] & 255) << 24 | HEAPU8[$3105 + 4 | 0] & 255 | (HEAPU8[$3105 + 3 | 0] & 255) << 8;
    var $3125 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $3125;
    var $_idx275 = $3125 | 0;
    var $_idx275_val$0 = HEAPU32[$_idx275 >> 2];
    var $_idx275_val$1 = HEAP32[$_idx275 + 4 >> 2];
    var $3126 = __ZNK2JS5Value7isInt32Ev($_idx275_val$0, $_idx275_val$1);
    if ($3126) {
      __label__ = 707;
      break;
    } else {
      __label__ = 708;
      break;
    }
   case 707:
    var $3128 = __ZNK2JS5Value7toInt32Ev($_idx275_val$0, $_idx275_val$1);
    var $i245_0 = $3128;
    __label__ = 710;
    break;
   case 708:
    var $3130 = __ZNK2JS5Value8isDoubleEv($_idx275_val$0, $_idx275_val$1);
    if ($3130) {
      __label__ = 709;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = $3123;
      __label__ = 17;
      break;
    }
   case 709:
    var $3132 = __ZNK2JS5Value8toDoubleEv($3125);
    if ($3132 == 0) {
      var $i245_0 = 0;
      __label__ = 710;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = $3123;
      __label__ = 17;
      break;
    }
   case 710:
    var $i245_0;
    var $3143 = ((HEAPU8[$3105 + 5 | 0] & 255) << 8 | HEAPU8[$3105 + 6 | 0] & 255) << 16 >> 16;
    var $3153 = $i245_0 - $3143 | 0;
    if ($3153 >>> 0 < (1 - $3143 + (((HEAPU8[$3105 + 7 | 0] & 255) << 8 | HEAPU8[$3105 + 8 | 0] & 255) << 16 >> 16) | 0) >>> 0) {
      __label__ = 711;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = $3123;
      __label__ = 17;
      break;
    }
   case 711:
    var $3159 = $3153 << 2 | 2;
    var $3177 = (HEAPU8[$3159 + ($3105 + 8) | 0] & 255) << 16 | (HEAPU8[$3159 + ($3105 + 7) | 0] & 255) << 24 | HEAPU8[$3159 + ($3105 + 10) | 0] & 255 | (HEAPU8[$3159 + ($3105 + 9) | 0] & 255) << 8;
    if (($3177 | 0) == 0) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = $3123;
      __label__ = 17;
      break;
    } else {
      __label__ = 712;
      break;
    }
   case 712:
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = $3177;
    __label__ = 17;
    break;
   case 713:
    var $off249_0 = 2;
    __label__ = 714;
    break;
   case 714:
    var $off249_0;
    var $3180 = HEAPU32[$_pre_phi >> 2];
    var $3181 = HEAPU32[$_pre_phi580 >> 2];
    var $3182 = $3181 - 8 | 0;
    var $st$4$0 = $3182 | 0;
    var $3183$0 = HEAPU32[$st$4$0 >> 2];
    var $st$4$1 = $3182 + 4 | 0;
    var $3183$1 = HEAPU32[$st$4$1 >> 2];
    var $st$8$0 = $5119 | 0;
    HEAP32[$st$8$0 >> 2] = $3183$0;
    var $st$8$1 = $5119 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $3183$1;
    HEAP32[$_pre_phi580 >> 2] = $3181 - 8 | 0;
    var $3185 = __ZNK2JS5Value11isPrimitiveEv($3183$0, $3183$1);
    if ($3185) {
      __label__ = 715;
      break;
    } else {
      var $pc2250_3 = $3180;
      __label__ = 731;
      break;
    }
   case 715:
    var $_sum39 = $off249_0 + 2 | 0;
    var $3191 = $3180 + $_sum39 | 0;
    var $3194 = (HEAPU8[$3180 + ($off249_0 | 1) | 0] & 255) << 8 | HEAPU8[$3191] & 255;
    var $3195 = __ZNK2JS5Value8isStringEv($3183$0, $3183$1);
    if ($3195) {
      __label__ = 716;
      break;
    } else {
      __label__ = 723;
      break;
    }
   case 716:
    var $3197 = __ZNK2JS5Value8toStringEv($3183$0, $3183$1);
    var $3198 = __ZN8JSString12ensureLinearEP9JSContext($3197, $cx);
    if (($3198 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 717;
      break;
    }
   case 717:
    var $script_1_idx256_val = HEAP32[$script_1 + 4 >> 2];
    var $script_1_idx257_val = HEAP8[$script_1 + 21 | 0];
    var $npairs_0 = $3194;
    var $pc2250_0 = $3191;
    __label__ = 718;
    break;
   case 718:
    var $pc2250_0;
    var $npairs_0;
    var $3204 = $pc2250_0 + 2 | 0;
    var $3207 = (HEAPU8[$pc2250_0 + 1 | 0] & 255) << 8 | HEAPU8[$3204] & 255;
    var $3208 = __ZN8JSScript8getConstEj($script_1_idx256_val, $script_1_idx257_val, $3207);
    var $3209 = $3208 | 0;
    var $st$12$0 = $3209 | 0;
    var $3210$0 = HEAPU32[$st$12$0 >> 2];
    var $st$12$1 = $3209 + 4 | 0;
    var $3210$1 = HEAP32[$st$12$1 >> 2];
    var $3211 = __ZNK2JS5Value8isStringEv($3210$0, $3210$1);
    if ($3211) {
      __label__ = 719;
      break;
    } else {
      __label__ = 721;
      break;
    }
   case 719:
    var $3213 = __ZNK2JS5Value8toStringEv($3210$0, $3210$1);
    var $3214 = __ZN8JSString8asLinearEv($3213);
    if (($3214 | 0) == ($3198 | 0)) {
      var $pc2250_3 = $3204;
      __label__ = 731;
      break;
    } else {
      __label__ = 720;
      break;
    }
   case 720:
    var $3217 = __ZN2js12EqualStringsEP14JSLinearStringS1_($3214, $3198);
    if ($3217) {
      var $pc2250_3 = $3204;
      __label__ = 731;
      break;
    } else {
      __label__ = 721;
      break;
    }
   case 721:
    var $3219 = $npairs_0 - 1 | 0;
    if (($3219 | 0) == 0) {
      __label__ = 722;
      break;
    } else {
      var $npairs_0 = $3219;
      var $pc2250_0 = $pc2250_0 + $_sum39 | 0;
      __label__ = 718;
      break;
    }
   case 722:
    var $pc2250_3 = HEAP32[$_pre_phi >> 2];
    __label__ = 731;
    break;
   case 723:
    var $3224 = __ZNK2JS5Value8isNumberEv($3183$0, $3183$1);
    if ($3224) {
      __label__ = 725;
      break;
    } else {
      __label__ = 724;
      break;
    }
   case 724:
    var $script_1_idx252_val = HEAP32[$script_1 + 4 >> 2];
    var $script_1_idx253_val = HEAP8[$script_1 + 21 | 0];
    var $npairs_2 = $3194;
    var $pc2250_2 = $3191;
    __label__ = 729;
    break;
   case 725:
    var $3226 = __ZNK2JS5Value8toNumberEv($lval251);
    var $script_1_idx254 = $script_1 + 4 | 0;
    var $script_1_idx255 = $script_1 + 21 | 0;
    var $npairs_1 = $3194;
    var $pc2250_1 = $3191;
    __label__ = 726;
    break;
   case 726:
    var $pc2250_1;
    var $npairs_1;
    var $3232 = $pc2250_1 + 2 | 0;
    var $3235 = (HEAPU8[$pc2250_1 + 1 | 0] & 255) << 8 | HEAPU8[$3232] & 255;
    var $script_1_idx254_val = HEAP32[$script_1_idx254 >> 2];
    var $script_1_idx255_val = HEAP8[$script_1_idx255];
    var $3236 = __ZN8JSScript8getConstEj($script_1_idx254_val, $script_1_idx255_val, $3235);
    var $3237 = $3236 | 0;
    var $st$14$0 = $3237 | 0;
    var $3238$0 = HEAPU32[$st$14$0 >> 2];
    var $st$14$1 = $3237 + 4 | 0;
    var $3238$1 = HEAP32[$st$14$1 >> 2];
    var $st$18$0 = $5120 | 0;
    HEAP32[$st$18$0 >> 2] = $3238$0;
    var $st$18$1 = $5120 + 4 | 0;
    HEAP32[$st$18$1 >> 2] = $3238$1;
    var $3239 = __ZNK2JS5Value8isNumberEv($3238$0, $3238$1);
    if ($3239) {
      __label__ = 727;
      break;
    } else {
      __label__ = 728;
      break;
    }
   case 727:
    var $3241 = __ZNK2JS5Value8toNumberEv($rval254);
    if ($3226 == $3241) {
      var $pc2250_3 = $3232;
      __label__ = 731;
      break;
    } else {
      __label__ = 728;
      break;
    }
   case 728:
    var $3244 = $npairs_1 - 1 | 0;
    if (($3244 | 0) == 0) {
      var $pc2250_3 = $3180;
      __label__ = 731;
      break;
    } else {
      var $npairs_1 = $3244;
      var $pc2250_1 = $pc2250_1 + $_sum39 | 0;
      __label__ = 726;
      break;
    }
   case 729:
    var $pc2250_2;
    var $npairs_2;
    var $3250 = $pc2250_2 + 2 | 0;
    var $3253 = (HEAPU8[$pc2250_2 + 1 | 0] & 255) << 8 | HEAPU8[$3250] & 255;
    var $3254 = __ZN8JSScript8getConstEj($script_1_idx252_val, $script_1_idx253_val, $3253);
    var $3255 = $3254 | 0;
    var $st$12$0 = $3255 | 0;
    var $3256$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $3255 + 4 | 0;
    var $3256$1 = HEAP32[$st$12$1 >> 2];
    var $3257 = __ZNK2JS5ValueeqERKS0_($3183$0, $3183$1, $3256$0, $3256$1);
    if ($3257) {
      var $pc2250_3 = $3250;
      __label__ = 731;
      break;
    } else {
      __label__ = 730;
      break;
    }
   case 730:
    var $3260 = $npairs_2 - 1 | 0;
    if (($3260 | 0) == 0) {
      var $pc2250_3 = $3180;
      __label__ = 731;
      break;
    } else {
      var $npairs_2 = $3260;
      var $pc2250_2 = $pc2250_2 + $_sum39 | 0;
      __label__ = 729;
      break;
    }
   case 731:
    var $pc2250_3;
    var $3265 = HEAPU8[$pc2250_3 + 1 | 0] & 255;
    if (($op_0 | 0) == 71) {
      __label__ = 732;
      break;
    } else {
      __label__ = 733;
      break;
    }
   case 732:
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = (HEAPU8[$pc2250_3 + 2 | 0] & 255 | $3265 << 8) << 16 >> 16;
    __label__ = 17;
    break;
   case 733:
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = (HEAPU8[$pc2250_3 + 2 | 0] & 255) << 16 | $3265 << 24 | HEAPU8[$pc2250_3 + 4 | 0] & 255 | (HEAPU8[$pc2250_3 + 3 | 0] & 255) << 8;
    __label__ = 17;
    break;
   case 734:
    var $3290 = __ZN2js8Debugger6onTrapEP9JSContextPN2JS5ValueE($cx, $rval256);
    if (($3290 | 0) == 2) {
      __label__ = 735;
      break;
    } else if (($3290 | 0) == 3) {
      __label__ = 736;
      break;
    } else if (($3290 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 737;
      break;
    }
   case 735:
    var $regs_idx34_val = HEAP32[$regs_idx73 >> 2];
    var $3292 = __ZNK2js9FrameRegs2fpEv($regs_idx34_val);
    var $3293 = $3292;
    var $st$3$0 = $rval256_idx | 0;
    var $rval256_idx390_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $rval256_idx + 4 | 0;
    var $rval256_idx390_val$1 = HEAP32[$st$3$1 >> 2];
    __ZN2js10StackFrame14setReturnValueERKN2JS5ValueE($3293, $rval256_idx390_val$0, $rval256_idx390_val$1);
    var $interpReturnOK_1 = 1;
    __label__ = 1044;
    break;
   case 736:
    var $st$0$0 = $rval256_idx | 0;
    var $3295$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $rval256_idx + 4 | 0;
    var $3295$1 = HEAP32[$st$0$1 >> 2];
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($cx, $3295$0, $3295$1);
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 737:
    if ((HEAP32[HEAP32[$34 >> 2] >> 2] | 0) == 0) {
      __label__ = 739;
      break;
    } else {
      __label__ = 738;
      break;
    }
   case 738:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 739;
    break;
   case 739:
    var $st$0$0 = $rval256_idx | 0;
    var $rval256_idx_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $rval256_idx + 4 | 0;
    var $rval256_idx_val$1 = HEAP32[$st$0$1 >> 2];
    var $3303 = __ZNK2JS5Value7toInt32Ev($rval256_idx_val$0, $rval256_idx_val$1);
    var $script_1 = $script_1;
    var $pcCounts_1 = $pcCounts_1;
    var $argv_1 = $argv_1;
    var $atoms_1 = $atoms_1;
    var $op_0 = $3303;
    __label__ = 18;
    break;
   case 740:
    var $cx_idx233_val = HEAP8[$cx_idx234];
    var $3305 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx233_val);
    if ($3305) {
      __label__ = 741;
      break;
    } else {
      __label__ = 746;
      break;
    }
   case 741:
    if ((HEAP8[$script_1 + 36 | 0] & 8) << 24 >> 24 == 0) {
      __label__ = 742;
      break;
    } else {
      __label__ = 746;
      break;
    }
   case 742:
    var $3312 = __ZN8JSScript18ensureRanInferenceEP9JSContext($script_1, $cx);
    if ($3312) {
      __label__ = 743;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 743:
    if ((HEAP8[$script_1 + 38 | 0] & 2) << 24 >> 24 == 0) {
      __label__ = 745;
      break;
    } else {
      __label__ = 744;
      break;
    }
   case 744:
    var $regs_idx33_val = HEAP32[$regs_idx73 >> 2];
    var $3319 = __ZNK2js9FrameRegs2fpEv($regs_idx33_val);
    var $3320 = __Z15js_GetArgsValueP9JSContextPN2js10StackFrameEPN2JS5ValueE($cx, $3319, $rval258);
    if (($3320 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 747;
      break;
    }
   case 745:
    __ZN2JSL10MagicValueE10JSWhyMagic1838($7);
    var $st$1$0 = $5121 | 0;
    var $3323$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $5121 + 4 | 0;
    var $3323$1 = HEAP32[$st$1$1 >> 2];
    var $st$5$0 = $5122 | 0;
    HEAP32[$st$5$0 >> 2] = $3323$0;
    var $st$5$1 = $5122 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $3323$1;
    __label__ = 747;
    break;
   case 746:
    var $regs_idx32_val = HEAP32[$regs_idx73 >> 2];
    var $3325 = __ZNK2js9FrameRegs2fpEv($regs_idx32_val);
    var $3326 = __Z15js_GetArgsValueP9JSContextPN2js10StackFrameEPN2JS5ValueE($cx, $3325, $rval258);
    if (($3326 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 747;
      break;
    }
   case 747:
    var $3328 = HEAP32[$_pre_phi580 >> 2];
    var $3329 = $3328 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $3329;
    var $st$3$0 = $5122 | 0;
    var $3330$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5122 + 4 | 0;
    var $3330$1 = HEAP32[$st$3$1 >> 2];
    var $3331 = $3328 | 0;
    var $st$8$0 = $3331 | 0;
    HEAP32[$st$8$0 >> 2] = $3330$0;
    var $st$8$1 = $3331 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $3330$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 748:
    var $3333 = HEAPU32[$_pre_phi >> 2];
    var $3341 = (HEAPU8[$3333 + 1 | 0] & 255) << 8 | HEAPU8[$3333 + 2 | 0] & 255;
    var $3342 = _INT_TO_JSID1826($3341);
    var $regs_idx31_val = HEAP32[$regs_idx73 >> 2];
    var $3343 = __ZNK2js9FrameRegs2fpEv($regs_idx31_val);
    var $3344 = __Z18js_GetArgsPropertyP9JSContextPN2js10StackFrameEiPN2JS5ValueE($cx, $3343, $3342, $rval260);
    if (($3344 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 749;
      break;
    }
   case 749:
    var $3347 = HEAP32[$_pre_phi580 >> 2];
    var $3348 = $3347 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $3348;
    var $st$3$0 = $5123 | 0;
    var $3349$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5123 + 4 | 0;
    var $3349$1 = HEAP32[$st$3$1 >> 2];
    var $3350 = $3347 | 0;
    var $st$8$0 = $3350 | 0;
    HEAP32[$st$8$0 >> 2] = $3349$0;
    var $st$8$1 = $3350 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $3349$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 750:
    var $3353 = HEAP32[$5124 >> 2] | 0;
    var $3354 = __ZL12ATOM_TO_JSIDP6JSAtom1798($3353);
    var $regs_idx30_val = HEAP32[$regs_idx73 >> 2];
    var $3355 = __ZNK2js9FrameRegs2fpEv($regs_idx30_val);
    var $3356 = __Z18js_GetArgsPropertyP9JSContextPN2js10StackFrameEiPN2JS5ValueE($cx, $3355, $3354, $rval262);
    if (($3356 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 751;
      break;
    }
   case 751:
    var $3359 = HEAP32[$_pre_phi580 >> 2];
    var $3360 = $3359 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $3360;
    var $st$3$0 = $5125 | 0;
    var $3361$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5125 + 4 | 0;
    var $3361$1 = HEAP32[$st$3$1 >> 2];
    var $3362 = $3359 | 0;
    var $st$8$0 = $3362 | 0;
    HEAP32[$st$8$0 >> 2] = $3361$0;
    var $st$8$1 = $3362 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $3361$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 752:
    var $3363 = HEAPU32[$_pre_phi >> 2];
    var $3371 = (HEAPU8[$3363 + 1 | 0] & 255) << 8 | HEAPU8[$3363 + 2 | 0] & 255;
    var $3372 = HEAPU32[$_pre_phi580 >> 2];
    HEAP32[$_pre_phi580 >> 2] = $3372 + 8 | 0;
    var $3374 = $argv_1 + ($3371 << 3) | 0;
    var $st$13$0 = $3374 | 0;
    var $3375$0 = HEAP32[$st$13$0 >> 2];
    var $st$13$1 = $3374 + 4 | 0;
    var $3375$1 = HEAP32[$st$13$1 >> 2];
    var $3376 = $3372 | 0;
    var $st$18$0 = $3376 | 0;
    HEAP32[$st$18$0 >> 2] = $3375$0;
    var $st$18$1 = $3376 + 4 | 0;
    HEAP32[$st$18$1 >> 2] = $3375$1;
    if (($op_0 | 0) == 216) {
      __label__ = 753;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    }
   case 753:
    var $3379 = HEAP32[$_pre_phi580 >> 2];
    var $3380 = $3379 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $3380;
    __ZN2JS5Value12setUndefinedEv($3379);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 754:
    var $3382 = HEAPU32[$_pre_phi >> 2];
    var $3392 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$11$0 = $3392 | 0;
    var $3393$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $3392 + 4 | 0;
    var $3393$1 = HEAP32[$st$11$1 >> 2];
    var $3394 = $argv_1 + (((HEAPU8[$3382 + 1 | 0] & 255) << 8 | HEAPU8[$3382 + 2 | 0] & 255) << 3) | 0;
    var $st$16$0 = $3394 | 0;
    HEAP32[$st$16$0 >> 2] = $3393$0;
    var $st$16$1 = $3394 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $3393$1;
    var $3395 = HEAP32[$_pre_phi >> 2];
    if (HEAP8[$3395 + 3 | 0] << 24 >> 24 == 81) {
      __label__ = 755;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    }
   case 755:
    var $3401 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $3401;
    var $3402 = $3395 + 4 | 0;
    HEAP32[$_pre_phi >> 2] = $3402;
    var $script_1 = $script_1;
    var $pcCounts_1 = $pcCounts_1;
    var $argv_1 = $argv_1;
    var $atoms_1 = $atoms_1;
    var $op_0 = HEAPU8[$3402] & 255;
    __label__ = 18;
    break;
   case 756:
    var $3406 = HEAPU32[$_pre_phi >> 2];
    var $3414 = (HEAPU8[$3406 + 1 | 0] & 255) << 8 | HEAPU8[$3406 + 2 | 0] & 255;
    var $3415 = HEAPU32[$_pre_phi580 >> 2];
    HEAP32[$_pre_phi580 >> 2] = $3415 + 8 | 0;
    var $regs_idx29_val = HEAP32[$regs_idx73 >> 2];
    var $3417 = __ZNK2js9FrameRegs2fpEv($regs_idx29_val);
    var $3418 = $3417;
    var $3419 = __ZNK2js10StackFrame5slotsEv($3418);
    var $3420 = $3419 + ($3414 << 3) | 0;
    var $st$17$0 = $3420 | 0;
    var $3421$0 = HEAP32[$st$17$0 >> 2];
    var $st$17$1 = $3420 + 4 | 0;
    var $3421$1 = HEAP32[$st$17$1 >> 2];
    var $3422 = $3415 | 0;
    var $st$22$0 = $3422 | 0;
    HEAP32[$st$22$0 >> 2] = $3421$0;
    var $st$22$1 = $3422 + 4 | 0;
    HEAP32[$st$22$1 >> 2] = $3421$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 757:
    var $3424 = HEAPU32[$_pre_phi >> 2];
    var $3432 = (HEAPU8[$3424 + 1 | 0] & 255) << 8 | HEAPU8[$3424 + 2 | 0] & 255;
    var $3433 = HEAPU32[$_pre_phi580 >> 2];
    HEAP32[$_pre_phi580 >> 2] = $3433 + 8 | 0;
    var $regs_idx28_val = HEAP32[$regs_idx73 >> 2];
    var $3435 = __ZNK2js9FrameRegs2fpEv($regs_idx28_val);
    var $3436 = $3435;
    var $3437 = __ZNK2js10StackFrame5slotsEv($3436);
    var $3438 = $3437 + ($3432 << 3) | 0;
    var $st$17$0 = $3438 | 0;
    var $3439$0 = HEAP32[$st$17$0 >> 2];
    var $st$17$1 = $3438 + 4 | 0;
    var $3439$1 = HEAP32[$st$17$1 >> 2];
    var $3440 = $3433 | 0;
    var $st$22$0 = $3440 | 0;
    HEAP32[$st$22$0 >> 2] = $3439$0;
    var $st$22$1 = $3440 + 4 | 0;
    HEAP32[$st$22$1 >> 2] = $3439$1;
    var $3441 = HEAP32[$_pre_phi580 >> 2];
    var $3442 = $3441 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $3442;
    __ZN2JS5Value12setUndefinedEv($3441);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 758:
    var $3444 = HEAPU32[$_pre_phi >> 2];
    var $3452 = (HEAPU8[$3444 + 1 | 0] & 255) << 8 | HEAPU8[$3444 + 2 | 0] & 255;
    var $regs_idx27_val = HEAP32[$regs_idx73 >> 2];
    var $3453 = __ZNK2js9FrameRegs2fpEv($regs_idx27_val);
    var $3454 = $3453;
    var $3455 = __ZNK2js10StackFrame5slotsEv($3454);
    var $3457 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$15$0 = $3457 | 0;
    var $3458$0 = HEAP32[$st$15$0 >> 2];
    var $st$15$1 = $3457 + 4 | 0;
    var $3458$1 = HEAP32[$st$15$1 >> 2];
    var $3459 = $3455 + ($3452 << 3) | 0;
    var $st$20$0 = $3459 | 0;
    HEAP32[$st$20$0 >> 2] = $3458$0;
    var $st$20$1 = $3459 + 4 | 0;
    HEAP32[$st$20$1 >> 2] = $3458$1;
    var $3460 = HEAP32[$_pre_phi >> 2];
    if (HEAP8[$3460 + 3 | 0] << 24 >> 24 == 81) {
      __label__ = 759;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    }
   case 759:
    var $3466 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $3466;
    var $3467 = $3460 + 4 | 0;
    HEAP32[$_pre_phi >> 2] = $3467;
    var $script_1 = $script_1;
    var $pcCounts_1 = $pcCounts_1;
    var $argv_1 = $argv_1;
    var $atoms_1 = $atoms_1;
    var $op_0 = HEAPU8[$3467] & 255;
    __label__ = 18;
    break;
   case 760:
    var $3470 = HEAPU32[$_pre_phi >> 2];
    var $3478 = (HEAPU8[$3470 + 1 | 0] & 255) << 8 | HEAPU8[$3470 + 2 | 0] & 255;
    var $_idx130 = $argv_1 - 16 | 0;
    var $st$10$0 = $_idx130 | 0;
    var $_idx130_val$0 = HEAP32[$st$10$0 >> 2];
    var $st$10$1 = $_idx130 + 4 | 0;
    var $_idx130_val$1 = HEAP32[$st$10$1 >> 2];
    var $3479 = __ZNK2JS5Value8toObjectEv($_idx130_val$0, $_idx130_val$1);
    var $3480 = HEAPU32[$_pre_phi580 >> 2];
    HEAP32[$_pre_phi580 >> 2] = $3480 + 8 | 0;
    var $3482 = __ZN8JSObject19getFlatClosureUpvarEj($3479, $3478);
    var $3483 = $3482 | 0;
    var $st$20$0 = $3483 | 0;
    var $3484$0 = HEAP32[$st$20$0 >> 2];
    var $st$20$1 = $3483 + 4 | 0;
    var $3484$1 = HEAP32[$st$20$1 >> 2];
    var $3485 = $3480 | 0;
    HEAP32[$3485 >> 2] = $3484$0;
    HEAP32[$3485 + 4 >> 2] = $3484$1;
    var $3486 = HEAP32[$_pre_phi >> 2];
    var $3488 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $3486, $3488);
    if (($op_0 | 0) == 137) {
      __label__ = 761;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    }
   case 761:
    var $3491 = HEAP32[$_pre_phi580 >> 2];
    var $3492 = $3491 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $3492;
    __ZN2JS5Value12setUndefinedEv($3491);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 762:
    var $3493 = HEAPU32[$_pre_phi >> 2];
    var $3503 = HEAP32[$atoms_1 + (((HEAPU8[$3493 + 1 | 0] & 255) << 8 | HEAPU8[$3493 + 2 | 0] & 255) << 2) >> 2];
    var $regs_idx26_val = HEAP32[$regs_idx73 >> 2];
    var $3504 = __ZNK2js9FrameRegs2fpEv($regs_idx26_val);
    var $3505 = __ZN2js10StackFrame6varObjEv($3504);
    var $regs_idx25_val = HEAP32[$regs_idx73 >> 2];
    var $3506 = __ZNK2js9FrameRegs2fpEv($regs_idx25_val);
    var $_idx95_val = HEAP32[$3506 >> 2];
    var $3507 = __ZNK2js10StackFrame11isEvalFrameEv($_idx95_val);
    var $attrs_0 = $3507 ? 1 : 5;
    var $3508 = __ZL12ATOM_TO_JSIDP6JSAtom1798($3503);
    if (($op_0 | 0) == 129) {
      __label__ = 763;
      break;
    } else {
      __label__ = 765;
      break;
    }
   case 763:
    var $3511 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($3505, $cx, $3508, $obj2275, $prop274);
    if (($3511 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 764;
      break;
    }
   case 764:
    if ((HEAP32[$prop274 >> 2] | 0) == 0) {
      var $attrs_181 = $attrs_0;
      __label__ = 767;
      break;
    } else {
      __label__ = 766;
      break;
    }
   case 765:
    var $3517 = $attrs_0 | 2;
    var $3518 = __ZN2js18CheckRedeclarationEP9JSContextP8JSObjectij($cx, $3505, $3508, $3517);
    if ($3518) {
      var $attrs_181 = $3517;
      __label__ = 767;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 766:
    if ((HEAP32[$obj2275 >> 2] | 0) == ($3505 | 0)) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    } else {
      var $attrs_181 = $attrs_0;
      __label__ = 767;
      break;
    }
   case 767:
    var $attrs_181;
    __ZN2JSL14UndefinedValueEv1839($8);
    var $3522 = $3505;
    var $3523 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($5080, $3522, $3508, $8, 10, 12, $attrs_181, 0, 0, 0);
    if (($3523 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    }
   case 768:
    var $3532 = HEAPU32[$_pre_phi >> 2];
    var $3541 = ((HEAPU8[$3532 + 1 | 0] & 255) << 8 | HEAPU8[$3532 + 2 | 0] & 255) + ($atoms_1 - HEAP32[$script_1 + 56 >> 2] >> 2) | 0;
    var $script_1_idx179_val = HEAP32[$script_1 + 4 >> 2];
    var $script_1_idx180_val = HEAP8[$script_1 + 16 | 0];
    var $3542 = __ZN8JSScript11getFunctionEj($script_1_idx179_val, $script_1_idx180_val, $3541);
    var $3543 = $3542 | 0;
    var $_idx370_val = HEAP16[$3542 + 58 >> 1];
    var $3544 = __ZNK10JSFunction13isNullClosureEv($_idx370_val);
    var $regs_idx24_val = HEAP32[$regs_idx73 >> 2];
    var $3545 = __ZNK2js9FrameRegs2fpEv($regs_idx24_val);
    if ($3544) {
      __label__ = 769;
      break;
    } else {
      __label__ = 770;
      break;
    }
   case 769:
    var $3547 = __ZNK2js10StackFrame10scopeChainEv($3545);
    var $obj2278_0 = $3547;
    __label__ = 771;
    break;
   case 770:
    var $3549 = __ZN2js17GetScopeChainFastEP9JSContextPNS_10StackFrameE4JSOpj($cx, $3545, 3);
    if (($3549 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $obj2278_0 = $3549;
      __label__ = 771;
      break;
    }
   case 771:
    var $obj2278_0;
    var $_idx186_val = HEAP32[$3542 + 20 >> 2];
    var $3552 = __ZNK8JSObject9getParentEv($_idx186_val);
    if (($3552 | 0) == ($obj2278_0 | 0)) {
      var $obj277_0 = $3543;
      __label__ = 773;
      break;
    } else {
      __label__ = 772;
      break;
    }
   case 772:
    var $3555 = __Z19CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectb($cx, $3542, $obj2278_0, 1);
    if (($3555 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $obj277_0 = $3555;
      __label__ = 773;
      break;
    }
   case 773:
    var $obj277_0;
    var $regs_idx23_val = HEAP32[$regs_idx73 >> 2];
    var $3558 = __ZNK2js9FrameRegs2fpEv($regs_idx23_val);
    var $_idx94_val = HEAP32[$3558 >> 2];
    var $3559 = __ZNK2js10StackFrame11isEvalFrameEv($_idx94_val);
    var $3560 = $3559 ? 1 : 5;
    var $3561 = __ZN2js10StackFrame6varObjEv($3558);
    var $3563 = HEAP32[$3542 + 72 >> 2];
    var $3564 = __ZL12ATOM_TO_JSIDP6JSAtom1798($3563);
    HEAP32[$prop281 >> 2] = 0;
    var $3565 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($3561, $cx, $3564, $pobj282, $prop281);
    if (($3565 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 774;
      break;
    }
   case 774:
    __ZN2JSL11ObjectValueER8JSObject1804($rval283, $obj277_0);
    var $3568 = HEAP32[$prop281 >> 2];
    if (($3568 | 0) == 0) {
      __label__ = 776;
      break;
    } else {
      __label__ = 775;
      break;
    }
   case 775:
    if ((HEAP32[$pobj282 >> 2] | 0) == ($3561 | 0)) {
      __label__ = 777;
      break;
    } else {
      __label__ = 776;
      break;
    }
   case 776:
    var $3574 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($3561, $cx, $3564, $rval283, 10, 12, $3560);
    if (($3574 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    }
   case 777:
    var $_idx190_val = HEAP32[$3561 + 4 >> 2];
    var $3577 = __ZNK8JSObject8isGlobalEv($_idx190_val);
    if ($3577) {
      __label__ = 778;
      break;
    } else {
      __label__ = 786;
      break;
    }
   case 778:
    var $_idx331_val = HEAP8[$3568 + 28 | 0];
    var $3580 = __ZNK2js5Shape12configurableEv($_idx331_val);
    if ($3580) {
      __label__ = 779;
      break;
    } else {
      __label__ = 780;
      break;
    }
   case 779:
    var $3582 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($3561, $cx, $3564, $rval283, 10, 12, $3560);
    if (($3582 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    }
   case 780:
    var $3585 = __ZNK2js5Shape20isAccessorDescriptorEv($_idx331_val);
    if ($3585) {
      __label__ = 783;
      break;
    } else {
      __label__ = 781;
      break;
    }
   case 781:
    var $3587 = __ZNK2js5Shape8writableEv($_idx331_val);
    if ($3587) {
      __label__ = 782;
      break;
    } else {
      __label__ = 783;
      break;
    }
   case 782:
    var $3589 = __ZNK2js5Shape10enumerableEv($_idx331_val);
    if ($3589) {
      __label__ = 786;
      break;
    } else {
      __label__ = 783;
      break;
    }
   case 783:
    __ZN16JSAutoByteStringC1Ev($bytes);
    __ZN2jsL9IdToValueEi1799($9, $3564);
    var $3591 = $bytes;
    var $_idx447 = $9 | 0;
    var $st$4$0 = $_idx447 | 0;
    var $_idx447_val$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $_idx447 + 4 | 0;
    var $_idx447_val$1 = HEAP32[$st$4$1 >> 2];
    var $3592 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($5077, $_idx447_val$0, $_idx447_val$1, $3591);
    if (($3592 | 0) == 0) {
      __label__ = 785;
      break;
    } else {
      __label__ = 784;
      break;
    }
   case 784:
    _JS_ReportErrorNumber($cx, 4, 240, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $3592, tempInt));
    __label__ = 785;
    break;
   case 785:
    var $bytes_idx_val = HEAP32[$bytes >> 2];
    __ZN16JSAutoByteStringD1Ev($bytes_idx_val);
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 786:
    var $3601 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $3602 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($3561, $cx, $3564, $rval283, $3601);
    if (($3602 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    }
   case 787:
    var $3611 = HEAPU32[$_pre_phi >> 2];
    var $3620 = ((HEAPU8[$3611 + 1 | 0] & 255) << 8 | HEAPU8[$3611 + 2 | 0] & 255) + ($atoms_1 - HEAP32[$script_1 + 56 >> 2] >> 2) | 0;
    var $script_1_idx177_val = HEAP32[$script_1 + 4 >> 2];
    var $script_1_idx178_val = HEAP8[$script_1 + 16 | 0];
    var $3621 = __ZN8JSScript11getFunctionEj($script_1_idx177_val, $script_1_idx178_val, $3620);
    var $3622 = __Z17js_NewFlatClosureP9JSContextP10JSFunction4JSOpj($cx, $3621);
    if (($3622 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 788;
      break;
    }
   case 788:
    __ZN2JSL11ObjectValueER8JSObject1804($rval287, $3622);
    var $regs_idx22_val = HEAP32[$regs_idx73 >> 2];
    var $3625 = __ZNK2js9FrameRegs2fpEv($regs_idx22_val);
    var $_idx93_val = HEAP32[$3625 >> 2];
    var $3626 = __ZNK2js10StackFrame11isEvalFrameEv($_idx93_val);
    var $3627 = $3626 ? 1 : 5;
    var $3628 = __ZN2js10StackFrame6varObjEv($3625);
    var $3630 = HEAP32[$3621 + 72 >> 2];
    var $3631 = __ZL12ATOM_TO_JSIDP6JSAtom1798($3630);
    var $3632 = __ZN2js18CheckRedeclarationEP9JSContextP8JSObjectij($cx, $3628, $3631, $3627);
    if ($3632) {
      __label__ = 789;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 789:
    if ($3626) {
      __label__ = 790;
      break;
    } else {
      __label__ = 791;
      break;
    }
   case 790:
    var $3639 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $3640 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($3628, $cx, $3631, $rval287, $3639);
    if (($3640 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    }
   case 791:
    var $3643 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($3628, $cx, $3631, $rval287, 10, 12, $3627);
    if (($3643 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    }
   case 792:
    var $3652 = HEAPU32[$_pre_phi >> 2];
    var $3661 = ((HEAPU8[$3652 + 3 | 0] & 255) << 8 | HEAPU8[$3652 + 4 | 0] & 255) + ($atoms_1 - HEAP32[$script_1 + 56 >> 2] >> 2) | 0;
    var $script_1_idx175_val = HEAP32[$script_1 + 4 >> 2];
    var $script_1_idx176_val = HEAP8[$script_1 + 16 | 0];
    var $3662 = __ZN8JSScript11getFunctionEj($script_1_idx175_val, $script_1_idx176_val, $3661);
    var $3663 = $3662 | 0;
    var $_idx369_val = HEAP16[$3662 + 58 >> 1];
    var $3664 = __ZNK10JSFunction13isNullClosureEv($_idx369_val);
    var $regs_idx21_val = HEAP32[$regs_idx73 >> 2];
    var $3665 = __ZNK2js9FrameRegs2fpEv($regs_idx21_val);
    if ($3664) {
      __label__ = 793;
      break;
    } else {
      __label__ = 794;
      break;
    }
   case 793:
    var $3667 = __ZNK2js10StackFrame10scopeChainEv($3665);
    var $3668 = __Z19CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectb($cx, $3662, $3667, 1);
    if (($3668 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $obj292_0 = $3668;
      __label__ = 797;
      break;
    }
   case 794:
    var $3671 = __ZN2js17GetScopeChainFastEP9JSContextPNS_10StackFrameE4JSOpj($cx, $3665, 5);
    if (($3671 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 795;
      break;
    }
   case 795:
    var $_idx185_val = HEAP32[$3662 + 20 >> 2];
    var $3674 = __ZNK8JSObject9getParentEv($_idx185_val);
    if (($3674 | 0) == ($3671 | 0)) {
      var $obj292_0 = $3663;
      __label__ = 797;
      break;
    } else {
      __label__ = 796;
      break;
    }
   case 796:
    var $3677 = __Z19CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectb($cx, $3662, $3671, 1);
    if (($3677 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $obj292_0 = $3677;
      __label__ = 797;
      break;
    }
   case 797:
    var $obj292_0;
    var $3680 = HEAPU32[$_pre_phi >> 2];
    var $3688 = (HEAPU8[$3680 + 1 | 0] & 255) << 8 | HEAPU8[$3680 + 2 | 0] & 255;
    var $regs_idx20_val = HEAP32[$regs_idx73 >> 2];
    var $3689 = __ZNK2js9FrameRegs2fpEv($regs_idx20_val);
    var $3690 = $3689;
    var $3691 = __ZNK2js10StackFrame5slotsEv($3690);
    var $3692 = $3691 + ($3688 << 3) | 0;
    __ZN2JS5Value9setObjectER8JSObject($3692, $obj292_0);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 5;
    __label__ = 17;
    break;
   case 798:
    var $3700 = HEAPU32[$_pre_phi >> 2];
    var $3709 = ((HEAPU8[$3700 + 3 | 0] & 255) << 8 | HEAPU8[$3700 + 4 | 0] & 255) + ($atoms_1 - HEAP32[$script_1 + 56 >> 2] >> 2) | 0;
    var $script_1_idx173_val = HEAP32[$script_1 + 4 >> 2];
    var $script_1_idx174_val = HEAP8[$script_1 + 16 | 0];
    var $3710 = __ZN8JSScript11getFunctionEj($script_1_idx173_val, $script_1_idx174_val, $3709);
    var $3711 = __Z17js_NewFlatClosureP9JSContextP10JSFunction4JSOpj($cx, $3710);
    if (($3711 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 799;
      break;
    }
   case 799:
    var $3714 = HEAPU32[$_pre_phi >> 2];
    var $3722 = (HEAPU8[$3714 + 1 | 0] & 255) << 8 | HEAPU8[$3714 + 2 | 0] & 255;
    var $regs_idx19_val = HEAP32[$regs_idx73 >> 2];
    var $3723 = __ZNK2js9FrameRegs2fpEv($regs_idx19_val);
    var $3724 = $3723;
    var $3725 = __ZNK2js10StackFrame5slotsEv($3724);
    var $3726 = $3725 + ($3722 << 3) | 0;
    __ZN2JS5Value9setObjectER8JSObject($3726, $3711);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 5;
    __label__ = 17;
    break;
   case 800:
    var $3728 = $script_1 + 56 | 0;
    var $3730 = $atoms_1;
    var $3734 = HEAPU32[$_pre_phi >> 2];
    var $3743 = ((HEAPU8[$3734 + 1 | 0] & 255) << 8 | HEAPU8[$3734 + 2 | 0] & 255) + ($3730 - HEAP32[$3728 >> 2] >> 2) | 0;
    var $script_1_idx171_val = HEAP32[$script_1 + 4 >> 2];
    var $script_1_idx172_val = HEAP8[$script_1 + 16 | 0];
    var $3744 = __ZN8JSScript11getFunctionEj($script_1_idx171_val, $script_1_idx172_val, $3743);
    var $3745 = $3744 | 0;
    var $_idx368 = $3744 + 58 | 0;
    var $_idx368_val = HEAP16[$_idx368 >> 1];
    var $3746 = __ZNK10JSFunction13isNullClosureEv($_idx368_val);
    var $regs_idx18_val = HEAP32[$regs_idx73 >> 2];
    var $3747 = __ZNK2js9FrameRegs2fpEv($regs_idx18_val);
    if ($3746) {
      __label__ = 801;
      break;
    } else {
      __label__ = 813;
      break;
    }
   case 801:
    var $3749 = __ZNK2js10StackFrame10scopeChainEv($3747);
    var $_idx436_val = HEAP16[$_idx368 >> 1];
    var $3750 = __ZNK10JSFunction8joinableEv($_idx436_val);
    if ($3750) {
      __label__ = 802;
      break;
    } else {
      var $parent300_0 = $3749;
      __label__ = 814;
      break;
    }
   case 802:
    var $3752 = HEAPU32[$_pre_phi >> 2];
    var $3753 = $3752 + 3 | 0;
    var $3754 = __ZN2js23AdvanceOverBlockchainOpEPh($3753);
    var $3755 = HEAP8[$3754];
    if ($3755 << 24 >> 24 == -29) {
      __label__ = 803;
      break;
    } else if ($3755 << 24 >> 24 == -30) {
      __label__ = 804;
      break;
    } else if ($3755 << 24 >> 24 == 58) {
      __label__ = 807;
      break;
    } else if ($3755 << 24 >> 24 == 64) {
      __label__ = 811;
      break;
    } else {
      var $parent300_0 = $3749;
      __label__ = 814;
      break;
    }
   case 803:
    var $3757 = HEAPU32[$3728 >> 2];
    var $3763 = $3754 - $3752 | 0;
    var $3772 = ((HEAPU8[$3763 + ($3752 + 1) | 0] & 255) << 8 | HEAPU8[$3763 + ($3752 + 2) | 0] & 255) + ($3730 - $3757 >> 2) | 0;
    var $3773 = __ZN8JSScript7getAtomEj($3757, $3772);
    __ZN10JSFunction13setMethodAtomEP6JSAtom($3744, $3773);
    var $obj299_0 = $3745;
    __label__ = 815;
    break;
   case 804:
    var $_idx100 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$2$0 = $_idx100 | 0;
    var $_idx100_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx100 + 4 | 0;
    var $_idx100_val$1 = HEAP32[$st$2$1 >> 2];
    var $3776 = __ZNK2JS5Value8isObjectEv($_idx100_val$0, $_idx100_val$1);
    if ($3776) {
      __label__ = 805;
      break;
    } else {
      var $parent300_0 = $3749;
      __label__ = 814;
      break;
    }
   case 805:
    var $3778 = __ZNK2JS5Value8toObjectEv($_idx100_val$0, $_idx100_val$1);
    var $_idx417_val = HEAP32[$3778 + 4 >> 2];
    var $3779 = __ZNK8JSObject20canHaveMethodBarrierEv($_idx417_val);
    if ($3779) {
      __label__ = 806;
      break;
    } else {
      var $parent300_0 = $3749;
      __label__ = 814;
      break;
    }
   case 806:
    var $3781 = HEAPU32[$3728 >> 2];
    var $3787 = $3754 - $3752 | 0;
    var $3796 = ((HEAPU8[$3787 + ($3752 + 1) | 0] & 255) << 8 | HEAPU8[$3787 + ($3752 + 2) | 0] & 255) + ($3730 - $3781 >> 2) | 0;
    var $3797 = __ZN8JSScript7getAtomEj($3781, $3796);
    __ZN10JSFunction13setMethodAtomEP6JSAtom($3744, $3797);
    var $obj299_0 = $3745;
    __label__ = 815;
    break;
   case 807:
    var $3806 = (HEAPU8[$3754 + 1 | 0] & 255) << 8 | HEAPU8[$3754 + 2 | 0] & 255;
    var $_idx433 = HEAP32[$_pre_phi580 >> 2] + (($3806 ^ -1) << 3) | 0;
    var $st$11$0 = $_idx433 | 0;
    var $_idx433_val$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $_idx433 + 4 | 0;
    var $_idx433_val$1 = HEAP32[$st$11$1 >> 2];
    var $3809 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject1840($_idx433_val$0, $_idx433_val$1, $callee304);
    if ($3809) {
      __label__ = 808;
      break;
    } else {
      var $parent300_0 = $3749;
      __label__ = 814;
      break;
    }
   case 808:
    var $_idx152_val = HEAP32[HEAP32[$callee304 >> 2] + 24 >> 2];
    var $3812 = __ZNK8JSObject18getFunctionPrivateEv($_idx152_val);
    var $3813 = $3812;
    var $3814 = __ZNK10JSFunction11maybeNativeEv($3813);
    if (($3814 | 0) == 0) {
      var $parent300_0 = $3749;
      __label__ = 814;
      break;
    } else {
      __label__ = 809;
      break;
    }
   case 809:
    if (($3806 | 0) == 1 & ($3814 | 0) == 138) {
      var $obj299_0 = $3745;
      __label__ = 815;
      break;
    } else {
      __label__ = 810;
      break;
    }
   case 810:
    if (($3806 | 0) == 2 & ($3814 | 0) == 140) {
      var $obj299_0 = $3745;
      __label__ = 815;
      break;
    } else {
      var $parent300_0 = $3749;
      __label__ = 814;
      break;
    }
   case 811:
    if (HEAP8[$3754 + 1 | 0] << 24 >> 24 == 58) {
      __label__ = 812;
      break;
    } else {
      var $parent300_0 = $3749;
      __label__ = 814;
      break;
    }
   case 812:
    if (((HEAPU8[$3754 + 2 | 0] & 255) << 8 | HEAPU8[$3754 + 3 | 0] & 255 | 0) == 0) {
      var $obj299_0 = $3745;
      __label__ = 815;
      break;
    } else {
      var $parent300_0 = $3749;
      __label__ = 814;
      break;
    }
   case 813:
    var $3837 = __ZN2js17GetScopeChainFastEP9JSContextPNS_10StackFrameE4JSOpj($cx, $3747, 3);
    if (($3837 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $parent300_0 = $3837;
      __label__ = 814;
      break;
    }
   case 814:
    var $parent300_0;
    var $3840 = __Z19CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectb($cx, $3744, $parent300_0, 1);
    if (($3840 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $obj299_0 = $3840;
      __label__ = 815;
      break;
    }
   case 815:
    var $obj299_0;
    var $3843 = HEAP32[$_pre_phi580 >> 2];
    var $3844 = $3843 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $3844;
    __ZN2JS5Value9setObjectER8JSObject($3843, $obj299_0);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 816:
    var $3852 = HEAPU32[$_pre_phi >> 2];
    var $3861 = ((HEAPU8[$3852 + 1 | 0] & 255) << 8 | HEAPU8[$3852 + 2 | 0] & 255) + ($atoms_1 - HEAP32[$script_1 + 56 >> 2] >> 2) | 0;
    var $script_1_idx169_val = HEAP32[$script_1 + 4 >> 2];
    var $script_1_idx170_val = HEAP8[$script_1 + 16 | 0];
    var $3862 = __ZN8JSScript11getFunctionEj($script_1_idx169_val, $script_1_idx170_val, $3861);
    var $3863 = __Z17js_NewFlatClosureP9JSContextP10JSFunction4JSOpj($cx, $3862);
    if (($3863 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 817;
      break;
    }
   case 817:
    var $3866 = HEAP32[$_pre_phi580 >> 2];
    var $3867 = $3866 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $3867;
    __ZN2JS5Value9setObjectER8JSObject($3866, $3863);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 818:
    var $3869 = HEAP32[$_pre_phi580 >> 2];
    var $3870 = $3869 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $3870;
    var $3871 = $argv_1 - 16 | 0;
    var $st$4$0 = $3871 | 0;
    var $3872$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $3871 + 4 | 0;
    var $3872$1 = HEAP32[$st$4$1 >> 2];
    var $3873 = $3869 | 0;
    var $st$9$0 = $3873 | 0;
    HEAP32[$st$9$0 >> 2] = $3872$0;
    var $st$9$1 = $3873 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $3872$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 819:
    var $atoms_2;
    var $3875 = HEAP32[$_pre_phi >> 2] + 1 | 0;
    HEAP32[$_pre_phi >> 2] = $3875;
    var $3876 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh1793($script_1, $3875);
    if (($3876 | 0) == 191) {
      __label__ = 820;
      break;
    } else if (($3876 | 0) == 211 || ($3876 | 0) == 212 || ($3876 | 0) == 213) {
      __label__ = 822;
      break;
    } else if (($3876 | 0) == 111 || ($3876 | 0) == 54) {
      __label__ = 823;
      break;
    } else if (($3876 | 0) == 56) {
      __label__ = 824;
      break;
    } else if (($3876 | 0) == 93) {
      __label__ = 829;
      break;
    } else {
      __label__ = 830;
      break;
    }
   case 820:
    var $3879 = HEAP32[$_pre_phi >> 2] + 1 | 0;
    var $3882 = (HEAPU8[$3879] & 255) << 16;
    HEAP32[$_pre_phi >> 2] = $3879;
    var $_pn = $3882;
    __label__ = 821;
    break;
   case 821:
    var $_pn;
    var $atoms_2 = $atoms_2 + ($_pn << 2) | 0;
    __label__ = 819;
    break;
   case 822:
    var $_pn = ($3876 << 16) - 13762560 | 0;
    __label__ = 821;
    break;
   case 823:
    var $3887 = HEAPU32[$_pre_phi >> 2];
    var $3897 = HEAP32[$atoms_2 + (((HEAPU8[$3887 + 1 | 0] & 255) << 8 | HEAPU8[$3887 + 2 | 0] & 255) << 2) >> 2];
    var $3898 = __ZL12ATOM_TO_JSIDP6JSAtom1798($3897);
    HEAP32[$id308 >> 2] = $3898;
    var $3899 = HEAPU32[$_pre_phi580 >> 2];
    var $3900 = $3899 - 8 | 0;
    var $st$15$0 = $3900 | 0;
    var $st$15$1 = $3900 + 4 | 0;
    var $i310_0 = -1;
    var $rval309_0_0_0$1 = HEAP32[$st$15$1 >> 2];
    var $rval309_0_0_0$0 = HEAP32[$st$15$0 >> 2];
    var $3908 = $3898;
    var $3907 = $3899;
    __label__ = 825;
    break;
   case 824:
    var $3903 = HEAP32[$_pre_phi580 >> 2];
    var $3904 = $3903 - 8 | 0;
    var $st$2$0 = $3904 | 0;
    var $3905$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $3904 + 4 | 0;
    var $3905$1 = HEAP32[$st$2$1 >> 2];
    HEAP32[$id308 >> 2] = 2;
    var $i310_0 = -2;
    var $rval309_0_0_0$1 = $3905$1;
    var $rval309_0_0_0$0 = $3905$0;
    var $3908 = 2;
    var $3907 = $3903;
    __label__ = 825;
    break;
   case 825:
    var $3907;
    var $3908;
    var $rval309_0_0_0$0;
    var $rval309_0_0_0$1;
    var $i310_0;
    var $3910 = $3907 + ($i310_0 - 1 << 3) | 0;
    var $_idx99 = $3910 | 0;
    var $st$8$0 = $_idx99 | 0;
    var $_idx99_val$0 = HEAP32[$st$8$0 >> 2];
    var $st$8$1 = $_idx99 + 4 | 0;
    var $_idx99_val$1 = HEAP32[$st$8$1 >> 2];
    var $3911 = __ZNK2JS5Value8isObjectEv($_idx99_val$0, $_idx99_val$1);
    if ($3911) {
      __label__ = 826;
      break;
    } else {
      __label__ = 827;
      break;
    }
   case 826:
    var $3913 = __ZNK2JS5Value8toObjectEv($_idx99_val$0, $_idx99_val$1);
    var $obj311_0 = $3913;
    var $i310_2 = $i310_0;
    var $rval309_0_0_2$1 = $rval309_0_0_0$1;
    var $rval309_0_0_2$0 = $rval309_0_0_0$0;
    var $3940 = $3908;
    __label__ = 832;
    break;
   case 827:
    var $3915 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5080, $3910);
    var $3916 = $3915;
    if (($3915 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 828;
      break;
    }
   case 828:
    __ZN2JS5Value9setObjectER8JSObject($3910, $3916);
    var $obj311_0 = $3916;
    var $i310_2 = $i310_0;
    var $rval309_0_0_2$1 = $rval309_0_0_0$1;
    var $rval309_0_0_2$0 = $rval309_0_0_0$0;
    var $3940 = $3908;
    __label__ = 832;
    break;
   case 829:
    var $3920 = HEAP32[$_pre_phi580 >> 2];
    var $3921 = HEAPU32[$_pre_phi >> 2];
    var $3931 = HEAP32[$atoms_2 + (((HEAPU8[$3921 + 1 | 0] & 255) << 8 | HEAPU8[$3921 + 2 | 0] & 255) << 2) >> 2];
    var $3932 = __ZL12ATOM_TO_JSIDP6JSAtom1798($3931);
    var $i310_1 = -1;
    var $storemerge = $3932;
    var $3936 = $3920;
    __label__ = 831;
    break;
   case 830:
    var $i310_1 = -2;
    var $storemerge = 2;
    var $3936 = HEAP32[$_pre_phi580 >> 2];
    __label__ = 831;
    break;
   case 831:
    var $3936;
    var $storemerge;
    var $i310_1;
    var $rval309_0_0_1_in = $3936 - 8 | 0;
    var $st$4$0 = $rval309_0_0_1_in | 0;
    var $rval309_0_0_1$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $rval309_0_0_1_in + 4 | 0;
    var $rval309_0_0_1$1 = HEAP32[$st$4$1 >> 2];
    HEAP32[$id308 >> 2] = $storemerge;
    var $_idx127 = $3936 + ($i310_1 - 1 << 3) | 0;
    var $st$11$0 = $_idx127 | 0;
    var $_idx127_val$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $_idx127 + 4 | 0;
    var $_idx127_val$1 = HEAP32[$st$11$1 >> 2];
    var $3938 = __ZNK2JS5Value8toObjectEv($_idx127_val$0, $_idx127_val$1);
    var $obj311_0 = $3938;
    var $i310_2 = $i310_1;
    var $rval309_0_0_2$1 = $rval309_0_0_1$1;
    var $rval309_0_0_2$0 = $rval309_0_0_1$0;
    var $3940 = $storemerge;
    __label__ = 832;
    break;
   case 832:
    var $3940;
    var $rval309_0_0_2$0;
    var $rval309_0_0_2$1;
    var $i310_2;
    var $obj311_0;
    var $3941 = _JSID_IS_VOID1831($3940);
    if (($3941 | 0) == 0) {
      __label__ = 837;
      break;
    } else {
      __label__ = 833;
      break;
    }
   case 833:
    var $3945 = HEAP32[$_pre_phi580 >> 2] + ($i310_2 << 3) | 0;
    var $3946 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($3945, $i_317);
    if ($3946) {
      __label__ = 834;
      break;
    } else {
      __label__ = 836;
      break;
    }
   case 834:
    var $3948 = HEAP32[$i_317 >> 2];
    var $3949 = _INT_FITS_IN_JSID1825($3948);
    if (($3949 | 0) == 0) {
      __label__ = 836;
      break;
    } else {
      __label__ = 835;
      break;
    }
   case 835:
    var $3952 = _INT_TO_JSID1826($3948);
    HEAP32[$id308 >> 2] = $3952;
    __label__ = 837;
    break;
   case 836:
    var $3955 = HEAP32[$_pre_phi580 >> 2] + ($i310_2 << 3) | 0;
    var $3956 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $obj311_0, $3945, $id308, $3955);
    if ($3956) {
      __label__ = 837;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 837:
    var $3958 = __ZL13js_IsCallableRKN2JS5ValueE1841($rval309_0_0_2$0, $rval309_0_0_2$1);
    if ($3958) {
      __label__ = 839;
      break;
    } else {
      __label__ = 838;
      break;
    }
   case 838:
    var $_ = ($op_0 | 0) == 125 ? STRING_TABLE.__str12882 : STRING_TABLE.__str42885;
    var $3961 = $_ | 0;
    _JS_ReportErrorNumber($cx, 4, 151, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $3961, tempInt));
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 839:
    var $3963 = HEAP32[$id308 >> 2];
    var $3965 = __ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj($5080, $obj311_0, $3963, 3, $rtmp, $attrs318);
    if (($3965 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 840;
      break;
    }
   case 840:
    var $3968 = ($op_0 | 0) == 125;
    var $3969 = __ZNK2JS5Value8toObjectEv($rval309_0_0_2$0, $rval309_0_0_2$1);
    if ($3968) {
      __label__ = 841;
      break;
    } else {
      __label__ = 842;
      break;
    }
   case 841:
    var $3971 = __ZN2jsL16CastAsPropertyOpEP8JSObject1842($3969);
    var $setter_0 = 12;
    var $getter_0 = $3971;
    var $3975 = 81;
    __label__ = 843;
    break;
   case 842:
    var $3973 = __ZN2jsL22CastAsStrictPropertyOpEP8JSObject1843($3969);
    var $setter_0 = $3973;
    var $getter_0 = 10;
    var $3975 = 97;
    __label__ = 843;
    break;
   case 843:
    var $3975;
    var $getter_0;
    var $setter_0;
    HEAP32[$attrs318 >> 2] = $3975;
    var $3976 = __ZN2js18CheckRedeclarationEP9JSContextP8JSObjectij($cx, $obj311_0, $3963, $3975);
    if ($3976) {
      __label__ = 844;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 844:
    __ZN2JSL14UndefinedValueEv1839($10);
    var $3978 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj311_0, $cx, $3963, $10, $getter_0, $setter_0, $3975);
    if (($3978 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 845;
      break;
    }
   case 845:
    var $3981 = HEAP32[$_pre_phi580 >> 2];
    var $3982 = $3981 + ($i310_2 << 3) | 0;
    HEAP32[$_pre_phi580 >> 2] = $3982;
    if (HEAP8[_js_CodeSpec + ($3876 << 3) + 2 | 0] << 24 >> 24 > HEAP8[_js_CodeSpec + ($3876 << 3) + 1 | 0] << 24 >> 24) {
      __label__ = 846;
      break;
    } else {
      __label__ = 847;
      break;
    }
   case 846:
    var $3989 = $3981 + ($i310_2 - 1 << 3) | 0;
    var $st$2$0 = $3989 | 0;
    HEAP32[$st$2$0 >> 2] = $rval309_0_0_2$0;
    var $st$2$1 = $3989 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $rval309_0_0_2$1;
    __label__ = 847;
    break;
   case 847:
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_2;
    var $len_0 = HEAP8[_js_CodeSpec + ($3876 << 3) | 0] << 24 >> 24;
    __label__ = 17;
    break;
   case 848:
    var $3995 = HEAP32[$_pre_phi580 >> 2];
    var $3996 = $3995 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $3996;
    __ZN2JS5Value8setMagicE10JSWhyMagic($3995, 0);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 849:
    var $4000 = HEAPU8[HEAP32[$_pre_phi >> 2] + 1 | 0];
    var $4001 = $4000 & 255;
    if ($4000 << 24 >> 24 == 3) {
      __label__ = 850;
      break;
    } else {
      __label__ = 851;
      break;
    }
   case 850:
    var $4004 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($cx);
    var $obj320_0 = $4004;
    __label__ = 852;
    break;
   case 851:
    var $4006 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1845($cx, 4);
    var $obj320_0 = $4006;
    __label__ = 852;
    break;
   case 852:
    var $obj320_0;
    if (($obj320_0 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 853;
      break;
    }
   case 853:
    var $4010 = HEAP32[$_pre_phi >> 2];
    var $4011 = __ZN2js5types10TypeScript10InitObjectEP9JSContextP8JSScriptPKh10JSProtoKey($cx, $script_1, $4010, $4001);
    if (($4011 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 854;
      break;
    }
   case 854:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($obj320_0, $4011);
    var $4014 = HEAP32[$_pre_phi580 >> 2];
    var $4015 = $4014 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4015;
    __ZN2JS5Value9setObjectER8JSObject($4014, $obj320_0);
    if ((HEAP32[HEAP32[$34 >> 2] >> 2] | 0) == 0) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    } else {
      __label__ = 855;
      break;
    }
   case 855:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 856:
    var $4022 = HEAPU32[$_pre_phi >> 2];
    var $4035 = HEAPU8[$4022 + 3 | 0] & 255 | (HEAPU8[$4022 + 1 | 0] & 255) << 16 | (HEAPU8[$4022 + 2 | 0] & 255) << 8;
    var $4036 = __ZN2js22NewDenseAllocatedArrayEP9JSContextjP8JSObject($cx, $4035);
    if (($4036 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 857;
      break;
    }
   case 857:
    var $4039 = HEAP32[$_pre_phi >> 2];
    var $4040 = __ZN2js5types10TypeScript10InitObjectEP9JSContextP8JSScriptPKh10JSProtoKey($cx, $script_1, $4039, 3);
    if (($4040 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 858;
      break;
    }
   case 858:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($4036, $4040);
    var $4043 = HEAP32[$_pre_phi580 >> 2];
    var $4044 = $4043 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4044;
    __ZN2JS5Value9setObjectER8JSObject($4043, $4036);
    if ((HEAP32[HEAP32[$34 >> 2] >> 2] | 0) == 0) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 4;
      __label__ = 17;
      break;
    } else {
      __label__ = 859;
      break;
    }
   case 859:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 4;
    __label__ = 17;
    break;
   case 860:
    var $4057 = HEAPU32[$_pre_phi >> 2];
    var $4066 = ((HEAPU8[$4057 + 1 | 0] & 255) << 8 | HEAPU8[$4057 + 2 | 0] & 255) + ($atoms_1 - HEAP32[$script_1 + 56 >> 2] >> 2) | 0;
    var $script_1_idx156_val = HEAP32[$script_1 + 4 >> 2];
    var $script_1_idx157_val = HEAP8[$script_1 + 16 | 0];
    var $4067 = __ZN8JSScript9getObjectEj($script_1_idx156_val, $script_1_idx157_val, $4066);
    var $4068 = __ZN2js5types10TypeScript10InitObjectEP9JSContextP8JSScriptPKh10JSProtoKey($cx, $script_1, $4057, 1);
    if (($4068 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 861;
      break;
    }
   case 861:
    var $4071 = __ZN2jsL21CopyInitializerObjectEP9JSContextP8JSObjectPNS_5types10TypeObjectE($cx, $4067, $4068);
    if (($4071 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 862;
      break;
    }
   case 862:
    var $4074 = HEAP32[$_pre_phi580 >> 2];
    var $4075 = $4074 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4075;
    __ZN2JS5Value9setObjectER8JSObject($4074, $4071);
    if ((HEAP32[HEAP32[$34 >> 2] >> 2] | 0) == 0) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    } else {
      __label__ = 863;
      break;
    }
   case 863:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 864:
    var $4081 = HEAP32[$_pre_phi580 >> 2];
    var $4082 = $4081 - 8 | 0;
    var $st$2$0 = $4082 | 0;
    var $4083$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $4082 + 4 | 0;
    var $4083$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5126 | 0;
    HEAP32[$st$6$0 >> 2] = $4083$0;
    var $st$6$1 = $5126 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4083$1;
    var $_idx126 = $4081 - 16 | 0;
    var $st$11$0 = $_idx126 | 0;
    var $_idx126_val$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $_idx126 + 4 | 0;
    var $_idx126_val$1 = HEAP32[$st$11$1 >> 2];
    var $4084 = __ZNK2JS5Value8toObjectEv($_idx126_val$0, $_idx126_val$1);
    var $4086 = HEAP32[$22 >> 2] + 144336 | 0;
    var $4087 = HEAP32[$_pre_phi >> 2];
    var $_idx439_val = HEAP32[$4084 + 12 >> 2];
    var $4088 = __ZN2js13PropertyCache11testForInitEP9JSRuntimePhP8JSObjectPPKNS_5ShapeEPPNS_18PropertyCacheEntryE($4086, $23, $4087, $_idx439_val, $shape329, $entry328);
    if ($4088) {
      __label__ = 865;
      break;
    } else {
      __label__ = 870;
      break;
    }
   case 865:
    var $4090 = HEAPU32[$shape329 >> 2];
    var $_idx364_val = HEAP32[$4090 + 20 >> 2];
    var $4091 = __ZNK2js5Shape16hasDefaultSetterEv($_idx364_val);
    if ($4091) {
      __label__ = 866;
      break;
    } else {
      __label__ = 870;
      break;
    }
   case 866:
    var $_idx193_val = HEAP32[$4090 + 32 >> 2];
    var $4093 = __ZNK2js5Shape8previousEv($_idx193_val);
    var $_idx160_val = HEAP32[$4084 >> 2];
    var $4094 = __ZNK8JSObject12lastPropertyEv($_idx160_val);
    if (($4093 | 0) == ($4094 | 0)) {
      __label__ = 867;
      break;
    } else {
      __label__ = 870;
      break;
    }
   case 867:
    var $4098 = HEAPU32[$4090 + 24 >> 2];
    HEAP32[$slot330 >> 2] = $4098;
    var $_idx181_val = HEAP32[$4084 + 28 >> 2];
    var $4099 = __ZNK8JSObject8numSlotsEv($_idx181_val);
    if ($4098 >>> 0 < $4099 >>> 0) {
      __label__ = 869;
      break;
    } else {
      __label__ = 868;
      break;
    }
   case 868:
    var $4102 = $4084;
    var $4103 = __ZN8JSObject9allocSlotEP9JSContextPj($4102, $5080, $slot330);
    if ($4103) {
      __label__ = 869;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 869:
    __ZN8JSObject6extendEP9JSContextPKN2js5ShapeEb($4084, $cx, $4090);
    __ZN8JSObject21nativeSetSlotWithTypeEP9JSContextPKN2js5ShapeERKN2JS5ValueE($4084, $cx, $4090, $rval326);
    __label__ = 873;
    break;
   case 870:
    var $4106 = HEAPU32[$_pre_phi >> 2];
    var $4116 = HEAPU32[$atoms_1 + (((HEAPU8[$4106 + 1 | 0] & 255) << 8 | HEAPU8[$4106 + 2 | 0] & 255) << 2) >> 2];
    var $4117 = __ZL12ATOM_TO_JSIDP6JSAtom1798($4116);
    var $4119 = ($op_0 | 0) == 227 ? 5 : 1;
    if (($4116 | 0) == (HEAP32[HEAP32[$22 >> 2] + 210292 >> 2] | 0)) {
      __label__ = 871;
      break;
    } else {
      __label__ = 872;
      break;
    }
   case 871:
    var $4130 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $4131 = $4084;
    var $4132 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($5080, $4131, $4117, $4119, $rval326, $4130);
    if (($4132 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 873;
      break;
    }
   case 872:
    var $4135 = $4084;
    var $4136 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($5080, $4135, $4117, $rval326, 0, 0, 1, 0, 0, $4119);
    if (($4136 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 873;
      break;
    }
   case 873:
    var $4140 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4140;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 874:
    var $4142 = HEAP32[$_pre_phi580 >> 2];
    var $4143 = $4142 - 8 | 0;
    var $_idx125 = $4142 - 24 | 0;
    var $st$3$0 = $_idx125 | 0;
    var $_idx125_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx125 + 4 | 0;
    var $_idx125_val$1 = HEAP32[$st$3$1 >> 2];
    var $4144 = __ZNK2JS5Value8toObjectEv($_idx125_val$0, $_idx125_val$1);
    var $4145 = $4142 - 16 | 0;
    var $4146 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($4145, $i_339);
    if ($4146) {
      __label__ = 875;
      break;
    } else {
      __label__ = 877;
      break;
    }
   case 875:
    var $4148 = HEAP32[$i_339 >> 2];
    var $4149 = _INT_FITS_IN_JSID1825($4148);
    if (($4149 | 0) == 0) {
      __label__ = 877;
      break;
    } else {
      __label__ = 876;
      break;
    }
   case 876:
    var $4152 = _INT_TO_JSID1826($4148);
    HEAP32[$id337 >> 2] = $4152;
    __label__ = 878;
    break;
   case 877:
    var $4155 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    var $4156 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $4144, $4145, $id337, $4155);
    if ($4156) {
      __label__ = 878;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 878:
    var $_idx355 = $4143 | 0;
    var $st$1$0 = $_idx355 | 0;
    var $_idx355_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx355 + 4 | 0;
    var $_idx355_val$1 = HEAP32[$st$1$1 >> 2];
    var $4158 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx355_val$0, $_idx355_val$1);
    if ($4158) {
      __label__ = 879;
      break;
    } else {
      __label__ = 881;
      break;
    }
   case 879:
    var $4161 = HEAP32[$_pre_phi >> 2] + 1 | 0;
    var $4162 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh1793($script_1, $4161);
    if (($4162 | 0) == 92) {
      __label__ = 880;
      break;
    } else {
      __label__ = 882;
      break;
    }
   case 880:
    var $4165 = HEAP32[$id337 >> 2];
    var $4166 = _JSID_TO_INT1836($4165);
    var $4168 = ($4166 + 1 | 0) >>> 0;
    var $4169 = __Z20js_SetLengthPropertyP9JSContextP8JSObjectd($cx, $4144, $4168);
    if (($4169 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 882;
      break;
    }
   case 881:
    var $4172 = HEAP32[$id337 >> 2];
    var $4173 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($4144, $cx, $4172, $4143, 0, 0, 1);
    if (($4173 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 882;
      break;
    }
   case 882:
    var $4177 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4177;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 883:
    var $4179 = HEAPU32[$_pre_phi >> 2];
    var $4187 = (HEAPU8[$4179 + 1 | 0] & 255) << 8 | HEAPU8[$4179 + 2 | 0] & 255;
    var $regs_idx17_val = HEAP32[$regs_idx73 >> 2];
    var $4188 = __ZNK2js9FrameRegs2fpEv($regs_idx17_val);
    var $4189 = $4188;
    var $4190 = __ZNK2js10StackFrame5slotsEv($4189);
    var $_idx98 = $4190 + ($4187 << 3) | 0;
    var $st$14$0 = $_idx98 | 0;
    var $_idx98_val$0 = HEAP32[$st$14$0 >> 2];
    var $st$14$1 = $_idx98 + 4 | 0;
    var $_idx98_val$1 = HEAP32[$st$14$1 >> 2];
    var $4191 = __ZNK2JS5Value8isObjectEv($_idx98_val$0, $_idx98_val$1);
    if ($4191) {
      __label__ = 884;
      break;
    } else {
      __label__ = 885;
      break;
    }
   case 884:
    var $4193 = __ZNK2JS5Value8toObjectEv($_idx98_val$0, $_idx98_val$1);
    var $obj342_0 = $4193;
    var $4203 = $4179;
    __label__ = 887;
    break;
   case 885:
    var $4195 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($cx);
    if (($4195 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 886;
      break;
    }
   case 886:
    var $regs_idx16_val = HEAP32[$regs_idx73 >> 2];
    var $4198 = __ZNK2js9FrameRegs2fpEv($regs_idx16_val);
    var $4199 = $4198;
    var $4200 = __ZNK2js10StackFrame5slotsEv($4199);
    var $4201 = $4200 + ($4187 << 3) | 0;
    __ZN2JS5Value9setObjectER8JSObject($4201, $4195);
    var $obj342_0 = $4195;
    var $4203 = HEAP32[$_pre_phi >> 2];
    __label__ = 887;
    break;
   case 887:
    var $4203;
    var $obj342_0;
    var $4211 = (HEAPU8[$4203 + 3 | 0] & 255) << 8 | HEAPU8[$4203 + 4 | 0] & 255;
    var $4213 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $_idx230 = $4213 | 0;
    var $st$13$0 = $_idx230 | 0;
    var $_idx230_val$0 = HEAP32[$st$13$0 >> 2];
    var $st$13$1 = $_idx230 + 4 | 0;
    var $_idx230_val$1 = HEAP32[$st$13$1 >> 2];
    var $4214 = __ZNK2JS5Value11isPrimitiveEv($_idx230_val$0, $_idx230_val$1);
    if ($4214) {
      __label__ = 888;
      break;
    } else {
      __label__ = 889;
      break;
    }
   case 888:
    var $4216 = $numBuf | 0;
    var $4217 = _JS_snprintf($4216, 12, STRING_TABLE.__str544300 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $4211, tempInt));
    _JS_ReportErrorNumber($cx, 4, 29, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $4216, tempInt));
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 889:
    var $4219 = _INT_TO_JSID1826($4211);
    var $4220 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj342_0, $cx, $4219, $4213, 0, 0, 1);
    if (($4220 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 5;
      __label__ = 17;
      break;
    }
   case 890:
    var $4223 = HEAPU32[$_pre_phi >> 2];
    var $4231 = (HEAPU8[$4223 + 1 | 0] & 255) << 8 | HEAPU8[$4223 + 2 | 0] & 255;
    var $regs_idx15_val = HEAP32[$regs_idx73 >> 2];
    var $4232 = __ZNK2js9FrameRegs2fpEv($regs_idx15_val);
    var $4233 = $4232;
    var $4234 = __ZNK2js10StackFrame5slotsEv($4233);
    var $4242 = (HEAPU8[$4223 + 3 | 0] & 255) << 8 | HEAPU8[$4223 + 4 | 0] & 255;
    var $_idx184 = $4234 + ($4231 << 3) | 0;
    var $st$22$0 = $_idx184 | 0;
    var $_idx184_val$0 = HEAPU32[$st$22$0 >> 2];
    var $st$22$1 = $_idx184 + 4 | 0;
    var $_idx184_val$1 = HEAPU32[$st$22$1 >> 2];
    var $4243 = __ZNK2JS5Value11isUndefinedEv($_idx184_val$0, $_idx184_val$1);
    if ($4243) {
      __label__ = 891;
      break;
    } else {
      __label__ = 892;
      break;
    }
   case 891:
    __ZN2JS5Value12setUndefinedEv($rval349);
    __label__ = 893;
    break;
   case 892:
    var $4246 = __ZNK2JS5Value8toObjectEv($_idx184_val$0, $_idx184_val$1);
    var $4247 = _INT_TO_JSID1826($4242);
    var $4248 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($4246, $cx, $4247, $rval349);
    if (($4248 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 893;
      break;
    }
   case 893:
    var $st$0$0 = $5127 | 0;
    var $rval349_idx_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5127 + 4 | 0;
    var $rval349_idx_val$1 = HEAP32[$st$0$1 >> 2];
    var $4251 = __ZNK2JS5Value14isObjectOrNullEv($rval349_idx_val$0, $rval349_idx_val$1);
    if ($4251) {
      __label__ = 895;
      break;
    } else {
      __label__ = 894;
      break;
    }
   case 894:
    var $4253 = $numBuf352 | 0;
    var $4254 = _JS_snprintf($4253, 12, STRING_TABLE.__str544300 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $4242, tempInt));
    _JS_ReportErrorNumber($cx, 4, 30, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $4253, tempInt));
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 895:
    var $4256 = HEAP32[$_pre_phi580 >> 2];
    var $4257 = $4256 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4257;
    var $4258 = $4256 | 0;
    var $st$4$0 = $4258 | 0;
    HEAP32[$st$4$0 >> 2] = $rval349_idx_val$0;
    var $st$4$1 = $4258 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $rval349_idx_val$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 5;
    __label__ = 17;
    break;
   case 896:
    var $4260 = HEAPU32[$_pre_phi >> 2];
    var $4268 = (HEAPU8[$4260 + 1 | 0] & 255) << 8 | HEAPU8[$4260 + 2 | 0] & 255;
    var $regs_idx14_val = HEAP32[$regs_idx73 >> 2];
    var $4269 = __ZNK2js9FrameRegs2fpEv($regs_idx14_val);
    var $4270 = $4269;
    var $4271 = __ZNK2js10StackFrame5slotsEv($4270);
    var $4272 = $4271 + ($4268 << 3) | 0;
    var $4273 = $4271 + ($4268 + 1 << 3) | 0;
    var $st$16$0 = $4273 | 0;
    var $4274$0 = HEAPU32[$st$16$0 >> 2];
    var $st$16$1 = $4273 + 4 | 0;
    var $4274$1 = HEAPU32[$st$16$1 >> 2];
    var $st$20$0 = $5128 | 0;
    HEAP32[$st$20$0 >> 2] = $4274$0;
    var $st$20$1 = $5128 + 4 | 0;
    HEAP32[$st$20$1 >> 2] = $4274$1;
    if (HEAP8[$4260 + 3 | 0] << 24 >> 24 == 92) {
      __label__ = 900;
      break;
    } else {
      __label__ = 897;
      break;
    }
   case 897:
    var $4279 = __ZNK2JS5Value11isUndefinedEv($4274$0, $4274$1);
    if ($4279) {
      var $4284 = 1;
      __label__ = 899;
      break;
    } else {
      __label__ = 898;
      break;
    }
   case 898:
    var $4281 = __ZNK2JS5Value7toInt32Ev($4274$0, $4274$1);
    var $4284 = $4281 + 1 | 0;
    __label__ = 899;
    break;
   case 899:
    var $4284;
    __ZN2JS5Value8setInt32Ei($rval355, $4284);
    __label__ = 902;
    break;
   case 900:
    var $4286 = __ZN2JS5Value11getInt32RefEv($rval355);
    var $4288 = HEAP32[$4286 >> 2] - 1 | 0;
    HEAP32[$4286 >> 2] = $4288;
    var $st$4$0 = $5128 | 0;
    var $rval355_idx_val$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $5128 + 4 | 0;
    var $rval355_idx_val$1 = HEAP32[$st$4$1 >> 2];
    var $4289 = __ZNK2JS5Value7toInt32Ev($rval355_idx_val$0, $rval355_idx_val$1);
    if (($4289 | 0) == 0) {
      __label__ = 901;
      break;
    } else {
      __label__ = 902;
      break;
    }
   case 901:
    __ZN2JS5Value12setUndefinedEv($4272);
    __label__ = 902;
    break;
   case 902:
    var $st$0$0 = $5128 | 0;
    var $4293$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5128 + 4 | 0;
    var $4293$1 = HEAP32[$st$0$1 >> 2];
    var $st$4$0 = $4273 | 0;
    HEAP32[$st$4$0 >> 2] = $4293$0;
    var $st$4$1 = $4273 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $4293$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 903:
    var $4295 = HEAP32[$_pre_phi580 >> 2];
    var $4296 = $4295 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4296;
    __ZN2JS5Value10setBooleanEb($4295, 0);
    var $4302 = HEAP32[$_pre_phi >> 2] + 3 - HEAP32[$72 >> 2] | 0;
    var $4303 = HEAP32[$_pre_phi580 >> 2];
    var $4304 = $4303 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4304;
    __ZN2JS5Value8setInt32Ei($4303, $4302);
    var $4305 = HEAPU32[$_pre_phi >> 2];
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = ((HEAPU8[$4305 + 1 | 0] & 255) << 8 | HEAPU8[$4305 + 2 | 0] & 255) << 16 >> 16;
    __label__ = 17;
    break;
   case 904:
    var $4316 = HEAP32[$_pre_phi580 >> 2];
    var $4317 = $4316 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4317;
    __ZN2JS5Value10setBooleanEb($4316, 0);
    var $4318 = HEAPU32[$_pre_phi >> 2];
    var $4323 = $4318 + 5 - HEAP32[$72 >> 2] | 0;
    var $4341 = (HEAPU8[$4318 + 2 | 0] & 255) << 16 | (HEAPU8[$4318 + 1 | 0] & 255) << 24 | HEAPU8[$4318 + 4 | 0] & 255 | (HEAPU8[$4318 + 3 | 0] & 255) << 8;
    var $4342 = HEAP32[$_pre_phi580 >> 2];
    var $4343 = $4342 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4343;
    __ZN2JS5Value8setInt32Ei($4342, $4323);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = $4341;
    __label__ = 17;
    break;
   case 905:
    var $4345 = HEAP32[$_pre_phi580 >> 2];
    var $4346 = $4345 - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4346;
    var $4347 = $4346 | 0;
    var $st$4$0 = $4347 | 0;
    var $4348$0 = HEAPU32[$st$4$0 >> 2];
    var $st$4$1 = $4347 + 4 | 0;
    var $4348$1 = HEAP32[$st$4$1 >> 2];
    var $4349 = $4345 - 16 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4349;
    var $4350 = $4349 | 0;
    var $st$11$0 = $4350 | 0;
    var $4351$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $4350 + 4 | 0;
    var $4351$1 = HEAP32[$st$11$1 >> 2];
    var $4352 = __ZNK2JS5Value9toBooleanEv($4351$0, $4351$1);
    if ($4352) {
      __label__ = 906;
      break;
    } else {
      __label__ = 907;
      break;
    }
   case 906:
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($cx, $4348$0, $4348$1);
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 907:
    var $4355 = __ZNK2JS5Value7toInt32Ev($4348$0, $4348$1);
    var $4356 = HEAP32[$72 >> 2];
    HEAP32[$_pre_phi >> 2] = $4356;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = $4355;
    __label__ = 17;
    break;
   case 908:
    var $4358 = HEAP32[$_pre_phi580 >> 2];
    var $4359 = $4358 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4359;
    var $st$3$0 = $cx_idx202 | 0;
    var $cx_idx202_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $cx_idx202 + 4 | 0;
    var $cx_idx202_val$1 = HEAP32[$st$3$1 >> 2];
    __ZN9JSContext19getPendingExceptionEv($11, $cx_idx202_val$0, $cx_idx202_val$1);
    var $st$8$0 = $5129 | 0;
    var $4360$0 = HEAP32[$st$8$0 >> 2];
    var $st$8$1 = $5129 + 4 | 0;
    var $4360$1 = HEAP32[$st$8$1 >> 2];
    var $4361 = $4358 | 0;
    var $st$13$0 = $4361 | 0;
    HEAP32[$st$13$0 >> 2] = $4360$0;
    var $st$13$1 = $4361 + 4 | 0;
    HEAP32[$st$13$1 >> 2] = $4360$1;
    __ZN9JSContext21clearPendingExceptionEv($cx);
    if ((HEAP32[HEAP32[$22 >> 2] + 144280 >> 2] | 0) == 0) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 909;
      break;
    }
   case 909:
    var $4367 = __Z27js_HandleExecutionInterruptP9JSContext($cx);
    if (($4367 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    }
   case 910:
    if ((HEAP32[HEAP32[$22 >> 2] + 144280 >> 2] | 0) == 0) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 911;
      break;
    }
   case 911:
    var $4375 = __Z27js_HandleExecutionInterruptP9JSContext($cx);
    if (($4375 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    }
   case 912:
    var $4379 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4379;
    var $_019 = $4379 | 0;
    var $st$4$0 = $_019 | 0;
    var $tmp20$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $_019 + 4 | 0;
    var $tmp20$1 = HEAP32[$st$4$1 >> 2];
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($cx, $tmp20$0, $tmp20$1);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 913:
    if ((HEAP32[HEAP32[$22 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 915;
      break;
    } else {
      __label__ = 914;
      break;
    }
   case 914:
    var $4386 = __Z27js_HandleExecutionInterruptP9JSContext($cx);
    if (($4386 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 915;
      break;
    }
   case 915:
    var $4390 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4390;
    var $_014 = $4390 | 0;
    var $st$4$0 = $_014 | 0;
    var $tmp$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $_014 + 4 | 0;
    var $tmp$1 = HEAP32[$st$4$1 >> 2];
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($cx, $tmp$0, $tmp$1);
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 916:
    var $4392 = HEAPU32[$_pre_phi >> 2];
    var $4400 = (HEAPU8[$4392 + 1 | 0] & 255) << 8 | HEAPU8[$4392 + 2 | 0] & 255;
    var $regs_idx13_val = HEAP32[$regs_idx73 >> 2];
    var $4401 = __ZNK2js9FrameRegs2fpEv($regs_idx13_val);
    var $4402 = $4401;
    var $4403 = __ZNK2js10StackFrame5slotsEv($4402);
    var $4405 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4405;
    var $4406 = $4405 | 0;
    var $st$17$0 = $4406 | 0;
    var $4407$0 = HEAP32[$st$17$0 >> 2];
    var $st$17$1 = $4406 + 4 | 0;
    var $4407$1 = HEAP32[$st$17$1 >> 2];
    var $4408 = $4403 + ($4400 << 3) | 0;
    var $st$22$0 = $4408 | 0;
    HEAP32[$st$22$0 >> 2] = $4407$0;
    var $st$22$1 = $4408 + 4 | 0;
    HEAP32[$st$22$1 >> 2] = $4407$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 917:
    var $_idx437 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$2$0 = $_idx437 | 0;
    var $_idx437_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx437 + 4 | 0;
    var $_idx437_val$1 = HEAP32[$st$2$1 >> 2];
    var $4411 = __ZL13js_IsCallableRKN2JS5ValueE1841($_idx437_val$0, $_idx437_val$1);
    if ($4411) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    } else {
      __label__ = 918;
      break;
    }
   case 918:
    var $4413 = HEAPU32[$_pre_phi >> 2];
    var $4421 = (HEAPU8[$4413 + 1 | 0] & 255) << 8 | HEAPU8[$4413 + 2 | 0] & 255;
    var $4423 = $4413 + ($4421 << 16 >> 16) | 0;
    HEAP32[$_pre_phi >> 2] = $4423;
    var $4425 = HEAPU8[$4423] & 255;
    if ($4421 << 16 >> 16 < 1) {
      var $op_1 = $4425;
      __label__ = 34;
      break;
    } else {
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $4425;
      __label__ = 18;
      break;
    }
   case 919:
    var $4428 = HEAPU32[$_pre_phi580 >> 2];
    var $_idx97 = $4428 - 8 | 0;
    var $st$2$0 = $_idx97 | 0;
    var $_idx97_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx97 + 4 | 0;
    var $_idx97_val$1 = HEAP32[$st$2$1 >> 2];
    var $4429 = __ZNK2JS5Value8isObjectEv($_idx97_val$0, $_idx97_val$1);
    if ($4429) {
      __label__ = 920;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 2;
      __label__ = 17;
      break;
    }
   case 920:
    var $4433 = HEAP8[HEAP32[$_pre_phi >> 2] + 1 | 0];
    if ($4433 << 24 >> 24 == 0) {
      var $4441 = STRING_TABLE.__str242227 | 0;
      __label__ = 922;
      break;
    } else {
      __label__ = 921;
      break;
    }
   case 921:
    var $4441 = HEAP32[_js_common_atom_names + (($4433 << 24 >> 24) + 3 << 2) >> 2];
    __label__ = 922;
    break;
   case 922:
    var $4441;
    var $_idx449 = $4428 - 16 | 0;
    var $st$2$0 = $_idx449 | 0;
    var $_idx449_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx449 + 4 | 0;
    var $_idx449_val$1 = HEAP32[$st$2$1 >> 2];
    var $4442 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, 38, -2, $_idx449_val$0, $_idx449_val$1, 0, $4441);
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 923:
    var $_idx229 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$2$0 = $_idx229 | 0;
    var $_idx229_val$0 = HEAPU32[$st$2$0 >> 2];
    var $st$2$1 = $_idx229 + 4 | 0;
    var $_idx229_val$1 = HEAPU32[$st$2$1 >> 2];
    var $4445 = __ZNK2JS5Value11isPrimitiveEv($_idx229_val$0, $_idx229_val$1);
    if ($4445) {
      __label__ = 924;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 17;
      break;
    }
   case 924:
    var $4447 = HEAPU32[$_pre_phi >> 2];
    var $4455 = (HEAPU8[$4447 + 1 | 0] & 255) << 8 | HEAPU8[$4447 + 2 | 0] & 255;
    var $4456 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, $4455, -1, $_idx229_val$0, $_idx229_val$1, 0, 0);
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 925:
    var $4458 = HEAPU32[$_pre_phi580 >> 2];
    var $_idx228 = $4458 - 8 | 0;
    var $st$2$0 = $_idx228 | 0;
    var $_idx228_val$0 = HEAPU32[$st$2$0 >> 2];
    var $st$2$1 = $_idx228 + 4 | 0;
    var $_idx228_val$1 = HEAP32[$st$2$1 >> 2];
    var $4459 = __ZNK2JS5Value11isPrimitiveEv($_idx228_val$0, $_idx228_val$1);
    if ($4459) {
      __label__ = 926;
      break;
    } else {
      __label__ = 927;
      break;
    }
   case 926:
    var $4461 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, 31, -1, $_idx228_val$0, $_idx228_val$1, 0, 0);
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 927:
    var $4463 = __ZNK2JS5Value8toObjectEv($_idx228_val$0, $_idx228_val$1);
    var $4464 = $4458 - 16 | 0;
    HEAP32[$cond367 >> 2] = 0;
    var $4465 = __ZN2js11HasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPi($cx, $4463, $4464, $cond367);
    if (($4465 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 928;
      break;
    }
   case 928:
    var $4468 = HEAP32[$_pre_phi580 >> 2];
    var $4469 = $4468 - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4469;
    var $4470 = $4468 - 16 | 0;
    var $4472 = (HEAP32[$cond367 >> 2] | 0) != 0;
    __ZN2JS5Value10setBooleanEb($4470, $4472);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 929:
    var $4474 = HEAP32[$34 >> 2];
    var $4476 = HEAP32[$4474 + 24 >> 2];
    if (($4476 | 0) == 0) {
      __label__ = 931;
      break;
    } else {
      __label__ = 930;
      break;
    }
   case 930:
    var $4479 = HEAP32[$_pre_phi >> 2];
    var $4481 = HEAP32[$4474 + 28 >> 2];
    var $4482 = FUNCTION_TABLE[$4476]($cx, $script_1, $4479, $rval368, $4481);
    if (($4482 | 0) == 1) {
      __label__ = 931;
      break;
    } else {
      var $st_1 = $4482;
      __label__ = 932;
      break;
    }
   case 931:
    var $4484 = __ZN2js8Debugger19onDebuggerStatementEP9JSContextPN2JS5ValueE($cx, $rval368);
    var $st_1 = $4484;
    __label__ = 932;
    break;
   case 932:
    var $st_1;
    if (($st_1 | 0) == 2) {
      __label__ = 933;
      break;
    } else if (($st_1 | 0) == 3) {
      __label__ = 934;
      break;
    } else if (($st_1 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 935;
      break;
    }
   case 933:
    var $regs_idx12_val = HEAP32[$regs_idx73 >> 2];
    var $4487 = __ZNK2js9FrameRegs2fpEv($regs_idx12_val);
    var $4488 = $4487;
    var $rval368_idx = $rval368 | 0;
    var $st$4$0 = $rval368_idx | 0;
    var $rval368_idx_val$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $rval368_idx + 4 | 0;
    var $rval368_idx_val$1 = HEAP32[$st$4$1 >> 2];
    __ZN2js10StackFrame14setReturnValueERKN2JS5ValueE($4488, $rval368_idx_val$0, $rval368_idx_val$1);
    var $interpReturnOK_1 = 1;
    __label__ = 1044;
    break;
   case 934:
    var $4490 = $rval368 | 0;
    var $st$1$0 = $4490 | 0;
    var $4491$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $4490 + 4 | 0;
    var $4491$1 = HEAP32[$st$1$1 >> 2];
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($cx, $4491$0, $4491$1);
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 935:
    if ((HEAP32[HEAP32[$34 >> 2] >> 2] | 0) == 0) {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 936;
      break;
    }
   case 936:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 937:
    var $4500 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $4501 = __Z25js_SetDefaultXMLNamespaceP9JSContextRKN2JS5ValueE($5083, $4500);
    if (($4501 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 938;
      break;
    }
   case 938:
    var $4505 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4505;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 939:
    var $4507 = __Z13js_GetAnyNameP9JSContextPi($5083, $id369);
    if (($4507 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 940;
      break;
    }
   case 940:
    var $4510 = HEAP32[$_pre_phi580 >> 2];
    var $4511 = $4510 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4511;
    var $4512 = HEAP32[$id369 >> 2];
    __ZN2jsL9IdToValueEi1799($12, $4512);
    var $st$5$0 = $5130 | 0;
    var $4513$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $5130 + 4 | 0;
    var $4513$1 = HEAP32[$st$5$1 >> 2];
    var $4514 = $4510 | 0;
    var $st$10$0 = $4514 | 0;
    HEAP32[$st$10$0 >> 2] = $4513$0;
    var $st$10$1 = $4514 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $4513$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 941:
    var $4516 = HEAPU32[$_pre_phi >> 2];
    var $4526 = HEAP32[$atoms_1 + (((HEAPU8[$4516 + 1 | 0] & 255) << 8 | HEAPU8[$4516 + 2 | 0] & 255) << 2) >> 2];
    var $4527 = HEAPU32[$_pre_phi580 >> 2];
    HEAP32[$_pre_phi580 >> 2] = $4527 + 8 | 0;
    var $4529 = $4526 | 0;
    __ZN2JS5Value9setStringEP8JSString($4527, $4529);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 942:
    var $4531 = HEAPU32[$_pre_phi >> 2];
    var $4542 = HEAP32[$atoms_1 + (((HEAPU8[$4531 + 1 | 0] & 255) << 8 | HEAPU8[$4531 + 2 | 0] & 255) << 2) >> 2] | 0;
    __ZN2JSL11StringValueEP8JSString1846($rval372, $4542);
    var $4544 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$15$0 = $4544 | 0;
    var $4545$0 = HEAP32[$st$15$0 >> 2];
    var $st$15$1 = $4544 + 4 | 0;
    var $4545$1 = HEAP32[$st$15$1 >> 2];
    var $4546 = __Z26js_ConstructXMLQNameObjectP9JSContextRKN2JS5ValueES4_($5083, $4545$0, $4545$1, $rval372);
    if (($4546 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 943;
      break;
    }
   case 943:
    var $4549 = $4546;
    var $4551 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    __ZN2JS5Value9setObjectER8JSObject($4551, $4549);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 944:
    var $4553 = HEAP32[$_pre_phi580 >> 2];
    var $4554 = $4553 - 8 | 0;
    var $st$2$0 = $4554 | 0;
    var $4555$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $4554 + 4 | 0;
    var $4555$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5131 | 0;
    HEAP32[$st$6$0 >> 2] = $4555$0;
    var $st$6$1 = $5131 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4555$1;
    var $4556 = $4553 - 16 | 0;
    var $st$11$0 = $4556 | 0;
    var $4557$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $4556 + 4 | 0;
    var $4557$1 = HEAP32[$st$11$1 >> 2];
    var $4558 = __Z26js_ConstructXMLQNameObjectP9JSContextRKN2JS5ValueES4_($5083, $4557$0, $4557$1, $rval375);
    if (($4558 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 945;
      break;
    }
   case 945:
    var $4561 = $4558;
    var $4562 = HEAP32[$_pre_phi580 >> 2];
    var $4563 = $4562 - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4563;
    var $4564 = $4562 - 16 | 0;
    __ZN2JS5Value9setObjectER8JSObject($4564, $4561);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 946:
    var $4567 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$2$0 = $4567 | 0;
    var $4568$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $4567 + 4 | 0;
    var $4568$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5132 | 0;
    HEAP32[$st$6$0 >> 2] = $4568$0;
    var $st$6$1 = $5132 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4568$1;
    var $4569 = __Z18js_ToAttributeNameP9JSContextPN2JS5ValueE($5083, $rval378);
    if (($4569 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 947;
      break;
    }
   case 947:
    var $st$1$0 = $5132 | 0;
    var $4573$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $5132 + 4 | 0;
    var $4573$1 = HEAP32[$st$1$1 >> 2];
    var $4574 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$6$0 = $4574 | 0;
    HEAP32[$st$6$0 >> 2] = $4573$0;
    var $st$6$1 = $4574 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4573$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 948:
    var $4577 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$2$0 = $4577 | 0;
    var $4578$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $4577 + 4 | 0;
    var $4578$1 = HEAP32[$st$2$1 >> 2];
    var $4579 = __ZNK2JS5Value8toStringEv($4578$0, $4578$1);
    var $4580 = __Z23js_EscapeAttributeValueP9JSContextP8JSStringi($5083, $4579, 0);
    if (($4580 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 949;
      break;
    }
   case 949:
    var $4583 = $4580 | 0;
    var $4585 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    __ZN2JS5Value9setStringEP8JSString($4585, $4583);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 950:
    var $4587 = HEAP32[$_pre_phi580 >> 2];
    var $4588 = $4587 - 8 | 0;
    var $st$2$0 = $4588 | 0;
    var $4589$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $4588 + 4 | 0;
    var $4589$1 = HEAP32[$st$2$1 >> 2];
    var $4590 = $4587 - 16 | 0;
    var $st$7$0 = $4590 | 0;
    var $4591$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $4590 + 4 | 0;
    var $4591$1 = HEAP32[$st$7$1 >> 2];
    var $4592 = __ZNK2JS5Value8toStringEv($4591$0, $4591$1);
    var $4593 = __ZNK2JS5Value8toStringEv($4589$0, $4589$1);
    var $4596 = __Z19js_AddAttributePartP9JSContextiP8JSStringS2_($5083, ($op_0 | 0) == 170 & 1, $4592, $4593);
    if (($4596 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 951;
      break;
    }
   case 951:
    var $4599 = HEAP32[$_pre_phi580 >> 2];
    var $4600 = $4599 - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4600;
    var $4601 = $4599 - 16 | 0;
    __ZN2JS5Value9setStringEP8JSString($4601, $4596);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 952:
    var $4604 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$2$0 = $4604 | 0;
    var $4605$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $4604 + 4 | 0;
    var $4605$1 = HEAP32[$st$2$1 >> 2];
    var $4606 = __Z18js_FindXMLPropertyP9JSContextRKN2JS5ValueEPP8JSObjectPi($5083, $4605$0, $4605$1, $5133, $id387);
    if (($4606 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 953;
      break;
    }
   case 953:
    var $4610 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $4611 = HEAP32[$obj386 >> 2];
    __ZN2JS5Value15setObjectOrNullEP8JSObject($4610, $4611);
    var $4612 = HEAP32[$_pre_phi580 >> 2];
    var $4613 = $4612 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4613;
    var $4614 = HEAP32[$id387 >> 2];
    __ZN2jsL9IdToValueEi1799($13, $4614);
    var $st$9$0 = $5134 | 0;
    var $4615$0 = HEAP32[$st$9$0 >> 2];
    var $st$9$1 = $5134 + 4 | 0;
    var $4615$1 = HEAP32[$st$9$1 >> 2];
    var $4616 = $4612 | 0;
    var $st$14$0 = $4616 | 0;
    HEAP32[$st$14$0 >> 2] = $4615$0;
    var $st$14$1 = $4616 + 4 | 0;
    HEAP32[$st$14$1 >> 2] = $4615$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 954:
    var $4618 = HEAP32[$_pre_phi580 >> 2];
    var $_idx121 = $4618 - 24 | 0;
    var $st$2$0 = $_idx121 | 0;
    var $_idx121_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx121 + 4 | 0;
    var $_idx121_val$1 = HEAP32[$st$2$1 >> 2];
    var $4619 = __ZNK2JS5Value8toObjectEv($_idx121_val$0, $_idx121_val$1);
    var $4620 = $4618 - 8 | 0;
    var $st$8$0 = $4620 | 0;
    var $4621$0 = HEAP32[$st$8$0 >> 2];
    var $st$8$1 = $4620 + 4 | 0;
    var $4621$1 = HEAP32[$st$8$1 >> 2];
    var $st$12$0 = $5135 | 0;
    HEAP32[$st$12$0 >> 2] = $4621$0;
    var $st$12$1 = $5135 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $4621$1;
    var $4622 = $4618 - 16 | 0;
    var $4623 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($4622, $i_392);
    if ($4623) {
      __label__ = 955;
      break;
    } else {
      __label__ = 957;
      break;
    }
   case 955:
    var $4625 = HEAP32[$i_392 >> 2];
    var $4626 = _INT_FITS_IN_JSID1825($4625);
    if (($4626 | 0) == 0) {
      __label__ = 957;
      break;
    } else {
      __label__ = 956;
      break;
    }
   case 956:
    var $4629 = _INT_TO_JSID1826($4625);
    HEAP32[$id390 >> 2] = $4629;
    var $4635 = $4629;
    __label__ = 959;
    break;
   case 957:
    var $4632 = HEAP32[$_pre_phi580 >> 2] - 16 | 0;
    var $4633 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $4619, $4622, $id390, $4632);
    if ($4633) {
      __label__ = 958;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 958:
    var $4635 = HEAP32[$id390 >> 2];
    __label__ = 959;
    break;
   case 959:
    var $4635;
    var $4640 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $4641 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($4619, $cx, $4635, $rval389, $4640);
    if (($4641 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 960;
      break;
    }
   case 960:
    var $4644 = HEAPU32[$_pre_phi580 >> 2];
    var $4645 = $4644 - 8 | 0;
    var $st$2$0 = $4645 | 0;
    var $4646$0 = HEAPU32[$st$2$0 >> 2];
    var $st$2$1 = $4645 + 4 | 0;
    var $4646$1 = HEAPU32[$st$2$1 >> 2];
    var $st$6$0 = $5135 | 0;
    HEAP32[$st$6$0 >> 2] = $4646$0;
    var $st$6$1 = $5135 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4646$1;
    HEAP32[$_pre_phi580 >> 2] = $4644 - 16 | 0;
    var $4648 = $4644 - 24 | 0;
    var $st$13$0 = $4648 | 0;
    HEAP32[$st$13$0 >> 2] = $4646$0;
    var $st$13$1 = $4648 + 4 | 0;
    HEAP32[$st$13$1 >> 2] = $4646$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 961:
    var $4651 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$2$0 = $4651 | 0;
    var $4652$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $4651 + 4 | 0;
    var $4652$1 = HEAP32[$st$2$1 >> 2];
    var $4653 = __Z18js_FindXMLPropertyP9JSContextRKN2JS5ValueEPP8JSObjectPi($5083, $4652$0, $4652$1, $5136, $id395);
    if (($4653 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 962;
      break;
    }
   case 962:
    var $4656 = HEAP32[$obj394 >> 2];
    var $4657 = HEAP32[$id395 >> 2];
    var $4658 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($4656, $cx, $4657, $rval396);
    if (($4658 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 963;
      break;
    }
   case 963:
    var $st$1$0 = $5137 | 0;
    var $4662$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $5137 + 4 | 0;
    var $4662$1 = HEAP32[$st$1$1 >> 2];
    var $4663 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$6$0 = $4663 | 0;
    HEAP32[$st$6$0 >> 2] = $4662$0;
    var $st$6$1 = $4663 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4662$1;
    if (($op_0 | 0) == 199) {
      __label__ = 964;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 17;
      break;
    }
   case 964:
    var $4666 = __ZN2js19ComputeImplicitThisEP9JSContextP8JSObjectRKN2JS5ValueEPS5_($cx, $4656, $rval396, $v397);
    if ($4666) {
      __label__ = 965;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 965:
    var $4668 = HEAP32[$_pre_phi580 >> 2];
    var $4669 = $4668 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4669;
    var $st$3$0 = $5138 | 0;
    var $4670$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5138 + 4 | 0;
    var $4670$1 = HEAP32[$st$3$1 >> 2];
    var $4671 = $4668 | 0;
    var $st$8$0 = $4671 | 0;
    HEAP32[$st$8$0 >> 2] = $4670$0;
    var $st$8$1 = $4671 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $4670$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 966:
    var $4673 = HEAP32[$_pre_phi580 >> 2];
    var $4674 = $4673 - 16 | 0;
    var $_idx96 = $4674 | 0;
    var $st$3$0 = $_idx96 | 0;
    var $_idx96_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx96 + 4 | 0;
    var $_idx96_val$1 = HEAP32[$st$3$1 >> 2];
    var $4675 = __ZNK2JS5Value8isObjectEv($_idx96_val$0, $_idx96_val$1);
    if ($4675) {
      __label__ = 967;
      break;
    } else {
      __label__ = 968;
      break;
    }
   case 967:
    var $4677 = __ZNK2JS5Value8toObjectEv($_idx96_val$0, $_idx96_val$1);
    var $obj398_0 = $4677;
    var $4684 = $4673;
    __label__ = 970;
    break;
   case 968:
    var $4679 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5080, $4674);
    var $4680 = $4679;
    if (($4679 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 969;
      break;
    }
   case 969:
    __ZN2JS5Value9setObjectER8JSObject($4674, $4680);
    var $obj398_0 = $4680;
    var $4684 = HEAP32[$_pre_phi580 >> 2];
    __label__ = 970;
    break;
   case 970:
    var $4684;
    var $obj398_0;
    var $4685 = $4684 - 8 | 0;
    var $st$3$0 = $4685 | 0;
    var $4686$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $4685 + 4 | 0;
    var $4686$1 = HEAP32[$st$3$1 >> 2];
    var $st$7$0 = $5139 | 0;
    HEAP32[$st$7$0 >> 2] = $4686$0;
    var $st$7$1 = $5139 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $4686$1;
    var $4688 = __Z20js_GetXMLDescendantsP9JSContextP8JSObjectN2JS5ValueEPS4_($5083, $obj398_0, $4686$0, $4686$1, $rval400);
    if (($4688 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 971;
      break;
    }
   case 971:
    if (($op_0 | 0) == 186) {
      __label__ = 973;
      break;
    } else {
      __label__ = 972;
      break;
    }
   case 972:
    var $st$0$0 = $5139 | 0;
    var $st$0$1 = $5139 + 4 | 0;
    var $4700$1 = HEAP32[$st$0$1 >> 2];
    var $4700$0 = HEAP32[$st$0$0 >> 2];
    __label__ = 974;
    break;
   case 973:
    var $st$1$0 = $5139 | 0;
    var $4694$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $5139 + 4 | 0;
    var $4694$1 = HEAP32[$st$1$1 >> 2];
    var $4695 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$6$0 = $4695 | 0;
    HEAP32[$st$6$0 >> 2] = $4694$0;
    var $st$6$1 = $4695 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4694$1;
    var $4696 = _JSVAL_TO_OBJECT1847($4694$0, $4694$1);
    var $4697 = $4696;
    __Z24js_DeleteXMLListElementsP9JSContextP8JSObject($4697);
    var $$emscripten$temp$0 = _JSVAL_TRUE | 0;
    var $st$14$0 = $$emscripten$temp$0 | 0;
    var $4698$0 = HEAP32[$st$14$0 >> 2];
    var $st$14$1 = $$emscripten$temp$0 + 4 | 0;
    var $4698$1 = HEAP32[$st$14$1 >> 2];
    var $st$18$0 = $5139 | 0;
    HEAP32[$st$18$0 >> 2] = $4698$0;
    var $st$18$1 = $5139 + 4 | 0;
    HEAP32[$st$18$1 >> 2] = $4698$1;
    var $4700$1 = $4698$1;
    var $4700$0 = $4698$0;
    __label__ = 974;
    break;
   case 974:
    var $4700$0;
    var $4700$1;
    var $4701 = HEAP32[$_pre_phi580 >> 2];
    var $4702 = $4701 - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4702;
    var $4703 = $4701 - 16 | 0;
    var $st$6$0 = $4703 | 0;
    HEAP32[$st$6$0 >> 2] = $4700$0;
    var $st$6$1 = $4703 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4700$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 975:
    var $4705 = HEAP32[$_pre_phi580 >> 2];
    var $4706 = $4705 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4706;
    __ZN2JS5Value8setMagicE10JSWhyMagic($4705, 0);
    var $4707 = HEAPU32[$_pre_phi >> 2];
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = ((HEAPU8[$4707 + 1 | 0] & 255) << 8 | HEAPU8[$4707 + 2 | 0] & 255) << 16 >> 16;
    __label__ = 17;
    break;
   case 976:
    var $_idx378 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$2$0 = $_idx378 | 0;
    var $_idx378_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx378 + 4 | 0;
    var $_idx378_val$1 = HEAP32[$st$2$1 >> 2];
    var $4719 = __ZNK2JS5Value7isMagicEv($_idx378_val$0, $_idx378_val$1);
    if ($4719) {
      __label__ = 978;
      break;
    } else {
      __label__ = 977;
      break;
    }
   case 977:
    __ZL9LeaveWithP9JSContext($cx);
    __label__ = 978;
    break;
   case 978:
    var $4723 = $4719 & 1 ^ 1;
    var $4724 = __Z20js_StepXMLListFilterP9JSContexti($5083, $4723);
    if (($4724 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 979;
      break;
    }
   case 979:
    var $4728 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $_idx317 = $4728 | 0;
    var $st$3$0 = $_idx317 | 0;
    var $_idx317_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx317 + 4 | 0;
    var $_idx317_val$1 = HEAP32[$st$3$1 >> 2];
    var $4729 = __ZNK2JS5Value6isNullEv($_idx317_val$0, $_idx317_val$1);
    if ($4729) {
      __label__ = 982;
      break;
    } else {
      __label__ = 980;
      break;
    }
   case 980:
    var $4731 = __ZL9EnterWithP9JSContexti4JSOpj($cx, -2, 3);
    if ($4731) {
      __label__ = 981;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 981:
    var $4734 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4734;
    var $4735 = HEAPU32[$_pre_phi >> 2];
    var $4743 = (HEAPU8[$4735 + 1 | 0] & 255) << 8 | HEAPU8[$4735 + 2 | 0] & 255;
    var $4745 = $4735 + ($4743 << 16 >> 16) | 0;
    HEAP32[$_pre_phi >> 2] = $4745;
    var $4747 = HEAPU8[$4745] & 255;
    if ($4743 << 16 >> 16 < 1) {
      var $op_1 = $4747;
      __label__ = 34;
      break;
    } else {
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $4747;
      __label__ = 18;
      break;
    }
   case 982:
    HEAP32[$_pre_phi580 >> 2] = $4728;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 983:
    var $4752 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$2$0 = $4752 | 0;
    var $4753$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $4752 + 4 | 0;
    var $4753$1 = HEAP32[$st$2$1 >> 2];
    var $4754 = __Z19js_ValueToXMLObjectP9JSContextRKN2JS5ValueE($5083, $4753$0, $4753$1);
    if (($4754 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 984;
      break;
    }
   case 984:
    var $4757 = $4754;
    var $4759 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    __ZN2JS5Value9setObjectER8JSObject($4759, $4757);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 985:
    var $4762 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$2$0 = $4762 | 0;
    var $4763$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $4762 + 4 | 0;
    var $4763$1 = HEAP32[$st$2$1 >> 2];
    var $4764 = __Z23js_ValueToXMLListObjectP9JSContextRKN2JS5ValueE($5083, $4763$0, $4763$1);
    if (($4764 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 986;
      break;
    }
   case 986:
    var $4767 = $4764;
    var $4769 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    __ZN2JS5Value9setObjectER8JSObject($4769, $4767);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 987:
    var $4772 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$2$0 = $4772 | 0;
    var $4773$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $4772 + 4 | 0;
    var $4773$1 = HEAP32[$st$2$1 >> 2];
    var $4774 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($5077, $4773$0, $4773$1);
    if (($4774 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 988;
      break;
    }
   case 988:
    var $4778 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    __ZN2JS5Value9setStringEP8JSString($4778, $4774);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 989:
    var $4781 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$2$0 = $4781 | 0;
    var $4782$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $4781 + 4 | 0;
    var $4782$1 = HEAP32[$st$2$1 >> 2];
    var $4783 = __ZL5IsXMLRKN2JS5ValueE($4782$0, $4782$1);
    if ($4783) {
      __label__ = 990;
      break;
    } else {
      __label__ = 991;
      break;
    }
   case 990:
    var $4785 = __Z19js_ValueToXMLStringP9JSContextRKN2JS5ValueE($5083, $4782$0, $4782$1);
    var $str409_0 = $4785;
    __label__ = 993;
    break;
   case 991:
    var $4787 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($5077, $4782$0, $4782$1);
    if (($4787 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 992;
      break;
    }
   case 992:
    var $4790 = __Z21js_EscapeElementValueP9JSContextP8JSString($5083, $4787);
    var $str409_0 = $4790 | 0;
    __label__ = 993;
    break;
   case 993:
    var $str409_0;
    if (($str409_0 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 994;
      break;
    }
   case 994:
    var $4796 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    __ZN2JS5Value9setStringEP8JSString($4796, $str409_0);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 995:
    var $4798 = HEAPU32[$_pre_phi >> 2];
    var $4809 = HEAP32[$atoms_1 + (((HEAPU8[$4798 + 1 | 0] & 255) << 8 | HEAPU8[$4798 + 2 | 0] & 255) << 2) >> 2] | 0;
    var $4810 = __Z22js_NewXMLSpecialObjectP9JSContext10JSXMLClassP8JSStringS3_($5083, 4, 0, $4809);
    if (($4810 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 996;
      break;
    }
   case 996:
    var $4813 = $4810;
    var $4814 = HEAP32[$_pre_phi580 >> 2];
    var $4815 = $4814 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4815;
    __ZN2JS5Value9setObjectER8JSObject($4814, $4813);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 997:
    var $4817 = HEAPU32[$_pre_phi >> 2];
    var $4828 = HEAP32[$atoms_1 + (((HEAPU8[$4817 + 1 | 0] & 255) << 8 | HEAPU8[$4817 + 2 | 0] & 255) << 2) >> 2] | 0;
    var $4829 = __Z22js_NewXMLSpecialObjectP9JSContext10JSXMLClassP8JSStringS3_($5083, 5, 0, $4828);
    if (($4829 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 998;
      break;
    }
   case 998:
    var $4832 = $4829;
    var $4833 = HEAP32[$_pre_phi580 >> 2];
    var $4834 = $4833 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4834;
    __ZN2JS5Value9setObjectER8JSObject($4833, $4832);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 999:
    var $4836 = HEAPU32[$_pre_phi >> 2];
    var $4847 = HEAP32[$atoms_1 + (((HEAPU8[$4836 + 1 | 0] & 255) << 8 | HEAPU8[$4836 + 2 | 0] & 255) << 2) >> 2] | 0;
    var $4849 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$14$0 = $4849 | 0;
    var $4850$0 = HEAP32[$st$14$0 >> 2];
    var $st$14$1 = $4849 + 4 | 0;
    var $4850$1 = HEAP32[$st$14$1 >> 2];
    var $4851 = __ZNK2JS5Value8toStringEv($4850$0, $4850$1);
    var $4852 = __Z22js_NewXMLSpecialObjectP9JSContext10JSXMLClassP8JSStringS3_($5083, 3, $4847, $4851);
    if (($4852 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 1e3;
      break;
    }
   case 1e3:
    var $4855 = $4852;
    var $4857 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    __ZN2JS5Value9setObjectER8JSObject($4857, $4855);
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 1001:
    var $4859 = __ZNK9JSContext2fpEv($cx);
    var $4860 = __ZNK2js10StackFrame10scopeChainEv($4859);
    var $4861 = $4860;
    var $4862 = __ZNK8JSObject9getGlobalEv($4861);
    var $4863 = $4862;
    var $4864 = __ZN2js12GlobalObject20getFunctionNamespaceEP9JSContextPN2JS5ValueE($4863, $5083, $rval421);
    if ($4864) {
      __label__ = 1002;
      break;
    } else {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 1002:
    var $4866 = HEAP32[$_pre_phi580 >> 2];
    var $4867 = $4866 + 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4867;
    var $st$3$0 = $5140 | 0;
    var $4868$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5140 + 4 | 0;
    var $4868$1 = HEAP32[$st$3$1 >> 2];
    var $4869 = $4866 | 0;
    var $st$8$0 = $4869 | 0;
    HEAP32[$st$8$0 >> 2] = $4868$0;
    var $st$8$1 = $4869 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $4868$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 17;
    break;
   case 1003:
    var $4877 = HEAPU32[$_pre_phi >> 2];
    var $4886 = ((HEAPU8[$4877 + 1 | 0] & 255) << 8 | HEAPU8[$4877 + 2 | 0] & 255) + ($atoms_1 - HEAP32[$script_1 + 56 >> 2] >> 2) | 0;
    var $script_1_idx154_val = HEAP32[$script_1 + 4 >> 2];
    var $script_1_idx155_val = HEAP8[$script_1 + 16 | 0];
    var $4887 = __ZN8JSScript9getObjectEj($script_1_idx154_val, $script_1_idx155_val, $4886);
    var $4888 = HEAP32[$_pre_phi580 >> 2];
    var $4889 = $4887;
    var $4890 = __ZNK8JSObject13propertyCountEv($4889);
    var $4891 = $4888 + ($4890 << 3) | 0;
    var $4892 = HEAP32[$_pre_phi580 >> 2];
    __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueES2_1848($4892, $4891);
    HEAP32[$_pre_phi580 >> 2] = $4891;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 1004:
    var $4899 = HEAPU32[$_pre_phi >> 2];
    var $4908 = ((HEAPU8[$4899 + 3 | 0] & 255) << 8 | HEAPU8[$4899 + 4 | 0] & 255) + ($atoms_1 - HEAP32[$script_1 + 56 >> 2] >> 2) | 0;
    var $script_1_idx_val = HEAP32[$script_1 + 4 >> 2];
    var $script_1_idx153_val = HEAP8[$script_1 + 16 | 0];
    var $4909 = __ZN8JSScript9getObjectEj($script_1_idx_val, $script_1_idx153_val, $4908);
    var $regs_idx11_val = HEAP32[$regs_idx73 >> 2];
    var $4910 = __ZNK2js9FrameRegs2fpEv($regs_idx11_val);
    var $4911 = __ZNK2js10StackFrame10scopeChainEv($4910);
    var $_idx226_val_idx_val = HEAP32[HEAP32[$4911 + 36 >> 2] >> 2];
    var $4912 = __ZNK8JSObject8getProtoEv($_idx226_val_idx_val);
    if (($4912 | 0) == ($4909 | 0)) {
      __label__ = 1005;
      break;
    } else {
      __label__ = 1006;
      break;
    }
   case 1005:
    var $4915 = __Z17js_PutBlockObjectP9JSContexti($5080, 1);
    if (($4915 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 1006;
      break;
    }
   case 1006:
    var $4917 = ($op_0 | 0) == 210;
    var $4918 = HEAPU32[$_pre_phi580 >> 2];
    var $vp425_0 = $4917 ? $4918 - 8 | 0 : 0;
    var $4919 = HEAPU32[$_pre_phi >> 2];
    var $4927 = (HEAPU8[$4919 + 1 | 0] & 255) << 8 | HEAPU8[$4919 + 2 | 0] & 255;
    HEAP32[$_pre_phi580 >> 2] = $4918 + (-$4927 << 3) | 0;
    if ($4917) {
      __label__ = 1007;
      break;
    } else {
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 5;
      __label__ = 17;
      break;
    }
   case 1007:
    var $st$1$0 = $vp425_0 | 0;
    var $4931$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $vp425_0 + 4 | 0;
    var $4931$1 = HEAP32[$st$1$1 >> 2];
    var $4932 = $4918 + (($4927 ^ -1) << 3) | 0;
    var $st$6$0 = $4932 | 0;
    HEAP32[$st$6$0 >> 2] = $4931$0;
    var $st$6$1 = $4932 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4931$1;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 5;
    __label__ = 17;
    break;
   case 1008:
    var $4935 = HEAP32[$_pre_phi >> 2] + 1 | 0;
    HEAP32[$_pre_phi >> 2] = $4935;
    var $4936 = __Z15js_NewGeneratorP9JSContext($5084);
    if (($4936 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 1009;
      break;
    }
   case 1009:
    var $4939 = $4936;
    var $regs_idx10_val = HEAP32[$regs_idx73 >> 2];
    var $4940 = __ZNK2js9FrameRegs2fpEv($regs_idx10_val);
    __ZN2JSL11ObjectValueER8JSObject1804($14, $4939);
    var $4941 = $4940;
    var $_idx389 = $14 | 0;
    var $st$6$0 = $_idx389 | 0;
    var $_idx389_val$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $_idx389 + 4 | 0;
    var $_idx389_val$1 = HEAP32[$st$6$1 >> 2];
    __ZN2js10StackFrame14setReturnValueERKN2JS5ValueE($4941, $_idx389_val$0, $_idx389_val$1);
    var $regs_idx9_val = HEAPU32[$regs_idx73 >> 2];
    var $4942 = __ZNK2js9FrameRegs2fpEv($regs_idx9_val);
    if (($_08 | 0) == ($4942 | 0)) {
      var $interpReturnOK_2 = 1;
      var $regs_idx1_val = $regs_idx9_val;
      __label__ = 1047;
      break;
    } else {
      var $interpReturnOK_0 = 1;
      var $regs_idx62_val = $regs_idx9_val;
      __label__ = 49;
      break;
    }
   case 1010:
    var $regs_idx8_val = HEAP32[$regs_idx73 >> 2];
    var $4945 = __ZNK2js9FrameRegs2fpEv($regs_idx8_val);
    var $4946 = __ZNK9JSContext12generatorForEPN2js10StackFrameE($cx, $4945);
    if ((HEAP32[$4946 + 4 >> 2] | 0) == 3) {
      __label__ = 1011;
      break;
    } else {
      __label__ = 1012;
      break;
    }
   case 1011:
    var $_idx452 = $argv_1 - 16 | 0;
    var $st$1$0 = $_idx452 | 0;
    var $_idx452_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx452 + 4 | 0;
    var $_idx452_val$1 = HEAP32[$st$1$1 >> 2];
    var $4951 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, 214, 1, $_idx452_val$0, $_idx452_val$1, 0, 0);
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 1012:
    var $4954 = $4945;
    var $_idx388 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $st$3$0 = $_idx388 | 0;
    var $_idx388_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx388 + 4 | 0;
    var $_idx388_val$1 = HEAP32[$st$3$1 >> 2];
    __ZN2js10StackFrame14setReturnValueERKN2JS5ValueE($4954, $_idx388_val$0, $_idx388_val$1);
    var $regs_idx7_val = HEAP32[$regs_idx73 >> 2];
    var $4955 = __ZNK2js9FrameRegs2fpEv($regs_idx7_val);
    __ZN2js10StackFrame11setYieldingEv($4955);
    var $4957 = HEAP32[$_pre_phi >> 2] + 1 | 0;
    HEAP32[$_pre_phi >> 2] = $4957;
    var $interpReturnOK_2 = 1;
    var $regs_idx1_val = HEAP32[$regs_idx73 >> 2];
    __label__ = 1047;
    break;
   case 1013:
    var $4959 = HEAPU32[$_pre_phi >> 2];
    var $4967 = (HEAPU8[$4959 + 1 | 0] & 255) << 8 | HEAPU8[$4959 + 2 | 0] & 255;
    var $regs_idx6_val = HEAP32[$regs_idx73 >> 2];
    var $4968 = __ZNK2js9FrameRegs2fpEv($regs_idx6_val);
    var $4969 = $4968;
    var $4970 = __ZNK2js10StackFrame5slotsEv($4969);
    var $_idx119 = $4970 + ($4967 << 3) | 0;
    var $st$14$0 = $_idx119 | 0;
    var $_idx119_val$0 = HEAP32[$st$14$0 >> 2];
    var $st$14$1 = $_idx119 + 4 | 0;
    var $_idx119_val$1 = HEAP32[$st$14$1 >> 2];
    var $4971 = __ZNK2JS5Value8toObjectEv($_idx119_val$0, $_idx119_val$1);
    var $4973 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    var $4974 = __Z19js_NewbornArrayPushP9JSContextP8JSObjectRKN2JS5ValueE($cx, $4971, $4973);
    if (($4974 | 0) == 0) {
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 1014;
      break;
    }
   case 1014:
    var $4978 = HEAP32[$_pre_phi580 >> 2] - 8 | 0;
    HEAP32[$_pre_phi580 >> 2] = $4978;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 17;
    break;
   case 1015:
    var $4980 = $numBuf429 | 0;
    var $4981 = _JS_snprintf($4980, 12, STRING_TABLE.__str4498 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $op_0, tempInt));
    _JS_ReportErrorNumber($cx, 4, 32, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $4980, tempInt));
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 1016:
    var $argv_2_ph1345;
    var $pcCounts_2_ph1346;
    var $script_2_ph1347;
    var $4982 = $script_2_ph1347 + 56 | 0;
    var $4983 = $cx + 56 | 0;
    var $4984 = $script_2_ph1347 + 19 | 0;
    var $4985 = $regs + 4 | 0;
    var $4986 = $regs | 0;
    var $4987 = $cx;
    var $4988 = $v435 | 0;
    var $4989 = $rval432 | 0;
    var $cx_idx196 = $cx + 20 | 0;
    var $script_2_ph1347_idx250 = $script_2_ph1347 | 0;
    var $script_2_ph1347_idx251 = $script_2_ph1347 + 32 | 0;
    var $script_2_ph1347_idx337 = $script_2_ph1347 + 4 | 0;
    var $cx_idx201 = $cx + 24 | 0;
    var $_idx356 = $15 | 0;
    __label__ = 1017;
    break;
   case 1017:
    var $cx_idx196_val = HEAP32[$cx_idx196 >> 2];
    var $4990 = __ZN9JSContext18isExceptionPendingEv($cx_idx196_val);
    if ($4990) {
      __label__ = 1018;
      break;
    } else {
      var $interpReturnOK_1 = 0;
      __label__ = 1044;
      break;
    }
   case 1018:
    var $4992 = HEAP32[$4982 >> 2];
    if ((HEAP32[HEAP32[$34 >> 2] + 56 >> 2] | 0) == 0) {
      __label__ = 1019;
      break;
    } else {
      __label__ = 1020;
      break;
    }
   case 1019:
    var $4998 = HEAP32[$4983 >> 2];
    var $4999 = __ZN13JSCompartment12getDebuggeesEv($4998);
    var $5000 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5emptyEv($4999);
    if ($5000) {
      __label__ = 1029;
      break;
    } else {
      __label__ = 1020;
      break;
    }
   case 1020:
    var $5002 = __ZN2js8Debugger17onExceptionUnwindEP9JSContextPN2JS5ValueE($cx, $rval432);
    if (($5002 | 0) == 1) {
      __label__ = 1021;
      break;
    } else {
      var $st433_0 = $5002;
      __label__ = 1023;
      break;
    }
   case 1021:
    var $5005 = HEAP32[$34 >> 2];
    var $5007 = HEAP32[$5005 + 56 >> 2];
    if (($5007 | 0) == 0) {
      __label__ = 1027;
      break;
    } else {
      __label__ = 1022;
      break;
    }
   case 1022:
    var $5010 = HEAP32[$4985 >> 2];
    var $5012 = HEAP32[$5005 + 60 >> 2];
    var $5013 = FUNCTION_TABLE[$5007]($cx, $script_2_ph1347, $5010, $rval432, $5012);
    var $st433_0 = $5013;
    __label__ = 1023;
    break;
   case 1023:
    var $st433_0;
    if (($st433_0 | 0) == 0) {
      __label__ = 1024;
      break;
    } else if (($st433_0 | 0) == 2) {
      __label__ = 1025;
      break;
    } else if (($st433_0 | 0) == 3) {
      __label__ = 1026;
      break;
    } else {
      __label__ = 1027;
      break;
    }
   case 1024:
    __ZN9JSContext21clearPendingExceptionEv($cx);
    __label__ = 1017;
    break;
   case 1025:
    __ZN9JSContext21clearPendingExceptionEv($cx);
    var $regs_idx5_val = HEAP32[$regs_idx73 >> 2];
    var $5017 = __ZNK2js9FrameRegs2fpEv($regs_idx5_val);
    var $5018 = $5017;
    var $st$4$0 = $4989 | 0;
    var $rval432_idx_val$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $4989 + 4 | 0;
    var $rval432_idx_val$1 = HEAP32[$st$4$1 >> 2];
    __ZN2js10StackFrame14setReturnValueERKN2JS5ValueE($5018, $rval432_idx_val$0, $rval432_idx_val$1);
    var $interpReturnOK_1 = 1;
    __label__ = 1044;
    break;
   case 1026:
    var $st$0$0 = $4989 | 0;
    var $5020$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $4989 + 4 | 0;
    var $5020$1 = HEAP32[$st$0$1 >> 2];
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($cx, $5020$0, $5020$1);
    __label__ = 1027;
    break;
   case 1027:
    if ((HEAP32[HEAP32[$34 >> 2] >> 2] | 0) == 0) {
      __label__ = 1029;
      break;
    } else {
      __label__ = 1028;
      break;
    }
   case 1028:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 1029;
    break;
   case 1029:
    var $5027 = HEAP8[$4984];
    var $5028 = __ZN8JSScript13isValidOffsetEh($5027);
    if ($5028) {
      __label__ = 1030;
      break;
    } else {
      __label__ = 1041;
      break;
    }
   case 1030:
    var $5030 = HEAP32[$4985 >> 2];
    var $script_2_ph1347_idx250_val = HEAP32[$script_2_ph1347_idx250 >> 2];
    var $script_2_ph1347_idx251_val = HEAP32[$script_2_ph1347_idx251 >> 2];
    var $5031 = __ZN8JSScript4mainEv($script_2_ph1347_idx250_val, $script_2_ph1347_idx251_val);
    var $5032 = $5030;
    var $5033 = $5031;
    var $script_2_ph1347_idx337_val = HEAP32[$script_2_ph1347_idx337 >> 2];
    var $5034 = __ZN8JSScript8trynotesEv($script_2_ph1347_idx337_val, $5027);
    var $5036 = HEAP32[$5034 >> 2];
    var $5039 = $5036 + HEAP32[$5034 + 4 >> 2] * 12 | 0;
    var $5040 = $5032 - $5033 | 0;
    var $tn_0 = $5036;
    __label__ = 1031;
    break;
   case 1031:
    var $tn_0;
    var $5043 = HEAPU32[$tn_0 + 4 >> 2];
    var $5046 = HEAPU32[$tn_0 + 8 >> 2];
    if (($5040 - $5043 | 0) >>> 0 < $5046 >>> 0) {
      __label__ = 1032;
      break;
    } else {
      __label__ = 1040;
      break;
    }
   case 1032:
    var $5049 = $tn_0 + 2 | 0;
    var $5051 = HEAPU16[$5049 >> 1] & 65535;
    var $5052 = HEAP32[$4986 >> 2];
    var $regs_idx4_val = HEAP32[$regs_idx73 >> 2];
    var $5053 = __ZNK2js9FrameRegs2fpEv($regs_idx4_val);
    var $5054 = $5053;
    var $5055 = __ZNK2js10StackFrame4baseEv($5054);
    if (($5051 | 0) > ($5052 - $5055 >> 3 | 0)) {
      __label__ = 1040;
      break;
    } else {
      __label__ = 1033;
      break;
    }
   case 1033:
    var $script_2_ph1347_idx_val = HEAP32[$script_2_ph1347_idx250 >> 2];
    var $script_2_ph1347_idx249_val = HEAP32[$script_2_ph1347_idx251 >> 2];
    var $5062 = __ZN8JSScript4mainEv($script_2_ph1347_idx_val, $script_2_ph1347_idx249_val);
    var $5063 = $5062 + ($5046 + $5043) | 0;
    HEAP32[$4985 >> 2] = $5063;
    var $5065 = HEAPU16[$5049 >> 1] & 65535;
    var $5066 = __ZN2js11UnwindScopeEP9JSContextii($cx, $5065, 1);
    if ($5066) {
      __label__ = 1034;
      break;
    } else {
      __label__ = 1017;
      break;
    }
   case 1034:
    var $5070 = HEAPU8[$tn_0 | 0] & 255;
    if (($5070 | 0) == 0) {
      __label__ = 1035;
      break;
    } else if (($5070 | 0) == 1) {
      __label__ = 1037;
      break;
    } else if (($5070 | 0) == 2) {
      __label__ = 1038;
      break;
    } else {
      __label__ = 1040;
      break;
    }
   case 1035:
    var $st$0$0 = $cx_idx201 | 0;
    var $cx_idx201_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $cx_idx201 + 4 | 0;
    var $cx_idx201_val$1 = HEAP32[$st$0$1 >> 2];
    __ZN9JSContext19getPendingExceptionEv($15, $cx_idx201_val$0, $cx_idx201_val$1);
    var $st$5$0 = $_idx356 | 0;
    var $_idx356_val$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $_idx356 + 4 | 0;
    var $_idx356_val$1 = HEAP32[$st$5$1 >> 2];
    var $5072 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx356_val$0, $_idx356_val$1);
    if ($5072) {
      __label__ = 1040;
      break;
    } else {
      var $script_0_ph = $script_2_ph1347;
      var $pcCounts_0_ph = $pcCounts_2_ph1346;
      var $argv_0_ph = $argv_2_ph1345;
      var $atoms_0_ph = $4992;
      var $len_0_ph1296 = 0;
      var $_pre_phi = $4985;
      var $_pre_phi580 = $4986;
      __label__ = 1036;
      break;
    }
   case 1036:
    var $_pre_phi580;
    var $_pre_phi;
    var $len_0_ph1296;
    var $atoms_0_ph;
    var $argv_0_ph;
    var $pcCounts_0_ph;
    var $script_0_ph;
    var $5073 = $rval35 | 0;
    var $5074 = $lval36 | 0;
    var $5075 = $rval39 | 0;
    var $5076 = $lval40 | 0;
    var $5077 = $cx;
    var $5078 = $rval187 | 0;
    var $5079 = $23 + 44 | 0;
    var $5080 = $cx;
    var $5081 = $rval215 | 0;
    var $5082 = $cx + 60 | 0;
    var $5083 = $cx;
    var $5084 = $cx;
    var $5085 = $rval96 | 0;
    var $5086 = $lval97 | 0;
    var $5087 = $rval102 | 0;
    var $5088 = $lval103 | 0;
    var $5089 = $rval104 | 0;
    var $5090 = $lval105 | 0;
    var $5091 = $rval109 | 0;
    var $5092 = $lval110 | 0;
    var $5093 = $obj127;
    var $5094 = $prop129;
    var $5095 = $rval134 | 0;
    var $5096 = $obj147;
    var $5097 = $obj2154;
    var $5098 = $prop157;
    var $5099 = $cx;
    var $5100 = $2 | 0;
    var $5101 = $rval168 | 0;
    var $5102 = $3 | 0;
    var $5103 = $4 | 0;
    var $5104 = $5 | 0;
    var $5105 = $6 | 0;
    var $5106 = $lval178 | 0;
    var $5107 = $objv | 0;
    var $5108 = $rval180 | 0;
    var $5109 = $pobj;
    var $5110 = $thisv206 | 0;
    var $5111 = $rval224 | 0;
    var $5112 = $v | 0;
    var $5113 = $rval229 | 0;
    var $5114 = $obj226;
    var $5115 = $obj2231;
    var $5116 = $prop235;
    var $5117 = $v236 | 0;
    var $5118 = $proto;
    var $5119 = $lval251 | 0;
    var $5120 = $rval254 | 0;
    var $5121 = $7 | 0;
    var $5122 = $rval258 | 0;
    var $5123 = $rval260 | 0;
    var $5124 = $23 + 210256 | 0;
    var $5125 = $rval262 | 0;
    var $5126 = $rval326 | 0;
    var $5127 = $rval349 | 0;
    var $5128 = $rval355 | 0;
    var $5129 = $11 | 0;
    var $5130 = $12 | 0;
    var $5131 = $rval375 | 0;
    var $5132 = $rval378 | 0;
    var $5133 = $obj386;
    var $5134 = $13 | 0;
    var $5135 = $rval389 | 0;
    var $5136 = $obj394;
    var $5137 = $rval396 | 0;
    var $5138 = $v397 | 0;
    var $5139 = $rval400 | 0;
    var $5140 = $rval421 | 0;
    var $_idx161 = $args225 | 0;
    var $cx_idx234 = $cx + 232 | 0;
    var $rval256_idx = $rval256 | 0;
    var $rf160_idx = $rf160 | 0;
    var $rf160_idx329 = $rf160 + 4 | 0;
    var $rf161_idx = $rf161 | 0;
    var $rf161_idx328 = $rf161 + 4 | 0;
    var $_idx359 = $1 | 0;
    var $_idx162 = $args | 0;
    var $cx_idx202 = $cx + 24 | 0;
    var $script_0 = $script_0_ph;
    var $pcCounts_0 = $pcCounts_0_ph;
    var $argv_0 = $argv_0_ph;
    var $atoms_0 = $atoms_0_ph;
    var $len_0 = $len_0_ph1296;
    __label__ = 17;
    break;
   case 1037:
    var $5142 = HEAP32[$4986 >> 2];
    var $5143 = $5142 + 8 | 0;
    HEAP32[$4986 >> 2] = $5143;
    __ZN2JS5Value10setBooleanEb($5142, 1);
    var $5144 = HEAP32[$4986 >> 2];
    var $5145 = $5144 + 8 | 0;
    HEAP32[$4986 >> 2] = $5145;
    var $st$7$0 = $cx_idx201 | 0;
    var $cx_idx200_val$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $cx_idx201 + 4 | 0;
    var $cx_idx200_val$1 = HEAP32[$st$7$1 >> 2];
    __ZN9JSContext19getPendingExceptionEv($16, $cx_idx200_val$0, $cx_idx200_val$1);
    var $5146 = $16 | 0;
    var $st$13$0 = $5146 | 0;
    var $5147$0 = HEAP32[$st$13$0 >> 2];
    var $st$13$1 = $5146 + 4 | 0;
    var $5147$1 = HEAP32[$st$13$1 >> 2];
    var $5148 = $5144 | 0;
    var $st$18$0 = $5148 | 0;
    HEAP32[$st$18$0 >> 2] = $5147$0;
    var $st$18$1 = $5148 + 4 | 0;
    HEAP32[$st$18$1 >> 2] = $5147$1;
    __ZN9JSContext21clearPendingExceptionEv($cx);
    var $script_0_ph = $script_2_ph1347;
    var $pcCounts_0_ph = $pcCounts_2_ph1346;
    var $argv_0_ph = $argv_2_ph1345;
    var $atoms_0_ph = $4992;
    var $len_0_ph1296 = 0;
    var $_pre_phi = $4985;
    var $_pre_phi580 = $4986;
    __label__ = 1036;
    break;
   case 1038:
    var $st$0$0 = $cx_idx201 | 0;
    var $cx_idx199_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $cx_idx201 + 4 | 0;
    var $cx_idx199_val$1 = HEAP32[$st$0$1 >> 2];
    __ZN9JSContext19getPendingExceptionEv($v435, $cx_idx199_val$0, $cx_idx199_val$1);
    __ZN9JSContext21clearPendingExceptionEv($cx);
    var $_idx118 = HEAP32[$4986 >> 2] - 8 | 0;
    var $st$8$0 = $_idx118 | 0;
    var $_idx118_val$0 = HEAP32[$st$8$0 >> 2];
    var $st$8$1 = $_idx118 + 4 | 0;
    var $_idx118_val$1 = HEAP32[$st$8$1 >> 2];
    var $5151 = __ZNK2JS5Value8toObjectEv($_idx118_val$0, $_idx118_val$1);
    var $5152 = $5151;
    var $5153 = __Z16js_CloseIteratorP9JSContextP8JSObject($4987, $5152);
    var $5155 = HEAP32[$4986 >> 2] - 8 | 0;
    HEAP32[$4986 >> 2] = $5155;
    if (($5153 | 0) == 0) {
      __label__ = 1017;
      break;
    } else {
      __label__ = 1039;
      break;
    }
   case 1039:
    var $st$0$0 = $4988 | 0;
    var $5158$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $4988 + 4 | 0;
    var $5158$1 = HEAP32[$st$0$1 >> 2];
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($cx, $5158$0, $5158$1);
    __label__ = 1040;
    break;
   case 1040:
    var $5160 = $tn_0 + 12 | 0;
    if (($5160 | 0) == ($5039 | 0)) {
      __label__ = 1041;
      break;
    } else {
      var $tn_0 = $5160;
      __label__ = 1031;
      break;
    }
   case 1041:
    var $cx_idx195_val = HEAP32[$cx_idx196 >> 2];
    var $5162 = __ZN9JSContext18isExceptionPendingEv($cx_idx195_val);
    if ($5162) {
      __label__ = 1042;
      break;
    } else {
      var $interpReturnOK_1 = 0;
      __label__ = 1044;
      break;
    }
   case 1042:
    var $st$0$0 = $cx_idx201 | 0;
    var $cx_idx198_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $cx_idx201 + 4 | 0;
    var $cx_idx198_val$1 = HEAP32[$st$0$1 >> 2];
    __ZN9JSContext19getPendingExceptionEv($17, $cx_idx198_val$0, $cx_idx198_val$1);
    var $_idx357 = $17 | 0;
    var $st$6$0 = $_idx357 | 0;
    var $_idx357_val$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $_idx357 + 4 | 0;
    var $_idx357_val$1 = HEAP32[$st$6$1 >> 2];
    var $5164 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx357_val$0, $_idx357_val$1);
    if ($5164) {
      __label__ = 1043;
      break;
    } else {
      var $interpReturnOK_1 = 0;
      __label__ = 1044;
      break;
    }
   case 1043:
    __ZN9JSContext21clearPendingExceptionEv($cx);
    var $regs_idx3_val = HEAP32[$regs_idx73 >> 2];
    var $5166 = __ZNK2js9FrameRegs2fpEv($regs_idx3_val);
    __ZN2js10StackFrame16clearReturnValueEv($5166);
    var $interpReturnOK_1 = 1;
    __label__ = 1044;
    break;
   case 1044:
    var $interpReturnOK_1;
    if (($interpReturnOK_1 | 0) == 0) {
      __label__ = 1045;
      break;
    } else {
      var $5171 = 1;
      __label__ = 1046;
      break;
    }
   case 1045:
    var $cx_idx_val = HEAP32[$cx + 20 >> 2];
    var $5169 = __ZN9JSContext18isExceptionPendingEv($cx_idx_val);
    var $5171 = $5169;
    __label__ = 1046;
    break;
   case 1046:
    var $5171;
    var $5173 = __ZN2js11UnwindScopeEP9JSContextii($cx, 0, $5171 & 1);
    var $5175 = $5173 & 1 & $interpReturnOK_1;
    var $regs_idx2_val = HEAPU32[$regs_idx73 >> 2];
    var $5176 = __ZNK2js9FrameRegs2fpEv($regs_idx2_val);
    if (($_08 | 0) == ($5176 | 0)) {
      var $interpReturnOK_2 = $5175;
      var $regs_idx1_val = $regs_idx2_val;
      __label__ = 1047;
      break;
    } else {
      var $interpReturnOK_0 = $5175;
      var $regs_idx62_val = $regs_idx2_val;
      __label__ = 49;
      break;
    }
   case 1047:
    var $regs_idx1_val;
    var $interpReturnOK_2;
    var $5179 = __ZNK2js9FrameRegs2fpEv($regs_idx1_val);
    var $5181 = __ZN2js30ScriptEpilogueOrGeneratorYieldEP9JSContextPNS_10StackFrameEb($cx, $5179, ($interpReturnOK_2 | 0) != 0);
    var $regs_idx_val = HEAP32[$regs_idx73 >> 2];
    var $5182 = __ZNK2js9FrameRegs2fpEv($regs_idx_val);
    __ZN2js10StackFrame24setFinishedInInterpreterEv($5182);
    var $interpreterFrame_idx_val = HEAP32[$interpreterFrame >> 2];
    var $interpreterFrame_idx441_val_idx_val = HEAP32[HEAP32[$interpreterFrame + 4 >> 2] + 52 >> 2];
    __ZN2js17InterpreterFramesD1Ev($interpreterFrame_idx_val, $interpreterFrame_idx441_val_idx_val);
    __ZN2js17PreserveRegsGuardD1Ev($interpGuard);
    var $rf_idx_val = HEAP32[$rf >> 2];
    var $rf_idx327_val = HEAP32[$rf + 4 >> 2];
    __ZN18JSAutoResolveFlagsD1Ev($rf_idx_val, $rf_idx327_val);
    STACKTOP = __stackBase__;
    return $5181;
   case 1048:
    var $atomNotDefined_0;
    __ZN16JSAutoByteStringC1Ev($printable);
    var $5184 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $atomNotDefined_0, $printable);
    var $printable_idx_val_pre = HEAP32[$printable >> 2];
    if (($5184 | 0) == 0) {
      __label__ = 1050;
      break;
    } else {
      __label__ = 1049;
      break;
    }
   case 1049:
    var $5187 = __ZNK16JSAutoByteString3ptrEv($printable_idx_val_pre);
    __Z21js_ReportIsNotDefinedP9JSContextPKc($cx, $5187);
    __label__ = 1050;
    break;
   case 1050:
    __ZN16JSAutoByteStringD1Ev($printable_idx_val_pre);
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js9InterpretEP9JSContextPNS_10StackFrameENS_10InterpModeE["X"] = 1;

function __ZN2jsL13ToReportFlagsENS_17InitialFrameFlagsE($initial) {
  return $initial & 128;
}

function __ZNK8JSScript7isEmptyEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$this + 8 >> 2] >>> 0 > 3) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$this >> 2];
    if ((HEAP8[$this + 36 | 0] & 1) << 24 >> 24 == 0) {
      var $pc_0 = $6;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (HEAP8[$6] << 24 >> 24 == 66) {
      __label__ = 4;
      break;
    } else {
      var $pc_0 = $6;
      __label__ = 5;
      break;
    }
   case 4:
    var $pc_0 = $6 + 1 | 0;
    __label__ = 5;
    break;
   case 5:
    var $pc_0;
    var $_0 = HEAP8[$pc_0] << 24 >> 24 == -59;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12InvokeKernelEP9JSContextRKNS_8CallArgsENS_14MaybeConstructE($cx, $argsRef, $construct) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $ifg = __stackBase__ + 8;
    var $preserve = __stackBase__ + 36;
    var $1 = $argsRef;
    var $2 = $args;
    var $3$0 = HEAP32[$1 >> 2];
    var $3$1 = HEAP32[$1 + 4 >> 2];
    HEAP32[$2 >> 2] = $3$0;
    HEAP32[$2 + 4 >> 2] = $3$1;
    var $_idx2 = $args | 0;
    var $inttoptr = $3$0;
    var $4 = __ZNK2js12CallReceiver7calleevEv($inttoptr);
    var $_idx4 = $4 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    var $5 = __ZNK2JS5Value11isPrimitiveEv($_idx4_val$0, $_idx4_val$1);
    var $7 = $3$1;
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = __ZN2jsL13ToReportFlagsENS_17InitialFrameFlagsE($construct);
    __Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj($cx, $4, $9);
    var $_1 = 0;
    __label__ = 15;
    break;
   case 3:
    var $11 = __ZNK2js12CallReceiver6calleeEv($inttoptr);
    var $_idx3_val = HEAP32[$11 + 4 >> 2];
    var $12 = __ZNK8JSObject8getClassEv($_idx3_val);
    if (($12 | 0) == (__ZN2js13FunctionClassE | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($12 | 0) == (_js_NoSuchMethodClass | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $17 = __ZNK2js8CallArgs4argcEv($7);
    var $18 = __ZNK2js12CallReceiver4baseEv($inttoptr);
    var $19 = __ZL12NoSuchMethodP9JSContextjPN2JS5ValueE($cx, $17, $18);
    var $_1 = ($19 | 0) != 0;
    __label__ = 15;
    break;
   case 6:
    var $23 = HEAP32[$12 + 48 >> 2];
    if (($23 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $26 = __ZN2jsL13ToReportFlagsENS_17InitialFrameFlagsE($construct);
    __Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj($cx, $4, $26);
    var $_1 = 0;
    __label__ = 15;
    break;
   case 8:
    var $28 = __ZN2js12CallJSNativeEP9JSContextPFiS1_jPN2JS5ValueEERKNS_8CallArgsE($cx, $23, $args);
    var $_1 = $28;
    __label__ = 15;
    break;
   case 9:
    var $_idx1_val = HEAP32[$11 + 24 >> 2];
    var $30 = __ZNK8JSObject18getFunctionPrivateEv($_idx1_val);
    var $31 = $30;
    var $32 = __ZNK10JSFunction8isNativeEv($31);
    if ($32) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $35 = HEAP32[$30 + 60 >> 2];
    var $36 = __ZN2js12CallJSNativeEP9JSContextPFiS1_jPN2JS5ValueEERKNS_8CallArgsE($cx, $35, $args);
    var $_1 = $36;
    __label__ = 15;
    break;
   case 11:
    var $38 = ($construct | 0) != 0;
    __ZN2js5types15TypeMonitorCallEP9JSContextRKNS_8CallArgsEb($cx, $args, $38);
    __ZN2js16InvokeFrameGuardC1Ev($ifg);
    var $40 = $cx + 60 | 0;
    var $41 = $cx;
    var $42 = $ifg;
    var $43 = __ZN2js12ContextStack15pushInvokeFrameEP9JSContextRKNS_8CallArgsENS_17InitialFrameFlagsEPNS_16InvokeFrameGuardE($40, $41, $args, $construct, $42);
    if ($43) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 12:
    var $45 = $ifg | 0;
    var $46 = __ZNK2js10FrameGuard2fpEv($45);
    var $47 = __ZN2js10StackFrame16functionPrologueEP9JSContext($46, $cx);
    if ($47) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 13:
    __ZN2js23AutoPreserveEnumeratorsC1EP9JSContext($preserve, $cx);
    var $49 = __ZNK10JSFunction6scriptEv($30);
    var $_idx8_val = HEAP8[$49 + 36 | 0];
    var $50 = __ZN2js9RunScriptEP9JSContextP8JSScriptPNS_10StackFrameE($cx, $_idx8_val, $46);
    var $preserve_idx_val = HEAP32[$preserve >> 2];
    var $preserve_idx7_val = HEAP32[$preserve + 4 >> 2];
    __ZN2js23AutoPreserveEnumeratorsD1Ev($preserve_idx_val, $preserve_idx7_val);
    var $_idx6_val = HEAP32[$_idx2 >> 2];
    var $51 = __ZNK2js12CallReceiver4rvalEv($_idx6_val);
    var $52 = $46;
    var $53 = __ZN2js10StackFrame11returnValueEv($52);
    var $54 = $53 | 0;
    var $55$0 = HEAP32[$54 >> 2];
    var $55$1 = HEAP32[$54 + 4 >> 2];
    var $56 = $51 | 0;
    var $st$20$0 = $56 | 0;
    HEAP32[$st$20$0 >> 2] = $55$0;
    var $st$20$1 = $56 + 4 | 0;
    HEAP32[$st$20$1 >> 2] = $55$1;
    var $_0 = $50;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    __ZN2js16InvokeFrameGuardD1Ev($ifg);
    var $_1 = $_0;
    __label__ = 15;
    break;
   case 15:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js12InvokeKernelEP9JSContextRKNS_8CallArgsENS_14MaybeConstructE["X"] = 1;

function __ZL12NoSuchMethodP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js15InvokeArgsGuardC1Ev($args);
    var $2 = $cx + 60 | 0;
    var $3 = $cx;
    var $4 = $args;
    var $5 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($2, $3, 2, $4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $7 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
    var $_idx = $args | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $8 = __ZNK2js12CallReceiver7calleevEv($_idx_val);
    var $9 = __ZNK8JSObject7getSlotEj($7, 0);
    var $10 = $9 | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = $8 | 0;
    var $st$16$0 = $12 | 0;
    HEAP32[$st$16$0 >> 2] = $11$0;
    var $st$16$1 = $12 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $11$1;
    var $_idx1_val = HEAP32[$_idx >> 2];
    var $13 = __ZNK2js12CallReceiver5thisvEv($_idx1_val);
    var $14 = $vp + 8 | 0;
    var $15$0 = HEAP32[$14 >> 2];
    var $15$1 = HEAP32[$14 + 4 >> 2];
    var $16 = $13 | 0;
    var $st$28$0 = $16 | 0;
    HEAP32[$st$28$0 >> 2] = $15$0;
    var $st$28$1 = $16 + 4 | 0;
    HEAP32[$st$28$1 >> 2] = $15$1;
    var $_idx3_val = HEAP32[$_idx >> 2];
    var $17 = __ZNK2js8CallArgsixEj($_idx3_val, 0);
    var $18 = __ZNK8JSObject7getSlotEj($7, 1);
    var $19 = $18 | 0;
    var $20$0 = HEAP32[$19 >> 2];
    var $20$1 = HEAP32[$19 + 4 >> 2];
    var $21 = $17 | 0;
    var $st$41$0 = $21 | 0;
    HEAP32[$st$41$0 >> 2] = $20$0;
    var $st$41$1 = $21 + 4 | 0;
    HEAP32[$st$41$1 >> 2] = $20$1;
    var $22 = $vp + 16 | 0;
    var $23 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($cx, $argc, $22);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx2_val = HEAP32[$_idx >> 2];
    var $26 = __ZNK2js8CallArgsixEj($_idx2_val, 1);
    __ZN2JS5Value9setObjectER8JSObject($26, $23);
    var $27 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($cx, $args, 0);
    var $28 = $27 & 1;
    var $_idx4_val = HEAP32[$_idx >> 2];
    var $29 = __ZNK2js12CallReceiver4rvalEv($_idx4_val);
    var $30 = $29 | 0;
    var $31$0 = HEAP32[$30 >> 2];
    var $31$1 = HEAP32[$30 + 4 >> 2];
    HEAP32[$vp_idx >> 2] = $31$0;
    HEAP32[$vp_idx + 4 >> 2] = $31$1;
    var $_0 = $28;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js15InvokeArgsGuardD1Ev($args);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12NoSuchMethodP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2js12CallJSNativeEP9JSContextPFiS1_jPN2JS5ValueEERKNS_8CallArgsE($cx, $native, $args) {
  var $args_idx_val = HEAP32[$args + 4 >> 2];
  var $1 = __ZNK2js8CallArgs4argcEv($args_idx_val);
  var $_idx_val = HEAP32[$args >> 2];
  var $2 = __ZNK2js12CallReceiver4baseEv($_idx_val);
  var $3 = FUNCTION_TABLE[$native]($cx, $1, $2);
  return ($3 | 0) != 0;
}

function __ZN2js5types15TypeMonitorCallEP9JSContextRKNS_8CallArgsEb($cx, $args, $constructing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx4_val = HEAP32[$args >> 2];
    var $1 = __ZNK2js12CallReceiver6calleeEv($_idx4_val);
    var $_idx_val = HEAP32[$1 + 4 >> 2];
    var $2 = __ZNK8JSObject10isFunctionEv($_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $_idx1 = $1 + 24 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $4 = __ZNK8JSObject18getFunctionPrivateEv($_idx1_val);
    var $_idx2_val = HEAP16[$4 + 58 >> 1];
    var $5 = __ZNK10JSFunction13isInterpretedEv($_idx2_val);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $7 = __ZNK10JSFunction6scriptEv($4);
    var $_idx3_val = HEAP32[$1 + 20 >> 2];
    var $8 = __ZNK8JSObject9getParentEv($_idx3_val);
    var $9 = __ZN8JSScript17ensureRanAnalysisEP9JSContextP10JSFunctionP8JSObject($7, $cx, $4, $8);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $11 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $_idx5_val = HEAP32[$_idx1 >> 2];
    __ZN2js5types19TypeMonitorCallSlowEP9JSContextP8JSObjectRKNS_8CallArgsEb($cx, $_idx5_val, $args, $constructing);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16InvokeFrameGuardC1Ev($this) {
  __ZN2js16InvokeFrameGuardC2Ev($this);
  return;
}

function __ZNK2js10FrameGuard2fpEv($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  var $1 = __ZNK2js9FrameRegs2fpEv($_idx_val);
  return $1;
}

function __ZN2js10StackFrame16functionPrologueEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame3funEv($this);
    var $_idx1_val = HEAP16[$1 + 58 >> 1];
    var $2 = __ZNK10JSFunction13isHeavyweightEv($_idx1_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js19CreateFunCallObjectEP9JSContextPNS_10StackFrameE($cx, $this);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZNK2js10StackFrame10scopeChainEv($this);
    __label__ = 4;
    break;
   case 4:
    var $9 = __ZNK2js10StackFrame6scriptEv($this);
    var $_idx_val_idx_val = HEAP32[HEAP32[$9 + 100 >> 2] + 12 >> 2];
    var $12 = __ZNK8JSScript7nestingEv($_idx_val_idx_val);
    if (($12 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js5types15NestingPrologueEP9JSContextPNS_10StackFrameE($cx, $this);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js23AutoPreserveEnumeratorsC1EP9JSContext($this, $cx) {
  __ZN2js23AutoPreserveEnumeratorsC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js23AutoPreserveEnumeratorsD1Ev($this_0_0_val, $this_0_1_val) {
  __ZN2js23AutoPreserveEnumeratorsD2Ev($this_0_0_val, $this_0_1_val);
  return;
}

function __ZN2js16InvokeFrameGuardD1Ev($this) {
  __ZN2js16InvokeFrameGuardD2Ev($this);
  return;
}

function __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $thisv, $fval, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js15InvokeArgsGuardC1Ev($args);
    var $2 = $cx + 60 | 0;
    var $3 = $cx;
    var $4 = $args;
    var $5 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($2, $3, $argc, $4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $_idx3 = $args | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $7 = __ZNK2js12CallReceiver7calleevEv($_idx3_val);
    var $8 = $fval | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $7 | 0;
    var $st$9$0 = $10 | 0;
    HEAP32[$st$9$0 >> 2] = $9$0;
    var $st$9$1 = $10 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $9$1;
    var $_idx6_val = HEAP32[$_idx3 >> 2];
    var $11 = __ZNK2js12CallReceiver5thisvEv($_idx6_val);
    var $12 = $thisv | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    var $14 = $11 | 0;
    var $st$21$0 = $14 | 0;
    HEAP32[$st$21$0 >> 2] = $13$0;
    var $st$21$1 = $14 + 4 | 0;
    HEAP32[$st$21$1 >> 2] = $13$1;
    var $_idx_val = HEAP32[$_idx3 >> 2];
    var $15 = __ZNK2js8CallArgs4argvEv($_idx_val);
    var $16 = $15;
    var $17 = $argv;
    var $18 = $argc << 3;
    _memcpy($16, $17, $18, 1);
    var $_idx5_val = HEAP32[$_idx3 >> 2];
    var $19 = __ZNK2js12CallReceiver5thisvEv($_idx5_val);
    var $_idx1 = $19 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $20 = __ZNK2JS5Value8isObjectEv($_idx1_val$0, $_idx1_val$1);
    if ($20) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $22 = __ZNK2JS5Value8toObjectEv($_idx1_val$0, $_idx1_val$1);
    var $23 = __ZN8JSObject10thisObjectEP9JSContext($22, $cx);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx4_val = HEAP32[$_idx3 >> 2];
    var $26 = __ZNK2js12CallReceiver5thisvEv($_idx4_val);
    __ZN2JS5Value9setObjectER8JSObject($26, $23);
    __label__ = 5;
    break;
   case 5:
    var $28 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($cx, $args, 0);
    if ($28) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $_idx7_val = HEAP32[$_idx3 >> 2];
    var $30 = __ZNK2js12CallReceiver4rvalEv($_idx7_val);
    var $31 = $30 | 0;
    var $32$0 = HEAP32[$31 >> 2];
    var $32$1 = HEAP32[$31 + 4 >> 2];
    var $33 = $rval | 0;
    HEAP32[$33 >> 2] = $32$0;
    HEAP32[$33 + 4 >> 2] = $32$1;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    __ZN2js15InvokeArgsGuardD1Ev($args);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_["X"] = 1;

function __ZN2js17InvokeConstructorEP9JSContextRKN2JS5ValueEjPS3_S6_($cx, $fval, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js15InvokeArgsGuardC1Ev($args);
    var $2 = $cx + 60 | 0;
    var $3 = $cx;
    var $4 = $args;
    var $5 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($2, $3, $argc, $4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $_idx1 = $args | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $7 = __ZNK2js12CallReceiver7calleevEv($_idx1_val);
    var $8 = $fval | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $7 | 0;
    var $st$9$0 = $10 | 0;
    HEAP32[$st$9$0 >> 2] = $9$0;
    var $st$9$1 = $10 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $9$1;
    var $_idx2_val = HEAP32[$_idx1 >> 2];
    var $11 = __ZNK2js12CallReceiver5thisvEv($_idx2_val);
    __ZN2JS5Value8setMagicE10JSWhyMagic($11, 6);
    var $_idx_val = HEAP32[$_idx1 >> 2];
    var $12 = __ZNK2js8CallArgs4argvEv($_idx_val);
    var $13 = $12;
    var $14 = $argv;
    var $15 = $argc << 3;
    _memcpy($13, $14, $15, 1);
    var $16 = __ZN2js17InvokeConstructorEP9JSContextRNS_15InvokeArgsGuardE($cx, $args);
    if ($16) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_idx3_val = HEAP32[$_idx1 >> 2];
    var $18 = __ZNK2js12CallReceiver4rvalEv($_idx3_val);
    var $19 = $18 | 0;
    var $20$0 = HEAP32[$19 >> 2];
    var $20$1 = HEAP32[$19 + 4 >> 2];
    var $21 = $rval | 0;
    HEAP32[$21 >> 2] = $20$0;
    HEAP32[$21 + 4 >> 2] = $20$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js15InvokeArgsGuardD1Ev($args);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js20InvokeGetterOrSetterEP9JSContextP8JSObjectRKN2JS5ValueEjPS5_S8_($cx, $obj, $fval, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL11ObjectValueER8JSObject1804($1, $obj);
    var $8 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $1, $fval, $argc, $argv, $rval);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11ObjectValueER8JSObject1804($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN2js13ExecuteKernelEP9JSContextP8JSScriptR8JSObjectRKN2JS5ValueENS_11ExecuteTypeEPNS_10StackFrameEPS7_($cx, $script, $scopeChain, $thisv, $type, $evalInFrame, $result) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $efg = __stackBase__;
    var $preserve = __stackBase__ + 28;
    var $1 = __ZNK8JSScript7isEmptyEv($script);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    if (($result | 0) == 0) {
      var $_1 = 1;
      __label__ = 16;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value12setUndefinedEv($result);
    var $_1 = 1;
    __label__ = 16;
    break;
   case 4:
    __ZN2js17ExecuteFrameGuardC1Ev($efg);
    var $7 = $cx + 60 | 0;
    var $8 = $cx;
    var $9 = $script;
    var $10 = $scopeChain;
    var $11 = $evalInFrame;
    var $12 = $efg;
    var $13 = __ZN2js12ContextStack16pushExecuteFrameEP9JSContextP8JSScriptRKN2JS5ValueER8JSObjectNS_11ExecuteTypeEPNS_10StackFrameEPNS_17ExecuteFrameGuardE($7, $8, $9, $thisv, $10, $type, $11, $12);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 5:
    var $15 = $efg | 0;
    var $16 = __ZNK2js10FrameGuard2fpEv($15);
    var $17 = __ZNK2js10StackFrame17isStrictEvalFrameEv($16);
    if ($17) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $19 = __ZN2js20CreateEvalCallObjectEP9JSContextPNS_10StackFrameE($cx, $16);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = $script + 36 | 0;
    if ((HEAP8[$22] & 4) << 24 >> 24 == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = __ZL14InitSharpSlotsP9JSContextPN2js10StackFrameE($cx, $16);
    if ($27) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 9:
    var $29 = __ZN8JSScript17ensureRanAnalysisEP9JSContextP10JSFunctionP8JSObject($script, $cx, 0, $scopeChain);
    if ($29) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 10:
    var $31 = __ZNK2js10StackFrame9thisValueEv($16);
    __ZN2js5types10TypeScript7SetThisEP9JSContextP8JSScriptRKN2JS5ValueE($cx, $script, $31);
    __ZN2js23AutoPreserveEnumeratorsC1EP9JSContext($preserve, $cx);
    var $script_idx_val = HEAP8[$22];
    var $32 = __ZN2js9RunScriptEP9JSContextP8JSScriptPNS_10StackFrameE($cx, $script_idx_val, $16);
    if (($result | 0) == 0 | $32 ^ 1) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $35 = $16;
    var $36 = __ZN2js10StackFrame11returnValueEv($35);
    var $37 = $36 | 0;
    var $38$0 = HEAP32[$37 >> 2];
    var $38$1 = HEAP32[$37 + 4 >> 2];
    var $39 = $result | 0;
    HEAP32[$39 >> 2] = $38$0;
    HEAP32[$39 + 4 >> 2] = $38$1;
    __label__ = 12;
    break;
   case 12:
    var $41 = __ZNK2js10StackFrame17isStrictEvalFrameEv($16);
    if ($41) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    __Z16js_PutCallObjectPN2js10StackFrameE($16);
    __label__ = 14;
    break;
   case 14:
    var $preserve_idx_val = HEAP32[$preserve >> 2];
    var $preserve_idx1_val = HEAP32[$preserve + 4 >> 2];
    __ZN2js23AutoPreserveEnumeratorsD1Ev($preserve_idx_val, $preserve_idx1_val);
    var $_0 = $32;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    __ZN2js17ExecuteFrameGuardD1Ev($efg);
    var $_1 = $_0;
    __label__ = 16;
    break;
   case 16:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ExecuteKernelEP9JSContextP8JSScriptR8JSObjectRKN2JS5ValueENS_11ExecuteTypeEPNS_10StackFrameEPS7_["X"] = 1;

function __ZN2js17ExecuteFrameGuardC1Ev($this) {
  __ZN2js17ExecuteFrameGuardC2Ev($this);
  return;
}

function __ZNK2js10StackFrame17isStrictEvalFrameEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK2js10StackFrame11isEvalFrameEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $9 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2js10StackFrame6scriptEv($this);
    var $9 = (HEAP8[$3 + 36 | 0] & 8) << 24 >> 24 != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14InitSharpSlotsP9JSContextPN2js10StackFrameE($cx, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fp_idx_val = HEAP32[$fp + 16 >> 2];
    var $1 = __ZNK2js10StackFrame4prevEv($fp_idx_val);
    var $2 = __ZNK2js10StackFrame6scriptEv($fp);
    var $5 = HEAPU16[$2 + 14 >> 1] & 65535;
    var $6 = $5 - 2 | 0;
    var $7 = $fp;
    var $8 = __ZNK2js10StackFrame5slotsEv($7);
    var $9 = $8 + ($6 << 3) | 0;
    var $fp_idx1_val = HEAP32[$fp >> 2];
    var $10 = __ZNK2js10StackFrame13isGlobalFrameEv($fp_idx1_val);
    if ($10) {
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = __ZNK2js10StackFrame6scriptEv($1);
    if ((HEAP8[$12 + 36 | 0] & 4) << 24 >> 24 == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$1 >> 2];
    var $18 = __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($_idx_val);
    if ($18) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $20 = __ZNK2js10StackFrame3funEv($1);
    var $21 = __ZNK10JSFunction6scriptEv($20);
    var $23 = $21 + 64 | 0;
    var $24 = $cx;
    var $25 = __ZN2js8Bindings13sharpSlotBaseEP9JSContext($23, $24);
    var $30 = $25;
    __label__ = 6;
    break;
   case 5:
    var $27 = __ZNK2js10StackFrame8numFixedEv($1);
    var $30 = $27 - 2 | 0;
    __label__ = 6;
    break;
   case 6:
    var $30;
    if (($30 | 0) < 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $33 = $1;
    var $34 = __ZNK2js10StackFrame5slotsEv($33);
    var $35 = $34 + ($30 << 3) | 0;
    var $36$0 = HEAP32[$35 >> 2];
    var $36$1 = HEAP32[$35 + 4 >> 2];
    var $37 = $9 | 0;
    HEAP32[$37 >> 2] = $36$0;
    HEAP32[$37 + 4 >> 2] = $36$1;
    var $39 = $34 + ($30 + 1 << 3) | 0;
    var $40$0 = HEAP32[$39 >> 2];
    var $40$1 = HEAP32[$39 + 4 >> 2];
    var $41 = $8 + ($5 - 1 << 3) | 0;
    HEAP32[$41 >> 2] = $40$0;
    HEAP32[$41 + 4 >> 2] = $40$1;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 8:
    __ZN2JS5Value12setUndefinedEv($9);
    var $43 = $8 + ($5 - 1 << 3) | 0;
    __ZN2JS5Value12setUndefinedEv($43);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14InitSharpSlotsP9JSContextPN2js10StackFrameE["X"] = 1;

function __ZN2js17ExecuteFrameGuardD1Ev($this) {
  __ZN2js17ExecuteFrameGuardD2Ev($this);
  return;
}

function __ZN2js7ExecuteEP9JSContextP8JSScriptR8JSObjectPN2JS5ValueE($cx, $script, $scopeChainArg, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $scopeChain = __stackBase__;
    var $thisv = __stackBase__ + 4;
    HEAP32[$scopeChain >> 2] = $scopeChainArg;
    __Z19OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($cx, $scopeChain);
    var $1 = HEAP32[$scopeChain >> 2];
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$1 >> 2];
    var $4 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 4, 266, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 8;
    break;
   case 4:
    var $cx_idx_val = HEAP32[$cx + 32 >> 2];
    var $7 = __ZNK9JSContext12hasRunOptionEj($cx_idx_val, 4);
    if ($7) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN8JSObject10makeVarObjEv($1);
    __label__ = 6;
    break;
   case 6:
    var $10 = __ZN8JSObject10thisObjectEP9JSContext($1, $cx);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JSL11ObjectValueER8JSObject1804($thisv, $10);
    var $13 = __ZN2js13ExecuteKernelEP9JSContextP8JSScriptR8JSObjectRKN2JS5ValueENS_11ExecuteTypeEPNS_10StackFrameEPS7_($cx, $script, $1, $thisv, 1, 0, $rval);
    var $_0 = $13;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18CheckRedeclarationEP9JSContextP8JSObjectij($cx, $obj, $id, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj2 = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $oldAttrs = __stackBase__ + 8;
    var $value = __stackBase__ + 12;
    var $bytes = __stackBase__ + 20;
    var $1 = __stackBase__ + 24;
    var $2 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($obj, $cx, $id, $obj2, $prop);
    if (($2 | 0) == 0) {
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$prop >> 2];
    if (($5 | 0) == 0) {
      var $_1 = 1;
      __label__ = 20;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = HEAPU32[$obj2 >> 2];
    var $_idx_val = HEAP32[$8 >> 2];
    var $9 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx1_val = HEAP8[$5 + 28 | 0];
    var $12 = __ZNK2js5Shape10attributesEv($_idx1_val);
    var $13 = $12 & 255;
    HEAP32[$oldAttrs >> 2] = $13;
    var $18 = $13;
    __label__ = 7;
    break;
   case 5:
    var $15 = __ZN8JSObject13getAttributesEP9JSContextiPj($8, $cx, $id, $oldAttrs);
    if (($15 | 0) == 0) {
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = HEAP32[$oldAttrs >> 2];
    __label__ = 7;
    break;
   case 7:
    var $18;
    if ((($18 | $attrs) & 2 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    if (($attrs & 48 | 0) == 0) {
      var $_1 = 1;
      __label__ = 20;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ((($18 ^ $attrs) & 48 | 0) == 48 | ($18 & 4 | 0) == 0) {
      var $_1 = 1;
      __label__ = 20;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $33 = ($18 & 48 | 0) != 0;
    if ($33) {
      var $isFunction_0 = $33 & 1;
      var $42 = $18;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $36 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($obj, $cx, $id, $value);
    if (($36 | 0) == 0) {
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $value_idx = $value | 0;
    var $value_idx_val$0 = HEAP32[$value_idx >> 2];
    var $value_idx_val$1 = HEAP32[$value_idx + 4 >> 2];
    var $39 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueE1809($value_idx_val$0, $value_idx_val$1);
    var $isFunction_0 = $39 & 1;
    var $42 = HEAP32[$oldAttrs >> 2];
    __label__ = 13;
    break;
   case 13:
    var $42;
    var $isFunction_0;
    var $43 = $42 & $attrs;
    if (($43 & 16 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      var $55 = STRING_TABLE.__str12882;
      __label__ = 17;
      break;
    }
   case 14:
    if (($43 & 32 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      var $55 = STRING_TABLE.__str42885;
      __label__ = 17;
      break;
    }
   case 15:
    if (($42 & 2 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      var $55 = STRING_TABLE.__str2233375;
      __label__ = 17;
      break;
    }
   case 16:
    var $_ = $isFunction_0 << 24 >> 24 != 0 ? STRING_TABLE.__str252545 : STRING_TABLE.__str2253377;
    var $55 = $_;
    __label__ = 17;
    break;
   case 17:
    var $55;
    __ZN16JSAutoByteStringC1Ev($bytes);
    __ZN2jsL9IdToValueEi1799($1, $id);
    var $56 = $cx;
    var $57 = $bytes;
    var $_idx2 = $1 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    var $58 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($56, $_idx2_val$0, $_idx2_val$1, $57);
    if (($58 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $62 = _JS_ReportErrorFlagsAndNumber($cx, 0, 155, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $55 | 0, HEAP32[tempInt + 4 >> 2] = $58, tempInt));
    __label__ = 19;
    break;
   case 19:
    var $bytes_idx_val = HEAP32[$bytes >> 2];
    __ZN16JSAutoByteStringD1Ev($bytes_idx_val);
    var $_1 = 0;
    __label__ = 20;
    break;
   case 20:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js18CheckRedeclarationEP9JSContextP8JSObjectij["X"] = 1;

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueE1809($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZNK8JSObject10isFunctionEv($_idx_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11HasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPi($cx, $obj, $v, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $2 = __ZNK8JSObject8getClassEv($obj_idx_val);
    var $4 = HEAP32[$2 + 60 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = FUNCTION_TABLE[$4]($cx, $obj, $v, $bp);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL11ObjectValueER8JSObject1804($1, $obj);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $9 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, 31, 1, $_idx_val$0, $_idx_val$1, 0, 0);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZeqRK8JSObjectS1_1816($lhs, $rhs) {
  return ($lhs | 0) == ($rhs | 0);
}

function __ZNK10JSFunction13isConstructorEv($this_0_2_val) {
  return ($this_0_2_val & 512) << 16 >> 16 != 0;
}

function _INT_FITS_IN_JSID1825($i) {
  return ($i + 1073741824 | 0) >>> 31 ^ 1;
}

function _INT_TO_JSID1826($i) {
  return $i << 1 | 1;
}

function __ZNK8JSObject7isXMLIdEv($this_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_1_val | 0) == (__ZN2js10QNameClassE | 0) | ($this_0_1_val | 0) == (__ZN2js18AttributeNameClassE | 0)) {
      var $6 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = ($this_0_1_val | 0) == (__ZN2js12AnyNameClassE | 0);
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _OBJECT_TO_JSID1827($obj) {
  return $obj | 4;
}

function __ZNK8JSObject6isWithEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js9WithClassE | 0);
}

function __ZNK8JSObject7isBlockEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js10BlockClassE | 0);
}

function __ZN8JSScript15stepModeEnabledEv($this_0_12_val) {
  return ($this_0_12_val | 0) != 0;
}

function __ZN12JSPCCounters3getEi($this_0_1_val) {
  var $2 = ($this_0_1_val | 0) == 0 ? 0 : $this_0_1_val;
  return $2;
}

function __ZNK2JS5Value18payloadAsRawUint32Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this + 4 >> 2];
  HEAP32[$4 >> 2] = $2;
  return;
}

function __ZN2js12LooselyEqualEP9JSContextRKN2JS5ValueES5_Pi($cx, $lval, $rval, $result) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lvalue = __stackBase__;
    var $rvalue = __stackBase__ + 8;
    var $l7 = __stackBase__ + 16;
    var $r8 = __stackBase__ + 24;
    var $lval_idx1 = $lval | 0;
    var $lval_idx1_val$0 = HEAPU32[$lval_idx1 >> 2];
    var $lval_idx1_val$1 = HEAPU32[$lval_idx1 + 4 >> 2];
    var $1 = __ZNK2JS5Value8isObjectEv($lval_idx1_val$0, $lval_idx1_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($lval_idx1_val$0, $lval_idx1_val$1);
    var $_idx13_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZNK8JSObject5isXMLEv($_idx13_val);
    if ($4) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $rval_idx = $rval | 0;
    var $st$1$0 = $rval_idx | 0;
    var $rval_idx_val$0 = HEAPU32[$st$1$0 >> 2];
    var $st$1$1 = $rval_idx + 4 | 0;
    var $rval_idx_val$1 = HEAPU32[$st$1$1 >> 2];
    var $6 = __ZNK2JS5Value8isObjectEv($rval_idx_val$0, $rval_idx_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toObjectEv($rval_idx_val$0, $rval_idx_val$1);
    var $_idx12_val = HEAP32[$8 + 4 >> 2];
    var $9 = __ZNK8JSObject5isXMLEv($_idx12_val);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = $cx;
    var $12 = __Z18js_TestXMLEqualityP9JSContextRKN2JS5ValueES4_Pi($11, $lval_idx1_val$0, $lval_idx1_val$1, $rval, $result);
    var $_0 = ($12 | 0) != 0;
    __label__ = 28;
    break;
   case 6:
    var $15 = __ZN2JS8SameTypeERKNS_5ValueES2_($lval_idx1_val$0, $lval_idx1_val$1, $rval_idx_val$0, $rval_idx_val$1);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 7:
    var $17 = __ZNK2JS5Value8isStringEv($lval_idx1_val$0, $lval_idx1_val$1);
    if ($17) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $19 = __ZNK2JS5Value8toStringEv($lval_idx1_val$0, $lval_idx1_val$1);
    var $20 = __ZNK2JS5Value8toStringEv($rval_idx_val$0, $rval_idx_val$1);
    var $21 = $cx;
    var $22 = __ZN2js12EqualStringsEP9JSContextP8JSStringS3_Pi($21, $19, $20, $result);
    var $_0 = $22;
    __label__ = 28;
    break;
   case 9:
    var $24 = __ZNK2JS5Value8isDoubleEv($lval_idx1_val$0, $lval_idx1_val$1);
    if ($24) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $26 = __ZNK2JS5Value8toDoubleEv($lval);
    var $27 = __ZNK2JS5Value8toDoubleEv($rval);
    HEAP32[$result >> 2] = $26 == $27 & 1;
    var $_0 = 1;
    __label__ = 28;
    break;
   case 11:
    if ($1) {
      __label__ = 12;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 12:
    var $32 = __ZNK2JS5Value8toObjectEv($lval_idx1_val$0, $lval_idx1_val$1);
    var $_idx_val = HEAP32[$32 + 4 >> 2];
    var $33 = __ZNK8JSObject8getClassEv($_idx_val);
    var $35 = HEAP32[$33 + 68 >> 2];
    if (($35 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $38 = FUNCTION_TABLE[$35]($cx, $32, $rval, $result);
    var $_0 = ($38 | 0) != 0;
    __label__ = 28;
    break;
   case 14:
    var $41 = __ZNK2JS5Value8toObjectEv($rval_idx_val$0, $rval_idx_val$1);
    HEAP32[$result >> 2] = ($32 | 0) == ($41 | 0) & 1;
    var $_0 = 1;
    __label__ = 28;
    break;
   case 15:
    var $45 = __ZNK2JS5Value18payloadAsRawUint32Ev($lval);
    var $46 = __ZNK2JS5Value18payloadAsRawUint32Ev($rval);
    HEAP32[$result >> 2] = ($45 | 0) == ($46 | 0) & 1;
    var $_0 = 1;
    __label__ = 28;
    break;
   case 16:
    var $50 = __ZNK2JS5Value17isNullOrUndefinedEv($lval_idx1_val$0, $lval_idx1_val$1);
    var $51 = __ZNK2JS5Value17isNullOrUndefinedEv($rval_idx_val$0, $rval_idx_val$1);
    if ($50) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    HEAP32[$result >> 2] = $51 & 1;
    var $_0 = 1;
    __label__ = 28;
    break;
   case 18:
    if ($51) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    HEAP32[$result >> 2] = 0;
    var $_0 = 1;
    __label__ = 28;
    break;
   case 20:
    var $57 = $lvalue | 0;
    var $st$1$0 = $57 | 0;
    HEAP32[$st$1$0 >> 2] = $lval_idx1_val$0;
    var $st$1$1 = $57 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $lval_idx1_val$1;
    var $58 = $rvalue | 0;
    HEAP32[$58 >> 2] = $rval_idx_val$0;
    HEAP32[$58 + 4 >> 2] = $rval_idx_val$1;
    var $59 = __ZN2jsL11ToPrimitiveEP9JSContextPN2JS5ValueE($cx, $lvalue);
    if ($59) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 21:
    var $61 = __ZN2jsL11ToPrimitiveEP9JSContextPN2JS5ValueE($cx, $rvalue);
    if ($61) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 22:
    var $st$0$0 = $57 | 0;
    var $lvalue_idx10_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $57 + 4 | 0;
    var $lvalue_idx10_val$1 = HEAP32[$st$0$1 >> 2];
    var $63 = __ZNK2JS5Value8isStringEv($lvalue_idx10_val$0, $lvalue_idx10_val$1);
    if ($63) {
      __label__ = 23;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 23:
    var $st$0$0 = $58 | 0;
    var $rvalue_idx9_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $58 + 4 | 0;
    var $rvalue_idx9_val$1 = HEAP32[$st$0$1 >> 2];
    var $65 = __ZNK2JS5Value8isStringEv($rvalue_idx9_val$0, $rvalue_idx9_val$1);
    if ($65) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $67 = __ZNK2JS5Value8toStringEv($lvalue_idx10_val$0, $lvalue_idx10_val$1);
    var $68 = __ZNK2JS5Value8toStringEv($rvalue_idx9_val$0, $rvalue_idx9_val$1);
    var $69 = $cx;
    var $70 = __ZN2js12EqualStringsEP9JSContextP8JSStringS3_Pi($69, $67, $68, $result);
    var $_0 = $70;
    __label__ = 28;
    break;
   case 25:
    var $72 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $lvalue, $l7);
    if ($72) {
      __label__ = 26;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 26:
    var $74 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $rvalue, $r8);
    if ($74) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 27:
    var $76 = (tempDoubleI32[0] = HEAP32[$l7 >> 2], tempDoubleI32[1] = HEAP32[$l7 + 4 >> 2], tempDoubleF64[0]);
    var $77 = (tempDoubleI32[0] = HEAP32[$r8 >> 2], tempDoubleI32[1] = HEAP32[$r8 + 4 >> 2], tempDoubleF64[0]);
    var $79 = $76 == $77 & 1;
    HEAP32[$result >> 2] = $79;
    var $_0 = 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js12LooselyEqualEP9JSContextRKN2JS5ValueES5_Pi["X"] = 1;

function __ZN2JS8SameTypeERKNS_5ValueES2_($lhs_0_0_0_val$0, $lhs_0_0_0_val$1, $rhs_0_0_0_val$0, $rhs_0_0_0_val$1) {
  var $1 = _JSVAL_SAME_TYPE_IMPL($lhs_0_0_0_val$0, $lhs_0_0_0_val$1, $rhs_0_0_0_val$0, $rhs_0_0_0_val$1);
  return ($1 | 0) != 0;
}

function __ZN2jsL11ToPrimitiveEP9JSContextPN2JS5ValueE($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $vp_idx1 = $vp | 0;
    var $vp_idx1_val$0 = HEAP32[$vp_idx1 >> 2];
    var $vp_idx1_val$1 = HEAP32[$vp_idx1 + 4 >> 2];
    var $1 = __ZNK2JS5Value11isPrimitiveEv($vp_idx1_val$0, $vp_idx1_val$1);
    if ($1) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($vp_idx1_val$0, $vp_idx1_val$1);
    var $4 = $3;
    var $5 = $cx;
    var $6 = __ZN8JSObject12defaultValueEP9JSContext6JSTypePN2JS5ValueE($4, $5, 0, $vp);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13StrictlyEqualEP9JSContextRKN2JS5ValueES5_Pi($cx, $lref_0_0_0_val$0, $lref_0_0_0_val$1, $rref_0_0_0_val$0, $rref_0_0_0_val$1, $equal) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lval = __stackBase__;
    var $rval = __stackBase__ + 8;
    var $1 = $lval | 0;
    HEAP32[$1 >> 2] = $lref_0_0_0_val$0;
    HEAP32[$1 + 4 >> 2] = $lref_0_0_0_val$1;
    var $2 = $rval | 0;
    HEAP32[$2 >> 2] = $rref_0_0_0_val$0;
    HEAP32[$2 + 4 >> 2] = $rref_0_0_0_val$1;
    var $3 = __ZN2JS8SameTypeERKNS_5ValueES2_($lref_0_0_0_val$0, $lref_0_0_0_val$1, $rref_0_0_0_val$0, $rref_0_0_0_val$1);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 2:
    var $5 = __ZNK2JS5Value8isStringEv($lref_0_0_0_val$0, $lref_0_0_0_val$1);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZNK2JS5Value8toStringEv($lref_0_0_0_val$0, $lref_0_0_0_val$1);
    var $8 = __ZNK2JS5Value8toStringEv($rref_0_0_0_val$0, $rref_0_0_0_val$1);
    var $9 = $cx;
    var $10 = __ZN2js12EqualStringsEP9JSContextP8JSStringS3_Pi($9, $7, $8, $equal);
    var $_0 = $10;
    __label__ = 18;
    break;
   case 4:
    var $12 = __ZNK2JS5Value8isDoubleEv($lref_0_0_0_val$0, $lref_0_0_0_val$1);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $14 = __ZNK2JS5Value8toDoubleEv($lval);
    var $15 = __ZNK2JS5Value8toDoubleEv($rval);
    HEAP32[$equal >> 2] = $14 == $15 & 1;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 6:
    var $19 = __ZNK2JS5Value8isObjectEv($lref_0_0_0_val$0, $lref_0_0_0_val$1);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $21 = __ZNK2JS5Value8toObjectEv($lref_0_0_0_val$0, $lref_0_0_0_val$1);
    var $22 = __ZNK2JS5Value8toObjectEv($rref_0_0_0_val$0, $rref_0_0_0_val$1);
    var $23 = __ZeqRK8JSObjectS1_1816($21, $22);
    HEAP32[$equal >> 2] = $23 & 1;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 8:
    var $26 = __ZNK2JS5Value11isUndefinedEv($lref_0_0_0_val$0, $lref_0_0_0_val$1);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    HEAP32[$equal >> 2] = 1;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 10:
    var $29 = __ZNK2JS5Value18payloadAsRawUint32Ev($lval);
    var $30 = __ZNK2JS5Value18payloadAsRawUint32Ev($rval);
    HEAP32[$equal >> 2] = ($29 | 0) == ($30 | 0) & 1;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 11:
    var $34 = __ZNK2JS5Value8isDoubleEv($lref_0_0_0_val$0, $lref_0_0_0_val$1);
    if ($34) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $36 = __ZNK2JS5Value7isInt32Ev($rref_0_0_0_val$0, $rref_0_0_0_val$1);
    if ($36) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $38 = __ZNK2JS5Value8toDoubleEv($lval);
    var $39 = __ZNK2JS5Value7toInt32Ev($rref_0_0_0_val$0, $rref_0_0_0_val$1);
    HEAP32[$equal >> 2] = $38 == ($39 | 0) & 1;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 14:
    var $44 = __ZNK2JS5Value7isInt32Ev($lref_0_0_0_val$0, $lref_0_0_0_val$1);
    if ($44) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $46 = __ZNK2JS5Value8isDoubleEv($rref_0_0_0_val$0, $rref_0_0_0_val$1);
    if ($46) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $48 = __ZNK2JS5Value7toInt32Ev($lref_0_0_0_val$0, $lref_0_0_0_val$1);
    var $49 = $48 | 0;
    var $50 = __ZNK2JS5Value8toDoubleEv($rval);
    HEAP32[$equal >> 2] = $49 == $50 & 1;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 17:
    HEAP32[$equal >> 2] = 0;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13StrictlyEqualEP9JSContextRKN2JS5ValueES5_Pi["X"] = 1;

function __ZN2js9SameValueEP9JSContextRKN2JS5ValueES5_Pi($cx, $v1, $v2, $same) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL14IsNegativeZeroRKN2JS5ValueE($v1);
    var $2 = __ZL14IsNegativeZeroRKN2JS5ValueE($v2);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$same >> 2] = $2 & 1;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    if ($2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$same >> 2] = 0;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 5:
    var $8 = __ZL5IsNaNRKN2JS5ValueE($v1);
    if ($8) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $10 = __ZL5IsNaNRKN2JS5ValueE($v2);
    if ($10) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    HEAP32[$same >> 2] = 1;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 8:
    var $v1_idx = $v1 | 0;
    var $v1_idx_val$0 = HEAP32[$v1_idx >> 2];
    var $v1_idx_val$1 = HEAP32[$v1_idx + 4 >> 2];
    var $v2_idx = $v2 | 0;
    var $v2_idx_val$0 = HEAP32[$v2_idx >> 2];
    var $v2_idx_val$1 = HEAP32[$v2_idx + 4 >> 2];
    var $13 = __ZN2js13StrictlyEqualEP9JSContextRKN2JS5ValueES5_Pi($cx, $v1_idx_val$0, $v1_idx_val$1, $v2_idx_val$0, $v2_idx_val$1, $same);
    var $_0 = $13;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14IsNegativeZeroRKN2JS5ValueE($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $1 = __ZNK2JS5Value8isDoubleEv($v_idx_val$0, $v_idx_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toDoubleEv($v);
    var $4 = _JSDOUBLE_IS_NEGZERO1872($3);
    var $7 = ($4 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5IsNaNRKN2JS5ValueE($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $1 = __ZNK2JS5Value8isDoubleEv($v_idx_val$0, $v_idx_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toDoubleEv($v);
    var $4 = __ZL15JSDOUBLE_IS_NaNd1870($3);
    var $7 = ($4 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TypeOfValueEP9JSContextRKN2JS5ValueE($cx, $vref_0_0_0_val$0, $vref_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isNumberEv($vref_0_0_0_val$0, $vref_0_0_0_val$1);
    if ($1) {
      var $_0 = 4;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8isStringEv($vref_0_0_0_val$0, $vref_0_0_0_val$1);
    if ($3) {
      var $_0 = 3;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK2JS5Value6isNullEv($vref_0_0_0_val$0, $vref_0_0_0_val$1);
    if ($5) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZNK2JS5Value11isUndefinedEv($vref_0_0_0_val$0, $vref_0_0_0_val$1);
    if ($7) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZNK2JS5Value8isObjectEv($vref_0_0_0_val$0, $vref_0_0_0_val$1);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 5;
      __label__ = 7;
      break;
    }
   case 6:
    var $11 = __ZNK2JS5Value8toObjectEv($vref_0_0_0_val$0, $vref_0_0_0_val$1);
    var $12 = __ZN8JSObject6typeOfEP9JSContext($11, $cx);
    var $_0 = $12;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject6typeOfEP9JSContext($this, $cx) {
  var $this_idx_val = HEAP32[$this + 4 >> 2];
  var $1 = __ZNK8JSObject6getOpsEv($this_idx_val);
  var $3 = HEAP32[$1 + 116 >> 2];
  var $5 = ($3 | 0) != 0 ? $3 : 142;
  var $6 = FUNCTION_TABLE[$5]($cx, $this);
  return $6;
}

function __ZN2js23InvokeConstructorKernelEP9JSContextRKNS_8CallArgsE($cx, $argsRef) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $1 = $argsRef;
    var $2 = $args;
    var $3$0 = HEAP32[$1 >> 2];
    var $3$1 = HEAP32[$1 + 4 >> 2];
    HEAP32[$2 >> 2] = $3$0;
    HEAP32[$2 + 4 >> 2] = $3$1;
    var $inttoptr = $3$0;
    var $4 = __ZNK2js12CallReceiver7calleevEv($inttoptr);
    var $_idx = $4 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $5 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    var $7 = __ZNK2js12CallReceiver6calleeEv($inttoptr);
    var $_idx6_val = HEAP32[$7 + 4 >> 2];
    var $8 = __ZNK8JSObject8getClassEv($_idx6_val);
    if (($8 | 0) == (__ZN2js13FunctionClassE | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    var $_idx1_val = HEAP32[$7 + 24 >> 2];
    var $11 = __ZNK8JSObject18getFunctionPrivateEv($_idx1_val);
    var $_idx9_val = HEAP16[$11 + 58 >> 1];
    var $12 = __ZNK10JSFunction13isConstructorEv($_idx9_val);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = __ZNK2js12CallReceiver5thisvEv($inttoptr);
    __ZN2JS5Value31setMagicWithObjectOrNullPayloadEP8JSObject($14, 0);
    var $16 = HEAP32[$11 + 60 >> 2];
    var $17 = __ZN2js23CallJSNativeConstructorEP9JSContextPFiS1_jPN2JS5ValueEERKNS_8CallArgsE($cx, $16, $args);
    var $_0 = $17;
    __label__ = 10;
    break;
   case 5:
    var $19 = __ZNK10JSFunction24isInterpretedConstructorEv($_idx9_val);
    if ($19) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $21 = __ZN2js12InvokeKernelEP9JSContextRKNS_8CallArgsENS_14MaybeConstructE($cx, $args, 128);
    var $_0 = $21;
    __label__ = 10;
    break;
   case 7:
    var $23 = $8 + 52 | 0;
    if ((HEAP32[$23 >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = __ZNK2js12CallReceiver5thisvEv($inttoptr);
    __ZN2JS5Value31setMagicWithObjectOrNullPayloadEP8JSObject($27, 0);
    var $28 = HEAP32[$23 >> 2];
    var $29 = __ZN2js23CallJSNativeConstructorEP9JSContextPFiS1_jPN2JS5ValueEERKNS_8CallArgsE($cx, $28, $args);
    var $_0 = $29;
    __label__ = 10;
    break;
   case 9:
    __Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj($cx, $4, 128);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js23InvokeConstructorKernelEP9JSContextRKNS_8CallArgsE["X"] = 1;

function __ZN2JS5Value31setMagicWithObjectOrNullPayloadEP8JSObject($this, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _MAGIC_OBJ_TO_JSVAL_IMPL($1, $obj);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js23CallJSNativeConstructorEP9JSContextPFiS1_jPN2JS5ValueEERKNS_8CallArgsE($cx, $native, $args) {
  var $1 = __ZN2js12CallJSNativeEP9JSContextPFiS1_jPN2JS5ValueEERKNS_8CallArgsE($cx, $native, $args);
  return $1;
}

function __ZNK10JSFunction24isInterpretedConstructorEv($this_0_2_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK10JSFunction13isInterpretedEv($this_0_2_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK10JSFunction19isFunctionPrototypeEv($this_0_2_val);
    var $6 = $3 ^ 1;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js30InvokeConstructorWithGivenThisEP9JSContextP8JSObjectRKN2JS5ValueEjPS5_S8_($cx, $thisobj, $fval, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js15InvokeArgsGuardC1Ev($args);
    var $2 = $cx + 60 | 0;
    var $3 = $cx;
    var $4 = $args;
    var $5 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($2, $3, $argc, $4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    var $_idx2 = $args | 0;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $7 = __ZNK2js12CallReceiver7calleevEv($_idx2_val);
    var $8 = $fval | 0;
    var $st$4$0 = $8 | 0;
    var $9$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $8 + 4 | 0;
    var $9$1 = HEAP32[$st$4$1 >> 2];
    var $10 = $7 | 0;
    var $st$9$0 = $10 | 0;
    HEAP32[$st$9$0 >> 2] = $9$0;
    var $st$9$1 = $10 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $9$1;
    var $11 = $args | 0;
    var $_idx_val = HEAP32[$_idx2 >> 2];
    var $12 = __ZNK2js8CallArgs4argvEv($_idx_val);
    var $13 = $12;
    var $14 = $argv;
    var $15 = $argc << 3;
    _memcpy($13, $14, $15, 1);
    var $fval_idx_val$0 = HEAP32[$8 >> 2];
    var $fval_idx_val$1 = HEAP32[$8 + 4 >> 2];
    var $16 = __ZNK2JS5Value8toObjectEv($fval_idx_val$0, $fval_idx_val$1);
    var $_idx5_val = HEAP32[$16 + 4 >> 2];
    var $17 = __ZNK8JSObject8getClassEv($_idx5_val);
    if (($17 | 0) == (__ZN2js13FunctionClassE | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $_idx1_val = HEAP32[$16 + 24 >> 2];
    var $20 = __ZNK8JSObject18getFunctionPrivateEv($_idx1_val);
    var $_idx7_val = HEAP16[$20 + 58 >> 1];
    var $21 = __ZNK10JSFunction13isConstructorEv($_idx7_val);
    if ($21) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx4_val = HEAP32[$_idx2 >> 2];
    var $23 = __ZNK2js12CallReceiver5thisvEv($_idx4_val);
    __ZN2JS5Value31setMagicWithObjectOrNullPayloadEP8JSObject($23, $thisobj);
    var $25 = HEAP32[$20 + 60 >> 2];
    var $26 = __ZN2js23CallJSNativeConstructorEP9JSContextPFiS1_jPN2JS5ValueEERKNS_8CallArgsE($cx, $25, $11);
    var $ok_0 = $26 & 1;
    __label__ = 8;
    break;
   case 5:
    var $29 = $17 + 52 | 0;
    var $31 = (HEAP32[$29 >> 2] | 0) == 0;
    var $_idx3_val = HEAP32[$_idx2 >> 2];
    var $32 = __ZNK2js12CallReceiver5thisvEv($_idx3_val);
    if ($31) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2JS5Value31setMagicWithObjectOrNullPayloadEP8JSObject($32, $thisobj);
    var $34 = HEAP32[$29 >> 2];
    var $35 = __ZN2js23CallJSNativeConstructorEP9JSContextPFiS1_jPN2JS5ValueEERKNS_8CallArgsE($cx, $34, $11);
    var $ok_0 = $35 & 1;
    __label__ = 8;
    break;
   case 7:
    __ZN2JS5Value15setObjectOrNullEP8JSObject($32, $thisobj);
    var $38 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($cx, $args, 128);
    var $ok_0 = $38 & 1;
    __label__ = 8;
    break;
   case 8:
    var $ok_0;
    var $_idx6_val = HEAP32[$_idx2 >> 2];
    var $41 = __ZNK2js12CallReceiver4rvalEv($_idx6_val);
    var $42 = $41 | 0;
    var $st$4$0 = $42 | 0;
    var $43$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $42 + 4 | 0;
    var $43$1 = HEAP32[$st$4$1 >> 2];
    var $44 = $rval | 0;
    var $st$9$0 = $44 | 0;
    HEAP32[$st$9$0 >> 2] = $43$0;
    var $st$9$1 = $44 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $43$1;
    var $_0 = $ok_0 << 24 >> 24 != 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    __ZN2js15InvokeArgsGuardD1Ev($args);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js30InvokeConstructorWithGivenThisEP9JSContextP8JSObjectRKN2JS5ValueEjPS5_S8_["X"] = 1;

function __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($cx, $v, $idp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $1 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($v, $i);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = HEAP32[$i >> 2];
    var $4 = _INT_FITS_IN_JSID1825($3);
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = _INT_TO_JSID1826($3);
    HEAP32[$idp >> 2] = $7;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 4:
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $9 = __ZNK2JS5Value8isObjectEv($v_idx_val$0, $v_idx_val$1);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $11 = __ZNK2JS5Value8toObjectEv($v_idx_val$0, $v_idx_val$1);
    var $_idx_val = HEAP32[$11 + 4 >> 2];
    var $12 = __ZNK8JSObject7isXMLIdEv($_idx_val);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $14 = _OBJECT_TO_JSID1827($11);
    HEAP32[$idp >> 2] = $14;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 7:
    var $16 = __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($cx, $v_idx_val$0, $v_idx_val$1, $idp);
    var $_0 = $16;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($v, $pi) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx2 = $v | 0;
    var $v_idx2_val$0 = HEAP32[$v_idx2 >> 2];
    var $v_idx2_val$1 = HEAP32[$v_idx2 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx2_val$0, $v_idx2_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx2_val$0, $v_idx2_val$1);
    HEAP32[$pi >> 2] = $3;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $5 = __ZNK2JS5Value8isDoubleEv($v_idx2_val$0, $v_idx2_val$1);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZNK2JS5Value8toDoubleEv($v);
    var $8 = _JSDOUBLE_IS_INT321871($7, $pi);
    var $_0 = ($8 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js19IsActiveWithOrBlockEP9JSContextR8JSObjecti($cx, $obj, $stackDepth) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj_idx2_val = HEAP32[$obj + 4 >> 2];
    var $1 = __ZNK8JSObject6isWithEv($obj_idx2_val);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject7isBlockEv($obj_idx2_val);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $15 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $obj_idx_val = HEAP32[$obj + 24 >> 2];
    var $5 = __ZNK8JSObject10getPrivateEv($obj_idx_val);
    var $6 = __ZNK9JSContext2fpEv($cx);
    var $7 = __Z27js_FloatingFrameIfGeneratorP9JSContextPN2js10StackFrameE($cx, $6);
    if (($5 | 0) == ($7 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $15 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = __ZNK8JSObject12getFixedSlotEj($obj, 0);
    var $_idx = $11 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $12 = __ZNK2JS5Value7toInt32Ev($_idx_val$0, $_idx_val$1);
    var $15 = ($12 | 0) >= ($stackDepth | 0);
    __label__ = 5;
    break;
   case 5:
    var $15;
    return $15;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z27js_FloatingFrameIfGeneratorP9JSContextPN2js10StackFrameE($cx, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fp_idx_val = HEAP32[$fp >> 2];
    var $1 = __ZNK2js10StackFrame16isGeneratorFrameEv($fp_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $fp;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK9JSContext12generatorForEPN2js10StackFrameE($cx, $fp);
    var $_idx_val = HEAP32[$3 + 28 >> 2];
    var $5 = __ZN11JSGenerator13floatingFrameEv($_idx_val);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11UnwindScopeEP9JSContextii($cx, $stackDepth, $normalUnwind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK9JSContext2fpEv($cx);
    var $2 = $cx;
    var $_0_ph = $normalUnwind;
    __label__ = 2;
    break;
   case 2:
    var $_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $4 = __ZNK2js10StackFrame10scopeChainEv($1);
    var $5 = __ZN2js19IsActiveWithOrBlockEP9JSContextR8JSObjecti($cx, $4, $stackDepth);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$4 + 4 >> 2];
    var $7 = __ZNK8JSObject7isBlockEv($_idx_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $9 = __Z17js_PutBlockObjectP9JSContexti($2, $_0_ph);
    var $_0_ph = $9 & $_0_ph;
    __label__ = 2;
    break;
   case 6:
    __ZL9LeaveWithP9JSContext($cx);
    __label__ = 3;
    break;
   case 7:
    var $13 = $1;
    var $14 = __ZNK2js10StackFrame4baseEv($13);
    var $15 = $14 + ($stackDepth << 3) | 0;
    var $16 = __ZNK9JSContext4regsEv($cx);
    HEAP32[$16 >> 2] = $15;
    return ($_0_ph | 0) != 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9LeaveWithP9JSContext($cx) {
  var $1 = __ZNK9JSContext2fpEv($cx);
  var $2 = __ZNK2js10StackFrame10scopeChainEv($1);
  __ZN8JSObject10setPrivateEPv($2, 0);
  var $3 = __ZNK9JSContext2fpEv($cx);
  var $_idx_val = HEAP32[$2 + 20 >> 2];
  var $4 = __ZNK8JSObject9getParentEv($_idx_val);
  var $5 = $3;
  var $6 = $4;
  __ZN2js10StackFrame22setScopeChainNoCallObjER8JSObject($5, $6);
  return;
}

function __ZN2js8GetUpvarEP9JSContextjNS_11UpvarCookieE($cx, $closureLevel, $cookie_0) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js11UpvarCookie5levelEv($cookie_0);
    var $3 = $closureLevel - ($1 & 65535) | 0;
    var $4 = __ZN2js14FindUpvarFrameEP9JSContextj($cx, $3);
    var $5 = __ZNK2js11UpvarCookie4slotEv($cookie_0);
    var $6 = $5 & 65535;
    var $_idx_val = HEAPU32[$4 >> 2];
    var $7 = __ZNK2js10StackFrame15isFunctionFrameEv($_idx_val);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = __ZNK2js10StackFrame11isEvalFrameEv($_idx_val);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = $4;
    var $12 = __ZNK2js10StackFrame5slotsEv($11);
    var $13 = __ZNK2js10StackFrame8numFixedEv($4);
    var $vp_0 = $12 + ($13 << 3) | 0;
    var $slot_0 = $6;
    __label__ = 9;
    break;
   case 4:
    var $16 = __ZNK2js10StackFrame13numFormalArgsEv($4);
    if ($6 >>> 0 < $16 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $19 = __ZNK2js10StackFrame10formalArgsEv($4);
    var $vp_0 = $19;
    var $slot_0 = $6;
    __label__ = 9;
    break;
   case 6:
    if ($5 << 16 >> 16 == -1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $23 = __ZNK2js10StackFrame7calleevEv($4);
    var $vp_0 = $23;
    var $slot_0 = 0;
    __label__ = 9;
    break;
   case 8:
    var $25 = $6 - $16 | 0;
    var $26 = $4;
    var $27 = __ZNK2js10StackFrame5slotsEv($26);
    var $vp_0 = $27;
    var $slot_0 = $25;
    __label__ = 9;
    break;
   case 9:
    var $slot_0;
    var $vp_0;
    return $vp_0 + ($slot_0 << 3) | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14FindUpvarFrameEP9JSContextj($cx, $targetLevel) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK9JSContext2fpEv($cx);
    var $2 = __ZNK2js10StackFrame6scriptEv($1);
    if ((HEAPU16[$2 + 46 >> 1] & 65535 | 0) == ($targetLevel | 0)) {
      var $fp_0_lcssa = $1;
      __label__ = 3;
      break;
    } else {
      var $fp_01 = $1;
      __label__ = 2;
      break;
    }
   case 2:
    var $fp_01;
    var $fp_01_idx_val = HEAP32[$fp_01 + 16 >> 2];
    var $7 = __ZNK2js10StackFrame4prevEv($fp_01_idx_val);
    var $8 = __ZNK2js10StackFrame6scriptEv($7);
    if ((HEAPU16[$8 + 46 >> 1] & 65535 | 0) == ($targetLevel | 0)) {
      var $fp_0_lcssa = $7;
      __label__ = 3;
      break;
    } else {
      var $fp_01 = $7;
      __label__ = 2;
      break;
    }
   case 3:
    var $fp_0_lcssa;
    return $fp_0_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame8numFixedEv($this) {
  var $1 = __ZNK2js10StackFrame6scriptEv($this);
  return HEAPU16[$1 + 14 >> 1] & 65535;
}

function __ZN23GenericInterruptEnablerIiEC1EPii($this, $variable) {
  __ZN23GenericInterruptEnablerIiEC2EPii($this, $variable);
  return;
}

function __ZN2js17PreserveRegsGuardC1EP9JSContextRNS_9FrameRegsE($this, $cx, $regs) {
  __ZN2js17PreserveRegsGuardC2EP9JSContextRNS_9FrameRegsE($this, $cx, $regs);
  return;
}

function __ZN2js17InterpreterFramesC1EP9JSContextPNS_9FrameRegsERKNS0_20InterruptEnablerBaseE($this, $cx, $regs, $enabler) {
  __ZN2js17InterpreterFramesC2EP9JSContextPNS_9FrameRegsERKNS0_20InterruptEnablerBaseE($this, $cx, $regs, $enabler);
  return;
}

function __ZNK2js10StackFrame15maybeFormalArgsEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this >> 2] & 10 | 0) == 2) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZNK2js10StackFrame10formalArgsEv($this);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js31ScriptPrologueOrGeneratorResumeEP9JSContextPNS_10StackFrameEb($cx, $fp, $newType) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fp_idx_val = HEAP32[$fp >> 2];
    var $1 = __ZNK2js10StackFrame16isGeneratorFrameEv($fp_idx_val);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2js14ScriptPrologueEP9JSContextPNS_10StackFrameEb($cx, $fp, $newType);
    var $_0 = $3;
    __label__ = 5;
    break;
   case 3:
    var $_idx_val = HEAP32[HEAP32[$cx + 56 >> 2] + 804 >> 2];
    var $7 = __ZNK13JSCompartment9debugModeEv($_idx_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = $cx;
    var $10 = $fp;
    __ZN2js19ScriptDebugPrologueEP9JSContextPNS_10StackFrameE($9, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types17UseNewTypeAtEntryEP9JSContextPNS_10StackFrameE($cx, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fp_idx1_val = HEAP32[$fp >> 2];
    var $1 = __ZNK2js10StackFrame14isConstructingEv($fp_idx1_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $18 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $3 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $18 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $fp_idx_val = HEAP32[$fp + 16 >> 2];
    var $5 = __ZNK2js10StackFrame4prevEv($fp_idx_val);
    if (($5 | 0) == 0) {
      var $18 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$5 >> 2];
    var $8 = __ZNK2js10StackFrame13isScriptFrameEv($_idx_val);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      var $18 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $10 = __ZNK2js10StackFrame6scriptEv($5);
    var $12 = $5;
    var $13 = $cx + 60 | 0;
    var $14 = $fp;
    var $15 = __ZN2js10StackFrame11pcQuadraticERKNS_12ContextStackEPS0_PPNS_13JSInlinedSiteE($12, $13, $14);
    var $16 = __ZN2js5types10UseNewTypeEP9JSContextP8JSScriptPh($cx, $10, $15);
    var $18 = $16;
    __label__ = 6;
    break;
   case 6:
    var $18;
    return $18;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject5shapeEv($this_0_3_val) {
  return $this_0_3_val;
}

function __ZNK2js10StackFrame18loweredCallOrApplyEv($this_0_0_val) {
  return ($this_0_0_val & 4194304 | 0) != 0;
}

function _JSID_IS_VOID1831($iden) {
  return ($iden | 0) == 2 & 1;
}

function __ZNK2js5PCVal6isSlotEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function __ZNK2js5PCVal6toSlotEv($this_0_0_val) {
  return $this_0_0_val >>> 1;
}

function __ZL24CanIncDecWithoutOverflowi($i) {
  return ($i - 2147483647 | 0) >>> 0 > 1;
}

function __ZNK2js5PCVal8isFunObjEv($this_0_0_val) {
  return ($this_0_0_val & 3 | 0) == 0;
}

function __ZNK2js5PCVal8toFunObjEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js5PCVal7toShapeEv($this_0_0_val) {
  return $this_0_0_val & -4;
}

function __ZNK2js18PropertyCacheEntry7vcapTagEv($this_0_2_val) {
  return $this_0_2_val & 255;
}

function __ZNK2js18PropertyCacheEntry6vshapeEv($this_0_2_val) {
  return $this_0_2_val >>> 8;
}

function __ZNK2js5Shape16hasDefaultSetterEv($this_0_5_0_val) {
  return ($this_0_5_0_val | 0) == 0;
}

function __ZN8JSObject25brandedOrHasMethodBarrierEv($this_0_2_val) {
  return ($this_0_2_val & 40 | 0) != 0;
}

function _JSID_IS_STRING1834($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_IS_INT1835($iden) {
  return $iden & 1;
}

function _JSID_TO_INT1836($iden) {
  return $iden >> 1;
}

function __ZN2JS5Value11getInt32RefEv($this) {
  return $this;
}

function __ZN2JS5Value4swapERS0_($this, $rhs) {
  var $1 = $rhs | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $this | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  HEAP32[$1 >> 2] = $4$0;
  HEAP32[$1 + 4 >> 2] = $4$1;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  return;
}

function __ZN2jsL18GetDecomposeLengthEPhj($pc, $len) {
  return HEAPU8[$pc + ($len - 1) | 0] & 255;
}

function __ZNK2js12CallReceiver11spAfterCallEv($this_0_0_val) {
  return $this_0_0_val - 8 | 0;
}

function __ZL9EnterWithP9JSContexti4JSOpj($cx, $stackIndex, $oplen) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __ZNK9JSContext2fpEv($cx);
    var $2 = __ZNK9JSContext4regsEv($cx);
    var $4 = HEAP32[$2 >> 2];
    var $5 = $4 - 8 | 0;
    var $_idx = $5 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $6 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    HEAP32[$obj >> 2] = $8;
    __label__ = 5;
    break;
   case 3:
    var $10 = $cx;
    var $11 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($10, $5);
    var $12 = $11;
    HEAP32[$obj >> 2] = $12;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value9setObjectER8JSObject($5, $12);
    __label__ = 5;
    break;
   case 5:
    var $16 = __ZN2js17GetScopeChainFastEP9JSContextPNS_10StackFrameE4JSOpj($cx, $1, $oplen);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __Z19OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($cx, $obj);
    var $19 = HEAP32[$obj >> 2];
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = $4 + ($stackIndex << 3) | 0;
    var $23 = $1;
    var $24 = __ZNK2js10StackFrame4baseEv($23);
    var $28 = $22 - $24 >> 3;
    var $29 = $cx;
    var $30 = $19;
    var $31 = $16;
    var $32 = __Z16js_NewWithObjectP9JSContextP8JSObjectS2_i($29, $30, $31, $28);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $35 = $32;
    __ZN2js10StackFrame22setScopeChainNoCallObjER8JSObject($23, $35);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9EnterWithP9JSContexti4JSOpj["X"] = 1;

function __ZN2js14ScriptEpilogueEP9JSContextPNS_10StackFrameEb($cx, $fp, $ok) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $ok & 1;
    var $3 = $fp;
    var $_idx_val = HEAP32[HEAP32[$cx + 56 >> 2] + 804 >> 2];
    var $6 = __ZNK13JSCompartment9debugModeEv($_idx_val);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $cx;
    var $9 = __ZN2js19ScriptDebugEpilogueEP9JSContextPNS_10StackFrameEb($8, $3, $ok);
    var $_0 = $9 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    var $fp_idx_val = HEAP32[$fp >> 2];
    var $12 = __ZNK2js10StackFrame14isConstructingEv($fp_idx_val);
    if ($_0 << 24 >> 24 == 0 | $12 ^ 1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = __ZN2js10StackFrame11returnValueEv($3);
    var $_idx1 = $15 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $16 = __ZNK2JS5Value11isPrimitiveEv($_idx1_val$0, $_idx1_val$1);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $18 = __ZNK2js10StackFrame15constructorThisEv($fp);
    __ZN2JSL11ObjectValueER8JSObject1804($1, $18);
    var $_idx2 = $1 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN2js10StackFrame14setReturnValueERKN2JS5ValueE($3, $_idx2_val$0, $_idx2_val$1);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return $_0 << 24 >> 24 != 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ContextStack14popInlineFrameERNS_9FrameRegsE($regs) {
  var $regs_idx_val = HEAP32[$regs + 12 >> 2];
  var $1 = __ZNK2js9FrameRegs2fpEv($regs_idx_val);
  var $2 = $1;
  __ZN2js10StackFrame16functionEpilogueEv($2);
  var $3 = __ZNK2js10StackFrame10actualArgsEv($1);
  var $4 = $3 - 8 | 0;
  var $5 = $1;
  var $6 = __ZN2js10StackFrame11returnValueEv($5);
  var $7 = $6 | 0;
  var $8$0 = HEAP32[$7 >> 2];
  var $8$1 = HEAP32[$7 + 4 >> 2];
  var $9 = $3 - 16 | 0;
  var $st$15$0 = $9 | 0;
  HEAP32[$st$15$0 >> 2] = $8$0;
  var $st$15$1 = $9 + 4 | 0;
  HEAP32[$st$15$1 >> 2] = $8$1;
  __ZN2js9FrameRegs8popFrameEPN2JS5ValueE($regs, $4);
  return;
}

function __ZN2jsL13FrameAtomBaseEP9JSContextPNS_10StackFrameE($cx, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fp_idx_val = HEAP32[$fp >> 2];
    var $1 = __ZNK2js10StackFrame11hasImacropcEv($fp_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$cx + 52 >> 2] + 209948 | 0;
    var $6 = __ZN11JSAtomState16commonAtomsStartEv($5);
    var $12 = $6;
    __label__ = 4;
    break;
   case 3:
    var $8 = __ZNK2js10StackFrame6scriptEv($fp);
    var $12 = HEAP32[$8 + 56 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $12;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script, $pc, $rval) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js5types17TypeMonitorResultEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script, $pc, $rval);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $obj, $idval, $idp, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $atom = __stackBase__;
    var $idval_idx = $idval | 0;
    var $idval_idx_val$0 = HEAP32[$idval_idx >> 2];
    var $idval_idx_val$1 = HEAP32[$idval_idx + 4 >> 2];
    var $1 = __ZNK2JS5Value8isObjectEv($idval_idx_val$0, $idval_idx_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $3 = __Z28js_InternNonIntElementIdSlowP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $obj_idx_val, $idval, $idp, $vp);
    var $_0 = $3;
    __label__ = 5;
    break;
   case 3:
    var $5 = __Z14js_ValueToAtomP9JSContextRKN2JS5ValueEPP6JSAtom($cx, $idval_idx_val$0, $idval_idx_val$1, $atom);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = HEAP32[$atom >> 2];
    var $8 = __ZL12ATOM_TO_JSIDP6JSAtom1798($7);
    HEAP32[$idp >> 2] = $8;
    var $9 = $7 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $9);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12IteratorMoreP9JSContextP8JSObjectPbPN2JS5ValueE($cx, $iterobj, $cond, $rval) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $iterobj_idx1_val = HEAP32[$iterobj + 4 >> 2];
    var $1 = __ZNK8JSObject10isIteratorEv($iterobj_idx1_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $iterobj_idx_val = HEAP32[$iterobj + 24 >> 2];
    var $3 = __ZNK8JSObject17getNativeIteratorEv($iterobj_idx_val);
    var $_idx_val = HEAP32[$3 + 28 >> 2];
    var $4 = __ZNK2js14NativeIterator9isKeyIterEv($_idx_val);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP8[$cond] = HEAPU32[$3 + 8 >> 2] >>> 0 < HEAPU32[$3 + 12 >> 2] >>> 0 & 1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 4:
    var $13 = $cx;
    var $14 = $iterobj;
    var $15 = __Z15js_IteratorMoreP9JSContextP8JSObjectPN2JS5ValueE($13, $14, $rval);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $rval_idx = $rval | 0;
    var $rval_idx_val$0 = HEAP32[$rval_idx >> 2];
    var $rval_idx_val$1 = HEAP32[$rval_idx + 4 >> 2];
    var $18 = __ZNK2JS5Value6isTrueEv($rval_idx_val$0, $rval_idx_val$1);
    HEAP8[$cond] = $18 & 1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12IteratorNextP9JSContextP8JSObjectPN2JS5ValueE($cx, $iterobj, $rval) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $iterobj_idx1_val = HEAP32[$iterobj + 4 >> 2];
    var $1 = __ZNK8JSObject10isIteratorEv($iterobj_idx1_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $iterobj_idx_val = HEAP32[$iterobj + 24 >> 2];
    var $3 = __ZNK8JSObject17getNativeIteratorEv($iterobj_idx_val);
    var $_idx_val = HEAP32[$3 + 28 >> 2];
    var $4 = __ZNK2js14NativeIterator9isKeyIterEv($_idx_val);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $_idx2_val = HEAP32[$3 + 8 >> 2];
    var $6 = __ZNK2js14NativeIterator7currentEv($_idx2_val);
    var $7 = HEAP32[$6 >> 2];
    var $8 = __ZL12JSID_IS_ATOMi1876($7);
    if (($8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = _JSID_TO_STRING1867($7);
    __ZN2JS5Value9setStringEP8JSString($rval, $11);
    __ZN2js14NativeIterator9incCursorEv($3);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $13 = $cx;
    var $14 = $iterobj;
    var $15 = __Z15js_IteratorNextP9JSContextP8JSObjectPN2JS5ValueE($13, $14, $rval);
    var $_0 = ($15 | 0) != 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame6varObjEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame10scopeChainEv($this);
    var $_idx1_val = HEAP32[$1 + 8 >> 2];
    var $2 = __ZNK8JSObject8isVarObjEv($_idx1_val);
    if ($2) {
      var $obj_0_lcssa = $1;
      __label__ = 3;
      break;
    } else {
      var $obj_01 = $1;
      __label__ = 2;
      break;
    }
   case 2:
    var $obj_01;
    var $obj_01_idx_val = HEAP32[$obj_01 + 20 >> 2];
    var $3 = __ZNK8JSObject9getParentEv($obj_01_idx_val);
    var $_idx_val = HEAP32[$3 + 8 >> 2];
    var $4 = __ZNK8JSObject8isVarObjEv($_idx_val);
    if ($4) {
      var $obj_0_lcssa = $3;
      __label__ = 3;
      break;
    } else {
      var $obj_01 = $3;
      __label__ = 2;
      break;
    }
   case 3:
    var $obj_0_lcssa;
    return $obj_0_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13PropertyCache4testEP9JSContextPhRP8JSObjectS6_RPNS_18PropertyCacheEntryERP6JSAtom($this, $cx, $pc, $obj, $pobj, $entry, $atom) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx1_val = HEAP32[HEAP32[$obj >> 2] + 12 >> 2];
    var $2 = __ZNK8JSObject5shapeEv($_idx1_val);
    var $3 = __ZN2js13PropertyCache4hashEPhj($pc, $2);
    var $4 = $this + ($3 << 4) | 0;
    HEAP32[$entry >> 2] = $4;
    if ((HEAP32[$4 >> 2] | 0) == ($pc | 0)) {
      __label__ = 2;
      break;
    } else {
      var $28 = $4;
      __label__ = 8;
      break;
    }
   case 2:
    if ((HEAP32[$this + ($3 << 4) + 4 >> 2] | 0) == ($2 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $28 = $4;
      __label__ = 8;
      break;
    }
   case 3:
    var $13 = HEAP32[$obj >> 2];
    HEAP32[$pobj >> 2] = $13;
    var $14 = HEAP32[$entry >> 2];
    var $_idx2_val = HEAP32[$14 + 8 >> 2];
    var $15 = __ZNK2js18PropertyCacheEntry7vcapTagEv($_idx2_val);
    if (($15 | 0) == 1) {
      __label__ = 4;
      break;
    } else {
      var $23 = $13;
      var $22 = $14;
      var $_idx3_val = $_idx2_val;
      __label__ = 6;
      break;
    }
   case 4:
    var $_idx_val_idx_val = HEAP32[HEAP32[$13 + 36 >> 2] >> 2];
    var $18 = __ZNK8JSObject8getProtoEv($_idx_val_idx_val);
    if (($18 | 0) == 0) {
      var $23 = $13;
      var $22 = $14;
      var $_idx3_val = $_idx2_val;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$pobj >> 2] = $18;
    var $_pre = HEAP32[$entry >> 2];
    var $23 = $18;
    var $22 = $_pre;
    var $_idx3_val = HEAP32[$_pre + 8 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $_idx3_val;
    var $22;
    var $23;
    var $24 = __ZNK2js18PropertyCacheEntry6vshapeEv($_idx3_val);
    var $_idx4_val = HEAP32[$23 + 12 >> 2];
    var $25 = __ZN2js13PropertyCache10matchShapeEP9JSContextP8JSObjectj($_idx4_val, $24);
    if ($25) {
      __label__ = 7;
      break;
    } else {
      var $28 = $22;
      __label__ = 8;
      break;
    }
   case 7:
    HEAP32[$atom >> 2] = 0;
    return;
   case 8:
    var $28;
    var $29 = __ZN2js13PropertyCache8fullTestEP9JSContextPhPP8JSObjectS6_PNS_18PropertyCacheEntryE($cx, $pc, $obj, $pobj, $28);
    HEAP32[$atom >> 2] = $29;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE1830($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $vp_idx1 = $vp | 0;
    var $vp_idx1_val$0 = HEAP32[$vp_idx1 >> 2];
    var $vp_idx1_val$1 = HEAP32[$vp_idx1 + 4 >> 2];
    var $1 = __ZNK2JS5Value11isPrimitiveEv($vp_idx1_val$0, $vp_idx1_val$1);
    if ($1) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($vp_idx1_val$0, $vp_idx1_val$1);
    var $4 = $3;
    var $5 = $cx;
    var $6 = __ZN8JSObject12defaultValueEP9JSContext6JSTypePN2JS5ValueE($4, $5, 4, $vp);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh($cx, $script, $pc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $2 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js5types4Type10DoubleTypeEv($1);
    var $_0_val = HEAP32[$1 >> 2];
    __ZN2js5types17TypeDynamicResultEP9JSContextP8JSScriptPhNS0_4TypeE($cx, $script, $pc, $_0_val);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5IsXMLRKN2JS5ValueE($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZNK8JSObject5isXMLEv($_idx_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript13MonitorStringEP9JSContextP8JSScriptPh($cx, $script, $pc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $2 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js5types4Type10StringTypeEv($1);
    var $_0_val = HEAP32[$1 >> 2];
    __ZN2js5types17TypeDynamicResultEP9JSContextP8JSScriptPhNS0_4TypeE($cx, $script, $pc, $_0_val);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9NumberDivEdd($a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($b == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    if ($a == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZL15JSDOUBLE_IS_NaNd1870($a);
    if (($5 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $_0 = $8;
    __label__ = 9;
    break;
   case 5:
    var $10 = __ZL15JSDOUBLE_IS_NEGd($a);
    var $11 = __ZL15JSDOUBLE_IS_NEGd($b);
    if ($10 ^ $11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $14 = (tempDoubleI32[0] = HEAP32[_js_NegativeInfinity >> 2], tempDoubleI32[1] = HEAP32[_js_NegativeInfinity + 4 >> 2], tempDoubleF64[0]);
    var $_0 = $14;
    __label__ = 9;
    break;
   case 7:
    var $16 = (tempDoubleI32[0] = HEAP32[_js_PositiveInfinity >> 2], tempDoubleI32[1] = HEAP32[_js_PositiveInfinity + 4 >> 2], tempDoubleF64[0]);
    var $_0 = $16;
    __label__ = 9;
    break;
   case 8:
    var $_0 = $a / $b;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL7js_fmoddd($d, $d2) {
  var $1 = _fmod($d, $d2);
  return $1;
}

function __ZN2js8ToNumberEP9JSContextPN2JS5ValueE($cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $1 = __ZNK2JS5Value8isNumberEv($vp_idx_val$0, $vp_idx_val$1);
    if ($1) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($cx, $vp_idx_val$0, $vp_idx_val$1, $d);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $6 = __ZN2JS5Value9setNumberEd($vp, $5);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL10Int32ValueEi1832($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZL8DoIncDecP9JSContextPK10JSCodeSpecPN2JS5ValueES6_($cx, $cs, $vp, $vp2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $d1 = __stackBase__ + 8;
    var $1 = $cs + 4 | 0;
    if ((HEAP32[$1 >> 2] & 4096 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 3:
    var $8 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $9 = __ZN2JS5Value9setNumberEd($vp, $8);
    if ((HEAP32[$1 >> 2] & 2048 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $storemerge1 = $8 + 1;
    __label__ = 6;
    break;
   case 5:
    var $storemerge1 = $8 - 1;
    __label__ = 6;
    break;
   case 6:
    var $storemerge1;
    tempDoubleF64[0] = $storemerge1, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $18 = __ZN2JS5Value9setNumberEd($vp2, $storemerge1);
    var $_0 = 1;
    __label__ = 12;
    break;
   case 7:
    var $20 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d1);
    if ($20) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 8:
    var $24 = (HEAP32[$1 >> 2] & 2048 | 0) == 0;
    var $25 = (tempDoubleI32[0] = HEAP32[$d1 >> 2], tempDoubleI32[1] = HEAP32[$d1 + 4 >> 2], tempDoubleF64[0]);
    if ($24) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $storemerge = $25 + 1;
    __label__ = 11;
    break;
   case 10:
    var $storemerge = $25 - 1;
    __label__ = 11;
    break;
   case 11:
    var $storemerge;
    tempDoubleF64[0] = $storemerge, HEAP32[$d1 >> 2] = tempDoubleI32[0], HEAP32[$d1 + 4 >> 2] = tempDoubleI32[1];
    var $31 = __ZN2JS5Value9setNumberEd($vp, $storemerge);
    var $32 = $vp | 0;
    var $33$0 = HEAP32[$32 >> 2];
    var $33$1 = HEAP32[$32 + 4 >> 2];
    var $34 = $vp2 | 0;
    HEAP32[$34 >> 2] = $33$0;
    HEAP32[$34 + 4 >> 2] = $33$1;
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL8DoIncDecP9JSContextPK10JSCodeSpecPN2JS5ValueES6_["X"] = 1;

function __ZN2JSL11NumberValueEd1833($agg_result, $dbl) {
  var $1 = __ZN2JS5Value9setNumberEd($agg_result, $dbl);
  return;
}

function __Z23js_GetProtoIfDenseArrayP8JSObject($obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $1 = __ZNK8JSObject12isDenseArrayEv($obj_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $5 = $obj;
      __label__ = 3;
      break;
    }
   case 2:
    var $obj_idx1_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $3 = __ZNK8JSObject8getProtoEv($obj_idx1_val_idx_val);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13PropertyCache10testForSetEP9JSContextPhP8JSObjectPPNS_18PropertyCacheEntryEPS5_PP6JSAtom($this, $cx, $pc, $obj, $entryp, $obj2p, $atomp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $obj;
    var $obj_idx_val = HEAP32[$obj + 12 >> 2];
    var $2 = __ZNK8JSObject5shapeEv($obj_idx_val);
    var $3 = __ZN2js13PropertyCache4hashEPhj($pc, $2);
    var $4 = $this + ($3 << 4) | 0;
    HEAP32[$entryp >> 2] = $4;
    if ((HEAP32[$4 >> 2] | 0) == ($pc | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    if ((HEAP32[$this + ($3 << 4) + 4 >> 2] | 0) == ($2 | 0)) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = __ZN2js13PropertyCache8fullTestEP9JSContextPhPP8JSObjectS6_PNS_18PropertyCacheEntryE($cx, $pc, $1, $obj2p, $4);
    HEAP32[$atomp >> 2] = $13;
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js18PropertyCacheEntry6addingEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 8 >> 2];
    var $1 = __ZNK2js18PropertyCacheEntry7vcapTagEv($this_idx_val);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $9 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$this + 4 >> 2];
    var $6 = __ZNK2js18PropertyCacheEntry6vshapeEv($this_idx_val);
    var $9 = ($5 | 0) != ($6 | 0);
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject21nativeSetSlotWithTypeEP9JSContextPKN2js5ShapeERKN2JS5ValueE($this, $cx, $shape, $value) {
  var $2 = HEAP32[$shape + 24 >> 2];
  var $value_idx = $value | 0;
  var $value_idx_val$0 = HEAP32[$value_idx >> 2];
  var $value_idx_val$1 = HEAP32[$value_idx + 4 >> 2];
  __ZN8JSObject13nativeSetSlotEjRKN2JS5ValueE($this, $2, $value_idx_val$0, $value_idx_val$1);
  var $4 = HEAP32[$shape + 12 >> 2];
  __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiRKN2JS5ValueE($cx, $this, $4, $value);
  return;
}

function __ZN8JSObject6extendEP9JSContextPKN2js5ShapeEb($this, $cx, $shape) {
  __ZN8JSObject15setLastPropertyEPKN2js5ShapeE($this, $shape);
  __ZN8JSObject11updateFlagsEPKN2js5ShapeEb($this, $shape);
  __ZN8JSObject11updateShapeEP9JSContext($this, $cx);
  return;
}

function __Z18js_PurgeScopeChainP9JSContextP8JSObjecti($cx, $obj, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj_idx_val = HEAP32[$obj + 8 >> 2];
    var $1 = __ZNK8JSObject10isDelegateEv($obj_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $cx;
    var $4 = $obj;
    __Z24js_PurgeScopeChainHelperP9JSContextP8JSObjecti($3, $4, $id);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13StaticStrings23getUnitStringForElementEP9JSContextP8JSStringj($this, $cx, $str, $index) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSString8getCharsEP9JSContext($str, $cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAPU16[$1 + ($index << 1) >> 1];
    if (($5 & 65535) < 256) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZN2js13StaticStrings7getUnitEt($this, $5);
    var $_0 = $8 | 0;
    __label__ = 5;
    break;
   case 4:
    var $11 = $cx;
    var $12 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($11, $str, $index, 1);
    var $_0 = $12;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js19ValuePropertyBearerEP9JSContextRKN2JS5ValueEi($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $1 = __ZNK2JS5Value8isObjectEv($v_idx_val$0, $v_idx_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_idx_val$0, $v_idx_val$1);
    var $_0 = $3;
    __label__ = 9;
    break;
   case 3:
    var $5 = __ZNK2JS5Value8isStringEv($v_idx_val$0, $v_idx_val$1);
    if ($5) {
      var $protoKey_0 = 9;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZNK2JS5Value8isNumberEv($v_idx_val$0, $v_idx_val$1);
    if ($7) {
      var $protoKey_0 = 8;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZNK2JS5Value9isBooleanEv($v_idx_val$0, $v_idx_val$1);
    if ($9) {
      var $protoKey_0 = 4;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __Z26js_ReportIsNullOrUndefinedP9JSContextiRKN2JS5ValueEP8JSString($cx, -2, $v);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 7:
    var $protoKey_0;
    var $12 = $cx;
    var $13 = $pobj;
    var $14 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($12, 0, $protoKey_0, $13, 0);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = HEAP32[$pobj >> 2];
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript13MonitorAssignEP9JSContextP8JSScriptPhP8JSObjectiRKN2JS5ValueE($cx, $obj, $id) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $obj_idx_val = HEAP32[$obj + 8 >> 2];
    var $3 = __ZNK8JSObject16hasSingletonTypeEv($obj_idx_val);
    if ($3) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __Z12js_IdIsIndexiPj($id, $i);
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $obj_idx1_val = HEAP32[$obj + 36 >> 2];
    var $8 = __ZNK8JSObject4typeEv($obj_idx1_val);
    __ZN2js5types31MarkTypeObjectUnknownPropertiesEP9JSContextPNS0_10TypeObjectEb($cx, $8, 0);
    __label__ = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14CallArgsFromSpEjPN2JS5ValueE($agg_result, $argc, $sp) {
  var $2 = $sp + (-$argc << 3) | 0;
  __ZN2js16CallArgsFromArgvEjPN2JS5ValueE($agg_result, $argc, $2);
  return;
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction1837($v_0_0_0_val$0, $v_0_0_0_val$1, $funobj, $fun) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject1840($v_0_0_0_val$0, $v_0_0_0_val$1, $funobj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[HEAP32[$funobj >> 2] + 24 >> 2];
    var $4 = __ZNK8JSObject18getFunctionPrivateEv($_idx_val);
    HEAP32[$fun >> 2] = $4;
    __label__ = 3;
    break;
   case 3:
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ContextStack15pushInlineFrameEP9JSContextRNS_9FrameRegsERKNS_8CallArgsER8JSObjectP10JSFunctionP8JSScriptNS_17InitialFrameFlagsE($this, $cx, $regs, $args, $callee, $fun, $script, $initial) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $flags = __stackBase__;
    var $1 = __ZN2jsL12ToFrameFlagsENS_17InitialFrameFlagsE1859($initial);
    HEAP32[$flags >> 2] = $1;
    var $2 = $this;
    var $3 = $cx;
    var $4 = $script;
    var $_idx_val = HEAP16[$fun + 56 >> 1];
    var $_idx1_val = HEAP16[$script + 44 >> 1];
    var $7 = __ZNK2js12ContextStack12getCallFrameEP9JSContextNS_16MaybeReportErrorERKNS_8CallArgsEP10JSFunctionP8JSScriptPNS_10StackFrame5FlagsE($2, $3, $args, $_idx_val, $_idx1_val, $flags);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $fun;
    var $args_idx_val = HEAP32[$args + 4 >> 2];
    var $11 = __ZNK2js8CallArgs4argcEv($args_idx_val);
    var $12 = HEAP32[$flags >> 2];
    var $13 = $callee;
    __ZN2js10StackFrame13initCallFrameEP9JSContextR8JSObjectP10JSFunctionP8JSScriptjNS0_5FlagsE($7, $3, $13, $10, $4, $11, $12);
    var $14 = $regs;
    __ZN2js9FrameRegs12prepareToRunERNS_10StackFrameEP8JSScript($14, $7, $4);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14ScriptPrologueEP9JSContextPNS_10StackFrameEb($cx, $fp, $newType) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fp_idx_val = HEAP32[$fp >> 2];
    var $1 = __ZNK2js10StackFrame14isConstructingEv($fp_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZNK2js10StackFrame6calleeEv($fp);
    var $4 = $cx;
    var $5 = $3;
    var $6 = __Z24js_CreateThisForFunctionP9JSContextP8JSObjectb($4, $5, $newType);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $6;
    var $10 = __ZNK2js10StackFrame12functionThisEv($fp);
    __ZN2JS5Value9setObjectER8JSObject($10, $9);
    __label__ = 4;
    break;
   case 4:
    var $_idx_val = HEAP32[HEAP32[$cx + 56 >> 2] + 804 >> 2];
    var $14 = __ZNK13JSCompartment9debugModeEv($_idx_val);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = $fp;
    var $17 = $cx;
    __ZN2js19ScriptDebugPrologueEP9JSContextPNS_10StackFrameE($17, $16);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js19ComputeImplicitThisEP9JSContextP8JSObjectRKN2JS5ValueEPS5_($cx, $obj, $funval, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $funval_idx = $funval | 0;
    var $funval_idx_val$0 = HEAP32[$funval_idx >> 2];
    var $funval_idx_val$1 = HEAP32[$funval_idx + 4 >> 2];
    var $1 = __ZNK2JS5Value8isObjectEv($funval_idx_val$0, $funval_idx_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 2:
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $3 = __ZNK8JSObject8isGlobalEv($obj_idx_val);
    if ($3) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2jsL25IsCacheableNonGlobalScopeEP8JSObject($obj);
    if ($5) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZN8JSObject10thisObjectEP9JSContext($obj, $cx);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JS5Value9setObjectER8JSObject($vp, $7);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19js_UnwrapWithObjectP9JSContextP8JSObject($withobj_0_9_val_0_0_val) {
  var $1 = __ZNK8JSObject8getProtoEv($withobj_0_9_val_0_0_val);
  return $1;
}

function __ZN8JSScript8getConstEj($this_0_1_val, $this_0_10_val, $index) {
  var $1 = __ZN8JSScript6constsEv($this_0_1_val, $this_0_10_val);
  return HEAP32[$1 >> 2] + ($index << 3) | 0;
}

function __ZN2jsL12ToFrameFlagsENS_17InitialFrameFlagsE1859($initial) {
  return $initial;
}

function __ZNK2js14NativeIterator7currentEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZL14JSID_FROM_BITSj1904($bits) {
  return $bits;
}

function __ZL17iterator_iteratorP9JSContextP8JSObjecti($cx, $obj, $keysonly) {
  return $obj;
}

function __ZNK2js14NativeIterator5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js14NativeIterator3endEv($this_0_3_val) {
  return $this_0_3_val;
}

function __ZNK2js5Shape20isAccessorDescriptorEv($this_0_7_val) {
  return ($this_0_7_val & 48) << 24 >> 24 != 0;
}

function __ZN2js10StackFrame10isYieldingEv($this_0_0_val) {
  return ($this_0_0_val & 256 | 0) != 0;
}

function _JSVAL_TO_OBJECT_IMPL1849($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_IS_OBJECT_OR_NULL_IMPL($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 > 4294967173 & 1;
}

function __ZN2js13PropertyCache4hashEPhj($pc, $kshape) {
  var $1 = $pc;
  return ($1 >>> 12 ^ $1) + $kshape & 4095;
}

function __ZNK8JSObject9isDeclEnvEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js12DeclEnvClassE | 0);
}

function _JSID_TO_STRING1867($iden) {
  return $iden;
}

function __ZNK8JSObject8isVarObjEv($this_0_2_val) {
  return ($this_0_2_val & 4096 | 0) != 0;
}

function __ZNK8JSObject10isIteratorEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js13IteratorClassE | 0);
}

function __ZNK2js14NativeIterator9isKeyIterEv($this_0_7_val) {
  return ($this_0_7_val & 2 | 0) == 0;
}

function _JSVAL_SAME_TYPE_IMPL($lhs_0$0, $lhs_0$1, $rhs_0$0, $rhs_0$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $lhs_0$1;
    var $4 = $rhs_0$1;
    if (($2 | 0) == ($4 | 0)) {
      var $11 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($2 >>> 0 < 4294967168) {
      __label__ = 3;
      break;
    } else {
      var $11 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = $4 >>> 0 < 4294967168;
    __label__ = 4;
    break;
   case 4:
    var $11;
    return $11 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10FrameGuard6pushedEv($this_0_0_val) {
  return ($this_0_0_val | 0) != 0;
}

function _JSID_IS_OBJECT1900($iden) {
  return ($iden & 7 | 0) == 4 & ($iden | 0) != 4 & 1;
}

function _JSID_TO_OBJECT1901($iden) {
  return $iden & -8;
}

function __ZN2jsL16CastAsPropertyOpEP8JSObject1842($object) {
  return $object;
}

function __ZN2jsL22CastAsStrictPropertyOpEP8JSObject1843($object) {
  return $object;
}

function __ZL15JSDOUBLE_IS_NaNd1870($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZL15JSDOUBLE_IS_NEGd($d) {
  tempDoubleF64[0] = $d;
  var $1$1 = tempDoubleI32[1];
  var $$emscripten$temp$0$1 = 0;
  return ($1$1 | 0) < ($$emscripten$temp$0$1 | 0) || ($1$1 | 0) == ($$emscripten$temp$0$1 | 0) && tempDoubleI32[0] >>> 0 < 0 >>> 0;
}

function _JSDOUBLE_IS_NEGZERO1872($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d != 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $_0 = tempDoubleI32[1] >>> 31 | 0 << 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js23AdvanceOverBlockchainOpEPh($pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP8[$pc];
    if ($1 << 24 >> 24 == -67) {
      __label__ = 2;
      break;
    } else if ($1 << 24 >> 24 == -68) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $pc;
      __label__ = 4;
      break;
    }
   case 2:
    var $_0 = $pc + 1 | 0;
    __label__ = 4;
    break;
   case 3:
    var $_0 = $pc + 3 | 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame11setYieldingEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 256;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN8JSScript4mainEv($this_0_0_val, $this_0_14_val) {
  return $this_0_0_val + $this_0_14_val | 0;
}

function __ZN2js10StackFrame24setFinishedInInterpreterEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 512;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js17InterpreterFrames20InterruptEnablerBaseC2Ev($this) {
  HEAP32[$this >> 2] = __ZTVN2js17InterpreterFrames20InterruptEnablerBaseE + 8 | 0;
  return;
}

function __ZN2js12StackSegment11repointRegsEPNS_9FrameRegsE($this, $regs) {
  HEAP32[$this + 8 >> 2] = $regs;
  return;
}

function __ZN2js17InterpreterFramesD2Ev($this_0_0_val, $this_0_1_val_0_11_val) {
  HEAP32[$this_0_1_val_0_11_val + 209936 >> 2] = $this_0_0_val;
  return;
}

function __ZL13JSVAL_TO_IMPLN2JS5ValueE1850($agg_result, $_0_0_0_val$0, $_0_0_0_val$1) {
  var $agg_result_0 = $agg_result | 0;
  HEAP32[$agg_result_0 >> 2] = $_0_0_0_val$0;
  HEAP32[$agg_result_0 + 4 >> 2] = $_0_0_0_val$1;
  return;
}

function __ZN2js2gcL25GetGCObjectFixedSlotsKindEj($numFixedSlots) {
  return HEAP32[__ZN2js2gc16slotsToThingKindE + ($numFixedSlots << 2) >> 2];
}

function __ZN8JSObject10setIndexedEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] | 64;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN8JSObject16setMethodBarrierEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] | 32;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js14NativeIterator9incCursorEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] + 4 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js17InterpreterFramesC2EP9JSContextPNS_9FrameRegsERKNS0_20InterruptEnablerBaseE($this, $cx, $regs, $enabler) {
  HEAP32[$this + 4 >> 2] = $cx;
  HEAP32[$this + 8 >> 2] = $regs;
  HEAP32[$this + 12 >> 2] = $enabler;
  var $4 = $cx + 52 | 0;
  var $7 = HEAP32[HEAP32[$4 >> 2] + 209936 >> 2];
  HEAP32[$this >> 2] = $7;
  var $10 = HEAP32[$4 >> 2] + 209936 | 0;
  HEAP32[$10 >> 2] = $this;
  return;
}

function _MAGIC_OBJ_TO_JSVAL_IMPL($agg_result, $obj) {
  HEAP32[$agg_result + 4 >> 2] = -124;
  HEAP32[$agg_result >> 2] = $obj;
  return;
}

function __ZN2js10FrameGuardC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP8[$this + 4 | 0] = 0;
  return;
}

function __ZN2js23AutoPreserveEnumeratorsD2Ev($this_0_0_val, $this_0_1_val) {
  HEAP32[$this_0_0_val + 284 >> 2] = $this_0_1_val;
  return;
}

function __ZN2js23AutoPreserveEnumeratorsC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  var $4 = HEAP32[$cx + 284 >> 2];
  HEAP32[$this + 4 >> 2] = $4;
  return;
}

function __ZN8JSScript9getRegExpEj($this, $index) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $_idx1_val = HEAP8[$this + 18 | 0];
  var $3 = __ZN8JSScript7regexpsEv($_idx_val, $_idx1_val);
  return HEAP32[HEAP32[$3 >> 2] + ($index << 2) >> 2];
}

function __ZN2JSL10MagicValueE10JSWhyMagic1838($agg_result) {
  __ZN2JS5Value8setMagicE10JSWhyMagic($agg_result, 9);
  return;
}

function __ZN2JSL14UndefinedValueEv1839($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN10JSFunction13setMethodAtomEP6JSAtom($this, $atom) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $3 = $atom | 0;
  __ZN2JSL11StringValueEP8JSString1846($1, $3);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, 0, $_idx_val$0, $_idx_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK8JSObject20canHaveMethodBarrierEv($this_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject8isObjectEv($this_0_1_val);
    if ($1) {
      var $9 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject10isFunctionEv($this_0_1_val);
    if ($3) {
      var $9 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK8JSObject11isPrimitiveEv($this_0_1_val);
    if ($5) {
      var $9 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZNK8JSObject6isDateEv($this_0_1_val);
    var $9 = $7;
    __label__ = 5;
    break;
   case 5:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject1840($v_0_0_0_val$0, $v_0_0_0_val$1, $funobj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    HEAP32[$funobj >> 2] = $3;
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZNK8JSObject10isFunctionEv($_idx_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13js_IsCallableRKN2JS5ValueE1841($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZN8JSObject10isCallableEv($_idx_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1845($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 24;
    var $4 = __ZNK9JSContext5hasfpEv($cx);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $7;
    var $8 = $cx;
    var $9 = $global;
    var $10 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($8, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $18 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZNK9JSContext2fpEv($cx);
    var $13 = __ZNK2js10StackFrame10scopeChainEv($12);
    var $14 = $13;
    var $15 = __ZNK8JSObject9getGlobalEv($14);
    var $16 = $15;
    HEAP32[$global >> 2] = $16;
    var $18 = $16;
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $18, $19);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $20 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    HEAP32[$proto >> 2] = $22;
    var $29 = $22;
    __label__ = 9;
    break;
   case 7:
    var $24 = $cx;
    var $26 = $proto;
    var $27 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($24, $18, $3, $26, __ZN2js11ObjectClassE);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $29 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $29;
    var $30 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1852($cx, $29, $18, $kind);
    var $_0 = $30;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL21CopyInitializerObjectEP9JSContextP8JSObjectPNS_5types10TypeObjectE($cx, $baseobj, $type) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $baseobj_idx = $baseobj + 8 | 0;
    var $baseobj_idx_val = HEAP32[$baseobj_idx >> 2];
    var $1 = __ZNK8JSObject13numFixedSlotsEv($baseobj_idx_val);
    var $2 = __ZN2js2gcL25GetGCObjectFixedSlotsKindEj($1);
    var $3 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1845($cx, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $baseobj_idx1_val = HEAP32[$baseobj + 28 >> 2];
    var $6 = __ZNK8JSObject8numSlotsEv($baseobj_idx1_val);
    var $7 = __ZN8JSObject11ensureSlotsEP9JSContextj($3, $cx, $6);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($3, $type);
    var $9 = HEAP32[$baseobj_idx >> 2];
    var $10 = $3 + 8 | 0;
    HEAP32[$10 >> 2] = $9;
    var $12 = HEAP32[$baseobj >> 2];
    var $13 = $3 | 0;
    HEAP32[$13 >> 2] = $12;
    var $15 = HEAP32[$baseobj + 12 >> 2];
    var $16 = $3 + 12 | 0;
    HEAP32[$16 >> 2] = $15;
    var $_0 = $3;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13PropertyCache11testForInitEP9JSRuntimePhP8JSObjectPPKNS_5ShapeEPPNS_18PropertyCacheEntryE($this, $rt, $pc, $obj_0_3_val, $shapep, $entryp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject5shapeEv($obj_0_3_val);
    var $2 = __ZN2js13PropertyCache4hashEPhj($pc, $1);
    var $3 = $this + ($2 << 4) | 0;
    HEAP32[$entryp >> 2] = $3;
    if ((HEAP32[$3 >> 2] | 0) == ($pc | 0)) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    if ((HEAP32[$this + ($2 << 4) + 4 >> 2] | 0) == ($1 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$this + ($2 << 4) + 8 >> 2];
    var $12 = __ZNK2js18PropertyCacheEntry6vshapeEv($_idx_val);
    if (($12 | 0) == (HEAP32[$rt + 44 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx1_val = HEAP32[$this + ($2 << 4) + 12 >> 2];
    var $17 = __ZNK2js5PCVal7toShapeEv($_idx1_val);
    HEAP32[$shapep >> 2] = $17;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value14isObjectOrNullEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_IS_OBJECT_OR_NULL_IMPL($this_0_0_0_val$0, $this_0_0_0_val$1);
  return ($1 | 0) != 0;
}

function __ZN2js8Debugger19onDebuggerStatementEP9JSContextPN2JS5ValueE($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 56 >> 2];
    var $3 = __ZN13JSCompartment12getDebuggeesEv($2);
    var $4 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5emptyEv($3);
    if ($4) {
      var $8 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN2js8Debugger12dispatchHookEP9JSContextPN2JS5ValueENS0_4HookE($cx, $vp, 0);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11StringValueEP8JSString1846($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function _JSVAL_TO_OBJECT1847($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE1850($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_OBJECT_IMPL1849($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueES2_1848($beg, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($beg | 0) == ($end | 0)) {
      __label__ = 3;
      break;
    } else {
      var $v_01 = $beg;
      __label__ = 2;
      break;
    }
   case 2:
    var $v_01;
    __ZN2JS5Value12setUndefinedEv($v_01);
    var $2 = $v_01 + 8 | 0;
    if (($2 | 0) == ($end | 0)) {
      __label__ = 3;
      break;
    } else {
      var $v_01 = $2;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger17onExceptionUnwindEP9JSContextPN2JS5ValueE($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 56 >> 2];
    var $3 = __ZN13JSCompartment12getDebuggeesEv($2);
    var $4 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5emptyEv($3);
    if ($4) {
      var $8 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN2js8Debugger12dispatchHookEP9JSContextPN2JS5ValueENS0_4HookE($cx, $vp, 1);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame16clearReturnValueEv($this) {
  var $1 = $this + 24 | 0;
  __ZN2JS5Value12setUndefinedEv($1);
  var $2 = $this;
  __ZN2js10StackFrame15markReturnValueEv($2);
  return;
}

function __ZN2js30ScriptEpilogueOrGeneratorYieldEP9JSContextPNS_10StackFrameEb($cx, $fp, $ok) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fp_idx_val = HEAP32[$fp >> 2];
    var $1 = __ZN2js10StackFrame10isYieldingEv($fp_idx_val);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2js14ScriptEpilogueEP9JSContextPNS_10StackFrameEb($cx, $fp, $ok);
    var $_0 = $3;
    __label__ = 5;
    break;
   case 3:
    var $_idx_val = HEAP32[HEAP32[$cx + 56 >> 2] + 804 >> 2];
    var $7 = __ZNK13JSCompartment9debugModeEv($_idx_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $ok;
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = $cx;
    var $10 = $fp;
    var $11 = __ZN2js19ScriptDebugEpilogueEP9JSContextPNS_10StackFrameEb($9, $10, $ok);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17InterpreterFramesD1Ev($this_0_0_val, $this_0_1_val_0_11_val) {
  __ZN2js17InterpreterFramesD2Ev($this_0_0_val, $this_0_1_val_0_11_val);
  return;
}

function __ZN2js17PreserveRegsGuardD1Ev($this) {
  __ZN2js17PreserveRegsGuardD2Ev($this);
  return;
}

function __ZN23GenericInterruptEnablerIiEC2EPii($this, $variable) {
  var $1 = $this | 0;
  __ZN2js17InterpreterFrames20InterruptEnablerBaseC2Ev($1);
  HEAP32[$this >> 2] = __ZTV23GenericInterruptEnablerIiE + 8 | 0;
  HEAP32[$this + 4 >> 2] = $variable;
  HEAP32[$this + 8 >> 2] = -1;
  return;
}

function __ZN2js17PreserveRegsGuardD2Ev($this) {
  var $1 = $this | 0;
  var $5 = HEAP32[$1 >> 2];
  var $6 = HEAP32[$this + 8 >> 2];
  HEAP32[$5 >> 2] = HEAP32[$6 >> 2];
  HEAP32[$5 + 4 >> 2] = HEAP32[$6 + 4 >> 2];
  HEAP32[$5 + 8 >> 2] = HEAP32[$6 + 8 >> 2];
  HEAP32[$5 + 12 >> 2] = HEAP32[$6 + 12 >> 2];
  var $9 = HEAP32[$1 >> 2];
  var $_idx_val = HEAP32[HEAP32[$this + 4 >> 2] + 60 >> 2];
  __ZN2js12ContextStack11repointRegsEPNS_9FrameRegsE($_idx_val, $9);
  return;
}

function __ZN2js12ContextStack11repointRegsEPNS_9FrameRegsE($this_0_0_val, $regs) {
  __ZN2js12StackSegment11repointRegsEPNS_9FrameRegsE($this_0_0_val, $regs);
  return;
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1852($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, __ZN2js11ObjectClassE, $1, $parent, 0, (__ZN2js11ObjectClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $7 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, __ZN2js11ObjectClassE, $kind);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $10);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject11isPrimitiveEv($this_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject8isNumberEv($this_0_1_val);
    if ($1) {
      var $7 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject8isStringEv($this_0_1_val);
    if ($3) {
      var $7 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK8JSObject9isBooleanEv($this_0_1_val);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL25IsCacheableNonGlobalScopeEP8JSObject($obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$obj + 4 >> 2];
    var $_idx_val = $1;
    var $2 = __ZNK8JSObject6isCallEv($_idx_val);
    if ($2) {
      var $8 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject7isBlockEv($1);
    if ($4) {
      var $8 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZNK8JSObject9isDeclEnvEv($1);
    var $8 = $6;
    __label__ = 4;
    break;
   case 4:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject11updateFlagsEPKN2js5ShapeEb($this, $shape) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $2 = HEAP32[$shape + 12 >> 2];
    var $3 = __Z12js_IdIsIndexiPj($2, $index);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN8JSObject10setIndexedEv($this);
    __label__ = 3;
    break;
   case 3:
    var $shape_idx_val = HEAP8[$shape + 29 | 0];
    var $7 = __ZNK2js5Shape8isMethodEv($shape_idx_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN8JSObject16setMethodBarrierEv($this);
    __label__ = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject11updateShapeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 8 >> 2];
    var $1 = __ZNK8JSObject11hasOwnShapeEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    var $3 = __Z16js_GenerateShapeP9JSContext($cx_idx_val);
    __ZN8JSObject11setOwnShapeEj($this, $3);
    __label__ = 4;
    break;
   case 3:
    var $8 = HEAP32[HEAP32[$this >> 2] >> 2];
    HEAP32[$this + 12 >> 2] = $8;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSDOUBLE_IS_INT321871($d, $pi) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSDOUBLE_IS_NEGZERO1872($d);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $d & -1;
    HEAP32[$pi >> 2] = $4;
    var $_0 = ($4 | 0) == $d & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13PropertyCache10matchShapeEP9JSContextP8JSObjectj($obj_0_3_val, $shape) {
  var $1 = __ZNK8JSObject5shapeEv($obj_0_3_val);
  return ($1 | 0) == ($shape | 0);
}

function __ZNK8JSObject17getNativeIteratorEv($this_0_6_val) {
  var $1 = __ZNK8JSObject10getPrivateEv($this_0_6_val);
  return $1;
}

function __ZL12JSID_IS_ATOMi1876($id) {
  var $1 = _JSID_IS_STRING1834($id);
  return $1;
}

function __ZN2js9FrameRegs8popFrameEPN2JS5ValueE($this, $newsp) {
  var $1 = $this + 12 | 0;
  var $4 = HEAP32[$1 >> 2];
  var $5 = $this + 8 | 0;
  var $6 = __ZN2js10StackFrame6prevpcEPPNS_13JSInlinedSiteE($4, $5);
  HEAP32[$this + 4 >> 2] = $6;
  HEAP32[$this >> 2] = $newsp;
  var $_idx_val = HEAP32[HEAP32[$1 >> 2] + 16 >> 2];
  var $10 = __ZNK2js10StackFrame4prevEv($_idx_val);
  HEAP32[$1 >> 2] = $10;
  return;
}

function __ZNK2js10StackFrame15constructorThisEv($this) {
  var $1 = __ZNK2js10StackFrame10formalArgsEv($this);
  var $_idx = $1 - 8 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $2 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
  return $2;
}

function __ZN2js17PreserveRegsGuardC2EP9JSContextRNS_9FrameRegsE($this, $cx, $regs) {
  var $1 = $this | 0;
  var $2 = $cx;
  var $3 = __ZNK9JSContext9maybeRegsEv($2);
  HEAP32[$1 >> 2] = $3;
  HEAP32[$this + 4 >> 2] = $cx;
  HEAP32[$this + 8 >> 2] = $regs;
  var $_idx_val = HEAP32[$cx + 60 >> 2];
  __ZN2js12ContextStack11repointRegsEPNS_9FrameRegsE($_idx_val, $regs);
  return;
}

function __ZN2js17ExecuteFrameGuardD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js10FrameGuardD2Ev($1);
  return;
}

function __ZN2js10FrameGuardD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK2js10FrameGuard6pushedEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this_idx_val;
    var $4 = $this;
    __ZN2js12ContextStack8popFrameERKNS_10FrameGuardE($3, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17ExecuteFrameGuardC2Ev($this) {
  var $1 = $this | 0;
  __ZN2js10FrameGuardC2Ev($1);
  return;
}

function __ZN2js16InvokeFrameGuardD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js10FrameGuardD2Ev($1);
  return;
}

function __ZN2js16InvokeFrameGuardC2Ev($this) {
  var $1 = $this | 0;
  __ZN2js10FrameGuardC2Ev($1);
  return;
}

function __ZL17iterator_finalizeP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $2 = __ZNK8JSObject17getNativeIteratorEv($_idx_val);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN9JSContext5free_EPv($5);
    __ZN8JSObject17setNativeIteratorEPN2js14NativeIteratorE($obj, 0);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14iterator_traceP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $2 = __ZNK8JSObject17getNativeIteratorEv($_idx_val);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN2js14NativeIterator4markEP8JSTracer($5, $trc);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14NativeIterator4markEP8JSTracer($this, $trc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx1_val = HEAP32[$this + 4 >> 2];
    var $1 = __ZNK2js14NativeIterator5beginEv($this_idx1_val);
    var $this_idx_val = HEAP32[$this + 12 >> 2];
    var $2 = __ZNK2js14NativeIterator3endEv($this_idx_val);
    var $3 = $trc;
    __ZN2js2gc11MarkIdRangeEP8JSTracerPiS3_PKc($3, $1, $2);
    var $5 = HEAP32[$this >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($3, $8);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15VectorToIdArrayEP9JSContextRNS_12AutoIdVectorEPP9JSIdArray($cx, $props, $idap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $props;
    var $2 = __ZNK2js16AutoVectorRooterIiE6lengthEv($1);
    var $3 = $2 << 2;
    var $4 = $3 + 4 | 0;
    var $5 = $cx;
    var $6 = __ZN9JSContext7malloc_Ej($5, $4);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    HEAP32[$6 >> 2] = $2;
    var $11 = $6 + 4 | 0;
    var $12 = __ZN2js16AutoVectorRooterIiE5beginEv($1);
    var $13 = $12;
    _memcpy($11, $13, $3, 1);
    HEAP32[$idap >> 2] = $9;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($cx, $obj, $flags, $props) {
  var $1 = $flags & 24;
  var $2 = __ZL8SnapshotP9JSContextP8JSObjectjPN2js12AutoIdVectorE($cx, $obj, $1, $props);
  return $2;
}

function __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE6lengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZN2js14NativeIterator4initEP8JSObjectjjj($this, $obj, $flags, $slength, $key) {
  HEAP32[$this >> 2] = $obj;
  HEAP32[$this + 28 >> 2] = $flags;
  var $4 = HEAP32[$this + 12 >> 2];
  HEAP32[$this + 16 >> 2] = $4;
  HEAP32[$this + 20 >> 2] = $slength;
  HEAP32[$this + 24 >> 2] = $key;
  return;
}

function __ZL18RegisterEnumeratorP9JSContextP8JSObjectPN2js14NativeIteratorE($cx, $iterobj, $ni) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $ni + 28 | 0;
    if ((HEAP32[$1 >> 2] & 1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx + 284 | 0;
    var $7 = HEAP32[$6 >> 2];
    HEAP32[$ni + 32 >> 2] = $7;
    HEAP32[$6 >> 2] = $iterobj;
    var $10 = HEAP32[$1 >> 2] | 4096;
    HEAP32[$1 >> 2] = $10;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL20UpdateNativeIteratorEPNS_14NativeIteratorEP8JSObject($ni, $obj) {
  HEAP32[$ni >> 2] = $obj;
  return;
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE5clearEv($this) {
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZL7CompareIjEbPT_S1_j($a, $b, $c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = ($c + 7 | 0) >>> 3;
    var $3 = $c & 7;
    if (($3 | 0) == 0) {
      var $_01 = $a;
      var $_02 = $b;
      var $n_0 = $2;
      __label__ = 2;
      break;
    } else if (($3 | 0) == 7) {
      var $_1 = $a;
      var $_13 = $b;
      var $n_1 = $2;
      __label__ = 3;
      break;
    } else if (($3 | 0) == 6) {
      var $_2 = $a;
      var $_24 = $b;
      var $n_2 = $2;
      __label__ = 4;
      break;
    } else if (($3 | 0) == 5) {
      var $_3 = $a;
      var $_35 = $b;
      var $n_3 = $2;
      __label__ = 5;
      break;
    } else if (($3 | 0) == 4) {
      var $_4 = $a;
      var $_46 = $b;
      var $n_4 = $2;
      __label__ = 6;
      break;
    } else if (($3 | 0) == 3) {
      var $_5 = $a;
      var $_57 = $b;
      var $n_5 = $2;
      __label__ = 7;
      break;
    } else if (($3 | 0) == 2) {
      var $_6 = $a;
      var $_68 = $b;
      var $n_6 = $2;
      __label__ = 8;
      break;
    } else if (($3 | 0) == 1) {
      var $_7 = $a;
      var $_79 = $b;
      var $n_7 = $2;
      __label__ = 9;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 2:
    var $n_0;
    var $_02;
    var $_01;
    if ((HEAP32[$_01 >> 2] | 0) == (HEAP32[$_02 >> 2] | 0)) {
      var $_1 = $_01 + 4 | 0;
      var $_13 = $_02 + 4 | 0;
      var $n_1 = $n_0;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 3:
    var $n_1;
    var $_13;
    var $_1;
    if ((HEAP32[$_1 >> 2] | 0) == (HEAP32[$_13 >> 2] | 0)) {
      var $_2 = $_1 + 4 | 0;
      var $_24 = $_13 + 4 | 0;
      var $n_2 = $n_1;
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 4:
    var $n_2;
    var $_24;
    var $_2;
    if ((HEAP32[$_2 >> 2] | 0) == (HEAP32[$_24 >> 2] | 0)) {
      var $_3 = $_2 + 4 | 0;
      var $_35 = $_24 + 4 | 0;
      var $n_3 = $n_2;
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $n_3;
    var $_35;
    var $_3;
    if ((HEAP32[$_3 >> 2] | 0) == (HEAP32[$_35 >> 2] | 0)) {
      var $_4 = $_3 + 4 | 0;
      var $_46 = $_35 + 4 | 0;
      var $n_4 = $n_3;
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 6:
    var $n_4;
    var $_46;
    var $_4;
    if ((HEAP32[$_4 >> 2] | 0) == (HEAP32[$_46 >> 2] | 0)) {
      var $_5 = $_4 + 4 | 0;
      var $_57 = $_46 + 4 | 0;
      var $n_5 = $n_4;
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $n_5;
    var $_57;
    var $_5;
    if ((HEAP32[$_5 >> 2] | 0) == (HEAP32[$_57 >> 2] | 0)) {
      var $_6 = $_5 + 4 | 0;
      var $_68 = $_57 + 4 | 0;
      var $n_6 = $n_5;
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 8:
    var $n_6;
    var $_68;
    var $_6;
    if ((HEAP32[$_6 >> 2] | 0) == (HEAP32[$_68 >> 2] | 0)) {
      var $_7 = $_6 + 4 | 0;
      var $_79 = $_68 + 4 | 0;
      var $n_7 = $n_6;
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 9:
    var $n_7;
    var $_79;
    var $_7;
    if ((HEAP32[$_7 >> 2] | 0) == (HEAP32[$_79 >> 2] | 0)) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $53 = $n_7 - 1 | 0;
    if (($53 | 0) == 0) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      var $_01 = $_7 + 4 | 0;
      var $_02 = $_79 + 4 | 0;
      var $n_0 = $53;
      __label__ = 2;
      break;
    }
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL7CompareIjEbPT_S1_j["X"] = 1;

function __ZL8SnapshotP9JSContextP8JSObjectjPN2js12AutoIdVectorE($cx, $obj, $flags, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 104;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ht = __stackBase__;
    var $1 = __stackBase__ + 28;
    var $proxyProps = __stackBase__ + 32;
    var $state = __stackBase__ + 92;
    var $id = __stackBase__ + 100;
    var $2 = $1;
    var $3 = $cx;
    __ZN2js15TempAllocPolicyC1EP9JSContext($2, $3);
    var $_0_val = HEAP32[$1 >> 2];
    __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEEC1ES2_($ht, $_0_val);
    var $4 = __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE4initEj($ht);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 34;
      break;
    }
   case 2:
    var $6 = ($flags & 8 | 0) == 0;
    var $_lobit = $flags >>> 4 & 1;
    var $cx_idx = $cx + 52 | 0;
    var $state_idx7 = $state | 0;
    var $pobj_0 = $obj;
    __label__ = 3;
    break;
   case 3:
    var $pobj_0;
    var $_idx = $pobj_0 + 4 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $10 = __ZNK8JSObject8getClassEv($_idx_val);
    var $_idx1_val = HEAP32[$pobj_0 >> 2];
    var $11 = __ZNK8JSObject8isNativeEv($_idx1_val);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $13 = __ZNK8JSObject6getOpsEv($_idx_val);
    if ((HEAP32[$13 + 112 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    if ((HEAP32[$10 + 4 >> 2] & 2 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $25 = HEAP32[$10 + 24 >> 2];
    var $26 = FUNCTION_TABLE[$25]($cx, $pobj_0);
    if (($26 | 0) == 0) {
      var $_1 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $29 = __ZL25EnumerateNativePropertiesP9JSContextP8JSObjectS2_jRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE($pobj_0, $flags, $ht, $props);
    if ($29 & $6) {
      __label__ = 28;
      break;
    } else {
      var $_1 = $29;
      __label__ = 34;
      break;
    }
   case 8:
    var $31 = __ZNK8JSObject12isDenseArrayEv($_idx_val);
    if ($31) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $cx_idx_val_idx_val = HEAP32[HEAP32[$cx_idx >> 2] + 210256 >> 2];
    var $33 = __ZL29EnumerateDenseArrayPropertiesP9JSContextP8JSObjectS2_jRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE($cx_idx_val_idx_val, $pobj_0, $flags, $ht, $props);
    if ($33 & $6) {
      __label__ = 28;
      break;
    } else {
      var $_1 = $33;
      __label__ = 34;
      break;
    }
   case 10:
    var $35 = __ZNK8JSObject7isProxyEv($_idx_val);
    if ($35) {
      __label__ = 11;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 11:
    var $37 = $pobj_0;
    var $38 = $proxyProps;
    __ZN2js12AutoIdVectorC1EP9JSContext($38, $3);
    if ($6) {
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (($flags & 16 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $43 = __ZN2js7JSProxy19getOwnPropertyNamesEP9JSContextP8JSObjectRNS_12AutoIdVectorE($3, $37, $38);
    if ($43) {
      __label__ = 16;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 14:
    var $45 = __ZN2js7JSProxy4keysEP9JSContextP8JSObjectRNS_12AutoIdVectorE($3, $37, $38);
    if ($45) {
      __label__ = 16;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 15:
    var $47 = __ZN2js7JSProxy9enumerateEP9JSContextP8JSObjectRNS_12AutoIdVectorE($3, $37, $38);
    if ($47) {
      __label__ = 16;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 16:
    var $49 = $proxyProps;
    var $50 = __ZNK2js16AutoVectorRooterIiE6lengthEv($49);
    var $n_0 = 0;
    __label__ = 17;
    break;
   case 17:
    var $n_0;
    if ($n_0 >>> 0 < $50 >>> 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 18:
    var $54 = __ZN2js16AutoVectorRooterIiEixEj($49, $n_0);
    var $55 = HEAP32[$54 >> 2];
    var $56 = __ZL9EnumerateP9JSContextP8JSObjectS2_ibjRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE($pobj_0, $55, 1, $flags, $ht, $props);
    if ($56) {
      __label__ = 19;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 19:
    var $n_0 = $n_0 + 1 | 0;
    __label__ = 17;
    break;
   case 20:
    __ZN2js12AutoIdVectorD1Ev($38);
    var $_1 = 1;
    __label__ = 34;
    break;
   case 21:
    var $61 = __ZN8JSObject9enumerateEP9JSContext11JSIterateOpPN2JS5ValueEPi($pobj_0, $cx, $_lobit, $state, 0);
    if (($61 | 0) == 0) {
      var $_1 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $st$0$0 = $state_idx7 | 0;
    var $state_idx7_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $state_idx7 + 4 | 0;
    var $state_idx7_val$1 = HEAP32[$st$0$1 >> 2];
    var $64 = __ZNK2JS5Value7isMagicE10JSWhyMagic($state_idx7_val$0, $state_idx7_val$1);
    if ($64) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $66 = __ZL25EnumerateNativePropertiesP9JSContextP8JSObjectS2_jRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE($pobj_0, $flags, $ht, $props);
    if ($66 & $6) {
      __label__ = 28;
      break;
    } else {
      var $_1 = $66;
      __label__ = 34;
      break;
    }
   case 24:
    var $67 = __ZN8JSObject9enumerateEP9JSContext11JSIterateOpPN2JS5ValueEPi($pobj_0, $cx, 2, $state, $id);
    if (($67 | 0) == 0) {
      var $_1 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $st$0$0 = $state_idx7 | 0;
    var $state_idx_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $state_idx7 + 4 | 0;
    var $state_idx_val$1 = HEAP32[$st$0$1 >> 2];
    var $70 = __ZNK2JS5Value6isNullEv($state_idx_val$0, $state_idx_val$1);
    if ($70) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $72 = HEAP32[$id >> 2];
    var $73 = __ZL9EnumerateP9JSContextP8JSObjectS2_ibjRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE($pobj_0, $72, 1, $flags, $ht, $props);
    if ($73) {
      __label__ = 24;
      break;
    } else {
      var $_1 = 0;
      __label__ = 34;
      break;
    }
   case 27:
    if ($6) {
      __label__ = 28;
      break;
    } else {
      var $_1 = 1;
      __label__ = 34;
      break;
    }
   case 28:
    var $_idx5_val = HEAP32[$_idx >> 2];
    var $76 = __ZNK8JSObject5isXMLEv($_idx5_val);
    if ($76) {
      var $_1 = 1;
      __label__ = 34;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $_idx4_val_idx_val = HEAP32[HEAP32[$pobj_0 + 36 >> 2] >> 2];
    var $79 = __ZNK8JSObject8getProtoEv($_idx4_val_idx_val);
    var $80 = $79;
    if (($79 | 0) == 0) {
      var $_1 = 1;
      __label__ = 34;
      break;
    } else {
      var $pobj_0 = $80;
      __label__ = 3;
      break;
    }
   case 30:
    __ZN2js12AutoIdVectorD1Ev($38);
    var $_1 = 0;
    __label__ = 34;
    break;
   case 31:
    __ZN2js12AutoIdVectorD1Ev($38);
    var $_1 = 0;
    __label__ = 34;
    break;
   case 32:
    __ZN2js12AutoIdVectorD1Ev($38);
    var $_1 = 0;
    __label__ = 34;
    break;
   case 33:
    __ZN2js12AutoIdVectorD1Ev($38);
    var $_1 = 0;
    __label__ = 34;
    break;
   case 34:
    var $_1;
    __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEED1Ev($ht);
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL8SnapshotP9JSContextP8JSObjectjPN2js12AutoIdVectorE["X"] = 1;

function __ZN2js14NativeIterator16allocateIteratorEP9JSContextjRKNS_12AutoIdVectorE($cx, $slength, $props) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $props | 0;
    var $2 = $props;
    var $3 = __ZNK2js16AutoVectorRooterIiE6lengthEv($2);
    var $4 = $3 << 2;
    var $7 = ($slength << 2) + 36 + $4 | 0;
    var $8 = $cx;
    var $9 = __ZN9JSContext7malloc_Ej($8, $7);
    var $10 = $9;
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = $9 + 36 | 0;
    var $14 = $13;
    HEAP32[$9 + 8 >> 2] = $14;
    HEAP32[$9 + 4 >> 2] = $14;
    HEAP32[$9 + 12 >> 2] = $14 + ($3 << 2) | 0;
    if (($3 | 0) == 0) {
      var $_0 = $10;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $24 = __ZNK2js16AutoVectorRooterIiE5beginEv($1);
    var $25 = $24;
    _memcpy($13, $25, $4, 1);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js16AutoVectorRooterIiE5beginEv($this) {
  var $_idx_val = HEAP32[$this + 16 >> 2];
  var $2 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE5beginEv($_idx_val);
  return $2;
}

function __ZN2js19VectorToKeyIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE($cx, $obj, $flags, $props, $vp) {
  var $1 = __ZL19VectorToKeyIteratorP9JSContextP8JSObjectjRN2js12AutoIdVectorEjjPN2JS5ValueE($cx, $obj, $flags, $props, 0, 0, $vp);
  return $1;
}

function __ZL19VectorToKeyIteratorP9JSContextP8JSObjectjRN2js12AutoIdVectorEjjPN2JS5ValueE($cx, $obj, $flags, $keys, $slength, $key, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $obj + 8 | 0;
    var $5 = HEAP32[$3 >> 2] | 32768;
    HEAP32[$3 >> 2] = $5;
    var $6 = $cx;
    var $7 = $obj;
    __ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj($6, $7, 4194304);
    __label__ = 3;
    break;
   case 3:
    var $9 = __ZL17NewIteratorObjectP9JSContextj($cx, $flags);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = __ZN2js14NativeIterator16allocateIteratorEP9JSContextjRKNS_12AutoIdVectorE($cx, $slength, $keys);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js14NativeIterator4initEP8JSObjectjjj($12, $obj, $flags, $slength, $key);
    if (($slength | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = $12 + 16 | 0;
    var $ind_0 = 0;
    var $pobj_0 = $obj;
    __label__ = 7;
    break;
   case 7:
    var $pobj_0;
    var $ind_0;
    var $_idx1_val = HEAP32[$pobj_0 + 12 >> 2];
    var $19 = __ZNK8JSObject5shapeEv($_idx1_val);
    var $20 = $ind_0 + 1 | 0;
    var $22 = HEAP32[$16 >> 2] + ($ind_0 << 2) | 0;
    HEAP32[$22 >> 2] = $19;
    var $_idx_val_idx_val = HEAP32[HEAP32[$pobj_0 + 36 >> 2] >> 2];
    var $24 = __ZNK8JSObject8getProtoEv($_idx_val_idx_val);
    var $25 = $24;
    if (($24 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $ind_0 = $20;
      var $pobj_0 = $25;
      __label__ = 7;
      break;
    }
   case 8:
    __ZN8JSObject17setNativeIteratorEPN2js14NativeIteratorE($9, $12);
    var $27 = $9;
    __ZN2JS5Value9setObjectER8JSObject($vp, $27);
    __ZL18RegisterEnumeratorP9JSContextP8JSObjectPN2js14NativeIteratorE($cx, $9, $12);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js21VectorToValueIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE($cx, $obj, $flags, $keys, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $obj + 8 | 0;
    var $5 = HEAP32[$3 >> 2] | 32768;
    HEAP32[$3 >> 2] = $5;
    var $6 = $cx;
    var $7 = $obj;
    __ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj($6, $7, 4194304);
    __label__ = 3;
    break;
   case 3:
    var $9 = __ZL17NewIteratorObjectP9JSContextj($cx, $flags);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = __ZN2js14NativeIterator16allocateIteratorEP9JSContextjRKNS_12AutoIdVectorE($cx, 0, $keys);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js14NativeIterator4initEP8JSObjectjjj($12, $obj, $flags, 0, 0);
    __ZN8JSObject17setNativeIteratorEPN2js14NativeIteratorE($9, $12);
    var $15 = $9;
    __ZN2JS5Value9setObjectER8JSObject($vp, $15);
    __ZL18RegisterEnumeratorP9JSContextP8JSObjectPN2js14NativeIteratorE($cx, $9, $12);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17NewIteratorObjectP9JSContextj($cx, $flags) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($flags & 1 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($4, 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZN2js10EmptyShape23getEmptyEnumeratorShapeEP9JSContext($cx);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($5, __ZN2js13IteratorClassE, __ZN2js5types15emptyTypeObjectE, 0, 0, 0);
    var $12 = $9;
    __ZN8JSObject6setMapEPN2js5ShapeE($5, $12);
    var $_0 = $6;
    __label__ = 6;
    break;
   case 5:
    var $14 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE1991($cx);
    var $_0 = $14;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject17setNativeIteratorEPN2js14NativeIteratorE($this, $ni) {
  var $1 = $ni;
  var $2 = $this;
  __ZN8JSObject10setPrivateEPv($2, $1);
  return;
}

function __ZN2js28EnumeratedIdVectorToIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE($cx, $obj, $flags, $props, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($flags & 2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js19VectorToKeyIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE($cx, $obj, $flags, $props, $vp);
    var $_0 = $4;
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN2js21VectorToValueIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE($cx, $obj, $flags, $props, $vp);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11GetIteratorEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $obj, $flags, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 112;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $shapes = __stackBase__;
    var $1 = __stackBase__ + 48;
    var $keys = __stackBase__ + 52;
    var $2 = $cx;
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $2);
    var $3 = $shapes;
    var $_014_val = HEAP32[$1 >> 2];
    __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEC1ES1_($3, $_014_val);
    var $4 = ($flags | 0) == 1;
    var $5 = ($obj | 0) != 0;
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $key_2 = 0;
      __label__ = 35;
      break;
    }
   case 2:
    var $7 = $obj;
    var $_idx2 = $obj + 4 | 0;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $9 = __ZNK8JSObject8getClassEv($_idx2_val);
    var $11 = HEAP32[$9 + 80 >> 2];
    var $12 = $11;
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($9 | 0) == (__ZN2js13IteratorClassE | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx17_val = HEAP32[$obj + 24 >> 2];
    var $18 = __ZNK8JSObject17getNativeIteratorEv($_idx17_val);
    if (($18 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $22 = $flags >>> 1 & 1 ^ 1;
    var $23 = FUNCTION_TABLE[$12]($cx, $obj, $22);
    if (($23 | 0) == 0) {
      var $_1 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $26 = $23;
    __ZN2JS5Value9setObjectER8JSObject($vp, $26);
    __ZN2js5types19MarkIteratorUnknownEP9JSContext($cx);
    var $_1 = 1;
    __label__ = 48;
    break;
   case 7:
    if ($4) {
      __label__ = 8;
      break;
    } else {
      var $key_1 = 0;
      __label__ = 30;
      break;
    }
   case 8:
    var $29 = $cx + 56 | 0;
    var $32 = HEAPU32[HEAP32[$29 >> 2] + 1832 >> 2];
    var $_idx9_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $34 = __ZNK8JSObject8getProtoEv($_idx9_val_idx_val);
    if (($32 | 0) == 0) {
      var $pobj_0 = $obj;
      var $key_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $37 = $32;
    var $_idx16_val = HEAP32[$32 + 24 >> 2];
    var $39 = __ZNK8JSObject17getNativeIteratorEv($_idx16_val);
    var $40 = $39;
    if ((HEAP32[$39 + 28 >> 2] & 12288 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $pobj_0 = $obj;
      var $key_0 = 0;
      __label__ = 16;
      break;
    }
   case 10:
    var $_idx5_val = HEAP32[$obj >> 2];
    var $46 = __ZNK8JSObject8isNativeEv($_idx5_val);
    if ($46) {
      __label__ = 11;
      break;
    } else {
      var $pobj_0 = $obj;
      var $key_0 = 0;
      __label__ = 16;
      break;
    }
   case 11:
    var $_idx13_val = HEAP32[$obj + 12 >> 2];
    var $49 = __ZNK8JSObject5shapeEv($_idx13_val);
    var $51 = HEAP32[$39 + 16 >> 2];
    if (($49 | 0) != (HEAP32[$51 >> 2] | 0) | ($34 | 0) == 0) {
      var $pobj_0 = $obj;
      var $key_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $_idx4_val = HEAP32[$34 >> 2];
    var $56 = __ZNK8JSObject8isNativeEv($_idx4_val);
    if ($56) {
      __label__ = 13;
      break;
    } else {
      var $pobj_0 = $obj;
      var $key_0 = 0;
      __label__ = 16;
      break;
    }
   case 13:
    var $_idx12_val = HEAP32[$34 + 12 >> 2];
    var $58 = __ZNK8JSObject5shapeEv($_idx12_val);
    if (($58 | 0) == (HEAP32[$51 + 4 >> 2] | 0)) {
      __label__ = 14;
      break;
    } else {
      var $pobj_0 = $obj;
      var $key_0 = 0;
      __label__ = 16;
      break;
    }
   case 14:
    var $_idx8_val_idx_val = HEAP32[HEAP32[$34 + 36 >> 2] >> 2];
    var $63 = __ZNK8JSObject8getProtoEv($_idx8_val_idx_val);
    if (($63 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      var $pobj_0 = $obj;
      var $key_0 = 0;
      __label__ = 16;
      break;
    }
   case 15:
    __ZN2JS5Value9setObjectER8JSObject($vp, $37);
    __ZN2jsL20UpdateNativeIteratorEPNS_14NativeIteratorEP8JSObject($40, $obj);
    __ZL18RegisterEnumeratorP9JSContextP8JSObjectPN2js14NativeIteratorE($cx, $32, $40);
    var $_1 = 1;
    __label__ = 48;
    break;
   case 16:
    var $key_0;
    var $pobj_0;
    var $_idx3_val = HEAP32[$pobj_0 >> 2];
    var $66 = __ZNK8JSObject8isNativeEv($_idx3_val);
    if ($66) {
      __label__ = 17;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 17:
    var $_idx6_val = HEAP32[$_idx2 >> 2];
    var $69 = __ZNK8JSObject6getOpsEv($_idx6_val);
    if ((HEAP32[$69 + 112 >> 2] | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $_idx_val = HEAP32[$pobj_0 + 4 >> 2];
    var $75 = __ZNK8JSObject8getClassEv($_idx_val);
    if ((HEAP32[$75 + 24 >> 2] | 0) == 144) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE5clearEv($shapes);
    var $key_1 = $key_0;
    __label__ = 30;
    break;
   case 20:
    var $_idx11_val = HEAP32[$pobj_0 + 12 >> 2];
    var $82 = __ZNK8JSObject5shapeEv($_idx11_val);
    var $84 = $82 ^ $key_0 * 65537;
    var $85 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE6appendIjEEbT_($shapes, $82);
    if ($85) {
      __label__ = 21;
      break;
    } else {
      var $_1 = 0;
      __label__ = 48;
      break;
    }
   case 21:
    var $_idx7_val_idx_val = HEAP32[HEAP32[$pobj_0 + 36 >> 2] >> 2];
    var $88 = __ZNK8JSObject8getProtoEv($_idx7_val_idx_val);
    if (($88 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $pobj_0 = $88;
    var $key_0 = $84;
    __label__ = 16;
    break;
   case 23:
    var $93 = HEAP32[$29 >> 2] + 808 | 0;
    var $94 = __ZNK2js15NativeIterCache3getEj($93, $84);
    if (($94 | 0) == 0) {
      var $key_1 = $84;
      __label__ = 30;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $97 = $94;
    var $_idx15_val = HEAP32[$94 + 24 >> 2];
    var $99 = __ZNK8JSObject17getNativeIteratorEv($_idx15_val);
    var $100 = $99;
    if ((HEAP32[$99 + 28 >> 2] & 12288 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      var $key_1 = $84;
      __label__ = 30;
      break;
    }
   case 25:
    if ((HEAP32[$99 + 24 >> 2] | 0) == ($84 | 0)) {
      __label__ = 26;
      break;
    } else {
      var $key_1 = $84;
      __label__ = 30;
      break;
    }
   case 26:
    var $111 = HEAP32[$99 + 20 >> 2];
    var $shapes_idx21 = $shapes + 8 | 0;
    var $shapes_idx21_val = HEAP32[$shapes_idx21 >> 2];
    var $112 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE6lengthEv($shapes_idx21_val);
    if (($111 | 0) == ($112 | 0)) {
      __label__ = 27;
      break;
    } else {
      var $key_1 = $84;
      __label__ = 30;
      break;
    }
   case 27:
    var $116 = HEAP32[$99 + 16 >> 2];
    var $shapes_idx22_val = HEAP32[$shapes + 4 >> 2];
    var $117 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE5beginEv($shapes_idx22_val);
    var $118 = __ZL7CompareIjEbPT_S1_j($116, $117, $111);
    if ($118) {
      __label__ = 28;
      break;
    } else {
      var $key_1 = $84;
      __label__ = 30;
      break;
    }
   case 28:
    __ZN2JS5Value9setObjectER8JSObject($vp, $97);
    __ZN2jsL20UpdateNativeIteratorEPNS_14NativeIteratorEP8JSObject($100, $obj);
    __ZL18RegisterEnumeratorP9JSContextP8JSObjectPN2js14NativeIteratorE($cx, $94, $100);
    var $shapes_idx20_val = HEAP32[$shapes_idx21 >> 2];
    var $120 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE6lengthEv($shapes_idx20_val);
    if (($120 | 0) == 2) {
      __label__ = 29;
      break;
    } else {
      var $_1 = 1;
      __label__ = 48;
      break;
    }
   case 29:
    var $124 = HEAP32[$29 >> 2] + 1832 | 0;
    HEAP32[$124 >> 2] = $94;
    var $_1 = 1;
    __label__ = 48;
    break;
   case 30:
    var $key_1;
    var $_idx10_val = HEAP32[$_idx2 >> 2];
    var $126 = __ZNK8JSObject7isProxyEv($_idx10_val);
    if ($126) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    __ZN2js5types19MarkIteratorUnknownEP9JSContext($cx);
    var $128 = __ZN2js7JSProxy7iterateEP9JSContextP8JSObjectjPN2JS5ValueE($2, $7, $flags, $vp);
    var $_1 = $128;
    __label__ = 48;
    break;
   case 32:
    var $130 = __ZL17GetCustomIteratorP9JSContextP8JSObjectjPN2JS5ValueE($cx, $obj, $flags, $vp);
    if ($130) {
      __label__ = 33;
      break;
    } else {
      var $_1 = 0;
      __label__ = 48;
      break;
    }
   case 33:
    var $vp_idx1 = $vp | 0;
    var $vp_idx1_val$0 = HEAP32[$vp_idx1 >> 2];
    var $vp_idx1_val$1 = HEAP32[$vp_idx1 + 4 >> 2];
    var $132 = __ZNK2JS5Value11isUndefinedEv($vp_idx1_val$0, $vp_idx1_val$1);
    if ($132) {
      var $key_2 = $key_1;
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    __ZN2js5types19MarkIteratorUnknownEP9JSContext($cx);
    var $_1 = 1;
    __label__ = 48;
    break;
   case 35:
    var $key_2;
    var $135 = $keys;
    __ZN2js12AutoIdVectorC1EP9JSContext($135, $2);
    if (($flags & 2 | 0) == 0) {
      __label__ = 40;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    if ($5) {
      __label__ = 37;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 37:
    var $140 = __ZL8SnapshotP9JSContextP8JSObjectjPN2js12AutoIdVectorE($cx, $obj, $flags, $keys);
    if ($140) {
      __label__ = 38;
      break;
    } else {
      var $_0 = 0;
      __label__ = 47;
      break;
    }
   case 38:
    var $142 = __ZN2js21VectorToValueIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE($cx, $obj, $flags, $keys, $vp);
    if ($142) {
      __label__ = 39;
      break;
    } else {
      var $_0 = 0;
      __label__ = 47;
      break;
    }
   case 39:
    var $shapes_idx18_pre_phi = $shapes + 8 | 0;
    __label__ = 43;
    break;
   case 40:
    if ($5) {
      __label__ = 41;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 41:
    var $145 = __ZL8SnapshotP9JSContextP8JSObjectjPN2js12AutoIdVectorE($cx, $obj, $flags, $keys);
    if ($145) {
      __label__ = 42;
      break;
    } else {
      var $_0 = 0;
      __label__ = 47;
      break;
    }
   case 42:
    var $shapes_idx19 = $shapes + 8 | 0;
    var $shapes_idx19_val = HEAP32[$shapes_idx19 >> 2];
    var $147 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE6lengthEv($shapes_idx19_val);
    var $148 = __ZL19VectorToKeyIteratorP9JSContextP8JSObjectjRN2js12AutoIdVectorEjjPN2JS5ValueE($cx, $obj, $flags, $keys, $147, $key_2, $vp);
    if ($148) {
      var $shapes_idx18_pre_phi = $shapes_idx19;
      __label__ = 43;
      break;
    } else {
      var $_0 = 0;
      __label__ = 47;
      break;
    }
   case 43:
    var $shapes_idx18_pre_phi;
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $150 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
    var $151 = $150;
    var $shapes_idx18_val = HEAP32[$shapes_idx18_pre_phi >> 2];
    var $152 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE6lengthEv($shapes_idx18_val);
    if (($152 | 0) == 0) {
      var $shapes_idx_val = $shapes_idx18_val;
      __label__ = 45;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $157 = HEAP32[$cx + 56 >> 2] + 808 | 0;
    __ZN2js15NativeIterCache3setEjP8JSObject($157, $key_2, $151);
    var $shapes_idx_val = HEAP32[$shapes_idx18_pre_phi >> 2];
    __label__ = 45;
    break;
   case 45:
    var $shapes_idx_val;
    var $159 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE6lengthEv($shapes_idx_val);
    if (($159 | 0) == 2) {
      __label__ = 46;
      break;
    } else {
      var $_0 = 1;
      __label__ = 47;
      break;
    }
   case 46:
    var $164 = HEAP32[$cx + 56 >> 2] + 1832 | 0;
    HEAP32[$164 >> 2] = $151;
    var $_0 = 1;
    __label__ = 47;
    break;
   case 47:
    var $_0;
    __ZN2js12AutoIdVectorD1Ev($135);
    var $_1 = $_0;
    __label__ = 48;
    break;
   case 48:
    var $_1;
    __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEED1Ev($3);
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11GetIteratorEP9JSContextP8JSObjectjPN2JS5ValueE["X"] = 1;

function __ZN2js5types19MarkIteratorUnknownEP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP8[$cx + 232 | 0];
    var $2 = __ZN9JSContext20typeInferenceEnabledEv($_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $cx;
    __ZN2js5types23MarkIteratorUnknownSlowEP9JSContext($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE6appendIjEEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $this;
    var $8 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE13growStorageByEj($7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE14internalAppendIjEEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js15NativeIterCache3getEj($this, $key) {
  var $1 = __ZN2js15NativeIterCache8getIndexEj($key);
  return HEAP32[$this + ($1 << 2) >> 2];
}

function __ZNK8JSObject11isGeneratorEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js14GeneratorClassE | 0);
}

function __ZN2js13StaticStrings6hasIntEi($i) {
  return $i >>> 0 < 256;
}

function __ZL17GetCustomIteratorP9JSContextP8JSObjectjPN2JS5ValueE($cx, $obj, $flags, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $arg = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $bytes = __stackBase__ + 16;
    var $2 = __stackBase__ + 20;
    var $7 = HEAP32[HEAP32[$cx + 52 >> 2] + 210244 >> 2] | 0;
    var $8 = __ZL12ATOM_TO_JSIDP6JSAtom1935($7);
    var $9 = $cx;
    var $10 = $obj;
    var $11 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($9, $10, $8, 2, $vp);
    if (($11 | 0) == 0) {
      var $_1 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $14 = __ZNK2JS5Value8isObjectEv($vp_idx_val$0, $vp_idx_val$1);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_1 = 1;
    __label__ = 12;
    break;
   case 4:
    var $17 = $cx;
    var $18 = __ZNK9JSContext28runningWithTrustedPrincipalsEv($17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $21 = HEAP32[_sCustomIteratorCount >> 2] + 1 | 0;
    HEAP32[_sCustomIteratorCount >> 2] = $21;
    __label__ = 6;
    break;
   case 6:
    var $24 = ($flags & 2 | 0) == 0;
    __ZN2JSL12BooleanValueEb1988($arg, $24);
    __ZN2JSL11ObjectValueER8JSObject1936($1, $obj);
    var $25 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($17, $1, $vp, 1, $arg, $vp);
    if ($25) {
      __label__ = 7;
      break;
    } else {
      var $_1 = 0;
      __label__ = 12;
      break;
    }
   case 7:
    var $vp_idx1_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx1_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $27 = __ZNK2JS5Value11isPrimitiveEv($vp_idx1_val$0, $vp_idx1_val$1);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      var $_1 = 1;
      __label__ = 12;
      break;
    }
   case 8:
    __ZN16JSAutoByteStringC1Ev($bytes);
    var $29 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($17, $7, $bytes);
    if (($29 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $bytes_idx_val = HEAP32[$bytes >> 2];
    __label__ = 11;
    break;
   case 10:
    __ZN2JSL11ObjectValueER8JSObject1936($2, $obj);
    var $bytes_idx2_val = HEAP32[$bytes >> 2];
    var $32 = __ZNK16JSAutoByteString3ptrEv($bytes_idx2_val);
    var $_idx = $2 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $33 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($17, 0, 212, -1, $_idx_val$0, $_idx_val$1, 0, $32);
    var $bytes_idx_val = $bytes_idx2_val;
    __label__ = 11;
    break;
   case 11:
    var $bytes_idx_val;
    __ZN16JSAutoByteStringD1Ev($bytes_idx_val);
    var $_1 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17GetCustomIteratorP9JSContextP8JSObjectjPN2JS5ValueE["X"] = 1;

function __ZN2js15NativeIterCache3setEjP8JSObject($this, $key, $iterobj) {
  var $1 = __ZN2js15NativeIterCache8getIndexEj($key);
  HEAP32[$this + ($1 << 2) >> 2] = $iterobj;
  return;
}

function __Z21js_ThrowStopIterationP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $cx;
    var $2 = __Z18js_FindClassObjectP9JSContextP8JSObject10JSProtoKeyPN2JS5ValueEPN2js5ClassE($1, 0, 23, $v, 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $v | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $cx;
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($7, $6$0, $6$1);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13iterator_nextP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $7 = __ZNK8JSObject10isIteratorEv($_idx_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($2, $vp, __ZN2js13IteratorClassE);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 4:
    var $10 = __Z15js_IteratorMoreP9JSContextP8JSObjectPN2JS5ValueE($cx, $4, $vp);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $13 = __ZNK2JS5Value9toBooleanEv($vp_idx_val$0, $vp_idx_val$1);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __Z21js_ThrowStopIterationP9JSContext($cx);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 7:
    var $16 = __Z15js_IteratorNextP9JSContextP8JSObjectPN2JS5ValueE($cx, $4, $vp);
    var $_0 = $16;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18js_ValueToIteratorP9JSContextjPN2JS5ValueE($cx, $flags, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = $cx + 224 | 0;
    __ZN2JS5Value8setMagicE10JSWhyMagic($1, 3);
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $2 = __ZNK2JS5Value8isObjectEv($vp_idx_val$0, $vp_idx_val$1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
    var $5 = $4;
    HEAP32[$obj >> 2] = $5;
    var $19 = $5;
    __label__ = 7;
    break;
   case 3:
    var $9 = $cx;
    if (($flags & 1 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $obj;
    var $12 = __Z22js_ValueToObjectOrNullP9JSContextRKN2JS5ValueEPP8JSObject($9, $vp, $11);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = HEAP32[$obj >> 2];
    __label__ = 7;
    break;
   case 6:
    var $15 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($9, $vp);
    var $16 = $15;
    HEAP32[$obj >> 2] = $16;
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      var $19 = $16;
      __label__ = 7;
      break;
    }
   case 7:
    var $19;
    var $20 = __ZN2js11GetIteratorEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $19, $flags, $vp);
    var $_0 = $20 & 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_CloseIteratorP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 224 | 0;
    __ZN2JS5Value8setMagicE10JSWhyMagic($1, 3);
    var $2 = HEAP32[$obj + 4 >> 2];
    var $_idx1_val = $2;
    var $3 = __ZNK8JSObject10isIteratorEv($_idx1_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $6 = __ZNK8JSObject17getNativeIteratorEv($_idx_val);
    var $7 = $6 + 28 | 0;
    if ((HEAP32[$7 >> 2] & 1 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = HEAP32[$6 + 32 >> 2];
    HEAP32[$cx + 284 >> 2] = $14;
    var $17 = HEAP32[$7 >> 2] & -4097;
    HEAP32[$7 >> 2] = $17;
    var $19 = HEAP32[$6 + 4 >> 2];
    var $20 = $6 + 8 | 0;
    HEAP32[$20 >> 2] = $19;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 4:
    var $22 = __ZNK8JSObject11isGeneratorEv($2);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 5:
    var $24 = __ZL14CloseGeneratorP9JSContextP8JSObject($cx, $obj);
    var $_0 = $24;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14CloseGeneratorP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $3 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$3 + 4 >> 2] | 0) == 4) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JSL14UndefinedValueEv1961($1);
    var $12 = __ZL15SendToGeneratorP9JSContext13JSGeneratorOpP8JSObjectP11JSGeneratorRKN2JS5ValueE($cx, 3, $obj, $4, $1);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z26js_SuppressDeletedPropertyP9JSContextP8JSObjecti($cx, $obj, $id) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __Z22js_CheckForStringIndexi($id);
  __ZN17SingleIdPredicateC1Ei($1, $2);
  var $_0_val = HEAP32[$1 >> 2];
  var $3 = __ZL29SuppressDeletedPropertyHelperI17SingleIdPredicateEbP9JSContextP8JSObjectT_($cx, $obj, $_0_val);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZL29SuppressDeletedPropertyHelperI17SingleIdPredicateEbP9JSContextP8JSObjectT_($cx, $obj, $predicate_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $proto = __stackBase__;
    var $obj2 = __stackBase__ + 16;
    var $prop = __stackBase__ + 32;
    var $attrs = __stackBase__ + 36;
    var $2 = $proto;
    var $3 = $cx;
    var $4 = $obj2;
    var $5 = $prop;
    var $_idx1 = $obj + 36 | 0;
    var $proto_idx = $proto + 12 | 0;
    var $obj2_idx = $obj2 + 12 | 0;
    var $iterobj_0_in = $cx + 284 | 0;
    __label__ = 2;
    break;
   case 2:
    var $iterobj_0_in;
    var $iterobj_0 = HEAP32[$iterobj_0_in >> 2];
    if (($iterobj_0 | 0) == 0) {
      var $_7 = 1;
      __label__ = 29;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $iterobj_0 + 24 | 0;
    __label__ = 4;
    break;
   case 4:
    var $_idx2_val = HEAP32[$8 >> 2];
    var $9 = __ZNK8JSObject17getNativeIteratorEv($_idx2_val);
    var $_idx3 = $9 + 28 | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $10 = __ZNK2js14NativeIterator9isKeyIterEv($_idx3_val);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 5:
    if ((HEAP32[$9 >> 2] | 0) == ($obj | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 6:
    var $16 = $9 + 8 | 0;
    var $17 = HEAPU32[$16 >> 2];
    var $18 = $9 + 12 | 0;
    var $19 = HEAPU32[$18 >> 2];
    if ($17 >>> 0 < $19 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 7:
    var $22 = __ZNK2js14NativeIterator7currentEv($17);
    var $23 = __ZNK2js14NativeIterator3endEv($19);
    var $idp_0 = $22;
    __label__ = 8;
    break;
   case 8:
    var $idp_0;
    if ($idp_0 >>> 0 < $23 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 9:
    var $27 = HEAP32[$idp_0 >> 2];
    var $28 = __ZN17SingleIdPredicateclEi($predicate_0, $27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 10:
    var $_idx1_val_idx_val = HEAP32[HEAP32[$_idx1 >> 2] >> 2];
    var $31 = __ZNK8JSObject8getProtoEv($_idx1_val_idx_val);
    if (($31 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($2, $3, $31);
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($4, $3, 0);
    var $proto_idx_val = HEAP32[$proto_idx >> 2];
    var $34 = __ZNK2js16AutoObjectRooter6objectEv($proto_idx_val);
    var $35 = HEAP32[$idp_0 >> 2];
    var $36 = __ZN2js16AutoObjectRooter4addrEv($obj2);
    var $37 = $34;
    var $38 = $36;
    var $39 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($37, $3, $35, $38, $5);
    if (($39 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $42 = HEAP32[$prop >> 2];
    if (($42 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $obj2_idx_val = HEAP32[$obj2_idx >> 2];
    var $45 = __ZNK2js16AutoObjectRooter6objectEv($obj2_idx_val);
    var $_idx_val = HEAP32[$45 >> 2];
    var $46 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($46) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $_idx5_val = HEAP8[$42 + 28 | 0];
    var $49 = __ZNK2js5Shape10attributesEv($_idx5_val);
    var $50 = $49 & 255;
    HEAP32[$attrs >> 2] = $50;
    var $57 = $50;
    __label__ = 17;
    break;
   case 15:
    var $52 = $45;
    var $53 = HEAP32[$idp_0 >> 2];
    var $54 = __ZN8JSObject13getAttributesEP9JSContextiPj($52, $3, $53, $attrs);
    if (($54 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $57 = HEAP32[$attrs >> 2];
    __label__ = 17;
    break;
   case 17:
    var $57;
    if (($57 & 1 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 18:
    __ZN2js16AutoObjectRooterD1Ev($4);
    __ZN2js16AutoObjectRooterD1Ev($2);
    __label__ = 21;
    break;
   case 19:
    __ZN2js16AutoObjectRooterD1Ev($4);
    __ZN2js16AutoObjectRooterD1Ev($2);
    var $_7 = 0;
    __label__ = 29;
    break;
   case 20:
    __ZN2js16AutoObjectRooterD1Ev($4);
    __ZN2js16AutoObjectRooterD1Ev($2);
    __label__ = 27;
    break;
   case 21:
    if (($23 | 0) == (HEAP32[$18 >> 2] | 0)) {
      __label__ = 22;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 22:
    if (($22 | 0) == (HEAP32[$16 >> 2] | 0)) {
      __label__ = 23;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 23:
    if (($idp_0 | 0) == ($22 | 0)) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    __ZN2js14NativeIterator9incCursorEv($9);
    __label__ = 26;
    break;
   case 25:
    var $71 = $idp_0 + 4 | 0;
    var $75 = $23 - $71 | 0;
    _llvm_memmove_p0i8_p0i8_i32($idp_0, $71, $75, 1, 0);
    var $_idx6_val = HEAP32[$18 >> 2];
    var $76 = __ZNK2js14NativeIterator3endEv($_idx6_val);
    var $77 = $76 - 4 | 0;
    HEAP32[$18 >> 2] = $77;
    __label__ = 26;
    break;
   case 26:
    var $80 = HEAP32[$_idx3 >> 2] | 8192;
    HEAP32[$_idx3 >> 2] = $80;
    __label__ = 28;
    break;
   case 27:
    var $idp_0 = $idp_0 + 4 | 0;
    __label__ = 8;
    break;
   case 28:
    var $iterobj_0_in = $9 + 32 | 0;
    __label__ = 2;
    break;
   case 29:
    var $_7;
    STACKTOP = __stackBase__;
    return $_7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL29SuppressDeletedPropertyHelperI17SingleIdPredicateEbP9JSContextP8JSObjectT_["X"] = 1;

function __ZN17SingleIdPredicateC1Ei($this, $id) {
  __ZN17SingleIdPredicateC2Ei($this, $id);
  return;
}

function __Z25js_SuppressDeletedElementP9JSContextP8JSObjectj($cx, $obj, $index) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = $cx;
    var $3 = __ZN2js9IndexToIdEP9JSContextjPi($2, $index, $id);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$id >> 2];
    __ZN17SingleIdPredicateC1Ei($1, $5);
    var $_01_val = HEAP32[$1 >> 2];
    var $6 = __ZL29SuppressDeletedPropertyHelperI17SingleIdPredicateEbP9JSContextP8JSObjectT_($cx, $obj, $_01_val);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z33js_SuppressDeletedIndexPropertiesP9JSContextP8JSObjectii($cx, $obj, $begin, $end) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN19IndexRangePredicateC1Eii($1, $begin, $end);
  var $_0_val = HEAP32[$1 >> 2];
  var $_1_val = HEAP32[$1 + 4 >> 2];
  var $2 = __ZL29SuppressDeletedPropertyHelperI19IndexRangePredicateEbP9JSContextP8JSObjectT_($cx, $obj, $_0_val, $_1_val);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL29SuppressDeletedPropertyHelperI19IndexRangePredicateEbP9JSContextP8JSObjectT_($cx, $obj, $predicate_0, $predicate_1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $proto = __stackBase__;
    var $obj2 = __stackBase__ + 16;
    var $prop = __stackBase__ + 32;
    var $attrs = __stackBase__ + 36;
    var $2 = $proto;
    var $3 = $cx;
    var $4 = $obj2;
    var $5 = $prop;
    var $_idx1 = $obj + 36 | 0;
    var $proto_idx = $proto + 12 | 0;
    var $obj2_idx = $obj2 + 12 | 0;
    var $iterobj_0_in = $cx + 284 | 0;
    __label__ = 2;
    break;
   case 2:
    var $iterobj_0_in;
    var $iterobj_0 = HEAP32[$iterobj_0_in >> 2];
    if (($iterobj_0 | 0) == 0) {
      var $_7 = 1;
      __label__ = 29;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $iterobj_0 + 24 | 0;
    __label__ = 4;
    break;
   case 4:
    var $_idx2_val = HEAP32[$8 >> 2];
    var $9 = __ZNK8JSObject17getNativeIteratorEv($_idx2_val);
    var $_idx3 = $9 + 28 | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $10 = __ZNK2js14NativeIterator9isKeyIterEv($_idx3_val);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 5:
    if ((HEAP32[$9 >> 2] | 0) == ($obj | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 6:
    var $16 = $9 + 8 | 0;
    var $17 = HEAPU32[$16 >> 2];
    var $18 = $9 + 12 | 0;
    var $19 = HEAPU32[$18 >> 2];
    if ($17 >>> 0 < $19 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 7:
    var $22 = __ZNK2js14NativeIterator7currentEv($17);
    var $23 = __ZNK2js14NativeIterator3endEv($19);
    var $24 = $23;
    var $idp_0 = $22;
    __label__ = 8;
    break;
   case 8:
    var $idp_0;
    if ($idp_0 >>> 0 < $23 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 9:
    var $28 = HEAP32[$idp_0 >> 2];
    var $29 = __ZN19IndexRangePredicateclEi($predicate_0, $predicate_1, $28);
    if ($29) {
      __label__ = 10;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 10:
    var $_idx1_val_idx_val = HEAP32[HEAP32[$_idx1 >> 2] >> 2];
    var $32 = __ZNK8JSObject8getProtoEv($_idx1_val_idx_val);
    if (($32 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($2, $3, $32);
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($4, $3, 0);
    var $proto_idx_val = HEAP32[$proto_idx >> 2];
    var $35 = __ZNK2js16AutoObjectRooter6objectEv($proto_idx_val);
    var $36 = HEAP32[$idp_0 >> 2];
    var $37 = __ZN2js16AutoObjectRooter4addrEv($obj2);
    var $38 = $35;
    var $39 = $37;
    var $40 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($38, $3, $36, $39, $5);
    if (($40 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $43 = HEAP32[$prop >> 2];
    if (($43 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $obj2_idx_val = HEAP32[$obj2_idx >> 2];
    var $46 = __ZNK2js16AutoObjectRooter6objectEv($obj2_idx_val);
    var $_idx_val = HEAP32[$46 >> 2];
    var $47 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($47) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $_idx5_val = HEAP8[$43 + 28 | 0];
    var $50 = __ZNK2js5Shape10attributesEv($_idx5_val);
    var $51 = $50 & 255;
    HEAP32[$attrs >> 2] = $51;
    var $58 = $51;
    __label__ = 17;
    break;
   case 15:
    var $53 = $46;
    var $54 = HEAP32[$idp_0 >> 2];
    var $55 = __ZN8JSObject13getAttributesEP9JSContextiPj($53, $3, $54, $attrs);
    if (($55 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $58 = HEAP32[$attrs >> 2];
    __label__ = 17;
    break;
   case 17:
    var $58;
    if (($58 & 1 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 18:
    __ZN2js16AutoObjectRooterD1Ev($4);
    __ZN2js16AutoObjectRooterD1Ev($2);
    __label__ = 21;
    break;
   case 19:
    __ZN2js16AutoObjectRooterD1Ev($4);
    __ZN2js16AutoObjectRooterD1Ev($2);
    var $_7 = 0;
    __label__ = 29;
    break;
   case 20:
    __ZN2js16AutoObjectRooterD1Ev($4);
    __ZN2js16AutoObjectRooterD1Ev($2);
    __label__ = 27;
    break;
   case 21:
    if (($23 | 0) == (HEAP32[$18 >> 2] | 0)) {
      __label__ = 22;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 22:
    if (($22 | 0) == (HEAP32[$16 >> 2] | 0)) {
      __label__ = 23;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 23:
    if (($idp_0 | 0) == ($22 | 0)) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    __ZN2js14NativeIterator9incCursorEv($9);
    __label__ = 26;
    break;
   case 25:
    var $72 = $idp_0 + 4 | 0;
    var $75 = $24 - $72 | 0;
    _llvm_memmove_p0i8_p0i8_i32($idp_0, $72, $75, 1, 0);
    var $_idx6_val = HEAP32[$18 >> 2];
    var $76 = __ZNK2js14NativeIterator3endEv($_idx6_val);
    var $77 = $76 - 4 | 0;
    HEAP32[$18 >> 2] = $77;
    __label__ = 26;
    break;
   case 26:
    var $80 = HEAP32[$_idx3 >> 2] | 8192;
    HEAP32[$_idx3 >> 2] = $80;
    __label__ = 27;
    break;
   case 27:
    var $idp_0 = $idp_0 + 4 | 0;
    __label__ = 8;
    break;
   case 28:
    var $iterobj_0_in = $9 + 32 | 0;
    __label__ = 2;
    break;
   case 29:
    var $_7;
    STACKTOP = __stackBase__;
    return $_7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL29SuppressDeletedPropertyHelperI19IndexRangePredicateEbP9JSContextP8JSObjectT_["X"] = 1;

function __ZN19IndexRangePredicateC1Eii($this, $begin, $end) {
  __ZN19IndexRangePredicateC2Eii($this, $begin, $end);
  return;
}

function __Z15js_IteratorMoreP9JSContextP8JSObjectPN2JS5ValueE($cx, $iterobj, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stackDummy_ = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $_idx4_val = HEAP32[$iterobj + 4 >> 2];
    var $4 = __ZNK8JSObject10isIteratorEv($_idx4_val);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $ni_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $_idx3_val = HEAP32[$iterobj + 24 >> 2];
    var $7 = __ZNK8JSObject17getNativeIteratorEv($_idx3_val);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $ni_0 = $8;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = HEAPU32[$7 + 8 >> 2] >>> 0 < HEAPU32[$7 + 12 >> 2] >>> 0;
    var $_idx5_val = HEAP32[$7 + 28 >> 2];
    var $16 = __ZNK2js14NativeIterator9isKeyIterEv($_idx5_val);
    if ($16 | $15 ^ 1) {
      __label__ = 4;
      break;
    } else {
      var $ni_0 = $8;
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value10setBooleanEb($rval, $15);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 5:
    var $ni_0;
    var $19 = $cx + 224 | 0;
    var $_idx2 = $19 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    var $20 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_idx2_val$0, $_idx2_val$1);
    if ($20) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 7:
    if ($stackDummy_ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $28 = $cx;
    __Z21js_ReportOverRecursedP9JSContext($28);
    var $_0 = 0;
    __label__ = 19;
    break;
   case 9:
    if (($ni_0 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 10:
    var $36 = HEAP32[HEAP32[$cx + 52 >> 2] + 210276 >> 2] | 0;
    var $37 = __ZL12ATOM_TO_JSIDP6JSAtom1935($36);
    var $38 = $cx;
    var $39 = $iterobj;
    var $40 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($38, $39, $37, 0, $rval);
    if (($40 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2JSL11ObjectValueER8JSObject1936($1, $iterobj);
    var $43 = $cx;
    var $44 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($43, $1, $rval, 0, 0, $rval);
    if ($44) {
      __label__ = 18;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $_idx_val = HEAP32[$cx + 20 >> 2];
    var $47 = __ZN9JSContext18isExceptionPendingEv($_idx_val);
    if ($47) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 13:
    var $49 = $cx + 24 | 0;
    var $st$1$0 = $49 | 0;
    var $_idx1_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $49 + 4 | 0;
    var $_idx1_val$1 = HEAP32[$st$1$1 >> 2];
    __ZN9JSContext19getPendingExceptionEv($2, $_idx1_val$0, $_idx1_val$1);
    var $_idx6 = $2 | 0;
    var $_idx6_val$0 = HEAP32[$_idx6 >> 2];
    var $_idx6_val$1 = HEAP32[$_idx6 + 4 >> 2];
    var $50 = __ZN2jsL15IsStopIterationERKN2JS5ValueE($_idx6_val$0, $_idx6_val$1);
    if ($50) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 14:
    __ZN9JSContext21clearPendingExceptionEv($43);
    __ZN2JS5Value8setMagicE10JSWhyMagic($19, 3);
    __ZN2JS5Value10setBooleanEb($rval, 0);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 15:
    var $53 = $ni_0;
    var $_idx7_val = HEAP32[$ni_0 + 8 >> 2];
    var $55 = __ZNK2js14NativeIterator7currentEv($_idx7_val);
    var $56 = HEAP32[$55 >> 2];
    __ZN2js14NativeIterator9incCursorEv($53);
    var $59 = HEAP32[$ni_0 >> 2];
    var $60 = $cx;
    var $61 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($59, $60, $56, $rval);
    if (($61 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if ((HEAP32[$ni_0 + 28 >> 2] & 4 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $69 = __ZL15NewKeyValuePairP9JSContextiRKN2JS5ValueEPS2_($cx, $56, $rval, $rval);
    if ($69) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 18:
    var $71 = $rval | 0;
    var $st$1$0 = $71 | 0;
    var $72$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $71 + 4 | 0;
    var $72$1 = HEAP32[$st$1$1 >> 2];
    HEAP32[$_idx2 >> 2] = $72$0;
    HEAP32[$_idx2 + 4 >> 2] = $72$1;
    __ZN2JS5Value10setBooleanEb($rval, 1);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z15js_IteratorMoreP9JSContextP8JSObjectPN2JS5ValueE["X"] = 1;

function __ZL12ATOM_TO_JSIDP6JSAtom1935($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj1979($1);
  return $2;
}

function __ZN2JSL11ObjectValueER8JSObject1936($agg_result, $obj) {
  var $1 = $obj;
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $1);
  return;
}

function __ZN2jsL15IsStopIterationERKN2JS5ValueE($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZNK8JSObject15isStopIterationEv($_idx_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15NewKeyValuePairP9JSContextiRKN2JS5ValueEPS2_($cx, $id, $val, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $vec = __stackBase__;
    var $tvr = __stackBase__ + 16;
    var $1 = $vec | 0;
    __ZN2jsL9IdToValueEi1939($1, $id);
    var $2 = $val | 0;
    var $3$0 = HEAP32[$2 >> 2];
    var $3$1 = HEAP32[$2 + 4 >> 2];
    var $4 = $vec + 8 | 0;
    HEAP32[$4 >> 2] = $3$0;
    HEAP32[$4 + 4 >> 2] = $3$1;
    var $5 = $cx;
    __ZN2js15AutoArrayRooterC1EP9JSContextjPN2JS5ValueE($tvr, $5, 2, $1);
    var $6 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($5, 2, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($rval, $6);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    __ZN2js15AutoArrayRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z15js_IteratorNextP9JSContextP8JSObjectPN2JS5ValueE($cx, $iterobj, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $_idx3_val = HEAP32[$iterobj + 4 >> 2];
    var $3 = __ZNK8JSObject10isIteratorEv($_idx3_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$iterobj + 24 >> 2];
    var $6 = __ZNK8JSObject17getNativeIteratorEv($_idx_val);
    if (($6 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx4_val = HEAP32[$6 + 28 >> 2];
    var $9 = __ZNK2js14NativeIterator9isKeyIterEv($_idx4_val);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 4:
    var $_idx5_val = HEAP32[$6 + 8 >> 2];
    var $11 = __ZNK2js14NativeIterator7currentEv($_idx5_val);
    var $12 = HEAP32[$11 >> 2];
    __ZN2jsL9IdToValueEi1939($1, $12);
    var $13 = $1 | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $rval | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    __ZN2js14NativeIterator9incCursorEv($6);
    var $rval_idx1_val$0 = HEAP32[$15 >> 2];
    var $rval_idx1_val$1 = HEAP32[$15 + 4 >> 2];
    var $16 = __ZNK2JS5Value8isStringEv($rval_idx1_val$0, $rval_idx1_val$1);
    if ($16) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = __ZNK2JS5Value7isInt32Ev($rval_idx1_val$0, $rval_idx1_val$1);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $20 = __ZNK2JS5Value7toInt32Ev($rval_idx1_val$0, $rval_idx1_val$1);
    var $21 = __ZN2js13StaticStrings6hasIntEi($20);
    if ($21) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $25 = HEAP32[$cx + 52 >> 2] + 210584 | 0;
    var $26 = __ZN2js13StaticStrings6getIntEi($25, $20);
    var $str_0 = $26 | 0;
    __label__ = 9;
    break;
   case 8:
    var $29 = $cx;
    var $30 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($29, $rval_idx1_val$0, $rval_idx1_val$1);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      var $str_0 = $30;
      __label__ = 9;
      break;
    }
   case 9:
    var $str_0;
    __ZN2JS5Value9setStringEP8JSString($rval, $str_0);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 10:
    var $34 = $cx + 224 | 0;
    var $35 = $34 | 0;
    var $36$0 = HEAP32[$35 >> 2];
    var $36$1 = HEAP32[$35 + 4 >> 2];
    var $37 = $rval | 0;
    HEAP32[$37 >> 2] = $36$0;
    HEAP32[$37 + 4 >> 2] = $36$1;
    __ZN2JS5Value8setMagicE10JSWhyMagic($34, 3);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z15js_IteratorNextP9JSContextP8JSObjectPN2JS5ValueE["X"] = 1;

function __ZN2jsL9IdToValueEi1939($agg_result, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_STRING1965($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_STRING1974($id);
    __ZN2JSL11StringValueEP8JSString1973($agg_result, $4);
    __label__ = 8;
    break;
   case 3:
    var $6 = _JSID_IS_INT1957($id);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _JSID_TO_INT1958($id);
    __ZN2JSL10Int32ValueEi1975($agg_result, $9);
    __label__ = 8;
    break;
   case 5:
    var $11 = _JSID_IS_OBJECT1976($id);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = _JSID_TO_OBJECT1977($id);
    __ZN2JSL11ObjectValueER8JSObject1936($agg_result, $14);
    __label__ = 8;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv1961($agg_result);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js16AutoObjectRooter6objectEv($this_0_1_val) {
  return $this_0_1_val;
}

function _JSID_IS_INT1957($iden) {
  return $iden & 1;
}

function _JSID_TO_INT1958($iden) {
  return $iden >> 1;
}

function __ZN17SingleIdPredicateclEi($this_0_0_val, $id) {
  return ($this_0_0_val | 0) == ($id | 0);
}

function _JSID_IS_STRING1965($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function __ZN2js10StackFrame21initFloatingGeneratorEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 96;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js2gcL15GetGCObjectKindEjb1947($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16AutoObjectRooter4addrEv($this) {
  return $this + 12 | 0;
}

function __ZN2js10StackFrame13clearYieldingEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -257;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE7popBackEv($this) {
  var $1 = $this + 4 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZL20stopiter_hasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi($cx, $obj, $v, $bp) {
  var $v_idx = $v | 0;
  var $v_idx_val$0 = HEAP32[$v_idx >> 2];
  var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
  var $1 = __ZN2jsL15IsStopIterationERKN2JS5ValueE($v_idx_val$0, $v_idx_val$1);
  var $2 = $1 & 1;
  HEAP32[$bp >> 2] = $2;
  return 1;
}

function __ZL18generator_finalizeP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $2 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN9JSContext5free_EPv($2);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15generator_traceP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $2 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$2 + 4 >> 2] - 2 | 0) >>> 0 < 2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx1_val = HEAP32[$2 + 28 >> 2];
    var $10 = __ZN11JSGenerator13floatingFrameEv($_idx1_val);
    var $12 = $2 + 32 | 0;
    var $13 = $10;
    var $14 = __ZNK2js10StackFrame13formalArgsEndEv($13);
    var $15 = $trc;
    __ZN2js28MarkStackRangeConservativelyEP8JSTracerPN2JS5ValueES4_($15, $12, $14);
    __Z18js_TraceStackFrameP8JSTracerPN2js10StackFrameE($15, $13);
    var $16 = __ZNK2js10StackFrame5slotsEv($10);
    var $19 = HEAP32[$2 + 8 >> 2];
    __ZN2js28MarkStackRangeConservativelyEP8JSTracerPN2JS5ValueES4_($15, $16, $19);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z15js_NewGeneratorP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __ZNK9JSContext4regsEv($1);
    var $_idx_val = HEAP32[$2 + 12 >> 2];
    var $3 = __ZNK2js9FrameRegs2fpEv($_idx_val);
    var $4 = __ZNK2js10StackFrame10scopeChainEv($3);
    var $5 = $4;
    var $6 = __ZNK8JSObject9getGlobalEv($5);
    var $7 = $6;
    var $8 = __ZN2js12GlobalObject29getOrCreateGeneratorPrototypeEP9JSContext($7, $1);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = $8;
    var $12 = $6;
    var $13 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_1942($cx, $11, $12);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = __ZNK2js10StackFrame10actualArgsEv($3);
    var $17 = $16 - 16 | 0;
    var $18 = __ZNK2js10StackFrame13formalArgsEndEv($3);
    var $22 = $18 - $17 >> 3;
    var $23 = $3;
    var $24 = __ZNK2js10StackFrame8numSlotsEv($23);
    var $28 = ($22 + ($24 + 6) << 3) + 40 | 0;
    var $29 = __ZN9JSContext7malloc_Ej($1, $28);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $33 = $29 + 32 | 0;
    var $34 = $33 + ($22 << 3) | 0;
    var $35 = $34;
    var $36 = $29;
    HEAP32[$36 >> 2] = $13;
    var $38 = $29 + 4 | 0;
    HEAP32[$38 >> 2] = 0;
    var $40 = $29 + 24 | 0;
    HEAP32[$40 >> 2] = 0;
    var $42 = $29 + 28 | 0;
    HEAP32[$42 >> 2] = $35;
    var $44 = $29 + 8 | 0;
    var $45 = $2;
    var $46 = $34;
    __ZN2js9FrameRegs12rebaseFromToERKS0_RNS_10StackFrameE($44, $45, $46);
    var $48 = HEAP32[$2 >> 2];
    __ZN2js10StackFrame18stealFrameAndSlotsEPN2JS5ValueEPS0_S3_S3_($46, $33, $23, $17, $48);
    __ZN2js10StackFrame21initFloatingGeneratorEv($35);
    var $49 = $13;
    __ZN8JSObject10setPrivateEPv($49, $29);
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z15js_NewGeneratorP9JSContext["X"] = 1;

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_1942($cx, $proto, $parent) {
  var $3 = HEAPU32[__ZN2js14GeneratorClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb1947($3);
  var $5 = __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE1948($cx, $proto, $parent, $4);
  return $5;
}

function __Z27js_FloatingFrameToGeneratorPN2js10StackFrameE($fp) {
  var $1 = $fp;
  var $2 = __ZNK2js10StackFrame10actualArgsEv($1);
  return $2 - 48 | 0;
}

function __ZL14generator_nextP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL12generator_opP9JSContext13JSGeneratorOpPN2JS5ValueEj($cx, 0, $vp, $argc);
  return $1;
}

function __ZL14generator_sendP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL12generator_opP9JSContext13JSGeneratorOpPN2JS5ValueEj($cx, 1, $vp, $argc);
  return $1;
}

function __ZL15generator_throwP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL12generator_opP9JSContext13JSGeneratorOpPN2JS5ValueEj($cx, 2, $vp, $argc);
  return $1;
}

function __ZL15generator_closeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL12generator_opP9JSContext13JSGeneratorOpPN2JS5ValueEj($cx, 3, $vp, $argc);
  return $1;
}

function __ZN2js12GlobalObject18initGeneratorClassEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this;
    var $3 = $cx;
    var $4 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($2, $3, __ZN2js14GeneratorClassE);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($3, $4, 0, __ZL17generator_methods);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2JSL11ObjectValueER8JSObject1936($1, $5);
    var $10 = $this;
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($10, 112, $_idx_val$0, $_idx_val$1);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z22js_InitIteratorClassesP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $iter = __stackBase__;
    var $1 = $obj;
    var $2 = __ZN8JSObject8asGlobalEv($1);
    var $3 = $2;
    var $4 = $cx;
    var $5 = $2;
    var $6 = $iter;
    var $7 = __Z17js_GetClassObjectP9JSContextP8JSObject10JSProtoKeyPS2_($4, $5, 22, $6);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAP32[$iter >> 2];
    if (($10 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $10;
      __label__ = 6;
      break;
    }
   case 3:
    var $13 = __ZL17InitIteratorClassP9JSContextPN2js12GlobalObjectE($cx, $3);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $15 = __ZN2js12GlobalObject18initGeneratorClassEP9JSContext($3, $cx);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $17 = __ZL22InitStopIterationClassP9JSContextPN2js12GlobalObjectE($cx, $3);
    var $_0 = $17;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17InitIteratorClassP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $global;
    var $2 = $cx;
    var $3 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($1, $2, __ZN2js13IteratorClassE);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAP32[HEAP32[$cx + 52 >> 2] + 210108 >> 2];
    var $11 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($1, $2, 146, __ZN2js13IteratorClassE, $10, 2);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = $11 | 0;
    var $15 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($2, $14, $3);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $17 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($2, $3, 0, __ZL16iterator_methods);
    if ($17) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $19 = $cx;
    var $20 = $global;
    var $21 = $11;
    var $22 = $3;
    var $23 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($19, $20, 22, $21, $22);
    var $_0 = $23;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL22InitStopIterationClassP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $global;
    var $2 = $cx;
    var $3 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($1, $2, __ZN2js18StopIterationClassE);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $3;
    var $8 = $cx;
    var $9 = __ZN8JSObject6freezeEP9JSContext($7, $8);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $11 = $global;
    var $12 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($8, $11, 23, $7, $7);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = $global;
    var $_idx_val = HEAP32[__ZN2js18StopIterationClassE + 4 >> 2];
    __ZN2js35MarkStandardClassInitializedNoProtoEP8JSObjectPNS_5ClassE($14, $_idx_val);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE1948($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($proto | 0) != 0;
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZN2js5types15emptyTypeObjectE;
    var $_pre_phi = $cx;
    __label__ = 4;
    break;
   case 3:
    var $3 = $proto;
    var $4 = $cx;
    var $5 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($3, $4, 0, 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      var $8 = $6;
      var $_pre_phi = $4;
      __label__ = 4;
      break;
    }
   case 4:
    var $_pre_phi;
    var $8;
    var $9 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($_pre_phi, $kind);
    var $10 = $9;
    if (($9 | 0) == 0) {
      var $_0 = $10;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($parent | 0) != 0 | $1 ^ 1) {
      var $18 = $parent;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx_val = HEAP32[$proto + 20 >> 2];
    var $15 = __ZNK8JSObject9getParentEv($_idx_val);
    var $18 = $15;
    __label__ = 7;
    break;
   case 7:
    var $18;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($9, __ZN2js14GeneratorClassE, $8, $18, 0, (__ZN2js14GeneratorClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $_idx1_val = HEAP32[__ZN2js14GeneratorClassE + 4 >> 2];
    var $21 = __ZNK2js5Class8isNativeEv($_idx1_val);
    if ($21) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $23 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE1951($cx, $10, $8, $kind);
    if ($23) {
      var $_0 = $10;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_0 = 0;
    __label__ = 11;
    break;
   case 10:
    __ZN8JSObject21setSharedNonNativeMapEv($9);
    var $_0 = $10;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE1951($cx, $obj, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAPU32[__ZN2js14GeneratorClassE + 4 >> 2] >>> 8 & 255;
    var $4 = $obj;
    var $_idx_val = HEAP32[$obj + 28 >> 2];
    var $6 = __ZNK8JSObject8numSlotsEv($_idx_val);
    if ($3 >>> 0 > $6 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $obj;
    var $10 = $cx;
    var $11 = __ZN8JSObject10allocSlotsEP9JSContextj($9, $10, $3);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $13 = $type;
    var $14 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($13, __ZN2js14GeneratorClassE);
    var $15 = $cx;
    if ($14) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($13, $15, __ZN2js14GeneratorClassE, $kind);
    var $empty_0_in = $17;
    __label__ = 6;
    break;
   case 5:
    var $19 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($15, __ZN2js14GeneratorClassE);
    var $empty_0_in = $19;
    __label__ = 6;
    break;
   case 6:
    var $empty_0_in;
    if (($empty_0_in | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $empty_0_in | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN19IndexRangePredicateclEi($this_0_0_val, $this_0_1_val, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_INT1957($id);
    if (($1 | 0) == 0) {
      var $9 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_INT1958($id);
    if (($4 | 0) < ($this_0_0_val | 0)) {
      var $9 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = ($4 | 0) < ($this_0_1_val | 0);
    __label__ = 4;
    break;
   case 4:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE14internalAppendIjEEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this + 4 >> 2];
    var $2 = $this + 8 | 0;
    var $_idx1_val = HEAP32[$2 >> 2];
    var $3 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE10endNoCheckEv($_idx_val, $_idx1_val);
    if (($3 | 0) == 0) {
      var $7 = $_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$3 >> 2] = $t;
    var $7 = HEAP32[$2 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $7;
    HEAP32[$2 >> 2] = $7 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL14UndefinedValueEv1961($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZL8IteratorP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if ($argc >>> 0 > 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $vp + 24 | 0;
    var $4 = __Z17js_ValueToBooleanRKN2JS5ValueE($3);
    var $phitmp2 = ($4 | 0) != 0 ? 8 : 14;
    var $8 = $phitmp2;
    __label__ = 4;
    break;
   case 3:
    if (($argc | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $8 = 14;
      __label__ = 4;
      break;
    }
   case 4:
    var $8;
    var $9 = $vp + 16 | 0;
    var $st$2$0 = $9 | 0;
    var $10$0 = HEAPU32[$st$2$0 >> 2];
    var $st$2$1 = $9 + 4 | 0;
    var $10$1 = HEAPU32[$st$2$1 >> 2];
    var $11 = $1 | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $15 = $8;
    var $14$1 = $10$1;
    var $14$0 = $10$0;
    __label__ = 6;
    break;
   case 5:
    __ZN2JSL14UndefinedValueEv1961($1);
    var $_phi_trans_insert = $1 | 0;
    var $st$2$0 = $_phi_trans_insert | 0;
    var $st$2$1 = $_phi_trans_insert + 4 | 0;
    var $15 = 14;
    var $14$1 = HEAP32[$st$2$1 >> 2];
    var $14$0 = HEAP32[$st$2$0 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $14$0;
    var $14$1;
    var $15;
    var $16 = $vp | 0;
    HEAP32[$16 >> 2] = $14$0;
    HEAP32[$16 + 4 >> 2] = $14$1;
    var $17 = __Z18js_ValueToIteratorP9JSContextjPN2JS5ValueE($cx, $15, $vp);
    STACKTOP = __stackBase__;
    return $17;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12generator_opP9JSContext13JSGeneratorOpPN2JS5ValueEj($cx, $op, $vp, $argc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = $cx;
    var $6 = $vp + 8 | 0;
    var $7 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($5, $6);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx4_val = HEAP32[$7 + 4 >> 2];
    var $12 = __ZNK8JSObject11isGeneratorEv($_idx4_val);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($5, $vp, __ZN2js14GeneratorClassE);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $_idx_val = HEAP32[$7 + 24 >> 2];
    var $15 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $16 = $15;
    if (($15 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = $15 + 4 | 0;
    var $21 = HEAP32[$20 >> 2];
    if (($21 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($21 | 0) == 4) {
      __label__ = 11;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 6:
    if (($op | 0) == 1) {
      __label__ = 7;
      break;
    } else if (($op | 0) == 0 || ($op | 0) == 2) {
      __label__ = 18;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    if (($argc | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx1 = $vp + 16 | 0;
    var $st$1$0 = $_idx1 | 0;
    var $_idx1_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx1 + 4 | 0;
    var $_idx1_val$1 = HEAP32[$st$1$1 >> 2];
    var $26 = __ZNK2JS5Value11isUndefinedEv($_idx1_val$0, $_idx1_val$1);
    if ($26) {
      __label__ = 18;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $28 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($5, 0, 182, 1, $_idx1_val$0, $_idx1_val$1, 0, 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 10:
    HEAP32[$20 >> 2] = 4;
    __ZN2JSL14UndefinedValueEv1961($1);
    var $30 = $1 | 0;
    var $31$0 = HEAP32[$30 >> 2];
    var $31$1 = HEAP32[$30 + 4 >> 2];
    var $32 = $vp | 0;
    HEAP32[$32 >> 2] = $31$0;
    HEAP32[$32 + 4 >> 2] = $31$1;
    var $_0 = 1;
    __label__ = 23;
    break;
   case 11:
    if (($op | 0) == 0 || ($op | 0) == 1) {
      __label__ = 12;
      break;
    } else if (($op | 0) == 2) {
      __label__ = 13;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 12:
    __Z21js_ThrowStopIterationP9JSContext($cx);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 13:
    if (($argc | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $38 = $vp + 16 | 0;
    var $st$1$0 = $38 | 0;
    var $39$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $38 + 4 | 0;
    var $39$1 = HEAP32[$st$1$1 >> 2];
    var $40 = $2 | 0;
    var $st$6$0 = $40 | 0;
    HEAP32[$st$6$0 >> 2] = $39$0;
    var $st$6$1 = $40 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $39$1;
    var $_idx2_val$1 = $39$1;
    var $_idx2_val$0 = $39$0;
    __label__ = 16;
    break;
   case 15:
    __ZN2JSL14UndefinedValueEv1961($2);
    var $_idx2_phi_trans_insert = $2 | 0;
    var $st$2$0 = $_idx2_phi_trans_insert | 0;
    var $st$2$1 = $_idx2_phi_trans_insert + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$2$1 >> 2];
    var $_idx2_val$0 = HEAP32[$st$2$0 >> 2];
    __label__ = 16;
    break;
   case 16:
    var $_idx2_val$0;
    var $_idx2_val$1;
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($5, $_idx2_val$0, $_idx2_val$1);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 17:
    __ZN2JSL14UndefinedValueEv1961($3);
    var $44 = $3 | 0;
    var $st$2$0 = $44 | 0;
    var $45$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $44 + 4 | 0;
    var $45$1 = HEAP32[$st$2$1 >> 2];
    var $46 = $vp | 0;
    var $st$7$0 = $46 | 0;
    HEAP32[$st$7$0 >> 2] = $45$0;
    var $st$7$1 = $46 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $45$1;
    var $_0 = 1;
    __label__ = 23;
    break;
   case 18:
    if (($op - 1 | 0) >>> 0 < 2 & ($argc | 0) != 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $52 = $vp + 16 | 0;
    var $st$1$0 = $52 | 0;
    var $53$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $52 + 4 | 0;
    var $53$1 = HEAP32[$st$1$1 >> 2];
    var $54 = $4 | 0;
    var $st$6$0 = $54 | 0;
    HEAP32[$st$6$0 >> 2] = $53$0;
    var $st$6$1 = $54 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $53$1;
    __label__ = 21;
    break;
   case 20:
    __ZN2JSL14UndefinedValueEv1961($4);
    __label__ = 21;
    break;
   case 21:
    var $56 = __ZL15SendToGeneratorP9JSContext13JSGeneratorOpP8JSObjectP11JSGeneratorRKN2JS5ValueE($cx, $op, $8, $16, $4);
    if (($56 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $_idx3_val = HEAP32[$15 + 28 >> 2];
    var $60 = __ZN11JSGenerator13floatingFrameEv($_idx3_val);
    var $61 = $60;
    var $62 = __ZN2js10StackFrame11returnValueEv($61);
    var $63 = $62 | 0;
    var $st$7$0 = $63 | 0;
    var $64$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $63 + 4 | 0;
    var $64$1 = HEAP32[$st$7$1 >> 2];
    var $65 = $vp | 0;
    HEAP32[$65 >> 2] = $64$0;
    HEAP32[$65 + 4 >> 2] = $64$1;
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12generator_opP9JSContext13JSGeneratorOpPN2JS5ValueEj["X"] = 1;

function __ZL15SendToGeneratorP9JSContext13JSGeneratorOpP8JSObjectP11JSGeneratorRKN2JS5ValueE($cx, $op, $obj, $gen, $arg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $gfg = __stackBase__ + 16;
    var $3 = $gen + 4 | 0;
    if ((HEAP32[$3 >> 2] - 2 | 0) >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JSL17ObjectOrNullValueEP8JSObject1967($1, $obj);
    var $_idx4_val = HEAP32[$gen + 28 >> 2];
    var $7 = __ZN11JSGenerator13floatingFrameEv($_idx4_val);
    var $8 = $7;
    var $9 = __ZNK2js10StackFrame3funEv($8);
    var $_idx5_val = HEAP32[$9 + 72 >> 2];
    var $10 = _JS_GetFunctionId($_idx5_val);
    var $11 = $cx;
    var $_idx8 = $1 | 0;
    var $_idx8_val$0 = HEAP32[$_idx8 >> 2];
    var $_idx8_val$1 = HEAP32[$_idx8 + 4 >> 2];
    var $12 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($11, 0, 175, 1, $_idx8_val$0, $_idx8_val$1, $10, 0);
    var $_1 = 0;
    __label__ = 17;
    break;
   case 3:
    var $14 = __ZN9JSContext25ensureGeneratorStackSpaceEv($cx);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      var $_1 = 0;
      __label__ = 17;
      break;
    }
   case 4:
    if (($op | 0) == 0 || ($op | 0) == 1) {
      __label__ = 5;
      break;
    } else if (($op | 0) == 2) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 5:
    if ((HEAP32[$3 >> 2] | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = $arg | 0;
    var $st$3$0 = $22 | 0;
    var $23$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $22 + 4 | 0;
    var $23$1 = HEAP32[$st$3$1 >> 2];
    var $24 = HEAP32[$gen + 8 >> 2] - 8 | 0;
    var $st$8$0 = $24 | 0;
    HEAP32[$st$8$0 >> 2] = $23$0;
    var $st$8$1 = $24 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $23$1;
    __label__ = 7;
    break;
   case 7:
    HEAP32[$3 >> 2] = 2;
    __label__ = 10;
    break;
   case 8:
    var $27 = $arg | 0;
    var $28$0 = HEAP32[$27 >> 2];
    var $28$1 = HEAP32[$27 + 4 >> 2];
    var $29 = $cx;
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($29, $28$0, $28$1);
    HEAP32[$3 >> 2] = 2;
    __label__ = 10;
    break;
   case 9:
    __ZN2JSL10MagicValueE10JSWhyMagic1968($2);
    var $31 = $cx;
    var $_idx = $2 | 0;
    var $st$3$0 = $_idx | 0;
    var $_idx_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAP32[$st$3$1 >> 2];
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($31, $_idx_val$0, $_idx_val$1);
    HEAP32[$3 >> 2] = 3;
    __label__ = 10;
    break;
   case 10:
    var $33 = $gen;
    var $_idx3 = $gen + 28 | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $35 = __ZN11JSGenerator13floatingFrameEv($_idx3_val);
    var $36 = $35;
    __ZN2js19GeneratorFrameGuardC1Ev($gfg);
    var $38 = $cx + 60 | 0;
    var $39 = $cx;
    var $40 = $gfg;
    var $41 = __ZN2js12ContextStack18pushGeneratorFrameEP9JSContextP11JSGeneratorPNS_19GeneratorFrameGuardE($38, $39, $33, $40);
    if ($41) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    HEAP32[$3 >> 2] = 4;
    __ZN2js19GeneratorFrameGuardD1Ev($gfg);
    var $_1 = 0;
    __label__ = 17;
    break;
   case 12:
    var $43 = $gfg;
    var $44 = __ZNK2js10FrameGuard2fpEv($43);
    var $45 = $gen + 8 | 0;
    var $46 = $cx;
    var $47 = __ZNK9JSContext4regsEv($46);
    var $48 = $45;
    var $49 = $47;
    HEAP32[$48 >> 2] = HEAP32[$49 >> 2];
    HEAP32[$48 + 4 >> 2] = HEAP32[$49 + 4 >> 2];
    HEAP32[$48 + 8 >> 2] = HEAP32[$49 + 8 >> 2];
    HEAP32[$48 + 12 >> 2] = HEAP32[$49 + 12 >> 2];
    __ZN9JSContext14enterGeneratorEP11JSGenerator($cx, $gen);
    var $50 = $cx + 284 | 0;
    var $51 = HEAP32[$50 >> 2];
    var $52 = $gen + 24 | 0;
    var $53 = HEAP32[$52 >> 2];
    HEAP32[$50 >> 2] = $53;
    var $54 = __ZNK2js10StackFrame6scriptEv($44);
    var $_idx7_val = HEAP8[$54 + 36 | 0];
    var $55 = __ZN2js9RunScriptEP9JSContextP8JSScriptPNS_10StackFrameE($46, $_idx7_val, $44);
    var $56 = HEAP32[$50 >> 2];
    HEAP32[$52 >> 2] = $56;
    HEAP32[$50 >> 2] = $51;
    __ZN9JSContext14leaveGeneratorEP11JSGenerator($cx);
    __ZN2js19GeneratorFrameGuardD1Ev($gfg);
    var $_idx2_val = HEAP32[$_idx3 >> 2];
    var $58 = __ZN11JSGenerator13floatingFrameEv($_idx2_val);
    var $_idx6_val = HEAP32[$58 >> 2];
    var $59 = __ZN2js10StackFrame10isYieldingEv($_idx6_val);
    if ($59) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    __ZN2js10StackFrame13clearYieldingEv($36);
    HEAP32[$3 >> 2] = 1;
    var $_1 = 1;
    __label__ = 17;
    break;
   case 14:
    var $62 = $35;
    __ZN2js10StackFrame16clearReturnValueEv($62);
    HEAP32[$3 >> 2] = 4;
    if ($55) {
      __label__ = 15;
      break;
    } else {
      var $_1 = 0;
      __label__ = 17;
      break;
    }
   case 15:
    if (($op | 0) == 3) {
      var $_1 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __Z21js_ThrowStopIterationP9JSContext($cx);
    var $_1 = 0;
    __label__ = 17;
    break;
   case 17:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15SendToGeneratorP9JSContext13JSGeneratorOpP8JSObjectP11JSGeneratorRKN2JS5ValueE["X"] = 1;

function __ZN2JSL17ObjectOrNullValueEP8JSObject1967($agg_result, $obj) {
  var $1 = $obj;
  __ZN2JS5Value15setObjectOrNullEP8JSObject($agg_result, $1);
  return;
}

function __ZN9JSContext25ensureGeneratorStackSpaceEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 288 | 0;
    var $_idx_val = HEAP32[$this + 292 >> 2];
    var $3 = __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE6lengthEv($_idx_val);
    var $4 = $3 + 1 | 0;
    var $5 = __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE7reserveEj($1, $4);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this;
    __Z20js_ReportOutOfMemoryP9JSContext($7);
    __label__ = 3;
    break;
   case 3:
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL10MagicValueE10JSWhyMagic1968($agg_result) {
  __ZN2JS5Value8setMagicE10JSWhyMagic($agg_result, 4);
  return;
}

function __ZN2js19GeneratorFrameGuardC1Ev($this) {
  __ZN2js19GeneratorFrameGuardC2Ev($this);
  return;
}

function __ZN9JSContext14enterGeneratorEP11JSGenerator($this, $gen) {
  var $1 = $this + 288 | 0;
  __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE6appendIS2_EEbT_($1, $gen);
  return;
}

function __ZN9JSContext14leaveGeneratorEP11JSGenerator($this) {
  var $1 = $this + 288 | 0;
  __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE7popBackEv($1);
  return;
}

function __ZN2js19GeneratorFrameGuardD1Ev($this) {
  __ZN2js19GeneratorFrameGuardD2Ev($this);
  return;
}

function __ZN2js19GeneratorFrameGuardD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $_idx_val = HEAP32[$this >> 2];
    var $2 = __ZNK2js10FrameGuard6pushedEv($_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this;
    __ZN2js12ContextStack17popGeneratorFrameERKNS_19GeneratorFrameGuardE($4);
    __label__ = 3;
    break;
   case 3:
    __ZN2js10FrameGuardD2Ev($1);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 4 >> 2] | 0) == (HEAP32[$this + 8 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_($this, $t);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE18usingInlineStorageEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $8 = $4;
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $8 = $6;
    __label__ = 4;
    break;
   case 4:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this >> 2];
    var $1 = $this + 4 | 0;
    var $_idx1_val = HEAP32[$1 >> 2];
    var $2 = __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE10endNoCheckEv($_idx_val, $_idx1_val);
    if (($2 | 0) == 0) {
      var $6 = $_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$2 >> 2] = $t;
    var $6 = HEAP32[$1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $6;
    HEAP32[$1 >> 2] = $6 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 2;
    var $7 = __ZN2js17SystemAllocPolicy7malloc_Ej($6);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$this >> 2];
    var $11 = __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE12beginNoCheckEv($_idx_val);
    var $12 = $11;
    var $_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE10endNoCheckEv($_idx_val, $_idx2_val);
    var $14 = $13;
    __ZN2js10VectorImplIP11JSGeneratorLj2ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($8, $12, $14);
    HEAP32[$this >> 2] = $8;
    HEAP32[$this + 8 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14JSID_FROM_BITSj1979($bits) {
  return $bits;
}

function __ZNK2js6detail14HashTableEntryIKiE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function _JSID_TO_STRING1974($iden) {
  return $iden;
}

function _JSID_IS_OBJECT1976($iden) {
  return ($iden & 7 | 0) == 4 & ($iden | 0) != 4 & 1;
}

function _JSID_TO_OBJECT1977($iden) {
  return $iden & -8;
}

function _INT_TO_JSID1982($i) {
  return $i << 1 | 1;
}

function __ZN2js15NativeIterCache8getIndexEj($key) {
  return $key & 255;
}

function __ZNK2js6detail14HashTableEntryIKiE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E10overloadedEv($this_0_2_val, $this_0_3_val, $this_0_5_val) {
  return ($this_0_5_val + $this_0_3_val | 0) >>> 0 >= ($this_0_2_val * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryIKiE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js10VectorImplIP11JSGeneratorLj2ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN19IndexRangePredicateC2Eii($this, $begin, $end) {
  HEAP32[$this >> 2] = $begin;
  HEAP32[$this + 4 >> 2] = $end;
  return;
}

function __ZN17SingleIdPredicateC2Ei($this, $id) {
  HEAP32[$this >> 2] = $id;
  return;
}

function __ZN2js10VectorImplIiLj8ENS_15TempAllocPolicyELb1EE13copyConstructIiEEvPiPKT_S7_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryIKiE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail14HashTableEntryIKiE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryIKiE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIP11JSGeneratorLj2ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj2ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $5;
    if ($5 >>> 0 > 536870911) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP11JSGeneratorLj2ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj2ES3_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = __ZN2js17SystemAllocPolicy8realloc_EPvjj($4, $1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5;
    var $9 = $v + 8 | 0;
    HEAP32[$2 >> 2] = $8;
    HEAP32[$9 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP11JSGeneratorLj2ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIP11JSGeneratorLj2ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js19GeneratorFrameGuardC2Ev($this) {
  var $1 = $this;
  __ZN2js10FrameGuardC2Ev($1);
  return;
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE7reserveEj($this, $request) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$this + 8 >> 2] >>> 0 < $request >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $request - HEAP32[$this + 4 >> 2] | 0;
    var $8 = __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE13growStorageByEj($this, $7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11StringValueEP8JSString1973($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2JSL10Int32ValueEi1975($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZN2JSL12BooleanValueEb1988($agg_result, $boo) {
  __ZN2JS5Value10setBooleanEb($agg_result, $boo);
  return;
}

function __ZN2js10EmptyShape23getEmptyEnumeratorShapeEP9JSContext($cx) {
  var $4 = $cx;
  var $5 = HEAP32[$cx + 56 >> 2] + 764 | 0;
  var $6 = __ZN2js10EmptyShape6ensureEP9JSContextPNS_5ClassEPPS0_($4, __ZN2js13IteratorClassE, $5);
  return $6;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE1991($cx) {
  var $3 = HEAPU32[__ZN2js13IteratorClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb1947($3);
  var $5 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1992($cx, $4);
  return $5;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1992($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js13IteratorClassE + 4 >> 2] >>> 24;
    var $4 = $cx;
    var $5 = __ZNK9JSContext5hasfpEv($4);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $8;
    var $9 = $cx;
    var $10 = $global;
    var $11 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($9, $10);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $19 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $13 = __ZNK9JSContext2fpEv($4);
    var $14 = __ZNK2js10StackFrame10scopeChainEv($13);
    var $15 = $14;
    var $16 = __ZNK8JSObject9getGlobalEv($15);
    var $17 = $16;
    HEAP32[$global >> 2] = $17;
    var $19 = $17;
    __label__ = 5;
    break;
   case 5:
    var $19;
    var $20 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $19, $20);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $22 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $24 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $25 = $24;
    HEAP32[$proto >> 2] = $25;
    var $32 = $25;
    __label__ = 9;
    break;
   case 7:
    var $27 = $cx;
    var $29 = $proto;
    var $30 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($27, $19, $3, $29, __ZN2js13IteratorClassE);
    if ($30) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $32 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $32;
    var $33 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1993($cx, $32, $19, $kind);
    var $_0 = $33;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1992["X"] = 1;

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1993($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $proto;
    var $2 = $cx;
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($1, $2, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($2, $kind);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_0 = $7;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $parent;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, __ZN2js13IteratorClassE, $3, $10, 0, (__ZN2js13IteratorClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $11 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($3, $2, __ZN2js13IteratorClassE, $kind);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $11 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($6, $14);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEEC1ES2_($this, $a_01) {
  __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEEC2ES2_($this, $a_01);
  return;
}

function __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E4initEj($1);
  return $2;
}

function __ZL25EnumerateNativePropertiesP9JSContextP8JSObjectS2_jRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE($pobj, $flags, $ht, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $props;
    var $2 = __ZNK2js16AutoVectorRooterIiE6lengthEv($1);
    var $_idx_val = HEAP32[$pobj >> 2];
    var $3 = __ZNK8JSObject12lastPropertyEv($_idx_val);
    var $4 = $r;
    var $5 = $3;
    __ZNK2js5Shape3allEv($4, $5);
    var $6 = $r;
    var $_idx1 = $r;
    __label__ = 2;
    break;
   case 2:
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $_idx1_val_idx_val = HEAP32[$_idx1_val + 32 >> 2];
    var $8 = __ZNK2js5Shape5Range5emptyEv($_idx1_val_idx_val);
    if ($8) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $_idx1_val;
    var $11 = __ZNK2js5Shape5Range5frontEv($10);
    var $13 = HEAP32[$11 + 12 >> 2];
    var $14 = _JSID_IS_DEFAULT_XML_NAMESPACE($13);
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx3_val = HEAP8[$11 + 28 | 0];
    var $17 = __ZNK2js5Shape10enumerableEv($_idx3_val);
    var $18 = __ZL9EnumerateP9JSContextP8JSObjectS2_ibjRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE($pobj, $13, $17, $flags, $ht, $props);
    if ($18) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    __ZN2js5Shape5Range8popFrontEv($6);
    __label__ = 2;
    break;
   case 6:
    var $21 = __ZN2js16AutoVectorRooterIiE5beginEv($1);
    var $22 = $21 + ($2 << 2) | 0;
    var $23 = __ZN2js16AutoVectorRooterIiE3endEv($1);
    __ZN2jsL7ReverseIiEEvPT_S2_1995($22, $23);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL29EnumerateDenseArrayPropertiesP9JSContextP8JSObjectS2_jRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE($cx_0_11_val_0_70_28_val, $pobj, $flags, $ht, $props) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx_0_11_val_0_70_28_val | 0;
    var $2 = __ZL12ATOM_TO_JSIDP6JSAtom1935($1);
    var $3 = __ZL9EnumerateP9JSContextP8JSObjectS2_ibjRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE($pobj, $2, 0, $flags, $ht, $props);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$pobj + 24 >> 2];
    var $6 = __ZNK8JSObject14getArrayLengthEv($_idx_val);
    if (($6 | 0) == 0) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $pobj;
    var $10 = __ZN8JSObject30getDenseArrayInitializedLengthEv($9);
    var $_idx1_val = HEAP32[$pobj + 32 >> 2];
    var $12 = __ZN8JSObject21getDenseArrayElementsEv($_idx1_val);
    var $i_0 = 0;
    var $vp_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $vp_0;
    var $i_0;
    if ($i_0 >>> 0 < $10 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 5:
    var $vp_0_idx = $vp_0 | 0;
    var $vp_0_idx_val$0 = HEAP32[$vp_0_idx >> 2];
    var $vp_0_idx_val$1 = HEAP32[$vp_0_idx + 4 >> 2];
    var $16 = __ZNK2JS5Value7isMagicE10JSWhyMagic($vp_0_idx_val$0, $vp_0_idx_val$1);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = _INT_TO_JSID1982($i_0);
    var $19 = __ZL9EnumerateP9JSContextP8JSObjectS2_ibjRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE($pobj, $18, 1, $flags, $ht, $props);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    var $vp_0 = $vp_0 + 8 | 0;
    __label__ = 4;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9EnumerateP9JSContextP8JSObjectS2_ibjRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE($pobj, $id, $enumerable, $flags, $ht, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    HEAP32[$1 >> 2] = $id;
    if (($flags & 8 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx4_val = HEAP32[$pobj + 4 >> 2];
    var $7 = __ZNK8JSObject7isProxyEv($_idx4_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZNK8JSObject6getOpsEv($_idx4_val);
    if ((HEAP32[$9 + 112 >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZNK2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE12lookupForAddERKi($p, $ht, $1);
    var $_idx5_val_idx_val = HEAP32[HEAP32[$p >> 2] >> 2];
    __ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3PtrcvMS9_FvvEEv($2, $_idx5_val_idx_val);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 5:
    var $_idx2_val_idx_val = HEAP32[HEAP32[$pobj + 36 >> 2] >> 2];
    var $19 = __ZNK8JSObject8getProtoEv($_idx2_val_idx_val);
    if (($19 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $_idx3_val = HEAP32[$pobj + 4 >> 2];
    var $23 = __ZNK8JSObject7isProxyEv($_idx3_val);
    if ($23) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = __ZNK8JSObject6getOpsEv($_idx3_val);
    if ((HEAP32[$25 + 112 >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $30 = __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE3addERNS_6detail9HashTableIKiNS3_6SetOpsES2_E6AddPtrERS6_($ht, $p, $1);
    if ($30) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 9:
    if ($enumerable) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if (($flags & 16 | 0) == 0) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $35 = $props | 0;
    var $_val = HEAP32[$1 >> 2];
    var $36 = __ZN2js16AutoVectorRooterIiE6appendERKi($35, $_val);
    var $_0 = $36;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9EnumerateP9JSContextP8JSObjectS2_ibjRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE["X"] = 1;

function __ZN8JSObject9enumerateEP9JSContext11JSIterateOpPN2JS5ValueEPi($this, $cx, $iterop, $statep, $idp) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $2 = __ZNK8JSObject6getOpsEv($_idx_val);
  var $4 = HEAP32[$2 + 112 >> 2];
  var $7 = ($4 | 0) != 0 ? $4 : 148;
  var $8 = FUNCTION_TABLE[$7]($cx, $this, $iterop, $statep, $idp);
  return $8;
}

function __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 24 >> 2];
  __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_ED1Ev($this_0_6_val) {
  __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_ED2Ev($this_0_6_val);
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_ED2Ev($this_0_6_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_6_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E12destroyTableERS5_PNS0_14HashTableEntryIS2_EEj($this_0_6_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E12destroyTableERS5_PNS0_14HashTableEntryIS2_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js15TempAllocPolicy5free_EPv($0);
  return;
}

function __ZNK2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE12lookupForAddERKi($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E12lookupForAddERS2_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3PtrcvMS9_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 150,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE3addERNS_6detail9HashTableIKiNS3_6SetOpsES2_E6AddPtrERS6_($this, $p, $t) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3addERNS8_6AddPtrERS2_($1, $p, $t);
  return $2;
}

function __ZN2js16AutoVectorRooterIiE6appendERKi($this, $v_val) {
  var $1 = $this + 12 | 0;
  var $2 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE6appendIiEEbT_($1, $v_val);
  return $2;
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE6appendIiEEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE14internalAppendIiEEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $8 = $4;
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $8 = $6;
    __label__ = 4;
    break;
   case 4:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE14internalAppendIiEEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this + 4 >> 2];
    var $2 = $this + 8 | 0;
    var $_idx1_val = HEAP32[$2 >> 2];
    var $3 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE10endNoCheckEv($_idx_val, $_idx1_val);
    if (($3 | 0) == 0) {
      var $7 = $_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$3 >> 2] = $t;
    var $7 = HEAP32[$2 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $7;
    HEAP32[$2 >> 2] = $7 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 2;
    var $7 = $this;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($7, $6);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $this + 4 | 0;
    var $_idx_val = HEAP32[$12 >> 2];
    var $13 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE12beginNoCheckEv($_idx_val);
    var $_idx2_val = HEAP32[$1 >> 2];
    var $14 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE10endNoCheckEv($_idx_val, $_idx2_val);
    __ZN2js10VectorImplIiLj8ENS_15TempAllocPolicyELb1EE13moveConstructIiEEvPiPKT_S7_($9, $13, $14);
    HEAP32[$12 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIiLj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIiLj8ES1_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIiLj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIiLj8ES1_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v + 4 | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = $v;
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($5, $4, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $v + 12 | 0;
    var $10 = $6;
    HEAP32[$2 >> 2] = $10;
    HEAP32[$9 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIiLj8ENS_15TempAllocPolicyELb1EE13moveConstructIiEEvPiPKT_S7_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIiLj8ENS_15TempAllocPolicyELb1EE13copyConstructIiEEvPiPKT_S7_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3addERNS8_6AddPtrERS2_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3addERNS8_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$t >> 2];
    var $6 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$6 >> 2] = $3;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3addERNS8_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryIKiE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 12 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 8 >> 2];
    var $this_idx1 = $this + 12 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 20 >> 2];
    var $12 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryIKiE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 3:
    var $14 = $this | 0;
    var $15 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E11createTableERS5_j($14, $10);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $19 = $this + 16 | 0;
    var $21 = HEAP32[$19 >> 2] + 1 | 0;
    HEAP32[$19 >> 2] = $21;
    HEAP32[$2 >> 2] = $15;
    var $22 = $3 + ($5 << 3) | 0;
    if (($5 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 6;
    break;
   case 6:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryIKiE6isLiveEv($src_01_idx_val);
    if ($24) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2js6detail14HashTableEntryIKiE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $26 = __ZNK2js6detail14HashTableEntryIKiE10getKeyHashEv($src_01_idx1_val);
    var $27 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E13findFreeEntryEj($this, $26);
    __ZN2js4MoveINS_6detail14HashTableEntryIKiEEEENS_7MoveRefIT_EERS6_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryIKiEaSENS_7MoveRefIS3_EE($27, $_02_val);
    __label__ = 8;
    break;
   case 8:
    var $29 = $src_01 + 8 | 0;
    if (($29 | 0) == ($22 | 0)) {
      __label__ = 9;
      break;
    } else {
      var $src_01 = $29;
      __label__ = 6;
      break;
    }
   case 9:
    __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E12destroyTableERS5_PNS0_14HashTableEntryIS2_EEj($3);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E15changeTableSizeEi["X"] = 1;

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 3) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryIKiE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryIKiE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + ($15 << 3) | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryIKiE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E11createTableERS5_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 3;
    var $2 = $alloc;
    var $3 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4 + ($capacity << 3) | 0;
    if (($4 | 0) == ($7 | 0)) {
      var $_0 = $4;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $4;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryIKiEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $12 = $e_01 + 8 | 0;
    if (($12 | 0) == ($7 | 0)) {
      var $_0 = $4;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $12;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryIKiE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryIKiE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryIKiEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefIiEcvRiEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOps6getKeyERKi($t) {
  return $t;
}

function __ZN12IdHashPolicy4hashEi($id) {
  return $id;
}

function __ZN2js6detail14HashTableEntryIKiE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail14HashTableEntryIKiE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZN12IdHashPolicy5matchEii($id1, $id2) {
  return ($id1 | 0) == ($id2 | 0);
}

function _JSID_IS_DEFAULT_XML_NAMESPACE($iden) {
  return ($iden | 0) == 6 & 1;
}

function __ZL15JSDOUBLE_IS_NaNd2026($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZL18JSDOUBLE_IS_FINITEd2027($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKiEEEC2ERS4_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefIiEC2ERi($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail14HashTableEntryIKiEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3PtrC2ERNS0_14HashTableEntryIS2_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryIKiE12setCollisionEj($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2jsL7ReverseIiEEvPT_S2_1995($beg, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_0 = $beg;
    var $_01 = $end;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $_0;
    if (($_0 | 0) == ($_01 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $4 = $_01 - 4 | 0;
    if (($4 | 0) == ($_0 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = HEAP32[$_0 >> 2];
    var $8 = HEAP32[$4 >> 2];
    HEAP32[$_0 >> 2] = $8;
    HEAP32[$4 >> 2] = $7;
    var $_0 = $_0 + 4 | 0;
    var $_01 = $4;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_EC2ES5_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  return;
}

function __ZL14random_setSeedP9JSContextx($cx, $seed$0, $seed$1) {
  var $2$1 = $seed$1 & 65535 ^ 5;
  var $3 = $cx + 212 | 0;
  HEAP32[$3 >> 2] = $seed$0 & -1 ^ -554899859;
  HEAP32[$3 + 4 >> 2] = $2$1;
  return;
}

function __ZN2js6detail14HashTableEntryIKiEaSENS_7MoveRefIS3_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryIKiEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $2 + 4 | 0;
  __ZN2js4MoveIiEENS_7MoveRefIT_EERS2_($1, $6);
  var $_idx_val = HEAP32[$1 >> 2];
  var $7 = __ZNK2js7MoveRefIiEcvRiEv($_idx_val);
  var $8 = HEAP32[$7 >> 2];
  HEAP32[$this + 4 >> 2] = $8;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryIKiEEEENS_7MoveRefIT_EERS6_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKiEEEC1ERS4_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKiEEEC1ERS4_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKiEEEC2ERS4_($this, $t);
  return;
}

function __ZN2js4MoveIiEENS_7MoveRefIT_EERS2_($agg_result, $t) {
  __ZN2js7MoveRefIiEC1ERi($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIiEC1ERi($this, $t) {
  __ZN2js7MoveRefIiEC2ERi($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryIKiEC1Ev($this) {
  __ZN2js6detail14HashTableEntryIKiEC2Ev($this);
  return;
}

function __ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryIKiE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E12lookupForAddERS2_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E11prepareHashERS2_($l_val);
  var $2 = __ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E6lookupERS2_jj($this, $l, $1);
  __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E6AddPtrC1ERNS0_14HashTableEntryIS2_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E11prepareHashERS2_($l_val) {
  var $1 = __ZN12IdHashPolicy4hashEi($l_val);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E6lookupERS2_jj($this, $l, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 3) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryIKiE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryIKiE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $l_val4 = HEAP32[$l >> 2];
    var $11 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5matchERNS0_14HashTableEntryIS2_EERS2_($6, $l_val4);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryIKiE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryIKiE12setCollisionEj($entry_0);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + ($26 << 3) | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryIKiE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryIKiE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $l_val = HEAP32[$l >> 2];
    var $35 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5matchERNS0_14HashTableEntryIS2_EERS2_($27, $l_val);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E6lookupERS2_jj["X"] = 1;

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E6AddPtrC1ERNS0_14HashTableEntryIS2_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E6AddPtrC2ERNS0_14HashTableEntryIS2_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E6AddPtrC2ERNS0_14HashTableEntryIS2_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3PtrC2ERNS0_14HashTableEntryIS2_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5matchERNS0_14HashTableEntryIS2_EERS2_($e, $l_val) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOps6getKeyERKi($1);
  var $3 = HEAP32[$2 >> 2];
  var $4 = __ZN12IdHashPolicy5matchEii($3, $l_val);
  return $4;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryIKiE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $roundUp_01 = 16;
    var $roundUpLog2_02 = 4;
    __label__ = 2;
    break;
   case 2:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $1 = $roundUp_01 << 1;
    var $2 = $roundUpLog2_02 + 1 | 0;
    if ($1 >>> 0 < 42) {
      var $roundUp_01 = $1;
      var $roundUpLog2_02 = $2;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $4 = $this | 0;
    var $5 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E11createTableERS5_j($4, $1);
    HEAP32[$this + 24 >> 2] = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E16setTableSizeLog2Ej($this, $2);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEEC2ES2_($this, $a_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_EC1ES5_($1, $a_0);
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_EC1ES5_($this, $ap_01) {
  __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_EC2ES5_($this, $ap_01);
  return;
}

function _JS_CeilingLog2($n) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($n >>> 0 < 2) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $n - 1 | 0;
    var $4 = _llvm_ctlz_i32($3);
    var $7 = 32 - $4 | 0;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9MathCacheC2Ev($this) {
  var $1 = $this;
  _memset($1, 0, 81920, 1);
  return;
}

function __Z11js_math_absP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $10 = _fabs($9);
    var $11 = __ZN2JS5Value9setNumberEd($vp, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_math_ceil_impld($x) {
  var $1 = _ceil($x);
  return $1;
}

function __Z12js_math_ceilP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $10 = __Z17js_math_ceil_impld($9);
    var $11 = __ZN2JS5Value9setNumberEd($vp, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18js_math_floor_impld($x) {
  var $1 = _floor($x);
  return $1;
}

function __Z13js_math_floorP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $10 = __Z18js_math_floor_impld($9);
    var $11 = __ZN2JS5Value9setNumberEd($vp, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z11js_math_maxP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    var $1 = (tempDoubleI32[0] = HEAP32[_js_NegativeInfinity >> 2], tempDoubleI32[1] = HEAP32[_js_NegativeInfinity + 4 >> 2], tempDoubleF64[0]);
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $cx;
    var $i_0 = 0;
    var $z_0 = $1;
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value9setDoubleEd($vp, $1);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 4:
    var $z_0;
    var $i_0;
    if ($i_0 >>> 0 < $argc >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 5:
    var $8 = $vp + ($i_0 + 2 << 3) | 0;
    var $9 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($3, $8, $x);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 6:
    var $11 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $12 = __ZL15JSDOUBLE_IS_NaNd2026($11);
    if (($12 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $15 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $15);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 8:
    if ($11 == 0 & $11 == $z_0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $20 = _copysign(1, $z_0);
    if ($20 == -1) {
      __label__ = 10;
      break;
    } else {
      var $z_1 = $z_0;
      __label__ = 12;
      break;
    }
   case 10:
    var $z_1 = $11;
    __label__ = 12;
    break;
   case 11:
    var $25 = $11 > $z_0 ? $11 : $z_0;
    var $z_1 = $25;
    __label__ = 12;
    break;
   case 12:
    var $z_1;
    var $i_0 = $i_0 + 1 | 0;
    var $z_0 = $z_1;
    __label__ = 4;
    break;
   case 13:
    var $29 = __ZN2JS5Value9setNumberEd($vp, $z_0);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z11js_math_minP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    var $1 = (tempDoubleI32[0] = HEAP32[_js_PositiveInfinity >> 2], tempDoubleI32[1] = HEAP32[_js_PositiveInfinity + 4 >> 2], tempDoubleF64[0]);
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $cx;
    var $i_0 = 0;
    var $z_0 = $1;
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value9setDoubleEd($vp, $1);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 4:
    var $z_0;
    var $i_0;
    if ($i_0 >>> 0 < $argc >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 5:
    var $8 = $vp + ($i_0 + 2 << 3) | 0;
    var $9 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($3, $8, $x);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 6:
    var $11 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $12 = __ZL15JSDOUBLE_IS_NaNd2026($11);
    if (($12 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $15 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $15);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 8:
    if ($11 == 0 & $11 == $z_0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $20 = _copysign(1, $11);
    if ($20 == -1) {
      __label__ = 10;
      break;
    } else {
      var $z_1 = $z_0;
      __label__ = 12;
      break;
    }
   case 10:
    var $z_1 = $11;
    __label__ = 12;
    break;
   case 11:
    var $25 = $11 < $z_0 ? $11 : $z_0;
    var $z_1 = $25;
    __label__ = 12;
    break;
   case 12:
    var $z_1;
    var $i_0 = $i_0 + 1 | 0;
    var $z_0 = $z_1;
    __label__ = 4;
    break;
   case 13:
    var $29 = __ZN2JS5Value9setNumberEd($vp, $z_0);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z11js_math_powP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    var $y = __stackBase__ + 8;
    if ($argc >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 4:
    var $9 = $vp + 24 | 0;
    var $10 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $9, $y);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 5:
    var $12 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $13 = __ZL18JSDOUBLE_IS_FINITEd2027($12);
    var $or_cond = ($13 | 0) != 0 & $12 != 0;
    var $16 = (tempDoubleI32[0] = HEAP32[$y >> 2], tempDoubleI32[1] = HEAP32[$y + 4 >> 2], tempDoubleF64[0]);
    if ($or_cond) {
      __label__ = 6;
      break;
    } else {
      var $28 = $16;
      __label__ = 10;
      break;
    }
   case 6:
    if ($16 == .5) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = _sqrt($12);
    var $21 = __ZN2JS5Value9setNumberEd($vp, $20);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 8:
    if ($16 == -.5) {
      __label__ = 9;
      break;
    } else {
      var $28 = $16;
      __label__ = 10;
      break;
    }
   case 9:
    var $25 = _sqrt($12);
    var $26 = 1 / $25;
    var $27 = __ZN2JS5Value9setNumberEd($vp, $26);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 10:
    var $28;
    var $29 = __ZL18JSDOUBLE_IS_FINITEd2027($28);
    if (($29 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    if ($12 == 1 | $12 == -1) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $35 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $35);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 13:
    if ($28 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    __ZN2JS5Value8setInt32Ei($vp, 1);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 15:
    var $_idx1 = $9 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $39 = __ZNK2JS5Value7isInt32Ev($_idx1_val$0, $_idx1_val$1);
    if ($39) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $41 = __ZNK2JS5Value7toInt32Ev($_idx1_val$0, $_idx1_val$1);
    var $42 = __ZL4powidi($12, $41);
    var $z_0 = $42;
    __label__ = 18;
    break;
   case 17:
    var $44 = _llvm_pow_f64($12, $28);
    var $z_0 = $44;
    __label__ = 18;
    break;
   case 18:
    var $z_0;
    var $46 = __ZN2JS5Value9setNumberEd($vp, $z_0);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z11js_math_powP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL4powidi($x, $y) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($y | 0) < 0;
    var $3 = $1 ? -$y | 0 : $y;
    var $p_0 = 1;
    var $m_0 = $x;
    var $n_0 = $3;
    __label__ = 2;
    break;
   case 2:
    var $n_0;
    var $m_0;
    var $p_0;
    if (($n_0 & 1 | 0) == 0) {
      var $p_1 = $p_0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $p_1 = $p_0 * $m_0;
    __label__ = 4;
    break;
   case 4:
    var $p_1;
    var $10 = $n_0 >>> 1;
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 5:
    if ($1) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $p_1;
      __label__ = 10;
      break;
    }
   case 6:
    var $14 = 1 / $p_1;
    if ($14 == 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = $14;
      __label__ = 10;
      break;
    }
   case 7:
    var $17 = __ZL20JSDOUBLE_IS_INFINITEd($p_1);
    if (($17 | 0) == 0) {
      var $_0 = $14;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = $y | 0;
    var $21 = _llvm_pow_f64($x, $20);
    var $_0 = $21;
    __label__ = 10;
    break;
   case 9:
    var $p_0 = $p_1;
    var $m_0 = $m_0 * $m_0;
    var $n_0 = $10;
    __label__ = 2;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z13js_InitRandomP9JSContext($cx) {
  var $1 = _PRMJ_Now();
  var $1$0 = $1[0];
  var $1$1 = $1[1];
  var $2$0 = (i64Math.divide($1$0, $1$1, 1e3, 0), i64Math.result[0]);
  var $2$1 = i64Math.result[1];
  var $10$0 = $2$0 ^ $cx ^ HEAP32[$cx >> 2];
  var $10$1 = $2$1 ^ 0 ^ 0;
  __ZL14random_setSeedP9JSContextx($cx, $10$0, $10$1);
  return;
}

function __Z13js_math_roundP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $10 = $9 + .5;
    var $11 = _floor($10);
    var $12 = _copysign($11, $9);
    var $13 = __ZN2JS5Value9setNumberEd($vp, $12);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z12js_math_sqrtP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZN2jsL12GetMathCacheEP9JSContext($cx);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $13 = __ZN2js9MathCache6lookupEPFddEd($9, 152, $12);
    __ZN2JS5Value9setDoubleEd($vp, $13);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL12GetMathCacheEP9JSContext($cx) {
  var $2 = HEAP32[$cx + 56 >> 2];
  var $3 = __ZN13JSCompartment12getMathCacheEP9JSContext($2, $cx);
  return $3;
}

function __ZN2js9MathCache6lookupEPFddEd($this, $f, $x) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js9MathCache4hashEd($x);
    var $2 = $this + $1 * 20 | 0;
    var $3 = (tempDoubleI32[0] = HEAP32[$2 >> 2], tempDoubleI32[1] = HEAP32[$2 + 4 >> 2], tempDoubleF64[0]);
    var $5 = $this + $1 * 20 + 8 | 0;
    if ($3 == $x) {
      __label__ = 2;
      break;
    } else {
      var $_pre_phi = $5;
      __label__ = 4;
      break;
    }
   case 2:
    if ((HEAP32[$5 >> 2] | 0) == ($f | 0)) {
      __label__ = 3;
      break;
    } else {
      var $_pre_phi = $5;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = $this + $1 * 20 + 12 | 0;
    var $11 = (tempDoubleI32[0] = HEAP32[$10 >> 2], tempDoubleI32[1] = HEAP32[$10 + 4 >> 2], tempDoubleF64[0]);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 4:
    var $_pre_phi;
    tempDoubleF64[0] = $x, HEAP32[$2 >> 2] = tempDoubleI32[0], HEAP32[$2 + 4 >> 2] = tempDoubleI32[1];
    HEAP32[$_pre_phi >> 2] = $f;
    var $12 = FUNCTION_TABLE[$f]($x);
    var $13 = $this + $1 * 20 + 12 | 0;
    tempDoubleF64[0] = $12, HEAP32[$13 >> 2] = tempDoubleI32[0], HEAP32[$13 + 4 >> 2] = tempDoubleI32[1];
    var $_0 = $12;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13math_toSourceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210048 >> 2] | 0;
  __ZN2JS5Value9setStringEP8JSString($vp, $5);
  return 1;
}

function __ZL9math_acosP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZN2jsL12GetMathCacheEP9JSContext($cx);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $13 = __ZN2js9MathCache6lookupEPFddEd($9, 154, $12);
    __ZN2JS5Value9setDoubleEd($vp, $13);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9math_asinP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZN2jsL12GetMathCacheEP9JSContext($cx);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $13 = __ZN2js9MathCache6lookupEPFddEd($9, 156, $12);
    __ZN2JS5Value9setDoubleEd($vp, $13);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9math_atanP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZN2jsL12GetMathCacheEP9JSContext($cx);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $13 = __ZN2js9MathCache6lookupEPFddEd($9, 158, $12);
    __ZN2JS5Value9setDoubleEd($vp, $13);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10math_atan2P9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    var $y = __stackBase__ + 8;
    if ($argc >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = $vp + 24 | 0;
    var $10 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $9, $y);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $12 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $13 = (tempDoubleI32[0] = HEAP32[$y >> 2], tempDoubleI32[1] = HEAP32[$y + 4 >> 2], tempDoubleF64[0]);
    var $14 = __ZL17math_atan2_kerneldd($12, $13);
    __ZN2JS5Value9setDoubleEd($vp, $14);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8math_cosP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZN2jsL12GetMathCacheEP9JSContext($cx);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $13 = __ZN2js9MathCache6lookupEPFddEd($9, 160, $12);
    __ZN2JS5Value9setDoubleEd($vp, $13);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16GetClassProtoKeyEPNS_5ClassE2046() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[__ZN2js9MathClassE + 4 >> 2];
    var $2 = $1 >>> 24;
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $1 >>> 17 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9MathCache4hashEd($x) {
  tempDoubleF64[0] = $x;
  var $4 = tempDoubleI32[1] ^ tempDoubleI32[0];
  var $6 = $4 & 65535 ^ $4 >>> 16;
  return $6 & 4095 ^ $6 >>> 4;
}

function __ZL20JSDOUBLE_IS_INFINITEd($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & -1) == 0 && (tempDoubleI32[1] & 2147483647) == 2146435072) & 1;
}

function __ZN2js2gcL15GetGCObjectKindEjb2034($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13IMPL_TO_JSVAL12jsval_layout2047($agg_result, $l_0$0, $l_0$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $l_0$0;
  HEAP32[$1 + 4 >> 2] = $l_0$1;
  return;
}

function _OBJECT_TO_JSVAL_IMPL2048($agg_result, $obj) {
  HEAP32[$agg_result + 4 >> 2] = -121;
  HEAP32[$agg_result >> 2] = $obj;
  return;
}

function __ZL11random_nextP9JSContexti($cx, $bits) {
  var $1 = $cx + 212 | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3$0 = (i64Math.multiply($2$0, $2$1, -554899859, 5), i64Math.result[0]);
  var $3$1 = i64Math.result[1];
  var $4$0 = (i64Math.add($3$0, $3$1, 11, 0), i64Math.result[0]);
  var $4$1 = i64Math.result[1];
  var $5$0 = $4$0 & -1;
  var $5$1 = $4$1 & 65535;
  HEAP32[$1 >> 2] = $5$0;
  HEAP32[$1 + 4 >> 2] = $5$1;
  var $7$0 = 48 - $bits | 0;
  var $8 = Runtime.bitshift64($5$0, $5$1, "lshr", $7$0);
  return [ $8[0], $8[1] ];
}

function __ZN2js12ToCStringBufC2Ev($this) {
  HEAP32[$this + 36 >> 2] = 0;
  return;
}

function __ZL8math_expP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZN2jsL12GetMathCacheEP9JSContext($cx);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $13 = __ZN2js9MathCache6lookupEPFddEd($9, 162, $12);
    var $14 = __ZN2JS5Value9setNumberEd($vp, $13);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8math_logP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZN2jsL12GetMathCacheEP9JSContext($cx);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $13 = __ZN2js9MathCache6lookupEPFddEd($9, 164, $12);
    var $14 = __ZN2JS5Value9setNumberEd($vp, $13);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11math_randomP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL17random_nextDoubleP9JSContext($cx);
  __ZN2JS5Value9setDoubleEd($vp, $1);
  return 1;
}

function __ZL8math_sinP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZN2jsL12GetMathCacheEP9JSContext($cx);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $13 = __ZN2js9MathCache6lookupEPFddEd($9, 166, $12);
    __ZN2JS5Value9setDoubleEd($vp, $13);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8math_tanP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZN2jsL12GetMathCacheEP9JSContext($cx);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $13 = __ZN2js9MathCache6lookupEPFddEd($9, 168, $12);
    __ZN2JS5Value9setDoubleEd($vp, $13);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_InitMathClassP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2032($cx, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    var $6 = $cx;
    __ZN8JSObject16setSingletonTypeEP9JSContext($5, $6);
    _OBJECT_TO_JSVAL2033($1, $2);
    var $7 = $cx;
    var $8 = $obj;
    var $_idx1 = $1 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $$emscripten$temp$0 = STRING_TABLE._js_Math_str | 0;
    var $9 = _JS_DefineProperty($7, $8, $$emscripten$temp$0, $_idx1_val$0, $_idx1_val$1, 10, 12, 0);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $2;
    var $13 = _JS_DefineFunctions($7, $12, __ZL19math_static_methods);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = _JS_DefineConstDoubles($7, $12, __ZL14math_constants);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = $obj;
    var $_idx_val = HEAP32[__ZN2js9MathClassE + 4 >> 2];
    __ZN2js35MarkStandardClassInitializedNoProtoEP8JSObjectPNS_5ClassE($19, $_idx_val);
    var $_0 = $2;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2032($cx, $parent) {
  var $3 = HEAPU32[__ZN2js9MathClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb2034($3);
  var $5 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2035($cx, $parent, $4);
  return $5;
}

function _OBJECT_TO_JSVAL2033($agg_result, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL_IMPL2048($1, $obj);
    var $_0 = $1 | 0;
    var $_0_val$0 = HEAP32[$_0 >> 2];
    var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
    __ZL13IMPL_TO_JSVAL12jsval_layout2047($agg_result, $_0_val$0, $_0_val$1);
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $6 = $agg_result | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2035($cx, $parent, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = 0;
    var $2 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_2036($cx, $parent, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 2:
    var $4 = HEAP32[$1 >> 2];
    var $5 = ($4 | 0) == 0;
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = __ZN2js5types15emptyTypeObjectE;
    var $_pre_phi = $cx;
    __label__ = 5;
    break;
   case 4:
    var $7 = $4;
    var $8 = $cx;
    var $9 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($7, $8, 0, 0);
    var $10 = $9;
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      var $12 = $10;
      var $_pre_phi = $8;
      __label__ = 5;
      break;
    }
   case 5:
    var $_pre_phi;
    var $12;
    var $13 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($_pre_phi, $kind);
    var $14 = $13;
    if (($13 | 0) == 0) {
      var $_0 = $14;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_not = ($parent | 0) == 0 ^ 1;
    var $parent_mux = $_not ? $parent : 0;
    if ($_not | $5) {
      var $23 = $parent_mux;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx_val = HEAP32[$4 + 20 >> 2];
    var $20 = __ZNK8JSObject9getParentEv($_idx_val);
    var $23 = $20;
    __label__ = 8;
    break;
   case 8:
    var $23;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($13, __ZN2js9MathClassE, $12, $23, 0, (__ZN2js9MathClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $_idx1_val = HEAP32[__ZN2js9MathClassE + 4 >> 2];
    var $26 = __ZNK2js5Class8isNativeEv($_idx1_val);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $28 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2039($cx, $14, $12, $kind);
    if ($28) {
      var $_0 = $14;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 0;
    __label__ = 12;
    break;
   case 11:
    __ZN8JSObject21setSharedNonNativeMapEv($13);
    var $_0 = $14;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_2036($cx, $parent, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL16GetClassProtoKeyEPNS_5ClassE2046();
    var $2 = $cx;
    var $3 = $parent;
    var $4 = $proto;
    var $5 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, $1, $4, __ZN2js9MathClassE);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$proto >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, 1, $4, 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2039($cx, $obj, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAPU32[__ZN2js9MathClassE + 4 >> 2] >>> 8 & 255;
    var $4 = $obj;
    var $_idx_val = HEAP32[$obj + 28 >> 2];
    var $6 = __ZNK8JSObject8numSlotsEv($_idx_val);
    if ($3 >>> 0 > $6 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $obj;
    var $10 = $cx;
    var $11 = __ZN8JSObject10allocSlotsEP9JSContextj($9, $10, $3);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $13 = $type;
    var $14 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($13, __ZN2js9MathClassE);
    var $15 = $cx;
    if ($14) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($13, $15, __ZN2js9MathClassE, $kind);
    var $empty_0_in = $17;
    __label__ = 6;
    break;
   case 5:
    var $19 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($15, __ZN2js9MathClassE);
    var $empty_0_in = $19;
    __label__ = 6;
    break;
   case 6:
    var $empty_0_in;
    if (($empty_0_in | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $empty_0_in | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17random_nextDoubleP9JSContext($cx) {
  var $1 = __ZL11random_nextP9JSContexti($cx, 26);
  var $1$0 = $1[0];
  var $2$0 = $1$0 << 27 | 0 >>> 5;
  var $2$1 = $1[1] << 27 | $1$0 >>> 5;
  var $3 = __ZL11random_nextP9JSContexti($cx, 27);
  var $3$0 = $3[0];
  var $3$1 = $3[1];
  var $4$0 = (i64Math.add($2$0, $2$1, $3$0, $3$1), i64Math.result[0]);
  var $4$1 = i64Math.result[1];
  return ($4$0 + $4$1 * 4294967296) * 1.1102230246251565e-16;
}

function __ZL13math_exp_bodyd($d) {
  var $1 = _exp($d);
  return $1;
}

function __ZL17math_atan2_kerneldd($x, $y) {
  var $1 = _atan2($x, $y);
  return $1;
}

function __ZN13JSCompartment12getMathCacheEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 1904 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $10 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this;
    var $6 = $cx;
    var $7 = __ZN13JSCompartment14allocMathCacheEP9JSContext($5, $6);
    var $10 = $7;
    __label__ = 3;
    break;
   case 3:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js22GetNativeStackBaseImplEv() {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var $sattr = __stackBase__;
  var $stackBase = __stackBase__ + 32;
  var $stackSize = __stackBase__ + 36;
  var $1 = _pthread_self();
  var $2 = _pthread_attr_init($sattr);
  var $3 = _pthread_getattr_np($1, $sattr);
  HEAP32[$stackBase >> 2] = 0;
  HEAP32[$stackSize >> 2] = 0;
  var $4 = _pthread_attr_getstack($sattr, $stackBase, $stackSize);
  var $5 = _pthread_attr_destroy($sattr);
  var $6 = HEAP32[$stackBase >> 2];
  STACKTOP = __stackBase__;
  return $6;
}

function __ZN2js16GetPrefixIntegerEP9JSContextPKtS3_iPS3_Pd($cx, $start, $end, $base, $endp, $dp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $base | 0;
    var $d_0 = 0;
    var $s_0 = $start;
    __label__ = 2;
    break;
   case 2:
    var $s_0;
    var $d_0;
    if ($s_0 >>> 0 < $end >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 3:
    var $5 = HEAPU16[$s_0 >> 1];
    var $6 = $5 & 65535;
    if (($5 - 48 & 65535 & 65535) < 10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $digit_0 = $6 - 48 | 0;
    __label__ = 9;
    break;
   case 5:
    if (($5 - 97 & 65535 & 65535) < 26) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $digit_0 = $6 - 87 | 0;
    __label__ = 9;
    break;
   case 7:
    if (($5 - 65 & 65535 & 65535) < 26) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $digit_0 = $6 - 55 | 0;
    __label__ = 9;
    break;
   case 9:
    var $digit_0;
    if (($digit_0 | 0) < ($base | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $d_0 = $d_0 * $1 + ($digit_0 | 0);
    var $s_0 = $s_0 + 2 | 0;
    __label__ = 2;
    break;
   case 11:
    HEAP32[$endp >> 2] = $s_0;
    tempDoubleF64[0] = $d_0, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    if ($d_0 < 9007199254740992) {
      var $_0 = 1;
      __label__ = 16;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (($base | 0) == 10) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $30 = __ZL29ComputeAccurateDecimalIntegerP9JSContextPKtS2_Pd($cx, $start, $s_0, $dp);
    var $_0 = $30;
    __label__ = 16;
    break;
   case 14:
    if (($base - 1 & $base | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 1;
      __label__ = 16;
      break;
    }
   case 15:
    var $36 = __ZL32ComputeAccurateBinaryBaseIntegerP9JSContextPKtS2_i($start, $s_0, $base);
    tempDoubleF64[0] = $36, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL29ComputeAccurateDecimalIntegerP9JSContextPKtS2_Pd($cx, $start, $end, $dp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $estr = __stackBase__;
    var $err = __stackBase__ + 4;
    var $4 = $end - $start >> 1;
    var $5 = $4 + 1 | 0;
    var $6 = __ZN9JSContext7malloc_Ej($cx, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 3;
      break;
    }
   case 3:
    var $i_01;
    HEAP8[$6 + $i_01 | 0] = HEAP16[$start + ($i_01 << 1) >> 1] & 255;
    var $13 = $i_01 + 1 | 0;
    if (($13 | 0) == ($4 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $i_01 = $13;
      __label__ = 3;
      break;
    }
   case 4:
    HEAP8[$6 + $4 | 0] = 0;
    HEAP32[$err >> 2] = 0;
    var $18 = HEAP32[HEAP32[$cx + 52 >> 2] + 209876 >> 2];
    var $19 = _js_strtod_harder($18, $6, $estr, $err);
    tempDoubleF64[0] = $19, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $20 = HEAP32[$err >> 2];
    if (($20 | 0) == 2) {
      __label__ = 5;
      break;
    } else if (($20 | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    _JS_ReportOutOfMemory($cx);
    __ZN9JSContext5free_EPv($6);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 6:
    if ($19 == Infinity) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $25 = (tempDoubleI32[0] = HEAP32[_js_PositiveInfinity >> 2], tempDoubleI32[1] = HEAP32[_js_PositiveInfinity + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $25, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    __label__ = 8;
    break;
   case 8:
    __ZN9JSContext5free_EPv($6);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL32ComputeAccurateBinaryBaseIntegerP9JSContextPKtS2_i($start, $end, $base) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $bdr = __stackBase__;
    __ZN17BinaryDigitReaderC1EiPKtS1_($bdr, $base, $start, $end);
    __label__ = 2;
    break;
   case 2:
    var $2 = __ZN17BinaryDigitReader9nextDigitEv($bdr);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $j_0 = 52;
      var $value_0 = 1;
      var $bit_0 = $2;
      __label__ = 3;
      break;
    }
   case 3:
    var $bit_0;
    var $value_0;
    var $j_0;
    var $4 = ($j_0 | 0) > 0;
    var $5 = __ZN17BinaryDigitReader9nextDigitEv($bdr);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    if (($5 | 0) < 0) {
      var $_0 = $value_0;
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $j_0 = $j_0 - 1 | 0;
    var $value_0 = $value_0 * 2 + ($5 | 0);
    var $bit_0 = $5;
    __label__ = 3;
    break;
   case 6:
    if (($5 | 0) > -1) {
      __label__ = 7;
      break;
    } else {
      var $_0 = $value_0;
      __label__ = 10;
      break;
    }
   case 7:
    var $15 = __ZN17BinaryDigitReader9nextDigitEv($bdr);
    if (($15 | 0) > -1) {
      var $factor_01 = 2;
      var $sticky_02 = 0;
      var $17 = $15;
      __label__ = 8;
      break;
    } else {
      var $factor_0_lcssa = 2;
      var $sticky_0_lcssa = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $17;
    var $sticky_02;
    var $factor_01;
    var $18 = $17 | $sticky_02;
    var $19 = $factor_01 * 2;
    var $20 = __ZN17BinaryDigitReader9nextDigitEv($bdr);
    if (($20 | 0) > -1) {
      var $factor_01 = $19;
      var $sticky_02 = $18;
      var $17 = $20;
      __label__ = 8;
      break;
    } else {
      var $factor_0_lcssa = $19;
      var $sticky_0_lcssa = $18;
      __label__ = 9;
      break;
    }
   case 9:
    var $sticky_0_lcssa;
    var $factor_0_lcssa;
    var $_0 = ($value_0 + (($sticky_0_lcssa | $bit_0) & $5 | 0)) * $factor_0_lcssa;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9num_isNaNP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($vp, 1);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $4 = $vp + 16 | 0;
    var $5 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $4, $x);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $8 = __ZL15JSDOUBLE_IS_NaNd2114($7);
    var $9 = ($8 | 0) != 0;
    __ZN2JS5Value10setBooleanEb($vp, $9);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12num_isFiniteP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($vp, 0);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $4 = $vp + 16 | 0;
    var $5 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $4, $x);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $8 = __ZL18JSDOUBLE_IS_FINITEd2111($7);
    var $9 = ($8 | 0) != 0;
    __ZN2JS5Value10setBooleanEb($vp, $9);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14num_parseFloatP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $ep = __stackBase__ + 8;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    var $5 = $cx;
    var $_idx1 = $vp + 16 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $6 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($5, $_idx1_val$0, $_idx1_val$1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZN8JSString8getCharsEP9JSContext($6, $cx);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx_val = HEAP32[$6 >> 2];
    var $12 = __ZNK8JSString6lengthEv($_idx_val);
    var $13 = $9 + ($12 << 1) | 0;
    var $14 = __Z9js_strtodP9JSContextPKtS2_PS2_Pd($cx, $9, $13, $ep, $d);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$ep >> 2] | 0) == ($9 | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $20);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 8:
    var $22 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $23 = __ZN2JS5Value9setNumberEd($vp, $22);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12num_parseIntP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $radix = __stackBase__;
    var $number = __stackBase__ + 4;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($argc | 0) == 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $2 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $2);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 3:
    var $_idx4 = $vp + 24 | 0;
    var $st$1$0 = $_idx4 | 0;
    var $_idx4_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx4 + 4 | 0;
    var $_idx4_val$1 = HEAP32[$st$1$1 >> 2];
    var $4 = __ZNK2JS5Value7isInt32Ev($_idx4_val$0, $_idx4_val$1);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 4:
    var $6 = __ZNK2JS5Value7toInt32Ev($_idx4_val$0, $_idx4_val$1);
    if (($6 | 0) == 0 || ($6 | 0) == 10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 5:
    var $8 = $vp + 16 | 0;
    var $_idx3 = $8 | 0;
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    var $9 = __ZNK2JS5Value7isInt32Ev($_idx3_val$0, $_idx3_val$1);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $11 = $vp | 0;
    var $st$1$0 = $11 | 0;
    HEAP32[$st$1$0 >> 2] = $_idx3_val$0;
    var $st$1$1 = $11 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $_idx3_val$1;
    var $_0 = 1;
    __label__ = 21;
    break;
   case 7:
    var $13 = __ZNK2JS5Value8isDoubleEv($_idx3_val$0, $_idx3_val$1);
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $15 = __ZNK2JS5Value8toDoubleEv($8);
    if ($15 > -1e+21 & $15 < 1e+21) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $19 = __ZL20ParseIntDoubleHelperd($15);
    var $20 = __ZN2JS5Value9setNumberEd($vp, $19);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 10:
    var $21 = $vp + 16 | 0;
    var $22 = $cx;
    var $_idx5 = $21 | 0;
    var $_idx5_val$0 = HEAP32[$_idx5 >> 2];
    var $_idx5_val$1 = HEAP32[$_idx5 + 4 >> 2];
    var $23 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($22, $_idx5_val$0, $_idx5_val$1);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2JS5Value9setStringEP8JSString($21, $23);
    HEAP32[$radix >> 2] = 0;
    if ($argc >>> 0 > 1) {
      __label__ = 12;
      break;
    } else {
      var $stripPrefix_0 = 1;
      var $41 = 0;
      __label__ = 18;
      break;
    }
   case 12:
    var $28 = $vp + 24 | 0;
    var $29 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $28, $radix);
    if ($29) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 13:
    var $31 = HEAPU32[$radix >> 2];
    if (($31 | 0) == 0) {
      var $stripPrefix_0 = 1;
      var $41 = $31;
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    if (($31 - 2 | 0) >>> 0 > 34) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $36 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $36);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 16:
    if (($31 | 0) == 16) {
      var $stripPrefix_0 = 1;
      var $41 = $31;
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $stripPrefix_0 = 0;
    var $41 = $31;
    __label__ = 18;
    break;
   case 18:
    var $41;
    var $stripPrefix_0;
    var $42 = __ZN8JSString8getCharsEP9JSContext($23, $cx);
    if (($42 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $_idx1_val = HEAP32[$23 >> 2];
    var $45 = __ZNK8JSString6lengthEv($_idx1_val);
    var $46 = $42 + ($45 << 1) | 0;
    var $47 = __ZL20ParseIntStringHelperP9JSContextPKtS2_ibPd($cx, $42, $46, $41, $stripPrefix_0, $number);
    if ($47) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 20:
    var $49 = (tempDoubleI32[0] = HEAP32[$number >> 2], tempDoubleI32[1] = HEAP32[$number + 4 >> 2], tempDoubleF64[0]);
    var $50 = __ZN2JS5Value9setNumberEd($vp, $49);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12num_parseIntP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2js12ToCStringBufD2Ev($this_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_1_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js10Foreground5free_EPv($this_0_1_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z14js_IntToStringP9JSContexti($cx, $si) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $end = __stackBase__;
    var $start = __stackBase__ + 4;
    if (($si | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZN2js13StaticStrings6hasIntEi($si);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $ui_0 = $si;
      __label__ = 5;
      break;
    }
   case 3:
    var $7 = HEAP32[$cx + 52 >> 2] + 210584 | 0;
    var $8 = __ZN2js13StaticStrings6getIntEi($7, $si);
    var $_0 = $8 | 0;
    __label__ = 11;
    break;
   case 4:
    var $ui_0 = -$si | 0;
    __label__ = 5;
    break;
   case 5:
    var $ui_0;
    var $15 = HEAP32[$cx + 56 >> 2] + 1888 | 0;
    var $16 = $si | 0;
    var $17 = __ZN2js9DtoaCache6lookupEid($15, 10, $16);
    if (($17 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_0 = $17 | 0;
    __label__ = 11;
    break;
   case 7:
    var $22 = __Z19js_NewGCShortStringP9JSContext($cx);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $25 = __ZN13JSShortString23inlineStorageBeforeInitEv($22);
    var $26 = $25 + 22 | 0;
    __ZN7mozilla9RangedPtrItEC1EPtS2_j($end, $26);
    var $end_idx_val = HEAP32[$end >> 2];
    var $27 = __ZNK7mozilla9RangedPtrItEdeEv($end_idx_val);
    HEAP16[$27 >> 1] = 0;
    __ZN2js25BackfillIndexInCharBufferItEEN7mozilla9RangedPtrIT_EEjS4_($start, $ui_0, $end_idx_val);
    if (($si | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $30 = __ZN7mozilla9RangedPtrItEmmEv($start);
    var $_idx_val = HEAP32[$30 >> 2];
    var $31 = __ZNK7mozilla9RangedPtrItEdeEv($_idx_val);
    HEAP16[$31 >> 1] = 45;
    __label__ = 10;
    break;
   case 10:
    var $start_idx_val = HEAP32[$start >> 2];
    var $33 = __ZNK7mozilla9RangedPtrItE3getEv($start_idx_val);
    var $34 = __ZNK7mozilla9RangedPtrItEmiERKS1_($end_idx_val, $start_idx_val);
    __ZN13JSShortString20initAtOffsetInBufferEPKtj($22, $33, $34);
    var $35 = $22 | 0;
    __ZN2js9DtoaCache5cacheEidP13JSFixedString($15, 10, $16, $35);
    var $_0 = $22 | 0;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z14js_IntToStringP9JSContexti["X"] = 1;

function __ZN2js13StaticStrings7hasUintEj($u) {
  return $u >>> 0 < 256;
}

function __ZN8JSObject8asNumberEv($this) {
  return $this;
}

function __ZN2js9DtoaCache6lookupEid($this, $base, $d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 12 >> 2];
    if (($2 | 0) == 0) {
      var $14 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$this + 8 >> 2] | 0) == ($base | 0)) {
      __label__ = 3;
      break;
    } else {
      var $14 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = $this | 0;
    var $10 = (tempDoubleI32[0] = HEAP32[$9 >> 2], tempDoubleI32[1] = HEAP32[$9 + 4 >> 2], tempDoubleF64[0]);
    if ($10 == $d) {
      __label__ = 4;
      break;
    } else {
      var $14 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = $2;
    __label__ = 5;
    break;
   case 5:
    var $14;
    return $14;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSShortString23inlineStorageBeforeInitEv($this) {
  return $this + 8 | 0;
}

function __ZN2js9DtoaCache5cacheEidP13JSFixedString($this, $base, $d, $s) {
  HEAP32[$this + 8 >> 2] = $base;
  var $2 = $this | 0;
  tempDoubleF64[0] = $d, HEAP32[$2 >> 2] = tempDoubleI32[0], HEAP32[$2 + 4 >> 2] = tempDoubleI32[1];
  HEAP32[$this + 12 >> 2] = $s;
  return;
}

function __ZN13JSShortString20initAtOffsetInBufferEPKtj($this, $chars, $length) {
  var $1 = __ZN8JSString19buildLengthAndFlagsEjj($length, 4);
  HEAP32[$this >> 2] = $1;
  HEAP32[$this + 4 >> 2] = $chars;
  return;
}

function __Z14js_num_valueOfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = __ZN2js16GetPrimitiveThisIdEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $d);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZN2JS5Value9setNumberEd($vp, $3);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16GetPrimitiveThisIdEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $_idx3 = $1 | 0;
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    var $2 = __ZN2js6detail17PrimitiveBehaviorIdE6isTypeERKN2JS5ValueE($_idx3_val$0, $_idx3_val$1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js6detail17PrimitiveBehaviorIdE7extractERKN2JS5ValueE($1);
    tempDoubleF64[0] = $4, HEAP32[$v >> 2] = tempDoubleI32[0], HEAP32[$v + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 7;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isObjectEv($_idx3_val$0, $_idx3_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toObjectEv($_idx3_val$0, $_idx3_val$1);
    var $_idx2_val = HEAP32[$8 + 4 >> 2];
    var $9 = __ZNK8JSObject8getClassEv($_idx2_val);
    if (($9 | 0) == (__ZN2js11NumberClassE | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $12 = $8;
    var $13 = __ZNK8JSObject16getPrimitiveThisEv($12);
    var $14 = __ZN2js6detail17PrimitiveBehaviorIdE7extractERKN2JS5ValueE($13);
    tempDoubleF64[0] = $14, HEAP32[$v >> 2] = tempDoubleI32[0], HEAP32[$v + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 7;
    break;
   case 6:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js11NumberClassE);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12num_toSourceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 112;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $cbuf = __stackBase__ + 8;
    var $buf = __stackBase__ + 48;
    var $1 = __ZN2js16GetPrimitiveThisIdEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $d);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    __ZN2js12ToCStringBufC2Ev($cbuf);
    var $3 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZN2js15NumberToCStringEP9JSContextPNS_12ToCStringBufEdi($cx, $cbuf, $3);
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportOutOfMemory($cx);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    var $8 = $buf | 0;
    var $9 = HEAP32[__ZN2js11NumberClassE >> 2];
    var $10 = _JS_snprintf($8, 64, STRING_TABLE.__str122090 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $9, HEAP32[tempInt + 4 >> 2] = $4, tempInt));
    var $11 = $cx;
    var $12 = __Z17js_NewStringCopyZP9JSContextPKc($11, $8);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = $12 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $15);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    var $cbuf_idx_val = HEAP32[$cbuf + 36 >> 2];
    __ZN2js12ToCStringBufD2Ev($cbuf_idx_val);
    var $_1 = $_0;
    __label__ = 7;
    break;
   case 7:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12num_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $d2 = __stackBase__ + 8;
    var $1 = __ZN2js16GetPrimitiveThisIdEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $d);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    if (($argc | 0) == 0) {
      var $base_0 = 10;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = $vp + 16 | 0;
    var $_idx = $5 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $6 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($6) {
      var $base_0 = 10;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd2159($cx, $5, $d2);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $10 = (tempDoubleI32[0] = HEAP32[$d2 >> 2], tempDoubleI32[1] = HEAP32[$d2 + 4 >> 2], tempDoubleF64[0]);
    if ($10 < 2 | $10 > 36) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 4, 33, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 11;
    break;
   case 7:
    var $base_0 = $10 & -1;
    __label__ = 8;
    break;
   case 8:
    var $base_0;
    var $17 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $18 = __ZL25js_NumberToStringWithBaseP9JSContextdi($cx, $17, $base_0);
    if (($18 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportOutOfMemory($cx);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 10:
    __ZN2JS5Value9setStringEP8JSString($vp, $18);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18num_toLocaleStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $numBytes = __stackBase__;
    var $1 = __ZL12num_toStringP9JSContextjPN2JS5ValueE($cx, 0, $vp);
    if (($1 | 0) == 0) {
      var $_1 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $4 = __ZNK2JS5Value8toStringEv($vp_idx_val$0, $vp_idx_val$1);
    var $5 = $cx;
    __ZN16JSAutoByteStringC1EP9JSContextP8JSString($numBytes, $5, $4);
    var $numBytes_idx2 = $numBytes | 0;
    var $numBytes_idx2_val = HEAP32[$numBytes_idx2 >> 2];
    var $6 = __ZNK16JSAutoByteStringntEv($numBytes_idx2_val);
    if ($6) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK16JSAutoByteString3ptrEv($numBytes_idx2_val);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = HEAP8[$8] << 24 >> 24 == 45;
    var $nint_0_ph = $11 ? $8 + 1 | 0 : $8;
    var $13 = HEAPU8[$nint_0_ph];
    if (($13 - 48 & 255 & 255) < 10) {
      var $nint_017 = $nint_0_ph;
      __label__ = 5;
      break;
    } else {
      var $nint_0_lcssa = $nint_0_ph;
      var $_lcssa15 = $13;
      __label__ = 6;
      break;
    }
   case 5:
    var $nint_017;
    var $15 = $nint_017 + 1 | 0;
    var $16 = HEAPU8[$15];
    if (($16 - 48 & 255 & 255) < 10) {
      var $nint_017 = $15;
      __label__ = 5;
      break;
    } else {
      var $nint_0_lcssa = $15;
      var $_lcssa15 = $16;
      __label__ = 6;
      break;
    }
   case 6:
    var $_lcssa15;
    var $nint_0_lcssa;
    var $20 = $nint_0_lcssa - $8 | 0;
    var $21 = $8 + $20 | 0;
    if (($nint_0_lcssa | 0) == ($8 | 0)) {
      var $_0 = 1;
      __label__ = 31;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = HEAPU32[$cx + 52 >> 2];
    var $26 = $25 + 144260 | 0;
    var $27 = HEAP32[$26 >> 2];
    var $28 = _strlen($27);
    var $29 = $25 + 144264 | 0;
    var $30 = HEAP32[$29 >> 2];
    var $31 = _strlen($30);
    var $32 = _strlen($8);
    if ($_lcssa15 << 24 >> 24 == 46) {
      __label__ = 8;
      break;
    } else {
      var $buflen_0 = $32;
      __label__ = 9;
      break;
    }
   case 8:
    var $buflen_0 = $31 - 1 + $32 | 0;
    __label__ = 9;
    break;
   case 9:
    var $buflen_0;
    var $39 = HEAP32[$25 + 144268 >> 2];
    var $remainder_0 = ($11 << 31 >> 31) + $20 | 0;
    var $buflen_1 = $buflen_0;
    var $tmpGroup_0 = $39;
    __label__ = 10;
    break;
   case 10:
    var $tmpGroup_0;
    var $buflen_1;
    var $remainder_0;
    var $42 = HEAP8[$tmpGroup_0];
    var $43 = $42 << 24 >> 24;
    if ($42 << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else if ($42 << 24 >> 24 == 127) {
      var $nrepeat_0 = 0;
      var $remainder_1 = $remainder_0;
      var $buflen_2 = $buflen_1;
      __label__ = 16;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    if (($43 | 0) < ($remainder_0 | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $remainder_0 = $remainder_0 - $43 | 0;
    var $buflen_1 = $buflen_1 + $28 | 0;
    var $tmpGroup_0 = $tmpGroup_0 + 1 | 0;
    __label__ = 10;
    break;
   case 13:
    if ($42 << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      var $nrepeat_0 = 0;
      var $remainder_1 = $remainder_0;
      var $buflen_2 = $buflen_1;
      __label__ = 16;
      break;
    }
   case 14:
    if (HEAP8[$39] << 24 >> 24 == 0) {
      var $nrepeat_0 = 0;
      var $remainder_1 = $remainder_0;
      var $buflen_2 = $buflen_1;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $58 = HEAP8[$tmpGroup_0 - 1 | 0] << 24 >> 24;
    var $59 = ($remainder_0 - 1 | 0) / ($58 | 0) & -1;
    var $nrepeat_0 = $59;
    var $remainder_1 = $remainder_0 - $59 * $58 | 0;
    var $buflen_2 = $59 * $28 + $buflen_1 | 0;
    __label__ = 16;
    break;
   case 16:
    var $buflen_2;
    var $remainder_1;
    var $nrepeat_0;
    var $66 = __ZN9JSContext7malloc_Ej($cx, $buflen_2 + 1 | 0);
    if (($66 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      var $remainder_2 = $remainder_1;
      var $tmpDest_0 = $66;
      var $tmpSrc_0 = $8;
      __label__ = 17;
      break;
    }
   case 17:
    var $tmpSrc_0;
    var $tmpDest_0;
    var $remainder_2;
    var $68 = HEAP8[$tmpSrc_0];
    if ($68 << 24 >> 24 == 45) {
      var $remainder_3 = $remainder_2;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if (($remainder_2 | 0) == 0) {
      var $nrepeat_1_ph = $nrepeat_0;
      var $tmpDest_1_ph = $tmpDest_0;
      var $tmpGroup_1_ph_pn = $tmpGroup_0;
      var $tmpSrc_1_ph = $tmpSrc_0;
      __label__ = 22;
      break;
    } else {
      var $remainder_3 = $remainder_2 - 1 | 0;
      __label__ = 19;
      break;
    }
   case 19:
    var $remainder_3;
    HEAP8[$tmpDest_0] = $68;
    var $remainder_2 = $remainder_3;
    var $tmpDest_0 = $tmpDest_0 + 1 | 0;
    var $tmpSrc_0 = $tmpSrc_0 + 1 | 0;
    __label__ = 17;
    break;
   case 20:
    var $tmpSrc_1;
    var $tmpDest_1;
    var $nrepeat_1;
    if ($tmpSrc_1 >>> 0 < $21 >>> 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 21:
    var $78 = HEAP32[$26 >> 2];
    var $79 = _strcpy($tmpDest_1, $78);
    var $80 = $tmpDest_1 + $28 | 0;
    var $82 = HEAP8[$tmpGroup_1_ph] << 24 >> 24;
    _memcpy($80, $tmpSrc_1, $82, 1);
    var $84 = HEAP8[$tmpGroup_1_ph] << 24 >> 24;
    var $85 = $tmpDest_1 + ($84 + $28) | 0;
    var $86 = $tmpSrc_1 + $84 | 0;
    var $87 = $nrepeat_1 - 1 | 0;
    if (($87 | 0) < 0) {
      var $nrepeat_1_ph = $87;
      var $tmpDest_1_ph = $85;
      var $tmpGroup_1_ph_pn = $tmpGroup_1_ph;
      var $tmpSrc_1_ph = $86;
      __label__ = 22;
      break;
    } else {
      var $nrepeat_1 = $87;
      var $tmpDest_1 = $85;
      var $tmpSrc_1 = $86;
      __label__ = 20;
      break;
    }
   case 22:
    var $tmpSrc_1_ph;
    var $tmpGroup_1_ph_pn;
    var $tmpDest_1_ph;
    var $nrepeat_1_ph;
    var $tmpGroup_1_ph = $tmpGroup_1_ph_pn - 1 | 0;
    var $nrepeat_1 = $nrepeat_1_ph;
    var $tmpDest_1 = $tmpDest_1_ph;
    var $tmpSrc_1 = $tmpSrc_1_ph;
    __label__ = 20;
    break;
   case 23:
    if (HEAP8[$nint_0_lcssa] << 24 >> 24 == 46) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $93 = HEAP32[$29 >> 2];
    var $94 = _strcpy($tmpDest_1, $93);
    var $95 = $tmpDest_1 + $31 | 0;
    var $97 = _strcpy($95, $nint_0_lcssa + 1 | 0);
    __label__ = 26;
    break;
   case 25:
    var $99 = _strcpy($tmpDest_1, $nint_0_lcssa);
    __label__ = 26;
    break;
   case 26:
    var $102 = HEAP32[$cx + 36 >> 2];
    if (($102 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $106 = HEAP32[$102 + 12 >> 2];
    if (($106 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $109 = FUNCTION_TABLE[$106]($cx, $66, $vp);
    __ZN9JSContext5free_EPv($66);
    var $_0 = $109;
    __label__ = 31;
    break;
   case 29:
    var $111 = $cx;
    var $112 = __Z17js_NewStringCopyNP9JSContextPKcj($111, $66, $buflen_2);
    __ZN9JSContext5free_EPv($66);
    if (($112 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $115 = $112 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $115);
    var $_0 = 1;
    __label__ = 31;
    break;
   case 31:
    var $_0;
    var $numBytes_idx_val = HEAP32[$numBytes_idx2 >> 2];
    __ZN16JSAutoByteStringD1Ev($numBytes_idx_val);
    var $_1 = $_0;
    __label__ = 32;
    break;
   case 32:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18num_toLocaleStringP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL11num_toFixedP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL6num_toP9JSContext12JSDToStrModeS1_iiijPN2JS5ValueE($cx, 2, 2, -20, 0, $argc, $vp);
  return $1;
}

function __ZL17num_toExponentialP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL6num_toP9JSContext12JSDToStrModeS1_iiijPN2JS5ValueE($cx, 1, 3, 0, 1, $argc, $vp);
  return $1;
}

function __ZL15num_toPrecisionP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx = $vp + 16 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $3 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = __ZL12num_toStringP9JSContextjPN2JS5ValueE($cx, 0, $vp);
    var $_0 = $5;
    __label__ = 5;
    break;
   case 4:
    var $7 = __ZL6num_toP9JSContext12JSDToStrModeS1_iiijPN2JS5ValueE($cx, 0, 4, 1, 0, $argc, $vp);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js22InitRuntimeNumberStateEP9JSRuntime($rt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    tempDoubleF64[0] = NaN, HEAP32[_js_NaN >> 2] = tempDoubleI32[0], HEAP32[_js_NaN + 4 >> 2] = tempDoubleI32[1];
    tempDoubleF64[0] = NaN, HEAP32[__ZL16number_constants >> 2] = tempDoubleI32[0], HEAP32[__ZL16number_constants + 4 >> 2] = tempDoubleI32[1];
    var $1 = $rt + 144112 | 0;
    __ZN2JS5Value9setDoubleEd($1, NaN);
    tempDoubleF64[0] = Infinity, HEAP32[_js_PositiveInfinity >> 2] = tempDoubleI32[0], HEAP32[_js_PositiveInfinity + 4 >> 2] = tempDoubleI32[1];
    tempDoubleF64[0] = Infinity, HEAP32[__ZL16number_constants + 16 >> 2] = tempDoubleI32[0], HEAP32[__ZL16number_constants + 20 >> 2] = tempDoubleI32[1];
    var $2 = $rt + 144128 | 0;
    __ZN2JS5Value9setDoubleEd($2, Infinity);
    tempDoubleF64[0] = -Infinity, HEAP32[_js_NegativeInfinity >> 2] = tempDoubleI32[0], HEAP32[_js_NegativeInfinity + 4 >> 2] = tempDoubleI32[1];
    tempDoubleF64[0] = -Infinity, HEAP32[__ZL16number_constants + 32 >> 2] = tempDoubleI32[0], HEAP32[__ZL16number_constants + 36 >> 2] = tempDoubleI32[1];
    var $3 = $rt + 144120 | 0;
    __ZN2JS5Value9setDoubleEd($3, -Infinity);
    tempDoubleF64[0] = 5e-324, HEAP32[__ZL16number_constants + 64 >> 2] = tempDoubleI32[0], HEAP32[__ZL16number_constants + 68 >> 2] = tempDoubleI32[1];
    var $4 = _localeconv();
    var $6 = HEAP32[$4 + 4 >> 2];
    var $8 = HEAP32[$4 >> 2];
    var $10 = HEAP32[$4 + 8 >> 2];
    var $thousandsSeparator_0 = ($6 | 0) == 0 ? STRING_TABLE.__str32081 | 0 : $6;
    var $decimalPoint_0 = ($8 | 0) == 0 ? STRING_TABLE.__str298 | 0 : $8;
    var $grouping_0 = ($10 | 0) == 0 ? STRING_TABLE.__str52083 | 0 : $10;
    var $14 = _strlen($thousandsSeparator_0);
    var $15 = $14 + 1 | 0;
    var $16 = _strlen($decimalPoint_0);
    var $17 = $16 + 1 | 0;
    var $18 = _strlen($grouping_0);
    var $19 = $18 + 1 | 0;
    var $20 = $17 + $15 | 0;
    var $21 = $20 + $19 | 0;
    var $22 = __ZN2js11OffTheBooks7malloc_Ej($21);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _memcpy($22, $thousandsSeparator_0, $15, 1);
    HEAP32[$rt + 144260 >> 2] = $22;
    var $26 = $22 + $15 | 0;
    _memcpy($26, $decimalPoint_0, $17, 1);
    HEAP32[$rt + 144264 >> 2] = $26;
    var $28 = $22 + $20 | 0;
    _memcpy($28, $grouping_0, $19, 1);
    HEAP32[$rt + 144268 >> 2] = $grouping_0;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js22InitRuntimeNumberStateEP9JSRuntime["X"] = 1;

function __ZN2js24FinishRuntimeNumberStateEP9JSRuntime($rt_0_62_val) {
  __ZN2js10Foreground5free_EPv($rt_0_62_val);
  return;
}

function __Z18js_InitNumberClassP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZN8JSObject8asGlobalEv($1);
    var $3 = $2;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($2, $4, __ZN2js11NumberClassE);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN8JSObject8asNumberEv($6);
    __ZN2js12NumberObject17setPrimitiveValueEd($9, 0);
    var $10 = $cx + 52 | 0;
    var $14 = HEAP32[HEAP32[$10 >> 2] + 210052 >> 2];
    var $15 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($2, $4, 170, __ZN2js11NumberClassE, $14, 1);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $18 = $15;
    var $19 = $15 | 0;
    var $20 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $19, $5);
    if ($20) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 4:
    var $22 = _JS_DefineConstDoubles($cx, $18, __ZL16number_constants | 0);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $25 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, 0, __ZL14number_methods);
    if ($25) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $27 = $2;
    var $28 = _JS_DefineFunctions($cx, $27, __ZL16number_functions | 0);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $31 = HEAP32[$10 >> 2];
    var $34 = HEAP32[$31 + 210380 >> 2] | 0;
    var $35 = __ZL12ATOM_TO_JSIDP6JSAtom2097($34);
    var $36 = $31 + 144112 | 0;
    var $37 = $cx;
    var $38 = $2;
    var $39 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($37, $38, $35, $36, 10, 12, 6, 0, 0, 0);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $42 = HEAP32[$10 >> 2];
    var $45 = HEAP32[$42 + 210376 >> 2] | 0;
    var $46 = __ZL12ATOM_TO_JSIDP6JSAtom2097($45);
    var $47 = $42 + 144128 | 0;
    var $48 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($37, $38, $46, $47, 10, 12, 6, 0, 0, 0);
    if (($48 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $51 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $3, 8, $18, $6);
    var $_ = $51 ? $6 : 0;
    var $_0 = $_;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18js_InitNumberClassP9JSContextP8JSObject["X"] = 1;

function __ZN2js12NumberObject17setPrimitiveValueEd($this, $d) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2JSL11NumberValueEd2157($1, $d);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, 0, $_idx_val$0, $_idx_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZL6NumberP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL14IsConstructingEPKN2JS5ValueE2144($vp);
    if (($argc | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $vp + 16 | 0;
    var $5 = __ZN2js8ToNumberEP9JSContextPN2JS5ValueE($cx, $4);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $7 = $4 | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $vp | 0;
    HEAP32[$9 >> 2] = $8$0;
    HEAP32[$9 + 4 >> 2] = $8$1;
    __label__ = 5;
    break;
   case 4:
    __ZN2JS5Value8setInt32Ei($vp, 0);
    __label__ = 5;
    break;
   case 5:
    if ($1) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 6:
    var $13 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2145($cx);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $16 = $13;
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    __ZN8JSObject16setPrimitiveThisERKN2JS5ValueE($16, $vp_idx_val$0, $vp_idx_val$1);
    __ZN2JS5Value9setObjectER8JSObject($vp, $13);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12ATOM_TO_JSIDP6JSAtom2097($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj2143($1);
  return $2;
}

function __ZN2js15NumberToCStringEP9JSContextPNS_12ToCStringBufEdi($cx, $cbuf, $d) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $1 = _JSDOUBLE_IS_INT322100($d, $i);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$i >> 2];
    var $5 = __ZL12IntToCStringPN2js12ToCStringBufEii($cbuf, $4, 10);
    var $9 = $5;
    __label__ = 4;
    break;
   case 3:
    var $7 = __ZN2jsL19FracNumberToCStringEP9JSContextPNS_12ToCStringBufEdi($cx, $cbuf, $d, 10);
    var $9 = $7;
    __label__ = 4;
    break;
   case 4:
    var $9;
    STACKTOP = __stackBase__;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSDOUBLE_IS_INT322100($d, $pi) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSDOUBLE_IS_NEGZERO2132($d);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $d & -1;
    HEAP32[$pi >> 2] = $4;
    var $_0 = ($4 | 0) == $d & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12IntToCStringPN2js12ToCStringBufEii($cbuf, $i, $base) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cp = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = ($i | 0) < 0;
    var $4 = $2 ? -$i | 0 : $i;
    var $5 = $cbuf + 33 | 0;
    __ZN7mozilla9RangedPtrIcEC1EPcS2_j($cp, $5);
    var $cp_idx = $cp | 0;
    var $cp_idx_val = HEAP32[$cp_idx >> 2];
    var $6 = __ZNK7mozilla9RangedPtrIcEdeEv($cp_idx_val);
    HEAP8[$6] = 0;
    if (($base | 0) == 10) {
      __label__ = 2;
      break;
    } else if (($base | 0) == 16) {
      var $u_0 = $4;
      __label__ = 3;
      break;
    } else {
      var $u_1 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = HEAP32[$cp_idx >> 2];
    __ZN2js25BackfillIndexInCharBufferIcEEN7mozilla9RangedPtrIT_EEjS4_($1, $4, $8);
    var $_idx3_val = HEAP32[$1 >> 2];
    __ZN7mozilla9RangedPtrIcEaSERKS1_($cp, $_idx3_val);
    __label__ = 5;
    break;
   case 3:
    var $u_0;
    var $9 = $u_0 >>> 4;
    var $11 = STRING_TABLE.__str62084 + ($u_0 & 15) | 0;
    var $12 = HEAP8[$11];
    var $13 = __ZN7mozilla9RangedPtrIcEmmEv($cp);
    var $_idx2_val = HEAP32[$13 >> 2];
    var $14 = __ZNK7mozilla9RangedPtrIcEdeEv($_idx2_val);
    HEAP8[$14] = $12;
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $u_0 = $9;
      __label__ = 3;
      break;
    }
   case 4:
    var $u_1;
    var $16 = Math.floor(($u_1 >>> 0) / ($base >>> 0));
    var $19 = STRING_TABLE.__str72085 + ($u_1 - $16 * $base) | 0;
    var $20 = HEAP8[$19];
    var $21 = __ZN7mozilla9RangedPtrIcEmmEv($cp);
    var $_idx1_val = HEAP32[$21 >> 2];
    var $22 = __ZNK7mozilla9RangedPtrIcEdeEv($_idx1_val);
    HEAP8[$22] = $20;
    if (($16 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $u_1 = $16;
      __label__ = 4;
      break;
    }
   case 5:
    if ($2) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $25 = __ZN7mozilla9RangedPtrIcEmmEv($cp);
    var $_idx_val = HEAP32[$25 >> 2];
    var $26 = __ZNK7mozilla9RangedPtrIcEdeEv($_idx_val);
    HEAP8[$26] = 45;
    __label__ = 7;
    break;
   case 7:
    var $cp_idx4_val = HEAP32[$cp_idx >> 2];
    var $28 = __ZNK7mozilla9RangedPtrIcE3getEv($cp_idx4_val);
    STACKTOP = __stackBase__;
    return $28;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12IntToCStringPN2js12ToCStringBufEii["X"] = 1;

function __ZN2jsL19FracNumberToCStringEP9JSContextPNS_12ToCStringBufEdi($cx, $cbuf, $d, $base) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($base | 0) == 10) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $cbuf | 0;
    var $4 = __ZN2v88internal15DoubleToCStringEdPci($d, $3);
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $numStr_0 = $4;
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = HEAP32[HEAP32[$cx + 52 >> 2] + 209876 >> 2];
    var $11 = _js_dtostr($10, $3, 34, 0, 0, $d);
    var $numStr_0 = $11;
    __label__ = 5;
    break;
   case 4:
    var $16 = HEAP32[HEAP32[$cx + 52 >> 2] + 209876 >> 2];
    var $17 = _js_dtobasestr($16, $base, $d);
    HEAP32[$cbuf + 36 >> 2] = $17;
    var $numStr_0 = $17;
    __label__ = 5;
    break;
   case 5:
    var $numStr_0;
    return $numStr_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_NumberToStringP9JSContextd($cx, $d) {
  var $1 = __ZL25js_NumberToStringWithBaseP9JSContextdi($cx, $d, 10);
  return $1;
}

function __ZL25js_NumberToStringWithBaseP9JSContextdi($cx, $d, $base) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cbuf = __stackBase__;
    var $i = __stackBase__ + 40;
    __ZN2js12ToCStringBufC2Ev($cbuf);
    if (($base - 2 | 0) >>> 0 > 34) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$cx + 56 >> 2];
    var $5 = _JSDOUBLE_IS_INT322100($d, $i);
    if (($5 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAPU32[$i >> 2];
    if (($base | 0) == 10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $11 = __ZN2js13StaticStrings6hasIntEi($9);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $15 = HEAP32[$cx + 52 >> 2] + 210584 | 0;
    var $16 = __ZN2js13StaticStrings6getIntEi($15, $9);
    var $_0 = $16 | 0;
    __label__ = 18;
    break;
   case 6:
    if ($9 >>> 0 < $base >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    if (($9 | 0) < 10) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $24 = HEAP32[$cx + 52 >> 2] + 210584 | 0;
    var $25 = __ZN2js13StaticStrings6getIntEi($24, $9);
    var $_0 = $25 | 0;
    __label__ = 18;
    break;
   case 9:
    var $29 = $9 + 87 & 65535;
    var $32 = HEAP32[$cx + 52 >> 2] + 210584 | 0;
    var $33 = __ZN2js13StaticStrings7getUnitEt($32, $29);
    var $_0 = $33 | 0;
    __label__ = 18;
    break;
   case 10:
    var $36 = $4 + 1888 | 0;
    var $37 = __ZN2js9DtoaCache6lookupEid($36, $base, $d);
    if (($37 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_0 = $37 | 0;
    __label__ = 18;
    break;
   case 12:
    var $42 = __ZL12IntToCStringPN2js12ToCStringBufEii($cbuf, $9, $base);
    var $numStr_0 = $42;
    __label__ = 17;
    break;
   case 13:
    var $44 = $4 + 1888 | 0;
    var $45 = __ZN2js9DtoaCache6lookupEid($44, $base, $d);
    if (($45 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $_0 = $45 | 0;
    __label__ = 18;
    break;
   case 15:
    var $50 = __ZN2jsL19FracNumberToCStringEP9JSContextPNS_12ToCStringBufEdi($cx, $cbuf, $d, $base);
    if (($50 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      var $numStr_0 = $50;
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportOutOfMemory($cx);
    var $_0 = 0;
    __label__ = 18;
    break;
   case 17:
    var $numStr_0;
    var $54 = $cx;
    var $55 = __Z17js_NewStringCopyZP9JSContextPKc($54, $numStr_0);
    var $56 = $4 + 1888 | 0;
    __ZN2js9DtoaCache5cacheEidP13JSFixedString($56, $base, $d, $55);
    var $_0 = $55 | 0;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    var $cbuf_idx_val = HEAP32[$cbuf + 36 >> 2];
    __ZN2js12ToCStringBufD2Ev($cbuf_idx_val);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL25js_NumberToStringWithBaseP9JSContextdi["X"] = 1;

function __ZN2js14NumberToStringEP9JSContextd($cx, $d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL25js_NumberToStringWithBaseP9JSContextdi($cx, $d, 10);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN8JSString7asFixedEv($1);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13IndexToStringEP9JSContextj($cx, $index) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $end = __stackBase__;
    var $start = __stackBase__ + 4;
    var $1 = __ZN2js13StaticStrings7hasUintEj($index);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$cx + 52 >> 2] + 210584 | 0;
    var $6 = __ZN2js13StaticStrings7getUintEj($5, $index);
    var $_0 = $6 | 0;
    __label__ = 6;
    break;
   case 3:
    var $11 = HEAP32[$cx + 56 >> 2] + 1888 | 0;
    var $12 = $index >>> 0;
    var $13 = __ZN2js9DtoaCache6lookupEid($11, 10, $12);
    if (($13 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $13;
      __label__ = 6;
      break;
    }
   case 4:
    var $16 = __Z19js_NewGCShortStringP9JSContext($cx);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = __ZN13JSShortString23inlineStorageBeforeInitEv($16);
    var $20 = $19 + 22 | 0;
    __ZN7mozilla9RangedPtrItEC1EPtS2_j($end, $20);
    var $end_idx_val = HEAP32[$end >> 2];
    var $21 = __ZNK7mozilla9RangedPtrItEdeEv($end_idx_val);
    HEAP16[$21 >> 1] = 0;
    __ZN2js25BackfillIndexInCharBufferItEEN7mozilla9RangedPtrIT_EEjS4_($start, $index, $end_idx_val);
    var $start_idx_val = HEAP32[$start >> 2];
    var $22 = __ZNK7mozilla9RangedPtrItE3getEv($start_idx_val);
    var $23 = __ZNK7mozilla9RangedPtrItEmiERKS1_($end_idx_val, $start_idx_val);
    __ZN13JSShortString20initAtOffsetInBufferEPKtj($16, $22, $23);
    var $24 = $16 | 0;
    __ZN2js9DtoaCache5cacheEidP13JSFixedString($11, 10, $12, $24);
    var $_0 = $24;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12NumberTraitsIdE10toSelfTypeEd($d) {
  return $d;
}

function __ZNK7mozilla9RangedPtrIcEdeEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK7mozilla9RangedPtrIcE3getEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZL14JSID_FROM_BITSj2143($bits) {
  return $bits;
}

function __ZN2js12NumberTraitsIdE3NaNEv() {
  var $1 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
  return $1;
}

function __ZNK2js7unicode13CharacterInfo7isSpaceEv($this_0_2_val) {
  return ($this_0_2_val & 1) << 24 >> 24 != 0;
}

function __ZL18JSDOUBLE_IS_FINITEd2111($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function __ZL15JSDOUBLE_IS_NaNd2114($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function _JSDOUBLE_IS_NEGZERO2132($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d != 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $_0 = tempDoubleI32[1] >>> 31 | 0 << 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla9RangedPtrIcEaSERKS1_($this, $other_0_0_val) {
  HEAP32[$this >> 2] = $other_0_0_val;
  return;
}

function __ZN7mozilla9RangedPtrIcEaSIcEERS1_RKNS0_IT_EE($this, $p_0_0_val) {
  HEAP32[$this >> 2] = $p_0_0_val;
  return;
}

function __ZN7mozilla9RangedPtrIcEC2EPcS2_j($this, $p) {
  HEAP32[$this >> 2] = $p;
  return;
}

function __ZN2js2gcL15GetGCObjectKindEjb2146($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js25NumberValueToStringBufferEP9JSContextRKN2JS5ValueERNS_12StringBufferE($cx, $v, $sb) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cbuf = __stackBase__;
    __ZN2js12ToCStringBufC2Ev($cbuf);
    var $v_idx1 = $v | 0;
    var $v_idx1_val$0 = HEAP32[$v_idx1 >> 2];
    var $v_idx1_val$1 = HEAP32[$v_idx1 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx1_val$0, $v_idx1_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx1_val$0, $v_idx1_val$1);
    var $4 = __ZL12IntToCStringPN2js12ToCStringBufEii($cbuf, $3, 10);
    var $cstr_0 = $4;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8toDoubleEv($v);
    var $7 = __ZN2js15NumberToCStringEP9JSContextPNS_12ToCStringBufEdi($cx, $cbuf, $6);
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $cstr_0 = $7;
      __label__ = 5;
      break;
    }
   case 4:
    _JS_ReportOutOfMemory($cx);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 5:
    var $cstr_0;
    var $11 = _strlen($cstr_0);
    var $12 = __ZN2js12StringBuffer14appendInflatedEPKcj($sb, $cstr_0, $11);
    var $_0 = $12;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    var $cbuf_idx_val = HEAP32[$cbuf + 36 >> 2];
    __ZN2js12ToCStringBufD2Ev($cbuf_idx_val);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer14appendInflatedEPKcj($this, $cstr, $cstrlen) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $cstrlen;
    var $2 = __ZNK2js12StringBuffer6lengthEv($this);
    var $3 = $this | 0;
    var $4 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE19growByUninitializedEj($3, $cstrlen);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZNK2js12StringBuffer7contextEv($this);
    var $7 = __ZN2js12StringBuffer5beginEv($this);
    var $8 = $7 + ($2 << 1) | 0;
    var $9 = $6;
    var $10 = __ZN2js21InflateStringToBufferEP9JSContextPKcjPtPj($9, $cstr, $cstrlen, $8, $1);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($cx, $_0_0_0_val$0, $_0_0_0_val$1, $out) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $v | 0;
    HEAP32[$1 >> 2] = $_0_0_0_val$0;
    HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
    var $v_idx1_val$1 = $_0_0_0_val$1;
    var $v_idx1_val$0 = $_0_0_0_val$0;
    __label__ = 3;
    break;
   case 2:
    var $3 = __ZNK2JS5Value8toNumberEv($v);
    tempDoubleF64[0] = $3, HEAP32[$out >> 2] = tempDoubleI32[0], HEAP32[$out + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 16;
    break;
   case 3:
    var $v_idx1_val$0;
    var $v_idx1_val$1;
    var $5 = __ZNK2JS5Value8isStringEv($v_idx1_val$0, $v_idx1_val$1);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZNK2JS5Value8toStringEv($v_idx1_val$0, $v_idx1_val$1);
    var $8 = __ZN2jsL18StringToNumberTypeIdEEbP9JSContextP8JSStringPT_($cx, $7, $out);
    var $_0 = $8;
    __label__ = 16;
    break;
   case 5:
    var $10 = __ZNK2JS5Value9isBooleanEv($v_idx1_val$0, $v_idx1_val$1);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $12 = __ZNK2JS5Value9toBooleanEv($v_idx1_val$0, $v_idx1_val$1);
    if ($12) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    tempDoubleF64[0] = 1, HEAP32[$out >> 2] = tempDoubleI32[0], HEAP32[$out + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 16;
    break;
   case 8:
    tempDoubleF64[0] = 0, HEAP32[$out >> 2] = tempDoubleI32[0], HEAP32[$out + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 16;
    break;
   case 9:
    var $16 = __ZNK2JS5Value6isNullEv($v_idx1_val$0, $v_idx1_val$1);
    if ($16) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    tempDoubleF64[0] = 0, HEAP32[$out >> 2] = tempDoubleI32[0], HEAP32[$out + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 16;
    break;
   case 11:
    var $19 = __ZNK2JS5Value11isUndefinedEv($v_idx1_val$0, $v_idx1_val$1);
    if ($19) {
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $21 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE2103($cx, $v);
    if ($21) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 13:
    var $v_idx_val$0 = HEAP32[$1 >> 2];
    var $v_idx_val$1 = HEAP32[$1 + 4 >> 2];
    var $23 = __ZNK2JS5Value8isObjectEv($v_idx_val$0, $v_idx_val$1);
    if ($23) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $25 = __ZNK2JS5Value8isNumberEv($v_idx_val$0, $v_idx_val$1);
    if ($25) {
      __label__ = 2;
      break;
    } else {
      var $v_idx1_val$1 = $v_idx_val$1;
      var $v_idx1_val$0 = $v_idx_val$0;
      __label__ = 3;
      break;
    }
   case 15:
    var $27 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $27, HEAP32[$out >> 2] = tempDoubleI32[0], HEAP32[$out + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd["X"] = 1;

function __ZN2jsL18StringToNumberTypeIdEEbP9JSContextP8JSStringPT_($cx, $str, $result) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $endptr = __stackBase__;
    var $d = __stackBase__ + 4;
    var $ep = __stackBase__ + 12;
    var $d1 = __stackBase__ + 16;
    var $str_idx_val = HEAP32[$str >> 2];
    var $1 = __ZNK8JSString6lengthEv($str_idx_val);
    var $2 = __ZN8JSString8getCharsEP9JSContext($str, 0);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($1 | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    var $7 = HEAPU16[$2 >> 1];
    if (($7 - 48 & 65535 & 65535) < 10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $12 = ($7 & 65535) - 48 | 0;
    var $13 = __ZN2js12NumberTraitsIdE10toSelfTypeEd($12);
    tempDoubleF64[0] = $13, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 19;
    break;
   case 5:
    var $15 = __ZN2js7unicode7IsSpaceEt($7);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $17 = __ZN2js12NumberTraitsIdE10toSelfTypeEd(0);
    tempDoubleF64[0] = $17, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 19;
    break;
   case 7:
    var $19 = __ZN2js12NumberTraitsIdE3NaNEv();
    tempDoubleF64[0] = $19, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 19;
    break;
   case 8:
    var $21 = $2 + ($1 << 1) | 0;
    var $22 = __ZN2jsL9SkipSpaceEPKtS1_($2, $21);
    if (($21 - $22 | 0) > 2) {
      __label__ = 9;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 9:
    if (HEAP16[$22 >> 1] << 16 >> 16 == 48) {
      __label__ = 10;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 10:
    var $32 = HEAP16[$22 + 2 >> 1];
    if ($32 << 16 >> 16 == 120 || $32 << 16 >> 16 == 88) {
      __label__ = 11;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 11:
    var $34 = $22 + 4 | 0;
    var $35 = __ZN2js16GetPrefixIntegerEP9JSContextPKtS3_iPS3_Pd($cx, $34, $21, 16, $endptr, $d);
    if ($35) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $37 = HEAP32[$endptr >> 2];
    var $38 = __ZN2jsL9SkipSpaceEPKtS1_($37, $21);
    if (($38 | 0) == ($21 | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $41 = __ZN2js12NumberTraitsIdE3NaNEv();
    tempDoubleF64[0] = $41, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 19;
    break;
   case 14:
    var $43 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $44 = __ZN2js12NumberTraitsIdE10toSelfTypeEd($43);
    tempDoubleF64[0] = $44, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 19;
    break;
   case 15:
    var $46 = __Z9js_strtodP9JSContextPKtS2_PS2_Pd($cx, $22, $21, $ep, $d1);
    if (($46 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $49 = HEAP32[$ep >> 2];
    var $50 = __ZN2jsL9SkipSpaceEPKtS1_($49, $21);
    if (($50 | 0) == ($21 | 0)) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $53 = __ZN2js12NumberTraitsIdE3NaNEv();
    tempDoubleF64[0] = $53, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 19;
    break;
   case 18:
    var $55 = (tempDoubleI32[0] = HEAP32[$d1 >> 2], tempDoubleI32[1] = HEAP32[$d1 + 4 >> 2], tempDoubleF64[0]);
    var $56 = __ZN2js12NumberTraitsIdE10toSelfTypeEd($55);
    tempDoubleF64[0] = $56, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2jsL18StringToNumberTypeIdEEbP9JSContextP8JSStringPT_["X"] = 1;

function __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE2103($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $vp_idx1 = $vp | 0;
    var $vp_idx1_val$0 = HEAP32[$vp_idx1 >> 2];
    var $vp_idx1_val$1 = HEAP32[$vp_idx1 + 4 >> 2];
    var $1 = __ZNK2JS5Value11isPrimitiveEv($vp_idx1_val$0, $vp_idx1_val$1);
    if ($1) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($vp_idx1_val$0, $vp_idx1_val$1);
    var $4 = $3;
    var $5 = $cx;
    var $6 = __ZN8JSObject12defaultValueEP9JSContext6JSTypePN2JS5ValueE($4, $5, 4, $vp);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js20ValueToECMAInt32SlowEP9JSContextRKN2JS5ValueEPi($cx, $v, $out) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $1 = __ZNK2JS5Value8isDoubleEv($v_idx_val$0, $v_idx_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toDoubleEv($v);
    tempDoubleF64[0] = $3, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $7 = $3;
    __label__ = 5;
    break;
   case 3:
    var $5 = __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($cx, $v_idx_val$0, $v_idx_val$1, $d);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $7 = $_pre;
    __label__ = 5;
    break;
   case 5:
    var $7;
    var $8 = __ZL20js_DoubleToECMAInt32d2106($7);
    HEAP32[$out >> 2] = $8;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20js_DoubleToECMAInt32d2106($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL18JSDOUBLE_IS_FINITEd2111($d);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $d & -1;
    if (($4 | 0) == $d) {
      var $_0 = $4;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = _fmod($d, 4294967296);
    if ($8 < 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = _floor($8);
    var $16 = $11;
    __label__ = 6;
    break;
   case 5:
    var $13 = _ceil($8);
    var $16 = $13 + 4294967296;
    __label__ = 6;
    break;
   case 6:
    var $16;
    if ($16 < 2147483648) {
      var $21 = $16;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $21 = $16 - 4294967296;
    __label__ = 8;
    break;
   case 8:
    var $21;
    var $_0 = $21 & -1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js21ValueToECMAUint32SlowEP9JSContextRKN2JS5ValueEPj($cx, $v, $out) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $1 = __ZNK2JS5Value8isDoubleEv($v_idx_val$0, $v_idx_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toDoubleEv($v);
    tempDoubleF64[0] = $3, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $7 = $3;
    __label__ = 5;
    break;
   case 3:
    var $5 = __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($cx, $v_idx_val$0, $v_idx_val$1, $d);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $7 = $_pre;
    __label__ = 5;
    break;
   case 5:
    var $7;
    var $8 = __Z21js_DoubleToECMAUint32d($7);
    HEAP32[$out >> 2] = $8;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z21js_DoubleToECMAUint32d($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL18JSDOUBLE_IS_FINITEd2111($d);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $d & -1;
    if (($4 | 0) == $d) {
      var $_0 = $4;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($d < 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _floor($d);
    var $15 = $9;
    __label__ = 6;
    break;
   case 5:
    var $11 = -$d;
    var $12 = _floor($11);
    var $15 = -$12;
    __label__ = 6;
    break;
   case 6:
    var $15;
    var $16 = _fmod($15, 4294967296);
    if ($16 < 0) {
      __label__ = 7;
      break;
    } else {
      var $21 = $16;
      __label__ = 8;
      break;
    }
   case 7:
    var $21 = $16 + 4294967296;
    __label__ = 8;
    break;
   case 8:
    var $21;
    var $22 = $21 >= 0 ? Math.floor($21) : Math.ceil($21);
    var $_0 = $22;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16ValueToInt32SlowEP9JSContextRKN2JS5ValueEPi($cx, $v, $out) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $1 = __ZNK2JS5Value8isDoubleEv($v_idx_val$0, $v_idx_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toDoubleEv($v);
    tempDoubleF64[0] = $3, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $7 = $3;
    __label__ = 5;
    break;
   case 3:
    var $5 = __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($cx, $v_idx_val$0, $v_idx_val$1, $d);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $7 = $_pre;
    __label__ = 5;
    break;
   case 5:
    var $7;
    var $8 = __ZL15JSDOUBLE_IS_NaNd2114($7);
    if (($8 | 0) != 0 | $7 <= -2147483649 | $7 >= 2147483648) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $v_idx1_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx1_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $13 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, 35, 1, $v_idx1_val$0, $v_idx1_val$1, 0, 0);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 7:
    var $16 = _floor($7 + .5);
    HEAP32[$out >> 2] = $16 & -1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17ValueToUint16SlowEP9JSContextRKN2JS5ValueEPt($cx, $v, $out) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $1 = __ZNK2JS5Value8isDoubleEv($v_idx_val$0, $v_idx_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toDoubleEv($v);
    tempDoubleF64[0] = $3, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $7 = $3;
    __label__ = 5;
    break;
   case 3:
    var $5 = __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($cx, $v_idx_val$0, $v_idx_val$1, $d);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 4:
    var $_pr = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $7 = $_pr;
    __label__ = 5;
    break;
   case 5:
    var $7;
    if ($7 == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $10 = __ZL18JSDOUBLE_IS_FINITEd2111($7);
    if (($10 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    HEAP16[$out >> 1] = 0;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 8:
    var $14 = $7 >= 0 ? Math.floor($7) : Math.ceil($7);
    if (($14 & 65535) == $7) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    HEAP16[$out >> 1] = $14;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 10:
    if ($7 < 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $20 = _floor($7);
    tempDoubleF64[0] = $20, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $26 = $20;
    __label__ = 13;
    break;
   case 12:
    var $23 = _floor(-$7);
    tempDoubleF64[0] = $23, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $26 = -$23;
    __label__ = 13;
    break;
   case 13:
    var $26;
    tempDoubleF64[0] = $26, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $27 = _fmod($26, 65536);
    if ($27 < 0) {
      __label__ = 14;
      break;
    } else {
      var $storemerge = $27;
      __label__ = 15;
      break;
    }
   case 14:
    var $storemerge = $27 + 65536;
    __label__ = 15;
    break;
   case 15:
    var $storemerge;
    tempDoubleF64[0] = $storemerge, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $32 = $storemerge >= 0 ? Math.floor($storemerge) : Math.ceil($storemerge);
    HEAP16[$out >> 1] = $32;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js17ValueToUint16SlowEP9JSContextRKN2JS5ValueEPt["X"] = 1;

function __Z9js_strtodP9JSContextPKtS2_PS2_Pd($cx, $s, $send, $ep, $dp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cbuf = __stackBase__;
    var $estr = __stackBase__ + 32;
    var $err = __stackBase__ + 36;
    var $1 = __ZN2jsL9SkipSpaceEPKtS1_($s, $send);
    var $5 = $send - $1 >> 1;
    if ($5 >>> 0 > 31) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $5 + 1 | 0;
    var $9 = __ZN9JSContext7malloc_Ej($cx, $8);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      var $cstr_0 = $9;
      __label__ = 4;
      break;
    }
   case 3:
    var $cstr_0 = $cbuf | 0;
    __label__ = 4;
    break;
   case 4:
    var $cstr_0;
    var $i_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_0;
    if (($i_0 | 0) == ($5 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = HEAPU16[$1 + ($i_0 << 1) >> 1];
    if (($18 & 65535) > 255) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP8[$cstr_0 + $i_0 | 0] = $18 & 255;
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 5;
    break;
   case 8:
    HEAP8[$cstr_0 + $i_0 | 0] = 0;
    var $26 = HEAP8[$cstr_0];
    var $27 = $26 << 24 >> 24 == 45;
    var $istr_0 = $27 | $26 << 24 >> 24 == 43 ? $cstr_0 + 1 | 0 : $cstr_0;
    if (HEAP8[$istr_0] << 24 >> 24 == 73) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $33 = _strncmp($istr_0, STRING_TABLE.__str11097 | 0, 8);
    if (($33 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $36 = (tempDoubleI32[0] = HEAP32[_js_NegativeInfinity >> 2], tempDoubleI32[1] = HEAP32[_js_NegativeInfinity + 4 >> 2], tempDoubleF64[0]);
    var $37 = (tempDoubleI32[0] = HEAP32[_js_PositiveInfinity >> 2], tempDoubleI32[1] = HEAP32[_js_PositiveInfinity + 4 >> 2], tempDoubleF64[0]);
    var $38 = $27 ? $36 : $37;
    HEAP32[$estr >> 2] = $istr_0 + 8 | 0;
    var $d_0 = $38;
    __label__ = 15;
    break;
   case 11:
    var $44 = HEAP32[HEAP32[$cx + 52 >> 2] + 209876 >> 2];
    var $45 = _js_strtod_harder($44, $cstr_0, $estr, $err);
    if ($45 == Infinity) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $48 = (tempDoubleI32[0] = HEAP32[_js_PositiveInfinity >> 2], tempDoubleI32[1] = HEAP32[_js_PositiveInfinity + 4 >> 2], tempDoubleF64[0]);
    var $d_0 = $48;
    __label__ = 15;
    break;
   case 13:
    if ($45 == -Infinity) {
      __label__ = 14;
      break;
    } else {
      var $d_0 = $45;
      __label__ = 15;
      break;
    }
   case 14:
    var $52 = (tempDoubleI32[0] = HEAP32[_js_NegativeInfinity >> 2], tempDoubleI32[1] = HEAP32[_js_NegativeInfinity + 4 >> 2], tempDoubleF64[0]);
    var $d_0 = $52;
    __label__ = 15;
    break;
   case 15:
    var $d_0;
    var $53 = HEAP32[$estr >> 2];
    var $56 = $53 - $cstr_0 | 0;
    if (($cstr_0 | 0) == ($cbuf | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN9JSContext5free_EPv($cstr_0);
    __label__ = 17;
    break;
   case 17:
    if (($53 | 0) == ($cstr_0 | 0)) {
      var $65 = $s;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $65 = $1 + ($56 << 1) | 0;
    __label__ = 19;
    break;
   case 19:
    var $65;
    HEAP32[$ep >> 2] = $65;
    tempDoubleF64[0] = $d_0, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 20;
    break;
   case 20:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z9js_strtodP9JSContextPKtS2_PS2_Pd["X"] = 1;

function __ZN2jsL9SkipSpaceEPKtS1_($s, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_0 = $s;
    __label__ = 2;
    break;
   case 2:
    var $_0;
    if ($_0 >>> 0 < $end >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $4 = HEAP16[$_0 >> 1];
    var $5 = __ZN2js7unicode7IsSpaceEt($4);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = $_0 + 2 | 0;
    __label__ = 2;
    break;
   case 5:
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7unicode7IsSpaceEt($ch) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($ch & 65535) < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = STRING_TABLE._js_isspace + ($ch & 65535) | 0;
    var $_0 = (HEAP8[$4] & 1) << 24 >> 24 != 0;
    __label__ = 5;
    break;
   case 3:
    if ($ch << 16 >> 16 == 160) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = __ZN2js7unicode8CharInfoEt($ch);
    var $_idx_val = HEAP8[$11 + 4 | 0];
    var $12 = __ZNK2js7unicode13CharacterInfo7isSpaceEv($_idx_val);
    var $_0 = $12;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail17PrimitiveBehaviorIdE6isTypeERKN2JS5ValueE($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var $1 = __ZNK2JS5Value8isNumberEv($v_0_0_0_val$0, $v_0_0_0_val$1);
  return $1;
}

function __ZN2js6detail17PrimitiveBehaviorIdE7extractERKN2JS5ValueE($v) {
  var $1 = __ZNK2JS5Value8toNumberEv($v);
  return $1;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE19growByUninitializedEj($this, $incr) {
  var $1 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10growByImplILb0EEEbj($this, $incr);
  return $1;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10growByImplILb0EEEbj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 8 | 0;
    var $4 = HEAPU32[$3 >> 2];
    if ((HEAP32[$this + 12 >> 2] - $4 | 0) >>> 0 < $incr >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $10 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE13growStorageByEj($this, $incr);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = HEAP32[$3 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $10;
    HEAP32[$3 >> 2] = $10 + $incr | 0;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla9RangedPtrIcEC1EPcS2_j($this, $p) {
  __ZN7mozilla9RangedPtrIcEC2EPcS2_j($this, $p);
  return;
}

function __ZN2js25BackfillIndexInCharBufferIcEEN7mozilla9RangedPtrIT_EEjS4_($agg_result, $index, $end_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $end = __stackBase__;
    var $_01 = $end | 0;
    HEAP32[$_01 >> 2] = $end_0;
    var $_0 = $index;
    __label__ = 2;
    break;
   case 2:
    var $_0;
    var $2 = Math.floor(($_0 >>> 0) / 10);
    var $5 = (($_0 >>> 0) % 10 | 48) & 255;
    var $6 = __ZN7mozilla9RangedPtrIcEmmEv($end);
    var $_idx_val = HEAP32[$6 >> 2];
    var $7 = __ZNK7mozilla9RangedPtrIcEdeEv($_idx_val);
    HEAP8[$7] = $5;
    if ($_0 >>> 0 > 9) {
      var $_0 = $2;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = HEAP32[$_01 >> 2];
    HEAP32[$agg_result >> 2] = $10;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla9RangedPtrIcEmmEv($this) {
  var $1 = __ZN7mozilla9RangedPtrIcEmIEj($this);
  return $1;
}

function __ZN7mozilla9RangedPtrIcEmIEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $this_idx_val = HEAP32[$this >> 2];
  __ZN7mozilla9RangedPtrIcEmiEj($1, $this_idx_val);
  var $_idx_val = HEAP32[$1 >> 2];
  __ZN7mozilla9RangedPtrIcEaSIcEERS1_RKNS0_IT_EE($this, $_idx_val);
  STACKTOP = __stackBase__;
  return $this;
}

function __ZN7mozilla9RangedPtrIcEmiEj($agg_result, $this_0_0_val) {
  var $1 = $this_0_0_val - 1 | 0;
  __ZNK7mozilla9RangedPtrIcE6createEPc($agg_result, $1);
  return;
}

function __ZNK7mozilla9RangedPtrIcE6createEPc($agg_result, $ptr) {
  __ZN7mozilla9RangedPtrIcEC1EPcS2_j($agg_result, $ptr);
  return;
}

function __ZN2jsL14IsConstructingEPKN2JS5ValueE2144($vp) {
  var $_idx = $vp + 8 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $1 = __ZNK2JS5Value7isMagicEv($_idx_val$0, $_idx_val$1);
  return $1;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2145($cx) {
  var $3 = HEAPU32[__ZN2js11NumberClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb2146($3);
  var $5 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2147($cx, $4);
  return $5;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2147($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js11NumberClassE + 4 >> 2] >>> 24;
    var $4 = __ZNK9JSContext5hasfpEv($cx);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $7;
    var $8 = $cx;
    var $9 = $global;
    var $10 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($8, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $18 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZNK9JSContext2fpEv($cx);
    var $13 = __ZNK2js10StackFrame10scopeChainEv($12);
    var $14 = $13;
    var $15 = __ZNK8JSObject9getGlobalEv($14);
    var $16 = $15;
    HEAP32[$global >> 2] = $16;
    var $18 = $16;
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $18, $19);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $20 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    HEAP32[$proto >> 2] = $22;
    var $29 = $22;
    __label__ = 9;
    break;
   case 7:
    var $24 = $cx;
    var $26 = $proto;
    var $27 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($24, $18, $3, $26, __ZN2js11NumberClassE);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $29 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $29;
    var $30 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2148($cx, $29, $18, $kind);
    var $_0 = $30;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2148($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, __ZN2js11NumberClassE, $1, $parent, 0, (__ZN2js11NumberClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $7 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, __ZN2js11NumberClassE, $kind);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $10);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11NumberValueEd2157($agg_result, $dbl) {
  var $1 = __ZN2JS5Value9setNumberEd($agg_result, $dbl);
  return;
}

function __ZL14js_hash_objectPKv($key) {
  return $key >>> 8;
}

function __ZN17BinaryDigitReader9nextDigitEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 8 | 0;
    var $2 = HEAPU32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $33 = $2;
    var $32 = HEAP32[$this + 4 >> 2];
    __label__ = 10;
    break;
   case 3:
    var $5 = $this + 12 | 0;
    var $6 = HEAP32[$5 >> 2];
    if (($6 | 0) == (HEAP32[$this + 16 >> 2] | 0)) {
      var $_0 = -1;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $6 + 2 | 0;
    HEAP32[$5 >> 2] = $11;
    var $12 = HEAPU16[$6 >> 1];
    var $13 = $12 & 65535;
    if (($12 - 48 & 65535 & 65535) < 10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = $13 - 48 | 0;
    HEAP32[$this + 4 >> 2] = $16;
    var $27 = $16;
    __label__ = 9;
    break;
   case 6:
    if (($12 - 97 & 65535 & 65535) < 26) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $21 = $13 - 87 | 0;
    HEAP32[$this + 4 >> 2] = $21;
    var $27 = $21;
    __label__ = 9;
    break;
   case 8:
    var $24 = $13 - 55 | 0;
    HEAP32[$this + 4 >> 2] = $24;
    var $27 = $24;
    __label__ = 9;
    break;
   case 9:
    var $27;
    var $30 = HEAP32[$this >> 2] >> 1;
    HEAP32[$1 >> 2] = $30;
    var $33 = $30;
    var $32 = $27;
    __label__ = 10;
    break;
   case 10:
    var $32;
    var $33;
    HEAP32[$1 >> 2] = $33 >> 1;
    var $_0 = ($33 & $32 | 0) != 0 & 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN17BinaryDigitReader9nextDigitEv["X"] = 1;

function __ZN17BinaryDigitReaderC2EiPKtS1_($this, $base, $start, $end) {
  HEAP32[$this >> 2] = $base;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = $start;
  HEAP32[$this + 16 >> 2] = $end;
  return;
}

function __ZL6num_toP9JSContext12JSDToStrModeS1_iiijPN2JS5ValueE($cx, $zeroArgMode, $oneArgMode, $precisionMin, $precisionOffset, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 184;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $buf = __stackBase__;
    var $d = __stackBase__ + 128;
    var $precision = __stackBase__ + 136;
    var $cbuf = __stackBase__ + 144;
    var $1 = __ZN2js16GetPrimitiveThisIdEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $d);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    tempDoubleF64[0] = 0, HEAP32[$precision >> 2] = tempDoubleI32[0], HEAP32[$precision + 4 >> 2] = tempDoubleI32[1];
    var $_01 = $zeroArgMode;
    var $17 = 0;
    __label__ = 7;
    break;
   case 4:
    var $6 = $vp + 16 | 0;
    var $7 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd2159($cx, $6, $precision);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $9 = (tempDoubleI32[0] = HEAP32[$precision >> 2], tempDoubleI32[1] = HEAP32[$precision + 4 >> 2], tempDoubleF64[0]);
    if ($9 < ($precisionMin | 0) | $9 > 100) {
      __label__ = 6;
      break;
    } else {
      var $_01 = $oneArgMode;
      var $17 = $9;
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js12ToCStringBufC2Ev($cbuf);
    var $14 = $9 & -1;
    var $15 = __ZL12IntToCStringPN2js12ToCStringBufEii($cbuf, $14, 10);
    _JS_ReportErrorNumber($cx, 4, 150, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $15, tempInt));
    var $cbuf_idx_val = HEAP32[$cbuf + 36 >> 2];
    __ZN2js12ToCStringBufD2Ev($cbuf_idx_val);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 7:
    var $17;
    var $_01;
    var $21 = HEAP32[HEAP32[$cx + 52 >> 2] + 209876 >> 2];
    var $22 = $buf | 0;
    var $24 = ($17 & -1) + $precisionOffset | 0;
    var $25 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $26 = _js_dtostr($21, $22, 125, $_01, $24, $25);
    if (($26 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    _JS_ReportOutOfMemory($cx);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 9:
    var $30 = $cx;
    var $31 = __Z17js_NewStringCopyZP9JSContextPKc($30, $26);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $34 = $31 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $34);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL6num_toP9JSContext12JSDToStrModeS1_iiijPN2JS5ValueE["X"] = 1;

function __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd2159($cx, $v, $dp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx2 = $v | 0;
    var $v_idx2_val$0 = HEAP32[$v_idx2 >> 2];
    var $v_idx2_val$1 = HEAP32[$v_idx2 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx2_val$0, $v_idx2_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx2_val$0, $v_idx2_val$1);
    tempDoubleF64[0] = $3 | 0, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 8;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($v_idx2_val$0, $v_idx2_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($v);
    tempDoubleF64[0] = $8, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $12 = $8;
    __label__ = 7;
    break;
   case 5:
    var $10 = __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($cx, $v_idx2_val$0, $v_idx2_val$1, $dp);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $_pre = (tempDoubleI32[0] = HEAP32[$dp >> 2], tempDoubleI32[1] = HEAP32[$dp + 4 >> 2], tempDoubleF64[0]);
    var $12 = $_pre;
    __label__ = 7;
    break;
   case 7:
    var $12;
    var $13 = __ZL18js_DoubleToIntegerd2161($12);
    tempDoubleF64[0] = $13, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18js_DoubleToIntegerd2161($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d == 0) {
      var $_0 = $d;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL18JSDOUBLE_IS_FINITEd2111($d);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZL15JSDOUBLE_IS_NaNd2114($d);
    var $d_ = ($6 | 0) == 0 ? $d : 0;
    var $_0 = $d_;
    __label__ = 7;
    break;
   case 4:
    if ($d < 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = _floor($d);
    var $_0 = $10;
    __label__ = 7;
    break;
   case 6:
    var $12 = -$d;
    var $13 = _floor($12);
    var $_0 = -$13;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20ParseIntDoubleHelperd($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d > 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = _floor($d);
    var $_0 = $3;
    __label__ = 5;
    break;
   case 3:
    if ($d < 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = -$d;
    var $8 = _floor($7);
    var $_0 = -$8;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20ParseIntStringHelperP9JSContextPKtS2_ibPd($cx, $ws, $end, $maybeRadix, $stripPrefix, $dp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $actualEnd = __stackBase__;
    var $1 = __ZN2jsL9SkipSpaceEPKtS1_($ws, $end);
    if (($1 | 0) == ($end | 0)) {
      var $s_0 = $1;
      var $8 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP16[$1 >> 1];
    var $5 = $4 << 16 >> 16 == 45;
    if ($4 << 16 >> 16 == 45 || $4 << 16 >> 16 == 43) {
      __label__ = 3;
      break;
    } else {
      var $s_0 = $1;
      var $8 = $5;
      __label__ = 4;
      break;
    }
   case 3:
    var $s_0 = $1 + 2 | 0;
    var $8 = $5;
    __label__ = 4;
    break;
   case 4:
    var $8;
    var $s_0;
    if (($maybeRadix | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $radix_0 = $maybeRadix;
      __label__ = 9;
      break;
    }
   case 5:
    if (($end - $s_0 | 0) > 2) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (HEAP16[$s_0 >> 1] << 16 >> 16 == 48) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = HEAP16[$s_0 + 2 >> 1];
    if ($20 << 16 >> 16 == 120 || $20 << 16 >> 16 == 88) {
      __label__ = 8;
      break;
    } else {
      var $radix_0 = 8;
      __label__ = 9;
      break;
    }
   case 8:
    var $radix_0 = 10;
    __label__ = 9;
    break;
   case 9:
    var $radix_0;
    if ($stripPrefix) {
      __label__ = 10;
      break;
    } else {
      var $radix_1 = $radix_0;
      var $s_1 = $s_0;
      __label__ = 14;
      break;
    }
   case 10:
    if (($end - $s_0 | 0) > 2) {
      __label__ = 11;
      break;
    } else {
      var $radix_1 = $radix_0;
      var $s_1 = $s_0;
      __label__ = 14;
      break;
    }
   case 11:
    if (HEAP16[$s_0 >> 1] << 16 >> 16 == 48) {
      __label__ = 12;
      break;
    } else {
      var $radix_1 = $radix_0;
      var $s_1 = $s_0;
      __label__ = 14;
      break;
    }
   case 12:
    var $33 = HEAP16[$s_0 + 2 >> 1];
    if ($33 << 16 >> 16 == 120 || $33 << 16 >> 16 == 88) {
      __label__ = 13;
      break;
    } else {
      var $radix_1 = $radix_0;
      var $s_1 = $s_0;
      __label__ = 14;
      break;
    }
   case 13:
    var $radix_1 = 16;
    var $s_1 = $s_0 + 4 | 0;
    __label__ = 14;
    break;
   case 14:
    var $s_1;
    var $radix_1;
    var $37 = __ZN2js16GetPrefixIntegerEP9JSContextPKtS3_iPS3_Pd($cx, $s_1, $end, $radix_1, $actualEnd, $dp);
    if ($37) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 15:
    if (($s_1 | 0) == (HEAP32[$actualEnd >> 2] | 0)) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $42 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $42, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 19;
    break;
   case 17:
    if ($8) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 1;
      __label__ = 19;
      break;
    }
   case 18:
    var $45 = (tempDoubleI32[0] = HEAP32[$dp >> 2], tempDoubleI32[1] = HEAP32[$dp + 4 >> 2], tempDoubleF64[0]);
    var $46 = -$45;
    tempDoubleF64[0] = $46, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL20ParseIntStringHelperP9JSContextPKtS2_ibPd["X"] = 1;

function __ZN17BinaryDigitReaderC1EiPKtS1_($this, $base, $start, $end) {
  __ZN17BinaryDigitReaderC2EiPKtS1_($this, $base, $start, $end);
  return;
}

function __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $cx;
    if ((HEAP32[$obj >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($3, 4, 2, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $6 = $obj;
    __Z19OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($3, $6);
    var $_0 = (HEAP32[$obj >> 2] | 0) != 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12obj_getProtoP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $attrs = __stackBase__;
  var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210292 >> 2] | 0;
  var $6 = __ZL12ATOM_TO_JSIDP6JSAtom2291($5);
  var $7 = __ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj($cx, $obj, $6, 0, $vp, $attrs);
  STACKTOP = __stackBase__;
  return $7;
}

function __ZL12obj_setProtoP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $attrs = __stackBase__ + 4;
    var $1 = $cx;
    var $2 = __ZNK9JSContext28runningWithTrustedPrincipalsEv($1);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[_sSetProtoCalled >> 2] + 1 | 0;
    HEAP32[_sSetProtoCalled >> 2] = $5;
    __label__ = 3;
    break;
   case 3:
    var $_idx_val = HEAP32[$obj + 8 >> 2];
    var $8 = __ZNK8JSObject12isExtensibleEv($_idx_val);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZN8JSObject19reportNotExtensibleEP9JSContextj($obj, $cx, 0);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 5:
    var $vp_idx1 = $vp | 0;
    var $vp_idx1_val$0 = HEAP32[$vp_idx1 >> 2];
    var $vp_idx1_val$1 = HEAP32[$vp_idx1 + 4 >> 2];
    var $12 = __ZNK2JS5Value14isObjectOrNullEv($vp_idx1_val$0, $vp_idx1_val$1);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 10;
      break;
    }
   case 6:
    var $14 = __ZNK2JS5Value14toObjectOrNullEv($vp_idx1_val$0, $vp_idx1_val$1);
    var $15 = $14;
    HEAP32[$pobj >> 2] = $15;
    if (($14 | 0) == 0) {
      var $22 = $15;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = $pobj;
    __Z19OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($1, $18);
    var $19 = HEAP32[$pobj >> 2];
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      var $22 = $19;
      __label__ = 8;
      break;
    }
   case 8:
    var $22;
    var $27 = HEAP32[HEAP32[$cx + 52 >> 2] + 210292 >> 2] | 0;
    var $28 = __ZL12ATOM_TO_JSIDP6JSAtom2291($27);
    var $29 = __ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj($cx, $obj, $28, 8, $vp, $attrs);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = __ZN2js8SetProtoEP9JSContextP8JSObjectS3_b($cx, $obj, $22, 1);
    var $_0 = $32 & 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19js_EnterSharpObjectP9JSContextP8JSObjectPP9JSIdArrayPPt($cx, $obj, $idap, $sp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ida = __stackBase__;
    var $hep = __stackBase__ + 4;
    var $buf = __stackBase__ + 8;
    var $len = __stackBase__ + 28;
    var $1 = $cx + 52 | 0;
    if ((HEAP32[HEAP32[$1 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $cx;
    var $8 = __Z26js_InvokeOperationCallbackP9JSContext($7);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$sp >> 2] = 0;
    var $10 = $cx + 144 | 0;
    var $11 = HEAP32[$10 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $table_0 = $11;
      __label__ = 7;
      break;
    }
   case 4:
    var $14 = _JS_NewHashTable();
    if (($14 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $17 = $cx;
    _JS_ReportOutOfMemory($17);
    var $_0 = 0;
    __label__ = 32;
    break;
   case 6:
    HEAP32[$10 >> 2] = $14;
    var $20 = HEAP32[$1 >> 2] + 136 | 0;
    var $22 = HEAP32[$20 >> 2] + 1 | 0;
    HEAP32[$20 >> 2] = $22;
    var $table_0 = $14;
    __label__ = 7;
    break;
   case 7:
    var $table_0;
    HEAP32[$ida >> 2] = 0;
    var $24 = $cx + 136 | 0;
    if ((HEAP32[$24 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    HEAP32[$24 >> 2] = 1;
    var $28 = __ZL16MarkSharpObjectsP9JSContextP8JSObjectPP9JSIdArray($cx, $obj, $ida);
    var $30 = HEAP32[$24 >> 2] - 1 | 0;
    HEAP32[$24 >> 2] = $30;
    if (($28 | 0) == 0) {
      var $93 = $30;
      __label__ = 30;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (($idap | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $he_0 = $28;
      __label__ = 14;
      break;
    }
   case 10:
    var $36 = HEAP32[$ida >> 2];
    _JS_DestroyIdArray($36);
    HEAP32[$ida >> 2] = 0;
    var $he_0 = $28;
    __label__ = 14;
    break;
   case 11:
    var $38 = $obj;
    var $39 = __ZL14js_hash_objectPKv($38);
    var $40 = _JS_HashTableRawLookup($table_0, $39, $38);
    HEAP32[$hep >> 2] = $40;
    var $41 = HEAP32[$40 >> 2];
    if (($41 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $he_0 = $41;
      __label__ = 14;
      break;
    }
   case 12:
    var $44 = _JS_HashTableRawAdd($table_0, $hep, $39, $38);
    if (($44 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $he_12 = $44;
      __label__ = 21;
      break;
    }
   case 13:
    var $47 = $cx;
    _JS_ReportOutOfMemory($47);
    __label__ = 29;
    break;
   case 14:
    var $he_0;
    var $50 = HEAP32[$he_0 + 12 >> 2];
    var $51 = $50;
    if (($50 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $_pre_phi = $51 & 1;
    __label__ = 19;
    break;
   case 16:
    var $54 = $buf | 0;
    var $55 = $51 >>> 2;
    var $56 = $51 & 1;
    var $58 = ($56 | 0) != 0 ? 35 : 61;
    var $59 = _JS_snprintf($54, 20, STRING_TABLE.__str63591 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $55, HEAP32[tempInt + 4 >> 2] = $58, tempInt));
    HEAP32[$len >> 2] = $59;
    var $60 = $cx;
    var $61 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($60, $54, $len, 0);
    HEAP32[$sp >> 2] = $61;
    if (($61 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $_pre_phi = $56;
      __label__ = 19;
      break;
    }
   case 17:
    var $64 = HEAP32[$ida >> 2];
    if (($64 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $67 = $64;
    _JS_DestroyIdArray($67);
    __label__ = 29;
    break;
   case 19:
    var $_pre_phi;
    if (($_pre_phi | 0) == 0) {
      var $he_12 = $he_0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    if (($idap | 0) == 0) {
      var $_0 = $he_0;
      __label__ = 32;
      break;
    } else {
      var $he_116 = $he_0;
      __label__ = 28;
      break;
    }
   case 21:
    var $he_12;
    if (($idap | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    if ((HEAP32[$ida >> 2] | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 23:
    var $75 = $cx;
    var $76 = $obj;
    var $77 = _JS_Enumerate($75, $76);
    HEAP32[$ida >> 2] = $77;
    if (($77 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 24:
    var $81 = HEAP32[$sp >> 2];
    if (($81 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $84 = $81;
    __ZN9JSContext5free_EPv($84);
    HEAP32[$sp >> 2] = 0;
    __label__ = 29;
    break;
   case 26:
    var $86 = HEAP32[$24 >> 2] + 1 | 0;
    HEAP32[$24 >> 2] = $86;
    var $he_116 = $he_12;
    __label__ = 28;
    break;
   case 27:
    var $89 = HEAP32[$24 >> 2] + 1 | 0;
    HEAP32[$24 >> 2] = $89;
    var $_0 = $he_12;
    __label__ = 32;
    break;
   case 28:
    var $he_116;
    var $91 = HEAP32[$ida >> 2];
    HEAP32[$idap >> 2] = $91;
    var $_0 = $he_116;
    __label__ = 32;
    break;
   case 29:
    var $93 = HEAP32[$24 >> 2];
    __label__ = 30;
    break;
   case 30:
    var $93;
    if (($93 | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      var $_0 = 0;
      __label__ = 32;
      break;
    }
   case 31:
    var $97 = HEAP32[$1 >> 2] + 136 | 0;
    var $99 = HEAP32[$97 >> 2] - 1 | 0;
    HEAP32[$97 >> 2] = $99;
    HEAP32[$cx + 140 >> 2] = 0;
    var $101 = HEAP32[$10 >> 2];
    _JS_HashTableDestroy($101);
    HEAP32[$10 >> 2] = 0;
    var $_0 = 0;
    __label__ = 32;
    break;
   case 32:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z19js_EnterSharpObjectP9JSContextP8JSObjectPP9JSIdArrayPPt["X"] = 1;

function __ZL16MarkSharpObjectsP9JSContextP8JSObjectPP9JSIdArray($cx, $obj, $idap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $hep = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $v = __stackBase__ + 16;
    var $setter = __stackBase__ + 40;
    var $1 = __stackBase__ + 64;
    var $2 = __stackBase__ + 72;
    if (__stackBase__ + 12 >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $cx;
    __Z21js_ReportOverRecursedP9JSContext($8);
    var $_0 = 0;
    __label__ = 34;
    break;
   case 3:
    var $11 = HEAPU32[$cx + 144 >> 2];
    var $12 = $obj;
    var $13 = __ZL14js_hash_objectPKv($12);
    var $14 = _JS_HashTableRawLookup($11, $13, $12);
    HEAP32[$hep >> 2] = $14;
    var $15 = HEAPU32[$14 >> 2];
    if (($15 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 4:
    var $18 = _JS_HashTableRawAdd($11, $hep, $13, $12);
    var $20 = $cx;
    if (($18 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    _JS_ReportOutOfMemory($20);
    var $_0 = 0;
    __label__ = 34;
    break;
   case 6:
    var $23 = $obj;
    var $24 = _JS_Enumerate($20, $23);
    var $25 = $24;
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $29 = HEAP32[$24 >> 2];
    var $30 = $obj2;
    var $31 = $prop;
    var $32 = $v;
    var $33 = $setter;
    var $34 = $v;
    var $35 = $setter;
    var $_idx9 = $1 | 0;
    var $_idx8 = $2 | 0;
    var $i_0 = 0;
    var $ok_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $ok_0;
    var $i_0;
    if (($i_0 | 0) < ($29 | 0)) {
      __label__ = 9;
      break;
    } else {
      var $ok_5 = $ok_0;
      __label__ = 27;
      break;
    }
   case 9:
    var $40 = HEAPU32[$24 + 4 + ($i_0 << 2) >> 2];
    var $41 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($23, $20, $40, $30, $31);
    if (($41 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    _JS_DestroyIdArray($24);
    var $_0 = 0;
    __label__ = 34;
    break;
   case 11:
    if ((HEAP32[$prop >> 2] | 0) == 0) {
      var $ok_4 = $41;
      __label__ = 26;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN2js15AutoValueRooterC1EP9JSContext($32, $20);
    __ZN2js15AutoValueRooterC1EP9JSContext($33, $20);
    var $_idx6_val = HEAP32[HEAP32[$obj2 >> 2] >> 2];
    var $48 = __ZNK8JSObject8isNativeEv($_idx6_val);
    if ($48) {
      __label__ = 13;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 13:
    var $50 = HEAP32[$prop >> 2];
    var $51 = $50;
    var $_idx4_val = HEAP8[$50 + 28 | 0];
    var $53 = __ZNK2js5Shape14hasGetterValueEv($_idx4_val);
    var $54 = __ZNK2js5Shape14hasSetterValueEv($_idx4_val);
    if ($53) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    __ZNK2js5Shape11getterValueEv($1, $51);
    var $st$1$0 = $_idx9 | 0;
    var $_idx9_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx9 + 4 | 0;
    var $_idx9_val$1 = HEAP32[$st$1$1 >> 2];
    __ZN2js15AutoValueRooter3setEN2JS5ValueE($34, $_idx9_val$0, $_idx9_val$1);
    __label__ = 15;
    break;
   case 15:
    if ($54) {
      __label__ = 16;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 16:
    __ZNK2js5Shape11setterValueEv($2, $51);
    var $st$1$0 = $_idx8 | 0;
    var $_idx8_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx8 + 4 | 0;
    var $_idx8_val$1 = HEAP32[$st$1$1 >> 2];
    __ZN2js15AutoValueRooter3setEN2JS5ValueE($35, $_idx8_val$0, $_idx8_val$1);
    if ($53) {
      __label__ = 17;
      break;
    } else {
      var $ok_1 = $41;
      __label__ = 19;
      break;
    }
   case 17:
    var $59 = __ZNK2js15AutoValueRooter5valueEv($32);
    var $_idx1 = $59 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $60 = __ZNK2JS5Value8isObjectEv($_idx1_val$0, $_idx1_val$1);
    if ($60) {
      __label__ = 18;
      break;
    } else {
      var $ok_1 = $41;
      __label__ = 19;
      break;
    }
   case 18:
    var $62 = __ZNK2JS5Value8toObjectEv($_idx1_val$0, $_idx1_val$1);
    var $63 = $62;
    var $64 = __ZL16MarkSharpObjectsP9JSContextP8JSObjectPP9JSIdArray($cx, $63, 0);
    var $65 = ($64 | 0) != 0;
    var $66 = $65 & 1;
    if ($65) {
      var $ok_1 = $66;
      __label__ = 19;
      break;
    } else {
      var $_01 = 1;
      var $ok_3 = $66;
      __label__ = 25;
      break;
    }
   case 19:
    var $ok_1;
    var $68 = __ZNK2js15AutoValueRooter5valueEv($33);
    var $69 = $68 | 0;
    var $st$3$0 = $69 | 0;
    var $70$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $69 + 4 | 0;
    var $70$1 = HEAP32[$st$3$1 >> 2];
    __ZN2js15AutoValueRooter3setEN2JS5ValueE($34, $70$0, $70$1);
    var $ok_2 = $ok_1;
    __label__ = 22;
    break;
   case 20:
    if ($53) {
      var $ok_2 = $41;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $71 = __ZN2js15AutoValueRooter4addrEv($32);
    var $72 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($23, $20, $40, $71);
    if (($72 | 0) == 0) {
      var $_01 = 1;
      var $ok_3 = 0;
      __label__ = 25;
      break;
    } else {
      var $ok_2 = $72;
      __label__ = 22;
      break;
    }
   case 22:
    var $ok_2;
    var $75 = __ZNK2js15AutoValueRooter5valueEv($32);
    var $_idx = $75 | 0;
    var $st$3$0 = $_idx | 0;
    var $_idx_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAP32[$st$3$1 >> 2];
    var $76 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($76) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $78 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $79 = $78;
    var $80 = __ZL16MarkSharpObjectsP9JSContextP8JSObjectPP9JSIdArray($cx, $79, 0);
    if (($80 | 0) == 0) {
      var $_01 = 1;
      var $ok_3 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $_01 = 0;
    var $ok_3 = $ok_2;
    __label__ = 25;
    break;
   case 25:
    var $ok_3;
    var $_01;
    __ZN2js15AutoValueRooterD1Ev($33);
    __ZN2js15AutoValueRooterD1Ev($32);
    if ($_01) {
      var $ok_5 = $ok_3;
      __label__ = 27;
      break;
    } else {
      var $ok_4 = $ok_3;
      __label__ = 26;
      break;
    }
   case 26:
    var $ok_4;
    var $i_0 = $i_0 + 1 | 0;
    var $ok_0 = $ok_4;
    __label__ = 8;
    break;
   case 27:
    var $ok_5;
    var $87 = ($ok_5 | 0) != 0;
    if (($idap | 0) == 0 | $87 ^ 1) {
      __label__ = 28;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 28:
    _JS_DestroyIdArray($24);
    if ($87) {
      var $ida_0 = $25;
      var $he_0 = $18;
      __label__ = 32;
      break;
    } else {
      var $_0 = 0;
      __label__ = 34;
      break;
    }
   case 29:
    if ($87) {
      var $ida_0 = $25;
      var $he_0 = $18;
      __label__ = 32;
      break;
    } else {
      var $_0 = 0;
      __label__ = 34;
      break;
    }
   case 30:
    var $92 = $15 + 12 | 0;
    if ((HEAP32[$92 >> 2] | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      var $ida_0 = 0;
      var $he_0 = $15;
      __label__ = 32;
      break;
    }
   case 31:
    var $96 = $cx + 140 | 0;
    var $98 = HEAP32[$96 >> 2] + 1 | 0;
    HEAP32[$96 >> 2] = $98;
    var $100 = $98 << 2;
    HEAP32[$92 >> 2] = $100;
    var $ida_0 = 0;
    var $he_0 = $15;
    __label__ = 32;
    break;
   case 32:
    var $he_0;
    var $ida_0;
    if (($idap | 0) == 0) {
      var $_0 = $he_0;
      __label__ = 34;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    HEAP32[$idap >> 2] = $ida_0;
    var $_0 = $he_0;
    __label__ = 34;
    break;
   case 34:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16MarkSharpObjectsP9JSContextP8JSObjectPP9JSIdArray["X"] = 1;

function __Z19js_LeaveSharpObjectP9JSContextPP9JSIdArray($cx, $idap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 136 | 0;
    var $3 = HEAP32[$1 >> 2] - 1 | 0;
    HEAP32[$1 >> 2] = $3;
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = HEAP32[$cx + 52 >> 2] + 136 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    HEAP32[$cx + 140 >> 2] = 0;
    var $12 = $cx + 144 | 0;
    var $13 = HEAP32[$12 >> 2];
    _JS_HashTableDestroy($13);
    HEAP32[$12 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    if (($idap | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = HEAP32[$idap >> 2];
    if (($17 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = $17;
    _JS_DestroyIdArray($20);
    HEAP32[$idap >> 2] = 0;
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_TraceSharpMapP8JSTracerP16JSSharpObjectMap($trc, $map_0_2_val) {
  var $1 = $trc;
  _JS_HashTableEnumerateEntries($map_0_2_val, $1);
  return;
}

function __ZL27gc_sharp_table_entry_markerP11JSHashEntryiPv($he_0_2_val, $i, $arg) {
  var $1 = $arg;
  var $2 = $he_0_2_val;
  __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($1, $2);
  return 0;
}

function __ZN2jsL16CastAsPropertyOpEP8JSObject2286($object) {
  return $object;
}

function __ZN2js18obj_toStringHelperEP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx1_val = HEAP32[$obj + 4 >> 2];
    var $2 = __ZNK8JSObject7isProxyEv($_idx1_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $obj;
    var $5 = $cx;
    var $6 = __ZN2js7JSProxy12obj_toStringEP9JSContextP8JSObject($5, $4);
    var $_0 = $6;
    __label__ = 10;
    break;
   case 3:
    var $8 = __ZNK8JSObject8getClassEv($_idx1_val);
    var $10 = HEAP32[$8 >> 2];
    var $11 = _strlen($10);
    var $13 = ($11 << 1) + 20 | 0;
    var $14 = $cx;
    var $15 = __ZN9JSContext7malloc_Ej($14, $13);
    var $16 = $15;
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP16[$16 >> 1] = 91;
    var $nchars_05 = 0;
    var $prefix_06 = STRING_TABLE.__str12178 | 0;
    __label__ = 6;
    break;
   case 5:
    var $18 = HEAP8[$10];
    HEAP16[$27 >> 1] = $18 << 24 >> 24;
    var $21 = $nchars_05 + 2 | 0;
    if ($18 << 24 >> 24 == 0) {
      var $_lcssa = $27;
      var $_lcssa1 = $21;
      __label__ = 8;
      break;
    } else {
      var $clazz_02 = $10;
      var $29 = $21;
      __label__ = 7;
      break;
    }
   case 6:
    var $prefix_06;
    var $nchars_05;
    var $23 = $nchars_05 + 1 | 0;
    var $24 = $prefix_06 + 1 | 0;
    var $25 = HEAP8[$24];
    var $27 = $16 + ($23 << 1) | 0;
    HEAP16[$27 >> 1] = $25 << 24 >> 24;
    if ($25 << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      var $nchars_05 = $23;
      var $prefix_06 = $24;
      __label__ = 6;
      break;
    }
   case 7:
    var $29;
    var $clazz_02;
    var $30 = $clazz_02 + 1 | 0;
    var $31 = HEAP8[$30];
    var $33 = $16 + ($29 << 1) | 0;
    HEAP16[$33 >> 1] = $31 << 24 >> 24;
    var $35 = $29 + 1 | 0;
    if ($31 << 24 >> 24 == 0) {
      var $_lcssa = $33;
      var $_lcssa1 = $35;
      __label__ = 8;
      break;
    } else {
      var $clazz_02 = $30;
      var $29 = $35;
      __label__ = 7;
      break;
    }
   case 8:
    var $_lcssa1;
    var $_lcssa;
    HEAP16[$_lcssa >> 1] = 93;
    HEAP16[$16 + ($_lcssa1 << 1) >> 1] = 0;
    var $37 = $cx;
    var $38 = __Z12js_NewStringP9JSContextPtj($37, $16, $_lcssa1);
    var $39 = $38 | 0;
    if (($38 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $_0 = $39;
      __label__ = 10;
      break;
    }
   case 9:
    __ZN9JSContext5free_EPv($15);
    var $_0 = $39;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js18obj_toStringHelperEP9JSContextP8JSObject["X"] = 1;

function __ZN2js13NonNullObjectEP9JSContextRKN2JS5ValueE($cx, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value11isPrimitiveEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $cx;
    _JS_ReportErrorNumber($3, 4, 231, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js21InformalValueTypeNameERKN2JS5ValueE($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZNK8JSObject8getClassEv($_idx_val);
    var $_0 = HEAP32[$4 >> 2];
    __label__ = 8;
    break;
   case 3:
    var $8 = __ZNK2JS5Value8isStringEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($8) {
      var $_0 = STRING_TABLE.__str268561 | 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZNK2JS5Value8isNumberEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($10) {
      var $_0 = STRING_TABLE.__str32180 | 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = __ZNK2JS5Value9isBooleanEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($12) {
      var $_0 = STRING_TABLE.__str42181 | 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = __ZNK2JS5Value6isNullEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($14) {
      var $_0 = STRING_TABLE.__str483817 | 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $16 = __ZNK2JS5Value11isUndefinedEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_ = $16 ? STRING_TABLE.__str493818 | 0 : STRING_TABLE.__str247540 | 0;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4evalEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($call, $argc, $vp);
    var $call_idx_val = HEAP32[$call + 4 >> 2];
    var $1 = __ZL17WarnOnTooManyArgsP9JSContextRKN2js8CallArgsE($cx, $call_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $9 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$call >> 2];
    var $3 = __ZNK2js12CallReceiver6calleeEv($_idx_val);
    var $4 = $3;
    var $5 = __ZNK8JSObject9getGlobalEv($4);
    var $6 = $5 | 0;
    var $7 = __ZL10EvalKernelP9JSContextRKN2js8CallArgsE8EvalTypePNS1_10StackFrameER8JSObject($cx, $call, 9, 0, $6);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    STACKTOP = __stackBase__;
    return $9 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17WarnOnTooManyArgsP9JSContextRKN2js8CallArgsE($cx, $call_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js8CallArgs4argcEv($call_0_1_val);
    if ($1 >>> 0 > 1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 2:
    var $5 = $cx + 60 | 0;
    var $6 = __ZNK2js12ContextStack13currentScriptEPPh($5, 0);
    if (($6 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $6 + 36 | 0;
    if (HEAP8[$9] << 24 >> 24 < 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $cx;
    var $14 = _JS_ReportWarning($13, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = HEAP8[$9] | -128;
    HEAP8[$9] = $18;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10EvalKernelP9JSContextRKN2js8CallArgsE8EvalTypePNS1_10StackFrameER8JSObject($cx, $call, $evalType, $caller, $scopeobj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 68;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $thisv = __stackBase__;
    var $parser = __stackBase__ + 8;
    var $tmp = __stackBase__ + 40;
    var $esg = __stackBase__ + 48;
    var $lineno = __stackBase__ + 64;
    var $1 = __ZNK8JSObject9getGlobalEv($scopeobj);
    var $2 = $1;
    var $3 = $cx;
    var $4 = __ZN2js12GlobalObject23isRuntimeCodeGenEnabledEP9JSContext($2, $3);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx;
    _JS_ReportError($6, STRING_TABLE.__str472250 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 34;
    break;
   case 3:
    var $call_idx_val = HEAP32[$call + 4 >> 2];
    var $8 = __ZNK2js8CallArgs4argcEv($call_idx_val);
    var $_idx9 = $call | 0;
    var $_idx9_val = HEAP32[$_idx9 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = __ZNK2js12CallReceiver4rvalEv($_idx9_val);
    __ZN2JS5Value12setUndefinedEv($11);
    var $_1 = 1;
    __label__ = 34;
    break;
   case 5:
    var $13 = __ZNK2js8CallArgsixEj($_idx9_val, 0);
    var $_idx4 = $13 | 0;
    var $st$2$0 = $_idx4 | 0;
    var $_idx4_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx4 + 4 | 0;
    var $_idx4_val$1 = HEAP32[$st$2$1 >> 2];
    var $14 = __ZNK2JS5Value8isStringEv($_idx4_val$0, $_idx4_val$1);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = __ZNK2js12CallReceiver4rvalEv($_idx9_val);
    var $17 = $16 | 0;
    var $st$2$0 = $17 | 0;
    HEAP32[$st$2$0 >> 2] = $_idx4_val$0;
    var $st$2$1 = $17 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $_idx4_val$1;
    var $_1 = 1;
    __label__ = 34;
    break;
   case 7:
    var $19 = __ZNK2JS5Value8toStringEv($_idx4_val$0, $_idx4_val$1);
    var $20 = ($evalType | 0) == 8;
    if ($20) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $22 = $caller;
    var $23 = __ZNK2js10StackFrame6scriptEv($22);
    var $25 = HEAPU16[$23 + 46 >> 1];
    var $26 = $cx;
    var $27 = __ZN2js11ComputeThisEP9JSContextPNS_10StackFrameE($26, $22);
    if ($27) {
      __label__ = 9;
      break;
    } else {
      var $_1 = 0;
      __label__ = 34;
      break;
    }
   case 9:
    var $30 = ($25 & 65535) + 1 | 0;
    var $31 = __ZNK2js10StackFrame9thisValueEv($22);
    var $32 = $31 | 0;
    var $33$0 = HEAP32[$32 >> 2];
    var $33$1 = HEAP32[$32 + 4 >> 2];
    var $34 = $thisv | 0;
    HEAP32[$34 >> 2] = $33$0;
    HEAP32[$34 + 4 >> 2] = $33$1;
    var $staticLevel_0 = $30;
    __label__ = 12;
    break;
   case 10:
    var $36 = $scopeobj;
    var $37 = $cx;
    var $38 = __ZN8JSObject10thisObjectEP9JSContext($36, $37);
    if (($38 | 0) == 0) {
      var $_1 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $41 = $38;
    __ZN2JSL11ObjectValueER8JSObject2354($thisv, $41);
    var $staticLevel_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $staticLevel_0;
    var $43 = $cx;
    var $44 = __ZN8JSString12ensureLinearEP9JSContext($19, $43);
    if (($44 | 0) == 0) {
      var $_1 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $_idx2_val = HEAP32[$44 + 4 >> 2];
    var $47 = __ZNK14JSLinearString5charsEv($_idx2_val);
    var $48 = $44 | 0;
    var $_idx1_val = HEAP32[$44 >> 2];
    var $49 = __ZNK8JSString6lengthEv($_idx1_val);
    if ($49 >>> 0 > 2) {
      __label__ = 14;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 14:
    if (HEAP16[$47 >> 1] << 16 >> 16 == 40) {
      __label__ = 15;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 15:
    if (HEAP16[$47 + ($49 - 1 << 1) >> 1] << 16 >> 16 == 41) {
      __label__ = 16;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 16:
    if (($caller | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $62 = $caller;
    var $63 = __ZNK2js10StackFrame6scriptEv($62);
    if ((HEAP8[$63 + 36 | 0] & 8) << 24 >> 24 == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 18:
    var $69 = $47 + 2 | 0;
    var $70 = $49 - 2 | 0;
    var $71 = $47 + ($70 << 1) | 0;
    var $cp_0 = $69;
    __label__ = 19;
    break;
   case 19:
    var $cp_0;
    if ((HEAP16[$cp_0 >> 1] - 8232 & 65535 & 65535) < 2) {
      __label__ = 25;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    if (($cp_0 | 0) == ($71 | 0)) {
      __label__ = 21;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 21:
    __ZN10JSONParserC1EP9JSContextPKtjNS_11ParsingModeENS_13ErrorHandlingE($parser, $cx, $69, $70, 0, 1);
    var $77 = $parser;
    var $78 = __ZN10JSONParser5parseEPN2JS5ValueE($77, $tmp);
    if ($78) {
      __label__ = 22;
      break;
    } else {
      var $_1 = 0;
      __label__ = 34;
      break;
    }
   case 22:
    var $tmp_idx = $tmp | 0;
    var $tmp_idx_val$0 = HEAPU32[$tmp_idx >> 2];
    var $tmp_idx_val$1 = HEAP32[$tmp_idx + 4 >> 2];
    var $80 = __ZNK2JS5Value11isUndefinedEv($tmp_idx_val$0, $tmp_idx_val$1);
    if ($80) {
      __label__ = 25;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $_idx7_val = HEAP32[$_idx9 >> 2];
    var $82 = __ZNK2js12CallReceiver4rvalEv($_idx7_val);
    var $83 = $82 | 0;
    var $st$3$0 = $83 | 0;
    HEAP32[$st$3$0 >> 2] = $tmp_idx_val$0;
    var $st$3$1 = $83 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $tmp_idx_val$1;
    var $_1 = 1;
    __label__ = 34;
    break;
   case 24:
    var $cp_0 = $cp_0 + 2 | 0;
    __label__ = 19;
    break;
   case 25:
    __ZN15EvalScriptGuardC1EP9JSContextP14JSLinearString($esg, $cx, $44);
    var $86 = __ZN2js25PrincipalsForCompiledCodeERKNS_8CallArgsEP9JSContext($call, $cx);
    if ($20) {
      __label__ = 26;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 26:
    var $_idx_val = HEAP32[$caller >> 2];
    var $88 = __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($_idx_val);
    if ($88) {
      __label__ = 27;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 27:
    __ZN15EvalScriptGuard17lookupInEvalCacheEPN2js10StackFrameEjP12JSPrincipalsR8JSObject($esg, $caller, $staticLevel_0, $86, $scopeobj);
    __label__ = 28;
    break;
   case 28:
    var $esg_idx = $esg + 12 | 0;
    var $esg_idx_val = HEAPU32[$esg_idx >> 2];
    var $91 = __ZN15EvalScriptGuard11foundScriptEv($esg_idx_val);
    if ($91) {
      __label__ = 29;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 29:
    var $esg_idx10_val = $esg_idx_val;
    var $_pre_phi = $scopeobj;
    __label__ = 32;
    break;
   case 30:
    var $94 = $20 & 1 ^ 1;
    var $95 = __ZN2js24CurrentScriptFileAndLineEP9JSContextPjNS_10LineOptionE($43, $lineno, $94);
    var $96 = HEAP32[$lineno >> 2];
    var $97 = __ZNK9JSContext11findVersionEv($43);
    var $98 = $scopeobj;
    var $99 = $caller;
    var $100 = $86;
    var $101 = __ZN2js8Compiler13compileScriptEP9JSContextP8JSObjectPNS_10StackFrameEP12JSPrincipalsjPKtjPKcj9JSVersionP8JSStringj($43, $98, $99, $100, 33693696, $47, $49, $95, $96, $97, $48, $staticLevel_0);
    if (($101 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $104 = $101;
    __ZN15EvalScriptGuard12setNewScriptEP8JSScript($esg, $104);
    var $esg_idx10_val = HEAP32[$esg_idx >> 2];
    var $_pre_phi = $98;
    __label__ = 32;
    break;
   case 32:
    var $_pre_phi;
    var $esg_idx10_val;
    var $106 = __ZNK15EvalScriptGuard6scriptEv($esg_idx10_val);
    var $_idx6_val = HEAP32[$_idx9 >> 2];
    var $107 = __ZNK2js12CallReceiver4rvalEv($_idx6_val);
    var $108 = $106;
    var $109 = __ZN2js13ExecuteKernelEP9JSContextP8JSScriptR8JSObjectRKN2JS5ValueENS_11ExecuteTypeEPNS_10StackFrameEPS7_($43, $108, $_pre_phi, $thisv, $evalType, 0, $107);
    var $_0 = $109;
    __label__ = 33;
    break;
   case 33:
    var $_0;
    __ZN15EvalScriptGuardD1Ev($esg);
    var $_1 = $_0;
    __label__ = 34;
    break;
   case 34:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10EvalKernelP9JSContextRKN2js8CallArgsE8EvalTypePNS1_10StackFrameER8JSObject["X"] = 1;

function __ZNK8JSObject9getGlobalEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx1_val = HEAP32[$this + 20 >> 2];
    var $2 = __ZNK8JSObject9getParentEv($_idx1_val);
    if (($2 | 0) == 0) {
      var $obj_0_lcssa = $this;
      __label__ = 4;
      break;
    } else {
      var $4 = $2;
      __label__ = 2;
      break;
    }
   case 2:
    var $4;
    var $_idx_val = HEAP32[$4 + 20 >> 2];
    var $5 = __ZNK8JSObject9getParentEv($_idx_val);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 3:
    var $obj_0_lcssa = $4;
    __label__ = 4;
    break;
   case 4:
    var $obj_0_lcssa;
    var $10 = __ZN8JSObject8asGlobalEv($obj_0_lcssa);
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10DirectEvalEP9JSContextRKNS_8CallArgsE($cx, $call) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $callProbe = __stackBase__;
    var $1 = $cx;
    var $2 = __ZNK9JSContext2fpEv($1);
    var $3 = $2;
    var $_idx1_val = HEAP32[$call >> 2];
    var $4 = __ZNK2js12CallReceiver6calleeEv($_idx1_val);
    var $_idx_val = HEAP32[$4 + 24 >> 2];
    var $5 = __ZNK8JSObject18getFunctionPrivateEv($_idx_val);
    var $6 = $5;
    var $7 = __ZNK2js10StackFrame6scriptEv($2);
    var $8 = $7;
    __ZN2js21AutoFunctionCallProbeC1EP9JSContextP10JSFunctionP8JSScript($callProbe, $cx, $6, $8);
    var $9 = __ZN2js17GetScopeChainFastEP9JSContextPNS_10StackFrameE4JSOpj($1, $2, 6);
    var $10 = $9;
    if (($9 | 0) == 0) {
      var $17 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $call_idx_val = HEAP32[$call + 4 >> 2];
    var $13 = __ZL17WarnOnTooManyArgsP9JSContextRKN2js8CallArgsE($cx, $call_idx_val);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      var $17 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $15 = __ZL10EvalKernelP9JSContextRKN2js8CallArgsE8EvalTypePNS1_10StackFrameER8JSObject($cx, $call, 8, $3, $10);
    var $17 = $15;
    __label__ = 4;
    break;
   case 4:
    var $17;
    STACKTOP = __stackBase__;
    return $17;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js21AutoFunctionCallProbeC1EP9JSContextP10JSFunctionP8JSScript($this, $cx, $fun, $script) {
  __ZN2js21AutoFunctionCallProbeC2EP9JSContextP10JSFunctionP8JSScript($this, $cx, $fun, $script);
  return;
}

function __ZN2js21IsBuiltinEvalForScopeEP8JSObjectRKN2JS5ValueE($scopeChain, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  var $1 = __ZNK8JSObject9getGlobalEv($scopeChain);
  var $2 = __ZNK2js12GlobalObject15getOriginalEvalEv($1);
  var $_idx = $2 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $3 = __ZNK2JS5ValueeqERKS0_($_idx_val$0, $_idx_val$1, $v_0_0_0_val$0, $v_0_0_0_val$1);
  return $3;
}

function __ZNK2js12GlobalObject15getOriginalEvalEv($this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject7getSlotEj($1, 116);
  return $2;
}

function __ZN2js25PrincipalsForCompiledCodeERKNS_8CallArgsEP9JSContext($call, $cx) {
  var $_idx_val = HEAP32[$call >> 2];
  var $1 = __ZNK2js12CallReceiver6calleeEv($_idx_val);
  var $2 = $cx;
  var $3 = __ZN8JSObject10principalsEP9JSContext($1, $2);
  return $3;
}

function __Z23js_HasOwnPropertyHelperP9JSContextPFiS0_P8JSObjectiPS2_PP10JSPropertyEjPN2JS5ValueE($cx, $lookup, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $obj2 = __stackBase__ + 12;
    var $prop = __stackBase__ + 16;
    var $has = __stackBase__ + 20;
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $vp + 16 | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = $1 | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv2280($1);
    __label__ = 4;
    break;
   case 4:
    var $9 = $cx;
    var $10 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($9, $1, $id);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $12 = $vp + 8 | 0;
    var $13 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($9, $12);
    var $14 = $13;
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx_val = HEAP32[$13 + 4 >> 2];
    var $17 = __ZNK8JSObject7isProxyEv($_idx_val);
    var $18 = HEAP32[$id >> 2];
    if ($17) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $20 = __ZN2js7JSProxy6hasOwnEP9JSContextP8JSObjectiPb($9, $13, $18, $has);
    if ($20) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 8:
    var $24 = (HEAP8[$has] & 1) << 24 >> 24 != 0;
    __ZN2JS5Value10setBooleanEb($vp, $24);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 9:
    var $26 = __Z17js_HasOwnPropertyP9JSContextPFiS0_P8JSObjectiPS2_PP10JSPropertyES2_iS3_S6_($cx, $lookup, $14, $18, $obj2, $prop);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $30 = (HEAP32[$prop >> 2] | 0) != 0;
    __ZN2JS5Value10setBooleanEb($vp, $30);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL14UndefinedValueEv2280($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __Z17js_HasOwnPropertyP9JSContextPFiS0_P8JSObjectiPS2_PP10JSPropertyES2_iS3_S6_($cx, $lookup, $obj, $id, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $rf = __stackBase__;
    var $1 = $cx;
    __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $1, 5);
    var $3 = ($lookup | 0) != 0 ? $lookup : 48;
    var $4 = FUNCTION_TABLE[$3]($cx, $obj, $id, $objp, $propp);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$propp >> 2] | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = HEAP32[$objp >> 2];
    if (($10 | 0) == ($obj | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$10 + 4 >> 2];
    var $14 = __ZNK8JSObject8getClassEv($_idx_val);
    var $16 = HEAP32[$14 + 72 >> 2];
    if (($16 | 0) == 0) {
      var $outer_0 = 0;
      var $23 = $10;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = $16;
    var $20 = FUNCTION_TABLE[$19]($cx, $10);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $outer_0 = $20;
    var $23 = HEAP32[$objp >> 2];
    __label__ = 7;
    break;
   case 7:
    var $23;
    var $outer_0;
    if (($outer_0 | 0) == ($23 | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP32[$propp >> 2] = 0;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    var $rf_idx_val = HEAP32[$rf >> 2];
    var $rf_idx1_val = HEAP32[$rf + 4 >> 2];
    __ZN18JSAutoResolveFlagsD1Ev($rf_idx_val, $rf_idx1_val);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $id, $objp, $propp) {
  var $1 = __Z22js_CheckForStringIndexi($id);
  var $3 = HEAP32[$cx + 208 >> 2];
  var $4 = __ZL29LookupPropertyWithFlagsInlineP9JSContextP8JSObjectijPS2_PP10JSProperty($cx, $obj, $1, $3, $objp, $propp);
  return $4 & 1;
}

function __Z23js_PropertyIsEnumerableP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $attrs = __stackBase__ + 8;
    var $1 = $obj;
    var $2 = $cx;
    var $3 = $pobj;
    var $4 = $prop;
    var $5 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($1, $2, $id, $3, $4);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$prop >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2JS5Value10setBooleanEb($vp, 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 4:
    var $12 = HEAP32[$pobj >> 2];
    if (($12 | 0) == ($obj | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JS5Value10setBooleanEb($vp, 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 6:
    var $16 = $12;
    var $17 = __ZN8JSObject13getAttributesEP9JSContextiPj($16, $2, $id, $attrs);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = (HEAP32[$attrs >> 2] & 1 | 0) != 0;
    __ZN2JS5Value10setBooleanEb($vp, $22);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19js_obj_defineGetterP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $id = __stackBase__ + 8;
    var $junk = __stackBase__ + 12;
    var $attrs = __stackBase__ + 20;
    var $1 = __stackBase__ + 24;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($call, $argc, $vp);
    var $2 = $call | 0;
    var $3 = $cx;
    var $4 = __ZN2js16BoxNonStrictThisEP9JSContextRKNS_12CallReceiverE($3, $2);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    var $_idx2_val = HEAPU32[$call >> 2];
    var $6 = __ZNK2js12CallReceiver5thisvEv($_idx2_val);
    var $_idx1 = $6 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $7 = __ZNK2JS5Value8toObjectEv($_idx1_val$0, $_idx1_val$1);
    var $8 = $7;
    if ($argc >>> 0 < 2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2js8CallArgsixEj($_idx2_val, 1);
    var $_idx5 = $11 | 0;
    var $_idx5_val$0 = HEAPU32[$_idx5 >> 2];
    var $_idx5_val$1 = HEAP32[$_idx5 + 4 >> 2];
    var $12 = __ZL13js_IsCallableRKN2JS5ValueE2285($_idx5_val$0, $_idx5_val$1);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _JS_ReportErrorNumber($3, 4, 151, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str12882 | 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 5:
    var $15 = __ZNK2JS5Value8toObjectEv($_idx5_val$0, $_idx5_val$1);
    var $16 = $15;
    var $17 = __ZN2jsL16CastAsPropertyOpEP8JSObject2286($16);
    var $18 = __ZNK2js8CallArgsixEj($_idx2_val, 0);
    var $19 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($3, $18, $id);
    if ($19) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $21 = HEAP32[$id >> 2];
    var $22 = __ZN2js18CheckRedeclarationEP9JSContextP8JSObjectij($3, $7, $21, 16);
    if ($22) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $24 = __ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj($cx, $8, $21, 3, $junk, $attrs);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = __ZNK2js12CallReceiver4rvalEv($_idx2_val);
    __ZN2JS5Value12setUndefinedEv($27);
    __ZN2JSL14UndefinedValueEv2280($1);
    var $28 = $17;
    var $29 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($7, $3, $21, $1, $28, 12, 81);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z19js_obj_defineGetterP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL13js_IsCallableRKN2JS5ValueE2285($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZN8JSObject10isCallableEv($_idx_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj($cx, $obj, $id, $mode, $vp, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $1 = $obj;
    var $_idx6_val = HEAP32[$obj + 4 >> 2];
    var $3 = __ZNK8JSObject6isWithEv($_idx6_val);
    if ($3) {
      var $4 = $1;
      __label__ = 2;
      break;
    } else {
      var $_01_lcssa = $obj;
      var $_lcssa = $1;
      __label__ = 4;
      break;
    }
   case 2:
    var $4;
    var $_idx3_val_idx_val = HEAP32[HEAP32[$4 + 36 >> 2] >> 2];
    var $5 = __ZNK8JSObject8getProtoEv($_idx3_val_idx_val);
    var $_idx5_val = HEAP32[$5 + 4 >> 2];
    var $6 = __ZNK8JSObject6isWithEv($_idx5_val);
    if ($6) {
      var $4 = $5;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_01_lcssa = $5;
    var $_lcssa = $5;
    __label__ = 4;
    break;
   case 4:
    var $_lcssa;
    var $_01_lcssa;
    var $10 = ($mode & 8 | 0) != 0;
    var $11 = $mode & 7;
    if (($11 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($11 | 0) == 1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 5:
    HEAP32[$pobj >> 2] = $_01_lcssa;
    if ($10) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_lcssa_idx2_val_idx_val = HEAP32[HEAP32[$_lcssa + 36 >> 2] >> 2];
    var $14 = __ZNK8JSObject8getProtoEv($_lcssa_idx2_val_idx_val);
    __ZN2JS5Value15setObjectOrNullEP8JSObject($vp, $14);
    __label__ = 7;
    break;
   case 7:
    HEAP32[$attrsp >> 2] = 4;
    __label__ = 21;
    break;
   case 8:
    HEAP32[$pobj >> 2] = $_01_lcssa;
    var $_lcssa_idx_val = HEAP32[$_lcssa + 20 >> 2];
    var $17 = __ZNK8JSObject9getParentEv($_lcssa_idx_val);
    __ZN2JS5Value9setObjectER8JSObject($vp, $17);
    HEAP32[$attrsp >> 2] = 6;
    __label__ = 21;
    break;
   case 9:
    var $19 = $cx;
    var $20 = $pobj;
    var $21 = $prop;
    var $22 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($_lcssa, $19, $id, $20, $21);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $25 = HEAPU32[$prop >> 2];
    if (($25 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 11:
    if ($10) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 13;
    break;
   case 13:
    HEAP32[$attrsp >> 2] = 0;
    HEAP32[$pobj >> 2] = $_01_lcssa;
    __label__ = 21;
    break;
   case 14:
    var $31 = HEAPU32[$pobj >> 2];
    var $_idx1 = $31;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $32 = __ZNK8JSObject8isNativeEv($_idx1_val);
    if ($32) {
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    if ($10) {
      __label__ = 21;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN2JS5Value12setUndefinedEv($vp);
    HEAP32[$attrsp >> 2] = 0;
    __label__ = 21;
    break;
   case 17:
    var $_idx7_val = HEAP8[$25 + 28 | 0];
    var $37 = __ZNK2js5Shape10attributesEv($_idx7_val);
    HEAP32[$attrsp >> 2] = $37 & 255;
    if ($10) {
      __label__ = 21;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $42 = HEAPU32[$25 + 24 >> 2];
    var $_idx4_val_idx_val = HEAP32[HEAP32[$_idx1 >> 2] + 4 >> 2];
    var $43 = __ZNK8JSObject12containsSlotEj($_idx4_val_idx_val, $42);
    if ($43) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $45 = $31;
    var $46 = __ZNK8JSObject13nativeGetSlotEj($45, $42);
    var $47 = $46 | 0;
    var $48$0 = HEAP32[$47 >> 2];
    var $48$1 = HEAP32[$47 + 4 >> 2];
    var $49 = $vp | 0;
    HEAP32[$49 >> 2] = $48$0;
    HEAP32[$49 + 4 >> 2] = $48$1;
    __label__ = 21;
    break;
   case 20:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 21;
    break;
   case 21:
    var $52 = HEAP32[$pobj >> 2];
    var $_idx_val = HEAP32[$52 + 4 >> 2];
    var $54 = __ZNK8JSObject8getClassEv($_idx_val);
    var $56 = HEAP32[$54 + 44 >> 2];
    var $57 = $56;
    if (($56 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      var $check_0 = $57;
      __label__ = 24;
      break;
    }
   case 22:
    var $60 = $cx;
    var $61 = _JS_GetSecurityCallbacks($60);
    if (($61 | 0) == 0) {
      var $71 = 1;
      __label__ = 26;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $check_0 = HEAP32[$61 >> 2];
    __label__ = 24;
    break;
   case 24:
    var $check_0;
    if (($check_0 | 0) == 0) {
      var $71 = 1;
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $69 = FUNCTION_TABLE[$check_0]($cx, $52, $id, $mode, $vp);
    var $71 = ($69 | 0) != 0;
    __label__ = 26;
    break;
   case 26:
    var $71;
    var $_0 = $71 & 1;
    __label__ = 27;
    break;
   case 27:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj["X"] = 1;

function __ZN2jsL22CastAsStrictPropertyOpEP8JSObject2289($object) {
  return $object;
}

function __Z19js_obj_defineSetterP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $id = __stackBase__ + 8;
    var $junk = __stackBase__ + 12;
    var $attrs = __stackBase__ + 20;
    var $1 = __stackBase__ + 24;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($call, $argc, $vp);
    var $2 = $call | 0;
    var $3 = $cx;
    var $4 = __ZN2js16BoxNonStrictThisEP9JSContextRKNS_12CallReceiverE($3, $2);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    var $_idx2_val = HEAPU32[$call >> 2];
    var $6 = __ZNK2js12CallReceiver5thisvEv($_idx2_val);
    var $_idx1 = $6 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $7 = __ZNK2JS5Value8toObjectEv($_idx1_val$0, $_idx1_val$1);
    var $8 = $7;
    if ($argc >>> 0 < 2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2js8CallArgsixEj($_idx2_val, 1);
    var $_idx5 = $11 | 0;
    var $_idx5_val$0 = HEAPU32[$_idx5 >> 2];
    var $_idx5_val$1 = HEAP32[$_idx5 + 4 >> 2];
    var $12 = __ZL13js_IsCallableRKN2JS5ValueE2285($_idx5_val$0, $_idx5_val$1);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _JS_ReportErrorNumber($3, 4, 151, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str42885 | 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 5:
    var $15 = __ZNK2JS5Value8toObjectEv($_idx5_val$0, $_idx5_val$1);
    var $16 = $15;
    var $17 = __ZN2jsL22CastAsStrictPropertyOpEP8JSObject2289($16);
    var $18 = __ZNK2js8CallArgsixEj($_idx2_val, 0);
    var $19 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($3, $18, $id);
    if ($19) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $21 = HEAP32[$id >> 2];
    var $22 = __ZN2js18CheckRedeclarationEP9JSContextP8JSObjectij($3, $7, $21, 32);
    if ($22) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $24 = __ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj($cx, $8, $21, 3, $junk, $attrs);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = __ZNK2js12CallReceiver4rvalEv($_idx2_val);
    __ZN2JS5Value12setUndefinedEv($27);
    __ZN2JSL14UndefinedValueEv2280($1);
    var $28 = $17;
    var $29 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($7, $3, $21, $1, 10, $28, 97);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z19js_obj_defineSetterP9JSContextjPN2JS5ValueE["X"] = 1;

function __Z18obj_getPrototypeOfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $attrs = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $cx;
    __Z19js_ReportMissingArgP9JSContextRKN2JS5ValueEj($3, $vp, 0);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $_idx1 = $vp + 16 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $5 = __ZNK2JS5Value11isPrimitiveEv($_idx1_val$0, $_idx1_val$1);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $7 = __ZN2jsL23DecompileValueGeneratorEP9JSContextiRKN2JS5ValueEP8JSString2290($cx, $_idx1_val$0, $_idx1_val$1);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = $cx;
    _JS_ReportErrorNumber($10, 4, 222, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $7, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str2433396 | 0, tempInt));
    _JS_free($7);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $12 = __ZNK2JS5Value8toObjectEv($_idx1_val$0, $_idx1_val$1);
    var $13 = $12;
    var $18 = HEAP32[HEAP32[$cx + 52 >> 2] + 210292 >> 2] | 0;
    var $19 = __ZL12ATOM_TO_JSIDP6JSAtom2291($18);
    var $20 = __ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj($cx, $13, $19, 0, $vp, $attrs);
    var $_0 = $20;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23DecompileValueGeneratorEP9JSContextiRKN2JS5ValueEP8JSString2290($cx, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  var $1 = $cx;
  var $2 = _js_DecompileValueGenerator($1, 1, $v_0_0_0_val$0, $v_0_0_0_val$1, 0);
  return $2;
}

function __ZL12ATOM_TO_JSIDP6JSAtom2291($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj2517($1);
  return $2;
}

function __ZN2js27NewPropertyDescriptorObjectEP9JSContextPK20JSPropertyDescriptorPN2JS5ValueE($cx, $desc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    if ((HEAP32[$desc >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    __ZN2js8PropDescC2Ev($d);
    __ZN2js8PropDesc26initFromPropertyDescriptorERK20JSPropertyDescriptor($d, $desc);
    var $6 = __ZN2js8PropDesc10makeObjectEP9JSContext($d, $cx);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = $d | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $vp | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8PropDesc26initFromPropertyDescriptorERK20JSPropertyDescriptor($this, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $this | 0;
    __ZN2JS5Value12setUndefinedEv($3);
    var $4 = $desc + 4 | 0;
    HEAP8[$this + 32 | 0] = HEAP32[$4 >> 2] & 255;
    var $11 = $this + 33 | 0;
    var $12 = HEAP8[$11];
    if ((HEAP32[$4 >> 2] & 48 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = $12 | 1;
    HEAP8[$11] = $14;
    if ((HEAP32[$4 >> 2] & 16 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $20 = HEAP32[$desc + 8 >> 2];
    if (($20 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $23 = $20;
    __ZN2js17CastAsObjectJsvalEPFiP9JSContextP8JSObjectiPN2JS5ValueEE($1, $23);
    __label__ = 6;
    break;
   case 5:
    __ZN2JSL14UndefinedValueEv2280($1);
    __label__ = 6;
    break;
   case 6:
    var $26 = $1 | 0;
    var $st$1$0 = $26 | 0;
    var $27$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $26 + 4 | 0;
    var $27$1 = HEAP32[$st$1$1 >> 2];
    var $28 = $this + 16 | 0;
    var $st$6$0 = $28 | 0;
    HEAP32[$st$6$0 >> 2] = $27$0;
    var $st$6$1 = $28 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $27$1;
    var $30 = HEAP8[$11] | 2;
    HEAP8[$11] = $30;
    if ((HEAP32[$4 >> 2] & 32 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $36 = HEAP32[$desc + 12 >> 2];
    if (($36 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $39 = $36;
    __ZN2js17CastAsObjectJsvalEPFiP9JSContextP8JSObjectiiPN2JS5ValueEE($2, $39);
    __label__ = 10;
    break;
   case 9:
    __ZN2JSL14UndefinedValueEv2280($2);
    __label__ = 10;
    break;
   case 10:
    var $42 = $2 | 0;
    var $st$1$0 = $42 | 0;
    var $43$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $42 + 4 | 0;
    var $43$1 = HEAP32[$st$1$1 >> 2];
    var $44 = $this + 24 | 0;
    var $st$6$0 = $44 | 0;
    HEAP32[$st$6$0 >> 2] = $43$0;
    var $st$6$1 = $44 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $43$1;
    var $46 = HEAP8[$11] & -5;
    HEAP8[$11] = $46;
    var $47 = $this + 8 | 0;
    __ZN2JS5Value12setUndefinedEv($47);
    var $storemerge = HEAP8[$11] & -9;
    __label__ = 12;
    break;
   case 11:
    var $51 = $12 & -2;
    HEAP8[$11] = $51;
    var $52 = $this + 16 | 0;
    __ZN2JS5Value12setUndefinedEv($52);
    var $54 = HEAP8[$11] & -3;
    HEAP8[$11] = $54;
    var $55 = $this + 24 | 0;
    __ZN2JS5Value12setUndefinedEv($55);
    var $56 = HEAP8[$11];
    var $57 = $56 | 4;
    HEAP8[$11] = $57;
    var $58 = $desc + 16 | 0;
    var $59$0 = HEAP32[$58 >> 2];
    var $59$1 = HEAP32[$58 + 4 >> 2];
    var $60 = $this + 8 | 0;
    HEAP32[$60 >> 2] = $59$0;
    HEAP32[$60 + 4 >> 2] = $59$1;
    var $storemerge = $56 | 12;
    __label__ = 12;
    break;
   case 12:
    var $storemerge;
    HEAP8[$11] = $storemerge | 48;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8PropDesc26initFromPropertyDescriptorERK20JSPropertyDescriptor["X"] = 1;

function __ZN2js8PropDesc10makeObjectEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2296($cx, __ZN2js11ObjectClassE);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$cx + 52 >> 2];
    var $9 = $this + 33 | 0;
    var $10 = HEAP8[$9];
    if (($10 & 32) << 24 >> 24 == 0) {
      var $27 = $10;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = HEAP32[$8 + 210348 >> 2] | 0;
    var $17 = __ZL12ATOM_TO_JSIDP6JSAtom2291($16);
    var $21 = (HEAP8[$this + 32 | 0] & 4) << 24 >> 24 == 0;
    __ZN2JSL12BooleanValueEb2297($1, $21);
    var $22 = $4;
    var $23 = $cx;
    var $24 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($22, $23, $17, $1, 10, 12, 1);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $27 = HEAP8[$9];
    __label__ = 5;
    break;
   case 5:
    var $27;
    if (($27 & 16) << 24 >> 24 == 0) {
      var $44 = $27;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $33 = HEAP32[$8 + 210344 >> 2] | 0;
    var $34 = __ZL12ATOM_TO_JSIDP6JSAtom2291($33);
    var $38 = (HEAP8[$this + 32 | 0] & 1) << 24 >> 24 != 0;
    __ZN2JSL12BooleanValueEb2297($2, $38);
    var $39 = $4;
    var $40 = $cx;
    var $41 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($39, $40, $34, $2, 10, 12, 1);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $44 = HEAP8[$9];
    __label__ = 8;
    break;
   case 8:
    var $44;
    if (($44 & 1) << 24 >> 24 == 0) {
      var $58 = $44;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $50 = HEAP32[$8 + 210220 >> 2] | 0;
    var $51 = __ZL12ATOM_TO_JSIDP6JSAtom2291($50);
    var $52 = $this + 16 | 0;
    var $53 = $4;
    var $54 = $cx;
    var $55 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($53, $54, $51, $52, 10, 12, 1);
    if (($55 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $58 = HEAP8[$9];
    __label__ = 11;
    break;
   case 11:
    var $58;
    if (($58 & 2) << 24 >> 24 == 0) {
      var $72 = $58;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $64 = HEAP32[$8 + 210296 >> 2] | 0;
    var $65 = __ZL12ATOM_TO_JSIDP6JSAtom2291($64);
    var $66 = $this + 24 | 0;
    var $67 = $4;
    var $68 = $cx;
    var $69 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($67, $68, $65, $66, 10, 12, 1);
    if (($69 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $72 = HEAP8[$9];
    __label__ = 14;
    break;
   case 14:
    var $72;
    if (($72 & 4) << 24 >> 24 == 0) {
      var $86 = $72;
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $78 = HEAP32[$8 + 210356 >> 2] | 0;
    var $79 = __ZL12ATOM_TO_JSIDP6JSAtom2291($78);
    var $80 = $this + 8 | 0;
    var $81 = $4;
    var $82 = $cx;
    var $83 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($81, $82, $79, $80, 10, 12, 1);
    if (($83 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $86 = HEAP8[$9];
    __label__ = 17;
    break;
   case 17:
    var $86;
    if (($86 & 8) << 24 >> 24 == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $_pre_phi = $4;
    __label__ = 20;
    break;
   case 19:
    var $92 = HEAP32[$8 + 210352 >> 2] | 0;
    var $93 = __ZL12ATOM_TO_JSIDP6JSAtom2291($92);
    var $97 = (HEAP8[$this + 32 | 0] & 2) << 24 >> 24 == 0;
    __ZN2JSL12BooleanValueEb2297($3, $97);
    var $98 = $4;
    var $99 = $cx;
    var $100 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($98, $99, $93, $3, 10, 12, 1);
    if (($100 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      var $_pre_phi = $98;
      __label__ = 20;
      break;
    }
   case 20:
    var $_pre_phi;
    var $103 = $this | 0;
    __ZN2JS5Value9setObjectER8JSObject($103, $_pre_phi);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8PropDesc10makeObjectEP9JSContext["X"] = 1;

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2296($cx, $clasp) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb2335($4);
  var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2318($cx, $clasp, $5);
  return $6;
}

function __ZN2JSL12BooleanValueEb2297($agg_result, $boo) {
  __ZN2JS5Value10setBooleanEb($agg_result, $boo);
  return;
}

function __ZN2js24GetOwnPropertyDescriptorEP9JSContextP8JSObjectiP20JSPropertyDescriptor($cx, $obj, $id, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $1 = $obj;
    var $_idx2_val = HEAP32[$obj + 4 >> 2];
    var $3 = __ZNK8JSObject7isProxyEv($_idx2_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $cx;
    var $6 = $desc;
    var $7 = __ZN2js7JSProxy24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($5, $1, $id, 0, $6);
    var $_0 = $7;
    __label__ = 16;
    break;
   case 3:
    var $9 = __ZNK8JSObject6getOpsEv($_idx2_val);
    var $12 = HEAP32[$9 + 4 >> 2];
    var $13 = __Z17js_HasOwnPropertyP9JSContextPFiS0_P8JSObjectiPS2_PP10JSPropertyES2_iS3_S6_($cx, $12, $obj, $id, $pobj, $prop);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = HEAP32[$prop >> 2];
    if (($16 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    HEAP32[$desc >> 2] = 0;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 6:
    var $21 = HEAPU32[$pobj >> 2];
    var $_idx_val = HEAP32[$21 >> 2];
    var $22 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($22) {
      __label__ = 7;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 7:
    var $24 = $16;
    var $_idx3_val = HEAP8[$24 + 28 | 0];
    var $25 = __ZNK2js5Shape10attributesEv($_idx3_val);
    var $26 = $25 & 255;
    HEAP32[$desc + 4 >> 2] = $26;
    if (($26 & 48 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $_pre_phi = $cx;
    __label__ = 14;
    break;
   case 9:
    if (($26 & 16 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $34 = __ZNK2js5Shape12getterObjectEv($24);
    var $35 = $34;
    var $36 = __ZN2jsL16CastAsPropertyOpEP8JSObject2286($35);
    HEAP32[$desc + 8 >> 2] = $36;
    __label__ = 11;
    break;
   case 11:
    if (($26 & 32 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $41 = __ZNK2js5Shape12setterObjectEv($24);
    var $42 = $41;
    var $43 = __ZN2jsL22CastAsStrictPropertyOpEP8JSObject2289($42);
    HEAP32[$desc + 12 >> 2] = $43;
    __label__ = 15;
    break;
   case 13:
    var $46 = $21;
    var $47 = $desc + 4 | 0;
    var $48 = $cx;
    var $49 = __ZN8JSObject13getAttributesEP9JSContextiPj($46, $48, $id, $47);
    if (($49 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      var $_pre_phi = $48;
      __label__ = 14;
      break;
    }
   case 14:
    var $_pre_phi;
    var $52 = $desc + 16 | 0;
    var $53 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($1, $_pre_phi, $id, $52);
    if (($53 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    HEAP32[$desc >> 2] = $obj;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js24GetOwnPropertyDescriptorEP9JSContextP8JSObjectiP20JSPropertyDescriptor["X"] = 1;

function __ZN2js24GetOwnPropertyDescriptorEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $desc = __stackBase__;
    var $1 = $desc;
    var $2 = $cx;
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($1, $2);
    var $3 = $desc + 16 | 0;
    var $4 = __ZN2js24GetOwnPropertyDescriptorEP9JSContextP8JSObjectiP20JSPropertyDescriptor($cx, $obj, $id, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZN2js27NewPropertyDescriptorObjectEP9JSContextPK20JSPropertyDescriptorPN2JS5ValueE($cx, $3, $vp);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($1);
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8PropDescC2Ev($this) {
  var $1 = $this | 0;
  __ZN2JSL14UndefinedValueEv2280($1);
  var $2 = $this + 8 | 0;
  __ZN2JSL14UndefinedValueEv2280($2);
  var $3 = $this + 16 | 0;
  __ZN2JSL14UndefinedValueEv2280($3);
  var $4 = $this + 24 | 0;
  __ZN2JSL14UndefinedValueEv2280($4);
  HEAP8[$this + 32 | 0] = 0;
  var $6 = $this + 33 | 0;
  var $8 = HEAP8[$6] & -64;
  HEAP8[$6] = $8;
  return;
}

function __ZN2js8PropDesc10initializeEP9JSContextRKN2JS5ValueEb($this, $cx, $origval_0_0_0_val$0, $origval_0_0_0_val$1, $checkAccessors) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $found = __stackBase__ + 8;
    var $1 = $v | 0;
    var $st$3$0 = $1 | 0;
    HEAP32[$st$3$0 >> 2] = $origval_0_0_0_val$0;
    var $st$3$1 = $1 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $origval_0_0_0_val$1;
    var $2 = __ZNK2JS5Value11isPrimitiveEv($origval_0_0_0_val$0, $origval_0_0_0_val$1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $cx;
    _JS_ReportErrorNumber($4, 4, 231, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 28;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8toObjectEv($origval_0_0_0_val$0, $origval_0_0_0_val$1);
    var $7 = $6;
    var $8 = $this | 0;
    var $st$3$0 = $8 | 0;
    HEAP32[$st$3$0 >> 2] = $origval_0_0_0_val$0;
    var $st$3$1 = $8 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $origval_0_0_0_val$1;
    var $9 = $this + 32 | 0;
    HEAP8[$9] = 6;
    HEAP8[$found] = 0;
    var $10 = $cx + 52 | 0;
    var $14 = HEAP32[HEAP32[$10 >> 2] + 210344 >> 2] | 0;
    var $15 = __ZL12ATOM_TO_JSIDP6JSAtom2291($14);
    var $16 = __ZL11HasPropertyP9JSContextP8JSObjectiPN2JS5ValueEPb($cx, $7, $15, $v, $found);
    if ($16) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 4:
    if ((HEAP8[$found] & 1) << 24 >> 24 == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $22 = $this + 33 | 0;
    var $24 = HEAP8[$22] | 16;
    HEAP8[$22] = $24;
    var $25 = __Z17js_ValueToBooleanRKN2JS5ValueE($v);
    if (($25 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $29 = HEAP8[$9] | 1;
    HEAP8[$9] = $29;
    __label__ = 7;
    break;
   case 7:
    var $34 = HEAP32[HEAP32[$10 >> 2] + 210348 >> 2] | 0;
    var $35 = __ZL12ATOM_TO_JSIDP6JSAtom2291($34);
    var $36 = __ZL11HasPropertyP9JSContextP8JSObjectiPN2JS5ValueEPb($cx, $7, $35, $v, $found);
    if ($36) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 8:
    if ((HEAP8[$found] & 1) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $42 = $this + 33 | 0;
    var $44 = HEAP8[$42] | 32;
    HEAP8[$42] = $44;
    var $45 = __Z17js_ValueToBooleanRKN2JS5ValueE($v);
    if (($45 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $49 = HEAP8[$9] & -5;
    HEAP8[$9] = $49;
    __label__ = 11;
    break;
   case 11:
    var $54 = HEAP32[HEAP32[$10 >> 2] + 210356 >> 2] | 0;
    var $55 = __ZL12ATOM_TO_JSIDP6JSAtom2291($54);
    var $56 = __ZL11HasPropertyP9JSContextP8JSObjectiPN2JS5ValueEPb($cx, $7, $55, $v, $found);
    if ($56) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 12:
    if ((HEAP8[$found] & 1) << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $62 = $this + 33 | 0;
    var $64 = HEAP8[$62] | 4;
    HEAP8[$62] = $64;
    var $st$4$0 = $1 | 0;
    var $65$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $1 + 4 | 0;
    var $65$1 = HEAP32[$st$4$1 >> 2];
    var $66 = $this + 8 | 0;
    var $st$9$0 = $66 | 0;
    HEAP32[$st$9$0 >> 2] = $65$0;
    var $st$9$1 = $66 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $65$1;
    __label__ = 14;
    break;
   case 14:
    var $71 = HEAP32[HEAP32[$10 >> 2] + 210352 >> 2] | 0;
    var $72 = __ZL12ATOM_TO_JSIDP6JSAtom2291($71);
    var $73 = __ZL11HasPropertyP9JSContextP8JSObjectiPN2JS5ValueEPb($cx, $7, $72, $v, $found);
    if ($73) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 15:
    if ((HEAP8[$found] & 1) << 24 >> 24 == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $79 = $this + 33 | 0;
    var $81 = HEAP8[$79] | 8;
    HEAP8[$79] = $81;
    var $82 = __Z17js_ValueToBooleanRKN2JS5ValueE($v);
    if (($82 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $86 = HEAP8[$9] & -3;
    HEAP8[$9] = $86;
    __label__ = 18;
    break;
   case 18:
    var $91 = HEAP32[HEAP32[$10 >> 2] + 210220 >> 2] | 0;
    var $92 = __ZL12ATOM_TO_JSIDP6JSAtom2291($91);
    var $93 = __ZL11HasPropertyP9JSContextP8JSObjectiPN2JS5ValueEPb($cx, $7, $92, $v, $found);
    if ($93) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 19:
    if ((HEAP8[$found] & 1) << 24 >> 24 == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $99 = $this + 33 | 0;
    var $101 = HEAP8[$99] | 1;
    HEAP8[$99] = $101;
    var $st$4$0 = $1 | 0;
    var $102$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $1 + 4 | 0;
    var $102$1 = HEAP32[$st$4$1 >> 2];
    var $103 = $this + 16 | 0;
    var $st$9$0 = $103 | 0;
    HEAP32[$st$9$0 >> 2] = $102$0;
    var $st$9$1 = $103 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $102$1;
    var $105 = HEAP8[$9] | 80;
    HEAP8[$9] = $105;
    if ($checkAccessors) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    var $107 = $cx;
    var $108 = __ZN2js8PropDesc11checkGetterEP9JSContext($this, $107);
    if ($108) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 22:
    var $113 = HEAP32[HEAP32[$10 >> 2] + 210296 >> 2] | 0;
    var $114 = __ZL12ATOM_TO_JSIDP6JSAtom2291($113);
    var $115 = __ZL11HasPropertyP9JSContextP8JSObjectiPN2JS5ValueEPb($cx, $7, $114, $v, $found);
    if ($115) {
      __label__ = 23;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 23:
    var $_pre = $this + 33 | 0;
    if ((HEAP8[$found] & 1) << 24 >> 24 == 0) {
      var $_pre_phi = $_pre;
      __label__ = 26;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $122 = HEAP8[$_pre] | 2;
    HEAP8[$_pre] = $122;
    var $st$3$0 = $1 | 0;
    var $123$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $1 + 4 | 0;
    var $123$1 = HEAP32[$st$3$1 >> 2];
    var $124 = $this + 24 | 0;
    HEAP32[$124 >> 2] = $123$0;
    HEAP32[$124 + 4 >> 2] = $123$1;
    var $126 = HEAP8[$9] | 96;
    HEAP8[$9] = $126;
    if ($checkAccessors) {
      __label__ = 25;
      break;
    } else {
      var $_pre_phi = $_pre;
      __label__ = 26;
      break;
    }
   case 25:
    var $128 = $cx;
    var $129 = __ZN2js8PropDesc11checkSetterEP9JSContext($this, $128);
    if ($129) {
      var $_pre_phi = $_pre;
      __label__ = 26;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 26:
    var $_pre_phi;
    var $130 = HEAP8[$_pre_phi];
    if (($130 & 3) << 24 >> 24 == 0 | ($130 & 12) << 24 >> 24 == 0) {
      var $_0 = 1;
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $136 = $cx;
    _JS_ReportErrorNumber($136, 4, 238, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8PropDesc10initializeEP9JSContextRKN2JS5ValueEb["X"] = 1;

function __ZL11HasPropertyP9JSContextP8JSObjectiPN2JS5ValueEPb($cx, $obj, $id, $vp, $foundp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = $cx;
    var $3 = __ZN8JSObject11hasPropertyEP9JSContextiPbj($1, $2, $id, $foundp, 5);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    if ((HEAP8[$foundp] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 4:
    var $10 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($1, $2, $id, $vp);
    var $_0 = ($10 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14DefinePropertyEP9JSContextP8JSObjectRKiRKNS_8PropDescEbPb($cx, $obj, $id, $desc, $rval) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $_idx2_val = HEAP32[$obj + 4 >> 2];
    var $3 = __ZNK8JSObject7isArrayEv($_idx2_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZL21DefinePropertyOnArrayP9JSContextP8JSObjectRKiRKN2js8PropDescEbPb($cx, $obj, $id, $desc, $rval);
    var $_0 = ($5 | 0) != 0;
    __label__ = 8;
    break;
   case 3:
    var $8 = __ZNK8JSObject6getOpsEv($_idx2_val);
    if ((HEAP32[$8 + 4 >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = __ZNK8JSObject7isProxyEv($_idx2_val);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $15 = HEAP32[$id >> 2];
    var $16 = $desc | 0;
    var $17 = $cx;
    var $18 = __ZN2js7JSProxy14definePropertyEP9JSContextP8JSObjectiRKN2JS5ValueE($17, $1, $15, $16);
    var $_0 = $18;
    __label__ = 8;
    break;
   case 6:
    var $20 = __ZL6RejectP9JSContextP8JSObjectjbPb($cx, $obj, 239, 1, $rval);
    var $_0 = ($20 | 0) != 0;
    __label__ = 8;
    break;
   case 7:
    var $23 = __ZL22DefinePropertyOnObjectP9JSContextP8JSObjectRKiRKN2js8PropDescEbPb($cx, $obj, $id, $desc, 1, $rval);
    var $_0 = ($23 | 0) != 0;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21DefinePropertyOnArrayP9JSContextP8JSObjectRKiRKN2js8PropDescEbPb($cx, $obj, $id, $desc, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = $obj;
    var $_idx_val = HEAP32[$obj + 4 >> 2];
    var $3 = __ZNK8JSObject12isDenseArrayEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $cx;
    var $6 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($1, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx1_val = HEAP32[$obj + 24 >> 2];
    var $10 = __ZNK8JSObject14getArrayLengthEv($_idx1_val);
    var $11 = HEAP32[$id >> 2];
    var $16 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $17 = __ZL12JSID_IS_ATOMiP6JSAtom2491($11, $16);
    if (($17 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $20 = $cx;
    _JS_ReportErrorNumber($20, 4, 242, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 13;
    break;
   case 5:
    var $22 = __Z12js_IdIsIndexiPj($11, $index);
    if (($22 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $25 = __ZL22DefinePropertyOnObjectP9JSContextP8JSObjectRKiRKN2js8PropDescEbPb($cx, $obj, $id, $desc, 0, $rval);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ((HEAP8[$rval] & 1) << 24 >> 24 == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $32 = __ZL6RejectP9JSContextP8JSObjectjbPb($cx, $obj, 243, 1, $rval);
    var $_0 = $32;
    __label__ = 13;
    break;
   case 9:
    var $34 = HEAPU32[$index >> 2];
    if ($34 >>> 0 < $10 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $37 = $34 + 1 | 0;
    var $38 = $cx;
    __ZN8JSObject14setArrayLengthEP9JSContextj($1, $38, $37);
    __label__ = 11;
    break;
   case 11:
    HEAP8[$rval] = 1;
    var $_0 = 1;
    __label__ = 13;
    break;
   case 12:
    var $41 = __ZL22DefinePropertyOnObjectP9JSContextP8JSObjectRKiRKN2js8PropDescEbPb($cx, $obj, $id, $desc, 1, $rval);
    var $_0 = $41;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL21DefinePropertyOnArrayP9JSContextP8JSObjectRKiRKN2js8PropDescEbPb["X"] = 1;

function __ZL6RejectP9JSContextP8JSObjectjbPb($cx, $obj, $errorNumber, $throwError, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if ($throwError) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    if (HEAP16[_js_ErrorFormatString + ($errorNumber << 3) + 4 >> 1] << 16 >> 16 == 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2JSL11ObjectValueER8JSObject2354($1, $obj);
    var $7 = $cx;
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $8 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($7, 0, $errorNumber, 0, $_idx_val$0, $_idx_val$1, 0, 0);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    var $10 = $cx;
    _JS_ReportErrorNumber($10, 4, $errorNumber, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 5:
    HEAP8[$rval] = 0;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL22DefinePropertyOnObjectP9JSContextP8JSObjectRKiRKN2js8PropDescEbPb($cx, $obj, $id, $desc, $throwError, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 112;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $current = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $dummy = __stackBase__ + 8;
    var $dummyAttrs = __stackBase__ + 16;
    var $tmp = __stackBase__ + 20;
    var $v = __stackBase__ + 28;
    var $same = __stackBase__ + 36;
    var $1 = __stackBase__ + 40;
    var $same1 = __stackBase__ + 48;
    var $2 = __stackBase__ + 52;
    var $same2 = __stackBase__ + 60;
    var $same3 = __stackBase__ + 64;
    var $same4 = __stackBase__ + 68;
    var $3 = __stackBase__ + 72;
    var $same5 = __stackBase__ + 80;
    var $4 = __stackBase__ + 84;
    var $attrs = __stackBase__ + 92;
    var $dummy6 = __stackBase__ + 96;
    var $dummy8 = __stackBase__ + 104;
    var $5 = HEAP32[$id >> 2];
    var $6 = __Z17js_HasOwnPropertyP9JSContextPFiS0_P8JSObjectiPS2_PP10JSPropertyES2_iS3_S6_($cx, 0, $obj, $5, $obj2, $current);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 102;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$current >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 3:
    var $_idx22_val = HEAP32[$obj + 8 >> 2];
    var $13 = __ZNK8JSObject12isExtensibleEv($_idx22_val);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = __ZL6RejectP9JSContextP8JSObjectjbPb($cx, $obj, 239, $throwError, $rval);
    var $_0 = $15;
    __label__ = 102;
    break;
   case 5:
    HEAP8[$rval] = 1;
    var $desc_idx42_val = HEAP8[$desc + 33 | 0];
    var $17 = __ZNK2js8PropDesc19isGenericDescriptorEv($desc_idx42_val);
    if ($17) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = __ZNK2js8PropDesc16isDataDescriptorEv($desc_idx42_val);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $21 = HEAP32[$id >> 2];
    var $22 = $desc + 8 | 0;
    var $25 = HEAPU8[$desc + 32 | 0] & 255;
    var $26 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $21, $22, 10, 12, $25);
    var $_0 = $26;
    __label__ = 102;
    break;
   case 8:
    var $28 = HEAP32[$id >> 2];
    var $29 = __ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj($cx, $obj, $28, 3, $dummy, $dummyAttrs);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 102;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2JSL14UndefinedValueEv2280($tmp);
    var $32 = HEAP32[$id >> 2];
    var $33 = __ZNK2js8PropDesc6getterEv($desc);
    var $34 = __ZNK2js8PropDesc6setterEv($desc);
    var $37 = HEAPU8[$desc + 32 | 0] & 255;
    var $38 = $33;
    var $39 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $32, $tmp, $38, $34, $37);
    var $_0 = $39;
    __label__ = 102;
    break;
   case 10:
    __ZN2JSL14UndefinedValueEv2280($v);
    var $41 = HEAPU32[$current >> 2];
    var $42 = $41;
    var $desc_idx = $desc + 33 | 0;
    var $desc_idx_val = HEAPU8[$desc_idx];
    var $43 = __ZNK2js8PropDesc20isAccessorDescriptorEv($desc_idx_val);
    var $44 = $41;
    var $_idx13 = $44 + 28 | 0;
    var $_idx13_val = HEAPU8[$_idx13];
    if ($43) {
      __label__ = 11;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 11:
    var $46 = __ZNK2js5Shape20isAccessorDescriptorEv($_idx13_val);
    if ($46) {
      __label__ = 12;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 12:
    if (($desc_idx_val & 1) << 24 >> 24 == 0) {
      var $58 = $desc_idx_val;
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $51 = __ZNK2js8PropDesc11getterValueEv($desc);
    __ZNK2js5Shape17getterOrUndefinedEv($1, $42);
    var $52 = $cx;
    var $53 = __ZN2js9SameValueEP9JSContextRKN2JS5ValueES5_Pi($52, $51, $1, $same);
    if ($53) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 102;
      break;
    }
   case 14:
    if ((HEAP32[$same >> 2] | 0) == 0) {
      __label__ = 48;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $58 = HEAP8[$desc_idx];
    __label__ = 16;
    break;
   case 16:
    var $58;
    if (($58 & 2) << 24 >> 24 == 0) {
      var $126 = $58;
      __label__ = 43;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $62 = __ZNK2js8PropDesc11setterValueEv($desc);
    __ZNK2js5Shape17setterOrUndefinedEv($2, $42);
    var $63 = $cx;
    var $64 = __ZN2js9SameValueEP9JSContextRKN2JS5ValueES5_Pi($63, $62, $2, $same1);
    if ($64) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 102;
      break;
    }
   case 18:
    if ((HEAP32[$same1 >> 2] | 0) == 0) {
      __label__ = 48;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $126 = HEAP8[$desc_idx];
    __label__ = 43;
    break;
   case 20:
    var $69 = __ZNK2js5Shape16isDataDescriptorEv($_idx13_val);
    if ($69) {
      __label__ = 21;
      break;
    } else {
      var $desc_idx37_val = $desc_idx_val;
      __label__ = 31;
      break;
    }
   case 21:
    var $71 = __ZNK2js5Shape12configurableEv($_idx13_val);
    if ($71) {
      __label__ = 29;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $_idx12_val = HEAP32[$44 + 16 >> 2];
    var $73 = __ZNK2js5Shape16hasDefaultGetterEv($_idx12_val);
    if ($73) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $_idx26_val = HEAP32[$44 + 20 >> 2];
    var $75 = __ZNK2js5Shape16hasDefaultSetterEv($_idx26_val);
    if ($75) {
      __label__ = 29;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $77 = __ZNK2js8PropDesc16isDataDescriptorEv($desc_idx_val);
    if ($77) {
      __label__ = 25;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 25:
    if (($desc_idx_val & 8) << 24 >> 24 == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $desc_idx45_val = HEAP8[$desc + 32 | 0];
    var $82 = __ZNK2js8PropDesc8writableEv($desc_idx45_val);
    if ($82) {
      __label__ = 28;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 27:
    var $84 = __ZNK2js5Shape8writableEv($_idx13_val);
    if ($84) {
      __label__ = 28;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 28:
    var $86 = HEAP32[$id >> 2];
    var $87 = __ZL6RejectP9JSContextjbiPb($cx, $throwError, $86, $rval);
    var $_0 = $87;
    __label__ = 102;
    break;
   case 29:
    var $89 = HEAP32[$obj2 >> 2];
    var $90 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($cx, $obj, $89, $42, 2, $v);
    if (($90 | 0) == 0) {
      var $_0 = 0;
      __label__ = 102;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $desc_idx37_val = HEAP8[$desc_idx];
    __label__ = 31;
    break;
   case 31:
    var $desc_idx37_val;
    var $93 = __ZNK2js8PropDesc16isDataDescriptorEv($desc_idx37_val);
    if ($93) {
      __label__ = 32;
      break;
    } else {
      var $126 = $desc_idx37_val;
      __label__ = 43;
      break;
    }
   case 32:
    var $_idx20_val = HEAP8[$_idx13];
    var $95 = __ZNK2js5Shape16isDataDescriptorEv($_idx20_val);
    if ($95) {
      __label__ = 33;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 33:
    if (($desc_idx37_val & 4) << 24 >> 24 == 0) {
      var $117 = $desc_idx37_val;
      __label__ = 41;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $100 = $desc + 8 | 0;
    var $101 = $cx;
    var $102 = __ZN2js9SameValueEP9JSContextRKN2JS5ValueES5_Pi($101, $100, $v, $same2);
    if ($102) {
      __label__ = 35;
      break;
    } else {
      var $_0 = 0;
      __label__ = 102;
      break;
    }
   case 35:
    if ((HEAP32[$same2 >> 2] | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $117 = HEAP8[$desc_idx];
    __label__ = 41;
    break;
   case 37:
    var $_idx17_val = HEAP8[$41 + 28 | 0];
    var $108 = __ZNK2js5Shape12configurableEv($_idx17_val);
    if ($108) {
      __label__ = 48;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $_idx11_val = HEAP32[$44 + 16 >> 2];
    var $110 = __ZNK2js5Shape16hasDefaultGetterEv($_idx11_val);
    if ($110) {
      __label__ = 39;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 39:
    var $_idx25_val = HEAP32[$44 + 20 >> 2];
    var $112 = __ZNK2js5Shape16hasDefaultSetterEv($_idx25_val);
    if ($112) {
      __label__ = 48;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $114 = HEAP32[$id >> 2];
    var $115 = __ZL6RejectP9JSContextjbiPb($cx, $throwError, $114, $rval);
    var $_0 = $115;
    __label__ = 102;
    break;
   case 41:
    var $117;
    if (($117 & 8) << 24 >> 24 == 0) {
      var $126 = $117;
      __label__ = 43;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $desc_idx44_val = HEAP8[$desc + 32 | 0];
    var $121 = __ZNK2js8PropDesc8writableEv($desc_idx44_val);
    var $_idx28_val = HEAP8[$41 + 28 | 0];
    var $123 = __ZNK2js5Shape8writableEv($_idx28_val);
    if ($121 ^ $123) {
      __label__ = 48;
      break;
    } else {
      var $126 = $117;
      __label__ = 43;
      break;
    }
   case 43:
    var $126;
    if (($126 & 32) << 24 >> 24 == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $desc_idx47_val = HEAP8[$desc + 32 | 0];
    var $130 = __ZNK2js8PropDesc12configurableEv($desc_idx47_val);
    var $_idx16_val = HEAP8[$41 + 28 | 0];
    var $132 = __ZNK2js5Shape12configurableEv($_idx16_val);
    if ($130 ^ $132) {
      __label__ = 48;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    if (($126 & 16) << 24 >> 24 == 0) {
      __label__ = 47;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $desc_idx49_val = HEAP8[$desc + 32 | 0];
    var $138 = __ZNK2js8PropDesc10enumerableEv($desc_idx49_val);
    var $_idx31_val = HEAP8[$44 + 28 | 0];
    var $139 = __ZNK2js5Shape10enumerableEv($_idx31_val);
    if ($138 ^ $139) {
      __label__ = 48;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    HEAP8[$rval] = 1;
    var $_0 = 1;
    __label__ = 102;
    break;
   case 48:
    var $_idx15_val = HEAP8[$41 + 28 | 0];
    var $143 = __ZNK2js5Shape12configurableEv($_idx15_val);
    if ($143) {
      __label__ = 49;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 49:
    var $desc_idx41_val = HEAP8[$desc_idx];
    __label__ = 54;
    break;
   case 50:
    var $desc_idx46_val = HEAP8[$desc + 32 | 0];
    var $145 = __ZNK2js8PropDesc12configurableEv($desc_idx46_val);
    if ($145) {
      __label__ = 53;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $147 = HEAP8[$desc_idx];
    if (($147 & 16) << 24 >> 24 == 0) {
      var $desc_idx41_val = $147;
      __label__ = 54;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 52:
    var $151 = __ZNK2js8PropDesc10enumerableEv($desc_idx46_val);
    var $152 = __ZNK2js5Shape10enumerableEv($_idx15_val);
    if ($151 ^ $152) {
      __label__ = 53;
      break;
    } else {
      var $desc_idx41_val = $147;
      __label__ = 54;
      break;
    }
   case 53:
    var $155 = HEAP32[$id >> 2];
    var $156 = __ZL6RejectP9JSContextjbiPb($cx, $throwError, $155, $rval);
    var $_0 = $156;
    __label__ = 102;
    break;
   case 54:
    var $desc_idx41_val;
    var $158 = __ZNK2js8PropDesc19isGenericDescriptorEv($desc_idx41_val);
    if ($158) {
      var $callDelProperty_0 = 0;
      __label__ = 80;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    var $160 = __ZNK2js8PropDesc16isDataDescriptorEv($desc_idx41_val);
    var $161 = __ZNK2js5Shape16isDataDescriptorEv($_idx15_val);
    if ($160 ^ $161) {
      __label__ = 56;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 56:
    if ($143) {
      var $callDelProperty_0 = 0;
      __label__ = 80;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    var $165 = HEAP32[$id >> 2];
    var $166 = __ZL6RejectP9JSContextjbiPb($cx, $throwError, $165, $rval);
    var $_0 = $166;
    __label__ = 102;
    break;
   case 58:
    if ($160) {
      __label__ = 59;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 59:
    if ($143) {
      __label__ = 68;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 60:
    var $170 = __ZNK2js5Shape8writableEv($_idx15_val);
    if ($170) {
      __label__ = 68;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    if (($desc_idx41_val & 8) << 24 >> 24 == 0) {
      __label__ = 64;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 62:
    var $desc_idx43_val = HEAP8[$desc + 32 | 0];
    var $175 = __ZNK2js8PropDesc8writableEv($desc_idx43_val);
    if ($175) {
      __label__ = 63;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 63:
    var $177 = HEAP32[$id >> 2];
    var $178 = __ZL6RejectP9JSContextjbiPb($cx, $throwError, $177, $rval);
    var $_0 = $178;
    __label__ = 102;
    break;
   case 64:
    if (($desc_idx41_val & 4) << 24 >> 24 == 0) {
      __label__ = 68;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 65:
    var $183 = $desc + 8 | 0;
    var $184 = $cx;
    var $185 = __ZN2js9SameValueEP9JSContextRKN2JS5ValueES5_Pi($184, $183, $v, $same3);
    if ($185) {
      __label__ = 66;
      break;
    } else {
      var $_0 = 0;
      __label__ = 102;
      break;
    }
   case 66:
    if ((HEAP32[$same3 >> 2] | 0) == 0) {
      __label__ = 67;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 67:
    var $190 = HEAP32[$id >> 2];
    var $191 = __ZL6RejectP9JSContextjbiPb($cx, $throwError, $190, $rval);
    var $_0 = $191;
    __label__ = 102;
    break;
   case 68:
    var $_idx10_val = HEAP32[$44 + 16 >> 2];
    var $192 = __ZNK2js5Shape16hasDefaultGetterEv($_idx10_val);
    if ($192) {
      __label__ = 69;
      break;
    } else {
      var $callDelProperty_0 = 1;
      __label__ = 80;
      break;
    }
   case 69:
    var $_idx24_val = HEAP32[$44 + 20 >> 2];
    var $194 = __ZNK2js5Shape16hasDefaultSetterEv($_idx24_val);
    var $callDelProperty_0 = $194 ^ 1;
    __label__ = 80;
    break;
   case 70:
    if ($143) {
      var $callDelProperty_0 = 0;
      __label__ = 80;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 71:
    if (($desc_idx41_val & 2) << 24 >> 24 == 0) {
      var $211 = $desc_idx41_val;
      __label__ = 76;
      break;
    } else {
      __label__ = 72;
      break;
    }
   case 72:
    var $201 = __ZNK2js8PropDesc11setterValueEv($desc);
    __ZNK2js5Shape17setterOrUndefinedEv($3, $42);
    var $202 = $cx;
    var $203 = __ZN2js9SameValueEP9JSContextRKN2JS5ValueES5_Pi($202, $201, $3, $same4);
    if ($203) {
      __label__ = 73;
      break;
    } else {
      var $_0 = 0;
      __label__ = 102;
      break;
    }
   case 73:
    if ((HEAP32[$same4 >> 2] | 0) == 0) {
      __label__ = 75;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 74:
    var $211 = HEAP8[$desc_idx];
    __label__ = 76;
    break;
   case 75:
    var $208 = HEAP32[$id >> 2];
    var $209 = __ZL6RejectP9JSContextjbiPb($cx, $throwError, $208, $rval);
    var $_0 = $209;
    __label__ = 102;
    break;
   case 76:
    var $211;
    if (($211 & 1) << 24 >> 24 == 0) {
      var $callDelProperty_0 = 0;
      __label__ = 80;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 77:
    var $215 = __ZNK2js8PropDesc11getterValueEv($desc);
    __ZNK2js5Shape17getterOrUndefinedEv($4, $42);
    var $216 = $cx;
    var $217 = __ZN2js9SameValueEP9JSContextRKN2JS5ValueES5_Pi($216, $215, $4, $same5);
    if ($217) {
      __label__ = 78;
      break;
    } else {
      var $_0 = 0;
      __label__ = 102;
      break;
    }
   case 78:
    if ((HEAP32[$same5 >> 2] | 0) == 0) {
      __label__ = 79;
      break;
    } else {
      var $callDelProperty_0 = 0;
      __label__ = 80;
      break;
    }
   case 79:
    var $222 = HEAP32[$id >> 2];
    var $223 = __ZL6RejectP9JSContextjbiPb($cx, $throwError, $222, $rval);
    var $_0 = $223;
    __label__ = 102;
    break;
   case 80:
    var $callDelProperty_0;
    var $desc_idx40_val = HEAPU8[$desc_idx];
    var $224 = __ZNK2js8PropDesc19isGenericDescriptorEv($desc_idx40_val);
    if ($224) {
      __label__ = 81;
      break;
    } else {
      __label__ = 83;
      break;
    }
   case 81:
    var $changed_0 = ($desc_idx40_val & 32) << 24 >> 24 == 0 ? 0 : 4;
    var $changed_0_ = $changed_0 | ($desc_idx40_val & 255) >>> 4 & 1 & 255;
    var $_idx34_val = HEAP8[$44 + 28 | 0];
    var $230 = __ZNK2js5Shape10attributesEv($_idx34_val);
    var $238 = $230 & 255 & ($changed_0_ ^ -1) | $changed_0_ & (HEAPU8[$desc + 32 | 0] & 255);
    HEAP32[$attrs >> 2] = $238;
    var $_idx8_val = HEAP8[$44 + 29 | 0];
    var $239 = __ZNK2js5Shape8isMethodEv($_idx8_val);
    if ($239) {
      var $setter_0 = 12;
      var $getter_1 = 10;
      var $319 = $238;
      __label__ = 99;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 82:
    var $_idx3_val = HEAP32[$44 + 16 >> 2];
    var $241 = __ZNK2js5Shape6getterEv($_idx3_val);
    var $242 = $241;
    var $_idx6_val = HEAP32[$44 + 20 >> 2];
    var $243 = __ZNK2js5Shape6setterEv($_idx6_val);
    var $setter_0 = $243;
    var $getter_1 = $242;
    var $319 = $238;
    __label__ = 99;
    break;
   case 83:
    var $246 = __ZNK2js8PropDesc16isDataDescriptorEv($desc_idx40_val);
    if ($246) {
      __label__ = 84;
      break;
    } else {
      __label__ = 87;
      break;
    }
   case 84:
    var $unchanged_0 = ($desc_idx40_val & 32) << 24 >> 24 == 0 ? 4 : 0;
    var $_unchanged_0 = (($desc_idx40_val & 255) >>> 4 & 1 ^ 1) & 255 | $unchanged_0;
    var $unchanged_2 = ($desc_idx40_val & 8) << 24 >> 24 == 0 ? $_unchanged_0 | 2 : $_unchanged_0;
    if (($desc_idx40_val & 4) << 24 >> 24 == 0) {
      __label__ = 86;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 85:
    var $259 = $desc + 8 | 0;
    var $260$0 = HEAP32[$259 >> 2];
    var $260$1 = HEAP32[$259 + 4 >> 2];
    var $261 = $v | 0;
    HEAP32[$261 >> 2] = $260$0;
    HEAP32[$261 + 4 >> 2] = $260$1;
    __label__ = 86;
    break;
   case 86:
    var $266 = HEAPU8[$desc + 32 | 0] & 255 & ($unchanged_2 ^ -1);
    var $_idx33_val = HEAP8[$44 + 28 | 0];
    var $267 = __ZNK2js5Shape10attributesEv($_idx33_val);
    var $270 = $267 & 255 & $unchanged_2 | $266;
    HEAP32[$attrs >> 2] = $270;
    var $setter_0 = 12;
    var $getter_1 = 10;
    var $319 = $270;
    __label__ = 99;
    break;
   case 87:
    var $272 = HEAP32[$obj2 >> 2];
    var $273 = HEAP32[$id >> 2];
    var $274 = __ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj($cx, $272, $273, 3, $dummy6, $attrs);
    if (($274 | 0) == 0) {
      var $_0 = 0;
      __label__ = 102;
      break;
    } else {
      __label__ = 88;
      break;
    }
   case 88:
    var $277 = HEAPU8[$desc_idx];
    var $changed7_0 = ($277 & 32) << 24 >> 24 == 0 ? 0 : 4;
    var $changed7_0_ = $changed7_0 | ($277 & 255) >>> 4 & 1 & 255;
    var $283 = ($277 & 1) << 24 >> 24 == 0;
    var $changed7_2 = $283 ? $changed7_0_ : $changed7_0_ | 80;
    var $287 = ($277 & 2) << 24 >> 24 == 0;
    var $changed7_2_ = $287 ? $changed7_2 : $changed7_2 | 96;
    var $291 = $changed7_2_ & (HEAPU8[$desc + 32 | 0] & 255);
    var $_idx32_val = HEAPU8[$44 + 28 | 0];
    var $292 = __ZNK2js5Shape10attributesEv($_idx32_val);
    var $296 = $291 | $292 & 255 & ($changed7_2_ ^ -1);
    HEAP32[$attrs >> 2] = $296;
    if ($283) {
      __label__ = 90;
      break;
    } else {
      __label__ = 89;
      break;
    }
   case 89:
    var $298 = __ZNK2js8PropDesc6getterEv($desc);
    var $getter_0 = $298;
    __label__ = 94;
    break;
   case 90:
    var $_idx7_val = HEAP8[$44 + 29 | 0];
    var $300 = __ZNK2js5Shape8isMethodEv($_idx7_val);
    if ($300) {
      var $getter_0 = 10;
      __label__ = 94;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 91:
    var $_idx9_val = HEAP32[$44 + 16 >> 2];
    var $302 = __ZNK2js5Shape16hasDefaultGetterEv($_idx9_val);
    if ($302) {
      __label__ = 92;
      break;
    } else {
      __label__ = 93;
      break;
    }
   case 92:
    var $304 = __ZNK2js5Shape14hasGetterValueEv($_idx32_val);
    if ($304) {
      __label__ = 93;
      break;
    } else {
      var $getter_0 = 10;
      __label__ = 94;
      break;
    }
   case 93:
    var $306 = __ZNK2js5Shape6getterEv($_idx9_val);
    var $getter_0 = $306;
    __label__ = 94;
    break;
   case 94:
    var $getter_0;
    if ($287) {
      __label__ = 96;
      break;
    } else {
      __label__ = 95;
      break;
    }
   case 95:
    var $310 = __ZNK2js8PropDesc6setterEv($desc);
    var $setter_0 = $310;
    var $getter_1 = $getter_0;
    var $319 = $296;
    __label__ = 99;
    break;
   case 96:
    var $_idx23_val = HEAP32[$44 + 20 >> 2];
    var $312 = __ZNK2js5Shape16hasDefaultSetterEv($_idx23_val);
    if ($312) {
      __label__ = 97;
      break;
    } else {
      __label__ = 98;
      break;
    }
   case 97:
    var $314 = __ZNK2js5Shape14hasSetterValueEv($_idx32_val);
    if ($314) {
      __label__ = 98;
      break;
    } else {
      var $setter_0 = 12;
      var $getter_1 = $getter_0;
      var $319 = $296;
      __label__ = 99;
      break;
    }
   case 98:
    var $316 = __ZNK2js5Shape6setterEv($_idx23_val);
    var $setter_0 = $316;
    var $getter_1 = $getter_0;
    var $319 = $296;
    __label__ = 99;
    break;
   case 99:
    var $319;
    var $getter_1;
    var $setter_0;
    HEAP8[$rval] = 1;
    if ($callDelProperty_0) {
      __label__ = 100;
      break;
    } else {
      __label__ = 101;
      break;
    }
   case 100:
    __ZN2JSL14UndefinedValueEv2280($dummy8);
    var $321 = HEAP32[$obj2 >> 2];
    var $_idx_val = HEAP32[$321 + 4 >> 2];
    var $323 = __ZNK8JSObject8getClassEv($_idx_val);
    var $326 = HEAP32[$323 + 12 >> 2];
    var $327 = HEAP32[$id >> 2];
    var $328 = __ZN2js16CallJSPropertyOpEP9JSContextPFiS1_P8JSObjectiPN2JS5ValueEES3_iS6_($cx, $326, $321, $327, $dummy8);
    if ($328) {
      __label__ = 101;
      break;
    } else {
      var $_0 = 0;
      __label__ = 102;
      break;
    }
   case 101:
    var $330 = HEAP32[$id >> 2];
    var $332 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $330, $v, $getter_1, $setter_0, $319);
    var $_0 = $332;
    __label__ = 102;
    break;
   case 102:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL22DefinePropertyOnObjectP9JSContextP8JSObjectRKiRKN2js8PropDescEbPb["X"] = 1;

function __Z20js_DefineOwnPropertyP9JSContextP8JSObjectiRKN2JS5ValueEPi($cx, $obj, $id, $descriptor, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 76;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $descs = __stackBase__ + 4;
    var $rval = __stackBase__ + 72;
    HEAP32[$1 >> 2] = $id;
    var $2 = $cx;
    __ZN2js23AutoPropDescArrayRooterC1EP9JSContext($descs, $2);
    var $3 = __ZN2js23AutoPropDescArrayRooter6appendEv($descs);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $descriptor_idx = $descriptor | 0;
    var $descriptor_idx_val$0 = HEAP32[$descriptor_idx >> 2];
    var $descriptor_idx_val$1 = HEAP32[$descriptor_idx + 4 >> 2];
    var $6 = __ZN2js8PropDesc10initializeEP9JSContextRKN2JS5ValueEb($3, $cx, $descriptor_idx_val$0, $descriptor_idx_val$1, 1);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $8 = __ZN2js14DefinePropertyEP9JSContextP8JSObjectRKiRKNS_8PropDescEbPb($cx, $obj, $1, $3, $rval);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$bp >> 2] = HEAP8[$rval] & 1 & 255;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    __ZN2js23AutoPropDescArrayRooterD1Ev($descs);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js23ReadPropertyDescriptorsEP9JSContextP8JSObjectbPNS_12AutoIdVectorEPNS_23AutoPropDescArrayRooterE($cx, $props, $checkAccessors, $ids, $descs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $cx;
    var $2 = $props;
    var $3 = $ids;
    var $4 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($1, $2, 8, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    var $6 = $ids;
    var $7 = __ZNK2js16AutoVectorRooterIiE6lengthEv($6);
    var $8 = $props;
    var $9 = $cx;
    var $10 = $descs;
    var $v_idx = $v | 0;
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    if ($i_0 >>> 0 < $7 >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 4:
    var $14 = __ZN2js16AutoVectorRooterIiEixEj($6, $i_0);
    var $15 = HEAP32[$14 >> 2];
    var $16 = __ZN2js23AutoPropDescArrayRooter6appendEv($10);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($8, $9, $15, $v);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $22 = __ZN2js8PropDesc10initializeEP9JSContextRKN2JS5ValueEb($16, $cx, $v_idx_val$0, $v_idx_val$1, $checkAccessors);
    if ($22) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 3;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_PopulateObjectP9JSContextP8JSObjectS2_($cx, $newborn, $props) {
  var $1 = __ZL16DefinePropertiesP9JSContextP8JSObjectS2_($cx, $newborn, $props);
  return $1 & 1;
}

function __ZL16DefinePropertiesP9JSContextP8JSObjectS2_($cx, $obj, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 132;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ids = __stackBase__;
    var $descs = __stackBase__ + 60;
    var $dummy = __stackBase__ + 128;
    var $1 = $ids;
    var $2 = $cx;
    __ZN2js12AutoIdVectorC1EP9JSContext($1, $2);
    var $3 = $descs;
    __ZN2js23AutoPropDescArrayRooterC1EP9JSContext($3, $2);
    var $4 = __ZN2js23ReadPropertyDescriptorsEP9JSContextP8JSObjectbPNS_12AutoIdVectorEPNS_23AutoPropDescArrayRooterE($cx, $props, 1, $ids, $descs);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $6 = $ids;
    var $7 = __ZNK2js16AutoVectorRooterIiE6lengthEv($6);
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    if ($i_0 >>> 0 < $7 >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 4:
    var $11 = __ZN2js16AutoVectorRooterIiEixEj($6, $i_0);
    var $12 = __ZN2js23AutoPropDescArrayRooterixEj($3, $i_0);
    var $13 = __ZN2js14DefinePropertyEP9JSContextP8JSObjectRKiRKNS_8PropDescEbPb($cx, $obj, $11, $12, $dummy);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 3;
    break;
   case 6:
    var $_0;
    __ZN2js23AutoPropDescArrayRooterD1Ev($3);
    __ZN2js12AutoIdVectorD1Ev($1);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject12sealOrFreezeEP9JSContextNS_16ImmutabilityTypeE($this, $cx, $it) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $props = __stackBase__;
    var $attrs = __stackBase__ + 60;
    var $1 = $cx;
    var $2 = $this;
    var $3 = $props;
    __ZN2js12AutoIdVectorC1EP9JSContext($3, $1);
    var $_idx_val = HEAP32[$this + 8 >> 2];
    var $5 = __ZNK8JSObject12isExtensibleEv($_idx_val);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN8JSObject17preventExtensionsEP9JSContextPN2js12AutoIdVectorE($2, $1, $3);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 3:
    var $9 = $cx;
    var $10 = $this;
    var $11 = $props;
    var $12 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($9, $10, 24, $11);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 4:
    var $14 = $props;
    var $15 = __ZNK2js16AutoVectorRooterIiE6lengthEv($14);
    var $16 = ($it | 0) == 1;
    var $i_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_0;
    if ($i_0 >>> 0 < $15 >>> 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 13;
      break;
    }
   case 6:
    var $20 = __ZN2js16AutoVectorRooterIiEixEj($14, $i_0);
    var $21 = HEAPU32[$20 >> 2];
    var $22 = __ZN8JSObject13getAttributesEP9JSContextiPj($2, $1, $21, $attrs);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = HEAPU32[$attrs >> 2];
    if ($16) {
      __label__ = 8;
      break;
    } else {
      var $_pre = $25;
      __label__ = 9;
      break;
    }
   case 8:
    if (($25 & 48 | 0) == 0) {
      var $new_attrs_0 = 6;
      var $30 = $25;
      __label__ = 10;
      break;
    } else {
      var $_pre = $25;
      __label__ = 9;
      break;
    }
   case 9:
    var $_pre;
    var $new_attrs_0 = 4;
    var $30 = $_pre;
    __label__ = 10;
    break;
   case 10:
    var $30;
    var $new_attrs_0;
    var $31 = $30 | $new_attrs_0;
    if (($31 | 0) == ($30 | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    HEAP32[$attrs >> 2] = $31;
    var $34 = __ZN8JSObject13setAttributesEP9JSContextiPj($2, $1, $21, $attrs);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 5;
    break;
   case 13:
    var $_0;
    __ZN2js12AutoIdVectorD1Ev($3);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject12sealOrFreezeEP9JSContextNS_16ImmutabilityTypeE["X"] = 1;

function __ZN8JSObject16isSealedOrFrozenEP9JSContextNS_16ImmutabilityTypeEPb($this, $cx, $it, $resultp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $props = __stackBase__;
    var $attrs = __stackBase__ + 60;
    var $1 = $this;
    var $_idx_val = HEAP32[$this + 8 >> 2];
    var $3 = __ZNK8JSObject12isExtensibleEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP8[$resultp] = 0;
    var $_1 = 1;
    __label__ = 14;
    break;
   case 3:
    var $6 = $props;
    var $7 = $cx;
    __ZN2js12AutoIdVectorC1EP9JSContext($6, $7);
    var $8 = $cx;
    var $9 = $this;
    var $10 = $props;
    var $11 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($8, $9, 24, $10);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 4:
    var $13 = $props;
    var $14 = __ZNK2js16AutoVectorRooterIiE6lengthEv($13);
    var $15 = ($it | 0) == 1;
    var $i_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_0;
    if ($i_0 >>> 0 < $14 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 6:
    var $19 = __ZN2js16AutoVectorRooterIiEixEj($13, $i_0);
    var $20 = HEAP32[$19 >> 2];
    var $21 = __ZN8JSObject13getAttributesEP9JSContextiPj($1, $7, $20, $attrs);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = HEAP32[$attrs >> 2];
    if (($24 & 4 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($15) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    if (($24 & 50 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    HEAP8[$resultp] = 0;
    var $_0 = 1;
    __label__ = 13;
    break;
   case 11:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 5;
    break;
   case 12:
    HEAP8[$resultp] = 1;
    var $_0 = 1;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    __ZN2js12AutoIdVectorD1Ev($6);
    var $_1 = $_0;
    __label__ = 14;
    break;
   case 14:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12obj_toSourceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 104;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ida = __stackBase__;
    var $chars = __stackBase__ + 4;
    var $vsharp = __stackBase__ + 8;
    var $obj2 = __stackBase__ + 12;
    var $prop = __stackBase__ + 16;
    var $gsop = __stackBase__ + 20;
    var $localroot = __stackBase__ + 32;
    var $tvr = __stackBase__ + 64;
    var $1 = __stackBase__ + 80;
    var $2 = __stackBase__ + 88;
    var $3 = __stackBase__ + 96;
    if (__stackBase__ + 28 >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $cx;
    __Z21js_ReportOverRecursedP9JSContext($9);
    var $_1 = 0;
    __label__ = 91;
    break;
   case 3:
    __ZN2jsL12PodArrayZeroIN2JS5ValueELj4EEEvRAT0__T_2515($localroot);
    var $11 = $localroot | 0;
    var $12 = $cx;
    __ZN2js15AutoArrayRooterC1EP9JSContextjPN2JS5ValueE($tvr, $12, 4, $11);
    var $15 = (HEAP32[$cx + 136 >> 2] | 0) == 0;
    var $16 = $15 & 1;
    var $17 = $vp + 8 | 0;
    var $18 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($12, $17);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 90;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $21 = $18;
    var $22 = __Z19js_EnterSharpObjectP9JSContextP8JSObjectPP9JSIdArrayPPt($cx, $21, $ida, $chars);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 90;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $27 = HEAPU32[$chars >> 2];
    if ((HEAP32[$ida >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $29 = __Z9js_strlenPKt($27);
    var $nchars_9 = $29;
    var $330 = $27;
    __label__ = 86;
    break;
   case 7:
    if (($27 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $33 = $15 ? 10 : 6;
    var $34 = __ZN9JSContext7malloc_Ej($12, $33);
    var $35 = $34;
    HEAP32[$chars >> 2] = $35;
    if (($34 | 0) == 0) {
      var $ok_2 = 1;
      var $nchars_8 = 0;
      __label__ = 81;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ($15) {
      __label__ = 10;
      break;
    } else {
      var $nchars_0 = 0;
      var $outermost_0 = $16;
      var $57 = $35;
      __label__ = 15;
      break;
    }
   case 10:
    HEAP16[$35 >> 1] = 40;
    var $nchars_0 = 1;
    var $outermost_0 = $16;
    var $57 = HEAP32[$chars >> 2];
    __label__ = 15;
    break;
   case 11:
    var $40 = $22 + 12 | 0;
    var $44 = HEAP32[$40 >> 2] | 1;
    HEAP32[$40 >> 2] = $44;
    var $45 = HEAP32[$chars >> 2];
    var $46 = __Z9js_strlenPKt($45);
    var $47 = $45;
    var $49 = ($46 << 1) + 6 | 0;
    var $50 = __ZN9JSContext8realloc_EPvj($12, $47, $49);
    var $51 = $50;
    HEAP32[$chars >> 2] = $51;
    if (($50 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    __ZN2js10Foreground5free_EPv($47);
    var $ok_2 = 1;
    var $nchars_8 = $46;
    __label__ = 81;
    break;
   case 13:
    if ($15) {
      __label__ = 14;
      break;
    } else {
      var $nchars_0 = $46;
      var $outermost_0 = $16;
      var $57 = $51;
      __label__ = 15;
      break;
    }
   case 14:
    var $nchars_0 = $46;
    var $outermost_0 = 0;
    var $57 = $51;
    __label__ = 15;
    break;
   case 15:
    var $57;
    var $outermost_0;
    var $nchars_0;
    HEAP16[$57 + ($nchars_0 << 1) >> 1] = 123;
    var $60 = $localroot + 16 | 0;
    var $63 = HEAP32[HEAP32[$ida >> 2] >> 2];
    var $64 = $obj2;
    var $65 = $prop;
    var $66 = $cx;
    var $68 = ($outermost_0 | 0) != 0 ? 3 : 2;
    var $69 = $3 | 0;
    var $70 = $cx + 52 | 0;
    var $71 = $2 | 0;
    var $72 = $60 | 0;
    var $73 = $gsop | 0;
    var $_idx10 = $1 | 0;
    var $ok_0 = 1;
    var $nchars_1 = $nchars_0 + 1 | 0;
    var $i_0 = 0;
    var $comma_0 = 0;
    __label__ = 16;
    break;
   case 16:
    var $comma_0;
    var $i_0;
    var $nchars_1;
    var $ok_0;
    if (($i_0 | 0) < ($63 | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 17:
    var $79 = HEAPU32[HEAP32[$ida >> 2] + 4 + ($i_0 << 2) >> 2];
    var $80 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($18, $12, $79, $64, $65);
    if (($80 | 0) == 0) {
      var $ok_2 = 0;
      var $nchars_8 = $nchars_1;
      __label__ = 81;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZN2jsL9IdToValueEi2416($1, $79);
    var $st$1$0 = $_idx10 | 0;
    var $_idx10_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx10 + 4 | 0;
    var $_idx10_val$1 = HEAP32[$st$1$1 >> 2];
    var $83 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($66, $_idx10_val$0, $_idx10_val$1);
    if (($83 | 0) == 0) {
      var $ok_2 = 0;
      var $nchars_8 = $nchars_1;
      __label__ = 81;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $86 = __ZN8JSString12ensureLinearEP9JSContext($83, $12);
    if (($86 | 0) == 0) {
      var $ok_2 = 0;
      var $nchars_8 = $nchars_1;
      __label__ = 81;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $89 = $86 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $89);
    var $90 = HEAP32[$prop >> 2];
    if (($90 | 0) == 0) {
      var $ok_1 = $80;
      var $valcnt_2 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $_idx7_val = HEAP32[HEAP32[$obj2 >> 2] >> 2];
    var $94 = __ZNK8JSObject8isNativeEv($_idx7_val);
    if ($94) {
      __label__ = 22;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 22:
    var $96 = $90;
    var $_idx9_val = HEAP8[$90 + 28 | 0];
    var $98 = __ZNK2js5Shape10attributesEv($_idx9_val);
    var $99 = $98 & 255;
    if (($99 & 16 | 0) == 0) {
      var $doGet_0 = 1;
      var $valcnt_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    __ZNK2js5Shape11getterValueEv($2, $96);
    var $st$1$0 = $71 | 0;
    var $103$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $71 + 4 | 0;
    var $103$1 = HEAP32[$st$1$1 >> 2];
    var $st$5$0 = $72 | 0;
    HEAP32[$st$5$0 >> 2] = $103$0;
    var $st$5$1 = $72 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $103$1;
    var $107 = HEAP32[HEAP32[$70 >> 2] + 210220 >> 2] | 0;
    HEAP32[$73 >> 2] = $107;
    var $doGet_0 = 0;
    var $valcnt_0 = 1;
    __label__ = 24;
    break;
   case 24:
    var $valcnt_0;
    var $doGet_0;
    if (($99 & 32 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $_sum78 = $valcnt_0 | 2;
    __ZNK2js5Shape11setterValueEv($3, $96);
    var $111$0 = HEAP32[$69 >> 2];
    var $111$1 = HEAP32[$69 + 4 >> 2];
    var $112 = $localroot + ($_sum78 << 3) | 0;
    HEAP32[$112 >> 2] = $111$0;
    HEAP32[$112 + 4 >> 2] = $111$1;
    var $116 = HEAP32[HEAP32[$70 >> 2] + 210296 >> 2] | 0;
    HEAP32[$gsop + ($valcnt_0 << 2) >> 2] = $116;
    var $ok_1 = $80;
    var $valcnt_2 = $valcnt_0 + 1 | 0;
    __label__ = 28;
    break;
   case 26:
    if ($doGet_0 << 24 >> 24 == 0) {
      var $ok_1 = $80;
      var $valcnt_2 = $valcnt_0;
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    HEAP32[$73 >> 2] = 0;
    var $121 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($18, $12, $79, $60);
    if (($121 | 0) == 0) {
      var $ok_2 = 0;
      var $nchars_8 = $nchars_1;
      __label__ = 81;
      break;
    } else {
      var $ok_1 = $121;
      var $valcnt_2 = 1;
      __label__ = 28;
      break;
    }
   case 28:
    var $valcnt_2;
    var $ok_1;
    var $124 = __ZL12JSID_IS_ATOMi2511($79);
    if (($124 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $127 = __Z15js_IsIdentifierP14JSLinearString($86);
    if (($127 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      var $idstr_0 = $86;
      __label__ = 35;
      break;
    }
   case 30:
    var $130 = _JSID_IS_INT2487($79);
    if (($130 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $133 = _JSID_TO_INT2488($79);
    if (($133 | 0) < 0) {
      __label__ = 32;
      break;
    } else {
      var $idstr_0 = $86;
      __label__ = 35;
      break;
    }
   case 32:
    var $136 = _js_QuoteString($12, $89, 39);
    if (($136 | 0) == 0) {
      var $ok_2 = 0;
      var $nchars_8 = $nchars_1;
      __label__ = 81;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $139 = __ZN8JSString12ensureLinearEP9JSContext($136, $12);
    if (($139 | 0) == 0) {
      var $ok_2 = 0;
      var $nchars_8 = $nchars_1;
      __label__ = 81;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $142 = $139 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $142);
    var $idstr_0 = $139;
    __label__ = 35;
    break;
   case 35:
    var $idstr_0;
    var $144 = $idstr_0 | 0;
    var $_idx6_val = HEAP32[$idstr_0 >> 2];
    var $145 = __ZNK8JSString6lengthEv($_idx6_val);
    var $146 = __ZN8JSString8getCharsEP9JSContext($144, $12);
    if (($146 | 0) == 0) {
      var $ok_2 = 0;
      var $nchars_8 = $nchars_1;
      __label__ = 81;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $148 = $145 + 1 | 0;
    var $149 = $146;
    var $150 = $145 << 1;
    var $j_0 = 0;
    var $nchars_2 = $nchars_1;
    var $comma_1 = $comma_0;
    __label__ = 37;
    break;
   case 37:
    var $comma_1;
    var $nchars_2;
    var $j_0;
    if (($j_0 | 0) < ($valcnt_2 | 0)) {
      __label__ = 38;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 38:
    var $154 = $gsop + ($j_0 << 2) | 0;
    var $155 = HEAPU32[$154 >> 2];
    var $156 = ($155 | 0) == 0;
    var $_sum_pre = $j_0 + 2 | 0;
    if ($156) {
      var $_sum_pre_phi = $_sum_pre;
      __label__ = 40;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $_idx2 = $localroot + ($_sum_pre << 3) | 0;
    var $st$1$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$1$1 >> 2];
    var $158 = __ZNK2JS5Value11isUndefinedEv($_idx2_val$0, $_idx2_val$1);
    if ($158) {
      var $nchars_6 = $nchars_2;
      var $comma_2 = $comma_1;
      __label__ = 76;
      break;
    } else {
      var $_sum_pre_phi = $_sum_pre;
      __label__ = 40;
      break;
    }
   case 40:
    var $_sum_pre_phi;
    var $159 = $localroot + ($_sum_pre_phi << 3) | 0;
    var $160 = __Z16js_ValueToSourceP9JSContextRKN2JS5ValueE($66, $159);
    if (($160 | 0) == 0) {
      var $ok_2 = 0;
      var $nchars_8 = $nchars_2;
      __label__ = 81;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    var $163 = $localroot + ($j_0 << 3) | 0;
    __ZN2JS5Value9setStringEP8JSString($163, $160);
    var $164 = __ZN8JSString8getCharsEP9JSContext($160, $12);
    if (($164 | 0) == 0) {
      var $ok_2 = 0;
      var $nchars_8 = $nchars_2;
      __label__ = 81;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $_idx5_val = HEAP32[$160 >> 2];
    var $167 = __ZNK8JSString6lengthEv($_idx5_val);
    HEAP32[$vsharp >> 2] = 0;
    var $_idx = $159 | 0;
    var $st$5$0 = $_idx | 0;
    var $_idx_val$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAP32[$st$5$1 >> 2];
    if ($156) {
      __label__ = 43;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 43:
    var $169 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($169) {
      __label__ = 44;
      break;
    } else {
      var $vchars_5 = $164;
      var $vlength_1 = $167;
      var $vsharplength_112 = 0;
      var $218 = 0;
      var $217 = $155;
      __label__ = 57;
      break;
    }
   case 44:
    if (HEAP16[$164 >> 1] << 16 >> 16 == 35) {
      var $vchars_5 = $164;
      var $vlength_1 = $167;
      var $vsharplength_112 = 0;
      var $218 = 0;
      var $217 = $155;
      __label__ = 57;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $174 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $175 = $174;
    var $176 = __Z19js_EnterSharpObjectP9JSContextP8JSObjectPP9JSIdArrayPPt($cx, $175, 0, $vsharp);
    if (($176 | 0) == 0) {
      var $ok_2 = 0;
      var $nchars_8 = $nchars_2;
      __label__ = 81;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $179 = $176 + 12 | 0;
    var $181 = HEAP32[$179 >> 2];
    var $184 = HEAPU32[$vsharp >> 2];
    if (($181 & 1 | 0) == 0) {
      __label__ = 48;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $186 = __Z9js_strlenPKt($184);
    var $vchars_5 = $184;
    var $vlength_1 = $186;
    var $vsharplength_112 = 0;
    var $218 = $184;
    var $217 = $155;
    __label__ = 57;
    break;
   case 48:
    if (($184 | 0) == 0) {
      var $vsharplength_0 = 0;
      __label__ = 50;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $190 = __Z9js_strlenPKt($184);
    var $192 = $181 | 1;
    HEAP32[$179 >> 2] = $192;
    var $vsharplength_0 = $190;
    __label__ = 50;
    break;
   case 50:
    var $vsharplength_0;
    __Z19js_LeaveSharpObjectP9JSContextPP9JSIdArray($cx, 0);
    var $vchars_5 = $164;
    var $vlength_1 = $167;
    var $vsharplength_112 = $vsharplength_0;
    var $218 = $184;
    var $217 = $155;
    __label__ = 57;
    break;
   case 51:
    var $194 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueE2445($_idx_val$0, $_idx_val$1);
    if ($194) {
      __label__ = 52;
      break;
    } else {
      var $vchars_5 = $164;
      var $vlength_1 = $167;
      var $vsharplength_112 = 0;
      var $218 = 0;
      var $217 = $155;
      __label__ = 57;
      break;
    }
   case 52:
    var $196 = $164 + ($167 << 1) | 0;
    var $198 = HEAP16[$164 >> 1] << 16 >> 16 == 40;
    var $vchars_1 = $198 ? $164 + 2 | 0 : $164;
    var $parenChomp_0 = $198 & 1;
    if (($vchars_1 | 0) == 0) {
      __label__ = 56;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    var $202 = __Z15js_strchr_limitPKttS0_($vchars_1, 32, $196);
    if (($202 | 0) == 0) {
      __label__ = 56;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    var $205 = __Z15js_strchr_limitPKttS0_($202, 40, $196);
    if (($205 | 0) == 0) {
      __label__ = 56;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    var $vchars_4 = HEAP16[$205 >> 1] << 16 >> 16 == 32 ? $205 + 2 | 0 : $205;
    var $vchars_5 = $vchars_4;
    var $vlength_1 = ($196 - $vchars_4 >> 1) - $parenChomp_0 | 0;
    var $vsharplength_112 = 0;
    var $218 = 0;
    var $217 = $155;
    __label__ = 57;
    break;
   case 56:
    HEAP32[$154 >> 2] = 0;
    var $vchars_5 = $164;
    var $vlength_1 = $167;
    var $vsharplength_112 = 0;
    var $218 = 0;
    var $217 = 0;
    __label__ = 57;
    break;
   case 57:
    var $217;
    var $218;
    var $vsharplength_112;
    var $vlength_1;
    var $vchars_5;
    var $219 = ($comma_1 | 0) != 0;
    if ($219) {
      __label__ = 58;
      break;
    } else {
      var $curlen_0 = $nchars_2;
      __label__ = 59;
      break;
    }
   case 58:
    if ($nchars_2 >>> 0 > 4294967293) {
      var $nchars_10 = $nchars_2;
      __label__ = 89;
      break;
    } else {
      var $curlen_0 = $nchars_2 + 2 | 0;
      __label__ = 59;
      break;
    }
   case 59:
    var $curlen_0;
    var $uadd = _llvm_uadd_with_overflow_i32($curlen_0, $148);
    var $224 = $uadd.f0;
    var $225 = $uadd.f1;
    if ($225) {
      var $nchars_10 = $nchars_2;
      __label__ = 89;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 60:
    var $227 = ($217 | 0) == 0;
    if ($227) {
      var $curlen_1 = $224;
      __label__ = 62;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    var $_idx4_val = HEAP32[$217 >> 2];
    var $229 = __ZNK8JSString6lengthEv($_idx4_val);
    var $230 = $229 + 1 | 0;
    var $uadd5 = _llvm_uadd_with_overflow_i32($224, $230);
    var $231 = $uadd5.f0;
    var $232 = $uadd5.f1;
    if ($232) {
      var $nchars_10 = $nchars_2;
      __label__ = 89;
      break;
    } else {
      var $curlen_1 = $231;
      __label__ = 62;
      break;
    }
   case 62:
    var $curlen_1;
    var $uadd2 = _llvm_uadd_with_overflow_i32($curlen_1, $vsharplength_112);
    var $234 = $uadd2.f1;
    if ($234) {
      var $nchars_10 = $nchars_2;
      __label__ = 89;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $236 = $uadd2.f0;
    var $uadd3 = _llvm_uadd_with_overflow_i32($236, $vlength_1);
    var $237 = $uadd3.f1;
    if ($237) {
      var $nchars_10 = $nchars_2;
      __label__ = 89;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    var $239 = $uadd3.f0;
    var $uadd4 = _llvm_uadd_with_overflow_i32($239, $68);
    var $240 = $uadd4.f0;
    var $241 = $uadd4.f1;
    if ($241 | ($240 | 0) < 0) {
      var $nchars_10 = $nchars_2;
      __label__ = 89;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 65:
    var $244 = HEAP32[$chars >> 2];
    var $245 = $244;
    var $246 = $240 << 1;
    var $247 = __ZN9JSContext8realloc_EPvj($12, $245, $246);
    var $248 = $247;
    HEAP32[$chars >> 2] = $248;
    if (($247 | 0) == 0) {
      __label__ = 66;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 66:
    HEAP32[$chars >> 2] = $244;
    var $nchars_10 = $nchars_2;
    __label__ = 89;
    break;
   case 67:
    if ($219) {
      __label__ = 68;
      break;
    } else {
      var $nchars_3 = $nchars_2;
      __label__ = 69;
      break;
    }
   case 68:
    HEAP16[$248 + ($nchars_2 << 1) >> 1] = HEAP8[$comma_1] << 24 >> 24;
    HEAP16[HEAP32[$chars >> 2] + ($nchars_2 + 1 << 1) >> 1] = HEAP8[$comma_1 + 1 | 0] << 24 >> 24;
    var $nchars_3 = $nchars_2 + 2 | 0;
    __label__ = 69;
    break;
   case 69:
    var $nchars_3;
    if ($227) {
      var $nchars_4 = $nchars_3;
      __label__ = 72;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    var $_idx3_val = HEAP32[$217 >> 2];
    var $265 = __ZNK8JSString6lengthEv($_idx3_val);
    var $266 = __ZN8JSString8getCharsEP9JSContext($217, $12);
    if (($266 | 0) == 0) {
      var $nchars_10 = $nchars_3;
      __label__ = 89;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 71:
    var $271 = HEAP32[$chars >> 2] + ($nchars_3 << 1) | 0;
    var $272 = $266;
    var $273 = $265 << 1;
    _memcpy($271, $272, $273, 1);
    var $274 = $265 + $nchars_3 | 0;
    var $275 = $274 + 1 | 0;
    HEAP16[HEAP32[$chars >> 2] + ($274 << 1) >> 1] = 32;
    var $nchars_4 = $275;
    __label__ = 72;
    break;
   case 72:
    var $nchars_4;
    var $280 = HEAP32[$chars >> 2] + ($nchars_4 << 1) | 0;
    _memcpy($280, $149, $150, 1);
    var $281 = $nchars_4 + $145 | 0;
    var $283 = ($217 | 0) != 0 ? 32 : 58;
    var $284 = $281 + 1 | 0;
    HEAP16[HEAP32[$chars >> 2] + ($281 << 1) >> 1] = $283;
    if (($vsharplength_112 | 0) == 0) {
      var $nchars_5 = $284;
      __label__ = 74;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    var $291 = HEAP32[$chars >> 2] + ($284 << 1) | 0;
    _memcpy($291, $218, $vsharplength_112 << 1, 1);
    var $nchars_5 = $284 + $vsharplength_112 | 0;
    __label__ = 74;
    break;
   case 74:
    var $nchars_5;
    var $298 = HEAP32[$chars >> 2] + ($nchars_5 << 1) | 0;
    _memcpy($298, $vchars_5, $vlength_1 << 1, 1);
    var $301 = $nchars_5 + $vlength_1 | 0;
    if (($218 | 0) == 0) {
      var $nchars_6 = $301;
      var $comma_2 = STRING_TABLE.__str296 | 0;
      __label__ = 76;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 75:
    __ZN9JSContext5free_EPv($218);
    var $nchars_6 = $301;
    var $comma_2 = STRING_TABLE.__str296 | 0;
    __label__ = 76;
    break;
   case 76:
    var $comma_2;
    var $nchars_6;
    var $j_0 = $j_0 + 1 | 0;
    var $nchars_2 = $nchars_6;
    var $comma_1 = $comma_2;
    __label__ = 37;
    break;
   case 77:
    var $ok_0 = $ok_1;
    var $nchars_1 = $nchars_2;
    var $i_0 = $i_0 + 1 | 0;
    var $comma_0 = $comma_1;
    __label__ = 16;
    break;
   case 78:
    var $310 = $nchars_1 + 1 | 0;
    HEAP16[HEAP32[$chars >> 2] + ($nchars_1 << 1) >> 1] = 125;
    if (($outermost_0 | 0) == 0) {
      var $nchars_7 = $310;
      __label__ = 80;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 79:
    HEAP16[HEAP32[$chars >> 2] + ($310 << 1) >> 1] = 41;
    var $nchars_7 = $nchars_1 + 2 | 0;
    __label__ = 80;
    break;
   case 80:
    var $nchars_7;
    HEAP16[HEAP32[$chars >> 2] + ($nchars_7 << 1) >> 1] = 0;
    var $ok_2 = $ok_0;
    var $nchars_8 = $nchars_7;
    __label__ = 81;
    break;
   case 81:
    var $nchars_8;
    var $ok_2;
    __Z19js_LeaveSharpObjectP9JSContextPP9JSIdArray($cx, $ida);
    var $322 = HEAP32[$chars >> 2];
    var $323 = ($322 | 0) != 0;
    if (($ok_2 | 0) == 0) {
      __label__ = 82;
      break;
    } else {
      __label__ = 84;
      break;
    }
   case 82:
    if ($323) {
      __label__ = 83;
      break;
    } else {
      var $_0 = 0;
      __label__ = 90;
      break;
    }
   case 83:
    var $326 = $322;
    __ZN2js10Foreground5free_EPv($326);
    var $_0 = $ok_2;
    __label__ = 90;
    break;
   case 84:
    if ($323) {
      var $nchars_9 = $nchars_8;
      var $330 = $322;
      __label__ = 86;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 85:
    _JS_ReportOutOfMemory($12);
    var $_0 = 0;
    __label__ = 90;
    break;
   case 86:
    var $330;
    var $nchars_9;
    var $331 = $cx;
    var $332 = __Z12js_NewStringP9JSContextPtj($331, $330, $nchars_9);
    if (($332 | 0) == 0) {
      __label__ = 87;
      break;
    } else {
      __label__ = 88;
      break;
    }
   case 87:
    var $336 = HEAP32[$chars >> 2];
    __ZN9JSContext5free_EPv($336);
    var $_0 = 0;
    __label__ = 90;
    break;
   case 88:
    var $338 = $332 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $338);
    var $_0 = 1;
    __label__ = 90;
    break;
   case 89:
    var $nchars_10;
    __ZN9JSContext5free_EPv($218);
    var $341 = HEAP32[$chars >> 2];
    __ZN9JSContext5free_EPv($341);
    HEAP32[$chars >> 2] = 0;
    var $ok_2 = $ok_1;
    var $nchars_8 = $nchars_10;
    __label__ = 81;
    break;
   case 90:
    var $_0;
    __ZN2js15AutoArrayRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 91;
    break;
   case 91:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12obj_toSourceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL12obj_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $2 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = HEAP32[HEAP32[$cx + 52 >> 2] + 210288 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $8);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 3:
    var $10 = __ZNK2JS5Value6isNullEv($_idx_val$0, $_idx_val$1);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = HEAP32[HEAP32[$cx + 52 >> 2] + 210284 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $16);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 5:
    var $18 = $cx;
    var $19 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($18, $1);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = $19;
    var $23 = __ZN2js18obj_toStringHelperEP9JSContextP8JSObject($cx, $22);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JS5Value9setStringEP8JSString($vp, $23);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18obj_toLocaleStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx;
    __Z21js_ReportOverRecursedP9JSContext($6);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $8 = $vp + 8 | 0;
    var $9 = $cx;
    var $10 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($9, $8);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $10;
    var $18 = HEAP32[HEAP32[$cx + 52 >> 2] + 210324 >> 2] | 0;
    var $19 = __ZL12ATOM_TO_JSIDP6JSAtom2291($18);
    var $20 = __ZN8JSObject10callMethodEP9JSContextijPN2JS5ValueES4_($13, $cx, $19, $vp);
    var $_0 = $20 & 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11obj_valueOfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $3);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9obj_watchP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $propid = __stackBase__;
    var $tmp = __stackBase__ + 4;
    var $attrs = __stackBase__ + 12;
    if ($argc >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $cx;
    __Z19js_ReportMissingArgP9JSContextRKN2JS5ValueEj($3, $vp, 1);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 3:
    var $5 = $vp + 24 | 0;
    var $6 = $cx;
    var $7 = __Z24js_ValueToCallableObjectP9JSContextPN2JS5ValueEj($6, $5, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $vp + 16 | 0;
    var $11 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($6, $10, $propid);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $13 = $vp + 8 | 0;
    var $14 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($6, $13);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = $14;
    var $18 = HEAPU32[$propid >> 2];
    var $19 = __ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj($cx, $17, $18, 3, $tmp, $attrs);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JS5Value12setUndefinedEv($vp);
    if ((HEAP32[$attrs >> 2] & 2 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 8:
    var $_idx_val = HEAP32[$14 + 4 >> 2];
    var $26 = __ZNK8JSObject12isDenseArrayEv($_idx_val);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $28 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($14, $6);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $31 = $cx;
    var $32 = $14;
    var $33 = $7;
    var $34 = _JS_SetWatchPoint($31, $32, $18, $33);
    var $_0 = $34;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11obj_unwatchP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    if (($argc | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $vp + 16 | 0;
    var $9 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($2, $8, $id);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 4:
    var $12 = HEAP32[$id >> 2];
    __label__ = 6;
    break;
   case 5:
    HEAP32[$id >> 2] = 2;
    var $12 = 2;
    __label__ = 6;
    break;
   case 6:
    var $12;
    var $13 = $3;
    var $_idx_val_idx_val = HEAP32[HEAP32[$cx + 56 >> 2] + 1984 >> 2];
    _JS_ClearWatchPoint($_idx_val_idx_val, $13, $12);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18obj_hasOwnPropertyP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $6 = __ZNK8JSObject6getOpsEv($_idx_val);
    var $9 = HEAP32[$6 + 4 >> 2];
    var $10 = __Z23js_HasOwnPropertyHelperP9JSContextPFiS0_P8JSObjectiPS2_PP10JSPropertyEjPN2JS5ValueE($cx, $9, $argc, $vp);
    var $_0 = $10;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17obj_isPrototypeOfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx = $vp + 16 | 0;
    var $st$1$0 = $_idx | 0;
    var $_idx_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAP32[$st$1$1 >> 2];
    var $3 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value10setBooleanEb($vp, 0);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 4:
    var $6 = $vp + 8 | 0;
    var $7 = $cx;
    var $8 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($7, $6);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = $8;
    var $st$1$0 = $_idx | 0;
    var $_idx1_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx + 4 | 0;
    var $_idx1_val$1 = HEAP32[$st$1$1 >> 2];
    var $12 = __Z13js_IsDelegateP9JSContextP8JSObjectRKN2JS5ValueE($11, $_idx1_val$0, $_idx1_val$1);
    __ZN2JS5Value10setBooleanEb($vp, $12);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24obj_propertyIsEnumerableP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __stackBase__ + 4;
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $vp + 16 | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = $1 | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv2280($1);
    __label__ = 4;
    break;
   case 4:
    var $9 = $cx;
    var $10 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($9, $1, $id);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $12 = $vp + 8 | 0;
    var $13 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($9, $12);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = $13;
    var $17 = HEAP32[$id >> 2];
    var $18 = __Z23js_PropertyIsEnumerableP9JSContextP8JSObjectiPN2JS5ValueE($cx, $16, $17, $vp);
    var $_0 = $18;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL15NewObjectGCKindEP9JSContextPNS_5ClassE($clasp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($clasp | 0) == (__ZN2js10ArrayClassE | 0) | ($clasp | 0) == (__ZN2js14SlowArrayClassE | 0)) {
      var $_0 = 6;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_ = ($clasp | 0) == (__ZN2js13FunctionClassE | 0) ? 2 : 4;
    var $_0 = $_;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16obj_lookupGetterP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $pobj = __stackBase__ + 12;
    var $prop = __stackBase__ + 16;
    var $2 = __stackBase__ + 20;
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $vp + 16 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $1 | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv2280($1);
    __label__ = 4;
    break;
   case 4:
    var $10 = $cx;
    var $11 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($10, $1, $id);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $13 = $vp + 8 | 0;
    var $14 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($10, $13);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = HEAP32[$id >> 2];
    var $18 = $pobj;
    var $19 = $prop;
    var $20 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($14, $10, $17, $18, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $23 = HEAP32[$prop >> 2];
    if (($23 | 0) == 0) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx1_val = HEAP32[HEAP32[$pobj >> 2] >> 2];
    var $27 = __ZNK8JSObject8isNativeEv($_idx1_val);
    if ($27) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 9:
    var $_idx_val = HEAP8[$23 + 28 | 0];
    var $30 = __ZNK2js5Shape14hasGetterValueEv($_idx_val);
    if ($30) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 10:
    var $32 = $23;
    __ZNK2js5Shape11getterValueEv($2, $32);
    var $33 = $2 | 0;
    var $34$0 = HEAP32[$33 >> 2];
    var $34$1 = HEAP32[$33 + 4 >> 2];
    var $35 = $vp | 0;
    HEAP32[$35 >> 2] = $34$0;
    HEAP32[$35 + 4 >> 2] = $34$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16obj_lookupGetterP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL16obj_lookupSetterP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $pobj = __stackBase__ + 12;
    var $prop = __stackBase__ + 16;
    var $2 = __stackBase__ + 20;
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $vp + 16 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $1 | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv2280($1);
    __label__ = 4;
    break;
   case 4:
    var $10 = $cx;
    var $11 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($10, $1, $id);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $13 = $vp + 8 | 0;
    var $14 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($10, $13);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = HEAP32[$id >> 2];
    var $18 = $pobj;
    var $19 = $prop;
    var $20 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($14, $10, $17, $18, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $23 = HEAP32[$prop >> 2];
    if (($23 | 0) == 0) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx1_val = HEAP32[HEAP32[$pobj >> 2] >> 2];
    var $27 = __ZNK8JSObject8isNativeEv($_idx1_val);
    if ($27) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 9:
    var $_idx_val = HEAP8[$23 + 28 | 0];
    var $30 = __ZNK2js5Shape14hasSetterValueEv($_idx_val);
    if ($30) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 10:
    var $32 = $23;
    __ZNK2js5Shape11setterValueEv($2, $32);
    var $33 = $2 | 0;
    var $34$0 = HEAP32[$33 >> 2];
    var $34$1 = HEAP32[$33 + 4 >> 2];
    var $35 = $vp | 0;
    HEAP32[$35 >> 2] = $34$0;
    HEAP32[$35 + 4 >> 2] = $34$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16obj_lookupSetterP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL28obj_getOwnPropertyDescriptorP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $nameidr = __stackBase__ + 4;
    var $1 = __stackBase__ + 20;
    var $2 = __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, STRING_TABLE.__str452248 | 0, $obj);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    var $4 = _INT_TO_JSID2431(0);
    var $5 = $cx;
    __ZN2js12AutoIdRooterC1EP9JSContexti($nameidr, $5, $4);
    if ($argc >>> 0 > 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = $vp + 24 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $1 | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    __label__ = 5;
    break;
   case 4:
    __ZN2JSL14UndefinedValueEv2280($1);
    __label__ = 5;
    break;
   case 5:
    var $13 = __ZN2js12AutoIdRooter4addrEv($nameidr);
    var $14 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($5, $1, $13);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $16 = HEAP32[$obj >> 2];
    var $nameidr_idx_val = HEAP32[$nameidr + 12 >> 2];
    var $17 = __ZN2js12AutoIdRooter2idEv($nameidr_idx_val);
    var $18 = __ZN2js24GetOwnPropertyDescriptorEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $16, $17, $vp);
    var $_0 = $18 & 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    __ZN2js12AutoIdRooterD1Ev($nameidr);
    var $_1 = $_0;
    __label__ = 8;
    break;
   case 8:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8obj_keysP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 172;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $props = __stackBase__ + 4;
    var $vals = __stackBase__ + 64;
    var $1 = __stackBase__ + 156;
    var $2 = __stackBase__ + 164;
    var $3 = __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, STRING_TABLE.__str442247 | 0, $obj);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_2 = 0;
      __label__ = 16;
      break;
    }
   case 2:
    var $5 = $props;
    var $6 = $cx;
    __ZN2js12AutoIdVectorC1EP9JSContext($5, $6);
    var $8 = $cx;
    var $9 = HEAP32[$obj >> 2];
    var $10 = $props;
    var $11 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($8, $9, 8, $10);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 0;
      __label__ = 15;
      break;
    }
   case 3:
    var $13 = $vals;
    __ZN2js15AutoValueVectorC1EP9JSContext($13, $6);
    var $14 = $props;
    var $15 = __ZNK2js16AutoVectorRooterIiE6lengthEv($14);
    var $16 = $vals;
    var $17 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($16, $15);
    if ($17) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 4:
    var $19 = __ZNK2js16AutoVectorRooterIiE6lengthEv($14);
    var $_idx1 = $2 | 0;
    var $_idx = $1 | 0;
    var $i_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_0;
    if ($i_0 >>> 0 < $19 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 6:
    var $23 = __ZN2js16AutoVectorRooterIiEixEj($14, $i_0);
    var $24 = HEAPU32[$23 >> 2];
    var $25 = _JSID_IS_STRING2486($24);
    if (($25 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $28 = _JSID_TO_STRING2421($24);
    __ZN2JSL11StringValueEP8JSString2480($1, $28);
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $29 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($16, $_idx_val$0, $_idx_val$1);
    __label__ = 11;
    break;
   case 8:
    var $31 = _JSID_IS_INT2487($24);
    if (($31 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $34 = _JSID_TO_INT2488($24);
    var $35 = __Z14js_IntToStringP9JSContexti($6, $34);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2JSL11StringValueEP8JSString2480($2, $35);
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($16, $_idx1_val$0, $_idx1_val$1);
    __label__ = 11;
    break;
   case 11:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 5;
    break;
   case 12:
    var $41 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($16);
    var $42 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($16);
    var $43 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($6, $41, $42);
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    __ZN2JS5Value9setObjectER8JSObject($vp, $43);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($13);
    var $_1 = $_0;
    __label__ = 15;
    break;
   case 15:
    var $_1;
    __ZN2js12AutoIdVectorD1Ev($5);
    var $_2 = $_1;
    __label__ = 16;
    break;
   case 16:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL8obj_keysP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL18obj_definePropertyP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $id = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $descval = __stackBase__ + 16;
    var $junk = __stackBase__ + 24;
    var $2 = __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, STRING_TABLE.__str432246 | 0, $obj);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    if ($argc >>> 0 > 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = $vp + 24 | 0;
    var $st$1$0 = $6 | 0;
    var $7$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $6 + 4 | 0;
    var $7$1 = HEAP32[$st$1$1 >> 2];
    var $8 = $1 | 0;
    var $st$6$0 = $8 | 0;
    HEAP32[$st$6$0 >> 2] = $7$0;
    var $st$6$1 = $8 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $7$1;
    __label__ = 5;
    break;
   case 4:
    __ZN2JSL14UndefinedValueEv2280($1);
    __label__ = 5;
    break;
   case 5:
    var $11 = $cx;
    var $12 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($11, $1, $id);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 6:
    if ($argc >>> 0 > 2) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $16 = $vp + 32 | 0;
    var $st$1$0 = $16 | 0;
    var $17$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $16 + 4 | 0;
    var $17$1 = HEAP32[$st$1$1 >> 2];
    var $18 = $descval | 0;
    var $st$6$0 = $18 | 0;
    HEAP32[$st$6$0 >> 2] = $17$0;
    var $st$6$1 = $18 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $17$1;
    __label__ = 9;
    break;
   case 8:
    __ZN2JSL14UndefinedValueEv2280($descval);
    __label__ = 9;
    break;
   case 9:
    var $21 = HEAP32[$obj >> 2];
    var $22 = HEAP32[$id >> 2];
    var $23 = __Z20js_DefineOwnPropertyP9JSContextP8JSObjectiRKN2JS5ValueEPi($cx, $21, $22, $descval, $junk);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $26 = $21;
    __ZN2JS5Value9setObjectER8JSObject($vp, $26);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18obj_definePropertyP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL20obj_definePropertiesP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, STRING_TABLE.__str422245 | 0, $obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $3 = HEAPU32[$obj >> 2];
    var $4 = $3;
    __ZN2JS5Value9setObjectER8JSObject($vp, $4);
    if ($argc >>> 0 < 2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = $cx;
    _JS_ReportErrorNumber($7, 4, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str422245 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str225518 | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str226519 | 0, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    var $9 = $vp + 24 | 0;
    var $10 = $cx;
    var $11 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($10, $9);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = $11;
    var $15 = __ZL16DefinePropertiesP9JSContextP8JSObjectS2_($cx, $3, $14);
    var $_0 = $15 & 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10obj_createP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $cx;
    _JS_ReportErrorNumber($3, 4, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str402243 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str225518 | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str226519 | 0, tempInt));
    var $_0 = 0;
    __label__ = 16;
    break;
   case 3:
    var $_idx6 = $vp + 16 | 0;
    var $st$1$0 = $_idx6 | 0;
    var $_idx6_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx6 + 4 | 0;
    var $_idx6_val$1 = HEAP32[$st$1$1 >> 2];
    var $5 = __ZNK2JS5Value14isObjectOrNullEv($_idx6_val$0, $_idx6_val$1);
    if ($5) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZN2jsL23DecompileValueGeneratorEP9JSContextiRKN2JS5ValueEP8JSString2290($cx, $_idx6_val$0, $_idx6_val$1);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = $cx;
    _JS_ReportErrorNumber($10, 4, 222, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $7, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str412244 | 0, tempInt));
    _JS_free($7);
    var $_0 = 0;
    __label__ = 16;
    break;
   case 6:
    var $12 = __ZNK2JS5Value14toObjectOrNullEv($_idx6_val$0, $_idx6_val$1);
    var $13 = $12;
    if (($12 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx4_val = HEAP32[$12 + 4 >> 2];
    var $16 = __ZNK8JSObject5isXMLEv($_idx4_val);
    if ($16) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $18 = $cx;
    _JS_ReportErrorNumber($18, 4, 272, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 16;
    break;
   case 9:
    var $vp_idx = $vp | 0;
    var $st$1$0 = $vp_idx | 0;
    var $vp_idx_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $vp_idx + 4 | 0;
    var $vp_idx_val$1 = HEAP32[$st$1$1 >> 2];
    var $20 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
    var $21 = $20;
    var $22 = __ZNK8JSObject9getGlobalEv($21);
    var $23 = $22 | 0;
    var $24 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2514($cx, $13, $23);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $27 = $24;
    __ZN2JS5Value9setObjectER8JSObject($vp, $27);
    var $_idx3_val = HEAP32[$24 + 36 >> 2];
    var $29 = __ZNK8JSObject4typeEv($_idx3_val);
    var $30 = $cx;
    __ZN2js5types31MarkTypeObjectUnknownPropertiesEP9JSContextPNS0_10TypeObjectEb($30, $29, 0);
    if ($argc >>> 0 > 1) {
      __label__ = 11;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 11:
    var $_idx1 = $vp + 24 | 0;
    var $st$1$0 = $_idx1 | 0;
    var $_idx1_val$0 = HEAPU32[$st$1$0 >> 2];
    var $st$1$1 = $_idx1 + 4 | 0;
    var $_idx1_val$1 = HEAPU32[$st$1$1 >> 2];
    var $33 = __ZNK2JS5Value11isUndefinedEv($_idx1_val$0, $_idx1_val$1);
    if ($33) {
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $35 = __ZNK2JS5Value11isPrimitiveEv($_idx1_val$0, $_idx1_val$1);
    if ($35) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    _JS_ReportErrorNumber($30, 4, 231, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 16;
    break;
   case 14:
    var $38 = __ZNK2JS5Value8toObjectEv($_idx1_val$0, $_idx1_val$1);
    var $39 = $38;
    var $40 = __ZL16DefinePropertiesP9JSContextP8JSObjectS2_($cx, $24, $39);
    if ($40) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 15:
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10obj_createP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL23obj_getOwnPropertyNamesP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 164;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $keys = __stackBase__ + 4;
    var $vals = __stackBase__ + 64;
    var $1 = __stackBase__ + 156;
    var $2 = __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, STRING_TABLE.__str392242 | 0, $obj);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_2 = 0;
      __label__ = 17;
      break;
    }
   case 2:
    var $4 = $keys;
    var $5 = $cx;
    __ZN2js12AutoIdVectorC1EP9JSContext($4, $5);
    var $7 = $cx;
    var $8 = HEAP32[$obj >> 2];
    var $9 = $keys;
    var $10 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($7, $8, 24, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 0;
      __label__ = 16;
      break;
    }
   case 3:
    var $12 = $vals;
    __ZN2js15AutoValueVectorC1EP9JSContext($12, $5);
    var $13 = $keys;
    var $14 = __ZNK2js16AutoVectorRooterIiE6lengthEv($13);
    var $15 = $vals;
    var $16 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6resizeEj($15, $14);
    if ($16) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 4:
    var $18 = __ZNK2js16AutoVectorRooterIiE6lengthEv($13);
    var $19 = $cx;
    var $_idx = $1 | 0;
    var $i_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_0;
    if ($i_0 >>> 0 < $18 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 6:
    var $23 = __ZN2js16AutoVectorRooterIiEixEj($13, $i_0);
    var $24 = HEAPU32[$23 >> 2];
    var $25 = _JSID_IS_INT2487($24);
    if (($25 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $28 = _JSID_TO_INT2488($24);
    __ZN2JSL10Int32ValueEi2332($1, $28);
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $29 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($19, $_idx_val$0, $_idx_val$1);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $32 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($15, $i_0);
    __ZN2JS5Value9setStringEP8JSString($32, $29);
    __label__ = 12;
    break;
   case 9:
    var $34 = __ZL12JSID_IS_ATOMi2511($24);
    var $35 = ($34 | 0) == 0;
    var $36 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($15, $i_0);
    if ($35) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = _JSID_TO_STRING2421($24);
    __ZN2JS5Value9setStringEP8JSString($36, $38);
    __label__ = 12;
    break;
   case 11:
    var $40 = _JSID_TO_OBJECT2490($24);
    var $41 = $40;
    __ZN2JS5Value9setObjectER8JSObject($36, $41);
    __label__ = 12;
    break;
   case 12:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 5;
    break;
   case 13:
    var $45 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($15);
    var $46 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($15);
    var $47 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($5, $45, $46);
    if (($47 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZN2JS5Value9setObjectER8JSObject($vp, $47);
    var $_0 = 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($12);
    var $_1 = $_0;
    __label__ = 16;
    break;
   case 16:
    var $_1;
    __ZN2js12AutoIdVectorD1Ev($4);
    var $_2 = $_1;
    __label__ = 17;
    break;
   case 17:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL23obj_getOwnPropertyNamesP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL16obj_isExtensibleP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, STRING_TABLE.__str382241 | 0, $obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[HEAP32[$obj >> 2] + 8 >> 2];
    var $5 = __ZNK8JSObject12isExtensibleEv($_idx_val);
    __ZN2JS5Value10setBooleanEb($vp, $5);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21obj_preventExtensionsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $props = __stackBase__ + 4;
    var $1 = __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, STRING_TABLE.__str362239 | 0, $obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = HEAP32[$obj >> 2];
    var $4 = $3;
    __ZN2JS5Value9setObjectER8JSObject($vp, $4);
    var $_idx_val = HEAP32[$3 + 8 >> 2];
    var $6 = __ZNK8JSObject12isExtensibleEv($_idx_val);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = $cx;
    __ZN2js12AutoIdVectorC1EP9JSContext($props, $8);
    var $9 = __ZN8JSObject17preventExtensionsEP9JSContextPN2js12AutoIdVectorE($4, $8, $props);
    var $10 = $9 & 1;
    __ZN2js12AutoIdVectorD1Ev($props);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10obj_freezeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, STRING_TABLE.__str372240 | 0, $obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$obj >> 2];
    __ZN2JS5Value9setObjectER8JSObject($vp, $4);
    var $5 = $cx;
    var $6 = __ZN8JSObject6freezeEP9JSContext($4, $5);
    var $_0 = $6 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12obj_isFrozenP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $frozen = __stackBase__ + 4;
    var $1 = __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, STRING_TABLE.__str362239 | 0, $obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = HEAP32[$obj >> 2];
    var $5 = $cx;
    var $6 = __ZN8JSObject8isFrozenEP9JSContextPb($4, $5, $frozen);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = (HEAP8[$frozen] & 1) << 24 >> 24 != 0;
    __ZN2JS5Value10setBooleanEb($vp, $10);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8obj_sealP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, STRING_TABLE.__str352238 | 0, $obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$obj >> 2];
    __ZN2JS5Value9setObjectER8JSObject($vp, $4);
    var $5 = $cx;
    var $6 = __ZN8JSObject4sealEP9JSContext($4, $5);
    var $_0 = $6 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12obj_isSealedP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $sealed = __stackBase__ + 4;
    var $1 = __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, STRING_TABLE.__str322235 | 0, $obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = HEAP32[$obj >> 2];
    var $5 = $cx;
    var $6 = __ZN8JSObject8isSealedEP9JSContextPb($4, $5, $sealed);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = (HEAP8[$sealed] & 1) << 24 >> 24 != 0;
    __ZN2JS5Value10setBooleanEb($vp, $10);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z9js_ObjectP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$obj >> 2] = 0;
    __label__ = 5;
    break;
   case 3:
    var $3 = $vp + 16 | 0;
    var $4 = __Z22js_ValueToObjectOrNullP9JSContextRKN2JS5ValueEPP8JSObject($cx, $3, $obj);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_pr = HEAP32[$obj >> 2];
    if (($_pr | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $19 = $_pr;
      __label__ = 8;
      break;
    }
   case 5:
    var $9 = __ZN2jsL15NewObjectGCKindEP9JSContextPNS_5ClassE(__ZN2js11ObjectClassE);
    var $10 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2318($cx, __ZN2js11ObjectClassE, $9);
    HEAP32[$obj >> 2] = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $13 = $cx;
    var $14 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($13, 1);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $17 = $10;
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($17, $14);
    var $19 = $10;
    __label__ = 8;
    break;
   case 8:
    var $19;
    __ZN2JS5Value9setObjectER8JSObject($vp, $19);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z22js_ValueToObjectOrNullP9JSContextRKN2JS5ValueEPP8JSObject($cx, $v, $objp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx2 = $v | 0;
    var $v_idx2_val$0 = HEAP32[$v_idx2 >> 2];
    var $v_idx2_val$1 = HEAP32[$v_idx2 + 4 >> 2];
    var $1 = __ZNK2JS5Value14isObjectOrNullEv($v_idx2_val$0, $v_idx2_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value14toObjectOrNullEv($v_idx2_val$0, $v_idx2_val$1);
    var $obj_0 = $3;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZNK2JS5Value11isUndefinedEv($v_idx2_val$0, $v_idx2_val$1);
    if ($6) {
      var $obj_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __Z17PrimitiveToObjectP9JSContextRKN2JS5ValueE($cx, $v);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      var $obj_0 = $8;
      __label__ = 5;
      break;
    }
   case 5:
    var $obj_0;
    HEAP32[$objp >> 2] = $obj_0;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2318($cx, $clasp, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $4 = HEAPU32[$clasp + 4 >> 2] >>> 24;
    var $5 = $cx;
    var $6 = __ZNK9JSContext5hasfpEv($5);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $9;
    var $10 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($cx, $global);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $18 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZNK9JSContext2fpEv($5);
    var $13 = __ZNK2js10StackFrame10scopeChainEv($12);
    var $14 = $13;
    var $15 = __ZNK8JSObject9getGlobalEv($14);
    var $16 = $15 | 0;
    HEAP32[$global >> 2] = $16;
    var $18 = $16;
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = $4 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $18, $19);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $21 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $23 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $24 = $23;
    HEAP32[$proto >> 2] = $24;
    var $28 = $24;
    __label__ = 9;
    break;
   case 7:
    var $26 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($cx, $18, $4, $proto, $clasp);
    if ($26) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $28 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $28;
    var $29 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2510($cx, $clasp, $28, $18, $kind);
    var $_0 = $29;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17NewReshapedObjectEP9JSContextPNS_5types10TypeObjectEP8JSObjectNS_2gc9AllocKindEPKNS_5ShapeE($cx, $type, $parent, $kind, $shape) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 68;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ids = __stackBase__;
    var $1 = __stackBase__ + 60;
    var $2 = __ZN2jsL17NewObjectWithTypeEP9JSContextPNS_5types10TypeObjectEP8JSObjectNS_2gc9AllocKindE($cx, $type, $parent, $kind);
    if (($2 | 0) == 0) {
      var $_1 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $shape + 12 | 0;
    var $6 = HEAP32[$5 >> 2];
    var $7 = _JSID_IS_EMPTY2321($6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_1 = $2;
      __label__ = 15;
      break;
    }
   case 3:
    var $10 = $ids;
    var $11 = $cx;
    __ZN2js12AutoIdVectorC1EP9JSContext($10, $11);
    var $12 = $shape + 24 | 0;
    var $13 = $ids;
    var $i_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_0;
    var $15 = HEAPU32[$12 >> 2];
    if ($i_0 >>> 0 > $15 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $17 = HEAPU32[$5 >> 2];
    var $18 = _JSID_IS_EMPTY2321($17);
    var $20 = $ids;
    if (($18 | 0) == 0) {
      var $nshape_02 = $shape;
      var $26 = $17;
      var $25 = $15;
      __label__ = 9;
      break;
    } else {
      var $_pre_phi = $20;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = __ZN2js16AutoVectorRooterIiE6appendERKi($13, 2);
    if ($22) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 4;
    break;
   case 8:
    var $_pre_phi;
    var $i1_0 = 0;
    __label__ = 11;
    break;
   case 9:
    var $25;
    var $26;
    var $nshape_02;
    var $27 = __ZN2js16AutoVectorRooterIiEixEj($20, $25);
    HEAP32[$27 >> 2] = $26;
    var $_idx_val = HEAP32[$nshape_02 + 32 >> 2];
    var $29 = __ZNK2js5Shape8previousEv($_idx_val);
    var $31 = HEAP32[$29 + 12 >> 2];
    var $32 = _JSID_IS_EMPTY2321($31);
    if (($32 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_pre_phi = $20;
      __label__ = 8;
      break;
    }
   case 10:
    var $_pre = HEAP32[$29 + 24 >> 2];
    var $nshape_02 = $29;
    var $26 = $31;
    var $25 = $_pre;
    __label__ = 9;
    break;
   case 11:
    var $i1_0;
    var $37 = __ZNK2js16AutoVectorRooterIiE6lengthEv($_pre_phi);
    if ($i1_0 >>> 0 < $37 >>> 0) {
      __label__ = 12;
      break;
    } else {
      var $_0 = $2;
      __label__ = 14;
      break;
    }
   case 12:
    var $40 = __ZN2js16AutoVectorRooterIiEixEj($_pre_phi, $i1_0);
    var $41 = HEAP32[$40 >> 2];
    __ZN2JSL14UndefinedValueEv2280($1);
    var $42 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($cx, $2, $41, $1, 0, 0, 1, 0, 0, 16);
    if (($42 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 11;
    break;
   case 14:
    var $_0;
    __ZN2js12AutoIdVectorD1Ev($10);
    var $_1 = $_0;
    __label__ = 15;
    break;
   case 15:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js17NewReshapedObjectEP9JSContextPNS_5types10TypeObjectEP8JSObjectNS_2gc9AllocKindEPKNS_5ShapeE["X"] = 1;

function _JSID_IS_EMPTY2321($iden) {
  return ($iden | 0) == 4 & 1;
}

function __ZN2jsL17NewObjectWithTypeEP9JSContextPNS_5types10TypeObjectEP8JSObjectNS_2gc9AllocKindE($cx, $type, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($1, $kind);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $obj_0 = $3;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($parent | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $16 = $parent;
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = HEAP32[$type >> 2];
    if (($9 | 0) == 0) {
      var $16 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$9 + 20 >> 2];
    var $13 = __ZNK8JSObject9getParentEv($_idx_val);
    var $16 = $13;
    __label__ = 5;
    break;
   case 5:
    var $16;
    var $17 = $type;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($2, __ZN2js11ObjectClassE, $17, $16, 0, 0);
    var $19 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2468($cx, $3, __ZN2js11ObjectClassE, $type, $kind);
    if ($19) {
      var $obj_0 = $3;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $obj_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $obj_0;
    return $obj_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($cx, $obj, $id, $value, $getter, $setter, $attrs, $flags, $shortid, $defineHow) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $valueCopy = __stackBase__ + 12;
    var $2 = __stackBase__ + 20;
    var $3 = __Z22js_CheckForStringIndexi($id);
    if (($attrs & 48 | 0) == 0) {
      var $shape_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js5types4Type11UnknownTypeEv($1);
    var $7 = $cx;
    var $8 = $obj;
    var $_07_val = HEAP32[$1 >> 2];
    __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiNS0_4TypeE($7, $8, $3, $_07_val);
    __ZN2js5types26MarkTypePropertyConfiguredEP9JSContextP8JSObjecti($7, $8, $3);
    var $9 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $3, $pobj, $prop);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAP32[$prop >> 2];
    if (($12 | 0) == 0) {
      var $shape_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP32[$pobj >> 2] | 0) == ($obj | 0)) {
      __label__ = 5;
      break;
    } else {
      var $shape_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $18 = $12;
    var $_idx8_val = HEAP8[$18 + 28 | 0];
    var $19 = __ZNK2js5Shape20isAccessorDescriptorEv($_idx8_val);
    if ($19) {
      __label__ = 6;
      break;
    } else {
      var $shape_0 = 0;
      __label__ = 11;
      break;
    }
   case 6:
    if (($attrs & 16 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $27 = $getter;
      __label__ = 8;
      break;
    }
   case 7:
    var $_idx2_val = HEAP32[$18 + 16 >> 2];
    var $24 = __ZNK2js5Shape6getterEv($_idx2_val);
    var $27 = $24;
    __label__ = 8;
    break;
   case 8:
    var $27;
    if (($attrs & 32 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $34 = $setter;
      __label__ = 10;
      break;
    }
   case 9:
    var $_idx3_val = HEAP32[$18 + 20 >> 2];
    var $31 = __ZNK2js5Shape6setterEv($_idx3_val);
    var $34 = $31;
    __label__ = 10;
    break;
   case 10:
    var $34;
    var $37 = __ZN8JSObject14changePropertyEP9JSContextPKN2js5ShapeEjjPFiS1_PS_iPN2JS5ValueEEPFiS1_S6_iiS9_E($8, $7, $18, $attrs, 48, $27, $34);
    var $38 = $37;
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      var $shape_0 = $38;
      __label__ = 11;
      break;
    }
   case 11:
    var $shape_0;
    if (($defineHow & 2 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $_pre_phi = $obj;
    __label__ = 14;
    break;
   case 13:
    var $44 = $cx;
    var $45 = $obj;
    __Z18js_PurgeScopeChainP9JSContextP8JSObjecti($44, $45, $3);
    var $_pre_phi = $45;
    __label__ = 14;
    break;
   case 14:
    var $_pre_phi;
    var $47 = $obj + 8 | 0;
    var $_idx9_val = HEAP32[$47 >> 2];
    var $48 = __ZNK8JSObject10isDelegateEv($_idx9_val);
    if ($48) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    if (($attrs & 34 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $_idx6 = $cx + 52 | 0;
    var $_idx6_val = HEAP32[$_idx6 >> 2];
    var $54 = __Z16js_GenerateShapeP9JSContext($_idx6_val);
    var $56 = HEAP32[$_idx6 >> 2] + 44 | 0;
    HEAP32[$56 >> 2] = $54;
    __label__ = 17;
    break;
   case 17:
    var $_idx1_val = HEAP32[$obj + 4 >> 2];
    var $59 = __ZNK8JSObject8getClassEv($_idx1_val);
    var $61 = ($defineHow & 4 | 0) != 0;
    if ($61) {
      var $_1 = $getter;
      var $_03 = $setter;
      __label__ = 24;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if (($getter | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      var $_02 = $getter;
      __label__ = 21;
      break;
    }
   case 19:
    if (($attrs & 16 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      var $_02 = 0;
      __label__ = 21;
      break;
    }
   case 20:
    var $_02 = HEAP32[$59 + 16 >> 2];
    __label__ = 21;
    break;
   case 21:
    var $_02;
    if (($setter | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      var $_1 = $_02;
      var $_03 = $setter;
      __label__ = 24;
      break;
    }
   case 22:
    if (($attrs & 32 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      var $_1 = $_02;
      var $_03 = 0;
      __label__ = 24;
      break;
    }
   case 23:
    var $_1 = $_02;
    var $_03 = HEAP32[$59 + 20 >> 2];
    __label__ = 24;
    break;
   case 24:
    var $_03;
    var $_1;
    var $84 = $cx;
    if (($61 | ($_1 | 0) == 10) & ($defineHow & 16 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      var $_pre_phi18 = $84;
      __label__ = 27;
      break;
    }
   case 25:
    __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiRKN2JS5ValueE($84, $_pre_phi, $3, $value);
    if (($attrs & 2 | 0) == 0) {
      var $_pre_phi18 = $84;
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    __ZN2js5types26MarkTypePropertyConfiguredEP9JSContextP8JSObjecti($84, $_pre_phi, $3);
    var $_pre_phi18 = $84;
    __label__ = 27;
    break;
   case 27:
    var $_pre_phi18;
    var $89 = __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($_pre_phi, $_pre_phi18);
    if ($89) {
      __label__ = 28;
      break;
    } else {
      var $_0 = 0;
      __label__ = 48;
      break;
    }
   case 28:
    var $91 = $value | 0;
    var $92$0 = HEAP32[$91 >> 2];
    var $92$1 = HEAP32[$91 + 4 >> 2];
    var $93 = $valueCopy | 0;
    HEAP32[$93 >> 2] = $92$0;
    HEAP32[$93 + 4 >> 2] = $92$1;
    if (($shape_0 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      var $adding_1 = 0;
      var $shape_1 = $shape_0;
      __label__ = 41;
      break;
    }
   case 29:
    if ($61) {
      __label__ = 30;
      break;
    } else {
      var $_01 = $flags;
      var $_2 = $_1;
      __label__ = 32;
      break;
    }
   case 30:
    var $97 = __ZNK2JS5Value8toObjectEv($92$0, $92$1);
    var $_idx_val = HEAP32[$97 + 24 >> 2];
    var $98 = __ZNK8JSObject18getFunctionPrivateEv($_idx_val);
    if (($98 | 0) == ($97 | 0)) {
      __label__ = 31;
      break;
    } else {
      var $_01 = $flags;
      var $_2 = $_1;
      __label__ = 32;
      break;
    }
   case 31:
    var $102 = $97;
    var $103 = $flags | 128;
    var $104 = __ZN2jsL16CastAsPropertyOpEP8JSObject2286($102);
    var $_01 = $103;
    var $_2 = $104;
    __label__ = 32;
    break;
   case 32:
    var $_2;
    var $_01;
    var $106 = __ZN8JSObject12nativeLookupEP9JSContexti($_pre_phi, $_pre_phi18, $3);
    if (($106 | 0) == 0) {
      var $adding_0 = 1;
      __label__ = 36;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $_idx4_val = HEAP8[$106 + 29 | 0];
    var $109 = __ZNK2js5Shape8isMethodEv($_idx4_val);
    if ($109) {
      __label__ = 34;
      break;
    } else {
      var $adding_0 = 0;
      __label__ = 36;
      break;
    }
   case 34:
    var $111 = __ZNK2js5Shape12methodObjectEv($106);
    var $112 = $111;
    __ZN2JSL11ObjectValueER8JSObject2354($2, $112);
    var $_idx10 = $2 | 0;
    var $_idx10_val$0 = HEAP32[$_idx10 >> 2];
    var $_idx10_val$1 = HEAP32[$_idx10 + 4 >> 2];
    var $valueCopy_idx_val$0 = HEAP32[$93 >> 2];
    var $valueCopy_idx_val$1 = HEAP32[$93 + 4 >> 2];
    var $113 = __ZNK2JS5ValueeqERKS0_($_idx10_val$0, $_idx10_val$1, $valueCopy_idx_val$0, $valueCopy_idx_val$1);
    if ($113) {
      __label__ = 35;
      break;
    } else {
      var $adding_0 = 0;
      __label__ = 36;
      break;
    }
   case 35:
    var $115 = __ZN8JSObject17methodReadBarrierEP9JSContextRKN2js5ShapeEPN2JS5ValueE($_pre_phi, $_pre_phi18, $106, $valueCopy);
    if (($115 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      var $adding_0 = 0;
      __label__ = 36;
      break;
    }
   case 36:
    var $adding_0;
    var $118 = $obj + 12 | 0;
    var $_idx14_val = HEAP32[$118 >> 2];
    var $121 = __ZN8JSObject11putPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji($_pre_phi, $_pre_phi18, $3, $_2, $_03, -1, $attrs, $_01, $shortid);
    var $122 = $121;
    if (($121 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $125 = __ZNK8JSObject5shapeEv($_idx14_val);
    var $_idx13_val = HEAP32[$118 >> 2];
    var $126 = __ZNK8JSObject5shapeEv($_idx13_val);
    if (($126 | 0) == ($125 | 0)) {
      __label__ = 38;
      break;
    } else {
      var $adding_1 = $adding_0;
      var $shape_1 = $122;
      __label__ = 41;
      break;
    }
   case 38:
    var $_idx11_val = HEAP32[$47 >> 2];
    var $129 = __ZN8JSObject7brandedEv($_idx11_val);
    if ($129) {
      __label__ = 39;
      break;
    } else {
      var $adding_1 = $adding_0;
      var $shape_1 = $122;
      __label__ = 41;
      break;
    }
   case 39:
    if ((HEAP32[$121 + 24 >> 2] | 0) == -1) {
      var $adding_1 = $adding_0;
      var $shape_1 = $122;
      __label__ = 41;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $135 = __ZN8JSObject18methodWriteBarrierEP9JSContextRKN2js5ShapeERKN2JS5ValueE($obj, $cx, $122, $valueCopy);
    var $adding_1 = $adding_0;
    var $shape_1 = $122;
    __label__ = 41;
    break;
   case 41:
    var $shape_1;
    var $adding_1;
    var $138 = HEAP32[$shape_1 + 24 >> 2];
    var $_idx5_val_idx_val = HEAP32[HEAP32[$obj >> 2] + 4 >> 2];
    var $139 = __ZNK8JSObject12containsSlotEj($_idx5_val_idx_val, $138);
    if ($139) {
      __label__ = 42;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 42:
    var $valueCopy_idx12_val$0 = HEAP32[$93 >> 2];
    var $valueCopy_idx12_val$1 = HEAP32[$93 + 4 >> 2];
    __ZN8JSObject13nativeSetSlotEjRKN2JS5ValueE($_pre_phi, $138, $valueCopy_idx12_val$0, $valueCopy_idx12_val$1);
    __label__ = 43;
    break;
   case 43:
    var $_idx15_val = HEAP32[$59 + 8 >> 2];
    var $143 = __ZL19CallAddPropertyHookP9JSContextPN2js5ClassEP8JSObjectPKNS1_5ShapeEPN2JS5ValueE($cx, $_idx15_val, $obj, $shape_1, $valueCopy);
    if ($143) {
      __label__ = 45;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $145 = __ZN8JSObject14removePropertyEP9JSContexti($_pre_phi, $_pre_phi18, $3);
    var $_0 = 0;
    __label__ = 48;
    break;
   case 45:
    if (($defineHow & 1 | 0) == 0) {
      var $_0 = $shape_1;
      __label__ = 48;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    if (($adding_1 & 1) << 24 >> 24 == 0) {
      var $_0 = $shape_1;
      __label__ = 48;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $156 = HEAP32[$cx + 52 >> 2] + 144336 | 0;
    var $158 = __ZN2js13PropertyCache4fillEP9JSContextP8JSObjectjS4_PKNS_5ShapeEi($156, $_pre_phi18, $_pre_phi, 0, $_pre_phi, $shape_1, 1);
    var $_0 = $shape_1;
    __label__ = 48;
    break;
   case 48:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij["X"] = 1;

function __Z13js_CreateThisP9JSContextP8JSObject($cx, $callee) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $protov = __stackBase__;
    var $1 = $callee;
    var $_idx2_val = HEAP32[$callee + 4 >> 2];
    var $3 = __ZNK8JSObject8getClassEv($_idx2_val);
    if (($3 | 0) == (__ZN2js13FunctionClassE | 0)) {
      __label__ = 2;
      break;
    } else {
      var $newclasp_0 = __ZN2js11ObjectClassE;
      __label__ = 5;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$callee + 24 >> 2];
    var $7 = __ZNK8JSObject18getFunctionPrivateEv($_idx_val);
    var $8 = $7;
    var $9 = __ZNK10JSFunction8isNativeEv($8);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $newclasp_0 = __ZN2js11ObjectClassE;
      __label__ = 5;
      break;
    }
   case 3:
    var $12 = HEAP32[$7 + 64 >> 2];
    if (($12 | 0) == 0) {
      var $newclasp_0 = __ZN2js11ObjectClassE;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $newclasp_0 = $12;
    __label__ = 5;
    break;
   case 5:
    var $newclasp_0;
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210200 >> 2];
    var $21 = $cx;
    var $22 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($1, $21, $20, $protov);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $protov_idx3 = $protov | 0;
    var $protov_idx3_val$0 = HEAP32[$protov_idx3 >> 2];
    var $protov_idx3_val$1 = HEAP32[$protov_idx3 + 4 >> 2];
    var $25 = __ZNK2JS5Value14isObjectOrNullEv($protov_idx3_val$0, $protov_idx3_val$1);
    if ($25) {
      __label__ = 7;
      break;
    } else {
      var $30 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $27 = __ZNK2JS5Value14toObjectOrNullEv($protov_idx3_val$0, $protov_idx3_val$1);
    var $30 = $27;
    __label__ = 8;
    break;
   case 8:
    var $30;
    var $_idx1_val = HEAP32[$callee + 20 >> 2];
    var $32 = __ZNK8JSObject9getParentEv($_idx1_val);
    var $33 = $32;
    var $34 = __ZN2jsL15NewObjectGCKindEP9JSContextPNS_5ClassE($newclasp_0);
    var $35 = __ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE2326($cx, $newclasp_0, $30, $33, $34);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $38 = $35;
    __ZN8JSObject19syncSpecialEqualityEv($38);
    var $_0 = $35;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z13js_CreateThisP9JSContextP8JSObject["X"] = 1;

function __ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE2326($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($clasp | 0) == (__ZN2js13FunctionClassE | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detailL9NewObjectILb0ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2471($cx, __ZN2js13FunctionClassE, $proto, $parent, $kind);
    var $_0 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2469($cx, $clasp, $proto, $parent, $kind);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z33js_CreateThisForFunctionWithProtoP9JSContextP8JSObjectS2_($cx, $callee, $proto) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($proto | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$callee + 24 >> 2];
    var $5 = __ZNK8JSObject18getFunctionPrivateEv($_idx1_val);
    var $6 = $proto;
    var $7 = $cx;
    var $8 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($6, $7, $5, 0);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = $8;
    var $_idx3_val = HEAP32[$callee + 20 >> 2];
    var $13 = __ZNK8JSObject9getParentEv($_idx3_val);
    var $14 = $13;
    var $15 = __ZL29CreateThisForFunctionWithTypeP9JSContextPN2js5types10TypeObjectEP8JSObject($cx, $11, $14);
    var $res_0 = $15;
    __label__ = 5;
    break;
   case 4:
    var $17 = __ZN2jsL15NewObjectGCKindEP9JSContextPNS_5ClassE(__ZN2js11ObjectClassE);
    var $_idx2_val = HEAP32[$callee + 20 >> 2];
    var $19 = __ZNK8JSObject9getParentEv($_idx2_val);
    var $20 = $19;
    var $21 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE($cx, 0, $20, $17);
    var $res_0 = $21;
    __label__ = 5;
    break;
   case 5:
    var $res_0;
    if (($res_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx4_val = HEAP8[$cx + 232 | 0];
    var $26 = __ZN9JSContext20typeInferenceEnabledEv($_idx4_val);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $_0 = $res_0;
      __label__ = 8;
      break;
    }
   case 7:
    var $28 = $cx;
    var $_idx_val = HEAP32[$callee + 24 >> 2];
    var $30 = __ZNK8JSObject18getFunctionPrivateEv($_idx_val);
    var $31 = __ZNK10JSFunction6scriptEv($30);
    __ZN2js5types4Type10ObjectTypeEP8JSObject($1, $res_0);
    var $_05_val = HEAP32[$1 >> 2];
    __ZN2js5types10TypeScript7SetThisEP9JSContextP8JSScriptNS0_4TypeE($28, $31, $_05_val);
    var $_0 = $res_0;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL29CreateThisForFunctionWithTypeP9JSContextPN2js5types10TypeObjectEP8JSObject($cx, $type, $parent) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $type + 16 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$2 + 4 >> 2];
    var $7 = __ZN2jsL17NewObjectWithTypeEP9JSContextPNS_5types10TypeObjectEP8JSObjectNS_2gc9AllocKindE($cx, $type, $parent, $6);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = $7;
    var $14 = HEAP32[HEAP32[$1 >> 2] + 8 >> 2];
    __ZN8JSObject6setMapEPN2js5ShapeE($13, $14);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 4:
    var $16 = __ZN2jsL15NewObjectGCKindEP9JSContextPNS_5ClassE(__ZN2js11ObjectClassE);
    var $17 = __ZN2jsL17NewObjectWithTypeEP9JSContextPNS_5types10TypeObjectEP8JSObjectNS_2gc9AllocKindE($cx, $type, $parent, $16);
    var $_0 = $17;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE($cx, $proto, $parent, $kind) {
  var $1 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2469($cx, __ZN2js11ObjectClassE, $proto, $parent, $kind);
  return $1;
}

function __Z24js_CreateThisForFunctionP9JSContextP8JSObjectb($cx, $callee, $newType) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $protov = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210200 >> 2];
    var $6 = $callee;
    var $7 = $cx;
    var $8 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($6, $7, $5, $protov);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $protov_idx = $protov | 0;
    var $protov_idx_val$0 = HEAP32[$protov_idx >> 2];
    var $protov_idx_val$1 = HEAP32[$protov_idx + 4 >> 2];
    var $11 = __ZNK2JS5Value8isObjectEv($protov_idx_val$0, $protov_idx_val$1);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $proto_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $13 = __ZNK2JS5Value8toObjectEv($protov_idx_val$0, $protov_idx_val$1);
    var $proto_0 = $13;
    __label__ = 4;
    break;
   case 4:
    var $proto_0;
    var $16 = __Z33js_CreateThisForFunctionWithProtoP9JSContextP8JSObjectS2_($cx, $callee, $proto_0);
    if (($16 | 0) == 0 | $newType ^ 1) {
      var $_0 = $16;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = $16;
    __ZN8JSObject5clearEP9JSContext($19, $7);
    var $20 = $16;
    var $21 = $cx;
    __ZN8JSObject16setSingletonTypeEP9JSContext($20, $21);
    var $_idx_val = HEAP32[$callee + 24 >> 2];
    var $23 = __ZNK8JSObject18getFunctionPrivateEv($_idx_val);
    var $24 = __ZNK10JSFunction6scriptEv($23);
    __ZN2js5types4Type10ObjectTypeEP8JSObject($1, $19);
    var $_02_val = HEAP32[$1 >> 2];
    __ZN2js5types10TypeScript7SetThisEP9JSContextP8JSScriptNS0_4TypeE($7, $24, $_02_val);
    var $_0 = $16;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z9DetectingP9JSContextPh($cx, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $cx + 60 | 0;
    var $3 = __ZNK2js12ContextStack13currentScriptEPPh($2, 0);
    var $4 = $3;
    var $5 = $3 | 0;
    var $7 = $3 + 8 | 0;
    var $9 = HEAP32[$5 >> 2] + HEAP32[$7 >> 2] | 0;
    var $_04 = $pc;
    __label__ = 2;
    break;
   case 2:
    var $_04;
    var $11 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2329($4, $_04);
    var $12 = _js_CodeSpec + ($11 << 3) | 0;
    var $14 = HEAPU32[_js_CodeSpec + ($11 << 3) + 4 >> 2];
    if (($14 & 16384 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 17;
      break;
    }
   case 3:
    if (($11 | 0) == 64) {
      __label__ = 4;
      break;
    } else if (($11 | 0) == 156 || ($11 | 0) == 59) {
      __label__ = 6;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 4:
    var $19 = $_04 + 1 | 0;
    if ($19 >>> 0 < $9 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 5:
    var $22 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2329($4, $19);
    var $_0 = (HEAP8[$19] - 18 & 255 & 255) < 2 & 1;
    __label__ = 17;
    break;
   case 6:
    var $27 = _js_GetIndexFromBytecode($3, $_04, 0);
    var $28 = HEAPU32[$5 >> 2];
    if ($_04 >>> 0 < $28 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($28 + HEAP32[$7 >> 2] | 0) >>> 0 > $_04 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $36 = HEAPU32[$cx + 52 >> 2];
    var $37 = $36 + 209948 | 0;
    var $38 = __ZN11JSAtomState16commonAtomsStartEv($37);
    var $atom_0 = HEAP32[$38 + ($27 << 2) >> 2];
    var $44 = $36;
    __label__ = 10;
    break;
   case 9:
    var $_idx_val = HEAP32[$3 + 56 >> 2];
    var $42 = __ZN8JSScript7getAtomEj($_idx_val, $27);
    var $atom_0 = $42;
    var $44 = HEAP32[$cx + 52 >> 2];
    __label__ = 10;
    break;
   case 10:
    var $44;
    var $atom_0;
    if (($atom_0 | 0) == (HEAP32[$44 + 209984 >> 2] | 0)) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 11:
    var $53 = $_04 + (HEAP8[$12 | 0] << 24 >> 24) | 0;
    if ($53 >>> 0 < $9 >>> 0) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 12:
    var $56 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2329($4, $53);
    if (($56 - 18 | 0) >>> 0 < 2 | ($56 | 0) == 72) {
      var $62 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $62 = ($56 | 0) == 73;
    __label__ = 14;
    break;
   case 14:
    var $62;
    var $_0 = $62 & 1;
    __label__ = 17;
    break;
   case 15:
    if (($14 & 262144 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $_04 = $_04 + (HEAP8[$12 | 0] << 24 >> 24) | 0;
    __label__ = 2;
    break;
   case 17:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z9DetectingP9JSContextPh["X"] = 1;

function __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2329($script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU8[$pc];
    var $2 = $1 & 255;
    if ($1 << 24 >> 24 == 83) {
      __label__ = 2;
      break;
    } else {
      var $op_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $script;
    var $6 = _JS_GetTrapOpcode($5, $pc);
    var $op_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $op_0;
    return $op_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z13js_InferFlagsP9JSContextj($cx, $defaultFlags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pc = __stackBase__;
    var $2 = $cx + 60 | 0;
    var $3 = __ZNK2js12ContextStack13currentScriptEPPh($2, $pc);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = $defaultFlags;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$pc >> 2];
    if (($7 | 0) == 0) {
      var $_0 = $defaultFlags;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2329($4, $7);
    var $12 = HEAPU32[_js_CodeSpec + ($10 << 3) + 4 >> 2];
    var $flags_0 = ($12 & 224 | 0) != 32 & 1;
    if (($12 & 8448 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $flags_1 = $flags_0 | 2;
    __label__ = 8;
    break;
   case 5:
    var $20 = HEAP8[_js_CodeSpec + ($10 << 3) | 0];
    if ($20 << 24 >> 24 > -1) {
      __label__ = 6;
      break;
    } else {
      var $flags_1 = $flags_0;
      __label__ = 8;
      break;
    }
   case 6:
    var $25 = HEAP32[$pc >> 2] + ($20 << 24 >> 24) | 0;
    HEAP32[$pc >> 2] = $25;
    if ($25 >>> 0 < (HEAP32[$3 >> 2] + HEAP32[$3 + 8 >> 2] | 0) >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $flags_1 = $flags_0;
      __label__ = 8;
      break;
    }
   case 7:
    var $33 = __Z9DetectingP9JSContextPh($cx, $25);
    var $flags_0_ = ($33 | 0) == 0 ? $flags_0 : $flags_0 | 4;
    var $flags_1 = $flags_0_;
    __label__ = 8;
    break;
   case 8:
    var $flags_1;
    var $flags_2 = ($12 & 131072 | 0) == 0 ? $flags_1 : $flags_1 | 8;
    var $_0 = $flags_2;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19with_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $id, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $rf = __stackBase__;
    var $2 = HEAP32[$cx + 208 >> 2];
    if (($2 | 0) == 65535) {
      __label__ = 2;
      break;
    } else {
      var $flags_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __Z13js_InferFlagsP9JSContextj($cx, 65535);
    var $flags_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $flags_0;
    var $8 = $cx;
    __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $8, $flags_0 | 32);
    var $_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $10 = __ZNK8JSObject8getProtoEv($_idx_val_idx_val);
    var $11 = $objp;
    var $12 = $propp;
    var $13 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($10, $8, $id, $11, $12);
    var $rf_idx_val = HEAP32[$rf >> 2];
    var $rf_idx1_val = HEAP32[$rf + 4 >> 2];
    __ZN18JSAutoResolveFlagsD1Ev($rf_idx_val, $rf_idx1_val);
    STACKTOP = __stackBase__;
    return $13;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18with_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty($cx, $obj, $index, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL19with_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $4, $objp, $propp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18with_LookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty($cx, $obj, $sid, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE2500($sid_idx_val);
  var $2 = __ZL19with_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $1, $objp, $propp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL15with_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var $_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
  var $2 = __ZNK8JSObject8getProtoEv($_idx_val_idx_val);
  var $3 = $cx;
  var $4 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($2, $3, $id, $vp);
  return $4;
}

function __ZL16with_GetPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom2291($1);
  var $3 = __ZL15with_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $2, $vp);
  return $3;
}

function __ZL15with_GetElementP9JSContextP8JSObjectS2_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL15with_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $4, $vp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15with_GetSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE2500($sid_idx_val);
  var $2 = __ZL15with_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL16with_SetPropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var $_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
  var $2 = __ZNK8JSObject8getProtoEv($_idx_val_idx_val);
  var $3 = $cx;
  var $4 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($2, $3, $id, $vp, $strict);
  return $4;
}

function __ZL15with_SetElementP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL16with_SetPropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $4, $vp, $strict);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15with_SetSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE2500($sid_idx_val);
  var $2 = __ZL16with_SetPropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, $strict);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL18with_GetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var $_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
  var $2 = __ZNK8JSObject8getProtoEv($_idx_val_idx_val);
  var $3 = $cx;
  var $4 = __ZN8JSObject13getAttributesEP9JSContextiPj($2, $3, $id, $attrsp);
  return $4;
}

function __ZL25with_GetElementAttributesP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL18with_GetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $4, $attrsp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL25with_GetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE2500($sid_idx_val);
  var $2 = __ZL18with_GetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $1, $attrsp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL18with_SetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var $_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
  var $2 = __ZNK8JSObject8getProtoEv($_idx_val_idx_val);
  var $3 = $cx;
  var $4 = __ZN8JSObject13setAttributesEP9JSContextiPj($2, $3, $id, $attrsp);
  return $4;
}

function __ZL25with_SetElementAttributesP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL18with_SetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $4, $attrsp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL25with_SetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE2500($sid_idx_val);
  var $2 = __ZL18with_SetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $1, $attrsp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL11with_TypeOfP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZNK8JSObject7watchedEv($this_0_2_val) {
  return ($this_0_2_val & 8192 | 0) != 0;
}

function __ZN2js2gcL15GetGCObjectKindEjb2335($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19with_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var $_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
  var $2 = __ZNK8JSObject8getProtoEv($_idx_val_idx_val);
  var $3 = $cx;
  var $4 = __ZN8JSObject14deletePropertyEP9JSContextiPN2JS5ValueEi($2, $3, $id, $rval, $strict);
  return $4;
}

function __ZL18with_DeleteElementP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL19with_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $4, $rval, $strict);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18with_DeleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE2500($sid_idx_val);
  var $2 = __ZL19with_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, $strict);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL14with_EnumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var $_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
  var $2 = __ZNK8JSObject8getProtoEv($_idx_val_idx_val);
  var $3 = $2;
  var $4 = $cx;
  var $5 = __ZN8JSObject9enumerateEP9JSContext11JSIterateOpPN2JS5ValueEPi($3, $4, $enum_op, $statep, $idp);
  return $5;
}

function __ZL15with_ThisObjectP9JSContextP8JSObject($cx, $obj) {
  var $1 = __ZNK8JSObject11getWithThisEv($obj);
  return $1;
}

function __Z16js_NewWithObjectP9JSContextP8JSObjectS2_i($cx, $proto, $parent, $depth) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $tvr = __stackBase__ + 8;
    var $2 = $proto;
    var $3 = $cx;
    var $4 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($2, $3, 0, 0);
    if (($4 | 0) == 0) {
      var $_1 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($3, 2);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_1 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK9JSContext2fpEv($3);
    var $12 = __Z27js_FloatingFrameIfGeneratorP9JSContextPN2js10StackFrameE($3, $11);
    var $13 = $12;
    var $14 = $parent;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($7, __ZN2js9WithClassE, $4, $14, $13, 0);
    var $15 = __ZN2js10EmptyShape17getEmptyWithShapeEP9JSContext($cx);
    if (($15 | 0) == 0) {
      var $_1 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $18 = $15;
    __ZN8JSObject6setMapEPN2js5ShapeE($7, $18);
    __ZN2JSL10Int32ValueEi2332($1, $depth);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject12setFixedSlotEjRKN2JS5ValueE($7, 0, $_idx_val$0, $_idx_val$1);
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($tvr, $3, $7);
    var $19 = __ZN8JSObject10thisObjectEP9JSContext($2, $3);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $22 = $19;
    __ZN8JSObject11setWithThisEPS_($8, $22);
    var $_0 = $8;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js16AutoObjectRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 7;
    break;
   case 7:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10EmptyShape17getEmptyWithShapeEP9JSContext($cx) {
  var $4 = $cx;
  var $5 = HEAP32[$cx + 56 >> 2] + 768 | 0;
  var $6 = __ZN2js10EmptyShape6ensureEP9JSContextPNS_5ClassEPPS0_($4, __ZN2js9WithClassE, $5);
  return $6;
}

function __ZN2JSL10Int32ValueEi2332($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZN8JSObject11setWithThisEPS_($this, $thisp) {
  var $1 = __ZN8JSObject15getFixedSlotRefEj($this);
  var $2 = $thisp;
  __ZN2JS5Value9setObjectER8JSObject($1, $2);
  return;
}

function __Z17js_NewBlockObjectP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($1, 2);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN2js10EmptyShape18getEmptyBlockShapeEP9JSContext($cx);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($2, __ZN2js10BlockClassE, __ZN2js5types15emptyTypeObjectE, 0, 0, 0);
    var $9 = $6;
    __ZN8JSObject6setMapEPN2js5ShapeE($2, $9);
    var $_0 = $3;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10EmptyShape18getEmptyBlockShapeEP9JSContext($cx) {
  var $4 = $cx;
  var $5 = HEAP32[$cx + 56 >> 2] + 752 | 0;
  var $6 = __ZN2js10EmptyShape6ensureEP9JSContextPNS_5ClassEPPS0_($4, __ZN2js10BlockClassE, $5);
  return $6;
}

function __Z19js_CloneBlockObjectP9JSContextP8JSObjectPN2js10StackFrameE($cx, $proto, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $proto;
    var $2 = __ZNK8JSObject13propertyCountEv($1);
    var $3 = $2 + 1 | 0;
    var $4 = $proto;
    var $5 = $cx;
    var $6 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($4, $5, 0, 0);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js2gcL15GetGCObjectKindEjb2335($3);
    var $11 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($5, $10);
    var $12 = $11;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = $fp;
    var $16 = __Z27js_FloatingFrameIfGeneratorP9JSContextPN2js10StackFrameE($5, $15);
    var $17 = $16;
    __ZN8JSObject15initClonedBlockEP9JSContextPN2js5types10TypeObjectEPNS2_10StackFrameE($12, $cx, $7, $17);
    var $18 = __ZN8JSObject27ensureInstanceReservedSlotsEP9JSContextj($12, $cx, $3);
    if ($18) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $20 = __ZNK8JSObject7getSlotEj($4, 0);
    var $_idx = $20 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($11, 0, $_idx_val$0, $_idx_val$1);
    var $_0 = $12;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject15initClonedBlockEP9JSContextPN2js5types10TypeObjectEPNS2_10StackFrameE($this, $cx, $type, $frame) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $frame;
    var $2 = $this;
    var $3 = $type;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($2, __ZN2js10BlockClassE, $3, 0, $1, 0);
    var $_idx2_val_idx = HEAP32[$this + 36 >> 2];
    var $_idx2_val_idx_val = HEAP32[$_idx2_val_idx >> 2];
    var $5 = __ZNK8JSObject8getProtoEv($_idx2_val_idx_val);
    var $7 = HEAP32[$5 >> 2];
    HEAP32[$this >> 2] = $7;
    var $_idx1_val_idx_val = HEAP32[$_idx2_val_idx >> 2];
    var $9 = __ZNK8JSObject8getProtoEv($_idx1_val_idx_val);
    var $_idx_val = HEAP32[$9 + 8 >> 2];
    var $10 = __ZNK8JSObject11hasOwnShapeEv($_idx_val);
    if ($10) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx3_val = HEAP32[$cx + 52 >> 2];
    var $13 = __Z16js_GenerateShapeP9JSContext($_idx3_val);
    __ZN8JSObject11setOwnShapeEj($2, $13);
    __label__ = 4;
    break;
   case 3:
    var $16 = HEAP32[$7 >> 2];
    HEAP32[$this + 12 >> 2] = $16;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject27ensureInstanceReservedSlotsEP9JSContextj($this, $cx, $nreserved) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx1_val = HEAP32[$this + 4 >> 2];
    var $2 = __ZNK8JSObject8getClassEv($_idx1_val);
    var $7 = (HEAPU32[$2 + 4 >> 2] >>> 8 & 255) + $nreserved | 0;
    var $_idx_val = HEAP32[$this + 28 >> 2];
    var $9 = __ZNK8JSObject8numSlotsEv($_idx_val);
    if ($7 >>> 0 > $9 >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $14 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $12 = __ZN8JSObject10allocSlotsEP9JSContextj($this, $cx, $7);
    var $14 = $12;
    __label__ = 3;
    break;
   case 3:
    var $14;
    return $14;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_PutBlockObjectP9JSContexti($cx, $normalUnwind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __ZNK9JSContext2fpEv($1);
    var $3 = __ZNK2js10StackFrame10scopeChainEv($2);
    var $4 = $3;
    var $5 = __ZNK8JSObject13propertyCountEv($4);
    if (($normalUnwind | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_pre_phi = $2;
    __label__ = 4;
    break;
   case 3:
    var $8 = __ZNK8JSObject12getFixedSlotEj($3, 0);
    var $_idx = $8 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $9 = __ZNK2JS5Value7toInt32Ev($_idx_val$0, $_idx_val$1);
    var $10 = $3;
    var $11 = __ZNK2js10StackFrame8numFixedEv($2);
    var $12 = $11 + $9 | 0;
    var $13 = $2;
    var $14 = __ZNK2js10StackFrame5slotsEv($13);
    var $15 = $14 + ($12 << 3) | 0;
    __ZN8JSObject13copySlotRangeEjPKN2JS5ValueEj($10, 1, $15, $5);
    var $_pre_phi = $13;
    __label__ = 4;
    break;
   case 4:
    var $_pre_phi;
    __ZN8JSObject10setPrivateEPv($3, 0);
    var $_idx1_val = HEAP32[$3 + 20 >> 2];
    var $17 = __ZNK8JSObject9getParentEv($_idx1_val);
    var $18 = $17;
    __ZN2js10StackFrame22setScopeChainNoCallObjER8JSObject($_pre_phi, $18);
    return $normalUnwind;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject13copySlotRangeEjPKN2JS5ValueEj($this, $start, $vector, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $_idx1_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK8JSObject12isDenseArrayEv($_idx1_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = HEAP32[$this + 32 >> 2] + ($start << 3) | 0;
    var $9 = $vector;
    var $10 = $length << 3;
    _memcpy($8, $9, $10, 1);
    __label__ = 8;
    break;
   case 3:
    var $_idx_val = HEAP32[$this + 8 >> 2];
    var $13 = __ZNK8JSObject13numFixedSlotsEv($_idx_val);
    if ($13 >>> 0 > $start >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    if (($length + $start | 0) >>> 0 < $13 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $19 = __ZNK8JSObject10fixedSlotsEv($1);
    var $21 = $19 + ($start << 3) | 0;
    var $22 = $vector;
    var $23 = $length << 3;
    _memcpy($21, $22, $23, 1);
    __label__ = 8;
    break;
   case 6:
    var $25 = $13 - $start | 0;
    var $26 = __ZNK8JSObject10fixedSlotsEv($1);
    var $28 = $26 + ($start << 3) | 0;
    var $29 = $vector;
    var $30 = $25 << 3;
    _memcpy($28, $29, $30, 1);
    var $33 = HEAP32[$this + 32 >> 2];
    var $35 = $vector + ($25 << 3) | 0;
    var $37 = $length - $25 << 3;
    _memcpy($33, $35, $37, 1);
    __label__ = 8;
    break;
   case 7:
    var $42 = HEAP32[$this + 32 >> 2] + ($start - $13 << 3) | 0;
    var $43 = $vector;
    var $44 = $length << 3;
    _memcpy($42, $43, $44, 1);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject13copySlotRangeEjPKN2JS5ValueEj["X"] = 1;

function __ZN8JSObject19defineBlockVariableEP9JSContextii($this, $cx, $id, $index) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = (HEAPU32[__ZN2js10BlockClassE + 4 >> 2] >>> 8 & 255) + $index | 0;
    var $5 = $this;
    var $6 = $cx;
    var $7 = __ZN8JSObject11addPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji($5, $6, $id, 172, 174, $4, 5, 64, $index);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this + 28 >> 2];
    var $12 = __ZNK8JSObject8numSlotsEv($_idx_val);
    if ($4 >>> 0 < $12 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = $4 + 1 | 0;
    var $16 = __ZN8JSObject9growSlotsEP9JSContextj($this, $cx, $15);
    if ($16) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = $8;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17block_getPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $2 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $obj;
    var $6 = _JSID_TO_INT2488($id);
    var $7 = $2;
    var $8 = __Z23js_LiveFrameIfGeneratorPN2js10StackFrameE($7);
    var $9 = $8;
    var $10 = __ZNK2js10StackFrame8numFixedEv($9);
    var $11 = __ZNK8JSObject12getFixedSlotEj($5, 0);
    var $_idx1 = $11 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $12 = __ZNK2JS5Value7toInt32Ev($_idx1_val$0, $_idx1_val$1);
    var $14 = $10 + $6 + $12 | 0;
    var $15 = $8;
    var $16 = __ZNK2js10StackFrame5slotsEv($15);
    var $17 = $16 + ($14 << 3) | 0;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    var $19 = $vp | 0;
    HEAP32[$19 >> 2] = $18$0;
    HEAP32[$19 + 4 >> 2] = $18$1;
    __label__ = 3;
    break;
   case 3:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17block_setPropertyP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $2 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $obj;
    var $6 = _JSID_TO_INT2488($id);
    var $7 = $2;
    var $8 = __Z23js_LiveFrameIfGeneratorPN2js10StackFrameE($7);
    var $9 = $8;
    var $10 = __ZNK2js10StackFrame8numFixedEv($9);
    var $11 = __ZNK8JSObject12getFixedSlotEj($5, 0);
    var $_idx1 = $11 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $12 = __ZNK2JS5Value7toInt32Ev($_idx1_val$0, $_idx1_val$1);
    var $14 = $10 + $6 + $12 | 0;
    var $15 = $8;
    var $16 = __ZNK2js10StackFrame5slotsEv($15);
    var $17 = $vp | 0;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    var $19 = $16 + ($14 << 3) | 0;
    var $st$24$0 = $19 | 0;
    HEAP32[$st$24$0 >> 2] = $18$0;
    var $st$24$1 = $19 + 4 | 0;
    HEAP32[$st$24$1 >> 2] = $18$1;
    __label__ = 3;
    break;
   case 3:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject9growSlotsEP9JSContextj($this, $cx, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = $this + 28 | 0;
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK8JSObject8numSlotsEv($_idx_val);
    if ($3 >>> 0 < 1048577) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = $3 << 1;
    __label__ = 4;
    break;
   case 3:
    var $11 = ($3 >>> 3) + $3 | 0;
    __label__ = 4;
    break;
   case 4:
    var $11;
    var $13 = $11 >>> 0 < $newcap >>> 0 ? $newcap : $11;
    if ($13 >>> 0 > 131071) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ($13 >>> 0 < 8) {
      __label__ = 6;
      break;
    } else {
      var $actualCapacity_01 = $13;
      __label__ = 9;
      break;
    }
   case 6:
    var $actualCapacity_01 = 8;
    __label__ = 9;
    break;
   case 7:
    var $20 = $13 + 131071 & -131072;
    if ($20 >>> 0 > 536870911) {
      __label__ = 8;
      break;
    } else {
      var $actualCapacity_01 = $20;
      __label__ = 9;
      break;
    }
   case 8:
    var $23 = $cx;
    _JS_ReportOutOfMemory($23);
    var $_0 = 0;
    __label__ = 19;
    break;
   case 9:
    var $actualCapacity_01;
    var $24 = __ZNK8JSObject13hasSlotsArrayEv($1);
    if ($24) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $26 = __ZN8JSObject10allocSlotsEP9JSContextj($this, $cx, $actualCapacity_01);
    var $_0 = $26;
    __label__ = 19;
    break;
   case 11:
    var $28 = __ZNK8JSObject15numDynamicSlotsEj($1, $3);
    var $29 = __ZNK8JSObject15numDynamicSlotsEj($1, $actualCapacity_01);
    var $30 = $this + 32 | 0;
    var $32 = HEAP32[$30 >> 2];
    var $33 = $28 << 3;
    var $34 = $29 << 3;
    var $35 = $cx;
    var $36 = __ZN9JSContext8realloc_EPvjj($35, $32, $33, $34);
    var $37 = $36;
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $41 = (HEAP32[$30 >> 2] | 0) == ($37 | 0);
    HEAP32[$30 >> 2] = $37;
    HEAP32[$2 >> 2] = $actualCapacity_01;
    var $_idx2 = $this + 4 | 0;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $43 = __ZNK8JSObject12isDenseArrayEv($_idx2_val);
    if ($43) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $_idx3_val = HEAP8[$cx + 232 | 0];
    var $46 = __ZN9JSContext20typeInferenceEnabledEv($_idx3_val);
    if ($46) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZN8JSObject23backfillDenseArrayHolesEP9JSContext($1, $35);
    __label__ = 16;
    break;
   case 15:
    var $49 = $37 + ($28 << 3) | 0;
    var $50 = $29 - $28 | 0;
    __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2364($49, $50, 0);
    __label__ = 16;
    break;
   case 16:
    if ($41) {
      var $_0 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $_idx1_val = HEAP32[$_idx2 >> 2];
    var $54 = __ZNK8JSObject8isGlobalEv($_idx1_val);
    if ($54) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 1;
      __label__ = 19;
      break;
    }
   case 18:
    __ZN2js5types21MarkObjectStateChangeEP9JSContextP8JSObject($cx, $this);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject9growSlotsEP9JSContextj["X"] = 1;

function __ZN8JSObject20nonNativeSetPropertyEP9JSContextiPN2JS5ValueEi($this, $cx, $id, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 8 >> 2];
    var $1 = __ZNK8JSObject7watchedEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_01 = $id;
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __Z22js_CheckForStringIndexi($id);
    var $7 = HEAP32[HEAP32[$cx + 56 >> 2] + 1984 >> 2];
    if (($7 | 0) == 0) {
      var $_01 = $3;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $7;
    var $11 = $cx;
    var $12 = $this;
    var $13 = __ZN2js13WatchpointMap17triggerWatchpointEP9JSContextP8JSObjectiPN2JS5ValueE($10, $11, $12, $3, $vp);
    if ($13) {
      var $_01 = $3;
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_01;
    var $_idx_val = HEAP32[$this + 4 >> 2];
    var $16 = __ZNK8JSObject6getOpsEv($_idx_val);
    var $19 = HEAP32[$16 + 52 >> 2];
    var $20 = FUNCTION_TABLE[$19]($cx, $this, $_01, $vp, $strict);
    var $_0 = $20;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject18copyPropertiesFromEP9JSContextPS_($this, $cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 84;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $shapes = __stackBase__;
    var $r = __stackBase__ + 60;
    var $getter = __stackBase__ + 68;
    var $setter = __stackBase__ + 72;
    var $v = __stackBase__ + 76;
    var $1 = $this;
    var $_idx4_val = HEAP32[$this >> 2];
    var $2 = __ZNK8JSObject8isNativeEv($_idx4_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 1;
      __label__ = 18;
      break;
    }
   case 2:
    __ZN2js15AutoShapeVectorC1EP9JSContext($shapes, $cx);
    var $4 = $obj;
    var $_idx_val = HEAP32[$obj >> 2];
    var $5 = __ZNK8JSObject12lastPropertyEv($_idx_val);
    var $6 = $r;
    __ZN2js5Shape5RangeC1EPKS0_($6, $5);
    var $7 = $shapes | 0;
    var $_idx1 = $r;
    __label__ = 3;
    break;
   case 3:
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $_idx1_val_idx_val = HEAP32[$_idx1_val + 32 >> 2];
    var $9 = __ZNK2js5Shape5Range5emptyEv($_idx1_val_idx_val);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $_idx1_val;
    var $12 = __ZNK2js5Shape5Range5frontEv($11);
    var $13 = $12;
    var $14 = __ZN2js16AutoVectorRooterIPKNS_5ShapeEE6appendERKS3_($7, $13);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 5:
    __ZN2js5Shape5Range8popFrontEv($6);
    __label__ = 3;
    break;
   case 6:
    var $17 = __ZNK2js16AutoVectorRooterIPKNS_5ShapeEE6lengthEv($7);
    var $18 = $v | 0;
    var $19 = $cx + 56 | 0;
    var $20 = $cx;
    var $21 = $setter;
    var $22 = $getter;
    var $n_0 = $17;
    __label__ = 7;
    break;
   case 7:
    var $n_0;
    if (($n_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $26 = $n_0 - 1 | 0;
    var $27 = __ZN2js16AutoVectorRooterIPKNS_5ShapeEEixEj($7, $26);
    var $28 = HEAPU32[$27 >> 2];
    var $29 = $28 + 28 | 0;
    var $_idx7_val = HEAP8[$29];
    var $30 = __ZNK2js5Shape10attributesEv($_idx7_val);
    var $31 = $30 & 255;
    var $_idx2_val = HEAP32[$28 + 16 >> 2];
    var $33 = __ZNK2js5Shape6getterEv($_idx2_val);
    var $34 = $33;
    HEAP32[$getter >> 2] = $34;
    if (($31 & 16 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $39 = HEAP32[$19 >> 2];
    var $40 = __ZN13JSCompartment4wrapEP9JSContextPPFiS1_P8JSObjectiPN2JS5ValueEE($39, $20, $22);
    if ($40) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 10:
    var $_idx3_val = HEAP32[$28 + 20 >> 2];
    var $43 = __ZNK2js5Shape6setterEv($_idx3_val);
    var $44 = $43;
    HEAP32[$setter >> 2] = $44;
    if (($31 & 32 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $49 = HEAP32[$19 >> 2];
    var $50 = __ZN13JSCompartment4wrapEP9JSContextPPFiS1_P8JSObjectiiPN2JS5ValueEE($49, $20, $21);
    if ($50) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 12:
    var $_idx6_val = HEAP8[$29];
    var $51 = __ZNK2js5Shape7hasSlotEv($_idx6_val);
    if ($51) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $54 = HEAP32[$28 + 24 >> 2];
    var $55 = __ZNK8JSObject7getSlotEj($4, $54);
    var $56 = $55 | 0;
    var $57$0 = HEAP32[$56 >> 2];
    var $57$1 = HEAP32[$56 + 4 >> 2];
    HEAP32[$18 >> 2] = $57$0;
    HEAP32[$18 + 4 >> 2] = $57$1;
    __label__ = 15;
    break;
   case 14:
    __ZN2JSL14UndefinedValueEv2280($v);
    __label__ = 15;
    break;
   case 15:
    var $61 = HEAP32[$19 >> 2];
    var $62 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($61, $20, $v);
    if ($62) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 16:
    var $65 = HEAP32[$28 + 12 >> 2];
    var $68 = HEAP32[$getter >> 2];
    var $69 = HEAP32[$setter >> 2];
    var $70 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($1, $20, $65, $v, $68, $69, $31);
    if (($70 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      var $n_0 = $26;
      __label__ = 7;
      break;
    }
   case 17:
    var $_0;
    __ZN2js15AutoShapeVectorD1Ev($shapes);
    var $_1 = $_0;
    __label__ = 18;
    break;
   case 18:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject18copyPropertiesFromEP9JSContextPS_["X"] = 1;

function __ZN2js15AutoShapeVectorC1EP9JSContext($this, $cx) {
  __ZN2js15AutoShapeVectorC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js16AutoVectorRooterIPKNS_5ShapeEE6appendERKS3_($this, $v_val) {
  var $1 = $this + 12 | 0;
  var $2 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE6appendIS3_EEbT_($1, $v_val);
  return $2;
}

function __ZNK2js16AutoVectorRooterIPKNS_5ShapeEE6lengthEv($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  var $2 = __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE6lengthEv($_idx_val);
  return $2;
}

function __ZN2js16AutoVectorRooterIPKNS_5ShapeEEixEj($this, $i) {
  var $1 = $this + 12 | 0;
  var $2 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEEixEj($1, $i);
  return $2;
}

function __ZN2js15AutoShapeVectorD1Ev($this) {
  __ZN2js15AutoShapeVectorD2Ev($this);
  return;
}

function __ZN8JSObject5cloneEP9JSContextPS_S2_($this, $cx, $proto, $parent) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $_idx5 = $this;
    var $_idx5_val = HEAP32[$_idx5 >> 2];
    var $2 = __ZNK8JSObject8isNativeEv($_idx5_val);
    var $_idx3_pre = $this + 4 | 0;
    if ($2) {
      var $_idx3_pre_phi = $_idx3_pre;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx6_val = HEAP32[$_idx3_pre >> 2];
    var $5 = __ZNK8JSObject12isDenseArrayEv($_idx6_val);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = $cx;
    var $8 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($1, $7);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      var $_idx3_pre_phi = $_idx3_pre;
      __label__ = 6;
      break;
    }
   case 4:
    var $11 = __ZNK8JSObject7isProxyEv($_idx6_val);
    if ($11) {
      var $_idx3_pre_phi = $_idx3_pre;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = $cx;
    _JS_ReportErrorNumber($13, 4, 265, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 15;
    break;
   case 6:
    var $_idx3_pre_phi;
    var $_idx3_val = HEAP32[$_idx3_pre_phi >> 2];
    var $15 = __ZNK8JSObject8getClassEv($_idx3_val);
    var $16 = $15;
    var $17 = $this;
    var $18 = __ZNK2js2gc4Cell12getAllocKindEv($17);
    var $19 = __ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE2346($cx, $16, $proto, $parent, $18);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx4_val = HEAP32[$_idx5 >> 2];
    var $22 = __ZNK8JSObject8isNativeEv($_idx4_val);
    if ($22) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $24 = $19;
    var $_idx1_val = HEAP32[$19 + 4 >> 2];
    var $26 = __ZNK8JSObject10isFunctionEv($_idx1_val);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $28 = __ZNK2js2gc4Cell11compartmentEv($17);
    var $29 = $19;
    var $30 = __ZNK2js2gc4Cell11compartmentEv($29);
    if (($28 | 0) == ($30 | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $33 = $cx;
    _JS_ReportErrorNumber($33, 4, 265, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 15;
    break;
   case 11:
    var $_idx2_val = HEAP32[$_idx3_pre_phi >> 2];
    var $36 = __ZNK8JSObject8getClassEv($_idx2_val);
    if ((HEAP32[$36 + 4 >> 2] & 1 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $_idx_val = HEAP32[$this + 24 >> 2];
    var $43 = __ZNK8JSObject10getPrivateEv($_idx_val);
    __ZN8JSObject10setPrivateEPv($24, $43);
    __label__ = 14;
    break;
   case 13:
    var $45 = __ZL9CopySlotsP9JSContextP8JSObjectS2_($cx, $this, $19);
    if ($45) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 14:
    var $_0 = $19;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject5cloneEP9JSContextPS_S2_["X"] = 1;

function __ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE2346($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($clasp | 0) == (__ZN2js13FunctionClassE | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detailL9NewObjectILb1ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2464($cx, __ZN2js13FunctionClassE, $proto, $parent, $kind);
    var $_0 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2465($cx, $clasp, $proto, $parent, $kind);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9CopySlotsP9JSContextP8JSObjectS2_($cx, $from, $to) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $from;
    var $_idx_val = HEAP32[$from + 28 >> 2];
    var $3 = __ZNK8JSObject8numSlotsEv($_idx_val);
    var $4 = $to;
    var $5 = $cx;
    var $6 = __ZN8JSObject11ensureSlotsEP9JSContextj($4, $5, $3);
    if ($6) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK8JSObject9isWrapperEv($1);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $n_0_ph = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = __ZN9JSWrapper14wrapperHandlerEPK8JSObject($1);
    var $_idx3_val = HEAP32[$10 + 8 >> 2];
    var $12 = __ZNK9JSWrapper5flagsEv($_idx3_val);
    if (($12 & 1 | 0) == 0) {
      var $n_0_ph = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = __ZNK8JSObject7getSlotEj($1, 0);
    var $_idx2 = $16 | 0;
    var $st$2$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$2$1 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($4, 0, $_idx2_val$0, $_idx2_val$1);
    var $17 = __ZNK8JSObject7getSlotEj($1, 1);
    var $_idx1 = $17 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($4, 1, $_idx1_val$0, $_idx1_val$1);
    var $n_0_ph = 2;
    __label__ = 5;
    break;
   case 5:
    var $n_0_ph;
    var $18 = $v | 0;
    var $19 = $cx + 56 | 0;
    var $n_0 = $n_0_ph;
    __label__ = 6;
    break;
   case 6:
    var $n_0;
    if ($n_0 >>> 0 < $3 >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 7:
    var $23 = __ZNK8JSObject7getSlotEj($1, $n_0);
    var $24 = $23 | 0;
    var $st$2$0 = $24 | 0;
    var $25$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $24 + 4 | 0;
    var $25$1 = HEAP32[$st$2$1 >> 2];
    HEAP32[$18 >> 2] = $25$0;
    HEAP32[$18 + 4 >> 2] = $25$1;
    var $27 = HEAP32[$19 >> 2];
    var $28 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($27, $5, $v);
    if ($28) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $v_idx_val$0 = HEAP32[$18 >> 2];
    var $v_idx_val$1 = HEAP32[$18 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($4, $n_0, $v_idx_val$0, $v_idx_val$1);
    var $n_0 = $n_0 + 1 | 0;
    __label__ = 6;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9CopySlotsP9JSContextP8JSObjectS2_["X"] = 1;

function __ZN2jsL3MaxIjEET_S1_S1_2347($t1, $t2) {
  var $2 = $t1 >>> 0 > $t2 >>> 0 ? $t1 : $t2;
  return $2;
}

function __ZN8JSObject16updateFixedSlotsEj($this, $fixed) {
  var $1 = $this + 8 | 0;
  var $5 = HEAP32[$1 >> 2] & 134217727 | $fixed << 27;
  HEAP32[$1 >> 2] = $5;
  return;
}

function __Z15FindObjectIndexP13JSObjectArrayP8JSObject($array, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($array | 0) == 0) {
      var $_0 = -1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$array >> 2];
    var $i_0 = HEAP32[$array + 4 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    var $8 = $i_0 - 1 | 0;
    if ((HEAP32[$6 + ($8 << 2) >> 2] | 0) == ($obj | 0)) {
      var $_0 = $8;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($8 | 0) == 0) {
      var $_0 = -1;
      __label__ = 5;
      break;
    } else {
      var $i_0 = $8;
      __label__ = 3;
      break;
    }
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject19ReserveForTradeGutsEP9JSContextPS_S2_RNS_17TradeGutsReservedE($cx, $a, $b, $reserved) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $a;
    var $2 = __ZNK8JSObject10structSizeEv($1);
    var $3 = $b;
    var $4 = __ZNK8JSObject10structSizeEv($3);
    if (($2 | 0) == ($4 | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx3_val = HEAP32[$a + 28 >> 2];
    var $8 = __ZNK8JSObject8numSlotsEv($_idx3_val);
    var $_idx2_val = HEAP32[$b + 28 >> 2];
    var $10 = __ZNK8JSObject8numSlotsEv($_idx2_val);
    var $11 = $reserved + 4 | 0;
    var $12 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE7reserveEj($11, $8);
    if ($12) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 3:
    var $14 = $reserved + 28 | 0;
    var $15 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE7reserveEj($14, $10);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 4:
    var $_idx1_val = HEAP32[$a + 8 >> 2];
    var $18 = __ZNK8JSObject13numFixedSlotsEv($_idx1_val);
    var $_idx_val = HEAP32[$b + 8 >> 2];
    var $20 = __ZNK8JSObject13numFixedSlotsEv($_idx_val);
    if ($18 >>> 0 < $10 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $24 = $10 - $18 << 3;
    var $25 = $cx;
    var $26 = __ZN9JSContext7malloc_Ej($25, $24);
    var $27 = $26;
    HEAP32[$reserved + 52 >> 2] = $27;
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ($20 >>> 0 < $8 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $34 = $8 - $20 << 3;
    var $35 = $cx;
    var $36 = __ZN9JSContext7malloc_Ej($35, $34);
    var $37 = $36;
    HEAP32[$reserved + 56 >> 2] = $37;
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE7reserveEj($this, $request) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$this + 12 >> 2] >>> 0 < $request >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this;
    var $8 = $request - HEAP32[$this + 8 >> 2] | 0;
    var $9 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE13growStorageByEj($5, $8);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject9TradeGutsEP9JSContextPS_S2_RNS_17TradeGutsReservedE($cx, $a, $b, $reserved) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 168;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $1 = $a + 16 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $b + 16 | 0;
    var $4 = HEAP32[$3 >> 2];
    var $5 = $a;
    var $6 = __ZNK8JSObject10structSizeEv($5);
    var $7 = $b;
    var $8 = __ZNK8JSObject10structSizeEv($7);
    if (($6 | 0) == ($8 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = $tmp | 0;
    var $12 = $a;
    _memcpy($11, $12, $6, 1);
    var $13 = $b;
    _memcpy($12, $13, $6, 1);
    _memcpy($13, $11, $6, 1);
    __label__ = 18;
    break;
   case 3:
    var $15 = $a;
    var $_idx5_val = HEAP32[$a >> 2];
    var $16 = __ZNK8JSObject8isNativeEv($_idx5_val);
    if ($16) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx7_val = HEAP32[$cx + 52 >> 2];
    __ZN8JSObject16generateOwnShapeEP9JSContext($15, $_idx7_val);
    __label__ = 5;
    break;
   case 5:
    var $20 = $b;
    var $_idx4_val = HEAP32[$b >> 2];
    var $21 = __ZNK8JSObject8isNativeEv($_idx4_val);
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $_idx6_val = HEAP32[$cx + 52 >> 2];
    __ZN8JSObject16generateOwnShapeEP9JSContext($20, $_idx6_val);
    __label__ = 7;
    break;
   case 7:
    var $25 = $a + 28 | 0;
    var $_idx3_val = HEAP32[$25 >> 2];
    var $26 = __ZNK8JSObject8numSlotsEv($_idx3_val);
    var $27 = $b + 28 | 0;
    var $_idx2_val = HEAP32[$27 >> 2];
    var $28 = __ZNK8JSObject8numSlotsEv($_idx2_val);
    if (($26 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $30 = $reserved + 4 | 0;
    var $i_023 = 0;
    __label__ = 11;
    break;
   case 9:
    if (($28 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $32 = $reserved + 28 | 0;
    var $i1_022 = 0;
    __label__ = 12;
    break;
   case 11:
    var $i_023;
    var $34 = __ZNK8JSObject7getSlotEj($15, $i_023);
    var $_idx11 = $34 | 0;
    var $st$3$0 = $_idx11 | 0;
    var $_idx11_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx11 + 4 | 0;
    var $_idx11_val$1 = HEAP32[$st$3$1 >> 2];
    __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE16infallibleAppendERKS2_($30, $_idx11_val$0, $_idx11_val$1);
    var $35 = $i_023 + 1 | 0;
    if (($35 | 0) == ($26 | 0)) {
      __label__ = 9;
      break;
    } else {
      var $i_023 = $35;
      __label__ = 11;
      break;
    }
   case 12:
    var $i1_022;
    var $37 = __ZNK8JSObject7getSlotEj($20, $i1_022);
    var $_idx10 = $37 | 0;
    var $st$3$0 = $_idx10 | 0;
    var $_idx10_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx10 + 4 | 0;
    var $_idx10_val$1 = HEAP32[$st$3$1 >> 2];
    __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE16infallibleAppendERKS2_($32, $_idx10_val$0, $_idx10_val$1);
    var $38 = $i1_022 + 1 | 0;
    if (($38 | 0) == ($28 | 0)) {
      __label__ = 13;
      break;
    } else {
      var $i1_022 = $38;
      __label__ = 12;
      break;
    }
   case 13:
    var $39 = __ZNK8JSObject13hasSlotsArrayEv($15);
    if ($39) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $43 = HEAP32[$a + 32 >> 2];
    __ZN9JSContext5free_EPv($43);
    __label__ = 15;
    break;
   case 15:
    var $45 = __ZNK8JSObject13hasSlotsArrayEv($20);
    var $46 = $b + 32 | 0;
    if ($45) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $49 = HEAP32[$46 >> 2];
    __ZN9JSContext5free_EPv($49);
    __label__ = 17;
    break;
   case 17:
    var $_idx1_val = HEAP32[$a + 8 >> 2];
    var $51 = __ZNK8JSObject13numFixedSlotsEv($_idx1_val);
    var $52 = $b + 8 | 0;
    var $_idx_val = HEAP32[$52 >> 2];
    var $53 = __ZNK8JSObject13numFixedSlotsEv($_idx_val);
    var $a_0 = $a | 0;
    var $tmp11 = HEAPU8[$a_0] | HEAPU8[$a_0 + 1] << 8 | HEAPU8[$a_0 + 2] << 16 | HEAPU8[$a_0 + 3] << 24 | 0;
    var $a_1 = $a + 4 | 0;
    var $tmp12 = HEAPU8[$a_1] | HEAPU8[$a_1 + 1] << 8 | HEAPU8[$a_1 + 2] << 16 | HEAPU8[$a_1 + 3] << 24 | 0;
    var $a_3 = $a + 12 | 0;
    var $tmp14 = HEAPU8[$a_3] | HEAPU8[$a_3 + 1] << 8 | HEAPU8[$a_3 + 2] << 16 | HEAPU8[$a_3 + 3] << 24 | 0;
    var $tmp20 = HEAPU8[$1] | HEAPU8[$1 + 1] << 8 | HEAPU8[$1 + 2] << 16 | HEAPU8[$1 + 3] << 24 | 0;
    var $a_5 = $a + 20 | 0;
    var $tmp15 = HEAPU8[$a_5] | HEAPU8[$a_5 + 1] << 8 | HEAPU8[$a_5 + 2] << 16 | HEAPU8[$a_5 + 3] << 24 | 0;
    var $a_6 = $a + 24 | 0;
    var $tmp16 = HEAPU8[$a_6] | HEAPU8[$a_6 + 1] << 8 | HEAPU8[$a_6 + 2] << 16 | HEAPU8[$a_6 + 3] << 24 | 0;
    var $tmp17 = HEAPU8[$25] | HEAPU8[$25 + 1] << 8 | HEAPU8[$25 + 2] << 16 | HEAPU8[$25 + 3] << 24 | 0;
    var $a_8 = $a + 32 | 0;
    var $tmp18 = HEAPU8[$a_8] | HEAPU8[$a_8 + 1] << 8 | HEAPU8[$a_8 + 2] << 16 | HEAPU8[$a_8 + 3] << 24 | 0;
    var $a_9 = $a + 36 | 0;
    var $tmp19 = HEAPU8[$a_9] | HEAPU8[$a_9 + 1] << 8 | HEAPU8[$a_9 + 2] << 16 | HEAPU8[$a_9 + 3] << 24 | 0;
    var $54 = $a;
    var $55 = $b;
    _memcpy($54, $55, 40, 1);
    var $b_0 = $b | 0;
    tempBigInt = $tmp11;
    HEAP8[$b_0] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_0 + 1] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_0 + 2] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_0 + 3] = tempBigInt & 255;
    var $b_1 = $b + 4 | 0;
    tempBigInt = $tmp12;
    HEAP8[$b_1] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_1 + 1] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_1 + 2] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_1 + 3] = tempBigInt & 255;
    tempBigInt = $_idx1_val;
    HEAP8[$52] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$52 + 1] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$52 + 2] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$52 + 3] = tempBigInt & 255;
    var $b_3 = $b + 12 | 0;
    tempBigInt = $tmp14;
    HEAP8[$b_3] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_3 + 1] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_3 + 2] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_3 + 3] = tempBigInt & 255;
    tempBigInt = $tmp20;
    HEAP8[$3] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$3 + 1] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$3 + 2] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$3 + 3] = tempBigInt & 255;
    var $b_5 = $b + 20 | 0;
    tempBigInt = $tmp15;
    HEAP8[$b_5] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_5 + 1] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_5 + 2] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_5 + 3] = tempBigInt & 255;
    var $b_6 = $b + 24 | 0;
    tempBigInt = $tmp16;
    HEAP8[$b_6] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_6 + 1] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_6 + 2] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_6 + 3] = tempBigInt & 255;
    tempBigInt = $tmp17;
    HEAP8[$27] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$27 + 1] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$27 + 2] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$27 + 3] = tempBigInt & 255;
    tempBigInt = $tmp18;
    HEAP8[$46] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$46 + 1] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$46 + 2] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$46 + 3] = tempBigInt & 255;
    var $b_9 = $b + 36 | 0;
    tempBigInt = $tmp19;
    HEAP8[$b_9] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_9 + 1] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_9 + 2] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_9 + 3] = tempBigInt & 255;
    __ZN8JSObject16updateFixedSlotsEj($a, $51);
    var $56 = $reserved + 52 | 0;
    var $57 = HEAP32[$56 >> 2];
    HEAP32[$a_8 >> 2] = $57;
    var $58 = __ZN2jsL3MaxIjEET_S1_S1_2347($51, $28);
    HEAP32[$25 >> 2] = $58;
    var $_idx9_val = HEAP32[$reserved + 32 >> 2];
    var $60 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE5beginEv($_idx9_val);
    __ZN8JSObject13copySlotRangeEjPKN2JS5ValueEj($a, 0, $60, $28);
    var $61 = $58 - $28 | 0;
    __ZN8JSObject14clearSlotRangeEjj($a, $28, $61);
    __ZN8JSObject16updateFixedSlotsEj($b, $53);
    var $62 = $reserved + 56 | 0;
    var $63 = HEAP32[$62 >> 2];
    HEAP32[$46 >> 2] = $63;
    var $64 = __ZN2jsL3MaxIjEET_S1_S1_2347($53, $26);
    HEAP32[$27 >> 2] = $64;
    var $_idx8_val = HEAP32[$reserved + 8 >> 2];
    var $66 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE5beginEv($_idx8_val);
    __ZN8JSObject13copySlotRangeEjPKN2JS5ValueEj($b, 0, $66, $26);
    var $67 = $64 - $26 | 0;
    __ZN8JSObject14clearSlotRangeEjj($b, $26, $67);
    HEAP32[$56 >> 2] = 0;
    HEAP32[$62 >> 2] = 0;
    __label__ = 18;
    break;
   case 18:
    HEAP32[$1 >> 2] = $2;
    HEAP32[$3 >> 2] = $4;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject9TradeGutsEP9JSContextPS_S2_RNS_17TradeGutsReservedE["X"] = 1;

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE16infallibleAppendERKS2_($this, $t_0_0_0_val$0, $t_0_0_0_val$1) {
  var $1 = $this;
  __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($1, $t_0_0_0_val$0, $t_0_0_0_val$1);
  return;
}

function __ZN8JSObject14clearSlotRangeEjj($this, $start, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $_idx1_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK8JSObject12isDenseArrayEv($_idx1_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 32 >> 2] + ($start << 3) | 0;
    __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2364($7, $length, 1);
    __label__ = 8;
    break;
   case 3:
    var $_idx_val = HEAP32[$this + 8 >> 2];
    var $10 = __ZNK8JSObject13numFixedSlotsEv($_idx_val);
    if ($10 >>> 0 > $start >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    if (($length + $start | 0) >>> 0 < $10 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = __ZNK8JSObject10fixedSlotsEv($1);
    var $17 = $16 + ($start << 3) | 0;
    __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2364($17, $length, 0);
    __label__ = 8;
    break;
   case 6:
    var $19 = $10 - $start | 0;
    var $20 = __ZNK8JSObject10fixedSlotsEv($1);
    var $21 = $20 + ($start << 3) | 0;
    __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2364($21, $19, 0);
    var $23 = HEAP32[$this + 32 >> 2];
    var $24 = $length - $19 | 0;
    __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2364($23, $24, 0);
    __label__ = 8;
    break;
   case 7:
    var $28 = HEAP32[$this + 32 >> 2] + ($start - $10 << 3) | 0;
    __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2364($28, $length, 0);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject4swapEP9JSContextPS_($this, $cx, $other) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 284;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $reserved = __stackBase__;
    var $ac = __stackBase__ + 60;
    var $ac1 = __stackBase__ + 112;
    var $reservedThis = __stackBase__ + 164;
    var $reservedOther = __stackBase__ + 224;
    var $1 = $this;
    var $2 = __ZNK2js2gc4Cell11compartmentEv($1);
    var $3 = $other;
    var $4 = __ZNK2js2gc4Cell11compartmentEv($3);
    if (($2 | 0) == ($4 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    __ZN8JSObject17TradeGutsReservedC1EP9JSContext($reserved, $cx);
    var $7 = __ZN8JSObject19ReserveForTradeGutsEP9JSContextPS_S2_RNS_17TradeGutsReservedE($cx, $this, $other, $reserved);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN8JSObject9TradeGutsEP9JSContextPS_S2_RNS_17TradeGutsReservedE($cx, $this, $other, $reserved);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN8JSObject17TradeGutsReservedD1Ev($reserved);
    var $_4 = $_0;
    __label__ = 17;
    break;
   case 5:
    var $11 = $cx;
    var $12 = $other;
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $11, $12);
    var $13 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $_idx3 = $other + 36 | 0;
    var $_idx3_val_idx_val = HEAP32[HEAP32[$_idx3 >> 2] >> 2];
    var $16 = __ZNK8JSObject8getProtoEv($_idx3_val_idx_val);
    var $17 = $16;
    var $_idx1 = $other + 20 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $19 = __ZNK8JSObject9getParentEv($_idx1_val);
    var $20 = $19;
    var $21 = __ZN8JSObject5cloneEP9JSContextPS_S2_($this, $cx, $17, $20);
    if (($21 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = __ZN8JSObject18copyPropertiesFromEP9JSContextPS_($21, $cx, $this);
    if ($24) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_4 = 0;
    __label__ = 17;
    break;
   case 9:
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $26 = $this;
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac1, $11, $26);
    var $27 = __ZN2js15AutoCompartment5enterEv($ac1);
    if ($27) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $_idx2_val_idx_val = HEAP32[HEAP32[$_idx3 >> 2] >> 2];
    var $30 = __ZNK8JSObject8getProtoEv($_idx2_val_idx_val);
    var $31 = $30;
    var $_idx_val = HEAP32[$_idx1 >> 2];
    var $33 = __ZNK8JSObject9getParentEv($_idx_val);
    var $34 = $33;
    var $35 = __ZN8JSObject5cloneEP9JSContextPS_S2_($other, $cx, $31, $34);
    if (($35 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $38 = __ZN8JSObject18copyPropertiesFromEP9JSContextPS_($35, $cx, $other);
    if ($38) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN2js15AutoCompartmentD2Ev($ac1);
    var $_4 = 0;
    __label__ = 17;
    break;
   case 13:
    __ZN2js15AutoCompartmentD2Ev($ac1);
    __ZN8JSObject17TradeGutsReservedC1EP9JSContext($reservedThis, $cx);
    __ZN8JSObject17TradeGutsReservedC1EP9JSContext($reservedOther, $cx);
    var $40 = __ZN8JSObject19ReserveForTradeGutsEP9JSContextPS_S2_RNS_17TradeGutsReservedE($cx, $this, $35, $reservedThis);
    if ($40) {
      __label__ = 14;
      break;
    } else {
      var $_3 = 0;
      __label__ = 16;
      break;
    }
   case 14:
    var $42 = __ZN8JSObject19ReserveForTradeGutsEP9JSContextPS_S2_RNS_17TradeGutsReservedE($cx, $other, $21, $reservedOther);
    if ($42) {
      __label__ = 15;
      break;
    } else {
      var $_3 = 0;
      __label__ = 16;
      break;
    }
   case 15:
    __ZN8JSObject9TradeGutsEP9JSContextPS_S2_RNS_17TradeGutsReservedE($cx, $this, $35, $reservedThis);
    __ZN8JSObject9TradeGutsEP9JSContextPS_S2_RNS_17TradeGutsReservedE($cx, $other, $21, $reservedOther);
    var $_3 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_3;
    __ZN8JSObject17TradeGutsReservedD1Ev($reservedOther);
    __ZN8JSObject17TradeGutsReservedD1Ev($reservedThis);
    var $_4 = $_3;
    __label__ = 17;
    break;
   case 17:
    var $_4;
    STACKTOP = __stackBase__;
    return $_4;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject4swapEP9JSContextPS_["X"] = 1;

function __ZN8JSObject17TradeGutsReservedC1EP9JSContext($this, $cx) {
  __ZN8JSObject17TradeGutsReservedC2EP9JSContext($this, $cx);
  return;
}

function __ZN8JSObject17TradeGutsReservedD1Ev($this) {
  __ZN8JSObject17TradeGutsReservedD2Ev($this);
  return;
}

function __Z17js_XDRBlockObjectP10JSXDRStatePP8JSObject($xdr, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 108;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $parentId = __stackBase__;
    var $depthAndCount = __stackBase__ + 4;
    var $tvr = __stackBase__ + 8;
    var $1 = __stackBase__ + 24;
    var $atom = __stackBase__ + 32;
    var $shapes = __stackBase__ + 36;
    var $r = __stackBase__ + 96;
    var $atom2 = __stackBase__ + 104;
    var $3 = HEAPU32[$xdr + 8 >> 2];
    var $4 = $xdr | 0;
    if ((HEAP32[$4 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $obj_0 = 0;
      var $count_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $8 = HEAP32[$objp >> 2];
    var $9 = $8;
    var $11 = HEAP32[$xdr + 32 >> 2];
    var $13 = HEAP8[$11 + 16 | 0];
    var $14 = __ZN8JSScript13isValidOffsetEh($13);
    if ($14) {
      __label__ = 3;
      break;
    } else {
      var $24 = -1;
      __label__ = 4;
      break;
    }
   case 3:
    var $_idx8_val = HEAP32[$8 + 20 >> 2];
    var $17 = __ZNK8JSObject9getParentEv($_idx8_val);
    var $18 = $17;
    var $_idx1_val = HEAP32[$11 + 4 >> 2];
    var $20 = __ZN8JSScript7objectsEv($_idx1_val, $13);
    var $21 = $20;
    var $22 = __Z15FindObjectIndexP13JSObjectArrayP8JSObject($21, $18);
    var $24 = $22;
    __label__ = 4;
    break;
   case 4:
    var $24;
    HEAP32[$parentId >> 2] = $24;
    var $25 = __ZNK8JSObject12getFixedSlotEj($9, 0);
    var $_idx = $25 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $26 = __ZNK2JS5Value7toInt32Ev($_idx_val$0, $_idx_val$1);
    var $27 = $8;
    var $28 = __ZNK8JSObject13propertyCountEv($27);
    var $29 = $28 & 65535;
    var $31 = $29 | $26 << 16;
    HEAP32[$depthAndCount >> 2] = $31;
    var $obj_0 = $8;
    var $count_0 = $29;
    __label__ = 5;
    break;
   case 5:
    var $count_0;
    var $obj_0;
    var $33 = $xdr;
    var $34 = _JS_XDRUint32($33, $parentId);
    if (($34 | 0) == 0) {
      var $_2 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$4 >> 2] | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      var $obj_1 = $obj_0;
      __label__ = 11;
      break;
    }
   case 7:
    var $40 = __Z17js_NewBlockObjectP9JSContext($3);
    if (($40 | 0) == 0) {
      var $_2 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP32[$objp >> 2] = $40;
    var $43 = HEAP32[$parentId >> 2];
    if (($43 | 0) == -1) {
      var $parent_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $47 = HEAP32[$xdr + 32 >> 2];
    var $_idx3_val = HEAP32[$47 + 4 >> 2];
    var $_idx4_val = HEAP8[$47 + 16 | 0];
    var $50 = __ZN8JSScript9getObjectEj($_idx3_val, $_idx4_val, $43);
    var $parent_0 = $50;
    __label__ = 10;
    break;
   case 10:
    var $parent_0;
    var $52 = $40;
    __ZN8JSObject9setParentEPS_($52, $parent_0);
    var $obj_1 = $40;
    __label__ = 11;
    break;
   case 11:
    var $obj_1;
    var $54 = $3;
    var $55 = $obj_1;
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($tvr, $54, $55);
    var $56 = _JS_XDRUint32($33, $depthAndCount);
    if (($56 | 0) == 0) {
      var $_1 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[$4 >> 2] | 0) == 1) {
      __label__ = 13;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 13:
    var $62 = HEAPU32[$depthAndCount >> 2];
    var $63 = $62 >>> 16;
    var $64 = $62 & 65535;
    __ZN2JSL10Int32ValueEi2332($1, $63);
    var $_idx10 = $1 | 0;
    var $_idx10_val$0 = HEAP32[$_idx10 >> 2];
    var $_idx10_val$1 = HEAP32[$_idx10 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($55, 0, $_idx10_val$0, $_idx10_val$1);
    var $65 = $atom;
    var $i_0 = 0;
    __label__ = 14;
    break;
   case 14:
    var $i_0;
    if ($i_0 >>> 0 < $64 >>> 0) {
      __label__ = 15;
      break;
    } else {
      var $_1 = 1;
      __label__ = 26;
      break;
    }
   case 15:
    var $69 = _js_XDRAtom($33, $65);
    if (($69 | 0) == 0) {
      var $_1 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $72 = HEAP32[$atom >> 2];
    var $73 = __ZL12ATOM_TO_JSIDP6JSAtom2291($72);
    var $74 = __ZN8JSObject19defineBlockVariableEP9JSContextii($obj_1, $3, $73, $i_0);
    if (($74 | 0) == 0) {
      var $_1 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 14;
    break;
   case 18:
    __ZN2js15AutoShapeVectorC1EP9JSContext($shapes, $3);
    var $79 = $shapes | 0;
    __ZN2js16AutoVectorRooterIPKNS_5ShapeEE6growByEj($79, $count_0);
    var $_idx5_val = HEAP32[$obj_1 >> 2];
    var $80 = __ZNK8JSObject12lastPropertyEv($_idx5_val);
    var $81 = $r;
    __ZN2js5Shape5RangeC1EPKS0_($81, $80);
    var $_idx7 = $r;
    var $_idx7_val = HEAP32[$_idx7 >> 2];
    var $_idx7_val_idx_val = HEAP32[$_idx7_val + 32 >> 2];
    var $82 = __ZNK2js5Shape5Range5emptyEv($_idx7_val_idx_val);
    if ($82) {
      __label__ = 19;
      break;
    } else {
      var $_idx9_val_in = $_idx7_val;
      __label__ = 20;
      break;
    }
   case 19:
    var $83 = $atom2;
    var $i1_0 = 0;
    __label__ = 21;
    break;
   case 20:
    var $_idx9_val_in;
    var $84 = __ZNK2js5Shape5Range5frontEv($_idx9_val_in);
    var $85 = $84;
    var $88 = HEAP16[$84 + 30 >> 1] << 16 >> 16;
    var $89 = __ZN2js16AutoVectorRooterIPKNS_5ShapeEEixEj($79, $88);
    HEAP32[$89 >> 2] = $85;
    __ZN2js5Shape5Range8popFrontEv($81);
    var $_idx6_val = HEAPU32[$_idx7 >> 2];
    var $_idx6_val_idx_val = HEAP32[$_idx6_val + 32 >> 2];
    var $90 = __ZNK2js5Shape5Range5emptyEv($_idx6_val_idx_val);
    if ($90) {
      __label__ = 19;
      break;
    } else {
      var $_idx9_val_in = $_idx6_val;
      __label__ = 20;
      break;
    }
   case 21:
    var $i1_0;
    if ($i1_0 >>> 0 < $count_0 >>> 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 22:
    var $94 = __ZN2js16AutoVectorRooterIPKNS_5ShapeEEixEj($79, $i1_0);
    var $97 = HEAP32[HEAP32[$94 >> 2] + 12 >> 2];
    var $98 = __ZL12JSID_TO_ATOMi2352($97);
    HEAP32[$atom2 >> 2] = $98;
    var $99 = _js_XDRAtom($33, $83);
    if (($99 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 21;
    break;
   case 24:
    __ZN2js15AutoShapeVectorD1Ev($shapes);
    var $_1 = 1;
    __label__ = 26;
    break;
   case 25:
    __ZN2js15AutoShapeVectorD1Ev($shapes);
    var $_1 = 0;
    __label__ = 26;
    break;
   case 26:
    var $_1;
    __ZN2js16AutoObjectRooterD1Ev($tvr);
    var $_2 = $_1;
    __label__ = 27;
    break;
   case 27:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z17js_XDRBlockObjectP10JSXDRStatePP8JSObject["X"] = 1;

function __ZN2js16AutoVectorRooterIPKNS_5ShapeEE6growByEj($this, $inc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    var $2 = $this + 20 | 0;
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE19growByUninitializedEj($1, $inc);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE6lengthEv($_idx_val);
    var $6 = HEAP32[$this + 16 >> 2];
    var $_idx1_val = $6;
    var $7 = __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE5beginEv($_idx1_val);
    var $9 = $7 + ($5 << 2) | 0;
    var $_idx3_val = HEAP32[$2 >> 2];
    var $10 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE3endEv($6, $_idx3_val);
    __ZN2jsL15MakeRangeGCSafeEPPKNS_5ShapeES3_($9, $10);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12JSID_TO_ATOMi2352($id) {
  var $1 = _JSID_TO_STRING2421($id);
  return $1;
}

function __ZN2js2gcL14GetGCKindSlotsENS0_9AllocKindE2367($thingKind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($thingKind | 0) == 2 || ($thingKind | 0) == 3) {
      __label__ = 2;
      break;
    } else if (($thingKind | 0) == 4 || ($thingKind | 0) == 5) {
      __label__ = 3;
      break;
    } else if (($thingKind | 0) == 6 || ($thingKind | 0) == 7) {
      __label__ = 4;
      break;
    } else if (($thingKind | 0) == 8 || ($thingKind | 0) == 9) {
      __label__ = 5;
      break;
    } else if (($thingKind | 0) == 11 || ($thingKind | 0) == 10) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $_0 = 2;
    __label__ = 7;
    break;
   case 3:
    var $_0 = 4;
    __label__ = 7;
    break;
   case 4:
    var $_0 = 8;
    __label__ = 7;
    break;
   case 5:
    var $_0 = 12;
    __label__ = 7;
    break;
   case 6:
    var $_0 = 16;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5ValueneERKS0_($this_0_0_0_val$0, $this_0_0_0_val$1, $rhs_0_0_0_val$0, $rhs_0_0_0_val$1) {
  return $this_0_0_0_val$0 != $rhs_0_0_0_val$0 || $this_0_0_0_val$1 != $rhs_0_0_0_val$1;
}

function __ZN2js2gcL21TryIncrementAllocKindEPNS0_9AllocKindE($kindp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$kindp >> 2] + 2 | 0;
    if ($2 >>> 0 > 11) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$kindp >> 2] = $2;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js29DefineConstructorAndPrototypeEP9JSContextP8JSObject10JSProtoKeyP6JSAtomS3_PNS_5ClassEPFiS1_jPN2JS5ValueEEjP14JSPropertySpecP14JSFunctionSpecSF_SH_PS3_($cx, $obj, $key, $atom, $protoProto, $clasp, $constructor, $nargs, $ps, $fs, $ctorp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 68;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $named = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $tvr2 = __stackBase__ + 12;
    var $2 = __stackBase__ + 36;
    var $rval = __stackBase__ + 44;
    var $3 = __stackBase__ + 52;
    var $rval1 = __stackBase__ + 60;
    var $4 = __ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2353($cx, $clasp, $protoProto, $obj);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 43;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4;
    var $8 = $cx;
    __ZN8JSObject16setSingletonTypeEP9JSContext($7, $8);
    var $10 = $4;
    var $11 = $cx;
    if (($clasp | 0) == (__ZN2js10ArrayClassE | 0)) {
      __label__ = 3;
      break;
    } else {
      var $_pre_phi = $10;
      var $_pre_phi11 = $11;
      __label__ = 4;
      break;
    }
   case 3:
    var $13 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($10, $11);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 43;
      break;
    } else {
      var $_pre_phi = $10;
      var $_pre_phi11 = $11;
      __label__ = 4;
      break;
    }
   case 4:
    var $_pre_phi11;
    var $_pre_phi;
    var $15 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($_pre_phi, $_pre_phi11, 0, 0);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 43;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx2_val = HEAP32[$4 + 4 >> 2];
    var $19 = __ZNK8JSObject8getClassEv($_idx2_val);
    var $20 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($15, $_pre_phi11, $19, 0);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 43;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN8JSObject19syncSpecialEqualityEv($7);
    HEAP8[$named] = 0;
    if (($constructor | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    var $27 = HEAP32[$clasp + 4 >> 2] & 131072;
    if (($27 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx3_val = HEAP32[$obj + 4 >> 2];
    var $31 = __ZNK8JSObject8isGlobalEv($_idx3_val);
    if (($key | 0) == 0 | $31 ^ 1) {
      __label__ = 9;
      break;
    } else {
      var $cached_1 = 0;
      var $ctor_1 = $4;
      var $proto_2 = $4;
      __label__ = 25;
      break;
    }
   case 9:
    var $35 = ($27 | 0) != 0 ? 6 : 0;
    __ZN2JSL11ObjectValueER8JSObject2354($1, $4);
    var $36 = __ZL18DefineStandardSlotP9JSContextP8JSObject10JSProtoKeyP6JSAtomRKN2JS5ValueEjRb($cx, $obj, $key, $atom, $1, $35, $named);
    if ($36) {
      var $cached_1 = 0;
      var $ctor_1 = $4;
      var $proto_2 = $4;
      __label__ = 25;
      break;
    } else {
      var $cached_2 = 0;
      __label__ = 39;
      break;
    }
   case 10:
    var $38 = $constructor;
    var $39 = $obj;
    var $40 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($_pre_phi11, 0, $38, $nargs, 512, $39, $atom);
    if (($40 | 0) == 0) {
      var $cached_2 = 0;
      __label__ = 39;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $43 = $40;
    var $44 = $clasp;
    __ZN10JSFunction19setConstructorClassEPN2js5ClassE($43, $44);
    if (($key | 0) == 0) {
      var $cached_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[$clasp + 4 >> 2] & 64 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $cached_0 = 0;
      __label__ = 14;
      break;
    }
   case 13:
    var $52 = $40;
    var $53 = __ZN2jsL14SetClassObjectEP9JSContextP8JSObject10JSProtoKeyS3_S3_($cx, $obj, $key, $52, $4);
    if ($53) {
      var $cached_0 = 1;
      __label__ = 14;
      break;
    } else {
      var $cached_2 = 0;
      __label__ = 39;
      break;
    }
   case 14:
    var $cached_0;
    var $55 = $40;
    __ZN2JSL11ObjectValueER8JSObject2354($2, $55);
    __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr2, $_pre_phi11, $2);
    var $56 = __ZNK2js15AutoValueRooter5valueEv($tvr2);
    var $57 = __ZL18DefineStandardSlotP9JSContextP8JSObject10JSProtoKeyP6JSAtomRKN2JS5ValueEjRb($cx, $obj, $key, $atom, $56, 0, $named);
    if ($57) {
      __label__ = 15;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 15:
    if ((HEAP32[$clasp + 4 >> 2] & 64 | 0) == 0) {
      var $proto_0 = $4;
      __label__ = 20;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN2JSL17ObjectOrNullValueEP8JSObject2355($3, $55);
    var $64 = __ZN2js30InvokeConstructorWithGivenThisEP9JSContextP8JSObjectRKN2JS5ValueEjPS5_S8_($_pre_phi11, $_pre_phi, $3, 0, 0, $rval);
    if ($64) {
      __label__ = 17;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 17:
    var $rval_idx = $rval | 0;
    var $rval_idx_val$0 = HEAP32[$rval_idx >> 2];
    var $rval_idx_val$1 = HEAP32[$rval_idx + 4 >> 2];
    var $66 = __ZNK2JS5Value8isObjectEv($rval_idx_val$0, $rval_idx_val$1);
    if ($66) {
      __label__ = 18;
      break;
    } else {
      var $proto_0 = $4;
      __label__ = 20;
      break;
    }
   case 18:
    var $68 = __ZNK2JS5Value8toObjectEv($rval_idx_val$0, $rval_idx_val$1);
    var $69 = $68;
    if (($69 | 0) == ($4 | 0)) {
      var $proto_0 = $4;
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $proto_0 = $69;
    __label__ = 20;
    break;
   case 20:
    var $proto_0;
    var $73 = $40;
    var $75 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($8, $73, $proto_0);
    if ($75) {
      __label__ = 21;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 21:
    var $_idx_val = HEAP32[$40 + 4 >> 2];
    var $77 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($77 | 0) == ($clasp | 0)) {
      __label__ = 22;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 22:
    var $81 = $40 | 0;
    var $83 = __ZN8JSObject15splicePrototypeEP9JSContextPS_($81, $_pre_phi11, $proto_0);
    if ($83) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    __ZN2js15AutoValueRooterD1Ev($tvr2);
    var $cached_2 = $cached_0;
    __label__ = 39;
    break;
   case 24:
    __ZN2js15AutoValueRooterD1Ev($tvr2);
    var $cached_1 = $cached_0;
    var $ctor_1 = $55;
    var $proto_2 = $proto_0;
    __label__ = 25;
    break;
   case 25:
    var $proto_2;
    var $ctor_1;
    var $cached_1;
    var $87 = $ps;
    var $88 = $fs;
    var $89 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($8, $proto_2, $87, $88);
    if ($89) {
      __label__ = 26;
      break;
    } else {
      var $cached_2 = $cached_1;
      __label__ = 39;
      break;
    }
   case 26:
    if (($ctor_1 | 0) == ($proto_2 | 0)) {
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $94 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($8, $ctor_1, 0, 0);
    if ($94) {
      __label__ = 28;
      break;
    } else {
      var $cached_2 = $cached_1;
      __label__ = 39;
      break;
    }
   case 28:
    var $96 = $clasp + 4 | 0;
    var $97 = HEAP32[$96 >> 2];
    if (($97 & 6291456 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    if (($proto_2 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    if (($97 & 2097152 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $107 = __ZN8JSObject6freezeEP9JSContext($proto_2, $_pre_phi11);
    if ($107) {
      __label__ = 32;
      break;
    } else {
      var $cached_2 = $cached_1;
      __label__ = 39;
      break;
    }
   case 32:
    if (($ctor_1 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    if ((HEAP32[$96 >> 2] & 4194304 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $116 = __ZN8JSObject6freezeEP9JSContext($ctor_1, $_pre_phi11);
    if ($116) {
      __label__ = 35;
      break;
    } else {
      var $cached_2 = $cached_1;
      __label__ = 39;
      break;
    }
   case 35:
    if (($cached_1 & 1) << 24 >> 24 != 0 | ($key | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $122 = __ZN2jsL14SetClassObjectEP9JSContextP8JSObject10JSProtoKeyS3_S3_($cx, $obj, $key, $ctor_1, $proto_2);
    if ($122) {
      __label__ = 37;
      break;
    } else {
      var $cached_2 = $cached_1;
      __label__ = 39;
      break;
    }
   case 37:
    if (($ctorp | 0) == 0) {
      var $_0 = $proto_2;
      __label__ = 43;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    HEAP32[$ctorp >> 2] = $ctor_1;
    var $_0 = $proto_2;
    __label__ = 43;
    break;
   case 39:
    var $cached_2;
    if ((HEAP8[$named] & 1) << 24 >> 24 == 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $130 = __ZL12ATOM_TO_JSIDP6JSAtom2291($atom);
    var $131 = $obj;
    var $132 = __ZN8JSObject14deletePropertyEP9JSContextiPN2JS5ValueEi($131, $_pre_phi11, $130, $rval1, 0);
    __label__ = 41;
    break;
   case 41:
    if (($cached_2 & 1) << 24 >> 24 == 0) {
      var $_0 = 0;
      __label__ = 43;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    __ZN2jsL16ClearClassObjectEP9JSContextP8JSObject10JSProtoKey($obj, $key);
    var $_0 = 0;
    __label__ = 43;
    break;
   case 43:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js29DefineConstructorAndPrototypeEP9JSContextP8JSObject10JSProtoKeyP6JSAtomS3_PNS_5ClassEPFiS1_jPN2JS5ValueEEjP14JSPropertySpecP14JSFunctionSpecSF_SH_PS3_["X"] = 1;

function __ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2353($cx, $clasp, $proto, $parent) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb2335($4);
  var $6 = __ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE2326($cx, $clasp, $proto, $parent, $5);
  return $6;
}

function __ZL18DefineStandardSlotP9JSContextP8JSObject10JSProtoKeyP6JSAtomRKN2JS5ValueEjRb($cx, $obj, $key, $atom, $v, $attrs, $named) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL12ATOM_TO_JSIDP6JSAtom2291($atom);
    var $_pre = $obj;
    var $_pre1 = $cx;
    if (($key | 0) == 0) {
      var $_pre_phi = $_pre;
      var $_pre_phi2 = $_pre1;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($_pre, $_pre1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $6 = __ZN8JSObject12nativeLookupEP9JSContexti($_pre, $_pre1, $1);
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_pre_phi = $_pre;
      var $_pre_phi2 = $_pre1;
      __label__ = 7;
      break;
    }
   case 4:
    var $9 = $key + 74 | 0;
    var $10 = __Z18js_SetReservedSlotP9JSContextP8JSObjectjRKN2JS5ValueE($cx, $obj, $9, $v);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $12 = __ZN8JSObject11addPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji($_pre, $_pre1, $1, 10, 12, $9, $attrs, 0, 0);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiRKN2JS5ValueE($_pre1, $_pre, $1, $v);
    HEAP8[$named] = 1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 7:
    var $_pre_phi2;
    var $_pre_phi;
    var $15 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($_pre_phi, $_pre_phi2, $1, $v, 10, 12, $attrs);
    var $16 = ($15 | 0) != 0;
    HEAP8[$named] = $16 & 1;
    var $_0 = $16;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11ObjectValueER8JSObject2354($agg_result, $obj) {
  var $1 = $obj;
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $1);
  return;
}

function __ZN2jsL14SetClassObjectEP9JSContextP8JSObject10JSProtoKeyS3_S3_($cx, $obj, $key, $cobj, $proto) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $_idx_val = HEAP32[$obj + 4 >> 2];
    var $4 = __ZNK8JSObject8isGlobalEv($_idx_val);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 2:
    __ZN2JSL17ObjectOrNullValueEP8JSObject2355($1, $cobj);
    var $6 = __Z18js_SetReservedSlotP9JSContextP8JSObjectjRKN2JS5ValueE($cx, $obj, $key, $1);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = $key + 37 | 0;
    __ZN2JSL17ObjectOrNullValueEP8JSObject2355($2, $proto);
    var $9 = __Z18js_SetReservedSlotP9JSContextP8JSObjectjRKN2JS5ValueE($cx, $obj, $8, $2);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL17ObjectOrNullValueEP8JSObject2355($agg_result, $obj) {
  var $1 = $obj;
  __ZN2JS5Value15setObjectOrNullEP8JSObject($agg_result, $1);
  return;
}

function __ZN2jsL16ClearClassObjectEP9JSContextP8JSObject10JSProtoKey($obj, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $obj;
    var $_idx_val = HEAP32[$obj + 4 >> 2];
    var $5 = __ZNK8JSObject8isGlobalEv($_idx_val);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JSL14UndefinedValueEv2280($1);
    var $_idx2 = $1 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($3, $key, $_idx2_val$0, $_idx2_val$1);
    var $7 = $key + 37 | 0;
    __ZN2JSL14UndefinedValueEv2280($2);
    var $_idx1 = $2 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($3, $7, $_idx1_val$0, $_idx1_val$1);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js23IsStandardClassResolvedEP8JSObjectPNS_5ClassE($obj, $clasp_0_1_val) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 8;
  var $3 = $clasp_0_1_val >>> 24;
  var $4 = $obj;
  __ZNK8JSObject15getReservedSlotEj($1, $4, $3);
  __ZN2JSL14UndefinedValueEv2280($2);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $_idx1 = $2 | 0;
  var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
  var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
  var $5 = __ZNK2JS5ValueneERKS0_($_idx_val$0, $_idx_val$1, $_idx1_val$0, $_idx1_val$1);
  STACKTOP = __stackBase__;
  return $5;
}

function __ZN2js35MarkStandardClassInitializedNoProtoEP8JSObjectPNS_5ClassE($obj, $clasp_0_1_val) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = $clasp_0_1_val >>> 24;
    var $5 = $obj;
    __ZNK8JSObject15getReservedSlotEj($1, $5, $4);
    __ZN2JSL14UndefinedValueEv2280($2);
    var $_idx1 = $1 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $_idx2 = $2 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    var $6 = __ZNK2JS5ValueeqERKS0_($_idx1_val$0, $_idx1_val$1, $_idx2_val$0, $_idx2_val$1);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JSL12BooleanValueEb2297($3, 1);
    var $_idx = $3 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($5, $4, $_idx_val$0, $_idx_val$1);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z12js_InitClassP9JSContextP8JSObjectS2_PN2js5ClassEPFiS0_jPN2JS5ValueEEjP14JSPropertySpecP14JSFunctionSpecSC_SE_PS2_($cx, $obj, $protoProto, $clasp, $constructor, $nargs, $ps, $fs, $ctorp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $protoProto;
    var $3 = HEAP32[$clasp >> 2];
    var $4 = _strlen($3);
    var $5 = $cx;
    var $6 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($5, $3, $4, 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = HEAPU32[$clasp + 4 >> 2] >>> 24;
    if (($11 | 0) != 0 & ($protoProto | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $18 = $protoProto;
      __label__ = 5;
      break;
    }
   case 3:
    var $15 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($cx, $obj, 1, $1, 0);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $18 = HEAP32[$1 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextP8JSObject10JSProtoKeyP6JSAtomS3_PNS_5ClassEPFiS1_jPN2JS5ValueEEjP14JSPropertySpecP14JSFunctionSpecSF_SH_PS3_($cx, $obj, $11, $6, $18, $clasp, $constructor, $nargs, $ps, $fs, $ctorp);
    var $_0 = $19;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($cx, $scopeobj, $protoKey, $protop, $clasp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($protoKey | 0) == 0) {
      var $_2 = $scopeobj;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($scopeobj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_1 = $scopeobj;
      __label__ = 7;
      break;
    }
   case 3:
    var $6 = $cx;
    var $7 = __ZNK9JSContext5hasfpEv($6);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZNK9JSContext2fpEv($6);
    var $10 = __ZNK2js10StackFrame10scopeChainEv($9);
    var $11 = $10;
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_1 = $11;
      __label__ = 7;
      break;
    }
   case 5:
    var $14 = HEAP32[$cx + 132 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_1 = $14;
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$protop >> 2] = 0;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 7:
    var $_1;
    var $18 = __ZNK8JSObject9getGlobalEv($_1);
    var $19 = $18 | 0;
    var $_idx2_val = HEAP32[$18 + 4 >> 2];
    var $21 = __ZNK8JSObject8isGlobalEv($_idx2_val);
    if ($21) {
      __label__ = 8;
      break;
    } else {
      var $_2 = $19;
      __label__ = 10;
      break;
    }
   case 8:
    var $23 = $18;
    var $24 = $protoKey + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $23, $24);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $25 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($25) {
      __label__ = 9;
      break;
    } else {
      var $_2 = $19;
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $28 = $27;
    HEAP32[$protop >> 2] = $28;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 10:
    var $_2;
    var $30 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($cx, $_2, $protoKey, $protop, $clasp);
    var $_0 = $30 & 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2364($vec, $len, $useHoles) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($len | 0) == 0;
    if ($useHoles) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    if ($1) {
      __label__ = 6;
      break;
    } else {
      var $i_04 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    if ($1) {
      __label__ = 6;
      break;
    } else {
      var $i1_01 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $i_04;
    var $2 = $vec + ($i_04 << 3) | 0;
    __ZN2JS5Value8setMagicE10JSWhyMagic($2, 0);
    var $3 = $i_04 + 1 | 0;
    if (($3 | 0) == ($len | 0)) {
      __label__ = 6;
      break;
    } else {
      var $i_04 = $3;
      __label__ = 4;
      break;
    }
   case 5:
    var $i1_01;
    var $4 = $vec + ($i1_01 << 3) | 0;
    __ZN2JS5Value12setUndefinedEv($4);
    var $5 = $i1_01 + 1 | 0;
    if (($5 | 0) == ($len | 0)) {
      __label__ = 6;
      break;
    } else {
      var $i1_01 = $5;
      __label__ = 5;
      break;
    }
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject10allocSlotsEP9JSContextj($this, $cx, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $kind = __stackBase__;
    var $1 = $this;
    var $_idx5_val = HEAP32[$this + 8 >> 2];
    var $3 = __ZNK8JSObject11hasLazyTypeEv($_idx5_val);
    if ($3) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx10 = $this + 36 | 0;
    var $_idx10_val = HEAP32[$_idx10 >> 2];
    var $6 = __ZNK8JSObject4typeEv($_idx10_val);
    var $8 = HEAP32[$6 + 16 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAP32[$8 + 4 >> 2];
    HEAP32[$kind >> 2] = $12;
    var $13 = __ZN2js2gcL14GetGCKindSlotsENS0_9AllocKindE2367($12);
    var $14 = __ZNK8JSObject13numFixedSlotsEv($_idx5_val);
    if (($13 | 0) == ($14 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $17 = __ZN2js2gcL21TryIncrementAllocKindEPNS0_9AllocKindE($kind);
    if ($17) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $_idx9_val = HEAP32[$_idx10 >> 2];
    var $20 = __ZNK8JSObject4typeEv($_idx9_val);
    var $21 = $20;
    var $_idx2_val = HEAP32[$this + 20 >> 2];
    var $23 = __ZNK8JSObject9getParentEv($_idx2_val);
    var $24 = $23;
    var $25 = HEAP32[$kind >> 2];
    var $30 = HEAP32[HEAP32[$20 + 16 >> 2] + 8 >> 2];
    var $31 = __ZN2js17NewReshapedObjectEP9JSContextPNS_5types10TypeObjectEP8JSObjectNS_2gc9AllocKindEPKNS_5ShapeE($cx, $21, $24, $25, $30);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx8_val = HEAP32[$_idx10 >> 2];
    var $35 = __ZNK8JSObject4typeEv($_idx8_val);
    var $38 = HEAP32[$35 + 16 >> 2] + 4 | 0;
    HEAP32[$38 >> 2] = $25;
    var $_idx1_val = HEAP32[$31 >> 2];
    var $39 = __ZNK8JSObject12lastPropertyEv($_idx1_val);
    var $_idx7_val = HEAP32[$_idx10 >> 2];
    var $41 = __ZNK8JSObject4typeEv($_idx7_val);
    var $44 = HEAP32[$41 + 16 >> 2] + 8 | 0;
    HEAP32[$44 >> 2] = $39;
    var $_idx6_val = HEAP32[$_idx10 >> 2];
    var $46 = __ZNK8JSObject4typeEv($_idx6_val);
    var $47 = $cx;
    __ZN2js5types10TypeObject15markStateChangeEP9JSContext($46, $47);
    __label__ = 7;
    break;
   case 7:
    if ($newcap >>> 0 > 536870912) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $51 = $cx;
    __Z27js_ReportAllocationOverflowP9JSContext($51);
    var $_0 = 0;
    __label__ = 14;
    break;
   case 9:
    var $53 = __ZNK8JSObject15numDynamicSlotsEj($1, $newcap);
    var $54 = $53 << 3;
    var $55 = $cx;
    var $56 = __ZN9JSContext7malloc_Ej($55, $54);
    if (($56 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $59 = $56;
    HEAP32[$this + 32 >> 2] = $59;
    HEAP32[$this + 28 >> 2] = $newcap;
    var $_idx3_val = HEAP32[$this + 4 >> 2];
    var $63 = __ZNK8JSObject12isDenseArrayEv($_idx3_val);
    if ($63) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $65 = __ZNK8JSObject10fixedSlotsEv($1);
    var $66 = $65;
    var $67 = __ZN8JSObject30getDenseArrayInitializedLengthEv($1);
    var $68 = $67 << 3;
    _memcpy($56, $66, $68, 1);
    var $_idx4_val = HEAP8[$cx + 232 | 0];
    var $70 = __ZN9JSContext20typeInferenceEnabledEv($_idx4_val);
    if ($70) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN8JSObject23backfillDenseArrayHolesEP9JSContext($1, $55);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 13:
    __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2364($59, $53, 0);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject10allocSlotsEP9JSContextj["X"] = 1;

function __ZN2js5types21MarkObjectStateChangeEP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $_idx_val = HEAP8[$cx + 232 | 0];
    var $3 = __ZN9JSContext20typeInferenceEnabledEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$obj + 8 >> 2];
    var $6 = __ZNK8JSObject11hasLazyTypeEv($_idx1_val);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx2_val = HEAP32[$obj + 36 >> 2];
    var $9 = __ZNK8JSObject4typeEv($_idx2_val);
    var $_idx3_val = HEAP32[$9 + 12 >> 2];
    var $10 = __ZN2js5types10TypeObject17unknownPropertiesEv($_idx3_val);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js5types10TypeObject15markStateChangeEP9JSContext($9, $1);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject11shrinkSlotsEP9JSContextj($this, $cx, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx5 = $this + 4 | 0;
    var $1 = HEAPU32[$_idx5 >> 2];
    var $_idx5_val = $1;
    var $2 = __ZNK8JSObject6isCallEv($_idx5_val);
    if ($2) {
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $this + 28 | 0;
    var $_idx1_val = HEAP32[$4 >> 2];
    var $5 = __ZNK8JSObject8numSlotsEv($_idx1_val);
    if ($5 >>> 0 < 9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $this;
    var $9 = __ZNK8JSObject13hasSlotsArrayEv($8);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx4_val = $1;
    var $11 = __ZNK8JSObject12isDenseArrayEv($_idx4_val);
    if ($11) {
      __label__ = 13;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = $5 - $newcap | 0;
    __ZN8JSObject14clearSlotRangeEjj($this, $newcap, $13);
    __label__ = 13;
    break;
   case 6:
    var $15 = __ZN2jsL3MaxIjEET_S1_S1_2347($newcap, 8);
    var $_idx_val = HEAP32[$this + 8 >> 2];
    var $17 = __ZNK8JSObject13numFixedSlotsEv($_idx_val);
    var $18 = __ZN2jsL3MaxIjEET_S1_S1_2347($15, $17);
    var $19 = $this + 32 | 0;
    var $21 = HEAP32[$19 >> 2];
    var $22 = $18 << 3;
    var $23 = $cx;
    var $24 = __ZN9JSContext8realloc_EPvj($23, $21, $22);
    var $25 = $24;
    if (($24 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $29 = (HEAP32[$19 >> 2] | 0) == ($25 | 0);
    HEAP32[$19 >> 2] = $25;
    HEAP32[$4 >> 2] = $18;
    if ($18 >>> 0 > $newcap >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $_idx3_val = HEAP32[$_idx5 >> 2];
    var $33 = __ZNK8JSObject12isDenseArrayEv($_idx3_val);
    if ($33) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $35 = $18 - $newcap | 0;
    __ZN8JSObject14clearSlotRangeEjj($this, $newcap, $35);
    __label__ = 10;
    break;
   case 10:
    if ($29) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_idx2_val = HEAP32[$_idx5 >> 2];
    var $39 = __ZNK8JSObject8isGlobalEv($_idx2_val);
    if ($39) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    __ZN2js5types21MarkObjectStateChangeEP9JSContextP8JSObject($cx, $this);
    __label__ = 13;
    break;
   case 13:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject11shrinkSlotsEP9JSContextj["X"] = 1;

function __ZN2js8SetProtoEP9JSContextP8JSObjectS3_b($cx, $obj, $proto, $checkForCycles) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $_idx2_val = HEAP32[$obj >> 2];
    var $2 = __ZNK8JSObject8isNativeEv($_idx2_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($1, $4);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 3:
    var $7 = ($proto | 0) != 0;
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx8 = $cx + 52 | 0;
    var $oldproto_0 = $obj;
    __label__ = 7;
    break;
   case 5:
    var $_idx7_val = HEAP32[$proto + 4 >> 2];
    var $10 = __ZNK8JSObject5isXMLEv($_idx7_val);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 6:
    var $12 = $cx;
    _JS_ReportErrorNumber($12, 4, 272, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 7:
    var $oldproto_0;
    if (($oldproto_0 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx1_val = HEAP32[$oldproto_0 >> 2];
    var $15 = __ZNK8JSObject8isNativeEv($_idx1_val);
    if ($15) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $_idx8_val = HEAP32[$_idx8 >> 2];
    __ZN8JSObject16protoShapeChangeEP9JSContext($oldproto_0, $_idx8_val);
    var $_idx4_val_idx_val = HEAP32[HEAP32[$oldproto_0 + 36 >> 2] >> 2];
    var $20 = __ZNK8JSObject8getProtoEv($_idx4_val_idx_val);
    var $oldproto_0 = $20;
    __label__ = 7;
    break;
   case 10:
    if ($checkForCycles) {
      var $obj2_0 = $proto;
      __label__ = 11;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 11:
    var $obj2_0;
    if (($obj2_0 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (($obj2_0 | 0) == ($obj | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $26 = $cx;
    _JS_ReportErrorNumber($26, 4, 36, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_proto_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 14:
    var $_idx3_val_idx_val = HEAP32[HEAP32[$obj2_0 + 36 >> 2] >> 2];
    var $29 = __ZNK8JSObject8getProtoEv($_idx3_val_idx_val);
    var $obj2_0 = $29;
    __label__ = 11;
    break;
   case 15:
    var $_idx_val = HEAP32[$obj + 8 >> 2];
    var $32 = __ZNK8JSObject16hasSingletonTypeEv($_idx_val);
    if ($32) {
      __label__ = 16;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 16:
    var $34 = $cx;
    var $35 = $proto;
    var $36 = __ZN8JSObject15splicePrototypeEP9JSContextPS_($1, $34, $35);
    if ($36) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 17:
    var $_idx6_val = HEAP32[$obj + 36 >> 2];
    var $39 = __ZNK8JSObject4typeEv($_idx6_val);
    __ZN2js5types31MarkTypeObjectUnknownPropertiesEP9JSContextPNS0_10TypeObjectEb($34, $39, 0);
    var $_0 = 1;
    __label__ = 22;
    break;
   case 18:
    if ($7) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $47 = __ZN2js5types15emptyTypeObjectE;
    var $_pre_phi = $cx;
    __label__ = 21;
    break;
   case 20:
    var $42 = $proto;
    var $43 = $cx;
    var $44 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($42, $43, 0, 1);
    var $45 = $44;
    if (($44 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      var $47 = $45;
      var $_pre_phi = $43;
      __label__ = 21;
      break;
    }
   case 21:
    var $_pre_phi;
    var $47;
    var $_idx5_val = HEAP32[$obj + 36 >> 2];
    var $49 = __ZNK8JSObject4typeEv($_idx5_val);
    __ZN2js5types31MarkTypeObjectUnknownPropertiesEP9JSContextPNS0_10TypeObjectEb($_pre_phi, $49, 1);
    var $50 = $47;
    __ZN2js5types31MarkTypeObjectUnknownPropertiesEP9JSContextPNS0_10TypeObjectEb($_pre_phi, $50, 1);
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($1, $50);
    var $_0 = 1;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8SetProtoEP9JSContextP8JSObjectS3_b["X"] = 1;

function __ZN2jsL16GetClassProtoKeyEPNS_5ClassE2381($clasp_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $clasp_0_1_val >>> 24;
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $clasp_0_1_val >>> 17 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_GetClassObjectP9JSContextP8JSObject10JSProtoKeyPS2_($cx, $obj, $key, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $resolving = __stackBase__ + 8;
    var $1 = __ZNK8JSObject9getGlobalEv($obj);
    var $2 = $1 | 0;
    var $3 = $1;
    var $_idx_val = HEAP32[$1 + 4 >> 2];
    var $5 = __ZNK8JSObject8isGlobalEv($_idx_val);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$objp >> 2] = 0;
    var $_1 = 1;
    __label__ = 12;
    break;
   case 3:
    __ZNK8JSObject15getReservedSlotEj($v, $3, $key);
    var $v_idx1 = $v | 0;
    var $v_idx1_val$0 = HEAP32[$v_idx1 >> 2];
    var $v_idx1_val$1 = HEAP32[$v_idx1 + 4 >> 2];
    var $8 = __ZNK2JS5Value8isObjectEv($v_idx1_val$0, $v_idx1_val$1);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = __ZNK2JS5Value8toObjectEv($v_idx1_val$0, $v_idx1_val$1);
    var $11 = $10;
    HEAP32[$objp >> 2] = $11;
    var $_1 = 1;
    __label__ = 12;
    break;
   case 5:
    var $17 = HEAP32[HEAP32[$cx + 52 >> 2] + 210020 + ($key << 2) >> 2] | 0;
    var $18 = __ZL12ATOM_TO_JSIDP6JSAtom2291($17);
    __ZN2js13AutoResolvingC1EP9JSContextP8JSObjectiNS0_4KindE($resolving, $cx, $2, $18, 0);
    var $19 = __ZNK2js13AutoResolving14alreadyStartedEv($resolving);
    if ($19) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$objp >> 2] = 0;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 7:
    var $23 = HEAP32[__ZL19lazy_prototype_init + ($key << 2) >> 2];
    var $24 = FUNCTION_TABLE[$23]($cx, $2);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZNK8JSObject15getReservedSlotEj($v, $3, $key);
    var $v_idx_val$0 = HEAP32[$v_idx1 >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx1 + 4 >> 2];
    var $27 = __ZNK2JS5Value8isObjectEv($v_idx_val$0, $v_idx_val$1);
    if ($27) {
      __label__ = 9;
      break;
    } else {
      var $cobj_0 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    var $29 = __ZNK2JS5Value8toObjectEv($v_idx_val$0, $v_idx_val$1);
    var $cobj_0 = $29;
    __label__ = 10;
    break;
   case 10:
    var $cobj_0;
    HEAP32[$objp >> 2] = $cobj_0;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    var $resolving_idx_val = HEAP32[$resolving >> 2];
    var $resolving_idx4_val = HEAP32[$resolving + 16 >> 2];
    __ZN2js13AutoResolvingD1Ev($resolving_idx_val, $resolving_idx4_val);
    var $_1 = $_0;
    __label__ = 12;
    break;
   case 12:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z17js_GetClassObjectP9JSContextP8JSObject10JSProtoKeyPS2_["X"] = 1;

function __ZN2js13AutoResolvingC1EP9JSContextP8JSObjectiNS0_4KindE($this, $cx, $obj, $id, $kind) {
  __ZN2js13AutoResolvingC2EP9JSContextP8JSObjectiNS0_4KindE($this, $cx, $obj, $id, $kind);
  return;
}

function __ZNK2js13AutoResolving14alreadyStartedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 16 >> 2] | 0) == 0) {
      var $8 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $this;
    var $6 = __ZNK2js13AutoResolving18alreadyStartedSlowEv($5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13AutoResolvingD1Ev($this_0_0_val, $this_0_4_val) {
  __ZN2js13AutoResolvingD2Ev($this_0_0_val, $this_0_4_val);
  return;
}

function __Z18js_FindClassObjectP9JSContextP8JSObject10JSProtoKeyPN2JS5ValueEPN2js5ClassE($cx, $start, $protoKey, $vp, $clasp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $cobj = __stackBase__ + 4;
    var $pobj = __stackBase__ + 8;
    var $prop = __stackBase__ + 12;
    var $v = __stackBase__ + 16;
    if (($start | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_1 = $start;
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $cx;
    var $4 = __ZNK9JSContext7maybefpEv($3);
    if (($4 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js10StackFrame10scopeChainEv($4);
    var $8 = $7;
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_1 = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $_1;
    HEAP32[$obj >> 2] = $_1;
    var $_idx_val = HEAP32[$_1 + 20 >> 2];
    var $11 = __ZNK8JSObject9getParentEv($_idx_val);
    var $12 = $11;
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $_1 = $12;
      __label__ = 4;
      break;
    }
   case 5:
    var $15 = HEAP32[$cx + 132 >> 2];
    HEAP32[$obj >> 2] = $15;
    if (($15 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_pre_phi = $3;
      __label__ = 8;
      break;
    }
   case 6:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 7:
    var $_pre_phi = $cx;
    __label__ = 8;
    break;
   case 8:
    var $_pre_phi;
    var $18 = $obj;
    __Z19OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($_pre_phi, $18);
    var $19 = HEAP32[$obj >> 2];
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (($protoKey | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $24 = __Z17js_GetClassObjectP9JSContextP8JSObject10JSProtoKeyPS2_($cx, $19, $protoKey, $cobj);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $27 = HEAP32[$cobj >> 2];
    if (($27 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $30 = $27;
    __ZN2JS5Value9setObjectER8JSObject($vp, $30);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 13:
    var $36 = HEAP32[HEAP32[$cx + 52 >> 2] + 210020 + ($protoKey << 2) >> 2] | 0;
    var $37 = __ZL12ATOM_TO_JSIDP6JSAtom2291($36);
    var $id_0 = $37;
    __label__ = 16;
    break;
   case 14:
    var $40 = HEAP32[$clasp >> 2];
    var $41 = _strlen($40);
    var $42 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($_pre_phi, $40, $41, 0);
    if (($42 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $45 = __ZL12ATOM_TO_JSIDP6JSAtom2291($42);
    var $id_0 = $45;
    __label__ = 16;
    break;
   case 16:
    var $id_0;
    var $47 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($cx, $19, $id_0, 16, $pobj, $prop);
    if ($47) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 17:
    __ZN2JSL14UndefinedValueEv2280($v);
    var $49 = HEAP32[$prop >> 2];
    if (($49 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $52 = HEAP32[$pobj >> 2];
    var $53 = $52;
    var $_idx1_val = HEAP32[$52 >> 2];
    var $54 = __ZNK8JSObject8isNativeEv($_idx1_val);
    if ($54) {
      __label__ = 19;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 19:
    var $58 = HEAP32[$49 + 24 >> 2];
    var $_idx2_val_idx_val = HEAP32[$_idx1_val + 4 >> 2];
    var $59 = __ZNK8JSObject12containsSlotEj($_idx2_val_idx_val, $58);
    if ($59) {
      __label__ = 20;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 20:
    var $61 = __ZNK8JSObject13nativeGetSlotEj($53, $58);
    var $62 = $61 | 0;
    var $63$0 = HEAP32[$62 >> 2];
    var $63$1 = HEAP32[$62 + 4 >> 2];
    var $64 = $v | 0;
    HEAP32[$64 >> 2] = $63$0;
    HEAP32[$64 + 4 >> 2] = $63$1;
    var $65 = __ZNK2JS5Value11isPrimitiveEv($63$0, $63$1);
    if ($65) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    __ZN2JS5Value12setUndefinedEv($v);
    __label__ = 22;
    break;
   case 22:
    var $67 = $v | 0;
    var $68$0 = HEAP32[$67 >> 2];
    var $68$1 = HEAP32[$67 + 4 >> 2];
    var $69 = $vp | 0;
    HEAP32[$69 >> 2] = $68$0;
    HEAP32[$69 + 4 >> 2] = $68$1;
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18js_FindClassObjectP9JSContextP8JSObject10JSProtoKeyPN2JS5ValueEPN2js5ClassE["X"] = 1;

function __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($cx, $obj, $id, $flags, $objp, $propp) {
  var $1 = __Z22js_CheckForStringIndexi($id);
  var $2 = __ZL29LookupPropertyWithFlagsInlineP9JSContextP8JSObjectijPS2_PP10JSProperty($cx, $obj, $1, $flags, $objp, $propp);
  return $2;
}

function __Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE($cx, $clasp, $parent, $argc, $argv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $argtvr = __stackBase__;
    var $tvr = __stackBase__ + 16;
    var $rval = __stackBase__ + 40;
    var $rval1 = __stackBase__ + 48;
    var $1 = $cx;
    __ZN2js15AutoArrayRooterC1EP9JSContextjPN2JS5ValueE($argtvr, $1, $argc, $argv);
    var $clasp_idx = $clasp + 4 | 0;
    var $clasp_idx_val = HEAP32[$clasp_idx >> 2];
    var $2 = __ZN2jsL16GetClassProtoKeyEPNS_5ClassE2381($clasp_idx_val);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $1);
    var $3 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $4 = __Z18js_FindClassObjectP9JSContextP8JSObject10JSProtoKeyPN2JS5ValueEPN2js5ClassE($cx, $parent, $2, $3, $clasp);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $_idx5 = $7 | 0;
    var $_idx5_val$0 = HEAP32[$_idx5 >> 2];
    var $_idx5_val$1 = HEAP32[$_idx5 + 4 >> 2];
    var $8 = __ZNK2JS5Value11isPrimitiveEv($_idx5_val$0, $_idx5_val$1);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj($1, $3, 65664);
    var $_0 = 0;
    __label__ = 16;
    break;
   case 4:
    var $11 = __ZNK2JS5Value8toObjectEv($_idx5_val$0, $_idx5_val$1);
    if (($parent | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_02 = $parent;
      __label__ = 6;
      break;
    }
   case 5:
    var $_idx2_val = HEAP32[$11 + 20 >> 2];
    var $14 = __ZNK8JSObject9getParentEv($_idx2_val);
    var $_02 = $14;
    __label__ = 6;
    break;
   case 6:
    var $_02;
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210200 >> 2];
    var $21 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($11, $1, $20, $rval);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $rval_idx7 = $rval | 0;
    var $st$1$0 = $rval_idx7 | 0;
    var $rval_idx7_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $rval_idx7 + 4 | 0;
    var $rval_idx7_val$1 = HEAP32[$st$1$1 >> 2];
    var $24 = __ZNK2JS5Value14isObjectOrNullEv($rval_idx7_val$0, $rval_idx7_val$1);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $_01 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = __ZNK2JS5Value14toObjectOrNullEv($rval_idx7_val$0, $rval_idx7_val$1);
    var $_01 = $26;
    __label__ = 9;
    break;
   case 9:
    var $_01;
    var $29 = __ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2353($cx, $clasp, $_01, $_02);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $32 = $29;
    __ZN8JSObject19syncSpecialEqualityEv($32);
    var $33 = $29;
    var $_idx6_val = HEAP32[$29 + 36 >> 2];
    var $35 = __ZNK8JSObject4typeEv($_idx6_val);
    __ZN2js5types31MarkTypeObjectUnknownPropertiesEP9JSContextPNS0_10TypeObjectEb($1, $35, 0);
    var $36 = __ZN2js30InvokeConstructorWithGivenThisEP9JSContextP8JSObjectRKN2JS5ValueEjPS5_S8_($1, $33, $7, $argc, $argv, $rval1);
    if ($36) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 11:
    var $rval1_idx4 = $rval1 | 0;
    var $st$1$0 = $rval1_idx4 | 0;
    var $rval1_idx4_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $rval1_idx4 + 4 | 0;
    var $rval1_idx4_val$1 = HEAP32[$st$1$1 >> 2];
    var $38 = __ZNK2JS5Value11isPrimitiveEv($rval1_idx4_val$0, $rval1_idx4_val$1);
    if ($38) {
      var $_0 = $29;
      __label__ = 16;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $40 = __ZNK2JS5Value8toObjectEv($rval1_idx4_val$0, $rval1_idx4_val$1);
    var $41 = $40;
    var $_idx3_val = HEAP32[$40 + 4 >> 2];
    var $42 = __ZNK8JSObject8getClassEv($_idx3_val);
    if (($42 | 0) == ($clasp | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    if ((HEAP32[$clasp_idx >> 2] & 65 | 0) == 65) {
      __label__ = 14;
      break;
    } else {
      var $_0 = $41;
      __label__ = 16;
      break;
    }
   case 14:
    var $_idx_val = HEAP32[$40 + 24 >> 2];
    var $50 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($50 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      var $_0 = $41;
      __label__ = 16;
      break;
    }
   case 15:
    var $54 = HEAP32[$clasp >> 2];
    _JS_ReportErrorNumber($1, 4, 207, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $54, tempInt));
    var $_0 = 0;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    __ZN2js15AutoArrayRooterD1Ev($argtvr);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE["X"] = 1;

function __ZN8JSObject9allocSlotEP9JSContextPj($this, $cx, $slotp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this;
    var $_idx2_val = HEAP32[$this >> 2];
    var $_idx2_val_idx_val = HEAP32[$_idx2_val + 4 >> 2];
    var $3 = __ZNK8JSObject8slotSpanEv($_idx2_val_idx_val);
    var $4 = __ZNK8JSObject16inDictionaryModeEv($_idx2_val);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$_idx2_val + 8 >> 2];
    var $7 = __ZNK2js5Shape8hasTableEv($_idx_val);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = __ZNK2js5Shape8getTableEv($_idx2_val);
    var $10 = $9 + 12 | 0;
    var $11 = HEAP32[$10 >> 2];
    if (($11 | 0) == -1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$slotp >> 2] = $11;
    var $14 = __ZNK8JSObject7getSlotEj($2, $11);
    var $_idx4 = $14 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    var $15 = __ZNK2JS5Value15toPrivateUint32Ev($_idx4_val$0, $_idx4_val$1);
    HEAP32[$10 >> 2] = $15;
    __ZN2JSL14UndefinedValueEv2280($1);
    var $_idx5 = $1 | 0;
    var $_idx5_val$0 = HEAP32[$_idx5 >> 2];
    var $_idx5_val$1 = HEAP32[$_idx5 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, $11, $_idx5_val$0, $_idx5_val$1);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 5:
    var $_idx1_val = HEAP32[$this + 28 >> 2];
    var $18 = __ZNK8JSObject8numSlotsEv($_idx1_val);
    if ($3 >>> 0 < $18 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = $3 + 1 | 0;
    var $22 = __ZN8JSObject9growSlotsEP9JSContextj($this, $cx, $21);
    if ($22) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    HEAP32[$slotp >> 2] = $3;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject8freeSlotEP9JSContextj($this, $slot) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $this;
    var $_idx2_val = HEAP32[$this >> 2];
    var $_idx2_val_idx_val = HEAP32[$_idx2_val + 4 >> 2];
    var $4 = __ZNK8JSObject8slotSpanEv($_idx2_val_idx_val);
    var $5 = __ZNK8JSObject16inDictionaryModeEv($_idx2_val);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$_idx2_val + 8 >> 2];
    var $8 = __ZNK2js5Shape8hasTableEv($_idx_val);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = __ZNK2js5Shape8getTableEv($_idx2_val);
    var $11 = $10 + 12 | 0;
    var $_idx1_val = HEAP32[$this + 4 >> 2];
    var $13 = __ZNK8JSObject8getClassEv($_idx1_val);
    if ((HEAPU32[$13 + 4 >> 2] >>> 8 & 255) >>> 0 <= $slot >>> 0 & ($slot + 1 | 0) >>> 0 < $4 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $22 = HEAP32[$11 >> 2];
    __ZN2JSL18PrivateUint32ValueEj2384($1, $22);
    var $_idx5 = $1 | 0;
    var $_idx5_val$0 = HEAP32[$_idx5 >> 2];
    var $_idx5_val$1 = HEAP32[$_idx5 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($3, $slot, $_idx5_val$0, $_idx5_val$1);
    HEAP32[$11 >> 2] = $slot;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    __ZN2JSL14UndefinedValueEv2280($2);
    var $_idx4 = $2 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($3, $slot, $_idx4_val$0, $_idx4_val$1);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL18PrivateUint32ValueEj2384($agg_result, $ui) {
  __ZN2JS5Value16setPrivateUint32Ej($agg_result, $ui);
  return;
}

function __Z24js_PurgeScopeChainHelperP9JSContextP8JSObjecti($cx, $obj, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx1_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $2 = __ZNK8JSObject8getProtoEv($_idx1_val_idx_val);
    var $3 = $2;
    var $4 = __ZL15PurgeProtoChainP9JSContextP8JSObjecti($cx, $3, $id);
    var $_idx2_val = HEAP32[$obj + 4 >> 2];
    var $6 = __ZNK8JSObject6isCallEv($_idx2_val);
    if ($6) {
      var $_0 = $obj;
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $_0;
    var $_idx_val = HEAP32[$_0 + 20 >> 2];
    var $8 = __ZNK8JSObject9getParentEv($_idx_val);
    var $9 = $8;
    if (($8 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZL15PurgeProtoChainP9JSContextP8JSObjecti($cx, $9, $id);
    if (($12 | 0) == 0) {
      var $_0 = $9;
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15PurgeProtoChainP9JSContextP8JSObjecti($cx, $obj, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $_01 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    if (($_01 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = $_01;
    var $_idx_val = HEAP32[$_01 >> 2];
    var $6 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($6) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx2_val_idx_val = HEAP32[HEAP32[$_01 + 36 >> 2] >> 2];
    var $9 = __ZNK8JSObject8getProtoEv($_idx2_val_idx_val);
    var $_01_be_in = $9;
    __label__ = 5;
    break;
   case 5:
    var $_01_be_in;
    var $_01 = $_01_be_in;
    __label__ = 2;
    break;
   case 6:
    var $11 = __ZN8JSObject12nativeLookupEP9JSContexti($5, $1, $id);
    if (($11 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx3_val = HEAP32[$cx + 52 >> 2];
    __ZN8JSObject20shadowingShapeChangeEP9JSContextRKN2js5ShapeE($5, $_idx3_val);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 8:
    var $_idx1_val_idx_val = HEAP32[HEAP32[$_01 + 36 >> 2] >> 2];
    var $17 = __ZNK8JSObject8getProtoEv($_idx1_val_idx_val);
    var $_01_be_in = $17;
    __label__ = 5;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z20js_AddNativePropertyP9JSContextP8JSObjectiPFiS0_S2_iPN2JS5ValueEEPFiS0_S2_iiS5_Ejjji($cx, $obj, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z22js_CheckForStringIndexi($id);
    var $2 = $cx;
    var $3 = $obj;
    __Z18js_PurgeScopeChainP9JSContextP8JSObjecti($2, $3, $1);
    var $4 = __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($3, $2);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZN8JSObject11putPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji($3, $2, $1, 178, 180, -1, 1, 0, 0);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z28js_ChangeNativePropertyAttrsP9JSContextP8JSObjectPKN2js5ShapeEjjPFiS0_S2_iPN2JS5ValueEEPFiS0_S2_iiS9_E($cx, $obj, $shape, $attrs, $getter, $setter) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $obj;
    var $2 = $cx;
    var $3 = __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($1, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    if (($attrs & 2 | 0) == 0) {
      var $_01 = $getter;
      var $_02 = $shape;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $shape;
    var $_idx_val = HEAP8[$shape + 29 | 0];
    var $10 = __ZNK2js5Shape8isMethodEv($_idx_val);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      var $_01 = $getter;
      var $_02 = $shape;
      __label__ = 7;
      break;
    }
   case 4:
    var $12 = __ZNK2js5Shape12methodObjectEv($8);
    var $13 = $12;
    __ZN2JSL11ObjectValueER8JSObject2354($v, $13);
    var $14 = __ZN8JSObject17methodReadBarrierEP9JSContextRKN2js5ShapeEPN2JS5ValueE($1, $2, $8, $v);
    var $15 = $14;
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = $getter;
    var $19 = __ZN2js12CastAsObjectEPFiP9JSContextP8JSObjectiPN2JS5ValueEE($18);
    if (($19 | 0) == ($12 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $_01 = $getter;
      var $_02 = $15;
      __label__ = 7;
      break;
    }
   case 6:
    var $_01 = 0;
    var $_02 = $15;
    __label__ = 7;
    break;
   case 7:
    var $_02;
    var $_01;
    var $25 = $setter;
    var $26 = __ZN8JSObject14changePropertyEP9JSContextPKN2js5ShapeEjjPFiS1_PS_iPN2JS5ValueEEPFiS1_S6_iiS9_E($1, $2, $_02, $attrs, 0, $_01, $25);
    var $_0 = $26;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $id, $value, $getter_coerce, $setter, $attrs) {
  var $1 = $getter_coerce;
  var $2 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($cx, $obj, $id, $value, $1, $setter, $attrs, 0, 0, 0);
  return ($2 | 0) != 0 & 1;
}

function __Z16js_DefineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $index, $value, $getter_coerce, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $getter_coerce;
    var $5 = HEAP32[$id >> 2];
    var $6 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($cx, $obj, $5, $value, $4, $setter, $attrs, 0, 0, 0);
    var $_0 = ($6 | 0) != 0 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject18methodWriteBarrierEP9JSContextRKN2js5ShapeERKN2JS5ValueE($this, $cx, $shape, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $_idx_val = HEAP32[$this + 8 >> 2];
    var $3 = __ZN8JSObject25brandedOrHasMethodBarrierEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $shape;
      __label__ = 5;
      break;
    }
   case 2:
    var $6 = HEAP32[$shape + 24 >> 2];
    if (($6 | 0) == -1) {
      var $_0 = $shape;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZNK8JSObject13nativeGetSlotEj($1, $6);
    var $_idx1 = $9 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $10 = __ZL18ChangesMethodValueRKN2JS5ValueES2_($_idx1_val$0, $_idx1_val$1, $v);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $shape;
      __label__ = 5;
      break;
    }
   case 4:
    var $12 = $cx;
    var $13 = $shape;
    var $14 = __ZN8JSObject17methodShapeChangeEP9JSContextRKN2js5ShapeE($1, $12, $13);
    var $_0 = $14;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19CallAddPropertyHookP9JSContextPN2js5ClassEP8JSObjectPKNS1_5ShapeEPN2JS5ValueE($cx, $clasp_0_2_val, $obj, $shape, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($clasp_0_2_val | 0) == 10) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $vp | 0;
    var $4$0 = HEAP32[$3 >> 2];
    var $4$1 = HEAP32[$3 + 4 >> 2];
    var $5 = $clasp_0_2_val;
    var $7 = HEAP32[$shape + 12 >> 2];
    var $8 = __ZN2js16CallJSPropertyOpEP9JSContextPFiS1_P8JSObjectiPN2JS5ValueEES3_iS6_($cx, $5, $obj, $7, $vp);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $vp_idx_val$0 = HEAP32[$3 >> 2];
    var $vp_idx_val$1 = HEAP32[$3 + 4 >> 2];
    var $10 = __ZNK2JS5ValueneERKS0_($vp_idx_val$0, $vp_idx_val$1, $4$0, $4$1);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 4:
    var $13 = HEAP32[$shape + 24 >> 2];
    var $_idx_val_idx_val = HEAP32[HEAP32[$obj >> 2] + 4 >> 2];
    var $14 = __ZNK8JSObject12containsSlotEj($_idx_val_idx_val, $13);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = $obj;
    var $17 = $cx;
    var $18 = $shape;
    __ZN8JSObject21nativeSetSlotWithTypeEP9JSContextPKN2js5ShapeERKN2JS5ValueE($16, $17, $18, $vp);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL29LookupPropertyWithFlagsInlineP9JSContextP8JSObjectijPS2_PP10JSProperty($cx, $obj, $id, $flags, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $recursed = __stackBase__;
    var $1 = $cx;
    var $_01 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $4 = __ZN8JSObject12nativeLookupEP9JSContexti($_01, $1, $id);
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$objp >> 2] = $_01;
    HEAP32[$propp >> 2] = $4;
    var $_0 = 1;
    __label__ = 12;
    break;
   case 4:
    var $_idx_val = HEAP32[$_01 + 4 >> 2];
    var $10 = __ZNK8JSObject8getClassEv($_idx_val);
    if ((HEAP32[$10 + 28 >> 2] | 0) == 176) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = __ZL13CallResolveOpP9JSContextP8JSObjectS2_ijPS2_PP10JSPropertyPb($cx, $obj, $_01, $id, $flags, $objp, $propp, $recursed);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP8[$recursed] & 1) << 24 >> 24 == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 7:
    if ((HEAP32[$propp >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 8:
    var $_idx2_val_idx_val = HEAP32[HEAP32[$_01 + 36 >> 2] >> 2];
    var $26 = __ZNK8JSObject8getProtoEv($_idx2_val_idx_val);
    if (($26 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $29 = $26;
    var $_idx1_val = HEAP32[$26 >> 2];
    var $30 = __ZNK8JSObject8isNativeEv($_idx1_val);
    if ($30) {
      var $_01 = $29;
      __label__ = 2;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $32 = $objp;
    var $33 = $propp;
    var $34 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($26, $1, $id, $32, $33);
    var $_0 = ($34 | 0) != 0;
    __label__ = 12;
    break;
   case 11:
    HEAP32[$objp >> 2] = 0;
    HEAP32[$propp >> 2] = 0;
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL29LookupPropertyWithFlagsInlineP9JSContextP8JSObjectijPS2_PP10JSProperty["X"] = 1;

function __Z16js_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty($cx, $obj, $index, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $6 = HEAP32[$cx + 208 >> 2];
    var $7 = __ZL29LookupPropertyWithFlagsInlineP9JSContextP8JSObjectijPS2_PP10JSProperty($cx, $obj, $4, $6, $objp, $propp);
    var $_0 = $7 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z21js_FindPropertyHelperP9JSContextibbPP8JSObjectS3_PP10JSProperty($cx, $id, $cacheResult, $global, $objp, $pobjp, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $1 = $cx + 60 | 0;
    var $2 = __ZNK2js12ContextStack25currentScriptedScopeChainEv($1);
    if ($global) {
      __label__ = 2;
      break;
    } else {
      var $scopeChain_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject9getGlobalEv($2);
    var $scopeChain_0 = $4 | 0;
    __label__ = 3;
    break;
   case 3:
    var $scopeChain_0;
    var $7 = $scopeChain_0;
    var $_idx1_val = HEAP32[$scopeChain_0 + 20 >> 2];
    var $9 = __ZNK8JSObject9getParentEv($_idx1_val);
    var $10 = $cx + 208 | 0;
    var $scopeIndex_0 = 0;
    var $parent_0_in = $9;
    var $obj_0 = $scopeChain_0;
    __label__ = 4;
    break;
   case 4:
    var $obj_0;
    var $parent_0_in;
    var $scopeIndex_0;
    var $parent_0 = $parent_0_in;
    var $12 = ($parent_0_in | 0) != 0;
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $14 = __ZN2jsL25IsCacheableNonGlobalScopeEP8JSObject2396($obj_0);
    if ($14) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $cx;
    var $16 = $pobj;
    var $17 = $prop;
    var $obj_1 = $obj_0;
    __label__ = 16;
    break;
   case 7:
    var $_idx3_val = HEAP32[$obj_0 + 4 >> 2];
    var $20 = __ZNK8JSObject6getOpsEv($_idx3_val);
    if ((HEAP32[$20 + 4 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 8:
    var $25 = HEAP32[$10 >> 2];
    var $26 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($cx, $obj_0, $id, $25, $pobj, $prop);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 9:
    var $28 = HEAP32[$prop >> 2];
    if (($28 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ($cacheResult) {
      __label__ = 11;
      break;
    } else {
      var $entry_0 = 16;
      var $obj_2 = $obj_0;
      var $63 = $28;
      __label__ = 21;
      break;
    }
   case 11:
    var $32 = HEAP32[$pobj >> 2];
    var $_idx2_val = HEAP32[$32 >> 2];
    var $33 = __ZNK8JSObject8isNativeEv($_idx2_val);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $entry_0 = 16;
      var $obj_2 = $obj_0;
      var $63 = $28;
      __label__ = 21;
      break;
    }
   case 12:
    var $35 = $32;
    var $39 = HEAP32[$cx + 52 >> 2] + 144336 | 0;
    var $40 = $cx;
    var $41 = $28;
    var $42 = __ZN2js13PropertyCache4fillEP9JSContextP8JSObjectjS4_PKNS_5ShapeEi($39, $40, $7, $scopeIndex_0, $35, $41, 0);
    var $entry_0 = $42;
    var $obj_2 = $obj_0;
    var $63 = HEAP32[$prop >> 2];
    __label__ = 21;
    break;
   case 13:
    if ($12) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    HEAP32[$pobj >> 2] = 0;
    var $entry_0 = 16;
    var $obj_2 = $obj_0;
    var $63 = $28;
    __label__ = 21;
    break;
   case 15:
    var $parent_0_in_idx_val = HEAP32[$parent_0_in + 20 >> 2];
    var $47 = __ZNK8JSObject9getParentEv($parent_0_in_idx_val);
    var $scopeIndex_0 = $scopeIndex_0 + 1 | 0;
    var $parent_0_in = $47;
    var $obj_0 = $parent_0;
    __label__ = 4;
    break;
   case 16:
    var $obj_1;
    var $51 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($obj_1, $15, $id, $16, $17);
    if (($51 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $54 = HEAP32[$prop >> 2];
    if (($54 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      var $entry_0 = 16;
      var $obj_2 = $obj_1;
      var $63 = $54;
      __label__ = 21;
      break;
    }
   case 18:
    var $_idx_val = HEAP32[$obj_1 + 20 >> 2];
    var $58 = __ZNK8JSObject9getParentEv($_idx_val);
    if (($58 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    HEAP32[$pobj >> 2] = 0;
    var $entry_0 = 16;
    var $obj_2 = $obj_1;
    var $63 = $54;
    __label__ = 21;
    break;
   case 20:
    var $obj_1 = $58;
    __label__ = 16;
    break;
   case 21:
    var $63;
    var $obj_2;
    var $entry_0;
    HEAP32[$objp >> 2] = $obj_2;
    var $64 = HEAP32[$pobj >> 2];
    HEAP32[$pobjp >> 2] = $64;
    HEAP32[$propp >> 2] = $63;
    var $_0 = $entry_0;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z21js_FindPropertyHelperP9JSContextibbPP8JSObjectS3_PP10JSProperty["X"] = 1;

function __ZNK2js12ContextStack25currentScriptedScopeChainEv($this) {
  var $_idx_val_idx_val_idx_val = HEAP32[HEAP32[HEAP32[$this >> 2] + 8 >> 2] + 12 >> 2];
  var $1 = __ZNK2js12ContextStack2fpEv($_idx_val_idx_val_idx_val);
  var $2 = __ZNK2js10StackFrame10scopeChainEv($1);
  return $2;
}

function __ZN2jsL25IsCacheableNonGlobalScopeEP8JSObject2396($obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$obj + 4 >> 2];
    var $_idx1_val = $1;
    var $2 = __ZNK8JSObject6isCallEv($_idx1_val);
    if ($2) {
      var $8 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = $1;
    var $4 = __ZNK8JSObject7isBlockEv($_idx_val);
    if ($4) {
      var $8 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZNK8JSObject9isDeclEnvEv($_idx_val);
    var $8 = $6;
    __label__ = 4;
    break;
   case 4:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z15js_FindPropertyP9JSContextibPP8JSObjectS3_PP10JSProperty($cx, $id, $objp, $pobjp, $propp) {
  var $1 = __Z21js_FindPropertyHelperP9JSContextibbPP8JSObjectS3_PP10JSProperty($cx, $id, 0, 0, $objp, $pobjp, $propp);
  return ($1 | 0) != 0 & 1;
}

function __Z21js_FindIdentifierBaseP9JSContextP8JSObjecti($cx, $scopeChain, $id) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $pobj1 = __stackBase__ + 8;
    var $prop2 = __stackBase__ + 12;
    var $1 = $cx + 208 | 0;
    var $scopeIndex_0 = 0;
    var $obj_0 = $scopeChain;
    __label__ = 2;
    break;
   case 2:
    var $obj_0;
    var $scopeIndex_0;
    var $_idx3 = $obj_0 + 20 | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $4 = __ZNK8JSObject9getParentEv($_idx3_val);
    if (($4 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZN2jsL25IsCacheableNonGlobalScopeEP8JSObject2396($obj_0);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = $cx;
    var $9 = $prop2;
    var $obj_1 = $obj_0;
    __label__ = 11;
    break;
   case 5:
    var $10 = HEAP32[$1 >> 2];
    var $11 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($cx, $obj_0, $id, $10, $pobj, $prop);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 6:
    var $13 = HEAP32[$prop >> 2];
    if (($13 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $16 = HEAP32[$pobj >> 2];
    var $_idx4_val = HEAP32[$16 >> 2];
    var $17 = __ZNK8JSObject8isNativeEv($_idx4_val);
    if ($17) {
      __label__ = 8;
      break;
    } else {
      var $_0 = $obj_0;
      __label__ = 15;
      break;
    }
   case 8:
    var $19 = $16;
    var $23 = HEAP32[$cx + 52 >> 2] + 144336 | 0;
    var $24 = $cx;
    var $25 = $scopeChain;
    var $26 = $13;
    var $27 = __ZN2js13PropertyCache4fillEP9JSContextP8JSObjectjS4_PKNS_5ShapeEi($23, $24, $25, $scopeIndex_0, $19, $26, 0);
    var $_0 = $obj_0;
    __label__ = 15;
    break;
   case 9:
    var $_idx2_val = HEAP32[$_idx3 >> 2];
    var $30 = __ZNK8JSObject9getParentEv($_idx2_val);
    if (($30 | 0) == 0) {
      var $_0 = $obj_0;
      __label__ = 15;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $scopeIndex_0 = $scopeIndex_0 + 1 | 0;
    var $obj_0 = $30;
    __label__ = 2;
    break;
   case 11:
    var $obj_1;
    var $37 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($obj_1, $8, $id, $pobj1, $9);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[$prop2 >> 2] | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $_0 = $obj_1;
      __label__ = 15;
      break;
    }
   case 13:
    var $_idx1_val = HEAP32[$obj_1 + 20 >> 2];
    var $44 = __ZNK8JSObject9getParentEv($_idx1_val);
    var $45 = $44;
    if (($44 | 0) == 0) {
      var $_0 = $obj_1;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $_idx_val = HEAP32[$44 + 20 >> 2];
    var $48 = __ZNK8JSObject9getParentEv($_idx_val);
    if (($48 | 0) == 0) {
      var $_0 = $45;
      __label__ = 15;
      break;
    } else {
      var $obj_1 = $45;
      __label__ = 11;
      break;
    }
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z21js_FindIdentifierBaseP9JSContextP8JSObjecti["X"] = 1;

function __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($cx, $obj, $pobj, $shape, $getHow, $vp) {
  var $1 = __ZL18js_NativeGetInlineP9JSContextP8JSObjectS2_S2_PKN2js5ShapeEjPN2JS5ValueE($cx, $obj, $pobj, $shape, $getHow, $vp);
  return $1;
}

function __ZL18js_NativeGetInlineP9JSContextP8JSObjectS2_S2_PKN2js5ShapeEjPN2JS5ValueE($cx, $receiver, $pobj, $shape, $getHow, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pc = __stackBase__;
    var $2 = HEAP32[$shape + 24 >> 2];
    if (($2 | 0) == -1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $pobj;
    var $6 = __ZNK8JSObject13nativeGetSlotEj($5, $2);
    var $7 = $6 | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $vp | 0;
    HEAP32[$9 >> 2] = $8$0;
    HEAP32[$9 + 4 >> 2] = $8$1;
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 4;
    break;
   case 4:
    var $_idx3_val = HEAP32[$shape + 16 >> 2];
    var $13 = __ZNK2js5Shape16hasDefaultGetterEv($_idx3_val);
    if ($13) {
      var $_0 = 1;
      __label__ = 18;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx1_val = HEAP8[$shape + 29 | 0];
    var $16 = __ZNK2js5Shape8isMethodEv($_idx1_val);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    if (($getHow & 2 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 18;
      break;
    }
   case 7:
    var $22 = $cx + 60 | 0;
    var $23 = __ZNK2js12ContextStack13currentScriptEPPh($22, $pc);
    if (($23 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx4_val = HEAP32[$23 + 100 >> 2];
    var $26 = __ZN8JSScript11hasAnalysisEv($_idx4_val);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 9:
    var $28 = $cx;
    var $29 = __ZNK9JSContext2fpEv($28);
    var $_idx_val = HEAP32[$29 >> 2];
    var $30 = __ZNK2js10StackFrame11hasImacropcEv($_idx_val);
    if ($30) {
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_idx5_val_idx_val = HEAP32[$_idx4_val >> 2];
    var $32 = __ZN8JSScript8analysisEv($_idx5_val_idx_val);
    var $33 = HEAP32[$pc >> 2];
    var $_idx7_val = HEAP32[$32 + 4 >> 2];
    var $_idx6_val_idx_val = HEAP32[HEAP32[$32 >> 2] >> 2];
    var $34 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEPKh($_idx6_val_idx_val, $_idx7_val, $33);
    if (($34 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $38 = $34 + 1 | 0;
    var $40 = HEAP8[$38] | 64;
    HEAP8[$38] = $40;
    __label__ = 12;
    break;
   case 12:
    var $42 = $cx + 52 | 0;
    var $45 = HEAP32[HEAP32[$42 >> 2] + 144252 >> 2];
    var $46 = __ZNK2js5Shape3getEP9JSContextP8JSObjectS4_S4_PN2JS5ValueE($shape, $cx, $receiver, $pobj, $vp);
    if ($46) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 13:
    var $48 = $pobj;
    var $_idx2_val_idx_val = HEAP32[HEAP32[$pobj >> 2] + 4 >> 2];
    var $49 = __ZNK8JSObject12containsSlotEj($_idx2_val_idx_val, $2);
    if ($49) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 1;
      __label__ = 18;
      break;
    }
   case 14:
    if ((HEAP32[HEAP32[$42 >> 2] + 144252 >> 2] | 0) == ($45 | 0)) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $56 = __ZN8JSObject14nativeContainsEP9JSContextRKN2js5ShapeE($pobj, $cx, $shape);
    if ($56) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 1;
      __label__ = 18;
      break;
    }
   case 16:
    var $58 = __ZN8JSObject18methodWriteBarrierEP9JSContextRKN2js5ShapeERKN2JS5ValueE($pobj, $cx, $shape, $vp);
    if (($58 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    __ZN8JSObject13nativeSetSlotEjRKN2JS5ValueE($48, $2, $vp_idx_val$0, $vp_idx_val$1);
    var $_0 = 1;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18js_NativeGetInlineP9JSContextP8JSObjectS2_S2_PKN2js5ShapeEjPN2JS5ValueE["X"] = 1;

function __Z12js_NativeSetP9JSContextP8JSObjectPKN2js5ShapeEbbPN2JS5ValueE($cx, $obj, $shape, $added, $strict, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$shape + 12 >> 2];
    var $3 = $cx;
    var $4 = $obj;
    __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiRKN2JS5ValueE($3, $4, $2, $vp);
    var $5 = $shape + 24 | 0;
    var $6 = HEAP32[$5 >> 2];
    if (($6 | 0) == -1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx4_val = HEAP32[$shape + 20 >> 2];
    var $10 = __ZNK2js5Shape16hasDefaultSetterEv($_idx4_val);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 3:
    if ($added) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = __ZN8JSObject18methodWriteBarrierEP9JSContextjRKN2JS5ValueE($obj, $cx, $6, $vp);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 5:
    var $vp_idx2 = $vp | 0;
    var $st$1$0 = $vp_idx2 | 0;
    var $vp_idx2_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $vp_idx2 + 4 | 0;
    var $vp_idx2_val$1 = HEAP32[$st$1$1 >> 2];
    __ZN8JSObject13nativeSetSlotEjRKN2JS5ValueE($4, $6, $vp_idx2_val$0, $vp_idx2_val$1);
    var $_0 = 1;
    __label__ = 16;
    break;
   case 6:
    var $_idx_val = HEAP8[$shape + 28 | 0];
    var $17 = __ZNK2js5Shape14hasGetterValueEv($_idx_val);
    if ($17) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx3_val = HEAP32[$shape + 20 >> 2];
    var $20 = __ZNK2js5Shape16hasDefaultSetterEv($_idx3_val);
    if ($20) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $22 = __Z29js_ReportGetterOnlyAssignmentP9JSContext($cx);
    var $_0 = $22;
    __label__ = 16;
    break;
   case 9:
    var $24 = $cx + 52 | 0;
    var $27 = HEAP32[HEAP32[$24 >> 2] + 144252 >> 2];
    var $28 = __ZNK2js5Shape3setEP9JSContextP8JSObjectbPN2JS5ValueE($shape, $cx, $obj, $strict, $vp);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 10:
    var $30 = HEAP32[$5 >> 2];
    var $_idx1_val_idx_val = HEAP32[HEAP32[$obj >> 2] + 4 >> 2];
    var $31 = __ZNK8JSObject12containsSlotEj($_idx1_val_idx_val, $30);
    if ($31) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 16;
      break;
    }
   case 11:
    if ((HEAP32[HEAP32[$24 >> 2] + 144252 >> 2] | 0) == ($27 | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $38 = __ZN8JSObject14nativeContainsEP9JSContextRKN2js5ShapeE($obj, $cx, $shape);
    if ($38) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 1;
      __label__ = 16;
      break;
    }
   case 13:
    if ($added) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $41 = __ZN8JSObject18methodWriteBarrierEP9JSContextRKN2js5ShapeERKN2JS5ValueE($obj, $cx, $shape, $vp);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $vp_idx = $vp | 0;
    var $st$1$0 = $vp_idx | 0;
    var $vp_idx_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $vp_idx + 4 | 0;
    var $vp_idx_val$1 = HEAP32[$st$1$1 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($4, $30, $vp_idx_val$0, $vp_idx_val$1);
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z12js_NativeSetP9JSContextP8JSObjectPKN2js5ShapeEbbPN2JS5ValueE["X"] = 1;

function __ZN8JSObject18methodWriteBarrierEP9JSContextjRKN2JS5ValueE($this, $cx, $slot, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $_idx_val = HEAP32[$this + 8 >> 2];
    var $3 = __ZN8JSObject25brandedOrHasMethodBarrierEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject13nativeGetSlotEj($1, $slot);
    var $_idx1 = $5 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $6 = __ZL18ChangesMethodValueRKN2JS5ValueES2_($_idx1_val$0, $_idx1_val$1, $v);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = $cx;
    var $9 = __ZN8JSObject17methodShapeChangeEP9JSContextj($1, $8, $slot);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z29js_ReportGetterOnlyAssignmentP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  var $1 = $cx;
  var $2 = _JS_ReportErrorFlagsAndNumber($1, 13, 160, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
  STACKTOP = __stackBase__;
  return $2;
}

function __ZNK2js5Shape3setEP9JSContextP8JSObjectbPN2JS5ValueE($this, $cx, $obj, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fval = __stackBase__;
    var $3 = HEAPU8[$this + 28 | 0] & 255;
    if (($3 & 32 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZNK2js5Shape11setterValueEv($fval, $this);
    var $7 = $cx;
    var $8 = $obj;
    var $9 = __ZN2js20InvokeGetterOrSetterEP9JSContextP8JSObjectRKN2JS5ValueEjPS5_S8_($7, $8, $fval, 1, $vp, $vp);
    var $_0 = $9;
    __label__ = 11;
    break;
   case 3:
    if (($3 & 16 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = __Z29js_ReportGetterOnlyAssignmentP9JSContext($cx);
    var $_0 = ($14 | 0) != 0;
    __label__ = 11;
    break;
   case 5:
    var $_idx_val = HEAP32[$obj + 4 >> 2];
    var $18 = __ZNK8JSObject6isWithEv($_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      var $_01 = $obj;
      __label__ = 7;
      break;
    }
   case 6:
    var $_idx1_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $21 = __Z19js_UnwrapWithObjectP9JSContextP8JSObject($_idx1_val_idx_val);
    var $_01 = $21;
    __label__ = 7;
    break;
   case 7:
    var $_01;
    var $this_idx2_val = HEAP32[$this + 20 >> 2];
    var $24 = __ZNK2js5Shape8setterOpEv($this_idx2_val);
    var $this_idx_val = HEAP8[$this + 29 | 0];
    var $25 = __ZNK2js5Shape10hasShortIDEv($this_idx_val);
    if ($25) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $29 = HEAP16[$this + 30 >> 1] << 16 >> 16;
    var $30 = _INT_TO_JSID2431($29);
    var $35 = $30;
    __label__ = 10;
    break;
   case 9:
    var $35 = HEAP32[$this + 12 >> 2];
    __label__ = 10;
    break;
   case 10:
    var $35;
    var $36 = $strict & 1;
    var $37 = __ZN2js22CallJSPropertyOpSetterEP9JSContextPFiS1_P8JSObjectiiPN2JS5ValueEES3_iiS6_($cx, $24, $_01, $35, $36, $vp);
    var $_0 = $37;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js5Shape3setEP9JSContextP8JSObjectbPN2JS5ValueE["X"] = 1;

function __ZN8JSObject14nativeContainsEP9JSContextRKN2js5ShapeE($this, $cx, $shape) {
  var $2 = HEAP32[$shape + 12 >> 2];
  var $3 = $this;
  var $4 = $cx;
  var $5 = __ZN8JSObject12nativeLookupEP9JSContexti($3, $4, $2);
  return ($5 | 0) == ($shape | 0);
}

function __Z20js_GetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueE($cx, $obj, $id, $getHow, $vp) {
  var $1 = __ZL26js_GetPropertyHelperInlineP9JSContextP8JSObjectS2_ijPN2JS5ValueE($cx, $obj, $obj, $id, $getHow, $vp);
  return $1;
}

function __ZL26js_GetPropertyHelperInlineP9JSContextP8JSObjectS2_ijPN2JS5ValueE($cx, $obj, $receiver, $id, $getHow, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj2 = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __Z22js_CheckForStringIndexi($id);
    var $3 = $obj;
    var $4 = __Z23js_GetProtoIfDenseArrayP8JSObject($3);
    var $5 = $4;
    var $6 = $cx + 208 | 0;
    var $7 = HEAP32[$6 >> 2];
    var $8 = __ZL29LookupPropertyWithFlagsInlineP9JSContextP8JSObjectijPS2_PP10JSProperty($cx, $5, $2, $7, $obj2, $prop);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 2:
    var $10 = HEAPU32[$prop >> 2];
    if (($10 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 3:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_idx2_val = HEAP32[$obj + 4 >> 2];
    var $14 = __ZNK8JSObject8getClassEv($_idx2_val);
    var $17 = HEAP32[$14 + 16 >> 2];
    var $18 = __ZN2js16CallJSPropertyOpEP9JSContextPFiS1_P8JSObjectiPN2JS5ValueEES3_iS6_($cx, $17, $obj, $2, $vp);
    if ($18) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 4:
    var $vp_idx1 = $vp | 0;
    var $vp_idx1_val$0 = HEAP32[$vp_idx1 >> 2];
    var $vp_idx1_val$1 = HEAP32[$vp_idx1 + 4 >> 2];
    var $20 = __ZNK2JS5Value11isUndefinedEv($vp_idx1_val$0, $vp_idx1_val$1);
    if ($20) {
      var $vp_idx_val$1 = $vp_idx1_val$1;
      var $vp_idx_val$0 = $vp_idx1_val$0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $22 = $cx;
    __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiRKN2JS5ValueE($22, $3, $2, $vp);
    var $vp_idx_val$1 = HEAP32[$vp_idx1 + 4 >> 2];
    var $vp_idx_val$0 = HEAP32[$vp_idx1 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $vp_idx_val$0;
    var $vp_idx_val$1;
    var $24 = __ZNK2JS5Value11isUndefinedEv($vp_idx_val$0, $vp_idx_val$1);
    if ($24) {
      __label__ = 7;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 7:
    var $26 = $cx;
    var $27 = __Z23js_GetCurrentBytecodePCP9JSContext($26);
    if (($27 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $30 = HEAPU8[$27];
    var $31 = $30 & 255;
    if ($30 << 24 >> 24 == 83) {
      __label__ = 9;
      break;
    } else {
      var $op_0 = $31;
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = __ZNK9JSContext2fpEv($26);
    var $35 = __ZNK2js10StackFrame6scriptEv($34);
    var $36 = $35;
    var $37 = _JS_GetTrapOpcode($36, $27);
    var $op_0 = $37;
    __label__ = 10;
    break;
   case 10:
    var $op_0;
    if (($op_0 | 0) == 198) {
      var $flags_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_idx_val = HEAP32[$cx + 32 >> 2];
    var $42 = __ZNK9JSContext15hasStrictOptionEv($_idx_val);
    if ($42) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 12:
    var $45 = $cx + 60 | 0;
    var $46 = __ZNK2js12ContextStack13currentScriptEPPh($45, 0);
    if ((HEAP8[$46 + 37 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 13:
    if (($op_0 | 0) == 55 || ($op_0 | 0) == 53) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 14:
    var $57 = HEAP32[HEAP32[$cx + 52 >> 2] + 210244 >> 2] | 0;
    var $58 = __ZL12JSID_IS_ATOMiP6JSAtom2491($2, $57);
    if (($58 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 15:
    var $61 = HEAP32[$6 >> 2];
    if (($61 | 0) == 65535) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $67 = $27 + (HEAP8[_js_CodeSpec + ($op_0 << 3) | 0] << 24 >> 24) | 0;
    var $68 = __Z9DetectingP9JSContextPh($cx, $67);
    if (($68 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 17:
    if (($61 & 4 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 18:
    var $74 = __ZNK2js12ContextStack13currentScriptEPPh($45, 0);
    var $75 = $74 + 37 | 0;
    var $77 = HEAP8[$75] | 1;
    HEAP8[$75] = $77;
    var $flags_0 = 5;
    __label__ = 19;
    break;
   case 19:
    var $flags_0;
    __ZN2jsL9IdToValueEi2416($1, $2);
    var $_idx5 = $1 | 0;
    var $_idx5_val$0 = HEAP32[$_idx5 >> 2];
    var $_idx5_val$1 = HEAP32[$_idx5 + 4 >> 2];
    var $79 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($26, $flags_0, 162, 0, $_idx5_val$0, $_idx5_val$1, 0, 0);
    if (($79 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $_0 = 1;
    __label__ = 28;
    break;
   case 21:
    var $83 = HEAPU32[$obj2 >> 2];
    var $84 = $83;
    var $_idx3_val = HEAP32[$83 >> 2];
    var $85 = __ZNK8JSObject8isNativeEv($_idx3_val);
    if ($85) {
      __label__ = 25;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $_idx4_val = HEAP32[$83 + 4 >> 2];
    var $88 = __ZNK8JSObject7isProxyEv($_idx4_val);
    var $89 = $cx;
    if ($88) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $91 = $receiver;
    var $92 = __ZN2js7JSProxy3getEP9JSContextP8JSObjectS4_iPN2JS5ValueE($89, $84, $91, $2, $vp);
    var $_0 = $92 & 1;
    __label__ = 28;
    break;
   case 24:
    var $95 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($84, $89, $2, $vp);
    var $_0 = $95;
    __label__ = 28;
    break;
   case 25:
    var $97 = $10;
    if (($getHow & 1 | 0) == 0) {
      var $109 = $83;
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $104 = HEAP32[$cx + 52 >> 2] + 144336 | 0;
    var $105 = $cx;
    var $106 = $10;
    var $107 = __ZN2js13PropertyCache4fillEP9JSContextP8JSObjectjS4_PKNS_5ShapeEi($104, $105, $4, 0, $84, $106, 0);
    var $109 = HEAP32[$obj2 >> 2];
    __label__ = 27;
    break;
   case 27:
    var $109;
    var $110 = __ZL18js_NativeGetInlineP9JSContextP8JSObjectS2_S2_PKN2js5ShapeEjPN2JS5ValueE($cx, $receiver, $109, $97, $getHow, $vp);
    var $_0 = ($110 | 0) != 0 & 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL26js_GetPropertyHelperInlineP9JSContextP8JSObjectS2_ijPN2JS5ValueE["X"] = 1;

function __Z14js_GetPropertyP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var $1 = __ZL26js_GetPropertyHelperInlineP9JSContextP8JSObjectS2_ijPN2JS5ValueE($cx, $obj, $receiver, $id, 0, $vp);
  return $1;
}

function __Z13js_GetElementP9JSContextP8JSObjectS2_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL26js_GetPropertyHelperInlineP9JSContextP8JSObjectS2_ijPN2JS5ValueE($cx, $obj, $receiver, $4, 0, $vp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18GetPropertyDefaultEP9JSContextP8JSObjectiRKN2JS5ValueEPS5_($cx, $obj, $id, $def, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $prop = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $1 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($cx, $obj, $id, 1, $obj2, $prop);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    if ((HEAP32[$prop >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = $def | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $vp | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 4:
    var $11 = $cx;
    var $12 = HEAP32[$obj2 >> 2];
    var $13 = __Z14js_GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($11, $12, $id, $vp);
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($cx, $obj, $id, $getHow, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $rf = __stackBase__;
    var $1 = $cx;
    __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $1, 1);
    var $_idx_val = HEAP32[$obj + 4 >> 2];
    var $3 = __ZNK8JSObject6getOpsEv($_idx_val);
    var $5 = HEAP32[$3 + 32 >> 2];
    var $6 = $5;
    if (($5 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = __Z20js_GetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueE($cx, $obj, $id, $getHow, $vp);
    var $_0 = $9;
    __label__ = 6;
    break;
   case 3:
    var $11 = __ZNK8JSObject5isXMLEv($_idx_val);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = $cx;
    var $14 = $obj;
    var $15 = __Z15js_GetXMLMethodP9JSContextP8JSObjectiPN2JS5ValueE($13, $14, $id, $vp);
    var $_0 = $15;
    __label__ = 6;
    break;
   case 5:
    var $17 = FUNCTION_TABLE[$6]($cx, $obj, $obj, $id, $vp);
    var $_0 = $17;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    var $rf_idx_val = HEAP32[$rf >> 2];
    var $rf_idx2_val = HEAP32[$rf + 4 >> 2];
    __ZN18JSAutoResolveFlagsD1Ev($rf_idx_val, $rf_idx2_val);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z31js_CheckUndeclaredVarAssignmentP9JSContextP8JSString($cx, $propname) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $bytes = __stackBase__;
    var $1 = __ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind2415($cx);
    if (($1 | 0) == 0) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$1 >> 2];
    var $4 = __ZNK2js10StackFrame13isScriptFrameEv($_idx_val);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = $1;
    var $7 = __ZNK2js10StackFrame6scriptEv($6);
    if ((HEAP8[$7 + 36 | 0] & 8) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx1_val = HEAP32[$cx + 32 >> 2];
    var $14 = __ZNK9JSContext15hasStrictOptionEv($_idx1_val);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 5:
    var $16 = $cx;
    __ZN16JSAutoByteStringC1EP9JSContextP8JSString($bytes, $16, $propname);
    var $bytes_idx3_val = HEAP32[$bytes >> 2];
    var $17 = __ZNK16JSAutoByteStringntEv($bytes_idx3_val);
    if ($17) {
      var $24 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = __ZNK16JSAutoByteString3ptrEv($bytes_idx3_val);
    var $20 = $cx;
    var $21 = _JS_ReportErrorFlagsAndNumber($20, 13, 156, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $19, tempInt));
    var $24 = ($21 | 0) != 0;
    __label__ = 7;
    break;
   case 7:
    var $24;
    __ZN16JSAutoByteStringD1Ev($bytes_idx3_val);
    var $_0 = $24;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind2415($cx) {
  var $1 = $cx;
  var $2 = __ZNK9JSContext7maybefpEv($1);
  return $2;
}

function __ZN8JSObject14reportReadOnlyEP9JSContextij($cx, $id, $report) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2jsL9IdToValueEi2416($1, $id);
  var $2 = $cx;
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $3 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($2, $report, 19, 0, $_idx_val$0, $_idx_val$1, 0, 0);
  var $4 = ($3 | 0) != 0;
  STACKTOP = __stackBase__;
  return $4;
}

function __ZN2jsL9IdToValueEi2416($agg_result, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_STRING2486($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_STRING2421($id);
    __ZN2JSL11StringValueEP8JSString2480($agg_result, $4);
    __label__ = 8;
    break;
   case 3:
    var $6 = _JSID_IS_INT2487($id);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _JSID_TO_INT2488($id);
    __ZN2JSL10Int32ValueEi2332($agg_result, $9);
    __label__ = 8;
    break;
   case 5:
    var $11 = _JSID_IS_OBJECT2489($id);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = _JSID_TO_OBJECT2490($id);
    __ZN2JSL11ObjectValueER8JSObject2354($agg_result, $14);
    __label__ = 8;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv2280($agg_result);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject21reportNotConfigurableEP9JSContextij($cx, $id) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2jsL9IdToValueEi2416($1, $id);
  var $2 = $cx;
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $3 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($2, 0, 21, 0, $_idx_val$0, $_idx_val$1, 0, 0);
  var $4 = ($3 | 0) != 0;
  STACKTOP = __stackBase__;
  return $4;
}

function __ZN8JSObject19reportNotExtensibleEP9JSContextj($this, $cx, $report) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL11ObjectValueER8JSObject2354($1, $this);
  var $2 = $cx;
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $3 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($2, $report, 239, 0, $_idx_val$0, $_idx_val$1, 0, 0);
  var $4 = ($3 | 0) != 0;
  STACKTOP = __stackBase__;
  return $4;
}

function __ZN8JSObject10callMethodEP9JSContextijPN2JS5ValueES4_($this, $cx, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fval = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($cx, $this, $id, 2, $fval);
    if (($2 | 0) == 0) {
      var $8 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL11ObjectValueER8JSObject2354($1, $this);
    var $5 = $cx;
    var $6 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($5, $1, $fval, 0, 0, $vp);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSID_TO_STRING2421($iden) {
  return $iden;
}

function __ZNK2js5Shape10hasShortIDEv($this_0_8_val) {
  return ($this_0_8_val & 64) << 24 >> 24 != 0;
}

function __ZeqRK8JSObjectS1_2422($lhs, $rhs) {
  return ($lhs | 0) == ($rhs | 0);
}

function _INT_TO_JSID2431($i) {
  return $i << 1 | 1;
}

function __ZN2js2gcL6GCPokeEP9JSContextN2JS5ValueE($cx_0_11_val) {
  HEAP8[$cx_0_11_val + 144088 | 0] = 1;
  return;
}

function __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($cx, $obj, $id, $defineHow, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $pd = __stackBase__ + 8;
    var $1 = __stackBase__ + 56;
    var $2 = __Z22js_CheckForStringIndexi($id);
    var $obj_idx = $obj + 8 | 0;
    var $obj_idx_val = HEAP32[$obj_idx >> 2];
    var $3 = __ZNK8JSObject7watchedEv($obj_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_02 = $defineHow;
      __label__ = 5;
      break;
    }
   case 2:
    var $8 = HEAP32[HEAP32[$cx + 56 >> 2] + 1984 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = $8;
    var $12 = $cx;
    var $13 = $obj;
    var $14 = __ZN2js13WatchpointMap17triggerWatchpointEP9JSContextP8JSObjectiPN2JS5ValueE($11, $12, $13, $2, $vp);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      var $_1 = 0;
      __label__ = 73;
      break;
    }
   case 4:
    var $_02 = $defineHow & -5;
    __label__ = 5;
    break;
   case 5:
    var $_02;
    var $19 = HEAP32[$cx + 208 >> 2];
    var $20 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($cx, $obj, $2, $19, $pobj, $prop);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_1 = 0;
      __label__ = 73;
      break;
    }
   case 6:
    var $22 = HEAPU32[$prop >> 2];
    if (($22 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = HEAP32[$pobj >> 2];
    var $_idx11_val = HEAP32[$25 >> 2];
    var $26 = __ZNK8JSObject8isNativeEv($_idx11_val);
    if ($26) {
      var $79 = $22;
      __label__ = 26;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx17_val = HEAP32[$25 + 4 >> 2];
    var $29 = __ZNK8JSObject7isProxyEv($_idx17_val);
    if ($29) {
      __label__ = 9;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 9:
    var $31 = $pd;
    var $32 = $cx;
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($31, $32);
    var $phitmp = $pd + 16 | 0;
    var $35 = HEAP32[$pobj >> 2];
    var $36 = __ZN2js7JSProxy21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($32, $35, $2, 1, $phitmp);
    if ($36) {
      __label__ = 10;
      break;
    } else {
      var $_0_ph = 0;
      __label__ = 19;
      break;
    }
   case 10:
    var $39 = HEAPU32[$pd + 20 >> 2];
    if (($39 & 192 | 0) == 64) {
      __label__ = 11;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 11:
    var $44 = HEAP32[$pd + 28 >> 2];
    if (($44 | 0) == 0) {
      var $51 = 1;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $48 = HEAP32[$pd + 40 >> 2];
    var $49 = __ZN2js10CallSetterEP9JSContextP8JSObjectiPFiS1_S3_iiPN2JS5ValueEEjjiS6_($cx, $obj, $2, $44, $39, $48, $strict, $vp);
    var $51 = $49;
    __label__ = 13;
    break;
   case 13:
    var $51;
    var $_0_ph = $51 & 1;
    __label__ = 19;
    break;
   case 14:
    if (($39 & 2 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    if (($strict | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $59 = __ZN8JSObject14reportReadOnlyEP9JSContextij($cx, $2, 0);
    var $_0_ph = $59 & 1;
    __label__ = 19;
    break;
   case 17:
    var $_idx5_val = HEAP32[$cx + 32 >> 2];
    var $63 = __ZNK9JSContext15hasStrictOptionEv($_idx5_val);
    if ($63) {
      __label__ = 18;
      break;
    } else {
      var $_0_ph = 1;
      __label__ = 19;
      break;
    }
   case 18:
    var $65 = __ZN8JSObject14reportReadOnlyEP9JSContextij($cx, $2, 5);
    var $_0_ph = $65 & 1;
    __label__ = 19;
    break;
   case 19:
    var $_0_ph;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($31);
    var $_1 = $_0_ph;
    __label__ = 73;
    break;
   case 20:
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($31);
    __label__ = 21;
    break;
   case 21:
    HEAP32[$prop >> 2] = 0;
    var $79 = 0;
    __label__ = 26;
    break;
   case 22:
    var $_idx2_val = HEAP32[$obj + 20 >> 2];
    var $71 = __ZNK8JSObject9getParentEv($_idx2_val);
    if (($71 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      var $79 = $22;
      __label__ = 26;
      break;
    }
   case 23:
    if (($_02 & 8 | 0) == 0) {
      var $79 = $22;
      __label__ = 26;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $77 = _JSID_TO_STRING2421($2);
    var $78 = __Z31js_CheckUndeclaredVarAssignmentP9JSContextP8JSString($cx, $77);
    if ($78) {
      __label__ = 25;
      break;
    } else {
      var $_1 = 0;
      __label__ = 73;
      break;
    }
   case 25:
    var $79 = HEAP32[$prop >> 2];
    __label__ = 26;
    break;
   case 26:
    var $79;
    var $80 = $79;
    var $81 = $obj;
    var $_idx6 = $obj + 4 | 0;
    var $_idx6_val = HEAP32[$_idx6 >> 2];
    var $83 = __ZNK8JSObject8getClassEv($_idx6_val);
    var $86 = HEAP32[$83 + 16 >> 2];
    var $89 = HEAP32[$83 + 20 >> 2];
    if (($79 | 0) == 0) {
      var $shortid_310 = 0;
      var $flags_311 = 0;
      var $attrs_212 = 1;
      var $getter_213 = $86;
      var $setter_214 = $89;
      var $_316 = $_02;
      __label__ = 55;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $92 = $79;
    var $_idx14 = $92 + 28 | 0;
    var $_idx14_val = HEAPU8[$_idx14];
    var $93 = __ZNK2js5Shape20isAccessorDescriptorEv($_idx14_val);
    if ($93) {
      __label__ = 28;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 28:
    var $_idx21_val = HEAP32[$92 + 20 >> 2];
    var $95 = __ZNK2js5Shape16hasDefaultSetterEv($_idx21_val);
    if ($95) {
      __label__ = 29;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 29:
    var $97 = __Z29js_ReportGetterOnlyAssignmentP9JSContext($cx);
    var $_1 = $97;
    __label__ = 73;
    break;
   case 30:
    var $99 = __ZNK2js5Shape8writableEv($_idx14_val);
    if ($99) {
      __label__ = 35;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    if (($strict | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $103 = __ZN8JSObject14reportReadOnlyEP9JSContextij($cx, $2, 0);
    var $_1 = $103 & 1;
    __label__ = 73;
    break;
   case 33:
    var $_idx4_val = HEAP32[$cx + 32 >> 2];
    var $107 = __ZNK9JSContext15hasStrictOptionEv($_idx4_val);
    if ($107) {
      __label__ = 34;
      break;
    } else {
      var $_1 = 1;
      __label__ = 73;
      break;
    }
   case 34:
    var $109 = __ZN8JSObject14reportReadOnlyEP9JSContextij($cx, $2, 5);
    var $_1 = $109 & 1;
    __label__ = 73;
    break;
   case 35:
    var $111 = __ZNK2js5Shape10attributesEv($_idx14_val);
    var $112 = $111 & 255;
    if ((HEAP32[$pobj >> 2] | 0) == ($obj | 0)) {
      __label__ = 48;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $116 = __ZNK2js5Shape10shadowableEv($80);
    if ($116) {
      __label__ = 44;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    if (($_02 & 4 | 0) == 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $121 = __ZL25CloneFunctionForSetMethodP9JSContextPN2JS5ValueE($cx, $vp);
    if ($121) {
      __label__ = 39;
      break;
    } else {
      var $_1 = 0;
      __label__ = 73;
      break;
    }
   case 39:
    if (($_02 & 1 | 0) == 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $130 = HEAP32[$cx + 52 >> 2] + 144336 | 0;
    var $131 = $cx;
    var $132 = HEAP32[$pobj >> 2];
    var $133 = __ZN2js13PropertyCache4fillEP9JSContextP8JSObjectjS4_PKNS_5ShapeEi($130, $131, $81, 0, $132, $92, 0);
    __label__ = 41;
    break;
   case 41:
    var $_idx20_val = HEAP32[$92 + 20 >> 2];
    var $134 = __ZNK2js5Shape16hasDefaultSetterEv($_idx20_val);
    if ($134) {
      __label__ = 42;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 42:
    var $_idx7_val = HEAP8[$_idx14];
    var $136 = __ZNK2js5Shape14hasGetterValueEv($_idx7_val);
    if ($136) {
      __label__ = 43;
      break;
    } else {
      var $_1 = 1;
      __label__ = 73;
      break;
    }
   case 43:
    var $138 = ($strict | 0) != 0;
    var $139 = __ZNK2js5Shape3setEP9JSContextP8JSObjectbPN2JS5ValueE($80, $cx, $obj, $138, $vp);
    var $_1 = $139 & 1;
    __label__ = 73;
    break;
   case 44:
    var $142 = __ZNK2js5Shape7hasSlotEv($_idx14_val);
    if ($142) {
      var $shortid_310 = 0;
      var $flags_311 = 0;
      var $attrs_212 = 1;
      var $getter_213 = $86;
      var $setter_214 = $89;
      var $_316 = $_02;
      __label__ = 55;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $144 = $_02 & -5;
    var $_idx13_val = HEAP8[$80 + 29 | 0];
    var $145 = __ZNK2js5Shape10hasShortIDEv($_idx13_val);
    if ($145) {
      __label__ = 46;
      break;
    } else {
      var $flags_0 = 0;
      var $shortid_0 = 0;
      __label__ = 47;
      break;
    }
   case 46:
    var $flags_0 = 64;
    var $shortid_0 = HEAP16[$80 + 30 >> 1] << 16 >> 16;
    __label__ = 47;
    break;
   case 47:
    var $shortid_0;
    var $flags_0;
    var $150 = $112 & 191;
    var $_idx8_val = HEAP32[$92 + 16 >> 2];
    var $151 = __ZNK2js5Shape6getterEv($_idx8_val);
    var $152 = $151;
    var $_idx9_val = HEAP32[$92 + 20 >> 2];
    var $153 = __ZNK2js5Shape6setterEv($_idx9_val);
    var $shortid_310 = $shortid_0;
    var $flags_311 = $flags_0;
    var $attrs_212 = $150;
    var $getter_213 = $152;
    var $setter_214 = $153;
    var $_316 = $144;
    __label__ = 55;
    break;
   case 48:
    if (($_02 & 4 | 0) == 0) {
      var $added_0 = 0;
      var $shape_3 = $80;
      var $_315 = $_02;
      __label__ = 70;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $_idx10_val = HEAP8[$92 + 29 | 0];
    var $159 = __ZNK2js5Shape8isMethodEv($_idx10_val);
    if ($159) {
      __label__ = 50;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 50:
    var $161 = __ZNK2js5Shape12methodObjectEv($92);
    var $162 = $161;
    var $vp_idx1 = $vp | 0;
    var $vp_idx1_val$0 = HEAP32[$vp_idx1 >> 2];
    var $vp_idx1_val$1 = HEAP32[$vp_idx1 + 4 >> 2];
    var $163 = __ZNK2JS5Value8toObjectEv($vp_idx1_val$0, $vp_idx1_val$1);
    var $164 = $163;
    var $165 = __ZeqRK8JSObjectS1_2422($162, $164);
    if ($165) {
      var $176 = 1;
      __label__ = 54;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $166 = $cx;
    var $167 = __ZN8JSObject17methodShapeChangeEP9JSContextRKN2js5ShapeE($81, $166, $92);
    if (($167 | 0) == 0) {
      var $_1 = 0;
      __label__ = 73;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 52:
    var $170 = __ZL25CloneFunctionForSetMethodP9JSContextPN2JS5ValueE($cx, $vp);
    if ($170) {
      __label__ = 53;
      break;
    } else {
      var $_1 = 0;
      __label__ = 73;
      break;
    }
   case 53:
    var $172 = $167;
    var $173 = ($strict | 0) != 0;
    var $174 = __Z12js_NativeSetP9JSContextP8JSObjectPKN2js5ShapeEbbPN2JS5ValueE($cx, $obj, $172, 0, $173, $vp);
    var $176 = ($174 | 0) != 0;
    __label__ = 54;
    break;
   case 54:
    var $176;
    var $_1 = $176 & 1;
    __label__ = 73;
    break;
   case 55:
    var $_316;
    var $setter_214;
    var $getter_213;
    var $attrs_212;
    var $flags_311;
    var $shortid_310;
    var $_idx16_val = HEAP32[$obj_idx >> 2];
    var $178 = __ZNK8JSObject12isExtensibleEv($_idx16_val);
    if ($178) {
      __label__ = 60;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    if (($strict | 0) == 0) {
      __label__ = 58;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    var $182 = __ZN8JSObject19reportNotExtensibleEP9JSContextj($obj, $cx, 0);
    var $_1 = $182 & 1;
    __label__ = 73;
    break;
   case 58:
    var $_idx3_val = HEAP32[$cx + 32 >> 2];
    var $186 = __ZNK9JSContext15hasStrictOptionEv($_idx3_val);
    if ($186) {
      __label__ = 59;
      break;
    } else {
      var $_1 = 1;
      __label__ = 73;
      break;
    }
   case 59:
    var $188 = __ZN8JSObject19reportNotExtensibleEP9JSContextj($obj, $cx, 5);
    var $_1 = $188 & 1;
    __label__ = 73;
    break;
   case 60:
    var $191 = $cx;
    __Z18js_PurgeScopeChainP9JSContextP8JSObjecti($191, $81, $2);
    var $192 = __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($81, $191);
    if ($192) {
      __label__ = 61;
      break;
    } else {
      var $_1 = 0;
      __label__ = 73;
      break;
    }
   case 61:
    if (($_316 & 4 | 0) == 0) {
      var $getter_3 = $getter_213;
      var $flags_4 = $flags_311;
      __label__ = 65;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 62:
    var $_idx24_val = HEAP32[$_idx6 >> 2];
    var $198 = __ZNK8JSObject20canHaveMethodBarrierEv($_idx24_val);
    if ($198) {
      __label__ = 63;
      break;
    } else {
      var $getter_3 = $getter_213;
      var $flags_4 = $flags_311;
      __label__ = 65;
      break;
    }
   case 63:
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $200 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
    var $_idx_val = HEAP32[$200 + 24 >> 2];
    var $201 = __ZNK8JSObject18getFunctionPrivateEv($_idx_val);
    if (($201 | 0) == ($200 | 0)) {
      __label__ = 64;
      break;
    } else {
      var $getter_3 = $getter_213;
      var $flags_4 = $flags_311;
      __label__ = 65;
      break;
    }
   case 64:
    var $205 = $200;
    var $206 = $flags_311 | 128;
    var $207 = __ZN2jsL16CastAsPropertyOpEP8JSObject2286($205);
    var $getter_3 = $207;
    var $flags_4 = $206;
    __label__ = 65;
    break;
   case 65:
    var $flags_4;
    var $getter_3;
    var $211 = __ZN8JSObject11putPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji($81, $191, $2, $getter_3, $setter_214, -1, $attrs_212, $flags_4, $shortid_310);
    var $212 = $211;
    if (($211 | 0) == 0) {
      var $_1 = 0;
      __label__ = 73;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 66:
    var $216 = HEAP32[$211 + 24 >> 2];
    var $_idx12_val_idx_val = HEAP32[HEAP32[$obj >> 2] + 4 >> 2];
    var $217 = __ZNK8JSObject12containsSlotEj($_idx12_val_idx_val, $216);
    if ($217) {
      __label__ = 67;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 67:
    __ZN2JSL14UndefinedValueEv2280($1);
    var $_idx18 = $1 | 0;
    var $_idx18_val$0 = HEAP32[$_idx18 >> 2];
    var $_idx18_val$1 = HEAP32[$_idx18 + 4 >> 2];
    __ZN8JSObject13nativeSetSlotEjRKN2JS5ValueE($81, $216, $_idx18_val$0, $_idx18_val$1);
    __label__ = 68;
    break;
   case 68:
    var $_idx19_val = HEAP32[$83 + 8 >> 2];
    var $221 = __ZL19CallAddPropertyHookP9JSContextPN2js5ClassEP8JSObjectPKNS1_5ShapeEPN2JS5ValueE($cx, $_idx19_val, $obj, $212, $vp);
    if ($221) {
      var $added_0 = 1;
      var $shape_3 = $212;
      var $_315 = $_316;
      __label__ = 70;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 69:
    var $223 = __ZN8JSObject14removePropertyEP9JSContexti($81, $191, $2);
    var $_1 = 0;
    __label__ = 73;
    break;
   case 70:
    var $_315;
    var $shape_3;
    var $added_0;
    if (($_315 & 1 | 0) == 0) {
      __label__ = 72;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 71:
    var $231 = HEAP32[$cx + 52 >> 2] + 144336 | 0;
    var $232 = $cx;
    var $234 = __ZN2js13PropertyCache4fillEP9JSContextP8JSObjectjS4_PKNS_5ShapeEi($231, $232, $81, 0, $81, $shape_3, $added_0 & 1);
    __label__ = 72;
    break;
   case 72:
    var $236 = ($strict | 0) != 0;
    var $237 = __Z12js_NativeSetP9JSContextP8JSObjectPKN2js5ShapeEbbPN2JS5ValueE($cx, $obj, $shape_3, $added_0, $236, $vp);
    var $_1 = $237;
    __label__ = 73;
    break;
   case 73:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi["X"] = 1;

function __ZN2js10CallSetterEP9JSContextP8JSObjectiPFiS1_S3_iiPN2JS5ValueEEjjiS6_($cx, $obj, $id, $op, $attrs, $shortid, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($attrs & 32 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $op;
    __ZN2js17CastAsObjectJsvalEPFiP9JSContextP8JSObjectiiPN2JS5ValueEE($1, $5);
    var $6 = $cx;
    var $7 = $obj;
    var $8 = __ZN2js20InvokeGetterOrSetterEP9JSContextP8JSObjectRKN2JS5ValueEjPS5_S8_($6, $7, $1, 1, $vp, $vp);
    var $_0 = $8;
    __label__ = 8;
    break;
   case 3:
    if (($attrs & 16 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = __Z29js_ReportGetterOnlyAssignmentP9JSContext($cx);
    var $_0 = ($13 | 0) != 0;
    __label__ = 8;
    break;
   case 5:
    if (($attrs & 256 | 0) == 0) {
      var $_01 = $id;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = _INT_TO_JSID2431($shortid);
    var $_01 = $19;
    __label__ = 7;
    break;
   case 7:
    var $_01;
    var $21 = __ZN2js22CallJSPropertyOpSetterEP9JSContextPFiS1_P8JSObjectiiPN2JS5ValueEES3_iiS6_($cx, $op, $obj, $_01, $strict, $vp);
    var $_0 = $21;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5Shape10shadowableEv($this) {
  var $_idx_val = HEAP8[$this + 28 | 0];
  var $2 = __ZNK2js5Shape7hasSlotEv($_idx_val);
  var $4 = $2 ? 1 : $_idx_val << 24 >> 24 < 0;
  return $4;
}

function __ZL25CloneFunctionForSetMethodP9JSContextPN2JS5ValueE($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $1 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $2 = __ZNK8JSObject18getFunctionPrivateEv($_idx_val);
    if (($2 | 0) == ($1 | 0)) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = $cx;
    var $7 = __Z19CloneFunctionObjectP9JSContextP10JSFunction($6, $2);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value9setObjectER8JSObject($vp, $7);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19js_SetElementHelperP9JSContextP8JSObjectjjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($cx, $obj, $4, 0, $vp, $strict);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_GetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $prop = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $obj;
    var $2 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $id, $1, $prop);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$prop >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[$attrsp >> 2] = 0;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 4:
    var $9 = HEAP32[$1 >> 2];
    var $_idx_val = HEAP32[$9 >> 2];
    var $10 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $9;
    var $13 = $cx;
    var $14 = __ZN8JSObject13getAttributesEP9JSContextiPj($12, $13, $id, $attrsp);
    var $_0 = $14;
    __label__ = 7;
    break;
   case 6:
    var $_idx1_val = HEAP8[$5 + 28 | 0];
    var $17 = __ZNK2js5Shape10attributesEv($_idx1_val);
    var $18 = $17 & 255;
    HEAP32[$attrsp >> 2] = $18;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z23js_GetElementAttributesP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $prop = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $obj;
    var $2 = __Z16js_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty($cx, $obj, $index, $1, $prop);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$prop >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[$attrsp >> 2] = 0;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 4:
    var $9 = HEAP32[$1 >> 2];
    var $_idx_val = HEAP32[$9 >> 2];
    var $10 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = __ZN8JSObject20getElementAttributesEP9JSContextjPj($9, $cx, $index, $attrsp);
    var $_0 = $12;
    __label__ = 7;
    break;
   case 6:
    var $_idx1_val = HEAP8[$5 + 28 | 0];
    var $15 = __ZNK2js5Shape10attributesEv($_idx1_val);
    var $16 = $15 & 255;
    HEAP32[$attrsp >> 2] = $16;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject20getElementAttributesEP9JSContextjPj($this, $cx, $index, $attrsp) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $2 = __ZNK8JSObject6getOpsEv($_idx_val);
  var $4 = HEAP32[$2 + 72 >> 2];
  var $7 = ($4 | 0) != 0 ? $4 : 182;
  var $8 = FUNCTION_TABLE[$7]($cx, $this, $index, $attrsp);
  return $8;
}

function __Z22js_SetNativeAttributesP9JSContextP8JSObjectPN2js5ShapeEj($cx, $obj, $shape, $attrs) {
  var $_idx_val = HEAP32[$shape + 16 >> 2];
  var $2 = __ZNK2js5Shape6getterEv($_idx_val);
  var $3 = $2;
  var $_idx1_val = HEAP32[$shape + 20 >> 2];
  var $5 = __ZNK2js5Shape6setterEv($_idx1_val);
  var $6 = $5;
  var $7 = __Z28js_ChangeNativePropertyAttrsP9JSContextP8JSObjectPKN2js5ShapeEjjPFiS0_S2_iPN2JS5ValueEEPFiS0_S2_iiS9_E($cx, $obj, $shape, $attrs, $3, $6);
  return ($7 | 0) != 0 & 1;
}

function __Z16js_SetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $prop = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $obj;
    var $2 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $id, $1, $prop);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$prop >> 2];
    if (($5 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = HEAP32[$1 >> 2];
    var $_idx_val = HEAP32[$8 >> 2];
    var $9 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = $5;
    var $12 = HEAP32[$attrsp >> 2];
    var $13 = __Z22js_SetNativeAttributesP9JSContextP8JSObjectPN2js5ShapeEj($cx, $8, $11, $12);
    var $_0 = $13;
    __label__ = 6;
    break;
   case 5:
    var $15 = $8;
    var $16 = $cx;
    var $17 = __ZN8JSObject13setAttributesEP9JSContextiPj($15, $16, $id, $attrsp);
    var $_0 = $17;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z23js_SetElementAttributesP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $prop = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $obj;
    var $2 = __Z16js_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty($cx, $obj, $index, $1, $prop);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$prop >> 2];
    if (($5 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = HEAP32[$1 >> 2];
    var $_idx_val = HEAP32[$8 >> 2];
    var $9 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = $5;
    var $12 = HEAP32[$attrsp >> 2];
    var $13 = __Z22js_SetNativeAttributesP9JSContextP8JSObjectPN2js5ShapeEj($cx, $8, $11, $12);
    var $_0 = $13;
    __label__ = 6;
    break;
   case 5:
    var $15 = __ZN8JSObject20setElementAttributesEP9JSContextjPj($8, $cx, $index, $attrsp);
    var $_0 = $15;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject20setElementAttributesEP9JSContextjPj($this, $cx, $index, $attrsp) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $2 = __ZNK8JSObject6getOpsEv($_idx_val);
  var $4 = HEAP32[$2 + 88 >> 2];
  var $7 = ($4 | 0) != 0 ? $4 : 184;
  var $8 = FUNCTION_TABLE[$7]($cx, $this, $index, $attrsp);
  return $8;
}

function __Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $proto = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $funobj = __stackBase__ + 8;
    __ZN2JS5Value10setBooleanEb($rval, 1);
    var $1 = __Z22js_CheckForStringIndexi($id);
    var $2 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $1, $proto, $prop);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAPU32[$prop >> 2];
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$proto >> 2] | 0) == ($obj | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx5_val = HEAP32[$obj + 4 >> 2];
    var $12 = __ZNK8JSObject8getClassEv($_idx5_val);
    var $15 = HEAP32[$12 + 12 >> 2];
    var $16 = __ZN2js16CallJSPropertyOpEP9JSContextPFiS1_P8JSObjectiPN2JS5ValueEES3_iS6_($cx, $15, $obj, $1, $rval);
    var $_0 = $16 & 1;
    __label__ = 31;
    break;
   case 5:
    var $19 = $5;
    var $_idx8_val = HEAP8[$5 + 28 | 0];
    var $21 = __ZNK2js5Shape12configurableEv($_idx8_val);
    if ($21) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($strict | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = __ZN8JSObject21reportNotConfigurableEP9JSContextij($cx, $1);
    var $_0 = $25 & 1;
    __label__ = 31;
    break;
   case 8:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    var $_0 = 1;
    __label__ = 31;
    break;
   case 9:
    var $29 = $obj;
    var $_idx4_val = HEAP32[$obj + 4 >> 2];
    var $31 = __ZNK8JSObject8getClassEv($_idx4_val);
    var $34 = HEAP32[$31 + 12 >> 2];
    var $_idx7_val = HEAP8[$19 + 29 | 0];
    var $35 = __ZNK2js5Shape10hasShortIDEv($_idx7_val);
    if ($35) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $39 = HEAP16[$19 + 30 >> 1] << 16 >> 16;
    var $40 = _INT_TO_JSID2431($39);
    var $45 = $40;
    __label__ = 12;
    break;
   case 11:
    var $45 = HEAP32[$19 + 12 >> 2];
    __label__ = 12;
    break;
   case 12:
    var $45;
    var $46 = __ZN2js16CallJSPropertyOpEP9JSContextPFiS1_P8JSObjectiPN2JS5ValueEES3_iS6_($cx, $34, $obj, $45, $rval);
    if ($46) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 31;
      break;
    }
   case 13:
    var $rval_idx = $rval | 0;
    var $st$1$0 = $rval_idx | 0;
    var $rval_idx_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $rval_idx + 4 | 0;
    var $rval_idx_val$1 = HEAP32[$st$1$1 >> 2];
    var $48 = __ZNK2JS5Value7isFalseEv($rval_idx_val$0, $rval_idx_val$1);
    if ($48) {
      var $_0 = 1;
      __label__ = 31;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $51 = HEAP32[$19 + 24 >> 2];
    var $_idx6_val_idx_val = HEAP32[HEAP32[$obj >> 2] + 4 >> 2];
    var $52 = __ZNK8JSObject12containsSlotEj($_idx6_val_idx_val, $51);
    if ($52) {
      __label__ = 15;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 15:
    var $54 = __ZNK8JSObject13nativeGetSlotEj($29, $51);
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN2js2gcL6GCPokeEP9JSContextN2JS5ValueE($cx_idx_val);
    var $_idx9_val = HEAP32[$obj + 8 >> 2];
    var $56 = __ZN8JSObject16hasMethodBarrierEv($_idx9_val);
    if ($56) {
      __label__ = 16;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 16:
    var $_idx10 = $54 | 0;
    var $st$1$0 = $_idx10 | 0;
    var $_idx10_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx10 + 4 | 0;
    var $_idx10_val$1 = HEAP32[$st$1$1 >> 2];
    var $58 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject2432($_idx10_val$0, $_idx10_val$1, $funobj);
    if ($58) {
      __label__ = 17;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 17:
    var $60 = HEAP32[$funobj >> 2];
    var $_idx3_val = HEAP32[$60 + 24 >> 2];
    var $62 = __ZNK8JSObject18getFunctionPrivateEv($_idx3_val);
    if (($62 | 0) == ($60 | 0)) {
      __label__ = 28;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $66 = $cx;
    var $67 = __ZNK9JSContext7maybefpEv($66);
    if (($67 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $69 = $60;
    var $fp_0_in2 = $67;
    __label__ = 20;
    break;
   case 20:
    var $fp_0_in2;
    var $fp_0_in2_idx1_val = HEAP32[$fp_0_in2 >> 2];
    var $70 = __ZNK2js10StackFrame15isFunctionFrameEv($fp_0_in2_idx1_val);
    if ($70) {
      __label__ = 21;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 21:
    var $72 = __ZNK2js10StackFrame6calleeEv($fp_0_in2);
    var $73 = $72;
    var $74 = __ZN10JSFunction14compiledFunObjEv($62);
    var $75 = $74;
    var $76 = __ZeqRK8JSObjectS1_2422($73, $75);
    if ($76) {
      __label__ = 22;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 22:
    var $78 = __ZNK2js10StackFrame9thisValueEv($fp_0_in2);
    var $_idx = $78 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $79 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($79) {
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 23:
    var $81 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $tmp_0_in = $81;
    __label__ = 24;
    break;
   case 24:
    var $tmp_0_in;
    if (($tmp_0_in | 0) == ($obj | 0)) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    __ZN2js10StackFrame15overwriteCalleeER8JSObject($fp_0_in2, $69);
    __label__ = 27;
    break;
   case 26:
    var $tmp_0_in_idx_val_idx_val = HEAP32[HEAP32[$tmp_0_in + 36 >> 2] >> 2];
    var $86 = __ZNK8JSObject8getProtoEv($tmp_0_in_idx_val_idx_val);
    if (($86 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $tmp_0_in = $86;
      __label__ = 24;
      break;
    }
   case 27:
    var $fp_0_in2_idx_val = HEAP32[$fp_0_in2 + 16 >> 2];
    var $88 = __ZNK2js10StackFrame4prevEv($fp_0_in2_idx_val);
    if (($88 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      var $fp_0_in2 = $88;
      __label__ = 20;
      break;
    }
   case 28:
    var $90 = $cx;
    var $91 = __ZN8JSObject14removePropertyEP9JSContexti($29, $90, $1);
    if ($91) {
      __label__ = 29;
      break;
    } else {
      var $97 = 0;
      __label__ = 30;
      break;
    }
   case 29:
    var $93 = $cx;
    var $94 = $obj;
    var $95 = __Z26js_SuppressDeletedPropertyP9JSContextP8JSObjecti($93, $94, $1);
    var $97 = $95;
    __label__ = 30;
    break;
   case 30:
    var $97;
    var $_0 = $97 & 1;
    __label__ = 31;
    break;
   case 31:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi["X"] = 1;

function __ZN2js16CallJSPropertyOpEP9JSContextPFiS1_P8JSObjectiPN2JS5ValueEES3_iS6_($cx, $op, $receiver, $id, $vp) {
  var $1 = FUNCTION_TABLE[$op]($cx, $receiver, $id, $vp);
  return ($1 | 0) != 0;
}

function __ZN2jsL8JsvalifyEPNS_5ClassE2452($c) {
  return $c;
}

function __ZN2jsL8ValueifyEP7JSClass2453($c) {
  return $c;
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject2432($v_0_0_0_val$0, $v_0_0_0_val$1, $funobj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    HEAP32[$funobj >> 2] = $3;
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $5 = __ZNK8JSObject10isFunctionEv($_idx_val);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_DeleteElementP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $4, $rval, $strict);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15HasDataPropertyEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $methodid, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = $cx;
    var $3 = __ZN8JSObject12nativeLookupEP9JSContexti($1, $2, $methodid);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK2js5Shape26hasDefaultGetterOrIsMethodEv($3);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = HEAP32[$3 + 24 >> 2];
    var $_idx_val_idx_val = HEAP32[HEAP32[$obj >> 2] + 4 >> 2];
    var $10 = __ZNK8JSObject12containsSlotEj($_idx_val_idx_val, $9);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $12 = __ZNK8JSObject13nativeGetSlotEj($1, $9);
    var $13 = $12 | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $vp | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12DefaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE($cx, $obj, $hint, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $_idx_val = HEAP32[$obj + 4 >> 2];
    var $3 = __ZNK8JSObject8getClassEv($_idx_val);
    var $4 = ($hint | 0) == 3;
    var $5 = ($3 | 0) == (__ZN2js11StringClassE | 0);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    var $7 = $cx + 52 | 0;
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_pre_phi = $7;
      __label__ = 5;
      break;
    }
   case 3:
    var $12 = HEAP32[HEAP32[$7 >> 2] + 210324 >> 2] | 0;
    var $13 = __ZL12ATOM_TO_JSIDP6JSAtom2291($12);
    var $14 = __ZN2jsL19ClassMethodIsNativeEP9JSContextP8JSObjectPNS_5ClassEiPFiS1_jPN2JS5ValueEE($cx, $obj, __ZN2js11StringClassE, $13, 186);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      var $_pre_phi = $7;
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = $obj;
    var $17 = __ZNK8JSObject16getPrimitiveThisEv($16);
    var $18 = $17 | 0;
    var $st$3$0 = $18 | 0;
    var $19$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $18 + 4 | 0;
    var $19$1 = HEAP32[$st$3$1 >> 2];
    var $20 = $vp | 0;
    var $st$8$0 = $20 | 0;
    HEAP32[$st$8$0 >> 2] = $19$0;
    var $st$8$1 = $20 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $19$1;
    var $_0 = 1;
    __label__ = 24;
    break;
   case 5:
    var $_pre_phi;
    var $24 = HEAP32[HEAP32[$_pre_phi >> 2] + 210324 >> 2] | 0;
    var $25 = __ZL12ATOM_TO_JSIDP6JSAtom2291($24);
    var $26 = __ZN2jsL15MaybeCallMethodEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $25, $vp);
    if ($26) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 6:
    var $vp_idx3 = $vp | 0;
    var $st$1$0 = $vp_idx3 | 0;
    var $vp_idx3_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $vp_idx3 + 4 | 0;
    var $vp_idx3_val$1 = HEAP32[$st$1$1 >> 2];
    var $28 = __ZNK2JS5Value11isPrimitiveEv($vp_idx3_val$0, $vp_idx3_val$1);
    if ($28) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $33 = HEAP32[HEAP32[$_pre_phi >> 2] + 210332 >> 2] | 0;
    var $34 = __ZL12ATOM_TO_JSIDP6JSAtom2291($33);
    var $35 = __ZN2jsL15MaybeCallMethodEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $34, $vp);
    if ($35) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 8:
    var $st$0$0 = $vp_idx3 | 0;
    var $vp_idx2_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $vp_idx3 + 4 | 0;
    var $vp_idx2_val$1 = HEAP32[$st$0$1 >> 2];
    var $37 = __ZNK2JS5Value11isPrimitiveEv($vp_idx2_val$0, $vp_idx2_val$1);
    if ($37) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 9:
    if ($5) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $44 = HEAP32[HEAP32[$cx + 52 >> 2] + 210332 >> 2] | 0;
    var $45 = __ZL12ATOM_TO_JSIDP6JSAtom2291($44);
    var $46 = __ZN2jsL19ClassMethodIsNativeEP9JSContextP8JSObjectPNS_5ClassEiPFiS1_jPN2JS5ValueEE($cx, $obj, __ZN2js11StringClassE, $45, 186);
    if ($46) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $49 = $cx + 52 | 0;
    if (($3 | 0) == (__ZN2js11NumberClassE | 0)) {
      __label__ = 12;
      break;
    } else {
      var $_pre_phi7 = $49;
      __label__ = 14;
      break;
    }
   case 12:
    var $54 = HEAP32[HEAP32[$49 >> 2] + 210332 >> 2] | 0;
    var $55 = __ZL12ATOM_TO_JSIDP6JSAtom2291($54);
    var $56 = __ZN2jsL19ClassMethodIsNativeEP9JSContextP8JSObjectPNS_5ClassEiPFiS1_jPN2JS5ValueEE($cx, $obj, __ZN2js11NumberClassE, $55, 188);
    if ($56) {
      __label__ = 13;
      break;
    } else {
      var $_pre_phi7 = $49;
      __label__ = 14;
      break;
    }
   case 13:
    var $58 = $obj;
    var $59 = __ZNK8JSObject16getPrimitiveThisEv($58);
    var $60 = $59 | 0;
    var $st$3$0 = $60 | 0;
    var $61$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $60 + 4 | 0;
    var $61$1 = HEAP32[$st$3$1 >> 2];
    var $62 = $vp | 0;
    var $st$8$0 = $62 | 0;
    HEAP32[$st$8$0 >> 2] = $61$0;
    var $st$8$1 = $62 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $61$1;
    var $_0 = 1;
    __label__ = 24;
    break;
   case 14:
    var $_pre_phi7;
    var $66 = HEAP32[HEAP32[$_pre_phi7 >> 2] + 210332 >> 2] | 0;
    var $67 = __ZL12ATOM_TO_JSIDP6JSAtom2291($66);
    var $68 = __ZN2jsL15MaybeCallMethodEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $67, $vp);
    if ($68) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 15:
    var $vp_idx1 = $vp | 0;
    var $st$1$0 = $vp_idx1 | 0;
    var $vp_idx1_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $vp_idx1 + 4 | 0;
    var $vp_idx1_val$1 = HEAP32[$st$1$1 >> 2];
    var $70 = __ZNK2JS5Value11isPrimitiveEv($vp_idx1_val$0, $vp_idx1_val$1);
    if ($70) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $75 = HEAP32[HEAP32[$_pre_phi7 >> 2] + 210324 >> 2] | 0;
    var $76 = __ZL12ATOM_TO_JSIDP6JSAtom2291($75);
    var $77 = __ZN2jsL15MaybeCallMethodEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $76, $vp);
    if ($77) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 17:
    var $st$0$0 = $vp_idx1 | 0;
    var $vp_idx_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $vp_idx1 + 4 | 0;
    var $vp_idx_val$1 = HEAP32[$st$0$1 >> 2];
    var $79 = __ZNK2JS5Value11isPrimitiveEv($vp_idx_val$0, $vp_idx_val$1);
    if ($79) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if ($4) {
      __label__ = 19;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 19:
    var $83 = HEAP32[$3 >> 2];
    var $84 = $cx;
    var $85 = _JS_InternString($84, $83);
    if (($85 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    __ZN2JSL11ObjectValueER8JSObject2354($1, $obj);
    var $str_01 = $85;
    __label__ = 22;
    break;
   case 21:
    __ZN2JSL11ObjectValueER8JSObject2354($1, $obj);
    if (($hint | 0) == 0) {
      var $94 = STRING_TABLE.__str242227 | 0;
      var $str_02 = 0;
      __label__ = 23;
      break;
    } else {
      var $str_01 = 0;
      __label__ = 22;
      break;
    }
   case 22:
    var $str_01;
    var $94 = HEAP32[_js_common_atom_names + ($hint + 3 << 2) >> 2];
    var $str_02 = $str_01;
    __label__ = 23;
    break;
   case 23:
    var $str_02;
    var $94;
    var $95 = $cx;
    var $_idx4 = $1 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    var $96 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($95, 0, 38, 1, $_idx4_val$0, $_idx4_val$1, $str_02, $94);
    var $_0 = 0;
    __label__ = 24;
    break;
   case 24:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js12DefaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE["X"] = 1;

function __ZN2jsL19ClassMethodIsNativeEP9JSContextP8JSObjectPNS_5ClassEiPFiS1_jPN2JS5ValueEE($cx, $obj, $clasp, $methodid, $native) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZN2js15HasDataPropertyEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $methodid, $v);
    if ($1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $4 = __ZNK8JSObject8getProtoEv($_idx1_val_idx_val);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$4 + 4 >> 2];
    var $8 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($8 | 0) == ($clasp | 0)) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $12 = __ZN2js15HasDataPropertyEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $5, $methodid, $v);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $14 = __ZN2jsL16IsNativeFunctionERKN2JS5ValueEPFiP9JSContextjPS1_E($v_idx_val$0, $v_idx_val$1, $native);
    var $_0 = $14;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL15MaybeCallMethodEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($cx, $obj, $id, 2, $vp);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $6 = __ZL13js_IsCallableRKN2JS5ValueE2285($vp_idx_val$0, $vp_idx_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JSL11ObjectValueER8JSObject2354($1, $obj);
    var $8 = $1 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    HEAP32[$vp_idx >> 2] = $9$0;
    HEAP32[$vp_idx + 4 >> 2] = $9$1;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 4:
    __ZN2JSL11ObjectValueER8JSObject2354($2, $obj);
    var $11 = $cx;
    var $12 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($11, $2, $vp, 0, 0, $vp);
    var $_0 = $12;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z12js_EnumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$obj + 4 >> 2];
    var $2 = __ZNK8JSObject8getClassEv($_idx_val);
    var $4 = HEAP32[$2 + 24 >> 2];
    if ((HEAP32[$2 + 4 >> 2] & 2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $4;
    var $11 = FUNCTION_TABLE[$10]($cx, $obj, $enum_op, $statep, $idp);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 3:
    var $13 = $4;
    var $14 = FUNCTION_TABLE[$13]($cx, $obj);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value8setMagicE10JSWhyMagic($statep, 2);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z9js_TypeOfP9JSContextP8JSObject($cx, $obj) {
  var $_idx_val = HEAP32[$obj + 4 >> 2];
  var $2 = __ZN8JSObject10isCallableEv($_idx_val);
  var $3 = $2 ? 2 : 1;
  return $3;
}

function __Z13js_IsDelegateP9JSContextP8JSObjectRKN2JS5ValueE($obj, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value11isPrimitiveEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $obj2_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $obj2_0;
    var $_idx_val_idx_val = HEAP32[HEAP32[$obj2_0 + 36 >> 2] >> 2];
    var $7 = __ZNK8JSObject8getProtoEv($_idx_val_idx_val);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($8 | 0) == ($obj | 0)) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      var $obj2_0 = $8;
      __label__ = 3;
      break;
    }
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($cx, $scopeobj, $protoKey, $protop, $clasp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __Z18js_FindClassObjectP9JSContextP8JSObject10JSProtoKeyPN2JS5ValueEPN2js5ClassE($cx, $scopeobj, $protoKey, $v, $clasp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $v_idx3 = $v | 0;
    var $v_idx3_val$0 = HEAP32[$v_idx3 >> 2];
    var $v_idx3_val$1 = HEAP32[$v_idx3 + 4 >> 2];
    var $4 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueE2445($v_idx3_val$0, $v_idx3_val$1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $v_idx_val$1 = $v_idx3_val$1;
      var $v_idx_val$0 = $v_idx3_val$0;
      __label__ = 5;
      break;
    }
   case 3:
    var $6 = __ZNK2JS5Value8toObjectEv($v_idx3_val$0, $v_idx3_val$1);
    var $10 = HEAP32[HEAP32[$cx + 52 >> 2] + 210200 >> 2];
    var $11 = $cx;
    var $12 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($6, $11, $10, $v);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $v_idx_val$1 = HEAP32[$v_idx3 + 4 >> 2];
    var $v_idx_val$0 = HEAP32[$v_idx3 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $v_idx_val$0;
    var $v_idx_val$1;
    var $15 = __ZNK2JS5Value8isObjectEv($v_idx_val$0, $v_idx_val$1);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      var $20 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $17 = __ZNK2JS5Value8toObjectEv($v_idx_val$0, $v_idx_val$1);
    var $20 = $17;
    __label__ = 7;
    break;
   case 7:
    var $20;
    HEAP32[$protop >> 2] = $20;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueE2445($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZNK8JSObject10isFunctionEv($_idx_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17PrimitiveToObjectP9JSContextRKN2JS5ValueE($cx, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx1 = $v | 0;
    var $st$1$0 = $v_idx1 | 0;
    var $v_idx1_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $v_idx1 + 4 | 0;
    var $v_idx1_val$1 = HEAP32[$st$1$1 >> 2];
    var $1 = __ZNK2JS5Value8isStringEv($v_idx1_val$0, $v_idx1_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toStringEv($v_idx1_val$0, $v_idx1_val$1);
    var $4 = __ZN2js12StringObject6createEP9JSContextP8JSString($cx, $3);
    var $_0 = $4 | 0;
    __label__ = 7;
    break;
   case 3:
    var $7 = __ZNK2JS5Value8isNumberEv($v_idx1_val$0, $v_idx1_val$1);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZNK2JS5Value8toNumberEv($v);
    var $10 = __ZN2js12NumberObject6createEP9JSContextd($cx, $9);
    var $_0 = $10 | 0;
    __label__ = 7;
    break;
   case 5:
    var $13 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2296($cx, __ZN2js12BooleanClassE);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = $13;
    var $st$1$0 = $v_idx1 | 0;
    var $v_idx3_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $v_idx1 + 4 | 0;
    var $v_idx3_val$1 = HEAP32[$st$1$1 >> 2];
    __ZN8JSObject16setPrimitiveThisERKN2JS5ValueE($16, $v_idx3_val$0, $v_idx3_val$1);
    var $_0 = $13;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringObject6createEP9JSContextP8JSString($cx, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2296($cx, __ZN2js11StringClassE);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN8JSObject8asStringEv($1);
    var $5 = __ZN2js12StringObject4initEP9JSContextP8JSString($4, $cx, $str);
    var $_ = $5 ? $4 : 0;
    var $_0 = $_;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12NumberObject6createEP9JSContextd($cx, $d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2296($cx, __ZN2js11NumberClassE);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    var $5 = __ZN8JSObject8asNumberEv($4);
    var $6 = $5;
    __ZN2js12NumberObject17setPrimitiveValueEd($5, $d);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z20js_PrimitiveToObjectP9JSContextPN2JS5ValueE($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z17PrimitiveToObjectP9JSContextRKN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2JS5Value9setObjectER8JSObject($vp, $4);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ToObjectSlowEP9JSContextPN2JS5ValueE($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $vp_idx1 = $vp | 0;
    var $vp_idx1_val$0 = HEAP32[$vp_idx1 >> 2];
    var $vp_idx1_val$1 = HEAP32[$vp_idx1 + 4 >> 2];
    var $1 = __ZNK2JS5Value17isNullOrUndefinedEv($vp_idx1_val$0, $vp_idx1_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value6isNullEv($vp_idx1_val$0, $vp_idx1_val$1);
    var $4 = $3 ? STRING_TABLE.__str483817 | 0 : STRING_TABLE.__str493818 | 0;
    var $5 = $cx;
    _JS_ReportErrorNumber($5, 4, 38, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $4, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str267560 | 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __Z17PrimitiveToObjectP9JSContextRKN2JS5ValueE($cx, $vp);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7;
    __ZN2JS5Value9setObjectER8JSObject($vp, $10);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __Z22js_ValueToObjectOrNullP9JSContextRKN2JS5ValueEPP8JSObject($cx, $v, $obj);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$obj >> 2];
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $4;
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = $cx;
    __Z26js_ReportIsNullOrUndefinedP9JSContextiRKN2JS5ValueEP8JSString($7, 1, $v);
    var $_0 = $4;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z12js_XDRObjectP10JSXDRStatePP8JSObject($xdr, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $atom = __stackBase__;
    var $classId = __stackBase__ + 4;
    var $classDef = __stackBase__ + 8;
    var $proto = __stackBase__ + 12;
    var $numBuf = __stackBase__ + 16;
    var $2 = HEAPU32[$xdr + 8 >> 2];
    HEAP32[$atom >> 2] = 0;
    var $3 = $xdr | 0;
    if ((HEAP32[$3 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[HEAP32[$objp >> 2] + 4 >> 2];
    var $9 = __ZNK8JSObject8getClassEv($_idx1_val);
    var $10 = $9;
    var $11 = $9 | 0;
    var $12 = HEAP32[$11 >> 2];
    var $13 = $xdr;
    var $14 = _JS_XDRFindClassIdByName($13, $12);
    HEAP32[$classId >> 2] = $14;
    var $15 = ($14 | 0) == 0;
    var $16 = $15 & 1;
    HEAP32[$classDef >> 2] = $16;
    if ($15) {
      __label__ = 3;
      break;
    } else {
      var $clasp_0 = $10;
      var $_pre_phi = $13;
      __label__ = 8;
      break;
    }
   case 3:
    var $18 = __ZN2jsL8JsvalifyEPNS_5ClassE2452($10);
    var $19 = $18;
    var $20 = _JS_XDRRegisterClass($13, $19, $classId);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $24 = HEAPU32[$9 + 4 >> 2];
    if ($24 >>> 0 < 16777216) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $30 = HEAP32[$classDef >> 2] | $24 >>> 23 & 510;
    HEAP32[$classDef >> 2] = $30;
    var $clasp_0 = $10;
    var $_pre_phi = $13;
    __label__ = 8;
    break;
   case 6:
    var $32 = HEAP32[$11 >> 2];
    var $33 = _strlen($32);
    var $34 = $2;
    var $35 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($34, $32, $33, 0);
    HEAP32[$atom >> 2] = $35;
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      var $clasp_0 = $10;
      var $_pre_phi = $13;
      __label__ = 8;
      break;
    }
   case 7:
    HEAP32[$classDef >> 2] = 0;
    var $clasp_0 = 0;
    var $_pre_phi = $xdr;
    __label__ = 8;
    break;
   case 8:
    var $_pre_phi;
    var $clasp_0;
    var $39 = _JS_XDRUint32($_pre_phi, $classDef);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ((HEAP32[$classDef >> 2] | 0) == 1) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $45 = $atom;
    var $46 = _js_XDRAtom($_pre_phi, $45);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $49 = _JS_XDRUint32($_pre_phi, $classId);
    if (($49 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[$3 >> 2] | 0) == 1) {
      __label__ = 13;
      break;
    } else {
      var $clasp_1 = $clasp_0;
      __label__ = 18;
      break;
    }
   case 13:
    var $55 = HEAPU32[$classDef >> 2];
    if (($55 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $58 = $55 >>> 1;
    var $59 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, 0, $58, $proto, $clasp_0);
    if (($59 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $_idx_val = HEAP32[HEAP32[$proto >> 2] + 4 >> 2];
    var $64 = __ZNK8JSObject8getClassEv($_idx_val);
    var $65 = $64;
    var $66 = __ZN2jsL8JsvalifyEPNS_5ClassE2452($65);
    var $67 = $66;
    var $68 = _JS_XDRRegisterClass($_pre_phi, $67, $classId);
    if (($68 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      var $clasp_1 = $65;
      __label__ = 18;
      break;
    }
   case 16:
    var $71 = HEAP32[$classId >> 2];
    var $72 = _JS_XDRFindClassById($_pre_phi, $71);
    var $73 = $72;
    var $74 = __ZN2jsL8ValueifyEP7JSClass2453($73);
    if (($74 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $clasp_1 = $74;
      __label__ = 18;
      break;
    }
   case 17:
    var $77 = $numBuf | 0;
    var $78 = _JS_snprintf($77, 12, STRING_TABLE.__str262229 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $71, tempInt));
    var $79 = $2;
    _JS_ReportErrorNumber($79, 4, 40, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $77, tempInt));
    var $_0 = 0;
    __label__ = 21;
    break;
   case 18:
    var $clasp_1;
    var $82 = HEAP32[$clasp_1 + 56 >> 2];
    if (($82 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $86 = HEAP32[$clasp_1 >> 2];
    var $87 = $2;
    _JS_ReportErrorNumber($87, 4, 41, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $86, tempInt));
    var $_0 = 0;
    __label__ = 21;
    break;
   case 20:
    var $89 = FUNCTION_TABLE[$82]($xdr, $objp);
    var $_0 = $89;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z12js_XDRObjectP10JSXDRStatePP8JSObject["X"] = 1;

function __Z14js_ClearNativeP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = $obj;
    var $3 = $cx;
    __label__ = 2;
    break;
   case 2:
    var $5 = __ZL21LastConfigurableShapeP8JSObject($obj);
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAP32[$5 + 12 >> 2];
    var $10 = __ZN8JSObject14removePropertyEP9JSContexti($2, $3, $9);
    if ($10) {
      __label__ = 2;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 4:
    var $_idx = $obj;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $12 = __ZNK8JSObject12lastPropertyEv($_idx_val);
    var $13 = $r;
    var $14 = $12;
    __ZNK2js5Shape3allEv($13, $14);
    var $_idx2 = $r;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $_idx2_val_idx_val = HEAP32[$_idx2_val + 32 >> 2];
    var $15 = __ZNK2js5Shape5Range5emptyEv($_idx2_val_idx_val);
    if ($15) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = $r;
    var $_idx6 = $1 | 0;
    var $_idx3_val_in = $_idx2_val;
    __label__ = 6;
    break;
   case 6:
    var $_idx3_val_in;
    var $18 = __ZNK2js5Shape5Range5frontEv($_idx3_val_in);
    var $_idx5_val = HEAP8[$18 + 28 | 0];
    var $19 = __ZNK2js5Shape16isDataDescriptorEv($_idx5_val);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 7:
    var $21 = __ZNK2js5Shape8writableEv($_idx5_val);
    if ($21) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $_idx7_val = HEAP32[$18 + 20 >> 2];
    var $23 = __ZNK2js5Shape16hasDefaultSetterEv($_idx7_val);
    if ($23) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $26 = HEAP32[$18 + 24 >> 2];
    var $_idx4_val_idx_val = HEAP32[HEAP32[$_idx >> 2] + 4 >> 2];
    var $27 = __ZNK8JSObject12containsSlotEj($_idx4_val_idx_val, $26);
    if ($27) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    __ZN2JSL14UndefinedValueEv2280($1);
    var $_idx6_val$0 = HEAP32[$_idx6 >> 2];
    var $_idx6_val$1 = HEAP32[$_idx6 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, $26, $_idx6_val$0, $_idx6_val$1);
    __label__ = 11;
    break;
   case 11:
    __ZN2js5Shape5Range8popFrontEv($16);
    var $_idx1_val = HEAP32[$_idx2 >> 2];
    var $_idx1_val_idx_val = HEAP32[$_idx1_val + 32 >> 2];
    var $30 = __ZNK2js5Shape5Range5emptyEv($_idx1_val_idx_val);
    if ($30) {
      __label__ = 12;
      break;
    } else {
      var $_idx3_val_in = $_idx1_val;
      __label__ = 6;
      break;
    }
   case 12:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z14js_ClearNativeP9JSContextP8JSObject["X"] = 1;

function __ZL21LastConfigurableShapeP8JSObject($obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $_idx_val = HEAP32[$obj >> 2];
    var $1 = __ZNK8JSObject12lastPropertyEv($_idx_val);
    var $2 = $r;
    var $3 = $1;
    __ZNK2js5Shape3allEv($2, $3);
    var $4 = $r;
    var $_idx1 = $r;
    __label__ = 2;
    break;
   case 2:
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $_idx1_val_idx_val = HEAP32[$_idx1_val + 32 >> 2];
    var $6 = __ZNK2js5Shape5Range5emptyEv($_idx1_val_idx_val);
    if ($6) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $_idx1_val;
    var $9 = __ZNK2js5Shape5Range5frontEv($8);
    var $_idx3_val = HEAP8[$9 + 28 | 0];
    var $11 = __ZNK2js5Shape12configurableEv($_idx3_val);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = $9;
    __label__ = 6;
    break;
   case 5:
    __ZN2js5Shape5Range8popFrontEv($4);
    __label__ = 2;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18js_GetReservedSlotP9JSContextP8JSObjectjPN2JS5ValueE($obj, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $_idx1_val = HEAP32[$obj >> 2];
    var $2 = __ZNK8JSObject8isNativeEv($_idx1_val);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 6;
    break;
   case 3:
    var $_idx_val = HEAP32[$obj + 28 >> 2];
    var $6 = __ZNK8JSObject8numSlotsEv($_idx_val);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZNK8JSObject7getSlotEj($1, 0);
    var $10 = $9 | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = $vp | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    __label__ = 6;
    break;
   case 5:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18js_SetReservedSlotP9JSContextP8JSObjectjRKN2JS5ValueE($cx, $obj, $slot, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $obj;
    var $_idx2_val = HEAP32[$obj >> 2];
    var $3 = __ZNK8JSObject8isNativeEv($_idx2_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$obj + 28 >> 2];
    var $6 = __ZNK8JSObject8numSlotsEv($_idx_val);
    if ($6 >>> 0 > $slot >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx1_val = HEAP32[$obj + 4 >> 2];
    var $10 = __ZNK8JSObject8getClassEv($_idx1_val);
    var $14 = HEAPU32[$10 + 4 >> 2] >>> 8 & 255;
    var $15 = __ZN8JSObject10allocSlotsEP9JSContextj($obj, $cx, $14);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, $slot, $v_idx_val$0, $v_idx_val$1);
    __ZN2JSL9NullValueEv2460($1);
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN2js2gcL6GCPokeEP9JSContextN2JS5ValueE($cx_idx_val);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL9NullValueEv2460($agg_result) {
  __ZN2JS5Value7setNullEv($agg_result);
  return;
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE19growByUninitializedEj($this, $incr) {
  var $1 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr);
  return $1;
}

function __ZN2jsL15MakeRangeGCSafeEPPKNS_5ShapeES3_($beg, $end) {
  var $4 = $end - $beg >> 2;
  __ZN2jsL7PodZeroIPKNS_5ShapeEEEvPT_j($beg, $4);
  return;
}

function __ZN2jsL7PodZeroIPKNS_5ShapeEEEvPT_j($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem << 2;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 8 | 0;
    var $4 = HEAPU32[$3 >> 2];
    if ((HEAP32[$this + 12 >> 2] - $4 | 0) >>> 0 < $incr >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $10 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = HEAP32[$3 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $10;
    HEAP32[$3 >> 2] = $10 + $incr | 0;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj32EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js5Shape8setterOpEv($this_0_5_0_val) {
  return $this_0_5_0_val;
}

function __ZNK2js5Shape8getterOpEv($this_0_4_0_val) {
  return $this_0_4_0_val;
}

function __ZL16js_InitNullClassP9JSContextP8JSObject($cx, $obj) {
  return 0;
}

function _JSID_IS_STRING2486($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_IS_INT2487($iden) {
  return $iden & 1;
}

function _JSID_TO_INT2488($iden) {
  return $iden >> 1;
}

function _JSID_IS_OBJECT2489($iden) {
  return ($iden & 7 | 0) == 4 & ($iden | 0) != 4 & 1;
}

function _JSID_TO_OBJECT2490($iden) {
  return $iden & -8;
}

function __ZN8JSObject8asStringEv($this) {
  return $this;
}

function __ZN2js10VectorImplIPKNS_5ShapeELj8ENS_15TempAllocPolicyELb1EE13copyConstructIS3_EEvPS3_PKT_SA_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13AutoResolvingD2Ev($this_0_0_val, $this_0_4_val) {
  HEAP32[$this_0_0_val + 40 >> 2] = $this_0_4_val;
  return;
}

function __ZN2js13AutoResolvingC2EP9JSContextP8JSObjectiNS0_4KindE($this, $cx, $obj, $id, $kind) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $obj;
  HEAP32[$this + 8 >> 2] = $id;
  HEAP32[$this + 12 >> 2] = $kind;
  var $6 = $cx + 40 | 0;
  var $7 = HEAP32[$6 >> 2];
  HEAP32[$this + 16 >> 2] = $7;
  HEAP32[$6 >> 2] = $this;
  return;
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 2;
    var $7 = $this;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($7, $6);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplIPKNS_5ShapeELj8ENS_15TempAllocPolicyELb1EE13moveConstructIS3_EEvPS3_PKT_SA_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIPKNS_5ShapeELj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS3_Lj8ES4_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPKNS_5ShapeELj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS3_Lj8ES4_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v + 4 | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = $v;
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($5, $4, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $v + 12 | 0;
    var $10 = $6;
    HEAP32[$2 >> 2] = $10;
    HEAP32[$9 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPKNS_5ShapeELj8ENS_15TempAllocPolicyELb1EE13moveConstructIS3_EEvPS3_PKT_SA_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIPKNS_5ShapeELj8ENS_15TempAllocPolicyELb1EE13copyConstructIS3_EEvPS3_PKT_SA_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6detailL9NewObjectILb1ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2464($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($proto | 0) != 0;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $8 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $proto;
    var $4 = $cx;
    var $5 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($3, $4, 0, 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      var $8 = $6;
      __label__ = 3;
      break;
    }
   case 3:
    var $8;
    var $9 = $cx;
    var $10 = __Z16js_NewGCFunctionP9JSContext($9);
    var $11 = $10;
    if (($10 | 0) == 0) {
      var $_0 = $11;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($parent | 0) != 0 | $1 ^ 1) {
      var $19 = $parent;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx_val = HEAP32[$proto + 20 >> 2];
    var $16 = __ZNK8JSObject9getParentEv($_idx_val);
    var $19 = $16;
    __label__ = 6;
    break;
   case 6:
    var $19;
    var $20 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    var $21 = $10;
    var $22 = $clasp;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($21, $22, $8, $19, 0, $20);
    var $_idx1_val = HEAP32[$clasp + 4 >> 2];
    var $26 = __ZNK2js5Class8isNativeEv($_idx1_val);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $28 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2468($cx, $11, $clasp, $8, $kind);
    if ($28) {
      var $_0 = $11;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = 0;
    __label__ = 10;
    break;
   case 9:
    __ZN8JSObject21setSharedNonNativeMapEv($21);
    var $_0 = $11;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2465($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($proto | 0) != 0;
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZN2js5types15emptyTypeObjectE;
    var $_pre_phi = $cx;
    __label__ = 4;
    break;
   case 3:
    var $3 = $proto;
    var $4 = $cx;
    var $5 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($3, $4, 0, 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      var $8 = $6;
      var $_pre_phi = $4;
      __label__ = 4;
      break;
    }
   case 4:
    var $_pre_phi;
    var $8;
    var $9 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($_pre_phi, $kind);
    var $10 = $9;
    if (($9 | 0) == 0) {
      var $_0 = $10;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($parent | 0) != 0 | $1 ^ 1) {
      var $18 = $parent;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx_val = HEAP32[$proto + 20 >> 2];
    var $15 = __ZNK8JSObject9getParentEv($_idx_val);
    var $18 = $15;
    __label__ = 7;
    break;
   case 7:
    var $18;
    var $19 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    var $20 = $clasp;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($9, $20, $8, $18, 0, $19);
    var $_idx1_val = HEAP32[$clasp + 4 >> 2];
    var $24 = __ZNK2js5Class8isNativeEv($_idx1_val);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $26 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2468($cx, $10, $clasp, $8, $kind);
    if ($26) {
      var $_0 = $10;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_0 = 0;
    __label__ = 11;
    break;
   case 10:
    __ZN8JSObject21setSharedNonNativeMapEv($9);
    var $_0 = $10;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2468($cx, $obj, $clasp, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
    var $5 = $obj;
    var $_idx_val = HEAP32[$obj + 28 >> 2];
    var $7 = __ZNK8JSObject8numSlotsEv($_idx_val);
    if ($4 >>> 0 > $7 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = __ZN8JSObject10allocSlotsEP9JSContextj($obj, $cx, $4);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $12 = $type;
    var $13 = $clasp;
    var $14 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($12, $13);
    var $15 = $cx;
    if ($14) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($12, $15, $13, $kind);
    var $empty_0_in = $17;
    __label__ = 6;
    break;
   case 5:
    var $19 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($15, $13);
    var $empty_0_in = $19;
    __label__ = 6;
    break;
   case 6:
    var $empty_0_in;
    if (($empty_0_in | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($5, $empty_0_in | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEEixEj($this, $i) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $2 = __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE5beginEv($_idx_val);
  return $2 + ($i << 2) | 0;
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE6appendIS3_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $5 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    var $5 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    HEAP32[$this_idx1 >> 2] = $5 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2469($cx, $clasp, $proto, $parent, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $proto;
    if (($proto | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $7 = $proto;
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_2470($cx, $clasp, $parent, $1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 3:
    var $_pr = HEAP32[$1 >> 2];
    if (($_pr | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $7 = $_pr;
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = __ZN2js5types15emptyTypeObjectE;
    var $13 = $_pr;
    var $_pre_phi = $cx;
    __label__ = 6;
    break;
   case 5:
    var $7;
    var $9 = $cx;
    var $10 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($7, $9, 0, 0);
    var $11 = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      var $14 = $11;
      var $13 = $7;
      var $_pre_phi = $9;
      __label__ = 6;
      break;
    }
   case 6:
    var $_pre_phi;
    var $13;
    var $14;
    var $15 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($_pre_phi, $kind);
    var $16 = $15;
    if (($15 | 0) == 0) {
      var $_0 = $16;
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($parent | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $27 = $parent;
      __label__ = 10;
      break;
    }
   case 8:
    if (($13 | 0) == 0) {
      var $27 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_idx_val = HEAP32[$13 + 20 >> 2];
    var $24 = __ZNK8JSObject9getParentEv($_idx_val);
    var $27 = $24;
    __label__ = 10;
    break;
   case 10:
    var $27;
    var $28 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    var $29 = $clasp;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($15, $29, $14, $27, 0, $28);
    var $_idx1_val = HEAP32[$clasp + 4 >> 2];
    var $33 = __ZNK2js5Class8isNativeEv($_idx1_val);
    if ($33) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $35 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2468($cx, $16, $clasp, $14, $kind);
    if ($35) {
      var $_0 = $16;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $_0 = 0;
    __label__ = 14;
    break;
   case 13:
    __ZN8JSObject21setSharedNonNativeMapEv($15);
    var $_0 = $16;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2469["X"] = 1;

function __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_2470($cx, $clasp, $parent, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $clasp_idx_val = HEAP32[$clasp + 4 >> 2];
    var $1 = __ZN2jsL16GetClassProtoKeyEPNS_5ClassE2381($clasp_idx_val);
    var $2 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($cx, $parent, $1, $proto, $clasp);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$proto >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($cx, $parent, 1, $proto, 0);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb0ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2471($cx, $clasp, $proto, $parent, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $proto;
    if (($proto | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $7 = $proto;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_2470($cx, $clasp, $parent, $1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 3:
    var $_pr = HEAP32[$1 >> 2];
    if (($_pr | 0) == 0) {
      var $14 = __ZN2js5types15emptyTypeObjectE;
      var $13 = $_pr;
      __label__ = 5;
      break;
    } else {
      var $7 = $_pr;
      __label__ = 4;
      break;
    }
   case 4:
    var $7;
    var $9 = $cx;
    var $10 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($7, $9, 0, 0);
    var $11 = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      var $14 = $11;
      var $13 = $7;
      __label__ = 5;
      break;
    }
   case 5:
    var $13;
    var $14;
    var $15 = $cx;
    var $16 = __Z16js_NewGCFunctionP9JSContext($15);
    var $17 = $16;
    if (($16 | 0) == 0) {
      var $_0 = $17;
      __label__ = 13;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($parent | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $28 = $parent;
      __label__ = 9;
      break;
    }
   case 7:
    if (($13 | 0) == 0) {
      var $28 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx_val = HEAP32[$13 + 20 >> 2];
    var $25 = __ZNK8JSObject9getParentEv($_idx_val);
    var $28 = $25;
    __label__ = 9;
    break;
   case 9:
    var $28;
    var $29 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    var $30 = $16;
    var $31 = $clasp;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($30, $31, $14, $28, 0, $29);
    var $_idx1_val = HEAP32[$clasp + 4 >> 2];
    var $35 = __ZNK2js5Class8isNativeEv($_idx1_val);
    if ($35) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $37 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2468($cx, $17, $clasp, $14, $kind);
    if ($37) {
      var $_0 = $17;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_0 = 0;
    __label__ = 13;
    break;
   case 12:
    __ZN8JSObject21setSharedNonNativeMapEv($30);
    var $_0 = $17;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6detailL9NewObjectILb0ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2471["X"] = 1;

function __ZN2js12StringObject4initEP9JSContextP8JSString($this, $cx, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$cx + 56 >> 2] + 800 | 0;
    var $4 = HEAP32[$3 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this;
    var $8 = $4;
    __ZN8JSObject15setLastPropertyEPKN2js5ShapeE($7, $8);
    __label__ = 4;
    break;
   case 3:
    var $10 = $this;
    var $11 = $cx;
    var $12 = __ZN2js12StringObject18assignInitialShapeEP9JSContext($10, $11);
    HEAP32[$3 >> 2] = $12;
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js12StringObject13setStringThisEP8JSString($this, $str);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringObject13setStringThisEP8JSString($this, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 8;
  __ZN2JSL11StringValueEP8JSString2480($1, $str);
  var $3 = $this;
  var $_idx1 = $1 | 0;
  var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
  var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($3, 0, $_idx1_val$0, $_idx1_val$1);
  var $str_idx_val = HEAP32[$str >> 2];
  var $4 = __ZNK8JSString6lengthEv($str_idx_val);
  __ZN2JSL10Int32ValueEi2332($2, $4);
  var $_idx = $2 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($3, 1, $_idx_val$0, $_idx_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2JSL11StringValueEP8JSString2480($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2jsL16IsNativeFunctionERKN2JS5ValueEPFiP9JSContextjPS1_E($v_0_0_0_val$0, $v_0_0_0_val$1, $native) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fun = __stackBase__;
    var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP10JSFunction2483($v_0_0_0_val$0, $v_0_0_0_val$1, $fun);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $9 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$fun >> 2];
    var $5 = __ZNK10JSFunction11maybeNativeEv($4);
    var $9 = ($5 | 0) == ($native | 0);
    __label__ = 3;
    break;
   case 3:
    var $9;
    STACKTOP = __stackBase__;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP10JSFunction2483($v_0_0_0_val$0, $v_0_0_0_val$1, $fun) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $funobj = __stackBase__;
  var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction2484($v_0_0_0_val$0, $v_0_0_0_val$1, $funobj, $fun);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction2484($v_0_0_0_val$0, $v_0_0_0_val$1, $funobj, $fun) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject2432($v_0_0_0_val$0, $v_0_0_0_val$1, $funobj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[HEAP32[$funobj >> 2] + 24 >> 2];
    var $5 = __ZNK8JSObject18getFunctionPrivateEv($_idx_val);
    var $6 = $5;
    HEAP32[$fun >> 2] = $6;
    __label__ = 3;
    break;
   case 3:
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js22CallJSPropertyOpSetterEP9JSContextPFiS1_P8JSObjectiiPN2JS5ValueEES3_iiS6_($cx, $op, $obj, $id, $strict, $vp) {
  var $1 = FUNCTION_TABLE[$op]($cx, $obj, $id, $strict, $vp);
  return ($1 | 0) != 0;
}

function __ZL12JSID_IS_ATOMiP6JSAtom2491($id, $atom) {
  var $1 = __ZL12ATOM_TO_JSIDP6JSAtom2291($atom);
  return ($1 | 0) == ($id | 0) & 1;
}

function __ZNK2js5Shape11setterValueEv($agg_result, $this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$this + 20 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL11ObjectValueER8JSObject2354($agg_result, $3);
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv2280($agg_result);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18ChangesMethodValueRKN2JS5ValueES2_($prev_0_0_0_val$0, $prev_0_0_0_val$1, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($prev_0_0_0_val$0, $prev_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($prev_0_0_0_val$0, $prev_0_0_0_val$1);
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZNK8JSObject10isFunctionEv($_idx_val);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $11 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $6 = __ZNK2JS5Value8isObjectEv($v_idx_val$0, $v_idx_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      var $11 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toObjectEv($v_idx_val$0, $v_idx_val$1);
    var $11 = ($8 | 0) != ($3 | 0);
    __label__ = 5;
    break;
   case 5:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5Shape3getEP9JSContextP8JSObjectS4_S4_PN2JS5ValueE($this, $cx, $receiver, $pobj, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fval = __stackBase__;
    var $1 = $this;
    var $_idx_val = HEAP8[$this + 28 | 0];
    var $3 = __ZNK2js5Shape14hasGetterValueEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZNK2js5Shape11getterValueEv($fval, $this);
    var $5 = $cx;
    var $6 = $receiver;
    var $7 = __ZN2js20InvokeGetterOrSetterEP9JSContextP8JSObjectRKN2JS5ValueEjPS5_S8_($5, $6, $fval, 0, 0, $vp);
    var $_0 = $7;
    __label__ = 9;
    break;
   case 3:
    var $_idx1_val = HEAP8[$this + 29 | 0];
    var $10 = __ZNK2js5Shape8isMethodEv($_idx1_val);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $12 = __ZNK2js5Shape12methodObjectEv($1);
    __ZN2JS5Value9setObjectER8JSObject($vp, $12);
    var $13 = $pobj;
    var $14 = $cx;
    var $15 = __ZN8JSObject17methodReadBarrierEP9JSContextRKN2js5ShapeEPN2JS5ValueE($13, $14, $1, $vp);
    var $_0 = ($15 | 0) != 0;
    __label__ = 9;
    break;
   case 5:
    var $this_idx2_val = HEAP32[$this + 16 >> 2];
    var $18 = __ZNK2js5Shape8getterOpEv($this_idx2_val);
    var $19 = __ZNK2js5Shape10hasShortIDEv($_idx1_val);
    if ($19) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $23 = HEAP16[$this + 30 >> 1] << 16 >> 16;
    var $24 = _INT_TO_JSID2431($23);
    var $29 = $24;
    __label__ = 8;
    break;
   case 7:
    var $29 = HEAP32[$this + 12 >> 2];
    __label__ = 8;
    break;
   case 8:
    var $29;
    var $30 = __ZN2js16CallJSPropertyOpEP9JSContextPFiS1_P8JSObjectiPN2JS5ValueEES3_iS6_($cx, $18, $receiver, $29, $vp);
    var $_0 = $30;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5Shape11getterValueEv($agg_result, $this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$this + 16 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL11ObjectValueER8JSObject2354($agg_result, $3);
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv2280($agg_result);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13CallResolveOpP9JSContextP8JSObjectS2_ijPS2_PP10JSPropertyPb($cx, $start, $obj, $id, $flags, $objp, $propp, $recursedp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $resolving = __stackBase__;
    var $obj2 = __stackBase__ + 20;
    var $_idx_val = HEAP32[$obj + 4 >> 2];
    var $2 = __ZNK8JSObject8getClassEv($_idx_val);
    var $4 = HEAP32[$2 + 28 >> 2];
    var $5 = $4;
    __ZN2js13AutoResolvingC1EP9JSContextP8JSObjectiNS0_4KindE($resolving, $cx, $obj, $id, 0);
    var $6 = __ZNK2js13AutoResolving14alreadyStartedEv($resolving);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP8[$recursedp] = 1;
    var $_0 = 1;
    __label__ = 15;
    break;
   case 3:
    HEAP8[$recursedp] = 0;
    HEAP32[$propp >> 2] = 0;
    var $9 = $2 + 4 | 0;
    var $10 = HEAP32[$9 >> 2];
    if (($10 & 4 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $4;
    if (($flags | 0) == 65535) {
      __label__ = 5;
      break;
    } else {
      var $_01 = $flags;
      var $19 = $10;
      __label__ = 6;
      break;
    }
   case 5:
    var $17 = __Z13js_InferFlagsP9JSContextj($cx, 0);
    var $_01 = $17;
    var $19 = HEAP32[$9 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $19;
    var $_01;
    var $22 = ($19 & 32 | 0) != 0 ? $start : 0;
    HEAP32[$obj2 >> 2] = $22;
    var $23 = FUNCTION_TABLE[$14]($cx, $obj, $id, $_01, $obj2);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $26 = HEAP32[$obj2 >> 2];
    if (($26 | 0) == 0) {
      var $_0 = 1;
      __label__ = 15;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx2_val = HEAP32[$26 >> 2];
    var $29 = __ZNK8JSObject8isNativeEv($_idx2_val);
    if ($29) {
      var $_02 = $26;
      var $_idx3_val = $_idx2_val;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $31 = $26;
    var $32 = $cx;
    var $33 = $objp;
    var $34 = $propp;
    var $35 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($31, $32, $id, $33, $34);
    var $_0 = $35;
    __label__ = 15;
    break;
   case 10:
    var $37 = FUNCTION_TABLE[$5]($cx, $obj, $id);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_02 = $obj;
    var $_idx3_val = HEAP32[$obj >> 2];
    __label__ = 12;
    break;
   case 12:
    var $_idx3_val;
    var $_02;
    var $40 = __ZNK8JSObject11nativeEmptyEv($_idx3_val);
    if ($40) {
      var $_0 = 1;
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $43 = $cx;
    var $44 = __ZN8JSObject12nativeLookupEP9JSContexti($_02, $43, $id);
    if (($44 | 0) == 0) {
      var $_0 = 1;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    HEAP32[$objp >> 2] = $_02;
    HEAP32[$propp >> 2] = $44;
    var $_0 = 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    var $resolving_idx_val = HEAP32[$resolving >> 2];
    var $resolving_idx1_val = HEAP32[$resolving + 16 >> 2];
    __ZN2js13AutoResolvingD1Ev($resolving_idx_val, $resolving_idx1_val);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13CallResolveOpP9JSContextP8JSObjectS2_ijPS2_PP10JSPropertyPb["X"] = 1;

function __ZN8JSObject17TradeGutsReservedD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 52 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN9JSContext5free_EPv($5);
    __label__ = 3;
    break;
   case 3:
    var $8 = HEAP32[$this + 56 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $8;
    __ZN9JSContext5free_EPv($11);
    __label__ = 5;
    break;
   case 5:
    var $14 = $this + 28 | 0;
    __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEED1Ev($14);
    var $16 = $this + 4 | 0;
    __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEED1Ev($16);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject17TradeGutsReservedC2EP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  HEAP32[$this >> 2] = $cx;
  var $4 = $this + 4 | 0;
  var $5 = $cx;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $5);
  var $6 = $4;
  var $_01_val = HEAP32[$1 >> 2];
  __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEEC1ES3_($6, $_01_val);
  var $7 = $this + 28 | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($2, $5);
  var $8 = $7;
  var $_0_val = HEAP32[$2 >> 2];
  __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEEC1ES3_($8, $_0_val);
  HEAP32[$this + 52 >> 2] = 0;
  HEAP32[$this + 56 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js15AutoShapeVectorD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js16AutoVectorRooterIPKNS_5ShapeEED2Ev($1);
  return;
}

function __ZN2js16AutoVectorRooterIPKNS_5ShapeEED2Ev($this) {
  var $1 = $this + 12 | 0;
  __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEED1Ev($1);
  var $_idx_val = HEAP32[$this >> 2];
  var $_idx1_val = HEAP32[$this + 8 >> 2];
  __ZN2js12AutoGCRooterD2Ev($_idx_val, $_idx1_val);
  return;
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE2500($sid_0_0_val) {
  return $sid_0_0_val;
}

function __ZL14JSID_FROM_BITSj2517($bits) {
  return $bits;
}

function __ZNK15EvalScriptGuard6scriptEv($this_0_3_val) {
  return $this_0_3_val;
}

function __ZNK2js8PropDesc16isDataDescriptorEv($this_0_5_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_5_val & 4) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      var $7 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = ($this_0_5_val & 8) << 24 >> 24 != 0;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js8PropDesc20isAccessorDescriptorEv($this_0_5_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_5_val & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      var $7 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = ($this_0_5_val & 2) << 24 >> 24 != 0;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js8PropDesc8writableEv($this_0_4_val) {
  return ($this_0_4_val & 2) << 24 >> 24 == 0;
}

function __ZNK2js8PropDesc12configurableEv($this_0_4_val) {
  return ($this_0_4_val & 4) << 24 >> 24 == 0;
}

function __ZNK2js8PropDesc10enumerableEv($this_0_4_val) {
  return ($this_0_4_val & 1) << 24 >> 24 != 0;
}

function __ZN15EvalScriptGuard11foundScriptEv($this_0_3_val) {
  return ($this_0_3_val | 0) != 0;
}

function __ZNK2js8PropDesc11getterValueEv($this) {
  return $this + 16 | 0;
}

function __ZNK2js8PropDesc11setterValueEv($this) {
  return $this + 24 | 0;
}

function __ZN2js21AutoFunctionCallProbeC2EP9JSContextP10JSFunctionP8JSScript($this, $cx, $fun, $script) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $fun;
  HEAP32[$this + 8 >> 2] = $script;
  return;
}

function __ZN15EvalScriptGuard12setNewScriptEP8JSScript($this, $script) {
  HEAP32[$this + 12 >> 2] = $script;
  var $2 = $script + 37 | 0;
  var $4 = HEAP8[$2] | 64;
  HEAP8[$2] = $4;
  return;
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15AutoShapeVectorC2EP9JSContext($this, $cx) {
  var $1 = $this | 0;
  __ZN2js16AutoVectorRooterIPKNS_5ShapeEEC2EP9JSContexti($1, $cx);
  return;
}

function __ZN2js16AutoVectorRooterIPKNS_5ShapeEEC2EP9JSContexti($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this;
  var $3 = $cx;
  __ZN2js12AutoGCRooterC2EP9JSContexti($2, $3, -4);
  var $4 = $this + 12 | 0;
  var $5 = $1;
  __ZN2js15TempAllocPolicyC1EP9JSContext($5, $3);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEEC1ES4_($4, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEEC1ES4_($this, $ap_01) {
  __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEEC2ES4_($this, $ap_01);
  return;
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEEC2ES4_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj32EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 8;
  return;
}

function __Z23js_LiveFrameIfGeneratorPN2js10StackFrameE($fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$fp >> 2];
    var $1 = __ZNK2js10StackFrame16isGeneratorFrameEv($_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $9 = $fp;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $fp;
    var $4 = __Z27js_FloatingFrameToGeneratorPN2js10StackFrameE($3);
    var $5 = $4;
    var $6 = __ZN11JSGenerator9liveFrameEv($5);
    var $9 = $6;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject15getFixedSlotRefEj($this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject10fixedSlotsEv($1);
  return $2 + 8 | 0;
}

function __ZNK8JSObject11getWithThisEv($this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject12getFixedSlotEj($1, 1);
  var $_idx = $2 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $3 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
  return $3;
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2510($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $proto;
    var $2 = $cx;
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($1, $2, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($2, $kind);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_0 = $7;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    var $11 = $clasp;
    var $12 = $parent;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, $11, $3, $12, 0, $10);
    var $13 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($3, $2, $11, $kind);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = $13 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($6, $16);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, $method, $objp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $cx;
    _JS_ReportErrorNumber($3, 4, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $method, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str225518 | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str226519 | 0, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $_idx = $vp + 16 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $5 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($5) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZN2jsL23DecompileValueGeneratorEP9JSContextiRKN2JS5ValueEP8JSString2290($cx, $_idx_val$0, $_idx_val$1);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = $cx;
    _JS_ReportErrorNumber($10, 4, 222, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $7, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str2433396 | 0, tempInt));
    _JS_free($7);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $12 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $13 = $12;
    HEAP32[$objp >> 2] = $13;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12JSID_IS_ATOMi2511($id) {
  var $1 = _JSID_IS_STRING2486($id);
  return $1;
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2514($cx, $proto, $parent) {
  var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb2335($3);
  var $5 = __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2465($cx, __ZN2js11ObjectClassE, $proto, $parent, $4);
  return $5;
}

function __ZL17obj_watch_handlerP9JSContextP8JSObjectiN2JS5ValueEPS4_Pv($cx, $obj, $id, $0, $nvp, $closure) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $resolving = __stackBase__;
    var $argv = __stackBase__ + 20;
    var $2 = __stackBase__ + 44;
    var $3 = __stackBase__ + 52;
    var $_03 = $0 | 0;
    var $tmp$0 = HEAP32[$_03 >> 2];
    var $tmp$1 = HEAP32[$_03 + 4 >> 2];
    var $4 = $closure;
    var $5 = $closure;
    var $6 = $cx;
    var $7 = __ZN8JSObject10principalsEP9JSContext($5, $6);
    var $8 = $7;
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = $cx + 60 | 0;
    var $12 = __ZNK2js12ContextStack25currentScriptedScopeChainEv($11);
    if (($12 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = $12;
    var $16 = __ZN8JSObject10principalsEP9JSContext($15, $6);
    if (($16 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = $16;
    var $22 = HEAP32[$7 + 20 >> 2];
    var $23 = FUNCTION_TABLE[$22]($8, $19);
    if (($23 | 0) == 0) {
      var $_1 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js13AutoResolvingC1EP9JSContextP8JSObjectiNS0_4KindE($resolving, $cx, $obj, $id, 1);
    var $26 = __ZNK2js13AutoResolving14alreadyStartedEv($resolving);
    if ($26) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $28 = $argv | 0;
    __ZN2jsL9IdToValueEi2416($28, $id);
    var $_04 = $argv + 8 | 0;
    HEAP32[$_04 >> 2] = $tmp$0;
    HEAP32[$_04 + 4 >> 2] = $tmp$1;
    var $29 = $nvp | 0;
    var $30$0 = HEAP32[$29 >> 2];
    var $30$1 = HEAP32[$29 + 4 >> 2];
    var $31 = $argv + 16 | 0;
    HEAP32[$31 >> 2] = $30$0;
    HEAP32[$31 + 4 >> 2] = $30$1;
    __ZN2JSL11ObjectValueER8JSObject2354($2, $obj);
    __ZN2JSL17ObjectOrNullValueEP8JSObject2355($3, $4);
    var $32 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($6, $2, $3, 3, $28, $nvp);
    var $_0 = $32 & 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    var $resolving_idx_val = HEAP32[$resolving >> 2];
    var $resolving_idx1_val = HEAP32[$resolving + 16 >> 2];
    __ZN2js13AutoResolvingD1Ev($resolving_idx_val, $resolving_idx1_val);
    var $_1 = $_0;
    __label__ = 8;
    break;
   case 8:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17obj_watch_handlerP9JSContextP8JSObjectiN2JS5ValueEPS4_Pv["X"] = 1;

function __ZN2jsL12PodArrayZeroIN2JS5ValueELj4EEEvRAT0__T_2515($t) {
  var $1 = $t;
  _memset($1, 0, 32, 1);
  return;
}

function __ZNK2js8PropDesc19isGenericDescriptorEv($this_0_5_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js8PropDesc20isAccessorDescriptorEv($this_0_5_val);
    if ($1) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js8PropDesc16isDataDescriptorEv($this_0_5_val);
    var $6 = $3 ^ 1;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js8PropDesc6getterEv($this) {
  var $1 = __ZNK2js8PropDesc12getterObjectEv($this);
  var $2 = __ZN2jsL16CastAsPropertyOpEP8JSObject2286($1);
  return $2;
}

function __ZNK2js8PropDesc6setterEv($this) {
  var $1 = __ZNK2js8PropDesc12setterObjectEv($this);
  var $2 = __ZN2jsL22CastAsStrictPropertyOpEP8JSObject2289($1);
  return $2;
}

function __ZNK2js5Shape17getterOrUndefinedEv($agg_result, $this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP8[$this + 28 | 0];
    var $2 = __ZNK2js5Shape14hasGetterValueEv($_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = HEAP32[$this + 16 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JSL11ObjectValueER8JSObject2354($agg_result, $6);
    __label__ = 5;
    break;
   case 4:
    __ZN2JSL14UndefinedValueEv2280($agg_result);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5Shape17setterOrUndefinedEv($agg_result, $this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP8[$this + 28 | 0];
    var $2 = __ZNK2js5Shape14hasSetterValueEv($_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = HEAP32[$this + 20 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JSL11ObjectValueER8JSObject2354($agg_result, $6);
    __label__ = 5;
    break;
   case 4:
    __ZN2JSL14UndefinedValueEv2280($agg_result);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL6RejectP9JSContextjbiPb($cx, $throwError, $id, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $idstr = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $bytes = __stackBase__ + 12;
    if ($throwError) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    __ZN2jsL9IdToValueEi2416($1, $id);
    var $3 = $cx;
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $4 = __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($3, $_idx_val$0, $_idx_val$1, $idstr);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    var $6 = HEAP32[$idstr >> 2];
    var $7 = _JSID_TO_STRING2421($6);
    var $8 = $cx;
    __ZN16JSAutoByteStringC1EP9JSContextP8JSString($bytes, $8, $7);
    var $bytes_idx2_val = HEAP32[$bytes >> 2];
    var $9 = __ZNK16JSAutoByteStringntEv($bytes_idx2_val);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = __ZNK16JSAutoByteString3ptrEv($bytes_idx2_val);
    _JS_ReportErrorNumber($3, 4, 240, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $11, tempInt));
    __label__ = 5;
    break;
   case 5:
    __ZN16JSAutoByteStringD1Ev($bytes_idx2_val);
    var $_1 = 0;
    __label__ = 7;
    break;
   case 6:
    HEAP8[$rval] = 0;
    var $_1 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js8PropDesc12setterObjectEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx1 = $this + 24 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $1 = __ZNK2JS5Value11isUndefinedEv($_idx1_val$0, $_idx1_val$1);
    if ($1) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($_idx1_val$0, $_idx1_val$1);
    var $6 = $3;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js8PropDesc12getterObjectEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx1 = $this + 16 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $1 = __ZNK2JS5Value11isUndefinedEv($_idx1_val$0, $_idx1_val$1);
    if ($1) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($_idx1_val$0, $_idx1_val$1);
    var $6 = $3;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSONParserC1EP9JSContextPKtjNS_11ParsingModeENS_13ErrorHandlingE($this, $cx, $data, $length, $parsingMode, $errorHandling) {
  __ZN10JSONParserC2EP9JSContextPKtjNS_11ParsingModeENS_13ErrorHandlingE($this, $cx, $data, $length, $parsingMode, $errorHandling);
  return;
}

function __ZN15EvalScriptGuardC1EP9JSContextP14JSLinearString($this, $cx, $str) {
  __ZN15EvalScriptGuardC2EP9JSContextP14JSLinearString($this, $cx, $str);
  return;
}

function __ZN15EvalScriptGuard17lookupInEvalCacheEPN2js10StackFrameEjP12JSPrincipalsR8JSObject($this, $caller, $staticLevel, $principals, $scopeobj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    var $4 = HEAP32[$this + 4 >> 2];
    var $6 = HEAP32[$this + 8 >> 2];
    var $7 = __ZL15EvalCacheLookupP9JSContextP14JSLinearStringPN2js10StackFrameEjP12JSPrincipalsR8JSObjectPP8JSScript($2, $4, $caller, $staticLevel, $principals, $scopeobj, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAP32[$1 >> 2];
    __Z20js_CallNewScriptHookP9JSContextP8JSScriptP10JSFunction($10, $7, 0);
    var $11 = $this + 12 | 0;
    HEAP32[$11 >> 2] = $7;
    var $12 = $7 + 37 | 0;
    var $14 = HEAP8[$12] & 127;
    HEAP8[$12] = $14;
    var $16 = HEAP32[$11 >> 2] + 37 | 0;
    var $18 = HEAP8[$16] | 64;
    HEAP8[$16] = $18;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN15EvalScriptGuardD1Ev($this) {
  __ZN15EvalScriptGuardD2Ev($this);
  return;
}

function __ZN15EvalScriptGuardD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$this >> 2];
    __Z24js_CallDestroyScriptHookP9JSContextP8JSScript($6, $2);
    var $8 = HEAP32[$1 >> 2] + 37 | 0;
    var $10 = HEAP8[$8] & -65;
    HEAP8[$8] = $10;
    var $12 = HEAP32[$1 >> 2] + 37 | 0;
    var $14 = HEAP8[$12] | -128;
    HEAP8[$12] = $14;
    var $15 = $this + 8 | 0;
    var $19 = HEAP32[$1 >> 2] + 84 | 0;
    var $_c = HEAP32[HEAP32[$15 >> 2] >> 2];
    HEAP32[$19 >> 2] = $_c;
    var $20 = HEAP32[$1 >> 2];
    var $21 = HEAP32[$15 >> 2];
    HEAP32[$21 >> 2] = $20;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15EvalCacheLookupP9JSContextP14JSLinearStringPN2js10StackFrameEjP12JSPrincipalsR8JSObjectPP8JSScript($cx, $str, $caller, $staticLevel, $principals, $scopeobj, $bucket) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __ZNK9JSContext11findVersionEv($1);
    var $3 = $caller;
    var $4 = ($principals | 0) == 0;
    var $5 = $principals + 20 | 0;
    var $scriptp_0 = $bucket;
    var $count_0 = 1;
    __label__ = 2;
    break;
   case 2:
    var $count_0;
    var $scriptp_0;
    var $7 = HEAPU32[$scriptp_0 >> 2];
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAPU16[$7 + 36 >> 1];
    if (($12 & 2) << 16 >> 16 == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAPU16[$7 + 46 >> 1] & 65535 | 0) == ($staticLevel | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 5:
    var $_idx5_val = HEAP16[$7 + 12 >> 1];
    var $22 = __ZNK8JSScript10getVersionEv($_idx5_val);
    if (($22 | 0) == ($2 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 6:
    if (($12 & 512) << 16 >> 16 == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 7:
    var $28 = $7 + 76 | 0;
    var $29 = HEAP32[$28 >> 2];
    if (($29 | 0) == ($principals | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($4 | ($29 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $34 = HEAP32[$5 >> 2];
    var $35 = FUNCTION_TABLE[$34]($principals, $29);
    if (($35 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = HEAP32[$28 >> 2];
    var $40 = HEAP32[$38 + 20 >> 2];
    var $41 = FUNCTION_TABLE[$40]($38, $principals);
    if (($41 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $44 = __ZN8JSScript17getCallerFunctionEv($7);
    var $45 = __ZNK2js10StackFrame3funEv($3);
    if (($44 | 0) == ($45 | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 12:
    var $52 = HEAP32[HEAP32[$7 + 56 >> 2] >> 2] | 0;
    if (($52 | 0) == ($str | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $55 = __ZN2js12EqualStringsEP14JSLinearStringS1_($52, $str);
    if ($55) {
      __label__ = 14;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 14:
    var $_idx_val = HEAP32[$7 + 4 >> 2];
    var $_idx1_val = HEAP8[$7 + 16 | 0];
    var $59 = __ZN8JSScript7objectsEv($_idx_val, $_idx1_val);
    var $60 = $59;
    if ((HEAP32[$59 + 4 >> 2] | 0) == 1) {
      __label__ = 15;
      break;
    } else {
      var $i_0_ph = 1;
      var $objarray_0_ph = $60;
      __label__ = 17;
      break;
    }
   case 15:
    var $66 = HEAP8[$7 + 18 | 0];
    var $67 = __ZN8JSScript13isValidOffsetEh($66);
    if ($67) {
      __label__ = 16;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 16:
    var $69 = __ZN8JSScript7regexpsEv($_idx_val, $66);
    var $i_0_ph = 0;
    var $objarray_0_ph = $69;
    __label__ = 17;
    break;
   case 17:
    var $objarray_0_ph;
    var $i_0_ph;
    var $_idx2_val = HEAP32[HEAP32[HEAP32[$objarray_0_ph >> 2] + ($i_0_ph << 2) >> 2] + 20 >> 2];
    var $77 = __ZNK8JSObject9getParentEv($_idx2_val);
    if (($77 | 0) == ($scopeobj | 0)) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $80 = $7 + 84 | 0;
    var $82 = HEAP32[$80 >> 2];
    HEAP32[$scriptp_0 >> 2] = $82;
    HEAP32[$80 >> 2] = 0;
    var $_0 = $7;
    __label__ = 21;
    break;
   case 19:
    if (($count_0 | 0) == 4) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $scriptp_0 = $7 + 84 | 0;
    var $count_0 = $count_0 + 1 | 0;
    __label__ = 2;
    break;
   case 21:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15EvalCacheLookupP9JSContextP14JSLinearStringPN2js10StackFrameEjP12JSPrincipalsR8JSObjectPP8JSScript["X"] = 1;

function __ZN8JSScript17getCallerFunctionEv($this) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $_idx1_val = HEAP8[$this + 16 | 0];
  var $3 = __ZN8JSScript11getFunctionEj($_idx_val, $_idx1_val, 0);
  return $3;
}

function __ZN15EvalScriptGuardC2EP9JSContextP14JSLinearString($this, $cx, $str) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $str;
  HEAP32[$this + 12 >> 2] = 0;
  var $4 = __ZL13EvalCacheHashP9JSContextP14JSLinearString($cx, $str);
  HEAP32[$this + 8 >> 2] = $4;
  return;
}

function __ZL13EvalCacheHashP9JSContextP14JSLinearString($cx, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$str >> 2];
    var $1 = __ZNK8JSString6lengthEv($_idx_val);
    var $n_0 = $1 >>> 0 > 100 ? 100 : $1;
    if (($n_0 | 0) == 0) {
      var $h_0_lcssa = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $str_idx_val = HEAP32[$str + 4 >> 2];
    var $4 = __ZNK14JSLinearString5charsEv($str_idx_val);
    var $s_01 = $4;
    var $n_12 = $n_0;
    var $h_03 = 0;
    __label__ = 3;
    break;
   case 3:
    var $h_03;
    var $n_12;
    var $s_01;
    var $11 = HEAPU16[$s_01 >> 1] & 65535 ^ ($h_03 << 4 | $h_03 >>> 28);
    var $13 = $n_12 - 1 | 0;
    if (($13 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $s_01 = $s_01 + 2 | 0;
      var $n_12 = $13;
      var $h_03 = $11;
      __label__ = 3;
      break;
    }
   case 4:
    var $h_0_lcssa = ($11 * -1640531527 | 0) >>> 26;
    __label__ = 5;
    break;
   case 5:
    var $h_0_lcssa;
    return HEAP32[$cx + 56 >> 2] + 452 + ($h_0_lcssa << 2) | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSONParserC2EP9JSContextPKtjNS_11ParsingModeENS_13ErrorHandlingE($this, $cx, $data, $length, $parsingMode, $errorHandling) {
  HEAP32[$this >> 2] = $cx;
  var $2 = $this + 4 | 0;
  __ZN7mozilla9RangedPtrIKtEC1EPS1_j($2, $data);
  var $3 = $this + 8 | 0;
  var $4 = $data + ($length << 1) | 0;
  __ZN7mozilla9RangedPtrIKtEC1EPS1_S3_j($3, $4);
  HEAP32[$this + 24 >> 2] = $parsingMode;
  HEAP32[$this + 28 >> 2] = $errorHandling;
  return;
}

function __Z13js_json_parseP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $anchor = __stackBase__;
    var $reviver = __stackBase__ + 4;
    if (($argc | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $cx;
    var $_idx1 = $vp + 16 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $4 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($3, $_idx1_val$0, $_idx1_val$1);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $cx;
    var $8 = __ZN8JSString12ensureLinearEP9JSContext($4, $7);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = HEAP32[HEAP32[$cx + 52 >> 2] + 209984 >> 2];
    var $14 = $13 | 0;
    var $15 = $13 | 0;
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $15);
    var $linear_02 = $14;
    var $24 = $15;
    __label__ = 7;
    break;
   case 5:
    var $17 = $8 | 0;
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $17);
    if ($argc >>> 0 > 1) {
      __label__ = 6;
      break;
    } else {
      var $linear_02 = $8;
      var $24 = $17;
      __label__ = 7;
      break;
    }
   case 6:
    var $20 = $vp + 24 | 0;
    var $21$0 = HEAP32[$20 >> 2];
    var $21$1 = HEAP32[$20 + 4 >> 2];
    var $22 = $reviver | 0;
    HEAP32[$22 >> 2] = $21$0;
    HEAP32[$22 + 4 >> 2] = $21$1;
    var $linear_01 = $8;
    var $26 = $17;
    __label__ = 8;
    break;
   case 7:
    var $24;
    var $linear_02;
    __ZN2JSL14UndefinedValueEv2537($reviver);
    var $linear_01 = $linear_02;
    var $26 = $24;
    __label__ = 8;
    break;
   case 8:
    var $26;
    var $linear_01;
    var $linear_01_idx_val = HEAP32[$linear_01 + 4 >> 2];
    var $27 = __ZNK14JSLinearString5charsEv($linear_01_idx_val);
    var $_idx_val = HEAP32[$26 >> 2];
    var $28 = __ZNK8JSString6lengthEv($_idx_val);
    var $29 = __ZN2js20ParseJSONWithReviverEP9JSContextPKtjRKN2JS5ValueEPS5_12DecodingMode($cx, $27, $28, $reviver, $vp, 0);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z13js_json_parseP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2JSL14UndefinedValueEv2537($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2js20ParseJSONWithReviverEP9JSContextPKtjRKN2JS5ValueEPS5_12DecodingMode($cx, $chars, $length, $reviver, $vp, $decodingMode) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $parser = __stackBase__;
    var $1 = ($decodingMode | 0) != 0 & 1;
    var $2 = $parser;
    var $3 = $cx;
    __ZN10JSONParserC1EP9JSContextPKtjNS_11ParsingModeENS_13ErrorHandlingE($2, $3, $chars, $length, $1, 0);
    var $4 = $parser;
    var $5 = __ZN10JSONParser5parseEPN2JS5ValueE($4, $vp);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $reviver_idx = $reviver | 0;
    var $reviver_idx_val$0 = HEAP32[$reviver_idx >> 2];
    var $reviver_idx_val$1 = HEAP32[$reviver_idx + 4 >> 2];
    var $7 = __ZL13js_IsCallableRKN2JS5ValueE2550($reviver_idx_val$0, $reviver_idx_val$1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = __ZL6ReviveP9JSContextRKN2JS5ValueEPS2_($cx, $reviver, $vp);
    var $_0 = $9 & 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_json_stringifyP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 96;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $space = __stackBase__ + 8;
    var $sb = __stackBase__ + 16;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JSL14UndefinedValueEv2537($1);
    var $3 = $1 | 0;
    var $4$0 = HEAP32[$3 >> 2];
    var $4$1 = HEAP32[$3 + 4 >> 2];
    var $5 = $vp | 0;
    HEAP32[$5 >> 2] = $4$0;
    HEAP32[$5 + 4 >> 2] = $4$1;
    var $24 = 0;
    __label__ = 8;
    break;
   case 3:
    var $7 = $vp + 16 | 0;
    var $st$1$0 = $7 | 0;
    var $8$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $7 + 4 | 0;
    var $8$1 = HEAP32[$st$1$1 >> 2];
    var $9 = $1 | 0;
    var $st$6$0 = $9 | 0;
    HEAP32[$st$6$0 >> 2] = $8$0;
    var $st$6$1 = $9 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $8$1;
    var $10 = $vp | 0;
    HEAP32[$10 >> 2] = $8$0;
    HEAP32[$10 + 4 >> 2] = $8$1;
    if ($argc >>> 0 > 1) {
      __label__ = 4;
      break;
    } else {
      var $24 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $_idx = $vp + 24 | 0;
    var $st$1$0 = $_idx | 0;
    var $_idx_val$0 = HEAPU32[$st$1$0 >> 2];
    var $st$1$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAP32[$st$1$1 >> 2];
    var $13 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      var $18 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $15 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $18 = $15;
    __label__ = 6;
    break;
   case 6:
    var $18;
    if ($argc >>> 0 > 2) {
      __label__ = 7;
      break;
    } else {
      var $24 = $18;
      __label__ = 8;
      break;
    }
   case 7:
    var $21 = $vp + 32 | 0;
    var $st$1$0 = $21 | 0;
    var $22$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $21 + 4 | 0;
    var $22$1 = HEAPU32[$st$1$1 >> 2];
    var $23 = $space | 0;
    var $st$6$0 = $23 | 0;
    HEAP32[$st$6$0 >> 2] = $22$0;
    var $st$6$1 = $23 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $22$1;
    var $27 = $18;
    var $26$1 = $22$1;
    var $26$0 = $22$0;
    __label__ = 9;
    break;
   case 8:
    var $24;
    __ZN2JSL14UndefinedValueEv2537($space);
    var $_phi_trans_insert = $space | 0;
    var $27 = $24;
    var $26$1 = HEAP32[$_phi_trans_insert + 4 >> 2];
    var $26$0 = HEAP32[$_phi_trans_insert >> 2];
    __label__ = 9;
    break;
   case 9:
    var $26$0;
    var $26$1;
    var $27;
    var $28 = $sb;
    var $29 = $cx;
    __ZN2js12StringBufferC1EP9JSContext($28, $29);
    var $30 = __Z12js_StringifyP9JSContextPN2JS5ValueEP8JSObjectS2_RN2js12StringBufferE($cx, $vp, $27, $26$0, $26$1, $sb);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $33 = __ZNK2js12StringBuffer5emptyEv($28);
    if ($33) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $35 = $sb;
    var $36 = __ZN2js12StringBuffer12finishStringEv($35);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $39 = $36 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $39);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 13:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    __ZN2js12StringBufferD1Ev($28);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z17js_json_stringifyP9JSContextjPN2JS5ValueE["X"] = 1;

function _INT_FITS_IN_JSID2543($i) {
  return ($i + 1073741824 | 0) >>> 31 ^ 1;
}

function _INT_TO_JSID2544($i) {
  return $i << 1 | 1;
}

function __ZN2js2gcL15GetGCObjectKindEjb2555($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z12js_StringifyP9JSContextPN2JS5ValueEP8JSObjectS2_RN2js12StringBufferE($cx, $vp, $replacer, $_0_0_0_val$0, $_0_0_0_val$1, $sb) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 284;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $space = __stackBase__;
    var $propertyList = __stackBase__ + 8;
    var $len = __stackBase__ + 68;
    var $idSet = __stackBase__ + 72;
    var $1 = __stackBase__ + 100;
    var $v = __stackBase__ + 104;
    var $id = __stackBase__ + 112;
    var $n = __stackBase__ + 116;
    var $p = __stackBase__ + 120;
    var $2 = __stackBase__ + 128;
    var $d = __stackBase__ + 136;
    var $gap = __stackBase__ + 144;
    var $d1 = __stackBase__ + 224;
    var $anchor = __stackBase__ + 232;
    var $scx = __stackBase__ + 236;
    var $3 = $space | 0;
    HEAP32[$3 >> 2] = $_0_0_0_val$0;
    HEAP32[$3 + 4 >> 2] = $_0_0_0_val$1;
    var $4 = $propertyList;
    var $5 = $cx;
    __ZN2js12AutoIdVectorC1EP9JSContext($4, $5);
    if (($replacer | 0) == 0) {
      var $_04 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $replacer;
    var $_idx9 = $replacer + 4 | 0;
    var $_idx9_val = HEAP32[$_idx9 >> 2];
    var $10 = __ZN8JSObject10isCallableEv($_idx9_val);
    if ($10) {
      var $_04 = $replacer;
      __label__ = 27;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = _JS_IsArrayObject($8);
    if (($12 | 0) == 0) {
      var $_04 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($5, $8, $len);
    var $_idx6_val = HEAP32[$_idx9 >> 2];
    var $17 = __ZNK8JSObject12isDenseArrayEv($_idx6_val);
    var $18 = HEAPU32[$len >> 2];
    if ($17) {
      __label__ = 5;
      break;
    } else {
      var $24 = $18;
      __label__ = 6;
      break;
    }
   case 5:
    var $_idx10_val = HEAP32[$replacer + 28 >> 2];
    var $21 = __ZN8JSObject21getDenseArrayCapacityEv($_idx10_val);
    var $23 = $18 >>> 0 < $21 >>> 0 ? $18 : $21;
    HEAP32[$len >> 2] = $23;
    var $24 = $23;
    __label__ = 6;
    break;
   case 6:
    var $24;
    var $25 = $1;
    __ZN2js15TempAllocPolicyC1EP9JSContext($25, $5);
    var $_0_val = HEAP32[$1 >> 2];
    __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEEC1ES3_($idSet, $_0_val);
    var $26 = __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE4initEj($idSet, $24);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 7:
    var $27 = $2 | 0;
    var $28 = $propertyList | 0;
    var $v_idx12 = $v | 0;
    var $_idx20 = $p | 0;
    var $i_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $i_0;
    if ($i_0 >>> 0 < $24 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 9:
    var $32 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($8, $5, $i_0, $v);
    if (($32 | 0) == 0) {
      __label__ = 49;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $st$0$0 = $v_idx12 | 0;
    var $v_idx12_val$0 = HEAPU32[$st$0$0 >> 2];
    var $st$0$1 = $v_idx12 + 4 | 0;
    var $v_idx12_val$1 = HEAPU32[$st$0$1 >> 2];
    var $35 = __ZNK2JS5Value8isNumberEv($v_idx12_val$0, $v_idx12_val$1);
    if ($35) {
      __label__ = 11;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 11:
    var $37 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi2542($v, $n);
    if ($37) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $39 = HEAP32[$n >> 2];
    var $40 = _INT_FITS_IN_JSID2543($39);
    if (($40 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $43 = _INT_TO_JSID2544($39);
    HEAP32[$id >> 2] = $43;
    __label__ = 22;
    break;
   case 14:
    var $st$0$0 = $v_idx12 | 0;
    var $v_idx19_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $v_idx12 + 4 | 0;
    var $v_idx19_val$1 = HEAP32[$st$0$1 >> 2];
    var $45 = __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($5, $v_idx19_val$0, $v_idx19_val$1, $id);
    if ($45) {
      __label__ = 15;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 15:
    var $47 = HEAP32[$id >> 2];
    var $48 = __Z22js_CheckForStringIndexi($47);
    HEAP32[$id >> 2] = $48;
    __label__ = 22;
    break;
   case 16:
    var $50 = __ZNK2JS5Value8isStringEv($v_idx12_val$0, $v_idx12_val$1);
    if ($50) {
      __label__ = 20;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $52 = __ZNK2JS5Value8isObjectEv($v_idx12_val$0, $v_idx12_val$1);
    if ($52) {
      __label__ = 18;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 18:
    var $54 = __ZNK2JS5Value8toObjectEv($v_idx12_val$0, $v_idx12_val$1);
    var $_idx16_val = HEAP32[$54 + 4 >> 2];
    var $55 = __ZNK8JSObject8isStringEv($_idx16_val);
    if ($55) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $57 = __ZNK8JSObject8isNumberEv($_idx16_val);
    if ($57) {
      __label__ = 20;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 20:
    var $59 = __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($5, $v_idx12_val$0, $v_idx12_val$1, $id);
    if ($59) {
      __label__ = 21;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 21:
    var $61 = HEAP32[$id >> 2];
    var $62 = __Z22js_CheckForStringIndexi($61);
    HEAP32[$id >> 2] = $62;
    __label__ = 22;
    break;
   case 22:
    __ZNK2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE12lookupForAddERKi($p, $idSet, $id);
    var $_idx20_val_idx_val = HEAP32[HEAP32[$_idx20 >> 2] >> 2];
    __ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3PtrcvMSA_FvvEEv($2, $_idx20_val_idx_val);
    if ((HEAP32[$27 >> 2] | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 23:
    var $67 = __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE3addERNS_6detail9HashTableIKiNS4_6SetOpsES3_E6AddPtrERS7_($idSet, $p, $id);
    if ($67) {
      __label__ = 24;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 24:
    var $id_val = HEAP32[$id >> 2];
    var $69 = __ZN2js16AutoVectorRooterIiE6appendERKi($28, $id_val);
    if ($69) {
      __label__ = 25;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 25:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 8;
    break;
   case 26:
    __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED1Ev($idSet);
    var $_04 = $replacer;
    __label__ = 27;
    break;
   case 27:
    var $_04;
    var $74 = __ZNK2JS5Value8isObjectEv($_0_0_0_val$0, $_0_0_0_val$1);
    if ($74) {
      __label__ = 28;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 28:
    var $76 = __ZNK2JS5Value8toObjectEv($_0_0_0_val$0, $_0_0_0_val$1);
    var $_idx13_val = HEAP32[$76 + 4 >> 2];
    var $77 = __ZNK8JSObject8isNumberEv($_idx13_val);
    if ($77) {
      __label__ = 29;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 29:
    var $79 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($5, $space, $d);
    if ($79) {
      __label__ = 30;
      break;
    } else {
      var $_5 = 0;
      __label__ = 54;
      break;
    }
   case 30:
    var $81 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    __ZN2JSL11NumberValueEd2545($space, $81);
    __label__ = 34;
    break;
   case 31:
    var $83 = __ZNK8JSObject8isStringEv($_idx13_val);
    if ($83) {
      __label__ = 32;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 32:
    var $85 = $cx;
    var $86 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($85, $_0_0_0_val$0, $_0_0_0_val$1);
    if (($86 | 0) == 0) {
      var $_5 = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    __ZN2JSL11StringValueEP8JSString2546($space, $86);
    __label__ = 34;
    break;
   case 34:
    var $90 = $gap;
    __ZN2js12StringBufferC1EP9JSContext($90, $5);
    var $space_idx11_val$0 = HEAPU32[$3 >> 2];
    var $space_idx11_val$1 = HEAPU32[$3 + 4 >> 2];
    var $91 = __ZNK2JS5Value8isNumberEv($space_idx11_val$0, $space_idx11_val$1);
    if ($91) {
      __label__ = 35;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 35:
    __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd2547($cx, $space, $d1);
    var $93 = (tempDoubleI32[0] = HEAP32[$d1 >> 2], tempDoubleI32[1] = HEAP32[$d1 + 4 >> 2], tempDoubleF64[0]);
    var $95 = $93 > 10 ? 10 : $93;
    tempDoubleF64[0] = $95, HEAP32[$d1 >> 2] = tempDoubleI32[0], HEAP32[$d1 + 4 >> 2] = tempDoubleI32[1];
    if ($95 < 1) {
      __label__ = 40;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $98 = $95 >= 0 ? Math.floor($95) : Math.ceil($95);
    var $99 = __ZN2js12StringBuffer7appendNEtj($gap, $98);
    if ($99) {
      __label__ = 40;
      break;
    } else {
      var $_4 = 0;
      __label__ = 47;
      break;
    }
   case 37:
    var $101 = __ZNK2JS5Value8isStringEv($space_idx11_val$0, $space_idx11_val$1);
    if ($101) {
      __label__ = 38;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 38:
    var $103 = __ZNK2JS5Value8toStringEv($space_idx11_val$0, $space_idx11_val$1);
    var $104 = __ZN8JSString12ensureLinearEP9JSContext($103, $5);
    if (($104 | 0) == 0) {
      var $_4 = 0;
      __label__ = 47;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $107 = $104 | 0;
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $107);
    var $_idx_val = HEAP32[$103 >> 2];
    var $108 = __ZNK8JSString6lengthEv($_idx_val);
    var $110 = $108 >>> 0 > 10 ? 10 : $108;
    var $_idx3_val = HEAP32[$104 + 4 >> 2];
    var $111 = __ZNK14JSLinearString5charsEv($_idx3_val);
    var $112 = __ZN2js12StringBuffer6appendEPKtj($90, $111, $110);
    if ($112) {
      __label__ = 40;
      break;
    } else {
      var $_4 = 0;
      __label__ = 47;
      break;
    }
   case 40:
    var $114 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2548($cx);
    if (($114 | 0) == 0) {
      var $_4 = 0;
      __label__ = 47;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    var $121 = HEAP32[HEAP32[$cx + 52 >> 2] + 209972 >> 2] | 0;
    var $122 = __ZL12ATOM_TO_JSIDP6JSAtom2549($121);
    var $123 = $cx;
    var $124 = $114;
    var $125 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($123, $124, $122, $vp, 10, 12, 1, 0, 0, 0);
    if (($125 | 0) == 0) {
      var $_4 = 0;
      __label__ = 47;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    __ZN16StringifyContextC1EP9JSContextRN2js12StringBufferERKS3_P8JSObjectRKNS2_12AutoIdVectorE($scx, $cx, $sb, $gap, $_04, $propertyList);
    var $128 = __ZN16StringifyContext4initEv($scx);
    if ($128) {
      __label__ = 43;
      break;
    } else {
      var $_3 = 0;
      __label__ = 46;
      break;
    }
   case 43:
    var $130 = __ZL15PreprocessValueIiEbP9JSContextP8JSObjectT_PN2JS5ValueEP16StringifyContext($cx, $114, $122, $vp, $scx);
    if ($130) {
      __label__ = 44;
      break;
    } else {
      var $_3 = 0;
      __label__ = 46;
      break;
    }
   case 44:
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $132 = __ZL15IsFilteredValueRKN2JS5ValueE($vp_idx_val$0, $vp_idx_val$1);
    if ($132) {
      var $_3 = 1;
      __label__ = 46;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $134 = __ZL3StrP9JSContextRKN2JS5ValueEP16StringifyContext($cx, $vp, $scx);
    var $_3 = $134;
    __label__ = 46;
    break;
   case 46:
    var $_3;
    __ZN16StringifyContextD1Ev($scx);
    var $_4 = $_3;
    __label__ = 47;
    break;
   case 47:
    var $_4;
    __ZN2js12StringBufferD1Ev($90);
    var $_5 = $_4;
    __label__ = 54;
    break;
   case 48:
    __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED1Ev($idSet);
    var $_5 = 0;
    __label__ = 54;
    break;
   case 49:
    __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED1Ev($idSet);
    var $_5 = 0;
    __label__ = 54;
    break;
   case 50:
    __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED1Ev($idSet);
    var $_5 = 0;
    __label__ = 54;
    break;
   case 51:
    __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED1Ev($idSet);
    var $_5 = 0;
    __label__ = 54;
    break;
   case 52:
    __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED1Ev($idSet);
    var $_5 = 0;
    __label__ = 54;
    break;
   case 53:
    __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED1Ev($idSet);
    var $_5 = 0;
    __label__ = 54;
    break;
   case 54:
    var $_5;
    __ZN2js12AutoIdVectorD1Ev($4);
    STACKTOP = __stackBase__;
    return $_5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z12js_StringifyP9JSContextPN2JS5ValueEP8JSObjectS2_RN2js12StringBufferE["X"] = 1;

function __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEEC1ES3_($this, $a_01) {
  __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEEC2ES3_($this, $a_01);
  return;
}

function __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E4initEj($1, $len);
  return $2;
}

function __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi2542($v, $pi) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx2 = $v | 0;
    var $v_idx2_val$0 = HEAP32[$v_idx2 >> 2];
    var $v_idx2_val$1 = HEAP32[$v_idx2 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx2_val$0, $v_idx2_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx2_val$0, $v_idx2_val$1);
    HEAP32[$pi >> 2] = $3;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $5 = __ZNK2JS5Value8isDoubleEv($v_idx2_val$0, $v_idx2_val$1);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZNK2JS5Value8toDoubleEv($v);
    var $8 = _JSDOUBLE_IS_INT322570($7, $pi);
    var $_0 = ($8 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE12lookupForAddERKi($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E12lookupForAddERS2_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3PtrcvMSA_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 190,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE3addERNS_6detail9HashTableIKiNS4_6SetOpsES3_E6AddPtrERS7_($this, $p, $t) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3addERNS9_6AddPtrERS2_($1, $p, $t);
  return $2;
}

function __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2JSL11NumberValueEd2545($agg_result, $dbl) {
  var $1 = __ZN2JS5Value9setNumberEd($agg_result, $dbl);
  return;
}

function __ZN2JSL11StringValueEP8JSString2546($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd2547($cx, $v, $dp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx2 = $v | 0;
    var $v_idx2_val$0 = HEAP32[$v_idx2 >> 2];
    var $v_idx2_val$1 = HEAP32[$v_idx2 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx2_val$0, $v_idx2_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx2_val$0, $v_idx2_val$1);
    tempDoubleF64[0] = $3 | 0, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    __label__ = 8;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($v_idx2_val$0, $v_idx2_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($v);
    tempDoubleF64[0] = $8, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $13 = $8;
    __label__ = 7;
    break;
   case 5:
    var $10 = $cx;
    var $11 = __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($10, $v_idx2_val$0, $v_idx2_val$1, $dp);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $_pre = (tempDoubleI32[0] = HEAP32[$dp >> 2], tempDoubleI32[1] = HEAP32[$dp + 4 >> 2], tempDoubleF64[0]);
    var $13 = $_pre;
    __label__ = 7;
    break;
   case 7:
    var $13;
    var $14 = __ZL18js_DoubleToIntegerd2596($13);
    tempDoubleF64[0] = $14, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer7appendNEtj($this, $n) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP16[$1 >> 1] = 32;
    var $_idx_val = HEAP32[$this + 8 >> 2];
    var $3 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv($_idx_val);
    var $4 = $3 + $n | 0;
    var $5 = $this;
    var $6 = __ZN2js12StringBuffer11checkLengthEj($5, $4);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $this | 0;
    var $9 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE7appendNERKtj($8, $1, $n);
    var $_0 = $9;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2548($cx) {
  var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb2555($3);
  var $5 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2593($cx, $4);
  return $5;
}

function __ZL12ATOM_TO_JSIDP6JSAtom2549($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj2592($1);
  return $2;
}

function __ZN16StringifyContextC1EP9JSContextRN2js12StringBufferERKS3_P8JSObjectRKNS2_12AutoIdVectorE($this, $cx, $sb, $gap, $replacer, $propertyList) {
  __ZN16StringifyContextC2EP9JSContextRN2js12StringBufferERKS3_P8JSObjectRKNS2_12AutoIdVectorE($this, $cx, $sb, $gap, $replacer, $propertyList);
  return;
}

function __ZN16StringifyContext4initEv($this) {
  var $1 = $this + 20 | 0;
  var $2 = __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($1);
  return $2;
}

function __ZL15PreprocessValueIiEbP9JSContextP8JSObjectT_PN2JS5ValueEP16StringifyContext($cx, $holder, $key, $vp, $scx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 96;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $toJSON = __stackBase__;
    var $args = __stackBase__ + 8;
    var $1 = __stackBase__ + 32;
    var $args1 = __stackBase__ + 40;
    var $2 = __stackBase__ + 64;
    var $3 = __stackBase__ + 72;
    var $4 = __stackBase__ + 80;
    var $d = __stackBase__ + 88;
    var $vp_idx1 = $vp | 0;
    var $vp_idx1_val$0 = HEAP32[$vp_idx1 >> 2];
    var $vp_idx1_val$1 = HEAP32[$vp_idx1 + 4 >> 2];
    var $5 = __ZNK2JS5Value8isObjectEv($vp_idx1_val$0, $vp_idx1_val$1);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $keyStr_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    var $11 = HEAP32[HEAP32[$cx + 52 >> 2] + 210336 >> 2] | 0;
    var $12 = __ZL12ATOM_TO_JSIDP6JSAtom2549($11);
    var $13 = __ZNK2JS5Value8toObjectEv($vp_idx1_val$0, $vp_idx1_val$1);
    var $14 = $cx;
    var $15 = $13;
    var $16 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($14, $15, $12, 2, $toJSON);
    if (($16 | 0) == 0) {
      var $_3 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $toJSON_idx = $toJSON | 0;
    var $toJSON_idx_val$0 = HEAP32[$toJSON_idx >> 2];
    var $toJSON_idx_val$1 = HEAP32[$toJSON_idx + 4 >> 2];
    var $19 = __ZL13js_IsCallableRKN2JS5ValueE2550($toJSON_idx_val$0, $toJSON_idx_val$1);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $keyStr_0 = 0;
      __label__ = 9;
      break;
    }
   case 4:
    var $21 = __ZN14KeyStringifierIiE8toStringEP9JSContexti($cx, $key);
    if (($21 | 0) == 0) {
      var $_3 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = $args;
    __ZN2js15InvokeArgsGuardC1Ev($24);
    var $26 = $cx + 60 | 0;
    var $27 = $cx;
    var $28 = $args;
    var $29 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($26, $27, 1, $28);
    if ($29) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $_idx4 = $args | 0;
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $31 = __ZNK2js12CallReceiver7calleevEv($_idx4_val);
    var $st$3$0 = $toJSON_idx | 0;
    var $32$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $toJSON_idx + 4 | 0;
    var $32$1 = HEAP32[$st$3$1 >> 2];
    var $33 = $31 | 0;
    var $st$8$0 = $33 | 0;
    HEAP32[$st$8$0 >> 2] = $32$0;
    var $st$8$1 = $33 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $32$1;
    var $_idx6_val = HEAP32[$_idx4 >> 2];
    var $34 = __ZNK2js12CallReceiver5thisvEv($_idx6_val);
    var $35$0 = HEAP32[$vp_idx1 >> 2];
    var $35$1 = HEAP32[$vp_idx1 + 4 >> 2];
    var $36 = $34 | 0;
    var $st$19$0 = $36 | 0;
    HEAP32[$st$19$0 >> 2] = $35$0;
    var $st$19$1 = $36 + 4 | 0;
    HEAP32[$st$19$1 >> 2] = $35$1;
    var $_idx11_val = HEAP32[$_idx4 >> 2];
    var $37 = __ZNK2js8CallArgsixEj($_idx11_val, 0);
    __ZN2JSL11StringValueEP8JSString2546($1, $21);
    var $38 = $1 | 0;
    var $39$0 = HEAP32[$38 >> 2];
    var $39$1 = HEAP32[$38 + 4 >> 2];
    var $40 = $37 | 0;
    var $st$32$0 = $40 | 0;
    HEAP32[$st$32$0 >> 2] = $39$0;
    var $st$32$1 = $40 + 4 | 0;
    HEAP32[$st$32$1 >> 2] = $39$1;
    var $41 = $cx;
    var $42 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($41, $24, 0);
    if ($42) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $_idx13_val = HEAP32[$_idx4 >> 2];
    var $43 = __ZNK2js12CallReceiver4rvalEv($_idx13_val);
    var $44 = $43 | 0;
    var $st$3$0 = $44 | 0;
    var $45$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $44 + 4 | 0;
    var $45$1 = HEAP32[$st$3$1 >> 2];
    var $st$7$0 = $vp_idx1 | 0;
    HEAP32[$st$7$0 >> 2] = $45$0;
    var $st$7$1 = $vp_idx1 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $45$1;
    __ZN2js15InvokeArgsGuardD1Ev($24);
    var $keyStr_0 = $21;
    __label__ = 9;
    break;
   case 8:
    __ZN2js15InvokeArgsGuardD1Ev($24);
    var $_3 = 0;
    __label__ = 26;
    break;
   case 9:
    var $keyStr_0;
    var $48 = $scx + 8 | 0;
    var $49 = HEAP32[$48 >> 2];
    if (($49 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_idx8_val = HEAP32[$49 + 4 >> 2];
    var $53 = __ZN8JSObject10isCallableEv($_idx8_val);
    if ($53) {
      __label__ = 11;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 11:
    if (($keyStr_0 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $keyStr_1 = $keyStr_0;
      __label__ = 13;
      break;
    }
   case 12:
    var $57 = __ZN14KeyStringifierIiE8toStringEP9JSContexti($cx, $key);
    if (($57 | 0) == 0) {
      var $_3 = 0;
      __label__ = 26;
      break;
    } else {
      var $keyStr_1 = $57;
      __label__ = 13;
      break;
    }
   case 13:
    var $keyStr_1;
    var $60 = $args1;
    __ZN2js15InvokeArgsGuardC1Ev($60);
    var $62 = $cx + 60 | 0;
    var $63 = $cx;
    var $64 = $args1;
    var $65 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($62, $63, 2, $64);
    if ($65) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    var $67 = $cx;
    var $_idx = $args1 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $68 = __ZNK2js12CallReceiver7calleevEv($_idx_val);
    var $69 = HEAP32[$48 >> 2];
    __ZN2JSL11ObjectValueER8JSObject2569($2, $69);
    var $70 = $2 | 0;
    var $st$7$0 = $70 | 0;
    var $71$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $70 + 4 | 0;
    var $71$1 = HEAP32[$st$7$1 >> 2];
    var $72 = $68 | 0;
    var $st$12$0 = $72 | 0;
    HEAP32[$st$12$0 >> 2] = $71$0;
    var $st$12$1 = $72 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $71$1;
    var $_idx5_val = HEAP32[$_idx >> 2];
    var $73 = __ZNK2js12CallReceiver5thisvEv($_idx5_val);
    __ZN2JSL11ObjectValueER8JSObject2569($3, $holder);
    var $74 = $3 | 0;
    var $75$0 = HEAP32[$74 >> 2];
    var $75$1 = HEAP32[$74 + 4 >> 2];
    var $76 = $73 | 0;
    var $st$25$0 = $76 | 0;
    HEAP32[$st$25$0 >> 2] = $75$0;
    var $st$25$1 = $76 + 4 | 0;
    HEAP32[$st$25$1 >> 2] = $75$1;
    var $_idx10_val = HEAP32[$_idx >> 2];
    var $77 = __ZNK2js8CallArgsixEj($_idx10_val, 0);
    __ZN2JSL11StringValueEP8JSString2546($4, $keyStr_1);
    var $78 = $4 | 0;
    var $79$0 = HEAP32[$78 >> 2];
    var $79$1 = HEAP32[$78 + 4 >> 2];
    var $80 = $77 | 0;
    var $st$38$0 = $80 | 0;
    HEAP32[$st$38$0 >> 2] = $79$0;
    var $st$38$1 = $80 + 4 | 0;
    HEAP32[$st$38$1 >> 2] = $79$1;
    var $_idx9_val = HEAP32[$_idx >> 2];
    var $81 = __ZNK2js8CallArgsixEj($_idx9_val, 1);
    var $82$0 = HEAP32[$vp_idx1 >> 2];
    var $82$1 = HEAP32[$vp_idx1 + 4 >> 2];
    var $83 = $81 | 0;
    var $st$49$0 = $83 | 0;
    HEAP32[$st$49$0 >> 2] = $82$0;
    var $st$49$1 = $83 + 4 | 0;
    HEAP32[$st$49$1 >> 2] = $82$1;
    var $84 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($67, $60, 0);
    if ($84) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $_idx12_val = HEAP32[$_idx >> 2];
    var $85 = __ZNK2js12CallReceiver4rvalEv($_idx12_val);
    var $86 = $85 | 0;
    var $st$3$0 = $86 | 0;
    var $87$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $86 + 4 | 0;
    var $87$1 = HEAP32[$st$3$1 >> 2];
    var $st$7$0 = $vp_idx1 | 0;
    HEAP32[$st$7$0 >> 2] = $87$0;
    var $st$7$1 = $vp_idx1 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $87$1;
    __ZN2js15InvokeArgsGuardD1Ev($60);
    __label__ = 17;
    break;
   case 16:
    __ZN2js15InvokeArgsGuardD1Ev($60);
    var $_3 = 0;
    __label__ = 26;
    break;
   case 17:
    var $vp_idx_val$0 = HEAP32[$vp_idx1 >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx1 + 4 >> 2];
    var $89 = __ZNK2JS5Value8isObjectEv($vp_idx_val$0, $vp_idx_val$1);
    if ($89) {
      __label__ = 18;
      break;
    } else {
      var $_3 = 1;
      __label__ = 26;
      break;
    }
   case 18:
    var $91 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
    var $_idx7_val = HEAP32[$91 + 4 >> 2];
    var $92 = __ZNK8JSObject8getClassEv($_idx7_val);
    if (($92 | 0) == (__ZN2js11NumberClassE | 0)) {
      __label__ = 19;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 19:
    var $95 = $cx;
    var $96 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($95, $vp, $d);
    if ($96) {
      __label__ = 20;
      break;
    } else {
      var $_3 = 0;
      __label__ = 26;
      break;
    }
   case 20:
    var $98 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $99 = __ZN2JS5Value9setNumberEd($vp, $98);
    var $_3 = 1;
    __label__ = 26;
    break;
   case 21:
    if (($92 | 0) == (__ZN2js11StringClassE | 0)) {
      __label__ = 22;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 22:
    var $103 = $cx;
    var $104 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($103, $vp_idx_val$0, $vp_idx_val$1);
    if (($104 | 0) == 0) {
      var $_3 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    __ZN2JS5Value9setStringEP8JSString($vp, $104);
    var $_3 = 1;
    __label__ = 26;
    break;
   case 24:
    if (($92 | 0) == (__ZN2js12BooleanClassE | 0)) {
      __label__ = 25;
      break;
    } else {
      var $_3 = 1;
      __label__ = 26;
      break;
    }
   case 25:
    var $110 = $91;
    var $111 = __ZNK8JSObject16getPrimitiveThisEv($110);
    var $112 = $111 | 0;
    var $st$3$0 = $112 | 0;
    var $113$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $112 + 4 | 0;
    var $113$1 = HEAP32[$st$3$1 >> 2];
    var $st$7$0 = $vp_idx1 | 0;
    HEAP32[$st$7$0 >> 2] = $113$0;
    var $st$7$1 = $vp_idx1 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $113$1;
    var $_3 = 1;
    __label__ = 26;
    break;
   case 26:
    var $_3;
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15PreprocessValueIiEbP9JSContextP8JSObjectT_PN2JS5ValueEP16StringifyContext["X"] = 1;

function __ZL15IsFilteredValueRKN2JS5ValueE($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value11isUndefinedEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      var $10 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL13js_IsCallableRKN2JS5ValueE2550($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($3) {
      var $10 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $10 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_idx_val = HEAP32[$7 + 4 >> 2];
    var $8 = __ZNK8JSObject5isXMLEv($_idx_val);
    var $10 = $8;
    __label__ = 5;
    break;
   case 5:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL3StrP9JSContextRKN2JS5ValueEP16StringifyContext($cx, $v, $scx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 84;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sb = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx;
    __Z21js_ReportOverRecursedP9JSContext($6);
    var $_1 = 0;
    __label__ = 20;
    break;
   case 3:
    var $v_idx4 = $v | 0;
    var $v_idx4_val$0 = HEAPU32[$v_idx4 >> 2];
    var $v_idx4_val$1 = HEAPU32[$v_idx4 + 4 >> 2];
    var $8 = __ZNK2JS5Value8isStringEv($v_idx4_val$0, $v_idx4_val$1);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = HEAP32[$scx >> 2];
    var $12 = __ZNK2JS5Value8toStringEv($v_idx4_val$0, $v_idx4_val$1);
    var $13 = __ZL5QuoteP9JSContextRN2js12StringBufferEP8JSString($cx, $11, $12);
    var $_1 = $13 & 1;
    __label__ = 20;
    break;
   case 5:
    var $16 = __ZNK2JS5Value6isNullEv($v_idx4_val$0, $v_idx4_val$1);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $20 = HEAP32[$scx >> 2];
    var $21 = __ZN2js12StringBuffer6appendILj5EEEbRAT__Kc($20, STRING_TABLE.__str483817);
    var $_1 = $21 & 1;
    __label__ = 20;
    break;
   case 7:
    var $24 = __ZNK2JS5Value9isBooleanEv($v_idx4_val$0, $v_idx4_val$1);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 8:
    var $26 = __ZNK2JS5Value9toBooleanEv($v_idx4_val$0, $v_idx4_val$1);
    var $29 = HEAP32[$scx >> 2];
    if ($26) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $31 = __ZN2js12StringBuffer6appendILj5EEEbRAT__Kc($29, STRING_TABLE.__str32534);
    var $35 = $31;
    __label__ = 11;
    break;
   case 10:
    var $33 = __ZN2js12StringBuffer6appendILj6EEEbRAT__Kc($29, STRING_TABLE.__str42535);
    var $35 = $33;
    __label__ = 11;
    break;
   case 11:
    var $35;
    var $_1 = $35 & 1;
    __label__ = 20;
    break;
   case 12:
    var $38 = __ZNK2JS5Value8isNumberEv($v_idx4_val$0, $v_idx4_val$1);
    if ($38) {
      __label__ = 13;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 13:
    var $40 = __ZNK2JS5Value8isDoubleEv($v_idx4_val$0, $v_idx4_val$1);
    if ($40) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    var $42 = __ZNK2JS5Value8toDoubleEv($v);
    var $43 = __ZL18JSDOUBLE_IS_FINITEd2585($42);
    if (($43 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $48 = HEAP32[$scx >> 2];
    var $49 = __ZN2js12StringBuffer6appendILj5EEEbRAT__Kc($48, STRING_TABLE.__str483817);
    var $_1 = $49 & 1;
    __label__ = 20;
    break;
   case 16:
    var $52 = $cx;
    __ZN2js12StringBufferC1EP9JSContext($sb, $52);
    var $53 = __ZN2js25NumberValueToStringBufferEP9JSContextRKN2JS5ValueERNS_12StringBufferE($52, $v, $sb);
    if ($53) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 17:
    var $56 = HEAP32[$scx >> 2];
    var $57 = __ZN2js12StringBuffer5beginEv($sb);
    var $58 = __ZNK2js12StringBuffer6lengthEv($sb);
    var $59 = $56;
    var $60 = __ZN2js12StringBuffer6appendEPKtj($59, $57, $58);
    var $_0 = $60 & 1;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    __ZN2js12StringBufferD1Ev($sb);
    var $_1 = $_0;
    __label__ = 20;
    break;
   case 19:
    var $64 = $scx + 16 | 0;
    var $66 = HEAP32[$64 >> 2] + 1 | 0;
    HEAP32[$64 >> 2] = $66;
    var $v_idx1_val$0 = HEAP32[$v_idx4 >> 2];
    var $v_idx1_val$1 = HEAP32[$v_idx4 + 4 >> 2];
    var $67 = __ZNK2JS5Value8toObjectEv($v_idx1_val$0, $v_idx1_val$1);
    var $68 = _JS_IsArrayObject($67);
    var $_ZL2JAP9JSContextP8JSObjectP16StringifyContext__ZL2JOP9JSContextP8JSObjectP16StringifyContext = ($68 | 0) != 0 ? 192 : 194;
    var $v_idx_val$0 = HEAP32[$v_idx4 >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx4 + 4 >> 2];
    var $70 = __ZNK2JS5Value8toObjectEv($v_idx_val$0, $v_idx_val$1);
    var $71 = $70;
    var $72 = FUNCTION_TABLE[$_ZL2JAP9JSContextP8JSObjectP16StringifyContext__ZL2JOP9JSContextP8JSObjectP16StringifyContext]($cx, $71, $scx);
    var $74 = HEAP32[$64 >> 2] - 1 | 0;
    HEAP32[$64 >> 2] = $74;
    var $_1 = $72;
    __label__ = 20;
    break;
   case 20:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL3StrP9JSContextRKN2JS5ValueEP16StringifyContext["X"] = 1;

function __ZN16StringifyContextD1Ev($this) {
  __ZN16StringifyContextD2Ev($this);
  return;
}

function __ZL13js_IsCallableRKN2JS5ValueE2550($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZN8JSObject10isCallableEv($_idx_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL6ReviveP9JSContextRKN2JS5ValueEPS2_($cx, $reviver, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2548($cx);
    if (($1 | 0) == 0) {
      var $_1 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $1;
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($tvr, $4, $5);
    var $6 = $cx + 52 | 0;
    var $10 = HEAP32[HEAP32[$6 >> 2] + 209972 >> 2] | 0;
    var $11 = __ZL12ATOM_TO_JSIDP6JSAtom2549($10);
    var $12 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($5, $4, $11, $vp, 0, 0, 1);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $18 = HEAP32[HEAP32[$6 >> 2] + 209972 >> 2] | 0;
    var $19 = __ZL12ATOM_TO_JSIDP6JSAtom2549($18);
    var $20 = __ZL4WalkP9JSContextP8JSObjectiRKN2JS5ValueEPS4_($cx, $1, $19, $reviver, $vp);
    var $_0 = $20;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js16AutoObjectRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 5;
    break;
   case 5:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13json_toSourceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210040 >> 2] | 0;
  __ZN2JS5Value9setStringEP8JSString($vp, $5);
  return 1;
}

function __Z16js_InitJSONClassP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2553($cx, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    var $6 = $cx;
    __ZN8JSObject16setSingletonTypeEP9JSContext($5, $6);
    _OBJECT_TO_JSVAL2554($1, $2);
    var $7 = $cx;
    var $8 = $obj;
    var $_idx1 = $1 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $$emscripten$temp$0 = STRING_TABLE._js_JSON_str | 0;
    var $9 = _JS_DefineProperty($7, $8, $$emscripten$temp$0, $_idx1_val$0, $_idx1_val$1, 10, 12, 0);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $2;
    var $13 = _JS_DefineFunctions($7, $12, __ZL19json_static_methods);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = $obj;
    var $_idx_val = HEAP32[__ZN2js9JSONClassE + 4 >> 2];
    __ZN2js35MarkStandardClassInitializedNoProtoEP8JSObjectPNS_5ClassE($16, $_idx_val);
    var $_0 = $2;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2553($cx, $parent) {
  var $3 = HEAPU32[__ZN2js9JSONClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb2555($3);
  var $5 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2556($cx, $parent, $4);
  return $5;
}

function _OBJECT_TO_JSVAL2554($agg_result, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL_IMPL2574($1, $obj);
    var $_0 = $1 | 0;
    var $_0_val$0 = HEAP32[$_0 >> 2];
    var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
    __ZL13IMPL_TO_JSVAL12jsval_layout2583($agg_result, $_0_val$0, $_0_val$1);
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $6 = $agg_result | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOps6getKeyERKi($t) {
  return $t;
}

function __ZN2js13DefaultHasherIiE4hashERKi($l_val) {
  return $l_val;
}

function __ZN2jsL16GetClassProtoKeyEPNS_5ClassE2566() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[__ZN2js9JSONClassE + 4 >> 2];
    var $2 = $1 >>> 24;
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $1 >>> 17 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E10overloadedEv($this_0_2_val, $this_0_3_val, $this_0_5_val) {
  return ($this_0_5_val + $this_0_3_val | 0) >>> 0 >= ($this_0_2_val * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js13DefaultHasherIiE5matchERKiS3_($id_val, $l_val) {
  return ($id_val | 0) == ($l_val | 0);
}

function _JSID_IS_STRING2575($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_TO_STRING2576($iden) {
  return $iden;
}

function _JSID_IS_INT2577($iden) {
  return $iden & 1;
}

function _JSID_TO_INT2578($iden) {
  return $iden >> 1;
}

function _JSID_IS_OBJECT2581($iden) {
  return ($iden & 7 | 0) == 4 & ($iden | 0) != 4 & 1;
}

function _JSID_TO_OBJECT2582($iden) {
  return $iden & -8;
}

function _JSDOUBLE_IS_NEGZERO2573($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d != 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $_0 = tempDoubleI32[1] >>> 31 | 0 << 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3PtrC2ERNS0_14HashTableEntryIS2_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_EC2ES6_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  return;
}

function _OBJECT_TO_JSVAL_IMPL2574($agg_result, $obj) {
  HEAP32[$agg_result + 4 >> 2] = -121;
  HEAP32[$agg_result >> 2] = $obj;
  return;
}

function __ZL13IMPL_TO_JSVAL12jsval_layout2583($agg_result, $l_0$0, $l_0$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $l_0$0;
  HEAP32[$1 + 4 >> 2] = $l_0$1;
  return;
}

function __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2556($cx, $parent, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = 0;
    var $2 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_2557($cx, $parent, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 2:
    var $4 = HEAP32[$1 >> 2];
    var $5 = ($4 | 0) == 0;
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = __ZN2js5types15emptyTypeObjectE;
    var $_pre_phi = $cx;
    __label__ = 5;
    break;
   case 4:
    var $7 = $4;
    var $8 = $cx;
    var $9 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($7, $8, 0, 0);
    var $10 = $9;
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      var $12 = $10;
      var $_pre_phi = $8;
      __label__ = 5;
      break;
    }
   case 5:
    var $_pre_phi;
    var $12;
    var $13 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($_pre_phi, $kind);
    var $14 = $13;
    if (($13 | 0) == 0) {
      var $_0 = $14;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_not = ($parent | 0) == 0 ^ 1;
    var $parent_mux = $_not ? $parent : 0;
    if ($_not | $5) {
      var $23 = $parent_mux;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx_val = HEAP32[$4 + 20 >> 2];
    var $20 = __ZNK8JSObject9getParentEv($_idx_val);
    var $23 = $20;
    __label__ = 8;
    break;
   case 8:
    var $23;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($13, __ZN2js9JSONClassE, $12, $23, 0, (__ZN2js9JSONClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $_idx1_val = HEAP32[__ZN2js9JSONClassE + 4 >> 2];
    var $26 = __ZNK2js5Class8isNativeEv($_idx1_val);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $28 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2560($cx, $14, $12, $kind);
    if ($28) {
      var $_0 = $14;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 0;
    __label__ = 12;
    break;
   case 11:
    __ZN8JSObject21setSharedNonNativeMapEv($13);
    var $_0 = $14;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_2557($cx, $parent, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL16GetClassProtoKeyEPNS_5ClassE2566();
    var $2 = $cx;
    var $3 = $parent;
    var $4 = $proto;
    var $5 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, $1, $4, __ZN2js9JSONClassE);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$proto >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, 1, $4, 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2560($cx, $obj, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAPU32[__ZN2js9JSONClassE + 4 >> 2] >>> 8 & 255;
    var $4 = $obj;
    var $_idx_val = HEAP32[$obj + 28 >> 2];
    var $6 = __ZNK8JSObject8numSlotsEv($_idx_val);
    if ($3 >>> 0 > $6 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $obj;
    var $10 = $cx;
    var $11 = __ZN8JSObject10allocSlotsEP9JSContextj($9, $10, $3);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $13 = $type;
    var $14 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($13, __ZN2js9JSONClassE);
    var $15 = $cx;
    if ($14) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($13, $15, __ZN2js9JSONClassE, $kind);
    var $empty_0_in = $17;
    __label__ = 6;
    break;
   case 5:
    var $19 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($15, __ZN2js9JSONClassE);
    var $empty_0_in = $19;
    __label__ = 6;
    break;
   case 6:
    var $empty_0_in;
    if (($empty_0_in | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $empty_0_in | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3addERNS9_6AddPtrERS2_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3addERNS9_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$t >> 2];
    var $6 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$6 >> 2] = $3;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3addERNS9_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryIKiE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 12 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 8 >> 2];
    var $this_idx1 = $this + 12 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 20 >> 2];
    var $12 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryIKiE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 3:
    var $14 = $this | 0;
    var $15 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E11createTableERS6_j($14, $10);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $19 = $this + 16 | 0;
    var $21 = HEAP32[$19 >> 2] + 1 | 0;
    HEAP32[$19 >> 2] = $21;
    HEAP32[$2 >> 2] = $15;
    var $22 = $3 + ($5 << 3) | 0;
    if (($5 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 6;
    break;
   case 6:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryIKiE6isLiveEv($src_01_idx_val);
    if ($24) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2js6detail14HashTableEntryIKiE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $26 = __ZNK2js6detail14HashTableEntryIKiE10getKeyHashEv($src_01_idx1_val);
    var $27 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E13findFreeEntryEj($this, $26);
    __ZN2js4MoveINS_6detail14HashTableEntryIKiEEEENS_7MoveRefIT_EERS6_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryIKiEaSENS_7MoveRefIS3_EE($27, $_02_val);
    __label__ = 8;
    break;
   case 8:
    var $29 = $src_01 + 8 | 0;
    if (($29 | 0) == ($22 | 0)) {
      __label__ = 9;
      break;
    } else {
      var $src_01 = $29;
      __label__ = 6;
      break;
    }
   case 9:
    __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E12destroyTableERS6_PNS0_14HashTableEntryIS2_EEj($3);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E15changeTableSizeEi["X"] = 1;

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 3) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryIKiE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryIKiE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + ($15 << 3) | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryIKiE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E11createTableERS6_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 3;
    var $2 = $alloc;
    var $3 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4 + ($capacity << 3) | 0;
    if (($4 | 0) == ($7 | 0)) {
      var $_0 = $4;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $4;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryIKiEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $12 = $e_01 + 8 | 0;
    if (($12 | 0) == ($7 | 0)) {
      var $_0 = $4;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $12;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E12destroyTableERS6_PNS0_14HashTableEntryIS2_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js15TempAllocPolicy5free_EPv($0);
  return;
}

function __ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryIKiE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E12lookupForAddERS2_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E11prepareHashERS2_($l_val);
  var $2 = __ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E6lookupERS2_jj($this, $l, $1);
  __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E6AddPtrC1ERNS0_14HashTableEntryIS2_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E11prepareHashERS2_($l_val1) {
  var $1 = __ZN2js13DefaultHasherIiE4hashERKi($l_val1);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E6lookupERS2_jj($this, $l, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 3) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryIKiE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryIKiE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $l_val4 = HEAP32[$l >> 2];
    var $11 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5matchERNS0_14HashTableEntryIS2_EERS2_($6, $l_val4);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryIKiE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryIKiE12setCollisionEj($entry_0);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + ($26 << 3) | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryIKiE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryIKiE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $l_val = HEAP32[$l >> 2];
    var $35 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5matchERNS0_14HashTableEntryIS2_EERS2_($27, $l_val);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E6lookupERS2_jj["X"] = 1;

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E6AddPtrC1ERNS0_14HashTableEntryIS2_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E6AddPtrC2ERNS0_14HashTableEntryIS2_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E6AddPtrC2ERNS0_14HashTableEntryIS2_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3PtrC2ERNS0_14HashTableEntryIS2_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5matchERNS0_14HashTableEntryIS2_EERS2_($e, $l_val1) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOps6getKeyERKi($1);
  var $_val = HEAP32[$2 >> 2];
  var $3 = __ZN2js13DefaultHasherIiE5matchERKiS3_($_val, $l_val1);
  return $3;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryIKiE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $4 = $length * 171 | 0;
    var $capacity_0 = $4 >>> 0 < 2048 ? 16 : $4 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 5;
      break;
    }
   case 4:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $8 = $roundUp_01 << 1;
    var $9 = $roundUpLog2_02 + 1 | 0;
    if ($8 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $8;
      var $roundUpLog2_02 = $9;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = $8;
      var $roundUpLog2_0_lcssa = $9;
      __label__ = 5;
      break;
    }
   case 5:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $11 = $this | 0;
    var $12 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E11createTableERS6_j($11, $roundUp_0_lcssa);
    HEAP32[$this + 24 >> 2] = $12;
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEEC2ES3_($this, $a_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_EC1ES6_($1, $a_0);
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_EC1ES6_($this, $ap_01) {
  __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_EC2ES6_($this, $ap_01);
  return;
}

function __ZN14KeyStringifierIiE8toStringEP9JSContexti($cx, $id) {
  var $1 = __ZN2jsL10IdToStringEP9JSContexti($cx, $id);
  return $1;
}

function __ZN2JSL11ObjectValueER8JSObject2569($agg_result, $obj) {
  var $1 = $obj;
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $1);
  return;
}

function _JSDOUBLE_IS_INT322570($d, $pi) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSDOUBLE_IS_NEGZERO2573($d);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $d & -1;
    HEAP32[$pi >> 2] = $4;
    var $_0 = ($4 | 0) == $d & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL10IdToStringEP9JSContexti($cx, $id) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = _JSID_IS_STRING2575($id);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = _JSID_TO_STRING2576($id);
    var $_0 = $5;
    __label__ = 6;
    break;
   case 3:
    var $7 = _JSID_IS_INT2577($id);
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = _JSID_TO_INT2578($id);
    var $11 = $cx;
    var $12 = __Z14js_IntToStringP9JSContexti($11, $10);
    var $_0 = $12;
    __label__ = 6;
    break;
   case 5:
    __ZN2jsL9IdToValueEi2579($1, $id);
    var $14 = $cx;
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $15 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($14, $_idx_val$0, $_idx_val$1);
    var $_0 = $15;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9IdToValueEi2579($agg_result, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_STRING2575($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_STRING2576($id);
    __ZN2JSL11StringValueEP8JSString2546($agg_result, $4);
    __label__ = 8;
    break;
   case 3:
    var $6 = _JSID_IS_INT2577($id);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _JSID_TO_INT2578($id);
    __ZN2JSL10Int32ValueEi2580($agg_result, $9);
    __label__ = 8;
    break;
   case 5:
    var $11 = _JSID_IS_OBJECT2581($id);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = _JSID_TO_OBJECT2582($id);
    __ZN2JSL11ObjectValueER8JSObject2569($agg_result, $14);
    __label__ = 8;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv2537($agg_result);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL10Int32ValueEi2580($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZL4WalkP9JSContextP8JSObjectiRKN2JS5ValueEPS4_($cx, $holder, $name, $reviver, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 132;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $val = __stackBase__ + 4;
    var $id = __stackBase__ + 12;
    var $newElement = __stackBase__ + 16;
    var $keys = __stackBase__ + 24;
    var $newElement2 = __stackBase__ + 84;
    var $args = __stackBase__ + 92;
    var $1 = __stackBase__ + 116;
    var $2 = __stackBase__ + 124;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $cx;
    __Z21js_ReportOverRecursedP9JSContext($8);
    var $_2 = 0;
    __label__ = 32;
    break;
   case 3:
    var $10 = $holder;
    var $11 = $cx;
    var $12 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($10, $11, $name, $val);
    if (($12 | 0) == 0) {
      var $_2 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $val_idx = $val | 0;
    var $val_idx_val$0 = HEAP32[$val_idx >> 2];
    var $val_idx_val$1 = HEAP32[$val_idx + 4 >> 2];
    var $15 = __ZNK2JS5Value8isObjectEv($val_idx_val$0, $val_idx_val$1);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 5:
    var $17 = __ZNK2JS5Value8toObjectEv($val_idx_val$0, $val_idx_val$1);
    var $18 = $17;
    var $_idx7_val = HEAP32[$17 + 4 >> 2];
    var $19 = __ZNK8JSObject7isArrayEv($_idx7_val);
    if ($19) {
      __label__ = 6;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 6:
    var $_idx5_val = HEAP32[$17 + 24 >> 2];
    var $21 = __ZNK8JSObject14getArrayLengthEv($_idx5_val);
    var $newElement_idx = $newElement | 0;
    var $i_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $i_0;
    if ($i_0 >>> 0 < $21 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 8:
    var $25 = __ZN2js9IndexToIdEP9JSContextjPi($11, $i_0, $id);
    if ($25) {
      __label__ = 9;
      break;
    } else {
      var $_2 = 0;
      __label__ = 32;
      break;
    }
   case 9:
    var $27 = HEAPU32[$id >> 2];
    var $28 = __ZL4WalkP9JSContextP8JSObjectiRKN2JS5ValueEPS4_($cx, $18, $27, $reviver, $newElement);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      var $_2 = 0;
      __label__ = 32;
      break;
    }
   case 10:
    var $st$0$0 = $newElement_idx | 0;
    var $newElement_idx_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $newElement_idx + 4 | 0;
    var $newElement_idx_val$1 = HEAP32[$st$0$1 >> 2];
    var $30 = __ZNK2JS5Value11isUndefinedEv($newElement_idx_val$0, $newElement_idx_val$1);
    if ($30) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $32 = __ZN2js20array_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($11, $17, $27, $newElement, 0);
    __label__ = 13;
    break;
   case 12:
    var $34 = __ZN2js20array_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ej($11, $17, $27, $newElement, 10, 12, 1);
    __label__ = 13;
    break;
   case 13:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 7;
    break;
   case 14:
    var $38 = $keys;
    __ZN2js12AutoIdVectorC1EP9JSContext($38, $11);
    var $39 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($cx, $18, 8, $keys);
    if ($39) {
      __label__ = 15;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 15:
    var $41 = $keys;
    var $42 = __ZNK2js16AutoVectorRooterIiE6lengthEv($41);
    var $43 = $cx;
    var $44 = $17;
    var $newElement2_idx = $newElement2 | 0;
    var $i1_0 = 0;
    __label__ = 16;
    break;
   case 16:
    var $i1_0;
    if ($i1_0 >>> 0 < $42 >>> 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 17:
    var $48 = __ZN2js16AutoVectorRooterIiEixEj($41, $i1_0);
    var $49 = HEAPU32[$48 >> 2];
    var $50 = __ZL4WalkP9JSContextP8JSObjectiRKN2JS5ValueEPS4_($cx, $18, $49, $reviver, $newElement2);
    if ($50) {
      __label__ = 18;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 18:
    var $st$0$0 = $newElement2_idx | 0;
    var $newElement2_idx_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $newElement2_idx + 4 | 0;
    var $newElement2_idx_val$1 = HEAP32[$st$0$1 >> 2];
    var $52 = __ZNK2JS5Value11isUndefinedEv($newElement2_idx_val$0, $newElement2_idx_val$1);
    if ($52) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $54 = __Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($43, $44, $49, $newElement2, 0);
    if (($54 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $57 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($43, $44, $49, $newElement2, 10, 12, 1, 0, 0, 0);
    if (($57 | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 16;
    break;
   case 22:
    __ZN2js12AutoIdVectorD1Ev($38);
    __label__ = 23;
    break;
   case 23:
    var $62 = __ZN2jsL10IdToStringEP9JSContexti($cx, $name);
    if (($62 | 0) == 0) {
      var $_2 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $65 = $args;
    __ZN2js15InvokeArgsGuardC1Ev($65);
    var $67 = $cx + 60 | 0;
    var $68 = $cx;
    var $69 = $args;
    var $70 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($67, $68, 2, $69);
    if ($70) {
      __label__ = 25;
      break;
    } else {
      var $_1 = 0;
      __label__ = 27;
      break;
    }
   case 25:
    var $_idx = $args | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $72 = __ZNK2js12CallReceiver7calleevEv($_idx_val);
    var $73 = $reviver | 0;
    var $74$0 = HEAP32[$73 >> 2];
    var $74$1 = HEAP32[$73 + 4 >> 2];
    var $75 = $72 | 0;
    var $st$9$0 = $75 | 0;
    HEAP32[$st$9$0 >> 2] = $74$0;
    var $st$9$1 = $75 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $74$1;
    var $_idx2_val = HEAP32[$_idx >> 2];
    var $76 = __ZNK2js12CallReceiver5thisvEv($_idx2_val);
    __ZN2JSL11ObjectValueER8JSObject2569($1, $holder);
    var $77 = $1 | 0;
    var $78$0 = HEAP32[$77 >> 2];
    var $78$1 = HEAP32[$77 + 4 >> 2];
    var $79 = $76 | 0;
    var $st$22$0 = $79 | 0;
    HEAP32[$st$22$0 >> 2] = $78$0;
    var $st$22$1 = $79 + 4 | 0;
    HEAP32[$st$22$1 >> 2] = $78$1;
    var $_idx4_val = HEAP32[$_idx >> 2];
    var $80 = __ZNK2js8CallArgsixEj($_idx4_val, 0);
    __ZN2JSL11StringValueEP8JSString2546($2, $62);
    var $81 = $2 | 0;
    var $82$0 = HEAP32[$81 >> 2];
    var $82$1 = HEAP32[$81 + 4 >> 2];
    var $83 = $80 | 0;
    var $st$35$0 = $83 | 0;
    HEAP32[$st$35$0 >> 2] = $82$0;
    var $st$35$1 = $83 + 4 | 0;
    HEAP32[$st$35$1 >> 2] = $82$1;
    var $_idx3_val = HEAP32[$_idx >> 2];
    var $84 = __ZNK2js8CallArgsixEj($_idx3_val, 1);
    var $85$0 = HEAP32[$val_idx >> 2];
    var $85$1 = HEAP32[$val_idx + 4 >> 2];
    var $86 = $84 | 0;
    var $st$46$0 = $86 | 0;
    HEAP32[$st$46$0 >> 2] = $85$0;
    var $st$46$1 = $86 + 4 | 0;
    HEAP32[$st$46$1 >> 2] = $85$1;
    var $87 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($11, $65, 0);
    if ($87) {
      __label__ = 26;
      break;
    } else {
      var $_1 = 0;
      __label__ = 27;
      break;
    }
   case 26:
    var $_idx6_val = HEAP32[$_idx >> 2];
    var $89 = __ZNK2js12CallReceiver4rvalEv($_idx6_val);
    var $90 = $89 | 0;
    var $91$0 = HEAP32[$90 >> 2];
    var $91$1 = HEAP32[$90 + 4 >> 2];
    var $92 = $vp | 0;
    HEAP32[$92 >> 2] = $91$0;
    HEAP32[$92 + 4 >> 2] = $91$1;
    var $_1 = 1;
    __label__ = 27;
    break;
   case 27:
    var $_1;
    __ZN2js15InvokeArgsGuardD1Ev($65);
    var $_2 = $_1;
    __label__ = 32;
    break;
   case 28:
    __ZN2js12AutoIdVectorD1Ev($38);
    var $_2 = 0;
    __label__ = 32;
    break;
   case 29:
    __ZN2js12AutoIdVectorD1Ev($38);
    var $_2 = 0;
    __label__ = 32;
    break;
   case 30:
    __ZN2js12AutoIdVectorD1Ev($38);
    var $_2 = 0;
    __label__ = 32;
    break;
   case 31:
    __ZN2js12AutoIdVectorD1Ev($38);
    var $_2 = 0;
    __label__ = 32;
    break;
   case 32:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL4WalkP9JSContextP8JSObjectiRKN2JS5ValueEPS4_["X"] = 1;

function __ZN16StringifyContextD2Ev($this) {
  var $1 = $this + 20 | 0;
  __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev($1);
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 24 >> 2];
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_ED1Ev($this_0_6_val) {
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_ED2Ev($this_0_6_val);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6SetOps6getKeyERKS2_($t) {
  return $t;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZL18JSDOUBLE_IS_FINITEd2585($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function __ZN7mozilla15AlignedStorage2IN2js12AutoIdVectorEE4addrEv($this) {
  return $this;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 8 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 12 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 1) | 0;
}

function __ZN7mozilla5MaybeIN2js12AutoIdVectorEEC2Ev($this) {
  HEAP8[$this + 60 | 0] = 0;
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_ED2Ev($this_0_6_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_6_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($this_0_6_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js15TempAllocPolicy5free_EPv($0);
  return;
}

function __ZL5QuoteP9JSContextRN2js12StringBufferEP8JSString($cx, $sb, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $anchor = __stackBase__;
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $str);
    var $str_idx_val = HEAP32[$str >> 2];
    var $1 = __ZNK8JSString6lengthEv($str_idx_val);
    var $2 = $cx;
    var $3 = __ZN8JSString8getCharsEP9JSContext($str, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $sb;
    var $7 = __ZN2js12StringBuffer6appendEt($6, 34);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 3:
    var $8 = $sb;
    var $i_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_0;
    if ($i_0 >>> 0 < $1 >>> 0) {
      var $i_1 = $i_0;
      __label__ = 5;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 5:
    var $i_1;
    var $12 = HEAP16[$3 + ($i_1 << 1) >> 1];
    var $13 = __ZL23IsQuoteSpecialCharactert($12);
    if ($13) {
      var $i_2 = $i_1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $i_1 + 1 | 0;
    if ($15 >>> 0 < $1 >>> 0) {
      var $i_1 = $15;
      __label__ = 5;
      break;
    } else {
      var $i_2 = $15;
      __label__ = 7;
      break;
    }
   case 7:
    var $i_2;
    if ($i_2 >>> 0 > $i_0 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $20 = $3 + ($i_0 << 1) | 0;
    var $22 = __ZN2js12StringBuffer6appendEPKtj($6, $20, $i_2 - $i_0 | 0);
    if ($22) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 9:
    if (($i_2 | 0) == ($1 | 0)) {
      __label__ = 22;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $26 = HEAPU16[$3 + ($i_2 << 1) >> 1];
    if ($26 << 16 >> 16 == 34 || $26 << 16 >> 16 == 92) {
      __label__ = 11;
      break;
    } else if ($26 << 16 >> 16 == 9 || $26 << 16 >> 16 == 10 || $26 << 16 >> 16 == 12 || $26 << 16 >> 16 == 13) {
      __label__ = 13;
      break;
    } else if ($26 << 16 >> 16 == 8) {
      var $38 = 98;
      __label__ = 16;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 11:
    var $28 = __ZN2js12StringBuffer6appendEt($6, 92);
    if ($28) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 12:
    var $30 = __ZN2js12StringBuffer6appendEt($6, $26);
    if ($30) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 13:
    if ($26 << 16 >> 16 == 12) {
      var $38 = 102;
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    if ($26 << 16 >> 16 == 10) {
      var $38 = 110;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $phitmp = $26 << 16 >> 16 == 13 ? 114 : 116;
    var $38 = $phitmp;
    __label__ = 16;
    break;
   case 16:
    var $38;
    var $39 = __ZN2js12StringBuffer6appendEt($6, 92);
    if ($39) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 17:
    var $41 = __ZN2js12StringBuffer6appendEt($6, $38);
    if ($41) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 18:
    var $43 = __ZN2js12StringBuffer6appendILj5EEEbRAT__Kc($8, STRING_TABLE.__str52536);
    if ($43) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 19:
    var $47 = (($26 & 65535) >>> 4 & 255) + 48 & 65535;
    var $48 = __ZN2js12StringBuffer6appendEt($6, $47);
    if ($48) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 20:
    var $50 = $26 & 65535 & 15;
    var $54 = $50 >>> 0 < 10 ? $50 | 48 : $50 + 87 | 0;
    var $55 = $54 & 65535;
    var $56 = __ZN2js12StringBuffer6appendEt($6, $55);
    if ($56) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 21:
    var $i_0 = $i_2 + 1 | 0;
    __label__ = 4;
    break;
   case 22:
    var $60 = __ZN2js12StringBuffer6appendEt($6, 34);
    var $_0 = $60;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL5QuoteP9JSContextRN2js12StringBufferEP8JSString["X"] = 1;

function __ZL2JAP9JSContextP8JSObjectP16StringifyContext($cx, $obj, $scx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $detect = __stackBase__;
    var $length = __stackBase__ + 8;
    var $outputValue = __stackBase__ + 12;
    __ZN13CycleDetectorC1EP16StringifyContextP8JSObject($detect, $scx, $obj);
    var $1 = __ZN13CycleDetector4initEP9JSContext($detect, $cx);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 2:
    var $3 = $scx | 0;
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js12StringBuffer6appendEt($5, 91);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 3:
    var $8 = $cx;
    var $9 = $obj;
    var $10 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($8, $9, $length);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = HEAPU32[$length >> 2];
    if (($13 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = $scx + 16 | 0;
    var $17 = HEAP32[$16 >> 2];
    var $18 = __ZL11WriteIndentP9JSContextP16StringifyContextj($scx, $17);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = $13 - 1 | 0;
    var $outputValue_idx = $outputValue | 0;
    var $i_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $i_0;
    if ($i_0 >>> 0 < $13 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 8:
    var $24 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($9, $8, $i_0, $outputValue);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $27 = __ZL15PreprocessValueIjEbP9JSContextP8JSObjectT_PN2JS5ValueEP16StringifyContext($cx, $obj, $i_0, $outputValue, $scx);
    if ($27) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 10:
    var $outputValue_idx_val$0 = HEAP32[$outputValue_idx >> 2];
    var $outputValue_idx_val$1 = HEAP32[$outputValue_idx + 4 >> 2];
    var $29 = __ZL15IsFilteredValueRKN2JS5ValueE($outputValue_idx_val$0, $outputValue_idx_val$1);
    if ($29) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $32 = HEAP32[$3 >> 2];
    var $33 = __ZN2js12StringBuffer6appendILj5EEEbRAT__Kc($32, STRING_TABLE.__str483817);
    if ($33) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 12:
    var $35 = __ZL3StrP9JSContextRKN2JS5ValueEP16StringifyContext($cx, $outputValue, $scx);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if ($i_0 >>> 0 < $20 >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    var $41 = HEAP32[$3 >> 2];
    var $42 = __ZN2js12StringBuffer6appendEt($41, 44);
    if ($42) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 15:
    var $44 = HEAP32[$16 >> 2];
    var $45 = __ZL11WriteIndentP9JSContextP16StringifyContextj($scx, $44);
    if (($45 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 7;
    break;
   case 17:
    var $51 = HEAP32[$16 >> 2] - 1 | 0;
    var $52 = __ZL11WriteIndentP9JSContextP16StringifyContextj($scx, $51);
    if (($52 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $56 = HEAP32[$3 >> 2];
    var $57 = __ZN2js12StringBuffer6appendEt($56, 93);
    var $_0 = $57 & 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    __ZN13CycleDetectorD1Ev($detect);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL2JAP9JSContextP8JSObjectP16StringifyContext["X"] = 1;

function __ZL2JOP9JSContextP8JSObjectP16StringifyContext($cx, $obj, $scx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $detect = __stackBase__;
    var $ids = __stackBase__ + 8;
    var $outputValue = __stackBase__ + 72;
    __ZN13CycleDetectorC1EP16StringifyContextP8JSObject($detect, $scx, $obj);
    var $1 = __ZN13CycleDetector4initEP9JSContext($detect, $cx);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 26;
      break;
    }
   case 2:
    var $3 = $scx | 0;
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js12StringBuffer6appendEt($5, 123);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 0;
      __label__ = 26;
      break;
    }
   case 3:
    __ZN7mozilla5MaybeIN2js12AutoIdVectorEEC1Ev($ids);
    var $9 = HEAP32[$scx + 8 >> 2];
    if (($9 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$9 + 4 >> 2];
    var $13 = __ZN8JSObject10isCallableEv($_idx_val);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $props_0 = HEAP32[$scx + 12 >> 2];
    __label__ = 7;
    break;
   case 6:
    __ZN7mozilla5MaybeIN2js12AutoIdVectorEE9constructIP9JSContextEEvRKT_($ids, $cx);
    var $18 = __ZN7mozilla5MaybeIN2js12AutoIdVectorEE4addrEv($ids);
    var $19 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($cx, $obj, 8, $18);
    if ($19) {
      var $props_0 = $18;
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 25;
      break;
    }
   case 7:
    var $props_0;
    var $21 = $props_0 | 0;
    var $23 = __ZNK2js16AutoVectorRooterIiE6lengthEv($props_0);
    var $24 = $obj;
    var $25 = $cx;
    var $26 = $scx + 16 | 0;
    var $27 = $scx + 4 | 0;
    var $outputValue_idx = $outputValue | 0;
    var $i_0 = 0;
    var $wroteMember_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $wroteMember_0;
    var $i_0;
    if ($i_0 >>> 0 < $23 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 9:
    var $31 = __ZNK2js16AutoVectorRooterIiEixEj($21, $i_0);
    var $32 = HEAP32[$31 >> 2];
    var $33 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($24, $25, $32, $outputValue);
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $36 = HEAP32[$31 >> 2];
    var $37 = __ZL15PreprocessValueIiEbP9JSContextP8JSObjectT_PN2JS5ValueEP16StringifyContext($cx, $obj, $36, $outputValue, $scx);
    if ($37) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 25;
      break;
    }
   case 11:
    var $outputValue_idx_val$0 = HEAP32[$outputValue_idx >> 2];
    var $outputValue_idx_val$1 = HEAP32[$outputValue_idx + 4 >> 2];
    var $39 = __ZL15IsFilteredValueRKN2JS5ValueE($outputValue_idx_val$0, $outputValue_idx_val$1);
    if ($39) {
      var $wroteMember_1 = $wroteMember_0;
      __label__ = 21;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (($wroteMember_0 & 1) << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $45 = HEAP32[$3 >> 2];
    var $46 = __ZN2js12StringBuffer6appendEt($45, 44);
    if ($46) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 25;
      break;
    }
   case 14:
    var $48 = HEAP32[$26 >> 2];
    var $49 = __ZL11WriteIndentP9JSContextP16StringifyContextj($scx, $48);
    if (($49 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $52 = HEAP32[$31 >> 2];
    var $53 = __ZN2jsL10IdToStringEP9JSContexti($cx, $52);
    if (($53 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $56 = HEAP32[$3 >> 2];
    var $57 = __ZL5QuoteP9JSContextRN2js12StringBufferEP8JSString($cx, $56, $53);
    if ($57) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 25;
      break;
    }
   case 17:
    var $60 = HEAP32[$3 >> 2];
    var $61 = __ZN2js12StringBuffer6appendEt($60, 58);
    if ($61) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 25;
      break;
    }
   case 18:
    var $64 = HEAP32[$27 >> 2];
    var $65 = __ZNK2js12StringBuffer5emptyEv($64);
    if ($65) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $68 = HEAP32[$3 >> 2];
    var $69 = __ZN2js12StringBuffer6appendEt($68, 32);
    if ($69) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 25;
      break;
    }
   case 20:
    var $71 = __ZL3StrP9JSContextRKN2JS5ValueEP16StringifyContext($cx, $outputValue, $scx);
    if (($71 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      var $wroteMember_1 = 1;
      __label__ = 21;
      break;
    }
   case 21:
    var $wroteMember_1;
    var $i_0 = $i_0 + 1 | 0;
    var $wroteMember_0 = $wroteMember_1;
    __label__ = 8;
    break;
   case 22:
    if (($wroteMember_0 & 1) << 24 >> 24 == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $80 = HEAP32[$26 >> 2] - 1 | 0;
    var $81 = __ZL11WriteIndentP9JSContextP16StringifyContextj($scx, $80);
    if (($81 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $85 = HEAP32[$3 >> 2];
    var $86 = __ZN2js12StringBuffer6appendEt($85, 125);
    var $_0 = $86 & 1;
    __label__ = 25;
    break;
   case 25:
    var $_0;
    __ZN7mozilla5MaybeIN2js12AutoIdVectorEED1Ev($ids);
    var $_1 = $_0;
    __label__ = 26;
    break;
   case 26:
    var $_1;
    __ZN13CycleDetectorD1Ev($detect);
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL2JOP9JSContextP8JSObjectP16StringifyContext["X"] = 1;

function __ZN13CycleDetectorC1EP16StringifyContextP8JSObject($this, $scx, $obj) {
  __ZN13CycleDetectorC2EP16StringifyContextP8JSObject($this, $scx, $obj);
  return;
}

function __ZN13CycleDetector4initEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ptr = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = $this | 0;
    var $3 = HEAP32[$2 >> 2];
    var $4 = $this + 4 | 0;
    __ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($ptr, $3, $4);
    var $_idx_val = HEAP32[$ptr >> 2];
    __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($1, $_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $cx;
    _JS_ReportErrorNumber($9, 4, 36, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str267560 | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $11 = HEAP32[$2 >> 2];
    var $12 = __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS6_6SetOpsES5_E6AddPtrERS9_($11, $ptr, $4);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla5MaybeIN2js12AutoIdVectorEEC1Ev($this) {
  __ZN7mozilla5MaybeIN2js12AutoIdVectorEEC2Ev($this);
  return;
}

function __ZN7mozilla5MaybeIN2js12AutoIdVectorEE9constructIP9JSContextEEvRKT_($this, $t1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZN7mozilla15AlignedStorage2IN2js12AutoIdVectorEE4addrEv($1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    var $6 = $t1_val;
    __ZN2js12AutoIdVectorC1EP9JSContext($5, $6);
    __label__ = 3;
    break;
   case 3:
    HEAP8[$this + 60 | 0] = 1;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla5MaybeIN2js12AutoIdVectorEE4addrEv($this) {
  var $1 = __ZN7mozilla5MaybeIN2js12AutoIdVectorEE3asTEv($this);
  return $1;
}

function __ZNK2js16AutoVectorRooterIiEixEj($this, $i) {
  var $1 = $this + 12 | 0;
  var $2 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEEixEj($1, $i);
  return $2;
}

function __ZL11WriteIndentP9JSContextP16StringifyContextj($scx, $limit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $scx + 4 | 0;
    var $3 = HEAP32[$1 >> 2];
    var $4 = __ZNK2js12StringBuffer5emptyEv($3);
    if ($4) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $scx | 0;
    var $8 = HEAP32[$6 >> 2];
    var $9 = __ZN2js12StringBuffer6appendEt($8, 10);
    if ($9) {
      var $i_0 = 0;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $i_0;
    if ($i_0 >>> 0 < $limit >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 4:
    var $12 = HEAP32[$6 >> 2];
    var $13 = HEAP32[$1 >> 2];
    var $14 = __ZNK2js12StringBuffer5beginEv($13);
    var $15 = __ZNK2js12StringBuffer3endEv($13);
    var $16 = __ZN2js12StringBuffer6appendEPKtS2_($12, $14, $15);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 3;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla5MaybeIN2js12AutoIdVectorEED1Ev($this) {
  __ZN7mozilla5MaybeIN2js12AutoIdVectorEED2Ev($this);
  return;
}

function __ZN13CycleDetectorD1Ev($this) {
  __ZN13CycleDetectorD2Ev($this);
  return;
}

function __ZN13CycleDetectorD2Ev($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = $this + 4 | 0;
  __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeERKS2_($2, $3);
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeERKS2_($this, $l) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 4;
    __ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_($p, $this, $l);
    var $p_idx_val = HEAP32[$p >> 2];
    __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($1, $p_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS6_6SetOpsES5_E3PtrE($this, $p_idx_val);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6lookupERS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($agg_result, $this_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3Ptr5foundEv($this_0_0_val);
  var $_ = $1 ? {
    f0: 196,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS6_6SetOpsES5_E3PtrE($this, $p_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE($1, $p_0);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE($this, $p_0) {
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS4_EE($this, $p_0);
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv($this);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS4_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $e;
    var $_idx_val = HEAP32[$e >> 2];
    var $2 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE12hasCollisionEv($_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryIKP8JSObjectE10setRemovedEv($1);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + 1 | 0;
    HEAP32[$4 >> 2] = $6;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryIKP8JSObjectE7setFreeEv($1);
    __label__ = 4;
    break;
   case 4:
    var $9 = $this + 12 | 0;
    var $11 = HEAP32[$9 >> 2] - 1 | 0;
    HEAP32[$9 >> 2] = $11;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 3:
    var $14 = $this | 0;
    var $15 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E11createTableERS8_j($14, $10);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $19 = $this + 16 | 0;
    var $21 = HEAP32[$19 >> 2] + 1 | 0;
    HEAP32[$19 >> 2] = $21;
    HEAP32[$2 >> 2] = $15;
    var $22 = $3 + ($5 << 3) | 0;
    if (($5 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_03 = $1 | 0;
    var $src_01 = $3;
    __label__ = 6;
    break;
   case 6:
    var $src_01;
    var $24 = $src_01;
    var $_idx1 = $src_01 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $25 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isLiveEv($_idx1_val);
    if ($25) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2js6detail14HashTableEntryIKP8JSObjectE14unsetCollisionEv($24);
    var $_idx2_val = HEAP32[$_idx1 >> 2];
    var $27 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE10getKeyHashEv($_idx2_val);
    var $28 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $27);
    __ZN2js4MoveINS_6detail14HashTableEntryIKP8JSObjectEEEENS_7MoveRefIT_EERS8_($1, $24);
    var $29 = $28;
    var $_03_val = HEAP32[$_03 >> 2];
    __ZN2js6detail14HashTableEntryIKP8JSObjectEaSENS_7MoveRefIS5_EE($29, $_03_val);
    __label__ = 8;
    break;
   case 8:
    var $31 = $src_01 + 8 | 0;
    if (($31 | 0) == ($22 | 0)) {
      __label__ = 9;
      break;
    } else {
      var $src_01 = $31;
      __label__ = 6;
      break;
    }
   case 9:
    __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($3);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E15changeTableSizeEi["X"] = 1;

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E11createTableERS8_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 3;
    var $2 = $alloc;
    var $3 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4 + ($capacity << 3) | 0;
    if (($4 | 0) == ($7 | 0)) {
      var $_0 = $4;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $4;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryIKP8JSObjectEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $13 = $e_01 + 8 | 0;
    if (($13 | 0) == ($7 | 0)) {
      var $_0 = $4;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $13;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 3) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryIKP8JSObjectE12setCollisionEv($entry_0);
    var $16 = $h1_0 - $10 & $12;
    var $18 = HEAP32[$4 >> 2] + ($16 << 3) | 0;
    var $_idx_val = HEAP32[$18 >> 2];
    var $19 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isFreeEv($_idx_val);
    if ($19) {
      var $_0 = $18;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $18;
      var $h1_0 = $16;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3Ptr5foundEv($this_0_0_val) {
  var $_idx_val = HEAP32[$this_0_0_val >> 2];
  var $1 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isLiveEv($_idx_val);
  return $1;
}

function __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6lookupERS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E11prepareHashERS4_($l);
  var $2 = __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6lookupERS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E11prepareHashERS4_($l) {
  var $_val = HEAP32[$l >> 2];
  var $2 = __ZN2js13PointerHasherIP8JSObjectLj2EE4hashERKS2_($_val);
  var $3 = $2 * -1640531527 | 0;
  var $4 = $3 - 2 | 0;
  var $5 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E10isLiveHashEj($3);
  var $_ = $5 ? $3 : $4;
  return $_ & -2;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry);
  return;
}

function __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6lookupERS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 3) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryIKP8JSObjectE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $_idx4_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $_idx4_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE9isRemovedEv($_idx4_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $25 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $25 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryIKP8JSObjectE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $25 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $25;
    var $firstRemoved_1;
    var $27 = $h1_0 - $14 & $16;
    var $28 = $25 + ($27 << 3) | 0;
    var $_idx_val = HEAP32[$28 >> 2];
    var $29 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isFreeEv($_idx_val);
    if ($29) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $32 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $28;
    var $_0 = $32;
    __label__ = 13;
    break;
   case 11:
    var $34 = __ZN2js6detail14HashTableEntryIKP8JSObjectE9matchHashEj($_idx_val, $keyHash);
    if ($34) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $28;
      var $h1_0 = $27;
      var $_idx4_val = $_idx_val;
      var $17 = $25;
      __label__ = 5;
      break;
    }
   case 12:
    var $36 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_($28, $l);
    if ($36) {
      var $_0 = $28;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $28;
      var $h1_0 = $27;
      var $_idx4_val = $_idx_val;
      var $17 = $25;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6lookupERS4_jj["X"] = 1;

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6SetOps6getKeyERKS2_($1);
  var $_val = HEAP32[$2 >> 2];
  var $_val1 = HEAP32[$l >> 2];
  var $5 = __ZN2js13PointerHasherIP8JSObjectLj2EE5matchERKS2_S5_($_val, $_val1);
  return $5;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryIKP8JSObjectE10isLiveHashEj($hash);
  return $1;
}

function __ZN7mozilla5MaybeIN2js12AutoIdVectorEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 60 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN7mozilla5MaybeIN2js12AutoIdVectorEE3asTEv($this);
    var $7 = $6;
    __ZN2js12AutoIdVectorD1Ev($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla5MaybeIN2js12AutoIdVectorEE3asTEv($this) {
  var $1 = $this | 0;
  var $2 = __ZN7mozilla15AlignedStorage2IN2js12AutoIdVectorEE4addrEv($1);
  return $2;
}

function __ZN2js12StringBuffer6appendEPKtS2_($this, $begin, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this + 8 >> 2];
    var $2 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv($_idx_val);
    var $7 = $2 + ($end - $begin >> 1) | 0;
    var $8 = $this;
    var $9 = __ZN2js12StringBuffer11checkLengthEj($8, $7);
    if ($9) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = $this;
    var $12 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbPKT_S6_($11, $begin, $end);
    var $_0 = $12;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12StringBuffer5beginEv($this) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $2 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE5beginEv($_idx_val);
  return $2;
}

function __ZNK2js12StringBuffer3endEv($this) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $_idx1_val = HEAP32[$this + 8 >> 2];
  var $1 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE3endEv($_idx_val, $_idx1_val);
  return $1;
}

function __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEEixEj($this, $i) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $2 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE5beginEv($_idx_val);
  return $2 + ($i << 2) | 0;
}

function __ZL14JSID_FROM_BITSj2592($bits) {
  return $bits;
}

function __ZN10JSONParser5tokenENS_5TokenE($t) {
  return $t;
}

function __ZNK7mozilla9RangedPtrIKtE3getEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E10overloadedEv($this_0_2_val, $this_0_3_val, $this_0_5_val) {
  return ($this_0_5_val + $this_0_3_val | 0) >>> 0 >= ($this_0_2_val * 192 | 0) >>> 8 >>> 0;
}

function __ZL23IsQuoteSpecialCharactert($c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($c << 16 >> 16 == 34 || $c << 16 >> 16 == 92) {
      var $4 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = ($c & 65535) < 32;
    __label__ = 3;
    break;
   case 3:
    var $4;
    return $4;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSONParser11errorReturnEv($this_0_6_val) {
  return ($this_0_6_val | 0) == 1;
}

function __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($this_0_0_val, $other_0_0_val) {
  return $this_0_0_val >>> 0 < $other_0_0_val >>> 0;
}

function __ZL15JSDOUBLE_IS_NaNd2597($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZN13CycleDetectorC2EP16StringifyContextP8JSObject($this, $scx, $obj) {
  HEAP32[$this >> 2] = $scx + 20 | 0;
  HEAP32[$this + 4 >> 2] = $obj;
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_EC2ES8_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  return;
}

function __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE14copyConstructNEPtjRKt($dst, $n, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $dst + ($n << 1) | 0;
    if (($n | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $p_01;
    var $3 = HEAP16[$t >> 1];
    HEAP16[$p_01 >> 1] = $3;
    var $4 = $p_01 + 2 | 0;
    if (($4 | 0) == ($1 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $4;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E12lookupForAddERS4_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS6_6SetOpsES5_E6AddPtrERS9_($this, $p, $t) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS4_($1, $p, $t);
  return $2;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS4_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$t >> 2];
    var $6 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$6 >> 2] = $3;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 12 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 8 >> 2];
    var $this_idx1 = $this + 12 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 20 >> 2];
    var $12 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryIKP8JSObjectE7setLiveEj($22, $23);
    var $26 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $26;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E12lookupForAddERS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E11prepareHashERS4_($l);
  var $2 = __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6lookupERS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZL15PreprocessValueIjEbP9JSContextP8JSObjectT_PN2JS5ValueEP16StringifyContext($cx, $holder, $key, $vp, $scx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 96;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $toJSON = __stackBase__;
    var $args = __stackBase__ + 8;
    var $1 = __stackBase__ + 32;
    var $args1 = __stackBase__ + 40;
    var $2 = __stackBase__ + 64;
    var $3 = __stackBase__ + 72;
    var $4 = __stackBase__ + 80;
    var $d = __stackBase__ + 88;
    var $vp_idx1 = $vp | 0;
    var $vp_idx1_val$0 = HEAP32[$vp_idx1 >> 2];
    var $vp_idx1_val$1 = HEAP32[$vp_idx1 + 4 >> 2];
    var $5 = __ZNK2JS5Value8isObjectEv($vp_idx1_val$0, $vp_idx1_val$1);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $keyStr_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    var $11 = HEAP32[HEAP32[$cx + 52 >> 2] + 210336 >> 2] | 0;
    var $12 = __ZL12ATOM_TO_JSIDP6JSAtom2549($11);
    var $13 = __ZNK2JS5Value8toObjectEv($vp_idx1_val$0, $vp_idx1_val$1);
    var $14 = $cx;
    var $15 = $13;
    var $16 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($14, $15, $12, 2, $toJSON);
    if (($16 | 0) == 0) {
      var $_3 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $toJSON_idx = $toJSON | 0;
    var $toJSON_idx_val$0 = HEAP32[$toJSON_idx >> 2];
    var $toJSON_idx_val$1 = HEAP32[$toJSON_idx + 4 >> 2];
    var $19 = __ZL13js_IsCallableRKN2JS5ValueE2550($toJSON_idx_val$0, $toJSON_idx_val$1);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $keyStr_0 = 0;
      __label__ = 9;
      break;
    }
   case 4:
    var $21 = __ZN14KeyStringifierIjE8toStringEP9JSContextj($cx, $key);
    if (($21 | 0) == 0) {
      var $_3 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = $args;
    __ZN2js15InvokeArgsGuardC1Ev($24);
    var $26 = $cx + 60 | 0;
    var $27 = $cx;
    var $28 = $args;
    var $29 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($26, $27, 1, $28);
    if ($29) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $_idx4 = $args | 0;
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $31 = __ZNK2js12CallReceiver7calleevEv($_idx4_val);
    var $st$3$0 = $toJSON_idx | 0;
    var $32$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $toJSON_idx + 4 | 0;
    var $32$1 = HEAP32[$st$3$1 >> 2];
    var $33 = $31 | 0;
    var $st$8$0 = $33 | 0;
    HEAP32[$st$8$0 >> 2] = $32$0;
    var $st$8$1 = $33 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $32$1;
    var $_idx6_val = HEAP32[$_idx4 >> 2];
    var $34 = __ZNK2js12CallReceiver5thisvEv($_idx6_val);
    var $35$0 = HEAP32[$vp_idx1 >> 2];
    var $35$1 = HEAP32[$vp_idx1 + 4 >> 2];
    var $36 = $34 | 0;
    var $st$19$0 = $36 | 0;
    HEAP32[$st$19$0 >> 2] = $35$0;
    var $st$19$1 = $36 + 4 | 0;
    HEAP32[$st$19$1 >> 2] = $35$1;
    var $_idx11_val = HEAP32[$_idx4 >> 2];
    var $37 = __ZNK2js8CallArgsixEj($_idx11_val, 0);
    __ZN2JSL11StringValueEP8JSString2546($1, $21);
    var $38 = $1 | 0;
    var $39$0 = HEAP32[$38 >> 2];
    var $39$1 = HEAP32[$38 + 4 >> 2];
    var $40 = $37 | 0;
    var $st$32$0 = $40 | 0;
    HEAP32[$st$32$0 >> 2] = $39$0;
    var $st$32$1 = $40 + 4 | 0;
    HEAP32[$st$32$1 >> 2] = $39$1;
    var $41 = $cx;
    var $42 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($41, $24, 0);
    if ($42) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $_idx13_val = HEAP32[$_idx4 >> 2];
    var $43 = __ZNK2js12CallReceiver4rvalEv($_idx13_val);
    var $44 = $43 | 0;
    var $st$3$0 = $44 | 0;
    var $45$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $44 + 4 | 0;
    var $45$1 = HEAP32[$st$3$1 >> 2];
    var $st$7$0 = $vp_idx1 | 0;
    HEAP32[$st$7$0 >> 2] = $45$0;
    var $st$7$1 = $vp_idx1 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $45$1;
    __ZN2js15InvokeArgsGuardD1Ev($24);
    var $keyStr_0 = $21;
    __label__ = 9;
    break;
   case 8:
    __ZN2js15InvokeArgsGuardD1Ev($24);
    var $_3 = 0;
    __label__ = 26;
    break;
   case 9:
    var $keyStr_0;
    var $48 = $scx + 8 | 0;
    var $49 = HEAP32[$48 >> 2];
    if (($49 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_idx8_val = HEAP32[$49 + 4 >> 2];
    var $53 = __ZN8JSObject10isCallableEv($_idx8_val);
    if ($53) {
      __label__ = 11;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 11:
    if (($keyStr_0 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $keyStr_1 = $keyStr_0;
      __label__ = 13;
      break;
    }
   case 12:
    var $57 = __ZN14KeyStringifierIjE8toStringEP9JSContextj($cx, $key);
    if (($57 | 0) == 0) {
      var $_3 = 0;
      __label__ = 26;
      break;
    } else {
      var $keyStr_1 = $57;
      __label__ = 13;
      break;
    }
   case 13:
    var $keyStr_1;
    var $60 = $args1;
    __ZN2js15InvokeArgsGuardC1Ev($60);
    var $62 = $cx + 60 | 0;
    var $63 = $cx;
    var $64 = $args1;
    var $65 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($62, $63, 2, $64);
    if ($65) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    var $67 = $cx;
    var $_idx = $args1 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $68 = __ZNK2js12CallReceiver7calleevEv($_idx_val);
    var $69 = HEAP32[$48 >> 2];
    __ZN2JSL11ObjectValueER8JSObject2569($2, $69);
    var $70 = $2 | 0;
    var $st$7$0 = $70 | 0;
    var $71$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $70 + 4 | 0;
    var $71$1 = HEAP32[$st$7$1 >> 2];
    var $72 = $68 | 0;
    var $st$12$0 = $72 | 0;
    HEAP32[$st$12$0 >> 2] = $71$0;
    var $st$12$1 = $72 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $71$1;
    var $_idx5_val = HEAP32[$_idx >> 2];
    var $73 = __ZNK2js12CallReceiver5thisvEv($_idx5_val);
    __ZN2JSL11ObjectValueER8JSObject2569($3, $holder);
    var $74 = $3 | 0;
    var $75$0 = HEAP32[$74 >> 2];
    var $75$1 = HEAP32[$74 + 4 >> 2];
    var $76 = $73 | 0;
    var $st$25$0 = $76 | 0;
    HEAP32[$st$25$0 >> 2] = $75$0;
    var $st$25$1 = $76 + 4 | 0;
    HEAP32[$st$25$1 >> 2] = $75$1;
    var $_idx10_val = HEAP32[$_idx >> 2];
    var $77 = __ZNK2js8CallArgsixEj($_idx10_val, 0);
    __ZN2JSL11StringValueEP8JSString2546($4, $keyStr_1);
    var $78 = $4 | 0;
    var $79$0 = HEAP32[$78 >> 2];
    var $79$1 = HEAP32[$78 + 4 >> 2];
    var $80 = $77 | 0;
    var $st$38$0 = $80 | 0;
    HEAP32[$st$38$0 >> 2] = $79$0;
    var $st$38$1 = $80 + 4 | 0;
    HEAP32[$st$38$1 >> 2] = $79$1;
    var $_idx9_val = HEAP32[$_idx >> 2];
    var $81 = __ZNK2js8CallArgsixEj($_idx9_val, 1);
    var $82$0 = HEAP32[$vp_idx1 >> 2];
    var $82$1 = HEAP32[$vp_idx1 + 4 >> 2];
    var $83 = $81 | 0;
    var $st$49$0 = $83 | 0;
    HEAP32[$st$49$0 >> 2] = $82$0;
    var $st$49$1 = $83 + 4 | 0;
    HEAP32[$st$49$1 >> 2] = $82$1;
    var $84 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($67, $60, 0);
    if ($84) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $_idx12_val = HEAP32[$_idx >> 2];
    var $85 = __ZNK2js12CallReceiver4rvalEv($_idx12_val);
    var $86 = $85 | 0;
    var $st$3$0 = $86 | 0;
    var $87$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $86 + 4 | 0;
    var $87$1 = HEAP32[$st$3$1 >> 2];
    var $st$7$0 = $vp_idx1 | 0;
    HEAP32[$st$7$0 >> 2] = $87$0;
    var $st$7$1 = $vp_idx1 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $87$1;
    __ZN2js15InvokeArgsGuardD1Ev($60);
    __label__ = 17;
    break;
   case 16:
    __ZN2js15InvokeArgsGuardD1Ev($60);
    var $_3 = 0;
    __label__ = 26;
    break;
   case 17:
    var $vp_idx_val$0 = HEAP32[$vp_idx1 >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx1 + 4 >> 2];
    var $89 = __ZNK2JS5Value8isObjectEv($vp_idx_val$0, $vp_idx_val$1);
    if ($89) {
      __label__ = 18;
      break;
    } else {
      var $_3 = 1;
      __label__ = 26;
      break;
    }
   case 18:
    var $91 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
    var $_idx7_val = HEAP32[$91 + 4 >> 2];
    var $92 = __ZNK8JSObject8getClassEv($_idx7_val);
    if (($92 | 0) == (__ZN2js11NumberClassE | 0)) {
      __label__ = 19;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 19:
    var $95 = $cx;
    var $96 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($95, $vp, $d);
    if ($96) {
      __label__ = 20;
      break;
    } else {
      var $_3 = 0;
      __label__ = 26;
      break;
    }
   case 20:
    var $98 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $99 = __ZN2JS5Value9setNumberEd($vp, $98);
    var $_3 = 1;
    __label__ = 26;
    break;
   case 21:
    if (($92 | 0) == (__ZN2js11StringClassE | 0)) {
      __label__ = 22;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 22:
    var $103 = $cx;
    var $104 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($103, $vp_idx_val$0, $vp_idx_val$1);
    if (($104 | 0) == 0) {
      var $_3 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    __ZN2JS5Value9setStringEP8JSString($vp, $104);
    var $_3 = 1;
    __label__ = 26;
    break;
   case 24:
    if (($92 | 0) == (__ZN2js12BooleanClassE | 0)) {
      __label__ = 25;
      break;
    } else {
      var $_3 = 1;
      __label__ = 26;
      break;
    }
   case 25:
    var $110 = $91;
    var $111 = __ZNK8JSObject16getPrimitiveThisEv($110);
    var $112 = $111 | 0;
    var $st$3$0 = $112 | 0;
    var $113$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $112 + 4 | 0;
    var $113$1 = HEAP32[$st$3$1 >> 2];
    var $st$7$0 = $vp_idx1 | 0;
    HEAP32[$st$7$0 >> 2] = $113$0;
    var $st$7$1 = $vp_idx1 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $113$1;
    var $_3 = 1;
    __label__ = 26;
    break;
   case 26:
    var $_3;
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15PreprocessValueIjEbP9JSContextP8JSObjectT_PN2JS5ValueEP16StringifyContext["X"] = 1;

function __ZN14KeyStringifierIjE8toStringEP9JSContextj($cx, $index) {
  var $1 = $cx;
  var $2 = __ZN2js13IndexToStringEP9JSContextj($1, $index);
  return $2 | 0;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E4initEj($1);
  return $2;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $0 = $this | 0;
    var $1 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E11createTableERS8_j($0, 32);
    HEAP32[$this + 24 >> 2] = $1;
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, 5);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN16StringifyContextC2EP9JSContextRN2js12StringBufferERKS3_P8JSObjectRKNS2_12AutoIdVectorE($this, $cx, $sb, $gap, $replacer, $propertyList) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = $sb;
  HEAP32[$this + 4 >> 2] = $gap;
  HEAP32[$this + 8 >> 2] = $replacer;
  HEAP32[$this + 12 >> 2] = $propertyList;
  HEAP32[$this + 16 >> 2] = 0;
  var $7 = $this + 20 | 0;
  var $8 = $1;
  var $9 = $cx;
  __ZN2js15TempAllocPolicyC1EP9JSContext($8, $9);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_($7, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_($this, $a_01) {
  __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_($this, $a_01);
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_($this, $a_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_EC1ES8_($1, $a_0);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_EC1ES8_($this, $ap_01) {
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_EC2ES8_($this, $ap_01);
  return;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2593($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 24;
    var $4 = $cx;
    var $5 = __ZNK9JSContext5hasfpEv($4);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $8;
    var $9 = $cx;
    var $10 = $global;
    var $11 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($9, $10);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $19 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $13 = __ZNK9JSContext2fpEv($4);
    var $14 = __ZNK2js10StackFrame10scopeChainEv($13);
    var $15 = $14;
    var $16 = __ZNK8JSObject9getGlobalEv($15);
    var $17 = $16;
    HEAP32[$global >> 2] = $17;
    var $19 = $17;
    __label__ = 5;
    break;
   case 5:
    var $19;
    var $20 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $19, $20);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $22 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $24 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $25 = $24;
    HEAP32[$proto >> 2] = $25;
    var $32 = $25;
    __label__ = 9;
    break;
   case 7:
    var $27 = $cx;
    var $29 = $proto;
    var $30 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($27, $19, $3, $29, __ZN2js11ObjectClassE);
    if ($30) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $32 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $32;
    var $33 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2594($cx, $32, $19, $kind);
    var $_0 = $33;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2593["X"] = 1;

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2594($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $proto;
    var $2 = $cx;
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($1, $2, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($2, $kind);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_0 = $7;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $parent;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, __ZN2js11ObjectClassE, $3, $10, 0, (__ZN2js11ObjectClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $11 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($3, $2, __ZN2js11ObjectClassE, $kind);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $11 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($6, $14);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE7appendNERKtj($this, $t, $needed) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] + $needed | 0) >>> 0 > HEAPU32[$this + 12 >> 2] >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $this;
    var $9 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE13growStorageByEj($8, $needed);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE15internalAppendNERKtj($this, $t, $needed);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE15internalAppendNERKtj($this, $t, $needed) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $2 = $this + 8 | 0;
  var $_idx1_val = HEAP32[$2 >> 2];
  var $3 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10endNoCheckEv($_idx_val, $_idx1_val);
  __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE14copyConstructNEPtjRKt($3, $needed, $t);
  var $5 = HEAP32[$2 >> 2] + $needed | 0;
  HEAP32[$2 >> 2] = $5;
  return;
}

function __ZL18js_DoubleToIntegerd2596($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d == 0) {
      var $_0 = $d;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL18JSDOUBLE_IS_FINITEd2585($d);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZL15JSDOUBLE_IS_NaNd2597($d);
    var $d_ = ($6 | 0) == 0 ? $d : 0;
    var $_0 = $d_;
    __label__ = 7;
    break;
   case 4:
    if ($d < 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = _floor($d);
    var $_0 = $10;
    __label__ = 7;
    break;
   case 6:
    var $12 = -$d;
    var $13 = _floor($12);
    var $_0 = -$13;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 24 >> 2];
  __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_ED1Ev($this_0_6_val) {
  __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_ED2Ev($this_0_6_val);
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_ED2Ev($this_0_6_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_6_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E12destroyTableERS6_PNS0_14HashTableEntryIS2_EEj($this_0_6_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSONParser5errorEPKc($this, $msg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 28 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($6, 4, 228, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $msg, tempInt));
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSONParser10readNumberEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $dummy = __stackBase__ + 8;
    var $d = __stackBase__ + 12;
    var $d1 = __stackBase__ + 20;
    var $finish = __stackBase__ + 28;
    var $3 = $this + 4 | 0;
    var $_idx21 = $3 | 0;
    var $_idx21_val = HEAP32[$_idx21 >> 2];
    var $4 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx21_val);
    var $6 = HEAP16[$4 >> 1] << 16 >> 16 == 45;
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $13 = $_idx21_val;
      __label__ = 5;
      break;
    }
   case 2:
    var $8 = __ZN7mozilla9RangedPtrIKtEppEv($3);
    var $_idx30_val = HEAP32[$8 >> 2];
    var $_idx31_val = HEAP32[$this + 8 >> 2];
    var $9 = __ZNK7mozilla9RangedPtrIKtEeqIS1_EEbRKNS0_IT_EE($_idx30_val, $_idx31_val);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = HEAP32[$_idx21 >> 2];
    __label__ = 5;
    break;
   case 4:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str2606 | 0);
    var $11 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $11;
    __label__ = 45;
    break;
   case 5:
    var $13;
    var $14 = __ZNK7mozilla9RangedPtrIKtEdeEv($13);
    if (((HEAPU16[$14 >> 1] & 65535) - 48 | 0) >>> 0 < 10) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str12607 | 0);
    var $20 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $20;
    __label__ = 45;
    break;
   case 7:
    __ZN7mozilla9RangedPtrIKtEppEi($1, $3);
    var $_idx19_val = HEAP32[$1 >> 2];
    var $22 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx19_val);
    if (HEAP16[$22 >> 1] << 16 >> 16 == 48) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $_idx29_phi_trans_insert = $this + 8 | 0;
    var $_idx28_val = HEAP32[$_idx21 >> 2];
    var $_idx29_val = HEAP32[$_idx29_phi_trans_insert >> 2];
    var $_idx29_pre_phi = $_idx29_phi_trans_insert;
    __label__ = 14;
    break;
   case 9:
    var $_idx9 = $this + 8 | 0;
    __label__ = 10;
    break;
   case 10:
    var $_idx8_val = HEAPU32[$_idx21 >> 2];
    var $_idx9_val = HEAPU32[$_idx9 >> 2];
    var $25 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($_idx8_val, $_idx9_val);
    if ($25) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $27 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx8_val);
    if (((HEAPU16[$27 >> 1] & 65535) - 48 | 0) >>> 0 < 10) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    __ZN7mozilla9RangedPtrIKtEppEi($2, $3);
    __label__ = 10;
    break;
   case 13:
    var $_idx28_val = $_idx8_val;
    var $_idx29_val = $_idx9_val;
    var $_idx29_pre_phi = $this + 8 | 0;
    __label__ = 14;
    break;
   case 14:
    var $_idx29_pre_phi;
    var $_idx29_val;
    var $_idx28_val;
    var $33 = __ZNK7mozilla9RangedPtrIKtEeqIS1_EEbRKNS0_IT_EE($_idx28_val, $_idx29_val);
    if ($33) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $35 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx28_val);
    var $36 = HEAPU16[$35 >> 1];
    if ($36 << 16 >> 16 == 46 || $36 << 16 >> 16 == 101 || $36 << 16 >> 16 == 69) {
      __label__ = 21;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $39 = HEAP32[$this >> 2];
    var $40 = __ZNK7mozilla9RangedPtrIKtE3getEv($13);
    var $41 = __ZNK7mozilla9RangedPtrIKtE3getEv($_idx28_val);
    var $42 = __ZN2js16GetPrefixIntegerEP9JSContextPKtS3_iPS3_Pd($39, $40, $41, 10, $dummy, $d);
    if ($42) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $44 = __ZN10JSONParser5tokenENS_5TokenE(11);
    var $_0 = $44;
    __label__ = 45;
    break;
   case 18:
    var $46 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    if ($6) {
      __label__ = 19;
      break;
    } else {
      var $50 = $46;
      __label__ = 20;
      break;
    }
   case 19:
    var $50 = -$46;
    __label__ = 20;
    break;
   case 20:
    var $50;
    __ZN10JSONParser11numberTokenEd($this, $50);
    var $_0 = 1;
    __label__ = 45;
    break;
   case 21:
    var $52 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($_idx28_val, $_idx29_val);
    if ($52 & $36 << 16 >> 16 == 46) {
      __label__ = 22;
      break;
    } else {
      var $_idx13_val = $_idx28_val;
      var $_idx3_val = $_idx29_val;
      __label__ = 28;
      break;
    }
   case 22:
    var $55 = __ZN7mozilla9RangedPtrIKtEppEv($3);
    var $_idx26_val = HEAP32[$55 >> 2];
    var $_idx27_val = HEAP32[$_idx29_pre_phi >> 2];
    var $56 = __ZNK7mozilla9RangedPtrIKtEeqIS1_EEbRKNS0_IT_EE($_idx26_val, $_idx27_val);
    if ($56) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str22608 | 0);
    var $58 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $58;
    __label__ = 45;
    break;
   case 24:
    var $_idx15_val = HEAP32[$_idx21 >> 2];
    var $60 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx15_val);
    if (((HEAPU16[$60 >> 1] & 65535) - 48 | 0) >>> 0 < 10) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str32609 | 0);
    var $66 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $66;
    __label__ = 45;
    break;
   case 26:
    var $67 = __ZN7mozilla9RangedPtrIKtEppEv($3);
    var $_idx4_val = HEAP32[$67 >> 2];
    var $_idx5_val = HEAPU32[$_idx29_pre_phi >> 2];
    var $68 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($_idx4_val, $_idx5_val);
    var $_idx14_val = HEAPU32[$_idx21 >> 2];
    if ($68) {
      __label__ = 27;
      break;
    } else {
      var $_idx13_val = $_idx14_val;
      var $_idx3_val = $_idx5_val;
      __label__ = 28;
      break;
    }
   case 27:
    var $70 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx14_val);
    if (((HEAPU16[$70 >> 1] & 65535) - 48 | 0) >>> 0 < 10) {
      __label__ = 26;
      break;
    } else {
      var $_idx13_val = $_idx14_val;
      var $_idx3_val = $_idx5_val;
      __label__ = 28;
      break;
    }
   case 28:
    var $_idx3_val;
    var $_idx13_val;
    var $75 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($_idx13_val, $_idx3_val);
    if ($75) {
      __label__ = 29;
      break;
    } else {
      var $_idx32_val = $_idx13_val;
      __label__ = 40;
      break;
    }
   case 29:
    var $77 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx13_val);
    var $78 = HEAP16[$77 >> 1];
    if ($78 << 16 >> 16 == 101 || $78 << 16 >> 16 == 69) {
      __label__ = 30;
      break;
    } else {
      var $_idx32_val = $_idx13_val;
      __label__ = 40;
      break;
    }
   case 30:
    var $80 = __ZN7mozilla9RangedPtrIKtEppEv($3);
    var $_idx24_val = HEAP32[$80 >> 2];
    var $_idx25_val = HEAP32[$_idx29_pre_phi >> 2];
    var $81 = __ZNK7mozilla9RangedPtrIKtEeqIS1_EEbRKNS0_IT_EE($_idx24_val, $_idx25_val);
    if ($81) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str42610 | 0);
    var $83 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $83;
    __label__ = 45;
    break;
   case 32:
    var $_idx12_val = HEAP32[$_idx21 >> 2];
    var $85 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx12_val);
    var $86 = HEAP16[$85 >> 1];
    if ($86 << 16 >> 16 == 43 || $86 << 16 >> 16 == 45) {
      __label__ = 33;
      break;
    } else {
      var $_idx11_val = $_idx12_val;
      __label__ = 36;
      break;
    }
   case 33:
    var $88 = __ZN7mozilla9RangedPtrIKtEppEv($3);
    var $_idx22_val = HEAP32[$88 >> 2];
    var $_idx23_val = HEAP32[$_idx29_pre_phi >> 2];
    var $89 = __ZNK7mozilla9RangedPtrIKtEeqIS1_EEbRKNS0_IT_EE($_idx22_val, $_idx23_val);
    if ($89) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $_idx11_val = HEAP32[$_idx21 >> 2];
    __label__ = 36;
    break;
   case 35:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str52611 | 0);
    var $91 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $91;
    __label__ = 45;
    break;
   case 36:
    var $_idx11_val;
    var $93 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx11_val);
    if (((HEAPU16[$93 >> 1] & 65535) - 48 | 0) >>> 0 < 10) {
      __label__ = 38;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str62612 | 0);
    var $99 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $99;
    __label__ = 45;
    break;
   case 38:
    var $100 = __ZN7mozilla9RangedPtrIKtEppEv($3);
    var $_idx_val = HEAP32[$100 >> 2];
    var $_idx1_val = HEAP32[$_idx29_pre_phi >> 2];
    var $101 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($_idx_val, $_idx1_val);
    var $_idx10_val = HEAPU32[$_idx21 >> 2];
    if ($101) {
      __label__ = 39;
      break;
    } else {
      var $_idx32_val = $_idx10_val;
      __label__ = 40;
      break;
    }
   case 39:
    var $103 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx10_val);
    if (((HEAPU16[$103 >> 1] & 65535) - 48 | 0) >>> 0 < 10) {
      __label__ = 38;
      break;
    } else {
      var $_idx32_val = $_idx10_val;
      __label__ = 40;
      break;
    }
   case 40:
    var $_idx32_val;
    var $109 = HEAP32[$this >> 2];
    var $110 = __ZNK7mozilla9RangedPtrIKtE3getEv($13);
    var $111 = __ZNK7mozilla9RangedPtrIKtE3getEv($_idx32_val);
    var $112 = __Z9js_strtodP9JSContextPKtS2_PS2_Pd($109, $110, $111, $finish, $d1);
    if (($112 | 0) == 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 41:
    var $115 = __ZN10JSONParser5tokenENS_5TokenE(11);
    var $_0 = $115;
    __label__ = 45;
    break;
   case 42:
    var $117 = (tempDoubleI32[0] = HEAP32[$d1 >> 2], tempDoubleI32[1] = HEAP32[$d1 + 4 >> 2], tempDoubleF64[0]);
    if ($6) {
      __label__ = 43;
      break;
    } else {
      var $121 = $117;
      __label__ = 44;
      break;
    }
   case 43:
    var $121 = -$117;
    __label__ = 44;
    break;
   case 44:
    var $121;
    __ZN10JSONParser11numberTokenEd($this, $121);
    var $_0 = 1;
    __label__ = 45;
    break;
   case 45:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN10JSONParser10readNumberEv["X"] = 1;

function __ZN10JSONParser11numberTokenEd($this, $d) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL11NumberValueEd2666($1, $d);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this + 16 | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZL16IsJSONWhitespacet($c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($c << 16 >> 16 == 9 || $c << 16 >> 16 == 13 || $c << 16 >> 16 == 10 || $c << 16 >> 16 == 32) {
      var $2 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $2 = 0;
    __label__ = 3;
    break;
   case 3:
    var $2;
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE($this_0_0_val, $other_0_0_val) {
  return $this_0_0_val >>> 0 >= $other_0_0_val >>> 0;
}

function __ZNK7mozilla9RangedPtrIKtEmiERKS2_($this_0_0_val, $other_0_0_val) {
  return ($this_0_0_val - $other_0_0_val | 0) >>> 1;
}

function __ZN10JSONParser7advanceEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 12;
    var $5 = __stackBase__ + 16;
    var $6 = __stackBase__ + 20;
    var $7 = __stackBase__ + 24;
    var $8 = $this + 4 | 0;
    var $_idx = $8 | 0;
    var $_idx1 = $this + 8 | 0;
    __label__ = 2;
    break;
   case 2:
    var $_idx_val = HEAPU32[$_idx >> 2];
    var $_idx1_val = HEAPU32[$_idx1 >> 2];
    var $10 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($_idx_val, $_idx1_val);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $12 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx_val);
    var $13 = HEAP16[$12 >> 1];
    var $14 = __ZL16IsJSONWhitespacet($13);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN7mozilla9RangedPtrIKtEppEi($1, $8);
    __label__ = 2;
    break;
   case 5:
    var $16 = __ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE($_idx_val, $_idx1_val);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str72613 | 0);
    var $18 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $18;
    __label__ = 36;
    break;
   case 7:
    var $20 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx_val);
    var $22 = HEAPU16[$20 >> 1] & 65535;
    if (($22 | 0) == 34) {
      __label__ = 8;
      break;
    } else if (($22 | 0) == 45 || ($22 | 0) == 48 || ($22 | 0) == 49 || ($22 | 0) == 50 || ($22 | 0) == 51 || ($22 | 0) == 52 || ($22 | 0) == 53 || ($22 | 0) == 54 || ($22 | 0) == 55 || ($22 | 0) == 56 || ($22 | 0) == 57) {
      __label__ = 9;
      break;
    } else if (($22 | 0) == 116) {
      __label__ = 10;
      break;
    } else if (($22 | 0) == 102) {
      __label__ = 16;
      break;
    } else if (($22 | 0) == 110) {
      __label__ = 23;
      break;
    } else if (($22 | 0) == 91) {
      __label__ = 29;
      break;
    } else if (($22 | 0) == 93) {
      __label__ = 30;
      break;
    } else if (($22 | 0) == 123) {
      __label__ = 31;
      break;
    } else if (($22 | 0) == 125) {
      __label__ = 32;
      break;
    } else if (($22 | 0) == 44) {
      __label__ = 33;
      break;
    } else if (($22 | 0) == 58) {
      __label__ = 34;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 8:
    var $24 = __ZN10JSONParser10readStringILNS_10StringTypeE1EEENS_5TokenEv($this);
    var $_0 = $24;
    __label__ = 36;
    break;
   case 9:
    var $26 = __ZN10JSONParser10readNumberEv($this);
    var $_0 = $26;
    __label__ = 36;
    break;
   case 10:
    var $28 = __ZNK7mozilla9RangedPtrIKtEmiERKS2_($_idx1_val, $_idx_val);
    if ($28 >>> 0 < 4) {
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $31 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx_val, 1);
    if (HEAP16[$31 >> 1] << 16 >> 16 == 114) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $_idx20_val = HEAP32[$_idx >> 2];
    var $35 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx20_val, 2);
    if (HEAP16[$35 >> 1] << 16 >> 16 == 117) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $_idx19_val = HEAP32[$_idx >> 2];
    var $39 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx19_val, 3);
    if (HEAP16[$39 >> 1] << 16 >> 16 == 101) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str82614 | 0);
    var $43 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $43;
    __label__ = 36;
    break;
   case 15:
    var $45 = __ZN7mozilla9RangedPtrIKtEpLEj($8, 4);
    var $46 = __ZN10JSONParser5tokenENS_5TokenE(2);
    var $_0 = $46;
    __label__ = 36;
    break;
   case 16:
    var $48 = __ZNK7mozilla9RangedPtrIKtEmiERKS2_($_idx1_val, $_idx_val);
    if ($48 >>> 0 < 5) {
      __label__ = 21;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $51 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx_val, 1);
    if (HEAP16[$51 >> 1] << 16 >> 16 == 97) {
      __label__ = 18;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 18:
    var $_idx17_val = HEAP32[$_idx >> 2];
    var $55 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx17_val, 2);
    if (HEAP16[$55 >> 1] << 16 >> 16 == 108) {
      __label__ = 19;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 19:
    var $_idx16_val = HEAP32[$_idx >> 2];
    var $59 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx16_val, 3);
    if (HEAP16[$59 >> 1] << 16 >> 16 == 115) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $_idx15_val = HEAP32[$_idx >> 2];
    var $63 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx15_val, 4);
    if (HEAP16[$63 >> 1] << 16 >> 16 == 101) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str82614 | 0);
    var $67 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $67;
    __label__ = 36;
    break;
   case 22:
    var $69 = __ZN7mozilla9RangedPtrIKtEpLEj($8, 5);
    var $70 = __ZN10JSONParser5tokenENS_5TokenE(3);
    var $_0 = $70;
    __label__ = 36;
    break;
   case 23:
    var $72 = __ZNK7mozilla9RangedPtrIKtEmiERKS2_($_idx1_val, $_idx_val);
    if ($72 >>> 0 < 4) {
      __label__ = 27;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $75 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx_val, 1);
    if (HEAP16[$75 >> 1] << 16 >> 16 == 117) {
      __label__ = 25;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 25:
    var $_idx13_val = HEAP32[$_idx >> 2];
    var $79 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx13_val, 2);
    if (HEAP16[$79 >> 1] << 16 >> 16 == 108) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $_idx12_val = HEAP32[$_idx >> 2];
    var $83 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx12_val, 3);
    if (HEAP16[$83 >> 1] << 16 >> 16 == 108) {
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str82614 | 0);
    var $87 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $87;
    __label__ = 36;
    break;
   case 28:
    var $89 = __ZN7mozilla9RangedPtrIKtEpLEj($8, 4);
    var $90 = __ZN10JSONParser5tokenENS_5TokenE(4);
    var $_0 = $90;
    __label__ = 36;
    break;
   case 29:
    __ZN7mozilla9RangedPtrIKtEppEi($2, $8);
    var $92 = __ZN10JSONParser5tokenENS_5TokenE(5);
    var $_0 = $92;
    __label__ = 36;
    break;
   case 30:
    __ZN7mozilla9RangedPtrIKtEppEi($3, $8);
    var $94 = __ZN10JSONParser5tokenENS_5TokenE(6);
    var $_0 = $94;
    __label__ = 36;
    break;
   case 31:
    __ZN7mozilla9RangedPtrIKtEppEi($4, $8);
    var $96 = __ZN10JSONParser5tokenENS_5TokenE(7);
    var $_0 = $96;
    __label__ = 36;
    break;
   case 32:
    __ZN7mozilla9RangedPtrIKtEppEi($5, $8);
    var $98 = __ZN10JSONParser5tokenENS_5TokenE(8);
    var $_0 = $98;
    __label__ = 36;
    break;
   case 33:
    __ZN7mozilla9RangedPtrIKtEppEi($6, $8);
    var $100 = __ZN10JSONParser5tokenENS_5TokenE(10);
    var $_0 = $100;
    __label__ = 36;
    break;
   case 34:
    __ZN7mozilla9RangedPtrIKtEppEi($7, $8);
    var $102 = __ZN10JSONParser5tokenENS_5TokenE(9);
    var $_0 = $102;
    __label__ = 36;
    break;
   case 35:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str92615 | 0);
    var $104 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $104;
    __label__ = 36;
    break;
   case 36:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN10JSONParser7advanceEv["X"] = 1;

function __ZN10JSONParser10readStringILNS_10StringTypeE1EEENS_5TokenEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 104;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $start = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 8;
    var $buffer = __stackBase__ + 12;
    var $3 = __stackBase__ + 92;
    var $4 = __stackBase__ + 96;
    var $5 = __stackBase__ + 100;
    var $6 = $this + 4 | 0;
    var $7 = __ZN7mozilla9RangedPtrIKtEppEv($6);
    var $_idx15_val = HEAP32[$7 >> 2];
    var $_idx16 = $this + 8 | 0;
    var $_idx16_val = HEAP32[$_idx16 >> 2];
    var $8 = __ZNK7mozilla9RangedPtrIKtEeqIS1_EEbRKNS0_IT_EE($_idx15_val, $_idx16_val);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str232629 | 0);
    var $10 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_1 = $10;
    __label__ = 67;
    break;
   case 3:
    var $12 = $6 | 0;
    var $13 = HEAPU32[$12 >> 2];
    var $14 = $start | 0;
    HEAP32[$14 >> 2] = $13;
    var $_idx19_val = $13;
    var $_idx6_val = $_idx16_val;
    __label__ = 4;
    break;
   case 4:
    var $_idx6_val;
    var $_idx19_val;
    var $16 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($_idx19_val, $_idx6_val);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 5:
    var $18 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx19_val);
    var $19 = HEAPU16[$18 >> 1];
    if ($19 << 16 >> 16 == 34) {
      __label__ = 6;
      break;
    } else if ($19 << 16 >> 16 == 92) {
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $21 = __ZNK7mozilla9RangedPtrIKtEmiERKS2_($_idx19_val, $13);
    __ZN7mozilla9RangedPtrIKtEppEi($1, $6);
    var $23 = HEAP32[$this >> 2];
    var $24 = __ZNK7mozilla9RangedPtrIKtE3getEv($13);
    var $25 = $23;
    var $26 = __Z17js_NewStringCopyNP9JSContextPKtj($25, $24, $21);
    if (($26 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $29 = __ZN10JSONParser5tokenENS_5TokenE(11);
    var $_1 = $29;
    __label__ = 67;
    break;
   case 8:
    var $31 = $26 | 0;
    __ZN10JSONParser11stringTokenEP8JSString($this, $31);
    var $_1 = 0;
    __label__ = 67;
    break;
   case 9:
    if (($19 & 65535) < 32) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str242630 | 0);
    var $35 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_1 = $35;
    __label__ = 67;
    break;
   case 11:
    __ZN7mozilla9RangedPtrIKtEppEi($2, $6);
    var $_idx19_val = HEAP32[$12 >> 2];
    var $_idx6_val = HEAP32[$_idx16 >> 2];
    __label__ = 4;
    break;
   case 12:
    var $39 = HEAP32[$this >> 2];
    __ZN2js12StringBufferC1EP9JSContext($buffer, $39);
    var $40 = $buffer;
    var $_idx9 = $3 | 0;
    var $_idx8 = $4 | 0;
    var $_idx21_val = HEAP32[$12 >> 2];
    var $start_idx_val = $13;
    __label__ = 13;
    break;
   case 13:
    var $start_idx_val;
    var $_idx21_val;
    var $42 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($start_idx_val, $_idx21_val);
    if ($42) {
      __label__ = 14;
      break;
    } else {
      var $_idx13_val = $_idx21_val;
      __label__ = 17;
      break;
    }
   case 14:
    var $44 = __ZNK7mozilla9RangedPtrIKtE3getEv($start_idx_val);
    var $45 = __ZNK7mozilla9RangedPtrIKtE3getEv($_idx21_val);
    var $46 = __ZN2js12StringBuffer6appendEPKtS2_($40, $44, $45);
    if ($46) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $_idx13_val = HEAP32[$12 >> 2];
    __label__ = 17;
    break;
   case 16:
    var $48 = __ZN10JSONParser5tokenENS_5TokenE(11);
    var $_0 = $48;
    __label__ = 66;
    break;
   case 17:
    var $_idx13_val;
    var $_idx14_val = HEAP32[$_idx16 >> 2];
    var $49 = __ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE($_idx13_val, $_idx14_val);
    if ($49) {
      __label__ = 65;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZN7mozilla9RangedPtrIKtEppEi($3, $6);
    var $_idx9_val = HEAP32[$_idx9 >> 2];
    var $51 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx9_val);
    var $52 = HEAP16[$51 >> 1];
    if ($52 << 16 >> 16 == 34) {
      __label__ = 19;
      break;
    } else if ($52 << 16 >> 16 == 92) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 19:
    var $54 = $buffer;
    var $55 = __ZN2js12StringBuffer12finishStringEv($54);
    if (($55 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $58 = __ZN10JSONParser5tokenENS_5TokenE(11);
    var $_0 = $58;
    __label__ = 66;
    break;
   case 21:
    var $60 = $55 | 0;
    __ZN10JSONParser11stringTokenEP8JSString($this, $60);
    var $_0 = 0;
    __label__ = 66;
    break;
   case 22:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str252631 | 0);
    var $62 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $62;
    __label__ = 66;
    break;
   case 23:
    var $_idx11_val = HEAP32[$12 >> 2];
    var $_idx12_val = HEAP32[$_idx16 >> 2];
    var $64 = __ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE($_idx11_val, $_idx12_val);
    if ($64) {
      __label__ = 65;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    __ZN7mozilla9RangedPtrIKtEppEi($4, $6);
    var $_idx8_val = HEAP32[$_idx8 >> 2];
    var $66 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx8_val);
    var $68 = HEAPU16[$66 >> 1] & 65535;
    if (($68 | 0) == 47) {
      __label__ = 25;
      break;
    } else if (($68 | 0) == 92) {
      __label__ = 26;
      break;
    } else if (($68 | 0) == 98) {
      __label__ = 27;
      break;
    } else if (($68 | 0) == 102) {
      __label__ = 28;
      break;
    } else if (($68 | 0) == 110) {
      __label__ = 29;
      break;
    } else if (($68 | 0) == 114) {
      __label__ = 30;
      break;
    } else if (($68 | 0) == 116) {
      __label__ = 31;
      break;
    } else if (($68 | 0) == 117) {
      __label__ = 32;
      break;
    } else if (($68 | 0) == 34) {
      var $c_0 = 34;
      __label__ = 56;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 25:
    var $c_0 = 47;
    __label__ = 56;
    break;
   case 26:
    var $c_0 = 92;
    __label__ = 56;
    break;
   case 27:
    var $c_0 = 8;
    __label__ = 56;
    break;
   case 28:
    var $c_0 = 12;
    __label__ = 56;
    break;
   case 29:
    var $c_0 = 10;
    __label__ = 56;
    break;
   case 30:
    var $c_0 = 13;
    __label__ = 56;
    break;
   case 31:
    var $c_0 = 9;
    __label__ = 56;
    break;
   case 32:
    var $_idx17_val = HEAP32[$_idx16 >> 2];
    var $_idx18_val = HEAPU32[$12 >> 2];
    var $77 = __ZNK7mozilla9RangedPtrIKtEmiERKS2_($_idx17_val, $_idx18_val);
    if ($77 >>> 0 < 4) {
      __label__ = 33;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 33:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str262632 | 0);
    var $80 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $80;
    __label__ = 66;
    break;
   case 34:
    var $82 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx18_val, 0);
    if ((HEAPU16[$82 >> 1] & 65535) < 128) {
      __label__ = 35;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 35:
    var $_idx38_val = HEAP32[$12 >> 2];
    var $86 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx38_val, 0);
    var $88 = HEAPU16[$86 >> 1] & 65535;
    var $89 = _isxdigit($88);
    if (($89 | 0) == 0) {
      __label__ = 55;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $_idx37_val = HEAP32[$12 >> 2];
    var $92 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx37_val, 1);
    if ((HEAPU16[$92 >> 1] & 65535) < 128) {
      __label__ = 37;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 37:
    var $_idx36_val = HEAP32[$12 >> 2];
    var $96 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx36_val, 1);
    var $98 = HEAPU16[$96 >> 1] & 65535;
    var $99 = _isxdigit($98);
    if (($99 | 0) == 0) {
      __label__ = 55;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $_idx35_val = HEAP32[$12 >> 2];
    var $102 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx35_val, 2);
    if ((HEAPU16[$102 >> 1] & 65535) < 128) {
      __label__ = 39;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 39:
    var $_idx34_val = HEAP32[$12 >> 2];
    var $106 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx34_val, 2);
    var $108 = HEAPU16[$106 >> 1] & 65535;
    var $109 = _isxdigit($108);
    if (($109 | 0) == 0) {
      __label__ = 55;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $_idx33_val = HEAP32[$12 >> 2];
    var $112 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx33_val, 3);
    if ((HEAPU16[$112 >> 1] & 65535) < 128) {
      __label__ = 41;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 41:
    var $_idx32_val = HEAP32[$12 >> 2];
    var $116 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx32_val, 3);
    var $118 = HEAPU16[$116 >> 1] & 65535;
    var $119 = _isxdigit($118);
    if (($119 | 0) == 0) {
      __label__ = 55;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $_idx31_val = HEAP32[$12 >> 2];
    var $122 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx31_val, 0);
    var $126 = ((HEAPU16[$122 >> 1] & 65535) - 48 | 0) >>> 0 < 10;
    var $_idx30_val = HEAP32[$12 >> 2];
    var $127 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx30_val, 0);
    var $129 = HEAPU16[$127 >> 1] & 65535;
    if ($126) {
      __label__ = 43;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 43:
    var $136 = $129 - 48 | 0;
    __label__ = 45;
    break;
   case 44:
    var $133 = _tolower($129);
    var $136 = $133 - 87 | 0;
    __label__ = 45;
    break;
   case 45:
    var $136;
    var $137 = $136 << 12;
    var $_idx29_val = HEAP32[$12 >> 2];
    var $138 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx29_val, 1);
    var $142 = ((HEAPU16[$138 >> 1] & 65535) - 48 | 0) >>> 0 < 10;
    var $_idx28_val = HEAP32[$12 >> 2];
    var $143 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx28_val, 1);
    var $145 = HEAPU16[$143 >> 1] & 65535;
    if ($142) {
      __label__ = 46;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 46:
    var $152 = $145 - 48 | 0;
    __label__ = 48;
    break;
   case 47:
    var $149 = _tolower($145);
    var $152 = $149 - 87 | 0;
    __label__ = 48;
    break;
   case 48:
    var $152;
    var $153 = $152 << 8;
    var $_idx27_val = HEAP32[$12 >> 2];
    var $154 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx27_val, 2);
    var $158 = ((HEAPU16[$154 >> 1] & 65535) - 48 | 0) >>> 0 < 10;
    var $_idx26_val = HEAP32[$12 >> 2];
    var $159 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx26_val, 2);
    var $161 = HEAPU16[$159 >> 1] & 65535;
    if ($158) {
      __label__ = 49;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 49:
    var $168 = $161 - 48 | 0;
    __label__ = 51;
    break;
   case 50:
    var $165 = _tolower($161);
    var $168 = $165 - 87 | 0;
    __label__ = 51;
    break;
   case 51:
    var $168;
    var $169 = $168 << 4;
    var $_idx25_val = HEAP32[$12 >> 2];
    var $170 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx25_val, 3);
    var $174 = ((HEAPU16[$170 >> 1] & 65535) - 48 | 0) >>> 0 < 10;
    var $_idx24_val = HEAP32[$12 >> 2];
    var $175 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx24_val, 3);
    var $177 = HEAPU16[$175 >> 1] & 65535;
    if ($174) {
      __label__ = 52;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 52:
    var $184 = $177 - 48 | 0;
    __label__ = 54;
    break;
   case 53:
    var $181 = _tolower($177);
    var $184 = $181 - 87 | 0;
    __label__ = 54;
    break;
   case 54:
    var $184;
    var $188 = ($153 | $137 | $169 | $184) & 65535;
    var $189 = __ZN7mozilla9RangedPtrIKtEpLEj($6, 4);
    var $c_0 = $188;
    __label__ = 56;
    break;
   case 55:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str272633 | 0);
    var $191 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $191;
    __label__ = 66;
    break;
   case 56:
    var $c_0;
    var $193 = __ZN2js12StringBuffer6appendEt($buffer, $c_0);
    if ($193) {
      __label__ = 58;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    var $195 = __ZN10JSONParser5tokenENS_5TokenE(11);
    var $_0 = $195;
    __label__ = 66;
    break;
   case 58:
    var $_idx40_val = HEAP32[$12 >> 2];
    __ZN7mozilla9RangedPtrIKtEaSERKS2_($start, $_idx40_val);
    __label__ = 59;
    break;
   case 59:
    var $_idx2_val = HEAPU32[$12 >> 2];
    var $_idx3_val = HEAP32[$_idx16 >> 2];
    var $198 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($_idx2_val, $_idx3_val);
    if ($198) {
      __label__ = 60;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 60:
    var $200 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx2_val);
    var $201 = HEAPU16[$200 >> 1];
    if ($201 << 16 >> 16 == 34 || $201 << 16 >> 16 == 92) {
      __label__ = 64;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    if (($201 & 65535) < 32) {
      __label__ = 63;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 62:
    __ZN7mozilla9RangedPtrIKtEppEi($5, $6);
    __label__ = 59;
    break;
   case 63:
    if ($198) {
      __label__ = 64;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 64:
    var $_idx21_val = $_idx2_val;
    var $start_idx_val = HEAP32[$14 >> 2];
    __label__ = 13;
    break;
   case 65:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str282634 | 0);
    var $206 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $206;
    __label__ = 66;
    break;
   case 66:
    var $_0;
    __ZN2js12StringBufferD1Ev($buffer);
    var $_1 = $_0;
    __label__ = 67;
    break;
   case 67:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN10JSONParser10readStringILNS_10StringTypeE1EEENS_5TokenEv["X"] = 1;

function __ZNK7mozilla9RangedPtrIKtEixEi($this_0_0_val, $index) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this_0_0_val + ($index << 1) | 0;
  __ZNK7mozilla9RangedPtrIKtE6createEPS1_($1, $2);
  var $_idx_val = HEAP32[$1 >> 2];
  var $3 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx_val);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN10JSONParser22advanceAfterObjectOpenEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = $this + 4 | 0;
    var $_idx = $3 | 0;
    var $_idx1 = $this + 8 | 0;
    __label__ = 2;
    break;
   case 2:
    var $_idx_val = HEAP32[$_idx >> 2];
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $5 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($_idx_val, $_idx1_val);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $7 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx_val);
    var $8 = HEAP16[$7 >> 1];
    var $9 = __ZL16IsJSONWhitespacet($8);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN7mozilla9RangedPtrIKtEppEi($1, $3);
    __label__ = 2;
    break;
   case 5:
    var $11 = __ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE($_idx_val, $_idx1_val);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str102616 | 0);
    var $13 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $13;
    __label__ = 11;
    break;
   case 7:
    var $15 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx_val);
    var $16 = HEAP16[$15 >> 1];
    if ($16 << 16 >> 16 == 34) {
      __label__ = 8;
      break;
    } else if ($16 << 16 >> 16 == 125) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $18 = __ZN10JSONParser10readStringILNS_10StringTypeE0EEENS_5TokenEv($this);
    var $_0 = $18;
    __label__ = 11;
    break;
   case 9:
    __ZN7mozilla9RangedPtrIKtEppEi($2, $3);
    var $20 = __ZN10JSONParser5tokenENS_5TokenE(8);
    var $_0 = $20;
    __label__ = 11;
    break;
   case 10:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str112617 | 0);
    var $22 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $22;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSONParser10readStringILNS_10StringTypeE0EEENS_5TokenEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 104;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $start = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 8;
    var $buffer = __stackBase__ + 12;
    var $3 = __stackBase__ + 92;
    var $4 = __stackBase__ + 96;
    var $5 = __stackBase__ + 100;
    var $6 = $this + 4 | 0;
    var $7 = __ZN7mozilla9RangedPtrIKtEppEv($6);
    var $_idx15_val = HEAP32[$7 >> 2];
    var $_idx16 = $this + 8 | 0;
    var $_idx16_val = HEAP32[$_idx16 >> 2];
    var $8 = __ZNK7mozilla9RangedPtrIKtEeqIS1_EEbRKNS0_IT_EE($_idx15_val, $_idx16_val);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str232629 | 0);
    var $10 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_1 = $10;
    __label__ = 67;
    break;
   case 3:
    var $12 = $6 | 0;
    var $13 = HEAPU32[$12 >> 2];
    var $14 = $start | 0;
    HEAP32[$14 >> 2] = $13;
    var $_idx19_val = $13;
    var $_idx6_val = $_idx16_val;
    __label__ = 4;
    break;
   case 4:
    var $_idx6_val;
    var $_idx19_val;
    var $16 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($_idx19_val, $_idx6_val);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 5:
    var $18 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx19_val);
    var $19 = HEAPU16[$18 >> 1];
    if ($19 << 16 >> 16 == 34) {
      __label__ = 6;
      break;
    } else if ($19 << 16 >> 16 == 92) {
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $21 = __ZNK7mozilla9RangedPtrIKtEmiERKS2_($_idx19_val, $13);
    __ZN7mozilla9RangedPtrIKtEppEi($1, $6);
    var $23 = HEAP32[$this >> 2];
    var $24 = __ZNK7mozilla9RangedPtrIKtE3getEv($13);
    var $25 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($23, $24, $21, 0);
    if (($25 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $28 = __ZN10JSONParser5tokenENS_5TokenE(11);
    var $_1 = $28;
    __label__ = 67;
    break;
   case 8:
    var $30 = $25 | 0;
    __ZN10JSONParser11stringTokenEP8JSString($this, $30);
    var $_1 = 0;
    __label__ = 67;
    break;
   case 9:
    if (($19 & 65535) < 32) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str242630 | 0);
    var $34 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_1 = $34;
    __label__ = 67;
    break;
   case 11:
    __ZN7mozilla9RangedPtrIKtEppEi($2, $6);
    var $_idx19_val = HEAP32[$12 >> 2];
    var $_idx6_val = HEAP32[$_idx16 >> 2];
    __label__ = 4;
    break;
   case 12:
    var $38 = HEAP32[$this >> 2];
    __ZN2js12StringBufferC1EP9JSContext($buffer, $38);
    var $39 = $buffer;
    var $_idx9 = $3 | 0;
    var $_idx8 = $4 | 0;
    var $_idx21_val = HEAP32[$12 >> 2];
    var $start_idx_val = $13;
    __label__ = 13;
    break;
   case 13:
    var $start_idx_val;
    var $_idx21_val;
    var $41 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($start_idx_val, $_idx21_val);
    if ($41) {
      __label__ = 14;
      break;
    } else {
      var $_idx13_val = $_idx21_val;
      __label__ = 17;
      break;
    }
   case 14:
    var $43 = __ZNK7mozilla9RangedPtrIKtE3getEv($start_idx_val);
    var $44 = __ZNK7mozilla9RangedPtrIKtE3getEv($_idx21_val);
    var $45 = __ZN2js12StringBuffer6appendEPKtS2_($39, $43, $44);
    if ($45) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $_idx13_val = HEAP32[$12 >> 2];
    __label__ = 17;
    break;
   case 16:
    var $47 = __ZN10JSONParser5tokenENS_5TokenE(11);
    var $_0 = $47;
    __label__ = 66;
    break;
   case 17:
    var $_idx13_val;
    var $_idx14_val = HEAP32[$_idx16 >> 2];
    var $48 = __ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE($_idx13_val, $_idx14_val);
    if ($48) {
      __label__ = 65;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZN7mozilla9RangedPtrIKtEppEi($3, $6);
    var $_idx9_val = HEAP32[$_idx9 >> 2];
    var $50 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx9_val);
    var $51 = HEAP16[$50 >> 1];
    if ($51 << 16 >> 16 == 34) {
      __label__ = 19;
      break;
    } else if ($51 << 16 >> 16 == 92) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 19:
    var $53 = $buffer;
    var $54 = __ZN2js12StringBuffer10finishAtomEv($53);
    if (($54 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $57 = __ZN10JSONParser5tokenENS_5TokenE(11);
    var $_0 = $57;
    __label__ = 66;
    break;
   case 21:
    var $59 = $54 | 0;
    __ZN10JSONParser11stringTokenEP8JSString($this, $59);
    var $_0 = 0;
    __label__ = 66;
    break;
   case 22:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str252631 | 0);
    var $61 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $61;
    __label__ = 66;
    break;
   case 23:
    var $_idx11_val = HEAP32[$12 >> 2];
    var $_idx12_val = HEAP32[$_idx16 >> 2];
    var $63 = __ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE($_idx11_val, $_idx12_val);
    if ($63) {
      __label__ = 65;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    __ZN7mozilla9RangedPtrIKtEppEi($4, $6);
    var $_idx8_val = HEAP32[$_idx8 >> 2];
    var $65 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx8_val);
    var $67 = HEAPU16[$65 >> 1] & 65535;
    if (($67 | 0) == 47) {
      __label__ = 25;
      break;
    } else if (($67 | 0) == 92) {
      __label__ = 26;
      break;
    } else if (($67 | 0) == 98) {
      __label__ = 27;
      break;
    } else if (($67 | 0) == 102) {
      __label__ = 28;
      break;
    } else if (($67 | 0) == 110) {
      __label__ = 29;
      break;
    } else if (($67 | 0) == 114) {
      __label__ = 30;
      break;
    } else if (($67 | 0) == 116) {
      __label__ = 31;
      break;
    } else if (($67 | 0) == 117) {
      __label__ = 32;
      break;
    } else if (($67 | 0) == 34) {
      var $c_0 = 34;
      __label__ = 56;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 25:
    var $c_0 = 47;
    __label__ = 56;
    break;
   case 26:
    var $c_0 = 92;
    __label__ = 56;
    break;
   case 27:
    var $c_0 = 8;
    __label__ = 56;
    break;
   case 28:
    var $c_0 = 12;
    __label__ = 56;
    break;
   case 29:
    var $c_0 = 10;
    __label__ = 56;
    break;
   case 30:
    var $c_0 = 13;
    __label__ = 56;
    break;
   case 31:
    var $c_0 = 9;
    __label__ = 56;
    break;
   case 32:
    var $_idx17_val = HEAP32[$_idx16 >> 2];
    var $_idx18_val = HEAPU32[$12 >> 2];
    var $76 = __ZNK7mozilla9RangedPtrIKtEmiERKS2_($_idx17_val, $_idx18_val);
    if ($76 >>> 0 < 4) {
      __label__ = 33;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 33:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str262632 | 0);
    var $79 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $79;
    __label__ = 66;
    break;
   case 34:
    var $81 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx18_val, 0);
    if ((HEAPU16[$81 >> 1] & 65535) < 128) {
      __label__ = 35;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 35:
    var $_idx38_val = HEAP32[$12 >> 2];
    var $85 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx38_val, 0);
    var $87 = HEAPU16[$85 >> 1] & 65535;
    var $88 = _isxdigit($87);
    if (($88 | 0) == 0) {
      __label__ = 55;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $_idx37_val = HEAP32[$12 >> 2];
    var $91 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx37_val, 1);
    if ((HEAPU16[$91 >> 1] & 65535) < 128) {
      __label__ = 37;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 37:
    var $_idx36_val = HEAP32[$12 >> 2];
    var $95 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx36_val, 1);
    var $97 = HEAPU16[$95 >> 1] & 65535;
    var $98 = _isxdigit($97);
    if (($98 | 0) == 0) {
      __label__ = 55;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $_idx35_val = HEAP32[$12 >> 2];
    var $101 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx35_val, 2);
    if ((HEAPU16[$101 >> 1] & 65535) < 128) {
      __label__ = 39;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 39:
    var $_idx34_val = HEAP32[$12 >> 2];
    var $105 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx34_val, 2);
    var $107 = HEAPU16[$105 >> 1] & 65535;
    var $108 = _isxdigit($107);
    if (($108 | 0) == 0) {
      __label__ = 55;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $_idx33_val = HEAP32[$12 >> 2];
    var $111 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx33_val, 3);
    if ((HEAPU16[$111 >> 1] & 65535) < 128) {
      __label__ = 41;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 41:
    var $_idx32_val = HEAP32[$12 >> 2];
    var $115 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx32_val, 3);
    var $117 = HEAPU16[$115 >> 1] & 65535;
    var $118 = _isxdigit($117);
    if (($118 | 0) == 0) {
      __label__ = 55;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $_idx31_val = HEAP32[$12 >> 2];
    var $121 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx31_val, 0);
    var $125 = ((HEAPU16[$121 >> 1] & 65535) - 48 | 0) >>> 0 < 10;
    var $_idx30_val = HEAP32[$12 >> 2];
    var $126 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx30_val, 0);
    var $128 = HEAPU16[$126 >> 1] & 65535;
    if ($125) {
      __label__ = 43;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 43:
    var $135 = $128 - 48 | 0;
    __label__ = 45;
    break;
   case 44:
    var $132 = _tolower($128);
    var $135 = $132 - 87 | 0;
    __label__ = 45;
    break;
   case 45:
    var $135;
    var $136 = $135 << 12;
    var $_idx29_val = HEAP32[$12 >> 2];
    var $137 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx29_val, 1);
    var $141 = ((HEAPU16[$137 >> 1] & 65535) - 48 | 0) >>> 0 < 10;
    var $_idx28_val = HEAP32[$12 >> 2];
    var $142 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx28_val, 1);
    var $144 = HEAPU16[$142 >> 1] & 65535;
    if ($141) {
      __label__ = 46;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 46:
    var $151 = $144 - 48 | 0;
    __label__ = 48;
    break;
   case 47:
    var $148 = _tolower($144);
    var $151 = $148 - 87 | 0;
    __label__ = 48;
    break;
   case 48:
    var $151;
    var $152 = $151 << 8;
    var $_idx27_val = HEAP32[$12 >> 2];
    var $153 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx27_val, 2);
    var $157 = ((HEAPU16[$153 >> 1] & 65535) - 48 | 0) >>> 0 < 10;
    var $_idx26_val = HEAP32[$12 >> 2];
    var $158 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx26_val, 2);
    var $160 = HEAPU16[$158 >> 1] & 65535;
    if ($157) {
      __label__ = 49;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 49:
    var $167 = $160 - 48 | 0;
    __label__ = 51;
    break;
   case 50:
    var $164 = _tolower($160);
    var $167 = $164 - 87 | 0;
    __label__ = 51;
    break;
   case 51:
    var $167;
    var $168 = $167 << 4;
    var $_idx25_val = HEAP32[$12 >> 2];
    var $169 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx25_val, 3);
    var $173 = ((HEAPU16[$169 >> 1] & 65535) - 48 | 0) >>> 0 < 10;
    var $_idx24_val = HEAP32[$12 >> 2];
    var $174 = __ZNK7mozilla9RangedPtrIKtEixEi($_idx24_val, 3);
    var $176 = HEAPU16[$174 >> 1] & 65535;
    if ($173) {
      __label__ = 52;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 52:
    var $183 = $176 - 48 | 0;
    __label__ = 54;
    break;
   case 53:
    var $180 = _tolower($176);
    var $183 = $180 - 87 | 0;
    __label__ = 54;
    break;
   case 54:
    var $183;
    var $187 = ($152 | $136 | $168 | $183) & 65535;
    var $188 = __ZN7mozilla9RangedPtrIKtEpLEj($6, 4);
    var $c_0 = $187;
    __label__ = 56;
    break;
   case 55:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str272633 | 0);
    var $190 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $190;
    __label__ = 66;
    break;
   case 56:
    var $c_0;
    var $192 = __ZN2js12StringBuffer6appendEt($buffer, $c_0);
    if ($192) {
      __label__ = 58;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    var $194 = __ZN10JSONParser5tokenENS_5TokenE(11);
    var $_0 = $194;
    __label__ = 66;
    break;
   case 58:
    var $_idx40_val = HEAP32[$12 >> 2];
    __ZN7mozilla9RangedPtrIKtEaSERKS2_($start, $_idx40_val);
    __label__ = 59;
    break;
   case 59:
    var $_idx2_val = HEAPU32[$12 >> 2];
    var $_idx3_val = HEAP32[$_idx16 >> 2];
    var $197 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($_idx2_val, $_idx3_val);
    if ($197) {
      __label__ = 60;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 60:
    var $199 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx2_val);
    var $200 = HEAPU16[$199 >> 1];
    if ($200 << 16 >> 16 == 34 || $200 << 16 >> 16 == 92) {
      __label__ = 64;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    if (($200 & 65535) < 32) {
      __label__ = 63;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 62:
    __ZN7mozilla9RangedPtrIKtEppEi($5, $6);
    __label__ = 59;
    break;
   case 63:
    if ($197) {
      __label__ = 64;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 64:
    var $_idx21_val = $_idx2_val;
    var $start_idx_val = HEAP32[$14 >> 2];
    __label__ = 13;
    break;
   case 65:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str282634 | 0);
    var $205 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $205;
    __label__ = 66;
    break;
   case 66:
    var $_0;
    __ZN2js12StringBufferD1Ev($buffer);
    var $_1 = $_0;
    __label__ = 67;
    break;
   case 67:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN10JSONParser10readStringILNS_10StringTypeE0EEENS_5TokenEv["X"] = 1;

function __ZN10JSONParser24advanceAfterArrayElementEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = __stackBase__ + 8;
    var $4 = $this + 4 | 0;
    var $_idx = $4 | 0;
    var $_idx1 = $this + 8 | 0;
    __label__ = 2;
    break;
   case 2:
    var $_idx_val = HEAP32[$_idx >> 2];
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $6 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($_idx_val, $_idx1_val);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $8 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx_val);
    var $9 = HEAP16[$8 >> 1];
    var $10 = __ZL16IsJSONWhitespacet($9);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN7mozilla9RangedPtrIKtEppEi($1, $4);
    __label__ = 2;
    break;
   case 5:
    var $12 = __ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE($_idx_val, $_idx1_val);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str122618 | 0);
    var $14 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $14;
    __label__ = 11;
    break;
   case 7:
    var $16 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx_val);
    var $17 = HEAP16[$16 >> 1];
    if ($17 << 16 >> 16 == 44) {
      __label__ = 8;
      break;
    } else if ($17 << 16 >> 16 == 93) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    __ZN7mozilla9RangedPtrIKtEppEi($2, $4);
    var $19 = __ZN10JSONParser5tokenENS_5TokenE(10);
    var $_0 = $19;
    __label__ = 11;
    break;
   case 9:
    __ZN7mozilla9RangedPtrIKtEppEi($3, $4);
    var $21 = __ZN10JSONParser5tokenENS_5TokenE(6);
    var $_0 = $21;
    __label__ = 11;
    break;
   case 10:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str132619 | 0);
    var $23 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $23;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSONParser19advancePropertyNameEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = $this + 4 | 0;
    var $_idx = $3 | 0;
    var $_idx1 = $this + 8 | 0;
    __label__ = 2;
    break;
   case 2:
    var $_idx_val = HEAP32[$_idx >> 2];
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $5 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($_idx_val, $_idx1_val);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $7 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx_val);
    var $8 = HEAP16[$7 >> 1];
    var $9 = __ZL16IsJSONWhitespacet($8);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN7mozilla9RangedPtrIKtEppEi($1, $3);
    __label__ = 2;
    break;
   case 5:
    var $11 = __ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE($_idx_val, $_idx1_val);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str142620 | 0);
    var $13 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $13;
    __label__ = 12;
    break;
   case 7:
    var $15 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx_val);
    var $16 = HEAP16[$15 >> 1];
    if ($16 << 16 >> 16 == 34) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $19 = __ZN10JSONParser10readStringILNS_10StringTypeE0EEENS_5TokenEv($this);
    var $_0 = $19;
    __label__ = 12;
    break;
   case 9:
    if ((HEAP32[$this + 24 >> 2] | 0) == 1 & $16 << 16 >> 16 == 125) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    __ZN7mozilla9RangedPtrIKtEppEi($2, $3);
    var $26 = __ZN10JSONParser5tokenENS_5TokenE(8);
    var $_0 = $26;
    __label__ = 12;
    break;
   case 11:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str152621 | 0);
    var $28 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $28;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSONParser20advancePropertyColonEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = $this + 4 | 0;
    var $_idx = $3 | 0;
    var $_idx1 = $this + 8 | 0;
    __label__ = 2;
    break;
   case 2:
    var $_idx_val = HEAP32[$_idx >> 2];
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $5 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($_idx_val, $_idx1_val);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $7 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx_val);
    var $8 = HEAP16[$7 >> 1];
    var $9 = __ZL16IsJSONWhitespacet($8);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN7mozilla9RangedPtrIKtEppEi($1, $3);
    __label__ = 2;
    break;
   case 5:
    var $11 = __ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE($_idx_val, $_idx1_val);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str162622 | 0);
    var $13 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $13;
    __label__ = 10;
    break;
   case 7:
    var $15 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx_val);
    if (HEAP16[$15 >> 1] << 16 >> 16 == 58) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    __ZN7mozilla9RangedPtrIKtEppEi($2, $3);
    var $19 = __ZN10JSONParser5tokenENS_5TokenE(9);
    var $_0 = $19;
    __label__ = 10;
    break;
   case 9:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str172623 | 0);
    var $21 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $21;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSONParser20advanceAfterPropertyEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = __stackBase__ + 8;
    var $4 = $this + 4 | 0;
    var $_idx = $4 | 0;
    var $_idx1 = $this + 8 | 0;
    __label__ = 2;
    break;
   case 2:
    var $_idx_val = HEAP32[$_idx >> 2];
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $6 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($_idx_val, $_idx1_val);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $8 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx_val);
    var $9 = HEAP16[$8 >> 1];
    var $10 = __ZL16IsJSONWhitespacet($9);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN7mozilla9RangedPtrIKtEppEi($1, $4);
    __label__ = 2;
    break;
   case 5:
    var $12 = __ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE($_idx_val, $_idx1_val);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str182624 | 0);
    var $14 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $14;
    __label__ = 11;
    break;
   case 7:
    var $16 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx_val);
    var $17 = HEAP16[$16 >> 1];
    if ($17 << 16 >> 16 == 44) {
      __label__ = 8;
      break;
    } else if ($17 << 16 >> 16 == 125) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    __ZN7mozilla9RangedPtrIKtEppEi($2, $4);
    var $19 = __ZN10JSONParser5tokenENS_5TokenE(10);
    var $_0 = $19;
    __label__ = 11;
    break;
   case 9:
    __ZN7mozilla9RangedPtrIKtEppEi($3, $4);
    var $21 = __ZN10JSONParser5tokenENS_5TokenE(8);
    var $_0 = $21;
    __label__ = 11;
    break;
   case 10:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str192625 | 0);
    var $23 = __ZN10JSONParser5tokenENS_5TokenE(12);
    var $_0 = $23;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js7MoveRefI11ParserStateEcvRS1_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZL14JSID_FROM_BITSj2665($bits) {
  return $bits;
}

function __ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE5emptyEv($this_0_2_val) {
  return ($this_0_2_val | 0) == 0;
}

function __ZNK10JSONParser11stringValueEv($agg_result, $this_0_4_0_0_val$0, $this_0_4_0_0_val$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $this_0_4_0_0_val$0;
  HEAP32[$1 + 4 >> 2] = $this_0_4_0_0_val$1;
  return;
}

function __ZNK10JSONParser11numberValueEv($agg_result, $this_0_4_0_0_val$0, $this_0_4_0_0_val$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $this_0_4_0_0_val$0;
  HEAP32[$1 + 4 >> 2] = $this_0_4_0_0_val$1;
  return;
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE7popBackEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZN2js7MoveRefI11ParserStateEC2ERS1_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN7mozilla9RangedPtrIKtEaSERKS2_($this, $other_0_0_val) {
  HEAP32[$this >> 2] = $other_0_0_val;
  return;
}

function __ZN2js2gcL15GetGCObjectKindEjb2650($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSONParser5parseEPN2JS5ValueE($this, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 212;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stateStack = __stackBase__;
    var $1 = __stackBase__ + 24;
    var $valueStack = __stackBase__ + 28;
    var $2 = __stackBase__ + 120;
    var $v = __stackBase__ + 128;
    var $3 = __stackBase__ + 136;
    var $4 = __stackBase__ + 144;
    var $v1 = __stackBase__ + 152;
    var $5 = __stackBase__ + 160;
    var $6 = __stackBase__ + 168;
    var $7 = __stackBase__ + 176;
    var $8 = __stackBase__ + 184;
    var $9 = __stackBase__ + 192;
    var $10 = __stackBase__ + 200;
    var $11 = __stackBase__ + 208;
    var $12 = $this | 0;
    var $13 = HEAP32[$12 >> 2];
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $13);
    var $_03_val = HEAP32[$1 >> 2];
    __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEEC1ES2_($stateStack, $_03_val);
    var $14 = HEAP32[$12 >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($valueStack, $14);
    __ZN2JSL14UndefinedValueEv2637($2);
    var $15 = $2 | 0;
    var $16$0 = HEAP32[$15 >> 2];
    var $16$1 = HEAP32[$15 + 4 >> 2];
    var $17 = $vp | 0;
    HEAP32[$17 >> 2] = $16$0;
    HEAP32[$17 + 4 >> 2] = $16$1;
    var $18 = $valueStack | 0;
    var $19 = $this + 24 | 0;
    var $stateStack_idx = $stateStack + 8 | 0;
    var $_idx2 = $3 | 0;
    var $this_idx14 = $this + 16 | 0;
    var $_idx25 = $4 | 0;
    var $_idx20 = $9 | 0;
    var $_idx23 = $6 | 0;
    var $_idx22 = $7 | 0;
    var $_idx21 = $8 | 0;
    var $_idx19 = $10 | 0;
    var $stateStack_idx17 = $stateStack + 4 | 0;
    var $_idx24 = $5 | 0;
    var $state_0 = 2;
    __label__ = 2;
    break;
   case 2:
    var $state_0;
    if (($state_0 | 0) == 1) {
      __label__ = 3;
      break;
    } else if (($state_0 | 0) == 0) {
      __label__ = 15;
      break;
    } else if (($state_0 | 0) == 2) {
      __label__ = 19;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 3:
    __ZN2js16AutoVectorRooterIN2JS5ValueEE7popCopyEv($v, $18);
    __ZN2js16AutoVectorRooterIN2JS5ValueEE7popCopyEv($3, $18);
    var $st$2$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$2$1 >> 2];
    var $22 = __ZNK2JS5Value8toStringEv($_idx2_val$0, $_idx2_val$1);
    var $23 = __ZNK8JSString6asAtomEv($22);
    var $24 = __ZL12ATOM_TO_JSIDP6JSAtom2638($23);
    var $25 = HEAP32[$12 >> 2];
    var $26 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE4backEv($18);
    var $_idx1 = $26 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $27 = __ZNK2JS5Value8toObjectEv($_idx1_val$0, $_idx1_val$1);
    var $28 = $25;
    var $29 = $27;
    var $30 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($28, $29, $24, $v, 10, 12, 1, 0, 0, 0);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $33 = __ZN10JSONParser20advanceAfterPropertyEv($this);
    if (($33 | 0) == 12) {
      __label__ = 6;
      break;
    } else if (($33 | 0) == 10) {
      __label__ = 7;
      break;
    } else if (($33 | 0) == 8) {
      __label__ = 40;
      break;
    } else if (($33 | 0) == 11) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str202626 | 0);
    __label__ = 6;
    break;
   case 6:
    var $this_idx12_val = HEAP32[$this + 28 >> 2];
    var $35 = __ZN10JSONParser11errorReturnEv($this_idx12_val);
    var $_0 = $35;
    __label__ = 48;
    break;
   case 7:
    var $37 = __ZN10JSONParser19advancePropertyNameEv($this);
    var $token_0 = $37;
    __label__ = 8;
    break;
   case 8:
    var $token_0;
    if (($token_0 | 0) == 0) {
      __label__ = 9;
      break;
    } else if (($token_0 | 0) == 12) {
      __label__ = 14;
      break;
    } else if (($token_0 | 0) == 8) {
      __label__ = 40;
      break;
    } else if (($token_0 | 0) == 11) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 9:
    var $st$0$0 = $this_idx14 | 0;
    var $this_idx14_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $this_idx14 + 4 | 0;
    var $this_idx14_val$1 = HEAP32[$st$0$1 >> 2];
    __ZNK10JSONParser9atomValueEv($4, $this_idx14_val$0, $this_idx14_val$1);
    var $_idx25_val$0 = HEAP32[$_idx25 >> 2];
    var $_idx25_val$1 = HEAP32[$_idx25 + 4 >> 2];
    var $40 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($18, $_idx25_val$0, $_idx25_val$1);
    if ($40) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 48;
      break;
    }
   case 10:
    var $42 = __ZN10JSONParser20advancePropertyColonEv($this);
    if (($42 | 0) == 9) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $this_idx11_val = HEAP32[$this + 28 >> 2];
    var $45 = __ZN10JSONParser11errorReturnEv($this_idx11_val);
    var $_0 = $45;
    __label__ = 48;
    break;
   case 12:
    var $47 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE6appendIS1_EEbT_($stateStack, 1);
    if ($47) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 48;
      break;
    }
   case 13:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str212627 | 0);
    __label__ = 14;
    break;
   case 14:
    var $this_idx10_val = HEAP32[$this + 28 >> 2];
    var $49 = __ZN10JSONParser11errorReturnEv($this_idx10_val);
    var $_0 = $49;
    __label__ = 48;
    break;
   case 15:
    __ZN2js16AutoVectorRooterIN2JS5ValueEE7popCopyEv($v1, $18);
    var $51 = HEAP32[$12 >> 2];
    var $52 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE4backEv($18);
    var $_idx = $52 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $53 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $54 = __Z19js_NewbornArrayPushP9JSContextP8JSObjectRKN2JS5ValueE($51, $53, $v1);
    if (($54 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $57 = __ZN10JSONParser24advanceAfterArrayElementEv($this);
    if (($57 | 0) == 10) {
      __label__ = 17;
      break;
    } else if (($57 | 0) == 6) {
      __label__ = 40;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $59 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE6appendIS1_EEbT_($stateStack, 0);
    if ($59) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 48;
      break;
    }
   case 18:
    var $this_idx9_val = HEAP32[$this + 28 >> 2];
    var $61 = __ZN10JSONParser11errorReturnEv($this_idx9_val);
    var $_0 = $61;
    __label__ = 48;
    break;
   case 19:
    var $63 = __ZN10JSONParser7advanceEv($this);
    var $token_1 = $63;
    __label__ = 20;
    break;
   case 20:
    var $token_1;
    if (($token_1 | 0) == 0) {
      __label__ = 21;
      break;
    } else if (($token_1 | 0) == 1) {
      __label__ = 22;
      break;
    } else if (($token_1 | 0) == 2) {
      __label__ = 24;
      break;
    } else if (($token_1 | 0) == 3) {
      __label__ = 25;
      break;
    } else if (($token_1 | 0) == 4) {
      __label__ = 26;
      break;
    } else if (($token_1 | 0) == 5) {
      __label__ = 27;
      break;
    } else if (($token_1 | 0) == 7) {
      __label__ = 31;
      break;
    } else if (($token_1 | 0) == 6) {
      __label__ = 34;
      break;
    } else if (($token_1 | 0) == 8 || ($token_1 | 0) == 9 || ($token_1 | 0) == 10) {
      __label__ = 38;
      break;
    } else if (($token_1 | 0) == 12) {
      __label__ = 39;
      break;
    } else if (($token_1 | 0) == 11) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 21:
    var $st$0$0 = $this_idx14 | 0;
    var $this_idx13_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $this_idx14 + 4 | 0;
    var $this_idx13_val$1 = HEAP32[$st$0$1 >> 2];
    __ZNK10JSONParser11stringValueEv($5, $this_idx13_val$0, $this_idx13_val$1);
    __label__ = 23;
    break;
   case 22:
    var $st$0$0 = $this_idx14 | 0;
    var $this_idx15_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $this_idx14 + 4 | 0;
    var $this_idx15_val$1 = HEAP32[$st$0$1 >> 2];
    __ZNK10JSONParser11numberValueEv($5, $this_idx15_val$0, $this_idx15_val$1);
    __label__ = 23;
    break;
   case 23:
    var $st$0$0 = $_idx24 | 0;
    var $_idx24_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $_idx24 + 4 | 0;
    var $_idx24_val$1 = HEAP32[$st$0$1 >> 2];
    var $68 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($18, $_idx24_val$0, $_idx24_val$1);
    if ($68) {
      __label__ = 40;
      break;
    } else {
      var $_0 = 0;
      __label__ = 48;
      break;
    }
   case 24:
    __ZN2JSL12BooleanValueEb2639($6, 1);
    var $st$1$0 = $_idx23 | 0;
    var $_idx23_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx23 + 4 | 0;
    var $_idx23_val$1 = HEAP32[$st$1$1 >> 2];
    var $70 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($18, $_idx23_val$0, $_idx23_val$1);
    if ($70) {
      __label__ = 40;
      break;
    } else {
      var $_0 = 0;
      __label__ = 48;
      break;
    }
   case 25:
    __ZN2JSL12BooleanValueEb2639($7, 0);
    var $st$1$0 = $_idx22 | 0;
    var $_idx22_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx22 + 4 | 0;
    var $_idx22_val$1 = HEAP32[$st$1$1 >> 2];
    var $72 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($18, $_idx22_val$0, $_idx22_val$1);
    if ($72) {
      __label__ = 40;
      break;
    } else {
      var $_0 = 0;
      __label__ = 48;
      break;
    }
   case 26:
    __ZN2JSL9NullValueEv2640($8);
    var $st$1$0 = $_idx21 | 0;
    var $_idx21_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx21 + 4 | 0;
    var $_idx21_val$1 = HEAP32[$st$1$1 >> 2];
    var $74 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($18, $_idx21_val$0, $_idx21_val$1);
    if ($74) {
      __label__ = 40;
      break;
    } else {
      var $_0 = 0;
      __label__ = 48;
      break;
    }
   case 27:
    var $76 = HEAP32[$12 >> 2];
    var $77 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($76);
    if (($77 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    __ZN2JSL11ObjectValueER8JSObject2641($9, $77);
    var $st$1$0 = $_idx20 | 0;
    var $_idx20_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx20 + 4 | 0;
    var $_idx20_val$1 = HEAP32[$st$1$1 >> 2];
    var $80 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($18, $_idx20_val$0, $_idx20_val$1);
    if ($80) {
      __label__ = 29;
      break;
    } else {
      var $_0 = 0;
      __label__ = 48;
      break;
    }
   case 29:
    var $82 = __ZN10JSONParser7advanceEv($this);
    if (($82 | 0) == 6) {
      __label__ = 40;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $85 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE6appendIS1_EEbT_($stateStack, 0);
    if ($85) {
      var $token_1 = $82;
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 48;
      break;
    }
   case 31:
    var $87 = HEAP32[$12 >> 2];
    var $88 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2642($87);
    if (($88 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    __ZN2JSL11ObjectValueER8JSObject2641($10, $88);
    var $st$1$0 = $_idx19 | 0;
    var $_idx19_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx19 + 4 | 0;
    var $_idx19_val$1 = HEAP32[$st$1$1 >> 2];
    var $91 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($18, $_idx19_val$0, $_idx19_val$1);
    if ($91) {
      __label__ = 33;
      break;
    } else {
      var $_0 = 0;
      __label__ = 48;
      break;
    }
   case 33:
    var $93 = __ZN10JSONParser22advanceAfterObjectOpenEv($this);
    if (($93 | 0) == 8) {
      __label__ = 40;
      break;
    } else {
      var $token_0 = $93;
      __label__ = 8;
      break;
    }
   case 34:
    if ((HEAP32[$19 >> 2] | 0) == 1) {
      __label__ = 35;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 35:
    var $stateStack_idx16_val = HEAP32[$stateStack_idx >> 2];
    var $99 = __ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE5emptyEv($stateStack_idx16_val);
    if ($99) {
      __label__ = 38;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $stateStack_idx17_val = HEAP32[$stateStack_idx17 >> 2];
    var $101 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE4backEv($stateStack_idx17_val, $stateStack_idx16_val);
    if ((HEAP32[$101 >> 2] | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 37:
    __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE7popBackEv($stateStack);
    __label__ = 40;
    break;
   case 38:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str92615 | 0);
    var $this_idx8_val = HEAP32[$this + 28 >> 2];
    var $105 = __ZN10JSONParser11errorReturnEv($this_idx8_val);
    var $_0 = $105;
    __label__ = 48;
    break;
   case 39:
    var $this_idx7_val = HEAP32[$this + 28 >> 2];
    var $107 = __ZN10JSONParser11errorReturnEv($this_idx7_val);
    var $_0 = $107;
    __label__ = 48;
    break;
   case 40:
    var $stateStack_idx_val = HEAP32[$stateStack_idx >> 2];
    var $108 = __ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE5emptyEv($stateStack_idx_val);
    if ($108) {
      __label__ = 41;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 41:
    var $109 = $this + 4 | 0;
    var $_idx4 = $109 | 0;
    var $_idx5 = $this + 8 | 0;
    __label__ = 43;
    break;
   case 42:
    var $111 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE7popCopyEv($stateStack);
    var $state_0 = $111;
    __label__ = 2;
    break;
   case 43:
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $_idx5_val = HEAP32[$_idx5 >> 2];
    var $113 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($_idx4_val, $_idx5_val);
    if ($113) {
      __label__ = 44;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 44:
    var $115 = __ZNK7mozilla9RangedPtrIKtEdeEv($_idx4_val);
    var $116 = HEAP16[$115 >> 1];
    var $117 = __ZL16IsJSONWhitespacet($116);
    if ($117) {
      __label__ = 46;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str222628 | 0);
    var $this_idx_val = HEAP32[$this + 28 >> 2];
    var $119 = __ZN10JSONParser11errorReturnEv($this_idx_val);
    var $_0 = $119;
    __label__ = 48;
    break;
   case 46:
    __ZN7mozilla9RangedPtrIKtEppEi($11, $109);
    __label__ = 43;
    break;
   case 47:
    var $122 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($18, 0);
    var $123 = $122 | 0;
    var $st$2$0 = $123 | 0;
    var $124$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $123 + 4 | 0;
    var $124$1 = HEAP32[$st$2$1 >> 2];
    HEAP32[$17 >> 2] = $124$0;
    HEAP32[$17 + 4 >> 2] = $124$1;
    var $_0 = 1;
    __label__ = 48;
    break;
   case 48:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($valueStack);
    __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEED1Ev($stateStack);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN10JSONParser5parseEPN2JS5ValueE["X"] = 1;

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEEC1ES2_($this, $ap_01) {
  __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEEC2ES2_($this, $ap_01);
  return;
}

function __ZN2JSL14UndefinedValueEv2637($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEE7popCopyEv($agg_result, $this) {
  var $1 = $this + 12 | 0;
  __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE7popCopyEv($agg_result, $1);
  return;
}

function __ZL12ATOM_TO_JSIDP6JSAtom2638($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj2665($1);
  return $2;
}

function __ZNK10JSONParser9atomValueEv($agg_result, $this_0_4_0_0_val$0, $this_0_4_0_0_val$1) {
  __ZNK10JSONParser11stringValueEv($agg_result, $this_0_4_0_0_val$0, $this_0_4_0_0_val$1);
  return;
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE6appendIS1_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE13growStorageByEj($this);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE14internalAppendIS1_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL12BooleanValueEb2639($agg_result, $boo) {
  __ZN2JS5Value10setBooleanEb($agg_result, $boo);
  return;
}

function __ZN2JSL9NullValueEv2640($agg_result) {
  __ZN2JS5Value7setNullEv($agg_result);
  return;
}

function __ZN2JSL11ObjectValueER8JSObject2641($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2642($cx) {
  var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb2650($3);
  var $5 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2651($cx, $4);
  return $5;
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE4backEv($this_0_1_val, $this_0_2_val) {
  var $1 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val);
  return $1 - 4 | 0;
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE7popCopyEv($this) {
  var $this_idx_val = HEAP32[$this + 4 >> 2];
  var $this_idx1_val = HEAP32[$this + 8 >> 2];
  var $1 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE4backEv($this_idx_val, $this_idx1_val);
  var $2 = HEAP32[$1 >> 2];
  __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE7popBackEv($this);
  return $2;
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE13growStorageByEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE14internalAppendIS1_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $5 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    var $5 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    HEAP32[$this_idx1 >> 2] = $5 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 2;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplI11ParserStateLj0ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplI11ParserStateLj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj0ES2_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, 1);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplI11ParserStateLj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj0ES2_EEj($v, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $v | 0;
    var $3 = $newcap << 2;
    var $4 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $v_idx = $v + 4 | 0;
    var $v_idx_val = HEAP32[$v_idx >> 2];
    var $8 = __ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($v_idx_val);
    var $v_idx4 = $v + 8 | 0;
    var $v_idx4_val = HEAP32[$v_idx4 >> 2];
    var $9 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE10endNoCheckEv($v_idx_val, $v_idx4_val);
    if (($8 | 0) == ($9 | 0)) {
      var $20 = $v_idx_val;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx = $1 | 0;
    var $dst_01 = $5;
    var $src_02 = $8;
    var $v_idx1_val5 = $v_idx_val;
    var $v_idx2_val7 = $v_idx4_val;
    __label__ = 4;
    break;
   case 4:
    var $v_idx2_val7;
    var $v_idx1_val5;
    var $src_02;
    var $dst_01;
    if (($dst_01 | 0) == 0) {
      var $v_idx1_val = $v_idx1_val5;
      var $v_idx2_val = $v_idx2_val7;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js4MoveI11ParserStateEENS_7MoveRefIT_EERS3_($1, $src_02);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $13 = __ZNK2js7MoveRefI11ParserStateEcvRS1_Ev($_idx_val);
    var $14 = HEAP32[$13 >> 2];
    HEAP32[$dst_01 >> 2] = $14;
    var $v_idx1_val = HEAP32[$v_idx >> 2];
    var $v_idx2_val = HEAP32[$v_idx4 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $v_idx2_val;
    var $v_idx1_val;
    var $16 = $dst_01 + 4 | 0;
    var $17 = $src_02 + 4 | 0;
    var $18 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE10endNoCheckEv($v_idx1_val, $v_idx2_val);
    if (($17 | 0) == ($18 | 0)) {
      var $20 = $v_idx1_val;
      __label__ = 7;
      break;
    } else {
      var $dst_01 = $16;
      var $src_02 = $17;
      var $v_idx1_val5 = $v_idx1_val;
      var $v_idx2_val7 = $v_idx2_val;
      __label__ = 4;
      break;
    }
   case 7:
    var $20;
    __ZN2js15TempAllocPolicy5free_EPv($20);
    HEAP32[$v_idx >> 2] = $5;
    HEAP32[$v + 12 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveI11ParserStateEENS_7MoveRefIT_EERS3_($agg_result, $t) {
  __ZN2js7MoveRefI11ParserStateEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefI11ParserStateEC1ERS1_($this, $t) {
  __ZN2js7MoveRefI11ParserStateEC2ERS1_($this, $t);
  return;
}

function __ZN2js10VectorImplI11ParserStateLj0ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_($dst, $srcbeg, $srcend) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx = $1 | 0;
    var $p_01 = $srcbeg;
    var $_02 = $dst;
    __label__ = 3;
    break;
   case 3:
    var $_02;
    var $p_01;
    if (($_02 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js4MoveI11ParserStateEENS_7MoveRefIT_EERKS3_($1, $p_01);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $5 = __ZNK2js7MoveRefI11ParserStateEcvRS1_Ev($_idx_val);
    var $6 = HEAP32[$5 >> 2];
    HEAP32[$_02 >> 2] = $6;
    __label__ = 5;
    break;
   case 5:
    var $8 = $p_01 + 4 | 0;
    if (($8 | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      var $p_01 = $8;
      var $_02 = $_02 + 4 | 0;
      __label__ = 3;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveI11ParserStateEENS_7MoveRefIT_EERKS3_($agg_result, $t) {
  __ZN2js7MoveRefI11ParserStateEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE7popCopyEv($agg_result, $this) {
  var $this_idx_val = HEAP32[$this + 4 >> 2];
  var $this_idx1_val = HEAP32[$this + 8 >> 2];
  var $1 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE4backEv($this_idx_val, $this_idx1_val);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $agg_result | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE7popBackEv($this);
  return;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE4backEv($this_0_1_val, $this_0_2_val) {
  var $1 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val);
  return $1 - 8 | 0;
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEEC2ES2_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZN10JSONParser11stringTokenEP8JSString($this, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL11StringValueEP8JSString2648($1, $str);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this + 16 | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2JSL11StringValueEP8JSString2648($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2651($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 24;
    var $4 = __ZNK9JSContext5hasfpEv($cx);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $7;
    var $8 = $cx;
    var $9 = $global;
    var $10 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($8, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $18 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZNK9JSContext2fpEv($cx);
    var $13 = __ZNK2js10StackFrame10scopeChainEv($12);
    var $14 = $13;
    var $15 = __ZNK8JSObject9getGlobalEv($14);
    var $16 = $15;
    HEAP32[$global >> 2] = $16;
    var $18 = $16;
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $18, $19);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $20 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    HEAP32[$proto >> 2] = $22;
    var $29 = $22;
    __label__ = 9;
    break;
   case 7:
    var $24 = $cx;
    var $26 = $proto;
    var $27 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($24, $18, $3, $26, __ZN2js11ObjectClassE);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $29 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $29;
    var $30 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2652($cx, $29, $18, $kind);
    var $_0 = $30;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2652($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, __ZN2js11ObjectClassE, $1, $parent, 0, (__ZN2js11ObjectClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $7 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, __ZN2js11ObjectClassE, $kind);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $10);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11NumberValueEd2666($agg_result, $dbl) {
  var $1 = __ZN2JS5Value9setNumberEd($agg_result, $dbl);
  return;
}

function _js_GetIndexFromBytecode($script, $pc, $pcoff) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2825($script, $pc);
    var $4 = HEAP8[_js_CodeSpec + ($1 << 3) | 0] << 24 >> 24;
    if (($4 + $pc - HEAP32[$script >> 2] | 0) >>> 0 < HEAPU32[$script + 8 >> 2] >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $base_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $15 = $pc + $4 | 0;
    var $16 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2825($script, $15);
    if (($16 | 0) == 192) {
      __label__ = 3;
      break;
    } else if (($16 | 0) == 193) {
      __label__ = 4;
      break;
    } else {
      var $base_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $base_0 = (HEAPU8[$pc - 1 | 0] & 255) << 16;
    __label__ = 5;
    break;
   case 4:
    var $23 = $pc - 1 | 0;
    var $24 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2825($script, $23);
    var $base_0 = ($24 << 16) - 13762560 | 0;
    __label__ = 5;
    break;
   case 5:
    var $base_0;
    return HEAPU8[$pcoff + ($pc + 2) | 0] & 255 | $base_0 | (HEAPU8[$pcoff + ($pc + 1) | 0] & 255) << 8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2825($script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU8[$pc];
    var $2 = $1 & 255;
    if ($1 << 24 >> 24 == 83) {
      __label__ = 2;
      break;
    } else {
      var $op_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $script;
    var $6 = _JS_GetTrapOpcode($5, $pc);
    var $op_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $op_0;
    return $op_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z28js_GetVariableBytecodeLength4JSOpPh($op, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($op | 0) == 70) {
      __label__ = 2;
      break;
    } else if (($op | 0) == 149) {
      var $jmplen_0 = 4;
      __label__ = 3;
      break;
    } else if (($op | 0) == 150) {
      var $jmplen_1 = 4;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $jmplen_0 = 2;
    __label__ = 3;
    break;
   case 3:
    var $jmplen_0;
    var $_sum23 = $jmplen_0 | 1;
    var $_0 = $_sum23 + 4 + (1 - (((HEAPU8[$pc + $_sum23 | 0] & 255) << 8 | HEAPU8[$jmplen_0 + ($pc + 2) | 0] & 255) << 16 >> 16) + (((HEAPU8[$jmplen_0 + ($pc + 3) | 0] & 255) << 8 | HEAPU8[$jmplen_0 + ($pc + 4) | 0] & 255) << 16 >> 16)) * $jmplen_0 | 0;
    __label__ = 6;
    break;
   case 4:
    var $jmplen_1 = 2;
    __label__ = 5;
    break;
   case 5:
    var $jmplen_1;
    var $_sum1 = $jmplen_1 | 1;
    var $_sum = $jmplen_1 + 2 | 0;
    var $_0 = $_sum1 + 2 + ((HEAPU8[$pc + $_sum1 | 0] & 255) << 8 | HEAPU8[$pc + $_sum | 0] & 255) * $_sum | 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_GetVariableStackUses($op, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($op | 0) == 11) {
      __label__ = 2;
      break;
    } else if (($op | 0) == 202) {
      __label__ = 3;
      break;
    } else if (($op | 0) == 210) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $_0 = (HEAPU8[$pc + 1 | 0] & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255;
    __label__ = 6;
    break;
   case 3:
    var $_0 = (HEAPU8[$pc + 1 | 0] & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255;
    __label__ = 6;
    break;
   case 4:
    var $_0 = ((HEAPU8[$pc + 1 | 0] & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255) + 1 | 0;
    __label__ = 6;
    break;
   case 5:
    var $_0 = ((HEAPU8[$pc + 1 | 0] & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255) + 2 | 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_GetEnterBlockStackDefs($script, $pc) {
  var $1 = _js_GetIndexFromBytecode($script, $pc, 0);
  var $script_idx_val = HEAP32[$script + 4 >> 2];
  var $script_idx1_val = HEAP8[$script + 16 | 0];
  var $2 = __ZN8JSScript9getObjectEj($script_idx_val, $script_idx1_val, $1);
  var $3 = $2;
  var $4 = __ZNK8JSObject13propertyCountEv($3);
  return $4;
}

function __ZL18SprintEnsureBufferPN2js8SprinterEj($sp, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = $len + 1 + HEAP32[$sp + 16 >> 2] | 0;
    var $5 = $sp + 12 | 0;
    var $6 = HEAPU32[$5 >> 2];
    var $7 = $4 - $6 | 0;
    if (($7 | 0) < 0) {
      var $_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $sp + 8 | 0;
    var $11 = HEAPU32[$10 >> 2];
    var $14 = HEAPU32[$sp + 4 >> 2];
    var $16 = HEAPU32[$14 + 16 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    var $19 = HEAP32[$14 + 24 >> 2];
    var $22 = $19 + $7 & ($19 ^ -1);
    var $23 = $16 + 12 | 0;
    var $24 = HEAPU32[$23 >> 2];
    var $26 = HEAPU32[$16 + 8 >> 2];
    if ($22 >>> 0 > $26 >>> 0 | $24 >>> 0 > ($26 - $22 | 0) >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $31 = _JS_ArenaAllocate($14, $22);
    var $_p_0 = $31;
    __label__ = 6;
    break;
   case 5:
    var $34 = $22 + $24 | 0;
    HEAP32[$23 >> 2] = $34;
    var $_p_0 = $24;
    __label__ = 6;
    break;
   case 6:
    var $_p_0;
    var $base_0 = $_p_0;
    __label__ = 14;
    break;
   case 7:
    var $38 = $16 + 12 | 0;
    var $40 = $11;
    var $42 = HEAP32[$14 + 24 >> 2];
    var $44 = $42 ^ -1;
    if ((HEAP32[$38 >> 2] | 0) == (($42 + $6 & $44) + $40 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $50 = $42 + $4 & $44;
    var $52 = HEAPU32[$16 + 8 >> 2];
    if ($52 >>> 0 < $50 >>> 0 | $40 >>> 0 > ($52 - $50 | 0) >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $57 = $50 + $40 | 0;
    HEAP32[$38 >> 2] = $57;
    var $base_0 = $11;
    __label__ = 14;
    break;
   case 10:
    if (($40 | 0) == (HEAP32[$16 + 4 >> 2] | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $63 = _JS_ArenaRealloc($14, $11, $6, $7);
    var $base_0 = $63;
    __label__ = 14;
    break;
   case 12:
    var $65 = _JS_ArenaGrow($14, $11, $6, $7);
    var $base_0 = $65;
    __label__ = 14;
    break;
   case 13:
    var $67 = _JS_ArenaGrow($14, $11, $6, $7);
    var $base_0 = $67;
    __label__ = 14;
    break;
   case 14:
    var $base_0;
    if (($base_0 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $72 = HEAP32[$sp >> 2];
    __Z20js_ReportOutOfMemoryP9JSContext($72);
    var $_0 = 0;
    __label__ = 17;
    break;
   case 16:
    HEAP32[$10 >> 2] = $base_0;
    var $75 = HEAP32[$5 >> 2] + $7 | 0;
    HEAP32[$5 >> 2] = $75;
    var $_0 = 1;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18SprintEnsureBufferPN2js8SprinterEj["X"] = 1;

function __ZN2js9SprintPutEPNS_8SprinterEPKcj($sp, $s, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$sp + 12 >> 2];
    var $3 = $sp + 8 | 0;
    var $4 = HEAPU32[$3 >> 2];
    var $5 = __ZL18SprintEnsureBufferPN2js8SprinterEj($sp, $len);
    if (($5 | 0) == 0) {
      var $_0 = -1;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAPU32[$3 >> 2];
    if (($8 | 0) == ($4 | 0) | $4 >>> 0 > $s >>> 0) {
      var $_01 = $s;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($4 + $2 | 0) >>> 0 > $s >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_01 = $s;
      __label__ = 5;
      break;
    }
   case 4:
    var $_01 = $8 + ($s - $4) | 0;
    __label__ = 5;
    break;
   case 5:
    var $_01;
    var $20 = $sp + 16 | 0;
    var $21 = HEAP32[$20 >> 2];
    var $22 = $21 + $len | 0;
    HEAP32[$20 >> 2] = $22;
    var $23 = $8 + $21 | 0;
    _llvm_memmove_p0i8_p0i8_i32($23, $_01, $len, 1, 0);
    HEAP8[$8 + $22 | 0] = 0;
    var $_0 = $21;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13SprintCStringEPNS_8SprinterEPKc($sp, $s) {
  var $1 = _strlen($s);
  var $2 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($sp, $s, $1);
  return $2;
}

function __ZN2js12SprintStringEPNS_8SprinterEP8JSString($sp, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $size = __stackBase__;
    var $str_idx_val = HEAP32[$str >> 2];
    var $1 = __ZNK8JSString6lengthEv($str_idx_val);
    var $2 = $sp | 0;
    var $3 = HEAP32[$2 >> 2];
    var $4 = __ZN8JSString8getCharsEP9JSContext($str, $3);
    if (($4 | 0) == 0) {
      var $_0 = -1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$2 >> 2];
    var $9 = __ZN2js23GetDeflatedStringLengthEP9JSContextPKtj($8, $4, $1);
    HEAP32[$size >> 2] = $9;
    if (($9 | 0) == -1) {
      var $_0 = -1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZL18SprintEnsureBufferPN2js8SprinterEj($sp, $9);
    if (($12 | 0) == 0) {
      var $_0 = -1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = $sp + 16 | 0;
    var $16 = HEAP32[$15 >> 2];
    var $17 = $9 + $16 | 0;
    HEAP32[$15 >> 2] = $17;
    var $19 = $sp + 8 | 0;
    var $21 = HEAP32[$19 >> 2] + $16 | 0;
    var $22 = HEAP32[$2 >> 2];
    var $23 = __ZN2js21DeflateStringToBufferEP9JSContextPKtjPcPj($22, $4, $1, $21, $size);
    HEAP8[HEAP32[$19 >> 2] + HEAP32[$15 >> 2] | 0] = 0;
    var $_0 = $16;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6SprintEPNS_8SprinterEPKcz($sp, $format) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ap = __stackBase__;
    HEAP32[$ap >> 2] = arguments[__ZN2js6SprintEPNS_8SprinterEPKcz.length];
    var $2 = HEAP32[$ap >> 2];
    var $3 = _JS_vsmprintf($format, $2);
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = HEAP32[$sp >> 2];
    _JS_ReportOutOfMemory($7);
    var $_0 = -1;
    __label__ = 4;
    break;
   case 3:
    var $9 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($sp, $3);
    __ZN9JSContext5free_EPv($3);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_QuoteString($cx, $str, $quote) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sprinter = __stackBase__;
    var $1 = $cx + 72 | 0;
    var $2 = $cx + 88 | 0;
    var $5 = HEAPU32[HEAP32[$2 >> 2] + 12 >> 2];
    var $6 = $5;
    HEAP32[$sprinter >> 2] = $cx;
    HEAP32[$sprinter + 4 >> 2] = $1;
    HEAP32[$sprinter + 8 >> 2] = 0;
    HEAP32[$sprinter + 12 >> 2] = 0;
    HEAP32[$sprinter + 16 >> 2] = 0;
    var $12 = $quote & 65535;
    var $13 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($sprinter, $str, $12);
    if (($13 | 0) == 0) {
      var $18 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $16 = _JS_NewStringCopyZ($cx, $13);
    var $18 = $16;
    __label__ = 3;
    break;
   case 3:
    var $18;
    var $19 = HEAPU32[$2 >> 2];
    if (($19 | 0) == ($1 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $24 = HEAP32[$19 + 4 >> 2];
    var $26 = $19 + 12 | 0;
    if (($5 - $24 | 0) >>> 0 > (HEAP32[$26 >> 2] - $24 | 0) >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $32 = HEAP32[$cx + 96 >> 2];
    var $35 = $32 + $5 & ($32 ^ -1);
    HEAP32[$26 >> 2] = $35;
    __label__ = 7;
    break;
   case 6:
    _JS_ArenaRelease($1, $6);
    __label__ = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return $18;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11QuoteStringPN2js8SprinterEP8JSStringj($sp, $str, $quote) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = ($quote & 65536 | 0) == 0;
    var $4 = $sp + 16 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = ($quote & 65535) << 16 >> 16 != 0;
    if ($6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $quote << 24 >> 24;
    var $9 = __ZN2js6SprintEPNS_8SprinterEPKcz($sp, STRING_TABLE.__str1462819 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $8, tempInt));
    if (($9 | 0) < 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = HEAP32[$sp >> 2];
    var $14 = __ZN8JSString8getCharsEP9JSContext($str, $13);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $str_idx_val = HEAP32[$str >> 2];
    var $17 = __ZNK8JSString6lengthEv($str_idx_val);
    var $18 = $14 + ($17 << 1) | 0;
    var $19 = $quote & 65535;
    var $20 = $sp + 8 | 0;
    var $_not = $6 ^ 1;
    var $s_0 = $14;
    __label__ = 5;
    break;
   case 5:
    var $s_0;
    if ($s_0 >>> 0 < $18 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 6:
    var $c_0 = HEAP16[$s_0 >> 1];
    var $t_1 = $s_0;
    __label__ = 7;
    break;
   case 7:
    var $t_1;
    var $c_0;
    var $26 = $c_0 & 65535;
    if (($c_0 & 65535) < 127) {
      __label__ = 8;
      break;
    } else {
      var $c_1 = $c_0;
      var $t_2 = $t_1;
      __label__ = 11;
      break;
    }
   case 8:
    var $29 = _isprint($26);
    if (($29 | 0) == 0 | ($26 | 0) == ($19 | 0)) {
      var $c_1 = $c_0;
      var $t_2 = $t_1;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ($c_0 << 16 >> 16 == 92 || $c_0 << 16 >> 16 == 9) {
      var $c_1 = $c_0;
      var $t_2 = $t_1;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $33 = $t_1 + 2 | 0;
    var $34 = HEAPU16[$33 >> 1];
    if (($33 | 0) == ($18 | 0)) {
      var $c_1 = $34;
      var $t_2 = $33;
      __label__ = 11;
      break;
    } else {
      var $c_0 = $34;
      var $t_1 = $33;
      __label__ = 7;
      break;
    }
   case 11:
    var $t_2;
    var $c_1;
    var $38 = $t_2 - $s_0 | 0;
    var $39 = $38 >> 1;
    var $40 = __ZL18SprintEnsureBufferPN2js8SprinterEj($sp, $39);
    if (($40 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $43 = HEAPU32[$20 >> 2];
    var $44 = HEAP32[$4 >> 2];
    var $45 = $43 + $44 | 0;
    var $46 = $44 + $39 | 0;
    HEAP32[$4 >> 2] = $46;
    if (($38 | 0) > 0) {
      __label__ = 13;
      break;
    } else {
      var $bp_0_lcssa = $45;
      __label__ = 16;
      break;
    }
   case 13:
    var $48 = -$39 | 0;
    var $smax = ($48 | 0) > -1 ? $48 : -1;
    var $50 = $46 + $smax | 0;
    var $s_18 = $s_0;
    var $len_09 = $39;
    var $bp_010 = $45;
    __label__ = 14;
    break;
   case 14:
    var $bp_010;
    var $len_09;
    var $s_18;
    var $52 = $len_09 - 1 | 0;
    HEAP8[$bp_010] = HEAP16[$s_18 >> 1] & 255;
    if (($52 | 0) > 0) {
      var $s_18 = $s_18 + 2 | 0;
      var $len_09 = $52;
      var $bp_010 = $bp_010 + 1 | 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $bp_0_lcssa = $50 + ($43 + 1) | 0;
    __label__ = 16;
    break;
   case 16:
    var $bp_0_lcssa;
    HEAP8[$bp_0_lcssa] = 0;
    if (($t_2 | 0) == ($18 | 0)) {
      __label__ = 25;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $61 = $c_1 & 65535;
    var $62 = ($61 & 65280 | 0) != 0;
    if ($62) {
      __label__ = 22;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $memchr = _memchr(STRING_TABLE._js_EscapeMap | 0, $61, 19);
    if (($memchr | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    if ($2) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $68 = __ZN2js6SprintEPNS_8SprinterEPKcz($sp, STRING_TABLE.__str1462819 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $61 << 24 >> 24, tempInt));
    var $ok_0_in_in_in = $68;
    __label__ = 23;
    break;
   case 21:
    var $72 = HEAP8[$memchr + 1 | 0] << 24 >> 24;
    var $73 = __ZN2js6SprintEPNS_8SprinterEPKcz($sp, STRING_TABLE.__str1472820 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $72, tempInt));
    var $ok_0_in_in_in = $73;
    __label__ = 23;
    break;
   case 22:
    var $75 = $62 | $_not ? STRING_TABLE.__str1492822 : STRING_TABLE.__str1482821;
    var $76 = $75 | 0;
    var $77 = __ZN2js6SprintEPNS_8SprinterEPKcz($sp, $76, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $61, tempInt));
    var $ok_0_in_in_in = $77;
    __label__ = 23;
    break;
   case 23:
    var $ok_0_in_in_in;
    if (($ok_0_in_in_in | 0) > -1) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 0;
      __label__ = 30;
      break;
    }
   case 24:
    var $s_0 = $t_2 + 2 | 0;
    __label__ = 5;
    break;
   case 25:
    if ($6) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $84 = $quote << 24 >> 24;
    var $85 = __ZN2js6SprintEPNS_8SprinterEPKcz($sp, STRING_TABLE.__str1462819 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $84, tempInt));
    if (($85 | 0) < 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    if (($5 | 0) == (HEAP32[$4 >> 2] | 0)) {
      __label__ = 28;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 28:
    var $91 = __ZN2js6SprintEPNS_8SprinterEPKcz($sp, __str17668 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    if (($91 | 0) < 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $_0 = HEAP32[$20 >> 2] + $5 | 0;
    __label__ = 30;
    break;
   case 30:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11QuoteStringPN2js8SprinterEP8JSStringj["X"] = 1;

function _js_NewPrinter($cx, $fun, $indent, $pretty, $grouped, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($cx, 76);
    var $2 = $1;
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $cx;
    var $7 = $1 + 20 | 0;
    HEAP32[$1 + 4 >> 2] = $7;
    HEAP32[$1 + 8 >> 2] = 0;
    HEAP32[$1 + 12 >> 2] = 0;
    HEAP32[$1 + 16 >> 2] = 0;
    _JS_InitArenaPool($7, 256, 1);
    HEAP32[$1 + 48 >> 2] = $indent;
    HEAP8[$1 + 52 | 0] = ($pretty | 0) != 0 & 1;
    HEAP8[$1 + 53 | 0] = ($grouped | 0) != 0 & 1;
    HEAP8[$1 + 54 | 0] = ($strict | 0) != 0 & 1;
    HEAP32[$1 + 56 >> 2] = 0;
    HEAP32[$1 + 60 >> 2] = 0;
    HEAP32[$1 + 64 >> 2] = 0;
    HEAP32[$1 + 68 >> 2] = $fun;
    var $36 = $1 + 72 | 0;
    HEAP32[$36 >> 2] = 0;
    if (($fun | 0) == 0) {
      var $_0 = $2;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $fun_idx_val = HEAP16[$fun + 58 >> 1];
    var $39 = __ZNK10JSFunction13isInterpretedEv($fun_idx_val);
    if ($39) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $2;
      __label__ = 8;
      break;
    }
   case 4:
    var $41 = __ZNK10JSFunction6scriptEv($fun);
    var $_idx_val = HEAP16[$41 + 68 >> 1];
    var $_idx1_val = HEAP16[$41 + 70 >> 1];
    var $_idx2_val = HEAP16[$41 + 72 >> 1];
    var $45 = __ZNK2js8Bindings13hasLocalNamesEv($_idx_val, $_idx1_val, $_idx2_val);
    if ($45) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $2;
      __label__ = 8;
      break;
    }
   case 5:
    var $47 = __ZN9JSContext4new_IN2js6VectorIP6JSAtomLj0ENS1_15TempAllocPolicyEEEPS_EEPT_T0_($cx, $cx);
    HEAP32[$36 >> 2] = $47;
    if (($47 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $50 = __ZNK10JSFunction6scriptEv($fun);
    var $52 = $50 + 64 | 0;
    var $53 = $47;
    var $54 = __ZN2js8Bindings17getLocalNameArrayEP9JSContextPNS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEE($52, $53);
    if ($54) {
      var $_0 = $2;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _js_DestroyPrinter($2);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_NewPrinter["X"] = 1;

function __ZN9JSContext4new_IN2js6VectorIP6JSAtomLj0ENS1_15TempAllocPolicyEEEPS_EEPT_T0_($this, $p1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN9JSContext7malloc_Ej($this, 24);
    if (($2 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $p1);
    var $_0_val = HEAP32[$1 >> 2];
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEC1ES3_($5, $_0_val);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    STACKTOP = __stackBase__;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_DestroyPrinter($jp) {
  var $1 = $jp + 20 | 0;
  _JS_FinishArenaPool($1);
  var $3 = HEAP32[$jp + 72 >> 2];
  __ZN2js10Foreground7delete_INS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEEEEvPT_($3);
  var $4 = $jp;
  __ZN9JSContext5free_EPv($4);
  return;
}

function __ZN2js10Foreground7delete_INS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev($p);
    var $3 = $p;
    _js_free2859($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_GetPrinterOutput($jp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $jp | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $jp + 8 | 0;
    var $4 = HEAP32[$3 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = HEAP32[HEAP32[$2 + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 5;
    break;
   case 3:
    var $13 = _JS_NewStringCopyZ($2, $4);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = $jp + 20 | 0;
    _JS_FreeArenaPool($16);
    HEAP32[$1 >> 2] = $2;
    HEAP32[$jp + 4 >> 2] = $16;
    HEAP32[$3 >> 2] = 0;
    HEAP32[$jp + 12 >> 2] = 0;
    HEAP32[$jp + 16 >> 2] = 0;
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_printf($jp, $format) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ap = __stackBase__;
    if (HEAP8[$format] << 24 >> 24 == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$ap >> 2] = arguments[_js_printf.length];
    if (HEAP8[$format] << 24 >> 24 == 9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_01 = $format;
    var $_pre_phi = $jp + 52 | 0;
    __label__ = 7;
    break;
   case 4:
    var $8 = $format + 1 | 0;
    var $9 = $jp + 52 | 0;
    if ((HEAP8[$9] & 1) << 24 >> 24 == 0) {
      var $_01 = $8;
      var $_pre_phi = $9;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = $jp | 0;
    var $16 = HEAP32[$jp + 48 >> 2];
    var $17 = __ZN2js6SprintEPNS_8SprinterEPKcz($14, STRING_TABLE.__str16667 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $16, HEAP32[tempInt + 4 >> 2] = __str17668 | 0, tempInt));
    if (($17 | 0) < 0) {
      __label__ = 6;
      break;
    } else {
      var $_01 = $8;
      var $_pre_phi = $9;
      __label__ = 7;
      break;
    }
   case 6:
    __label__ = 16;
    break;
   case 7:
    var $_pre_phi;
    var $_01;
    if ((HEAP8[$_pre_phi] & 1) << 24 >> 24 == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $24 = _strlen($_01);
    var $25 = $24 - 1 | 0;
    if (HEAP8[$_01 + $25 | 0] << 24 >> 24 == 10) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $31 = HEAP32[$jp >> 2];
    var $32 = _JS_strdup($31, $_01);
    if (($32 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    __label__ = 16;
    break;
   case 11:
    var $35 = HEAP32[$ap >> 2];
    var $36 = _JS_vsmprintf($_01, $35);
    var $42 = $36;
    __label__ = 13;
    break;
   case 12:
    HEAP8[$32 + $25 | 0] = 0;
    var $39 = HEAP32[$ap >> 2];
    var $40 = _JS_vsmprintf($32, $39);
    __ZN9JSContext5free_EPv($32);
    var $42 = $40;
    __label__ = 13;
    break;
   case 13:
    var $42;
    if (($42 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $46 = HEAP32[$jp >> 2];
    _JS_ReportOutOfMemory($46);
    __label__ = 16;
    break;
   case 15:
    var $48 = _strlen($42);
    var $49 = $jp | 0;
    var $50 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($49, $42, $48);
    __ZN9JSContext5free_EPv($42);
    __label__ = 16;
    break;
   case 16:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_printf["X"] = 1;

function _js_puts($jp, $s) {
  var $1 = $jp | 0;
  var $2 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($1, $s);
  return;
}

function __ZL10StackDepthP8JSScript($script_0_4_val, $script_0_19_val) {
  return ($script_0_19_val & 65535) - ($script_0_4_val & 65535) | 0;
}

function __Z8GetLocalP11SprintStacki($ss, $i) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $4 = HEAP32[HEAP32[$ss + 20 >> 2] + ($i << 2) >> 2];
    if (($4 | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = HEAP32[$ss + 8 >> 2] + $4 | 0;
    __label__ = 18;
    break;
   case 3:
    var $14 = HEAP32[HEAP32[$ss + 40 >> 2] + 56 >> 2];
    var $15 = $14 + 16 | 0;
    var $16 = HEAP8[$15];
    var $17 = __ZN8JSScript13isValidOffsetEh($16);
    if ($17) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = __ZL6GetStrP11SprintStackj($ss, $i);
    var $_0 = $19;
    __label__ = 18;
    break;
   case 5:
    var $_idx1 = $14 + 4 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $21 = __ZN8JSScript7objectsEv($_idx1_val, $16);
    var $23 = HEAP32[$21 + 4 >> 2];
    var $j_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $j_0;
    if (($j_0 | 0) == ($23 | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx3_val = HEAP32[$_idx1 >> 2];
    var $_idx4_val = HEAP8[$15];
    var $27 = __ZN8JSScript9getObjectEj($_idx3_val, $_idx4_val, $j_0);
    var $_idx7_val = HEAP32[$27 + 4 >> 2];
    var $28 = __ZNK8JSObject7isBlockEv($_idx7_val);
    if ($28) {
      __label__ = 8;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 8:
    var $30 = __ZNK8JSObject12getFixedSlotEj($27, 0);
    var $_idx = $30 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $31 = __ZNK2JS5Value7toInt32Ev($_idx_val$0, $_idx_val$1);
    var $32 = $27;
    var $33 = __ZNK8JSObject13propertyCountEv($32);
    var $34 = $i - $31 | 0;
    if ($34 >>> 0 < $33 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 9:
    var $_idx5_val = HEAP32[$27 >> 2];
    var $37 = __ZNK8JSObject12lastPropertyEv($_idx5_val);
    __ZN2js5Shape5RangeC1EPKS0_($r, $37);
    var $_idx6 = $r;
    __label__ = 10;
    break;
   case 10:
    var $_idx6_val = HEAP32[$_idx6 >> 2];
    var $_idx6_val_idx_val = HEAP32[$_idx6_val + 32 >> 2];
    var $39 = __ZNK2js5Shape5Range5emptyEv($_idx6_val_idx_val);
    if ($39) {
      __label__ = 17;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $41 = $_idx6_val;
    var $42 = __ZNK2js5Shape5Range5frontEv($41);
    if ((HEAP16[$42 + 30 >> 1] << 16 >> 16 | 0) == ($34 | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 12:
    var $49 = HEAP32[$42 + 12 >> 2];
    var $50 = __ZL12JSID_IS_ATOMi2840($49);
    if (($50 | 0) == 0) {
      var $_0 = __str17668 | 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $53 = __ZL12JSID_TO_ATOMi2841($49);
    var $54 = $ss | 0;
    var $55 = $53 | 0;
    var $56 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($54, $55, 0);
    if (($56 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $63 = $56 - HEAP32[$ss + 8 >> 2] | 0;
    HEAP32[$ss + 16 >> 2] = $63;
    var $_0 = $56;
    __label__ = 18;
    break;
   case 15:
    __ZN2js5Shape5Range8popFrontEv($r);
    __label__ = 10;
    break;
   case 16:
    var $j_0 = $j_0 + 1 | 0;
    __label__ = 6;
    break;
   case 17:
    var $68 = __ZL6GetStrP11SprintStackj($ss, $i);
    var $_0 = $68;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z8GetLocalP11SprintStacki["X"] = 1;

function __ZL6GetStrP11SprintStackj($ss, $i) {
  var $1 = __ZL6GetOffP11SprintStackj($ss, $i);
  return HEAP32[$ss + 8 >> 2] + $1 | 0;
}

function __ZL12JSID_IS_ATOMi2840($id) {
  var $1 = _JSID_IS_STRING2879($id);
  return $1;
}

function __ZL12JSID_TO_ATOMi2841($id) {
  var $1 = _JSID_TO_STRING2878($id);
  return $1;
}

function __ZL13DecompileBodyP9JSPrinterP8JSScriptPh($jp, $script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$script + 36 | 0] & 8) << 24 >> 24 == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $jp + 54 | 0;
    if ((HEAP8[$6] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    var $12 = HEAP32[$jp + 68 >> 2];
    if (($12 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP16[$12 + 58 >> 1] & 4096) << 16 >> 16 == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _js_printf($jp, STRING_TABLE.__str1442817 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 7;
    break;
   case 6:
    _js_printf($jp, STRING_TABLE.__str1452818 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 7;
    break;
   case 7:
    HEAP8[$6] = 1;
    __label__ = 8;
    break;
   case 8:
    var $30 = HEAP32[$script >> 2] + HEAP32[$script + 8 >> 2] - $pc | 0;
    var $31 = __ZL13DecompileCodeP9JSPrinterP8JSScriptPhjj($jp, $script, $pc, $30, 0);
    return $31;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_DecompileToString($cx, $fun, $indent, $pretty, $grouped, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_NewPrinter($cx, $fun, $indent, $pretty, $grouped, $strict);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _js_DecompileFunction($1);
    if (($4 | 0) == 0) {
      var $str_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = _js_GetPrinterOutput($1);
    var $str_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $str_0;
    _js_DestroyPrinter($1);
    var $_0 = $str_0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_DecompileFunction($jp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pc = __stackBase__;
    var $ss = __stackBase__ + 4;
    var $untrapper = __stackBase__ + 48;
    var $2 = HEAP32[$jp + 68 >> 2];
    var $3 = $jp + 52 | 0;
    if ((HEAP8[$3] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _js_printf($jp, STRING_TABLE.__str282701 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 6;
    break;
   case 3:
    if ((HEAP8[$jp + 53 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    if ((HEAP16[$2 + 58 >> 1] & 8) << 16 >> 16 == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _js_puts($jp, STRING_TABLE.__str292702 | 0);
    __label__ = 6;
    break;
   case 6:
    _js_printf($jp, STRING_TABLE.__str302703 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str252545 | 0, tempInt));
    var $21 = HEAP32[$2 + 72 >> 2];
    if (($21 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = $jp | 0;
    var $25 = $21 | 0;
    var $26 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($24, $25, 0);
    if (($26 | 0) == 0) {
      var $_1 = 0;
      __label__ = 44;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    _js_puts($jp, STRING_TABLE.__str292702 | 0);
    var $_idx = $2 + 58 | 0;
    var $_idx_val = HEAP16[$_idx >> 1];
    var $29 = __ZNK10JSFunction13isInterpretedEv($_idx_val);
    if ($29) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    _js_printf($jp, STRING_TABLE.__str312704 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $31 = $jp + 48 | 0;
    var $33 = HEAP32[$31 >> 2] + 4 | 0;
    HEAP32[$31 >> 2] = $33;
    _js_printf($jp, STRING_TABLE.__ZL15native_code_str | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $35 = HEAP32[$31 >> 2] - 4 | 0;
    HEAP32[$31 >> 2] = $35;
    _js_printf($jp, STRING_TABLE.__str322705 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 10:
    var $37 = __ZNK10JSFunction6scriptEv($2);
    var $_idx3_val = HEAP32[$37 >> 2];
    var $_idx4_val = HEAP32[$37 + 32 >> 2];
    var $38 = __ZN8JSScript4mainEv($_idx3_val, $_idx4_val);
    HEAP32[$pc >> 2] = $38;
    var $39 = $jp | 0;
    var $40 = $jp | 0;
    var $41 = HEAP32[$40 >> 2];
    __ZN19AutoScriptUntrapperC1EP9JSContextP8JSScriptPPh($untrapper, $41, $37, $pc);
    var $42 = HEAP32[$pc >> 2];
    var $45 = $42 + HEAP32[$37 + 8 >> 2] | 0;
    var $46 = $ss + 40 | 0;
    HEAP32[$46 >> 2] = 0;
    var $47 = $jp + 56 | 0;
    HEAP32[$47 >> 2] = $37;
    var $52 = HEAPU32[HEAP32[HEAP32[$40 >> 2] + 88 >> 2] + 12 >> 2];
    var $53 = $52;
    var $54 = $2 + 56 | 0;
    var $_idx1 = $37 + 14 | 0;
    var $_idx2 = $37 + 44 | 0;
    var $ok_0 = 1;
    var $i_0 = 0;
    var $56 = $42;
    __label__ = 11;
    break;
   case 11:
    var $56;
    var $i_0;
    var $ok_0;
    if ($i_0 >>> 0 < (HEAPU16[$54 >> 1] & 65535) >>> 0) {
      __label__ = 12;
      break;
    } else {
      var $ok_3 = $ok_0;
      var $99 = $56;
      __label__ = 24;
      break;
    }
   case 12:
    if (($i_0 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    _js_puts($jp, STRING_TABLE.__str296 | 0);
    __label__ = 14;
    break;
   case 14:
    var $64 = __ZL15GetArgOrVarAtomP9JSPrinterj($jp, $i_0);
    if (($64 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 15:
    if (HEAP8[$56] << 24 >> 24 == 84) {
      __label__ = 16;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 16:
    var $70 = $56 + 3 | 0;
    HEAP32[$pc >> 2] = $70;
    if (HEAP8[$70] << 24 >> 24 == 12) {
      __label__ = 17;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 17:
    if ((HEAP32[$46 >> 2] | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      var $ok_1 = $ok_0;
      __label__ = 19;
      break;
    }
   case 18:
    var $77 = HEAP32[$40 >> 2];
    var $_idx1_val = HEAP16[$_idx1 >> 1];
    var $_idx2_val = HEAP16[$_idx2 >> 1];
    var $78 = __ZL10StackDepthP8JSScript($_idx1_val, $_idx2_val);
    var $79 = __ZL15InitSprintStackP9JSContextP11SprintStackP9JSPrinterj($77, $ss, $jp, $78);
    if (($79 | 0) == 0) {
      var $ok_3 = 0;
      var $99 = $70;
      __label__ = 24;
      break;
    } else {
      var $ok_1 = $79;
      __label__ = 19;
      break;
    }
   case 19:
    var $ok_1;
    var $82 = __ZL22DecompileDestructuringP11SprintStackPhS1_($ss, $70, $45);
    HEAP32[$pc >> 2] = $82;
    if (($82 | 0) == 0) {
      var $ok_3 = 0;
      var $99 = $82;
      __label__ = 24;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    if (HEAP8[$82] << 24 >> 24 == 81) {
      __label__ = 21;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 21:
    var $88 = $82 + 1 | 0;
    HEAP32[$pc >> 2] = $88;
    var $89 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $90 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($39, $89);
    if (($90 | 0) < 0) {
      var $ok_3 = 0;
      var $99 = $88;
      __label__ = 24;
      break;
    } else {
      var $ok_2 = $ok_1;
      var $97 = $88;
      __label__ = 23;
      break;
    }
   case 22:
    var $93 = $64 | 0;
    var $94 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($39, $93, 0);
    if (($94 | 0) == 0) {
      var $ok_3 = 0;
      var $99 = $56;
      __label__ = 24;
      break;
    } else {
      var $ok_2 = $ok_0;
      var $97 = $56;
      __label__ = 23;
      break;
    }
   case 23:
    var $97;
    var $ok_2;
    var $ok_0 = $ok_2;
    var $i_0 = $i_0 + 1 | 0;
    var $56 = $97;
    __label__ = 11;
    break;
   case 24:
    var $99;
    var $ok_3;
    HEAP32[$47 >> 2] = 0;
    var $100 = HEAPU32[$40 >> 2];
    var $102 = HEAP32[$100 + 88 >> 2];
    if (($102 | 0) == ($100 + 72 | 0)) {
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $107 = HEAP32[$102 + 4 >> 2];
    var $109 = $102 + 12 | 0;
    if (($52 - $107 | 0) >>> 0 > (HEAP32[$109 >> 2] - $107 | 0) >>> 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $115 = HEAP32[$100 + 96 >> 2];
    var $118 = $115 + $52 & ($115 ^ -1);
    HEAP32[$109 >> 2] = $118;
    __label__ = 28;
    break;
   case 27:
    var $120 = $100 + 72 | 0;
    _JS_ArenaRelease($120, $53);
    __label__ = 28;
    break;
   case 28:
    if (($ok_3 | 0) == 0) {
      __label__ = 42;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    _js_printf($jp, STRING_TABLE.__str342707 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    if ((HEAP16[$_idx >> 1] & 4096) << 16 >> 16 == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    _js_printf($jp, STRING_TABLE.__str352708 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $128 = $jp + 48 | 0;
    var $130 = HEAP32[$128 >> 2] + 4 | 0;
    HEAP32[$128 >> 2] = $130;
    __label__ = 31;
    break;
   case 31:
    var $132 = __ZL13DecompileBodyP9JSPrinterP8JSScriptPh($jp, $37, $99);
    if (($132 | 0) == 0) {
      __label__ = 43;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    if ((HEAP16[$_idx >> 1] & 4096) << 16 >> 16 == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 33:
    var $139 = $jp + 48 | 0;
    var $141 = HEAP32[$139 >> 2] - 4 | 0;
    HEAP32[$139 >> 2] = $141;
    _js_printf($jp, STRING_TABLE.__str322705 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 34;
    break;
   case 34:
    __ZN19AutoScriptUntrapperD1Ev($untrapper);
    __label__ = 35;
    break;
   case 35:
    if ((HEAP8[$3] & 1) << 24 >> 24 == 0) {
      __label__ = 36;
      break;
    } else {
      var $_1 = 1;
      __label__ = 44;
      break;
    }
   case 36:
    if ((HEAP8[$jp + 53 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 37;
      break;
    } else {
      var $_1 = 1;
      __label__ = 44;
      break;
    }
   case 37:
    if ((HEAP16[$_idx >> 1] & 8) << 16 >> 16 == 0) {
      var $_1 = 1;
      __label__ = 44;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    _js_puts($jp, STRING_TABLE.__str362709 | 0);
    var $_1 = 1;
    __label__ = 44;
    break;
   case 39:
    __ZN19AutoScriptUntrapperD1Ev($untrapper);
    var $_1 = 0;
    __label__ = 44;
    break;
   case 40:
    __ZN19AutoScriptUntrapperD1Ev($untrapper);
    var $_1 = 0;
    __label__ = 44;
    break;
   case 41:
    __ZN19AutoScriptUntrapperD1Ev($untrapper);
    var $_1 = 0;
    __label__ = 44;
    break;
   case 42:
    __ZN19AutoScriptUntrapperD1Ev($untrapper);
    var $_1 = 0;
    __label__ = 44;
    break;
   case 43:
    __ZN19AutoScriptUntrapperD1Ev($untrapper);
    var $_1 = 0;
    __label__ = 44;
    break;
   case 44:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_DecompileFunction["X"] = 1;

function __ZN19AutoScriptUntrapperC1EP9JSContextP8JSScriptPPh($this, $cx, $script, $pc) {
  __ZN19AutoScriptUntrapperC2EP9JSContextP8JSScriptPPh($this, $cx, $script, $pc);
  return;
}

function __ZL15GetArgOrVarAtomP9JSPrinterj($jp, $slot) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$jp + 68 >> 2];
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK10JSFunction6scriptEv($2);
    var $_idx_val = HEAP16[$5 + 68 >> 1];
    var $_idx1_val = HEAP16[$5 + 70 >> 1];
    var $_idx2_val = HEAP16[$5 + 72 >> 1];
    var $9 = __ZNK2js8Bindings15countLocalNamesEv($_idx_val, $_idx1_val, $_idx2_val);
    if ($9 >>> 0 > $slot >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_idx3_val = HEAP32[HEAP32[$jp + 72 >> 2] + 4 >> 2];
    var $14 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEixEj($_idx3_val, $slot);
    var $_0 = HEAP32[$14 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15InitSprintStackP9JSContextP11SprintStackP9JSPrinterj($cx, $ss, $jp, $depth) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$ss >> 2] = $cx;
    var $2 = $cx + 72 | 0;
    HEAP32[$ss + 4 >> 2] = $2;
    HEAP32[$ss + 8 >> 2] = 0;
    HEAP32[$ss + 12 >> 2] = 0;
    HEAP32[$ss + 16 >> 2] = 3;
    var $7 = $depth << 2;
    var $9 = HEAP32[$cx + 88 >> 2];
    var $11 = HEAP32[$cx + 96 >> 2];
    var $15 = $7 + $depth + $11 & ($11 ^ -1);
    var $16 = $9 + 12 | 0;
    var $17 = HEAPU32[$16 >> 2];
    var $19 = HEAPU32[$9 + 8 >> 2];
    if ($15 >>> 0 > $19 >>> 0 | $17 >>> 0 > ($19 - $15 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $24 = _JS_ArenaAllocate($2, $15);
    var $_p_0 = $24;
    __label__ = 4;
    break;
   case 3:
    var $27 = $15 + $17 | 0;
    HEAP32[$16 >> 2] = $27;
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    HEAP32[$ss + 20 >> 2] = $_p_0;
    HEAP32[$ss + 24 >> 2] = $_p_0 + $7 | 0;
    HEAP32[$ss + 32 >> 2] = 0;
    HEAP32[$ss + 28 >> 2] = 0;
    HEAP32[$ss + 36 >> 2] = 0;
    HEAP32[$ss + 40 >> 2] = $jp;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15InitSprintStackP9JSContextP11SprintStackP9JSPrinterj["X"] = 1;

function __ZN2js10StackFrame13clearImacropcEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -8193;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js10StackFrame11setImacropcEPh($this, $pc) {
  HEAP32[$this + 40 >> 2] = $pc;
  var $2 = $this | 0;
  var $4 = HEAP32[$2 >> 2] | 8192;
  HEAP32[$2 >> 2] = $4;
  return;
}

function __ZL13GetJumpOffsetPhS_($pc_val, $pc2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $9 = HEAPU8[$pc2 + 1 | 0] & 255;
    if (((HEAP32[_js_CodeSpec + (($pc_val & 255) << 3) + 4 >> 2] & 31) - 9 | 0) >>> 0 < 3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = (HEAPU8[$pc2 + 2 | 0] & 255) << 16 | $9 << 24 | HEAPU8[$pc2 + 4 | 0] & 255 | (HEAPU8[$pc2 + 3 | 0] & 255) << 8;
    __label__ = 4;
    break;
   case 3:
    var $_0 = (HEAPU8[$pc2 + 2 | 0] & 255 | $9 << 8) << 16 >> 16;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL22DecompileDestructuringP11SprintStackPhS1_($ss, $pc, $endpc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $hole = __stackBase__;
    if (HEAP8[$pc] << 24 >> 24 == 12) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 2:
    var $4 = $ss | 0;
    var $5 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($4, STRING_TABLE.__str1002773 | 0, 1);
    if (($5 | 0) < 0) {
      var $_0 = 0;
      __label__ = 49;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZL7PushOffP11SprintStacki4JSOp($ss, $5, 0);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 49;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $ss + 16 | 0;
    var $12 = HEAP32[$11 >> 2];
    var $13 = $12 - 3 | 0;
    HEAP32[$11 >> 2] = $13;
    if (($5 | 0) == ($12 - 4 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 5:
    var $17 = $ss + 8 | 0;
    if (HEAP8[HEAP32[$17 >> 2] + $5 | 0] << 24 >> 24 == 91) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 6:
    var $24 = HEAP32[$ss >> 2];
    var $27 = HEAP32[$ss + 40 >> 2] + 56 | 0;
    var $28 = $24;
    var $29 = $24 + 52 | 0;
    var $pc_pn = $pc;
    var $lasti_0 = -1;
    __label__ = 7;
    break;
   case 7:
    var $lasti_0;
    var $pc_pn;
    var $_01 = $pc_pn + 1 | 0;
    if ($_01 >>> 0 < $endpc >>> 0) {
      __label__ = 8;
      break;
    } else {
      var $_2 = $_01;
      __label__ = 48;
      break;
    }
   case 8:
    var $33 = HEAPU8[$_01] & 255;
    var $36 = HEAP8[_js_CodeSpec + ($33 << 3) | 0] << 24 >> 24;
    if (($33 | 0) == 81) {
      __label__ = 9;
      break;
    } else if (($33 | 0) == 63) {
      __label__ = 10;
      break;
    } else if (($33 | 0) == 88) {
      __label__ = 11;
      break;
    } else if (($33 | 0) == 190) {
      __label__ = 12;
      break;
    } else if (($33 | 0) == 218) {
      __label__ = 13;
      break;
    } else if (($33 | 0) == 219) {
      __label__ = 14;
      break;
    } else if (($33 | 0) == 60) {
      __label__ = 15;
      break;
    } else if (($33 | 0) == 62) {
      var $d_0 = 0;
      var $i_0 = 0;
      __label__ = 18;
      break;
    } else if (($33 | 0) == 187 || ($33 | 0) == 53 || ($33 | 0) == 220) {
      __label__ = 26;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 9:
    var $_2 = $36 + ($pc_pn + 1) | 0;
    __label__ = 48;
    break;
   case 10:
    var $d_0 = 1;
    var $i_0 = 1;
    __label__ = 18;
    break;
   case 11:
    var $48 = (HEAPU8[$pc_pn + 2 | 0] & 255) << 8 | HEAPU8[$pc_pn + 3 | 0] & 255;
    var $d_0 = $48 | 0;
    var $i_0 = $48;
    __label__ = 18;
    break;
   case 12:
    var $63 = HEAPU8[$pc_pn + 4 | 0] & 255 | (HEAPU8[$pc_pn + 2 | 0] & 255) << 16 | (HEAPU8[$pc_pn + 3 | 0] & 255) << 8;
    var $d_0 = $63 | 0;
    var $i_0 = $63;
    __label__ = 18;
    break;
   case 13:
    var $67 = HEAP8[$pc_pn + 2 | 0];
    var $d_0 = $67 << 24 >> 24;
    var $i_0 = $67 << 24 >> 24;
    __label__ = 18;
    break;
   case 14:
    var $88 = (HEAPU8[$pc_pn + 3 | 0] & 255) << 16 | (HEAPU8[$pc_pn + 2 | 0] & 255) << 24 | HEAPU8[$pc_pn + 5 | 0] & 255 | (HEAPU8[$pc_pn + 4 | 0] & 255) << 8;
    var $d_0 = $88 | 0;
    var $i_0 = $88;
    __label__ = 18;
    break;
   case 15:
    var $91 = HEAP32[$27 >> 2];
    var $92 = _js_GetIndexFromBytecode($91, $_01, 0);
    var $93 = HEAP32[$27 >> 2];
    var $_idx1_val = HEAP32[$93 + 4 >> 2];
    var $_idx2_val = HEAP8[$93 + 21 | 0];
    var $94 = __ZN8JSScript8getConstEj($_idx1_val, $_idx2_val, $92);
    var $95 = __ZNK2JS5Value8toDoubleEv($94);
    var $96 = __ZL18JSDOUBLE_IS_FINITEd2876($95);
    if (($96 | 0) == 0) {
      var $_0 = 0;
      __label__ = 49;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $99 = _JSDOUBLE_IS_NEGZERO2875($95);
    if (($99 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 17:
    var $d_0 = $95;
    var $i_0 = $95 & -1;
    __label__ = 18;
    break;
   case 18:
    var $i_0;
    var $d_0;
    var $104 = HEAP32[$27 >> 2];
    var $105 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($28, $104, $_01);
    var $106 = $36 + ($pc_pn + 1) | 0;
    if (($106 | 0) == ($endpc | 0)) {
      var $_0 = $106;
      __label__ = 49;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $109 = HEAPU8[$106];
    var $113 = HEAP8[_js_CodeSpec + (($109 & 255) << 3) | 0] << 24 >> 24;
    if ($109 << 24 >> 24 == 55) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 20:
    if (($105 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $118 = HEAPU8[$105];
    if (($118 & 255) < 192 & ($118 & -8) << 24 >> 24 == 8) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    HEAP8[HEAP32[$17 >> 2] + $5 | 0] = 123;
    var $123 = __ZN2js6SprintEPNS_8SprinterEPKcz($4, STRING_TABLE.__str1412814 | 0, (tempInt = STACKTOP, STACKTOP += 8, tempDoubleF64[0] = $d_0, HEAP32[tempInt >> 2] = tempDoubleI32[0], HEAP32[tempInt + 4 >> 2] = tempDoubleI32[1], tempInt));
    if (($123 | 0) < 0) {
      var $_0 = 0;
      __label__ = 49;
      break;
    } else {
      var $_1 = $106;
      var $nameoff_0 = -1;
      var $oplen_0 = $113;
      var $lasti_2 = $lasti_0;
      __label__ = 32;
      break;
    }
   case 23:
    if (($i_0 | 0) == $d_0) {
      var $lasti_1 = $lasti_0;
      __label__ = 24;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 24:
    var $lasti_1;
    var $127 = $lasti_1 + 1 | 0;
    if (($127 | 0) < ($i_0 | 0)) {
      __label__ = 25;
      break;
    } else {
      var $_1 = $106;
      var $nameoff_0 = -1;
      var $oplen_0 = $113;
      var $lasti_2 = $127;
      __label__ = 32;
      break;
    }
   case 25:
    var $130 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($4, STRING_TABLE.__str296 | 0, 2);
    if (($130 | 0) < 0) {
      var $_0 = 0;
      __label__ = 49;
      break;
    } else {
      var $lasti_1 = $127;
      __label__ = 24;
      break;
    }
   case 26:
    var $133 = HEAP32[$27 >> 2];
    var $134 = _js_GetIndexFromBytecode($133, $_01, 0);
    var $135 = HEAPU32[$27 >> 2];
    var $137 = HEAPU32[$135 >> 2];
    if ($_01 >>> 0 < $137 >>> 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    if (($137 + HEAP32[$135 + 8 >> 2] | 0) >>> 0 > $_01 >>> 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $146 = HEAP32[$29 >> 2] + 209948 | 0;
    var $147 = __ZN11JSAtomState16commonAtomsStartEv($146);
    var $atom_0 = HEAP32[$147 + ($134 << 2) >> 2];
    __label__ = 30;
    break;
   case 29:
    var $_idx_val = HEAP32[$135 + 56 >> 2];
    var $151 = __ZN8JSScript7getAtomEj($_idx_val, $134);
    var $atom_0 = $151;
    __label__ = 30;
    break;
   case 30:
    var $atom_0;
    HEAP8[HEAP32[$17 >> 2] + $5 | 0] = 123;
    var $155 = HEAP32[$11 >> 2];
    var $156 = $atom_0 | 0;
    var $158 = __Z15js_IsIdentifierP14JSLinearString($atom_0 | 0);
    var $160 = ($158 | 0) != 0 ? 0 : 39;
    var $161 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($4, $156, $160);
    if (($161 | 0) == 0) {
      var $_0 = 0;
      __label__ = 49;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $164 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($4, STRING_TABLE.__str1422815 | 0, 2);
    if (($164 | 0) < 0) {
      var $_0 = 0;
      __label__ = 49;
      break;
    } else {
      var $_1 = $_01;
      var $nameoff_0 = $155;
      var $oplen_0 = $36;
      var $lasti_2 = $lasti_0;
      __label__ = 32;
      break;
    }
   case 32:
    var $lasti_2;
    var $oplen_0;
    var $nameoff_0;
    var $_1;
    var $166 = $_1 + $oplen_0 | 0;
    if (($166 | 0) == ($endpc | 0)) {
      var $_0 = $166;
      __label__ = 49;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $169 = __ZL25DecompileDestructuringLHSP11SprintStackPhS1_Pi($ss, $166, $endpc, $hole);
    if (($169 | 0) == 0) {
      var $_0 = 0;
      __label__ = 49;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    if (($nameoff_0 | 0) > -1) {
      __label__ = 35;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 35:
    var $174 = HEAPU32[$11 >> 2];
    var $175 = HEAPU32[$17 >> 2];
    if (HEAP8[$175 + $174 | 0] << 24 >> 24 == 0) {
      __label__ = 36;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 36:
    var $180 = $174 - $nameoff_0 | 0;
    if (($180 | 0) > 3) {
      __label__ = 37;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 37:
    if (($180 & 1 | 0) == 0) {
      __label__ = 38;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 38:
    var $187 = ($180 - 2 | 0) >>> 1;
    var $_sum = $187 + $nameoff_0 | 0;
    var $188 = $175 + $_sum | 0;
    var $189 = _strncmp($188, STRING_TABLE.__str1422815 | 0, 2);
    if (($189 | 0) == 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 39:
    var $192 = $175 + $nameoff_0 | 0;
    var $193 = $_sum + ($175 + 2) | 0;
    var $194 = _strncmp($192, $193, $187);
    if (($194 | 0) == 0) {
      __label__ = 40;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 40:
    var $197 = $174 - 2 - $187 | 0;
    HEAP8[$175 + $197 | 0] = 0;
    HEAP32[$11 >> 2] = $197;
    __label__ = 41;
    break;
   case 41:
    if (($169 | 0) == ($endpc | 0)) {
      var $_2 = $169;
      __label__ = 48;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    if (HEAP8[$169] << 24 >> 24 == 12) {
      __label__ = 43;
      break;
    } else {
      var $_2 = $169;
      __label__ = 48;
      break;
    }
   case 43:
    var $206 = HEAP32[$27 >> 2];
    var $207 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($28, $206, $169);
    if (($207 | 0) == 0) {
      var $_2 = $169;
      __label__ = 48;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $210 = HEAPU8[$207];
    var $_mask = $210 & -8;
    if (($210 & 255) > 191 | $_mask << 24 >> 24 != 40) {
      __label__ = 45;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 45:
    if (($210 & 255) < 192 & $_mask << 24 >> 24 == 48) {
      var $_2 = $169;
      __label__ = 48;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 46:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 47;
      break;
    } else {
      var $pc_pn = $169;
      var $lasti_0 = $lasti_2;
      __label__ = 7;
      break;
    }
   case 47:
    var $217 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($4, STRING_TABLE.__str296 | 0, 2);
    if (($217 | 0) < 0) {
      var $_0 = 0;
      __label__ = 49;
      break;
    } else {
      var $pc_pn = $169;
      var $lasti_0 = $lasti_2;
      __label__ = 7;
      break;
    }
   case 48:
    var $_2;
    var $_str562729__str1432816 = HEAP8[HEAP32[$17 >> 2] + $5 | 0] << 24 >> 24 == 91 ? STRING_TABLE.__str562729 : STRING_TABLE.__str1432816;
    var $223 = $_str562729__str1432816 | 0;
    var $224 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($4, $223, 1);
    var $__2 = ($224 | 0) < 0 ? 0 : $_2;
    var $_0 = $__2;
    __label__ = 49;
    break;
   case 49:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL22DecompileDestructuringP11SprintStackPhS1_["X"] = 1;

function __ZL6PopStrP11SprintStack4JSOp($ss, $op) {
  var $2 = HEAP8[_js_CodeSpec + ($op << 3) + 3 | 0];
  var $3 = __ZL10PopStrPrecP11SprintStackh($ss, $2);
  return $3;
}

function __ZN19AutoScriptUntrapperD1Ev($this) {
  __ZN19AutoScriptUntrapperD2Ev($this);
  return;
}

function _js_DecompileValueGenerator($cx, $spindex, $_0_0_0_val$0, $_0_0_0_val$1, $fallback) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $v | 0;
    var $st$2$0 = $1 | 0;
    HEAP32[$st$2$0 >> 2] = $_0_0_0_val$0;
    var $st$2$1 = $1 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $_0_0_0_val$1;
    var $2 = __ZNK9JSContext5hasfpEv($cx);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 2:
    var $4 = __ZNK9JSContext2fpEv($cx);
    var $_idx2_val = HEAP32[$4 >> 2];
    var $5 = __ZNK2js10StackFrame13isScriptFrameEv($_idx2_val);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 3:
    var $7 = __ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind2852($cx);
    var $8 = __ZNK2js10StackFrame6scriptEv($7);
    var $_idx3_val = HEAP32[$7 >> 2];
    var $9 = __ZNK2js10StackFrame11hasImacropcEv($_idx3_val);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx4_val = HEAP32[$7 + 40 >> 2];
    var $11 = __ZNK2js10StackFrame8imacropcEv($_idx4_val);
    var $17 = $11;
    __label__ = 6;
    break;
   case 5:
    var $13 = __ZNK9JSContext4regsEv($cx);
    var $17 = HEAP32[$13 + 4 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $17;
    var $_idx5 = $8 | 0;
    var $_idx5_val = HEAP32[$_idx5 >> 2];
    var $_idx6_val = HEAP32[$8 + 32 >> 2];
    var $18 = __ZN8JSScript4mainEv($_idx5_val, $_idx6_val);
    if ($17 >>> 0 < $18 >>> 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($spindex | 0) == 0) {
      var $pc_1 = $17;
      __label__ = 20;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx_val = HEAP16[$8 + 14 >> 1];
    var $_idx1_val = HEAP16[$8 + 44 >> 1];
    var $23 = __ZL10StackDepthP8JSScript($_idx_val, $_idx1_val);
    var $24 = $23 << 2;
    var $25 = __ZN9JSContext7malloc_Ej($cx, $24);
    var $26 = $25;
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $29 = __ZL18ReconstructPCStackP9JSContextP8JSScriptPhPS3_($cx, $8, $17, $26);
    if (($29 | 0) < 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if (($spindex | 0) == 1) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $34 = $29 + $spindex | 0;
    if (($34 | 0) < 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $37 = HEAP32[$26 + ($34 << 2) >> 2];
    __ZN9JSContext5free_EPv($25);
    var $pc_1 = $37;
    __label__ = 20;
    break;
   case 13:
    var $39 = $7;
    var $40 = __ZNK2js10StackFrame4baseEv($39);
    var $41 = __ZNK9JSContext4regsEv($cx);
    var $sp_0 = HEAP32[$41 >> 2];
    __label__ = 14;
    break;
   case 14:
    var $sp_0;
    if (($sp_0 | 0) == ($40 | 0)) {
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $47 = $sp_0 - 8 | 0;
    var $_idx7 = $47 | 0;
    var $st$2$0 = $_idx7 | 0;
    var $_idx7_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx7 + 4 | 0;
    var $_idx7_val$1 = HEAP32[$st$2$1 >> 2];
    var $48 = __ZNK2JS5ValueneERKS0_($_idx7_val$0, $_idx7_val$1, $_0_0_0_val$0, $_0_0_0_val$1);
    if ($48) {
      var $sp_0 = $47;
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if ($47 >>> 0 < ($40 + ($29 << 3) | 0) >>> 0) {
      __label__ = 17;
      break;
    } else {
      var $pc_0 = $17;
      __label__ = 19;
      break;
    }
   case 17:
    var $pc_0 = HEAP32[$26 + ($47 - $40 >> 3 << 2) >> 2];
    __label__ = 19;
    break;
   case 18:
    __ZN9JSContext5free_EPv($25);
    __label__ = 25;
    break;
   case 19:
    var $pc_0;
    __ZN9JSContext5free_EPv($25);
    var $pc_1 = $pc_0;
    __label__ = 20;
    break;
   case 20:
    var $pc_1;
    var $61 = __ZNK9JSContext4regsEv($cx);
    var $62 = $61 + 4 | 0;
    var $63 = HEAP32[$62 >> 2];
    var $64 = __ZNK2js10StackFrame13maybeImacropcEv($7);
    var $65 = ($64 | 0) != 0;
    if ($65) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    HEAP32[$62 >> 2] = $64;
    __ZN2js10StackFrame13clearImacropcEv($7);
    if (($pc_1 - HEAP32[$_idx5 >> 2] | 0) >>> 0 < HEAPU32[$8 + 8 >> 2] >>> 0) {
      __label__ = 22;
      break;
    } else {
      var $name_05 = 1;
      __label__ = 23;
      break;
    }
   case 22:
    var $75 = $7;
    var $76 = __ZNK2js10StackFrame8maybeFunEv($75);
    var $77 = $76;
    var $78 = __ZL19DecompileExpressionP9JSContextP8JSScriptP10JSFunctionPh($cx, $8, $77, $pc_1);
    if ($65) {
      var $name_05 = $78;
      __label__ = 23;
      break;
    } else {
      var $name_04 = $78;
      __label__ = 24;
      break;
    }
   case 23:
    var $name_05;
    var $79 = __ZNK9JSContext4regsEv($cx);
    HEAP32[$79 + 4 >> 2] = $63;
    __ZN2js10StackFrame11setImacropcEPh($7, $64);
    var $name_04 = $name_05;
    __label__ = 24;
    break;
   case 24:
    var $name_04;
    if (($name_04 | 0) == 1) {
      __label__ = 25;
      break;
    } else {
      var $_0 = $name_04;
      __label__ = 29;
      break;
    }
   case 25:
    if (($fallback | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      var $_01 = $fallback;
      __label__ = 27;
      break;
    }
   case 26:
    var $86 = $cx;
    var $87 = __Z16js_ValueToSourceP9JSContextRKN2JS5ValueE($86, $v);
    if (($87 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      var $_01 = $87;
      __label__ = 27;
      break;
    }
   case 27:
    var $_01;
    var $_01_idx_val = HEAP32[$_01 >> 2];
    var $90 = __ZN8JSString8getCharsEP9JSContext($_01, $cx);
    if (($90 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $93 = __ZNK8JSString6lengthEv($_01_idx_val);
    var $94 = $cx;
    var $95 = __ZN2js13DeflateStringEP9JSContextPKtj($94, $90, $93);
    var $_0 = $95;
    __label__ = 29;
    break;
   case 29:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_DecompileValueGenerator["X"] = 1;

function __ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind2852($cx) {
  var $1 = __ZNK9JSContext7maybefpEv($cx);
  return $1;
}

function __ZL18ReconstructPCStackP9JSContextP8JSScriptPhPS3_($cx, $script, $target, $pcstack) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pcdepth = __stackBase__;
    var $2 = HEAPU32[$script >> 2];
    if ($2 >>> 0 > $target >>> 0) {
      var $_0 = -1;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($2 + HEAP32[$script + 8 >> 2] | 0) >>> 0 > $target >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = -1;
      __label__ = 19;
      break;
    }
   case 3:
    HEAP32[$pcdepth >> 2] = 0;
    var $10 = $cx;
    var $11 = $script;
    var $pc_0 = $2;
    __label__ = 4;
    break;
   case 4:
    var $pc_0;
    if ($pc_0 >>> 0 < $target >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 5:
    var $15 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2825($script, $pc_0);
    var $16 = _js_CodeSpec + ($15 << 3) | 0;
    var $18 = HEAP8[$16 | 0];
    var $19 = $18 << 24 >> 24;
    if ($18 << 24 >> 24 < 0) {
      __label__ = 6;
      break;
    } else {
      var $oplen_0 = $19;
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = __Z28js_GetVariableBytecodeLengthPh($pc_0);
    var $oplen_0 = $22;
    __label__ = 7;
    break;
   case 7:
    var $oplen_0;
    if ((HEAP32[_js_CodeSpec + ($15 << 3) + 4 >> 2] & 134217728 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $oplen_2 = $oplen_0;
      var $pc_2 = $pc_0;
      __label__ = 16;
      break;
    }
   case 8:
    var $29 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($10, $11, $pc_0);
    if (($29 | 0) == 0) {
      var $pc_15 = $pc_0;
      var $oplen_17 = $oplen_0;
      var $op_09 = $15;
      var $cs_011 = $16;
      __label__ = 15;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = HEAPU8[$29];
    if (($32 & 255) < 192 & ($32 & -8) << 24 >> 24 == 72) {
      __label__ = 10;
      break;
    } else {
      var $pc_16 = $pc_0;
      var $oplen_18 = $oplen_0;
      var $op_010 = $15;
      var $cs_012 = $16;
      var $51 = $32;
      __label__ = 14;
      break;
    }
   case 10:
    var $35 = _js_GetSrcNoteOffset($29, 0);
    var $36 = $pc_0 + $35 | 0;
    if ($36 >>> 0 < $target >>> 0) {
      __label__ = 11;
      break;
    } else {
      var $pc_16 = $pc_0;
      var $oplen_18 = $oplen_0;
      var $op_010 = $15;
      var $cs_012 = $16;
      var $51 = $32;
      __label__ = 14;
      break;
    }
   case 11:
    var $39 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2825($script, $36);
    var $40 = _js_CodeSpec + ($39 << 3) | 0;
    var $43 = HEAP8[$40 | 0] << 24 >> 24;
    var $_val = HEAP8[$36];
    var $44 = __ZL13GetJumpOffsetPhS_($_val, $36);
    if (($pc_0 + ($44 + $35) | 0) >>> 0 < $target >>> 0) {
      var $oplen_2 = $44;
      var $pc_2 = $36;
      __label__ = 16;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $48 = HEAPU32[$pcdepth >> 2];
    if (($48 | 0) == 0) {
      var $_0 = -1;
      __label__ = 19;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    HEAP32[$pcdepth >> 2] = $48 - 1 | 0;
    var $pc_16 = $36;
    var $oplen_18 = $43;
    var $op_010 = $39;
    var $cs_012 = $40;
    var $51 = HEAP8[$29];
    __label__ = 14;
    break;
   case 14:
    var $51;
    var $cs_012;
    var $op_010;
    var $oplen_18;
    var $pc_16;
    if (($51 & 255) < 192 & ($51 & -8) << 24 >> 24 == 88) {
      var $oplen_2 = $oplen_18;
      var $pc_2 = $pc_16;
      __label__ = 16;
      break;
    } else {
      var $pc_15 = $pc_16;
      var $oplen_17 = $oplen_18;
      var $op_09 = $op_010;
      var $cs_011 = $cs_012;
      __label__ = 15;
      break;
    }
   case 15:
    var $cs_011;
    var $op_09;
    var $oplen_17;
    var $pc_15;
    var $cs_011_idx_val = HEAP8[$cs_011 + 1 | 0];
    var $cs_011_idx1_val = HEAP8[$cs_011 + 2 | 0];
    var $53 = __ZL10SimulateOpP9JSContextP8JSScript4JSOpPK10JSCodeSpecPhPS7_Rj($script, $op_09, $cs_011_idx_val, $cs_011_idx1_val, $pc_15, $pcstack, $pcdepth);
    if (($53 | 0) < 0) {
      var $_0 = -1;
      __label__ = 19;
      break;
    } else {
      var $oplen_2 = $oplen_17;
      var $pc_2 = $pc_15;
      __label__ = 16;
      break;
    }
   case 16:
    var $pc_2;
    var $oplen_2;
    var $pc_0 = $pc_2 + $oplen_2 | 0;
    __label__ = 4;
    break;
   case 17:
    if (($pc_0 | 0) == ($target | 0)) {
      __label__ = 18;
      break;
    } else {
      var $_0 = -1;
      __label__ = 19;
      break;
    }
   case 18:
    var $_0 = HEAP32[$pcdepth >> 2];
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18ReconstructPCStackP9JSContextP8JSScriptPhPS3_["X"] = 1;

function __ZL19DecompileExpressionP9JSContextP8JSScriptP10JSFunctionPh($cx, $script, $fun, $pc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $untrapper = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $pc;
    __ZN19AutoScriptUntrapperC1EP9JSContextP8JSScriptPPh($untrapper, $cx, $script, $1);
    var $2 = HEAPU32[$1 >> 2];
    var $3 = HEAPU8[$2];
    var $4 = $3 & 255;
    if ($3 << 24 >> 24 == 1) {
      __label__ = 2;
      break;
    } else if ($3 << 24 >> 24 == 65) {
      __label__ = 3;
      break;
    } else if ($3 << 24 >> 24 == 110) {
      var $name_1 = 1;
      var $pcstack_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = _JS_strdup($cx, STRING_TABLE.__str493818 | 0);
    var $name_1 = $6;
    var $pcstack_0 = 0;
    __label__ = 17;
    break;
   case 3:
    var $8 = _JS_strdup($cx, STRING_TABLE.__str57 | 0);
    var $name_1 = $8;
    var $pcstack_0 = 0;
    __label__ = 17;
    break;
   case 4:
    var $13 = $2 + (HEAP8[_js_CodeSpec + ($4 << 3) | 0] << 24 >> 24) | 0;
    var $16 = HEAP32[_js_CodeSpec + ($4 << 3) + 4 >> 2] & 224;
    if (($16 | 0) == 64 || ($16 | 0) == 96 || ($16 | 0) == 128 || ($16 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $end_0 = $13;
      var $begin_0 = $2;
      __label__ = 10;
      break;
    }
   case 5:
    var $18 = $cx;
    var $19 = $script;
    var $20 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($18, $19, $2);
    if (($20 | 0) == 0) {
      var $name_1 = 1;
      var $pcstack_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = HEAPU8[$20];
    if (($23 & 255) > 191) {
      var $name_1 = 1;
      var $pcstack_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $27 = ($23 & 255) >>> 3;
    if (($27 | 0) == 12) {
      __label__ = 8;
      break;
    } else if (($27 | 0) == 7) {
      __label__ = 9;
      break;
    } else {
      var $name_1 = 1;
      var $pcstack_0 = 0;
      __label__ = 17;
      break;
    }
   case 8:
    var $29 = _js_GetSrcNoteOffset($20, 0);
    var $end_0 = $13;
    var $begin_0 = $2 + -$29 | 0;
    __label__ = 10;
    break;
   case 9:
    var $33 = _js_GetSrcNoteOffset($20, 0);
    var $end_0 = $2 + $33 | 0;
    var $begin_0 = $13;
    __label__ = 10;
    break;
   case 10:
    var $begin_0;
    var $end_0;
    var $38 = $end_0 - $begin_0 | 0;
    if (($38 | 0) < 1) {
      var $name_1 = 1;
      var $pcstack_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $script_idx_val = HEAP16[$script + 14 >> 1];
    var $script_idx1_val = HEAP16[$script + 44 >> 1];
    var $41 = __ZL10StackDepthP8JSScript($script_idx_val, $script_idx1_val);
    var $42 = $41 << 2;
    var $43 = __ZN9JSContext7malloc_Ej($cx, $42);
    var $44 = $43;
    if (($43 | 0) == 0) {
      var $name_1 = 0;
      var $pcstack_0 = $44;
      __label__ = 17;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $47 = __ZL18ReconstructPCStackP9JSContextP8JSScriptPhPS3_($cx, $script, $begin_0, $44);
    if (($47 | 0) < 0) {
      var $name_1 = 1;
      var $pcstack_0 = $44;
      __label__ = 17;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $50 = _js_NewPrinter($cx, $fun, 0, 0, 0, 0);
    if (($50 | 0) == 0) {
      var $name_1 = 0;
      var $pcstack_0 = $44;
      __label__ = 17;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    HEAP32[$50 + 60 >> 2] = $end_0;
    HEAP32[$50 + 64 >> 2] = $44;
    var $55 = __ZL13DecompileCodeP9JSPrinterP8JSScriptPhjj($50, $script, $begin_0, $38, $47);
    if (($55 | 0) == 0) {
      var $name_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $59 = HEAP32[$50 + 8 >> 2];
    var $61 = ($59 | 0) == 0 ? __str17668 | 0 : $59;
    var $62 = _JS_strdup($cx, $61);
    var $name_0 = $62;
    __label__ = 16;
    break;
   case 16:
    var $name_0;
    _js_DestroyPrinter($50);
    var $name_1 = $name_0;
    var $pcstack_0 = $44;
    __label__ = 17;
    break;
   case 17:
    var $pcstack_0;
    var $name_1;
    __ZN9JSContext5free_EPv($pcstack_0);
    __ZN19AutoScriptUntrapperD1Ev($untrapper);
    STACKTOP = __stackBase__;
    return $name_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19DecompileExpressionP9JSContextP8JSScriptP10JSFunctionPh["X"] = 1;

function _js_ReconstructStackDepth($cx, $script, $pc) {
  var $1 = __ZL18ReconstructPCStackP9JSContextP8JSScriptPhPS3_($cx, $script, $pc, 0);
  return $1;
}

function __ZN2js17GetBytecodeLengthEP9JSContextP8JSScriptPh($script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2825($script, $pc);
    var $3 = HEAP8[_js_CodeSpec + ($1 << 3) | 0];
    if ($3 << 24 >> 24 == -1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = $3 << 24 >> 24;
    __label__ = 4;
    break;
   case 3:
    var $8 = __Z28js_GetVariableBytecodeLength4JSOpPh($1, $pc);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js21IsValidBytecodeOffsetEP9JSContextP8JSScriptj($cx, $script, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    __ZN2js13BytecodeRangeC1EP9JSContextP8JSScript($r, $cx, $script);
    var $r_idx = $r + 8 | 0;
    var $r_idx1 = $r + 12 | 0;
    var $r_idx2 = $r + 4 | 0;
    __label__ = 2;
    break;
   case 2:
    var $r_idx_val = HEAP32[$r_idx >> 2];
    var $r_idx1_val = HEAP32[$r_idx1 >> 2];
    var $2 = __ZNK2js13BytecodeRange5emptyEv($r_idx_val, $r_idx1_val);
    if ($2) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $r_idx2_val_idx_val = HEAP32[HEAP32[$r_idx2 >> 2] >> 2];
    var $4 = __ZNK2js13BytecodeRange11frontOffsetEv($r_idx2_val_idx_val, $r_idx_val);
    if ($4 >>> 0 < $offset >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = ($4 | 0) == ($offset | 0);
    __label__ = 6;
    break;
   case 5:
    __ZN2js13BytecodeRange8popFrontEv($r);
    __label__ = 2;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13BytecodeRangeC1EP9JSContextP8JSScript($this, $cx, $script) {
  __ZN2js13BytecodeRangeC2EP9JSContextP8JSScript($this, $cx, $script);
  return;
}

function _js_free2859($p) {
  _free($p);
  return;
}

function __ZL10SimulateOpP9JSContextP8JSScript4JSOpPK10JSCodeSpecPhPS7_Rj($script, $op, $cs_0_1_val, $cs_0_2_val, $pc, $pcstack, $pcdepth) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_GetStackUses2860($cs_0_1_val, $op, $pc);
    var $2 = _js_GetStackDefs($cs_0_2_val, $script, $pc);
    var $3 = HEAPU32[$pcdepth >> 2];
    if ($3 >>> 0 < $1 >>> 0) {
      var $_0 = -1;
      __label__ = 14;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 - $1 | 0;
    HEAP32[$pcdepth >> 2] = $6;
    var $7 = $6 + $2 | 0;
    var $script_idx_val = HEAP16[$script + 14 >> 1];
    var $script_idx2_val = HEAP16[$script + 44 >> 1];
    var $8 = __ZL10StackDepthP8JSScript($script_idx_val, $script_idx2_val);
    if ($7 >>> 0 > $8 >>> 0) {
      var $_0 = -1;
      __label__ = 14;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($op | 0) == 12) {
      __label__ = 7;
      break;
    } else if (($op | 0) == 13) {
      __label__ = 9;
      break;
    } else if (($op | 0) == 10) {
      __label__ = 11;
      break;
    } else if (($op | 0) == 121 || ($op | 0) == 147) {
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($pcstack | 0) == 0 | ($2 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $i_01 = 0;
      var $14 = $6;
      __label__ = 5;
      break;
    }
   case 5:
    var $14;
    var $i_01;
    HEAP32[$pcstack + ($14 + $i_01 << 2) >> 2] = $pc;
    var $17 = $i_01 + 1 | 0;
    if (($17 | 0) == ($2 | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $i_01 = $17;
    var $14 = HEAP32[$pcdepth >> 2];
    __label__ = 5;
    break;
   case 7:
    if (($pcstack | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $23 = HEAP32[$pcstack + ($6 << 2) >> 2];
    HEAP32[$pcstack + ($6 + 1 << 2) >> 2] = $23;
    __label__ = 13;
    break;
   case 9:
    if (($pcstack | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $30 = HEAP32[$pcstack + ($6 << 2) >> 2];
    HEAP32[$pcstack + ($6 + 2 << 2) >> 2] = $30;
    var $33 = HEAP32[$pcdepth >> 2];
    var $36 = HEAP32[$pcstack + ($33 + 1 << 2) >> 2];
    var $38 = $pcstack + ($33 + 3 << 2) | 0;
    HEAP32[$38 >> 2] = $36;
    __label__ = 13;
    break;
   case 11:
    if (($pcstack | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $43 = $pcstack + ($6 + 1 << 2) | 0;
    var $44 = HEAP32[$43 >> 2];
    var $46 = HEAP32[$pcstack + ($6 << 2) >> 2];
    HEAP32[$43 >> 2] = $46;
    var $48 = $pcstack + (HEAP32[$pcdepth >> 2] << 2) | 0;
    HEAP32[$48 >> 2] = $44;
    __label__ = 13;
    break;
   case 13:
    var $50 = HEAP32[$pcdepth >> 2] + $2 | 0;
    HEAP32[$pcdepth >> 2] = $50;
    var $_0 = $50;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10SimulateOpP9JSContextP8JSScript4JSOpPK10JSCodeSpecPhPS7_Rj["X"] = 1;

function _js_GetStackUses2860($cs_0_1_val, $op, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($cs_0_1_val << 24 >> 24 > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $cs_0_1_val << 24 >> 24;
    __label__ = 4;
    break;
   case 3:
    var $5 = _js_GetVariableStackUses($op, $pc);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_GetStackDefs($cs_0_2_val, $script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($cs_0_2_val << 24 >> 24 > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $cs_0_2_val << 24 >> 24;
    __label__ = 4;
    break;
   case 3:
    var $5 = _js_GetEnterBlockStackDefs($script, $pc);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13DecompileCodeP9JSPrinterP8JSScriptPhjj($jp, $script, $pc, $len, $pcdepth) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $ss = __stackBase__ + 4;
    var $untrapper = __stackBase__ + 48;
    HEAP32[$1 >> 2] = $pc;
    var $script_idx_val = HEAP16[$script + 14 >> 1];
    var $script_idx1_val = HEAP16[$script + 44 >> 1];
    var $2 = __ZL10StackDepthP8JSScript($script_idx_val, $script_idx1_val);
    var $4 = HEAPU32[$jp >> 2];
    __ZN19AutoScriptUntrapperC1EP9JSContextP8JSScriptPPh($untrapper, $4, $script, $1);
    var $5 = $4 + 72 | 0;
    var $6 = $4 + 88 | 0;
    var $9 = HEAPU32[HEAP32[$6 >> 2] + 12 >> 2];
    var $10 = $9;
    var $11 = __ZL15InitSprintStackP9JSContextP11SprintStackP9JSPrinterj($4, $ss, $jp, $2);
    if (($11 | 0) == 0) {
      var $ok_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = $ss + 28 | 0;
    HEAP32[$14 >> 2] = $pcdepth;
    if (($pcdepth | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = $ss + 20 | 0;
    var $17 = $jp + 64 | 0;
    var $18 = $ss + 24 | 0;
    var $i_01 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_01;
    var $22 = HEAP32[$16 >> 2] + ($i_01 << 2) | 0;
    HEAP32[$22 >> 2] = -2 - $i_01 | 0;
    var $26 = HEAP8[HEAP32[HEAP32[$17 >> 2] + ($i_01 << 2) >> 2]];
    HEAP8[HEAP32[$18 >> 2] + $i_01 | 0] = $26;
    var $29 = $i_01 + 1 | 0;
    if (($29 | 0) == ($pcdepth | 0)) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = $29;
      __label__ = 4;
      break;
    }
   case 5:
    var $30 = $jp + 56 | 0;
    var $31 = HEAP32[$30 >> 2];
    HEAP32[$30 >> 2] = $script;
    var $32 = HEAP32[$1 >> 2];
    var $33 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $32, $len);
    var $34 = ($33 | 0) != 0;
    var $35 = $34 & 1;
    HEAP32[$30 >> 2] = $31;
    if ($34) {
      __label__ = 6;
      break;
    } else {
      var $ok_0 = $35;
      __label__ = 10;
      break;
    }
   case 6:
    if ((HEAP32[$14 >> 2] | 0) == 0) {
      var $ok_0 = $35;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $39 = $ss + 8 | 0;
    __label__ = 8;
    break;
   case 8:
    var $41 = HEAP32[$39 >> 2];
    var $42 = __ZL6PopOffP11SprintStack4JSOp($ss, 81);
    if (HEAPU32[$14 >> 2] >>> 0 > $pcdepth >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $46 = $41 + $42 | 0;
    _js_printf($jp, STRING_TABLE.__str382711 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $46, tempInt));
    var $ok_0 = $35;
    __label__ = 10;
    break;
   case 10:
    var $ok_0;
    var $48 = HEAPU32[$6 >> 2];
    if (($48 | 0) == ($5 | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $53 = HEAP32[$48 + 4 >> 2];
    var $55 = $48 + 12 | 0;
    if (($9 - $53 | 0) >>> 0 > (HEAP32[$55 >> 2] - $53 | 0) >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $61 = HEAP32[$4 + 96 >> 2];
    var $64 = $61 + $9 & ($61 ^ -1);
    HEAP32[$55 >> 2] = $64;
    __label__ = 14;
    break;
   case 13:
    _JS_ArenaRelease($5, $10);
    __label__ = 14;
    break;
   case 14:
    __ZN19AutoScriptUntrapperD1Ev($untrapper);
    STACKTOP = __stackBase__;
    return $ok_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13DecompileCodeP9JSPrinterP8JSScriptPhjj["X"] = 1;

function __ZL9DecompileP11SprintStackPhi4JSOp($ss, $pc, $nb) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 140;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $todo = __stackBase__;
    var $saveop = __stackBase__ + 4;
    var $i = __stackBase__ + 8;
    var $val = __stackBase__ + 12;
    var $1 = __stackBase__ + 24;
    var $smallv = __stackBase__ + 36;
    var $r = __stackBase__ + 56;
    var $2 = __stackBase__ + 64;
    var $ss2 = __stackBase__ + 72;
    var $3 = __stackBase__ + 116;
    var $4 = __stackBase__ + 124;
    var $5 = __stackBase__ + 132;
    var $6 = $ss | 0;
    var $8 = HEAPU32[$ss >> 2];
    if (__stackBase__ + 20 >>> 0 < HEAPU32[$8 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($8);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 3:
    var $16 = HEAPU32[$ss + 40 >> 2];
    var $17 = ($nb | 0) < 0;
    if ($17) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $19 = $16 + 56 | 0;
    var $20 = HEAP32[$19 >> 2];
    var $29 = HEAP32[$20 >> 2] + HEAP32[$20 + 8 >> 2] | 0;
    var $_pre_phi = $19;
    __label__ = 6;
    break;
   case 5:
    var $29 = $pc + $nb | 0;
    var $_pre_phi = $16 + 56 | 0;
    __label__ = 6;
    break;
   case 6:
    var $_pre_phi;
    var $29;
    HEAP32[$todo >> 2] = -2;
    HEAP32[$saveop >> 2] = 0;
    var $30 = $ss + 28 | 0;
    var $31 = $nb ^ -1;
    var $32 = $16 + 60 | 0;
    var $33 = $8;
    var $34 = $8;
    var $35 = $16 + 48 | 0;
    var $36 = $ss + 24 | 0;
    var $37 = $ss + 8 | 0;
    var $38 = $ss + 16 | 0;
    var $39 = $16 + 52 | 0;
    var $40 = $16 + 53 | 0;
    var $41 = $16 + 54 | 0;
    var $42 = $ss + 20 | 0;
    var $43 = $smallv | 0;
    var $44 = $r;
    var $45 = $16 | 0;
    var $46 = $16 + 68 | 0;
    var $47 = $16 + 72 | 0;
    var $48 = $29;
    var $49 = $ss + 36 | 0;
    var $50 = $ss + 32 | 0;
    var $51 = $8 + 52 | 0;
    var $52 = $2 | 0;
    var $53 = $val | 0;
    var $54 = $8 + 72 | 0;
    var $55 = $8 + 88 | 0;
    var $56 = $ss2 + 36 | 0;
    var $57 = $ss2 + 28 | 0;
    var $58 = $ss2 + 24 | 0;
    var $59 = $54 | 0;
    var $60 = $8 + 96 | 0;
    var $61 = $8;
    var $62 = $8;
    var $63 = $4 | 0;
    var $64 = $5 | 0;
    var $_idx16 = $r;
    var $_016 = $pc;
    var $rval_0 = 0;
    var $foreach_0 = 0;
    var $inXML_0 = 0;
    var $quoteAttr_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $quoteAttr_0;
    var $inXML_0;
    var $foreach_0;
    var $rval_0;
    var $_016;
    if ($17 | $_016 >>> 0 < $29 >>> 0) {
      __label__ = 8;
      break;
    } else {
      var $_0 = $_016;
      __label__ = 742;
      break;
    }
   case 8:
    var $67 = HEAPU32[$saveop >> 2];
    var $69 = HEAPU8[$_016] & 255;
    var $70 = _js_CodeSpec + ($69 << 3) | 0;
    if ((HEAP32[_js_CodeSpec + ($69 << 3) + 4 >> 2] & 262144 | 0) == 0) {
      var $_1 = $_016;
      var $op_0 = $69;
      var $cs_0 = $70;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $79 = $_016 + (HEAP8[$70 | 0] << 24 >> 24) | 0;
    if ($79 >>> 0 < $29 >>> 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = $79;
      __label__ = 742;
      break;
    }
   case 10:
    var $83 = HEAPU8[$79] & 255;
    var $_1 = $79;
    var $op_0 = $83;
    var $cs_0 = _js_CodeSpec + ($83 << 3) | 0;
    __label__ = 11;
    break;
   case 11:
    var $cs_0;
    var $op_0;
    var $_1;
    HEAP32[$saveop >> 2] = $op_0;
    var $87 = HEAPU32[$cs_0 >> 2];
    var $89 = $87 << 24 >> 24;
    var $91 = ($87 & 65535 & 65535) >>> 8 & 255;
    var $92 = _js_GetStackUses2860($91, $op_0, $_1);
    var $94 = $87 >>> 16 & 255;
    if ($17) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    if (HEAPU32[$30 >> 2] >>> 0 < $92 >>> 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $99 = HEAP32[$_pre_phi >> 2];
    var $100 = _js_GetStackDefs($94, $99, $_1);
    if (($100 - $92 + HEAP32[$30 >> 2] | 0) == ($31 | 0)) {
      var $_0 = $_1;
      __label__ = 742;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $107 = HEAPU32[__ZL9CodeToken + ($op_0 << 2) >> 2];
    var $108 = $_1 + $89 | 0;
    if (($108 | 0) == (HEAP32[$32 >> 2] | 0)) {
      __label__ = 15;
      break;
    } else {
      var $op_2 = $op_0;
      __label__ = 35;
      break;
    }
   case 15:
    var $112 = __Z20js_GetScriptedCallerP9JSContextPN2js10StackFrameE($8, 0);
    var $114 = HEAPU32[$cs_0 + 4 >> 2];
    if (($112 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN2js12ContextStackC2EP9JSContext($1, $33);
    var $117 = $112;
    var $118 = __ZN2js10StackFrame11pcQuadraticERKNS_12ContextStackEPS0_PPNS_13JSInlinedSiteE($117, $1, 0);
    if (($_1 | 0) == ($118 | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    if (($114 & 12192 | 0) == 0) {
      var $op_1 = $op_0;
      __label__ = 30;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 18:
    if (($_1 | 0) != ($pc | 0) | ($92 | 0) == 0) {
      var $op_1 = $op_0;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    if (($114 & 12192 | 0) == 0) {
      var $op_1 = $op_0;
      __label__ = 30;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $129 = $114 & 224;
    if (($129 | 0) == 32) {
      __label__ = 21;
      break;
    } else if (($129 | 0) == 64) {
      __label__ = 25;
      break;
    } else if (($129 | 0) == 96) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 21:
    var $131 = $114 & 31;
    if (($131 | 0) == 6) {
      var $137 = 84;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $135 = ($131 | 0) == 7 ? 86 : 59;
    var $137 = $135;
    __label__ = 23;
    break;
   case 23:
    var $137;
    var $141 = $92 - (HEAP8[_js_CodeSpec + ($137 << 3) + 1 | 0] << 24 >> 24) | 0;
    HEAP32[$i >> 2] = $141 - 1 | 0;
    if (($141 | 0) > 0) {
      __label__ = 24;
      break;
    } else {
      var $op_1_ph = $137;
      __label__ = 29;
      break;
    }
   case 24:
    var $144 = __ZL6PopOffP11SprintStack4JSOp($ss, 0);
    var $_pr = HEAP32[$i >> 2];
    var $145 = $_pr - 1 | 0;
    HEAP32[$i >> 2] = $145;
    if (($_pr | 0) > 0) {
      __label__ = 24;
      break;
    } else {
      var $op_1_ph = $137;
      __label__ = 29;
      break;
    }
   case 25:
    var $150 = ($114 & 256 | 0) != 0 ? 232 : 53;
    var $op_1 = $150;
    __label__ = 30;
    break;
   case 26:
    var $154 = ($114 & 256 | 0) != 0 ? 233 : 55;
    var $op_1 = $154;
    __label__ = 30;
    break;
   case 27:
    if (($op_0 | 0) == 173) {
      __label__ = 28;
      break;
    } else if (($op_0 | 0) == 124 || ($op_0 | 0) == 209) {
      var $op_1_ph = 55;
      __label__ = 29;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 28:
    HEAP32[$saveop >> 2] = 233;
    __label__ = 33;
    break;
   case 29:
    var $op_1_ph;
    HEAP32[$saveop >> 2] = $op_1_ph;
    var $op_1204 = $op_1_ph;
    __label__ = 34;
    break;
   case 30:
    var $op_1;
    HEAP32[$saveop >> 2] = $op_1;
    if (($op_1 | 0) > 231) {
      __label__ = 31;
      break;
    } else {
      var $op_1204 = $op_1;
      __label__ = 34;
      break;
    }
   case 31:
    if (($op_1 | 0) == 232) {
      __label__ = 32;
      break;
    } else if (($op_1 | 0) == 233) {
      __label__ = 33;
      break;
    } else {
      var $op_1204 = $op_1;
      __label__ = 34;
      break;
    }
   case 32:
    HEAP32[$saveop >> 2] = 53;
    var $op_1204 = 232;
    __label__ = 34;
    break;
   case 33:
    HEAP32[$saveop >> 2] = 55;
    var $op_1204 = 233;
    __label__ = 34;
    break;
   case 34:
    var $op_1204;
    HEAP32[$32 >> 2] = 0;
    var $op_2 = $op_1204;
    __label__ = 35;
    break;
   case 35:
    var $op_2;
    if (($107 | 0) == 0) {
      __label__ = 47;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    if (($92 | 0) == 2) {
      __label__ = 37;
      break;
    } else if (($92 | 0) == 1) {
      __label__ = 44;
      break;
    } else if (($92 | 0) == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 37:
    var $166 = HEAP32[$_pre_phi >> 2];
    var $167 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $166, $_1);
    if (($167 | 0) == 0) {
      __label__ = 40;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $170 = HEAPU8[$167];
    if (($170 & 255) < 192 & ($170 & -8) << 24 >> 24 == 64) {
      __label__ = 39;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 39:
    var $174 = HEAPU8[$108] & 255;
    var $175 = __ZL6PopStrP11SprintStack4JSOp($ss, $174);
    var $176 = __ZL6PopStrP11SprintStack4JSOp($ss, $174);
    var $177 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, $175);
    HEAP32[$todo >> 2] = $177;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $175;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 40:
    if (($inXML_0 | 0) == 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 41:
    var $180 = $cs_0 + 3 | 0;
    var $183 = $cs_0 + 4 | 0;
    var $187 = (HEAPU32[$183 >> 2] >>> 16 & 1) + (HEAPU8[$180] & 255) & 255;
    var $188 = __ZL10PopStrPrecP11SprintStackh($ss, $187);
    var $195 = (HEAPU32[$183 >> 2] >>> 16 & 1 ^ 1) + (HEAPU8[$180] & 255) & 255;
    var $196 = __ZL10PopStrPrecP11SprintStackh($ss, $195);
    var $197 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str402713 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $196, HEAP32[tempInt + 4 >> 2] = $107, HEAP32[tempInt + 8 >> 2] = $188, tempInt));
    HEAP32[$todo >> 2] = $197;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $188;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = 0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 42:
    if (($op_2 | 0) == 27) {
      __label__ = 43;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 43:
    var $201 = __ZL6PopStrP11SprintStack4JSOp($ss, 27);
    var $202 = __ZL6PopStrP11SprintStack4JSOp($ss, 27);
    var $203 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str283576 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $202, HEAP32[tempInt + 4 >> 2] = $201, tempInt));
    HEAP32[$todo >> 2] = $203;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $201;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 44:
    var $205 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $206 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str283576 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $107, HEAP32[tempInt + 4 >> 2] = $205, tempInt));
    HEAP32[$todo >> 2] = $206;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $205;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 45:
    var $208 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, $107);
    HEAP32[$todo >> 2] = $208;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 46:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 47:
    if (($op_2 | 0) == 7 || ($op_2 | 0) == 142) {
      __label__ = 48;
      break;
    } else if (($op_2 | 0) == 0) {
      __label__ = 49;
      break;
    } else if (($op_2 | 0) == 1) {
      __label__ = 87;
      break;
    } else if (($op_2 | 0) == 110 || ($op_2 | 0) == 217) {
      __label__ = 91;
      break;
    } else if (($op_2 | 0) == 134) {
      __label__ = 92;
      break;
    } else if (($op_2 | 0) == 135) {
      __label__ = 93;
      break;
    } else if (($op_2 | 0) == 117) {
      __label__ = 96;
      break;
    } else if (($op_2 | 0) == 116 || ($op_2 | 0) == 146) {
      __label__ = 99;
      break;
    } else if (($op_2 | 0) == 11) {
      __label__ = 100;
      break;
    } else if (($op_2 | 0) == 81 || ($op_2 | 0) == 2) {
      __label__ = 138;
      break;
    } else if (($op_2 | 0) == 3) {
      __label__ = 161;
      break;
    } else if (($op_2 | 0) == 4) {
      __label__ = 163;
      break;
    } else if (($op_2 | 0) == 201) {
      __label__ = 167;
      break;
    } else if (($op_2 | 0) == 202 || ($op_2 | 0) == 210) {
      __label__ = 209;
      break;
    } else if (($op_2 | 0) == 136 || ($op_2 | 0) == 137) {
      __label__ = 222;
      break;
    } else if (($op_2 | 0) == 215 || ($op_2 | 0) == 86) {
      __label__ = 232;
      break;
    } else if (($op_2 | 0) == 87 || ($op_2 | 0) == 132) {
      __label__ = 241;
      break;
    } else if (($op_2 | 0) == 101 || ($op_2 | 0) == 102) {
      __label__ = 244;
      break;
    } else if (($op_2 | 0) == 103 || ($op_2 | 0) == 104) {
      __label__ = 247;
      break;
    } else if (($op_2 | 0) == 155) {
      __label__ = 250;
      break;
    } else if (($op_2 | 0) == 5) {
      __label__ = 251;
      break;
    } else if (($op_2 | 0) == 154) {
      __label__ = 256;
      break;
    } else if (($op_2 | 0) == 206) {
      __label__ = 260;
      break;
    } else if (($op_2 | 0) == 207) {
      __label__ = 270;
      break;
    } else if (($op_2 | 0) == 153) {
      __label__ = 284;
      break;
    } else if (($op_2 | 0) == 112) {
      __label__ = 285;
      break;
    } else if (($op_2 | 0) == 75) {
      __label__ = 288;
      break;
    } else if (($op_2 | 0) == 78) {
      __label__ = 289;
      break;
    } else if (($op_2 | 0) == 6 || ($op_2 | 0) == 141) {
      __label__ = 292;
      break;
    } else if (($op_2 | 0) == 68 || ($op_2 | 0) == 144) {
      var $xval_0 = STRING_TABLE.__str2063358 | 0;
      __label__ = 355;
      break;
    } else if (($op_2 | 0) == 69 || ($op_2 | 0) == 145) {
      __label__ = 365;
      break;
    } else if (($op_2 | 0) == 124 || ($op_2 | 0) == 209) {
      __label__ = 366;
      break;
    } else if (($op_2 | 0) == 125 || ($op_2 | 0) == 126) {
      __label__ = 370;
      break;
    } else if (($op_2 | 0) == 13) {
      __label__ = 371;
      break;
    } else if (($op_2 | 0) == 12) {
      __label__ = 373;
      break;
    } else if (($op_2 | 0) == 85) {
      __label__ = 381;
      break;
    } else if (($op_2 | 0) == 14 || ($op_2 | 0) == 111 || ($op_2 | 0) == 157) {
      __label__ = 382;
      break;
    } else if (($op_2 | 0) == 82 || ($op_2 | 0) == 58 || ($op_2 | 0) == 123 || ($op_2 | 0) == 108 || ($op_2 | 0) == 79) {
      __label__ = 400;
      break;
    } else if (($op_2 | 0) == 74) {
      __label__ = 419;
      break;
    } else if (($op_2 | 0) == 36) {
      __label__ = 420;
      break;
    } else if (($op_2 | 0) == 37) {
      __label__ = 427;
      break;
    } else if (($op_2 | 0) == 38) {
      __label__ = 433;
      break;
    } else if (($op_2 | 0) == 186) {
      __label__ = 435;
      break;
    } else if (($op_2 | 0) == 200 || ($op_2 | 0) == 39 || ($op_2 | 0) == 40) {
      __label__ = 436;
      break;
    } else if (($op_2 | 0) == 97 || ($op_2 | 0) == 98) {
      __label__ = 437;
      break;
    } else if (($op_2 | 0) == 41 || ($op_2 | 0) == 44 || ($op_2 | 0) == 158 || ($op_2 | 0) == 159) {
      __label__ = 438;
      break;
    } else if (($op_2 | 0) == 42 || ($op_2 | 0) == 45) {
      __label__ = 446;
      break;
    } else if (($op_2 | 0) == 43 || ($op_2 | 0) == 46) {
      __label__ = 452;
      break;
    } else if (($op_2 | 0) == 99 || ($op_2 | 0) == 100) {
      __label__ = 456;
      break;
    } else if (($op_2 | 0) == 47 || ($op_2 | 0) == 50 || ($op_2 | 0) == 160 || ($op_2 | 0) == 161) {
      __label__ = 457;
      break;
    } else if (($op_2 | 0) == 48 || ($op_2 | 0) == 51) {
      __label__ = 465;
      break;
    } else if (($op_2 | 0) == 49 || ($op_2 | 0) == 52) {
      __label__ = 471;
      break;
    } else if (($op_2 | 0) == 232) {
      __label__ = 475;
      break;
    } else if (($op_2 | 0) == 187 || ($op_2 | 0) == 53 || ($op_2 | 0) == 198 || ($op_2 | 0) == 220) {
      var $op_9 = $op_2;
      __label__ = 476;
      break;
    } else if (($op_2 | 0) == 54 || ($op_2 | 0) == 226) {
      __label__ = 484;
      break;
    } else if (($op_2 | 0) == 233) {
      __label__ = 495;
      break;
    } else if (($op_2 | 0) == 196 || ($op_2 | 0) == 55) {
      __label__ = 496;
      break;
    } else if (($op_2 | 0) == 56) {
      __label__ = 501;
      break;
    } else if (($op_2 | 0) == 138) {
      __label__ = 508;
      break;
    } else if (($op_2 | 0) == 139) {
      __label__ = 509;
      break;
    } else if (($op_2 | 0) == 216 || ($op_2 | 0) == 84) {
      __label__ = 510;
      break;
    } else if (($op_2 | 0) == 57 || ($op_2 | 0) == 59 || ($op_2 | 0) == 156 || ($op_2 | 0) == 214) {
      __label__ = 512;
      break;
    } else if (($op_2 | 0) == 88) {
      __label__ = 518;
      break;
    } else if (($op_2 | 0) == 190) {
      __label__ = 519;
      break;
    } else if (($op_2 | 0) == 218) {
      __label__ = 520;
      break;
    } else if (($op_2 | 0) == 219) {
      __label__ = 521;
      break;
    } else if (($op_2 | 0) == 60) {
      __label__ = 523;
      break;
    } else if (($op_2 | 0) == 61) {
      __label__ = 524;
      break;
    } else if (($op_2 | 0) == 130 || ($op_2 | 0) == 224) {
      __label__ = 530;
      break;
    } else if (($op_2 | 0) == 131) {
      __label__ = 571;
      break;
    } else if (($op_2 | 0) == 80) {
      __label__ = 572;
      break;
    } else if (($op_2 | 0) == 162) {
      __label__ = 573;
      break;
    } else if (($op_2 | 0) == 70 || ($op_2 | 0) == 149) {
      __label__ = 575;
      break;
    } else if (($op_2 | 0) == 71 || ($op_2 | 0) == 150) {
      __label__ = 592;
      break;
    } else if (($op_2 | 0) == 120) {
      __label__ = 604;
      break;
    } else if (($op_2 | 0) == 121 || ($op_2 | 0) == 147) {
      __label__ = 624;
      break;
    } else if (($op_2 | 0) == 127 || ($op_2 | 0) == 222) {
      __label__ = 626;
      break;
    } else if (($op_2 | 0) == 83) {
      __label__ = 627;
      break;
    } else if (($op_2 | 0) == 221) {
      __label__ = 631;
      break;
    } else if (($op_2 | 0) == 89) {
      __label__ = 632;
      break;
    } else if (($op_2 | 0) == 90) {
      __label__ = 641;
      break;
    } else if (($op_2 | 0) == 91) {
      __label__ = 642;
      break;
    } else if (($op_2 | 0) == 92) {
      __label__ = 643;
      break;
    } else if (($op_2 | 0) == 94) {
      __label__ = 652;
      break;
    } else if (($op_2 | 0) == 93 || ($op_2 | 0) == 227) {
      __label__ = 655;
      break;
    } else if (($op_2 | 0) == 95) {
      __label__ = 670;
      break;
    } else if (($op_2 | 0) == 96) {
      __label__ = 671;
      break;
    } else if (($op_2 | 0) == 115) {
      __label__ = 672;
      break;
    } else if (($op_2 | 0) == 194 || ($op_2 | 0) == 195) {
      __label__ = 673;
      break;
    } else if (($op_2 | 0) == 163) {
      __label__ = 674;
      break;
    } else if (($op_2 | 0) == 164) {
      __label__ = 675;
      break;
    } else if (($op_2 | 0) == 165) {
      __label__ = 678;
      break;
    } else if (($op_2 | 0) == 166) {
      __label__ = 684;
      break;
    } else if (($op_2 | 0) == 167) {
      __label__ = 690;
      break;
    } else if (($op_2 | 0) == 168) {
      __label__ = 691;
      break;
    } else if (($op_2 | 0) == 169) {
      __label__ = 692;
      break;
    } else if (($op_2 | 0) == 170) {
      __label__ = 693;
      break;
    } else if (($op_2 | 0) == 171) {
      __label__ = 694;
      break;
    } else if (($op_2 | 0) == 172) {
      __label__ = 697;
      break;
    } else if (($op_2 | 0) == 173) {
      __label__ = 698;
      break;
    } else if (($op_2 | 0) == 181 || ($op_2 | 0) == 180) {
      __label__ = 699;
      break;
    } else if (($op_2 | 0) == 179) {
      __label__ = 700;
      break;
    } else if (($op_2 | 0) == 178 || ($op_2 | 0) == 199 || ($op_2 | 0) == 174 || ($op_2 | 0) == 176) {
      __label__ = 701;
      break;
    } else if (($op_2 | 0) == 177) {
      __label__ = 702;
      break;
    } else if (($op_2 | 0) == 175) {
      __label__ = 705;
      break;
    } else if (($op_2 | 0) == 183) {
      __label__ = 708;
      break;
    } else if (($op_2 | 0) == 184) {
      __label__ = 714;
      break;
    } else if (($op_2 | 0) == 185) {
      __label__ = 720;
      break;
    } else if (($op_2 | 0) == 208) {
      __label__ = 733;
      break;
    } else if (($op_2 | 0) == 76) {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else if (($op_2 | 0) == 118 || ($op_2 | 0) == 8 || ($op_2 | 0) == 143) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 734;
      break;
    }
   case 48:
    var $_12 = $_1;
    var $oplen_1 = $89;
    var $rval_11 = $rval_0;
    var $elseif_0 = 0;
    var $_12_val = HEAP8[$_1];
    __label__ = 324;
    break;
   case 49:
    var $213 = HEAP32[$_pre_phi >> 2];
    var $214 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $213, $_1);
    HEAP32[$todo >> 2] = -2;
    if (($214 | 0) == 0) {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    var $217 = HEAPU8[$214];
    if (($217 & 255) > 191) {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $221 = ($217 & 255) >>> 3;
    if (($221 | 0) == 4) {
      __label__ = 52;
      break;
    } else if (($221 | 0) == 3) {
      var $_2 = $_1;
      var $op_3 = $op_2;
      var $sn_0 = $214;
      var $rval_1 = __str17668 | 0;
      __label__ = 55;
      break;
    } else if (($221 | 0) == 13) {
      __label__ = 71;
      break;
    } else if (($221 | 0) == 14) {
      __label__ = 74;
      break;
    } else if (($221 | 0) == 15) {
      __label__ = 77;
      break;
    } else if (($221 | 0) == 19) {
      __label__ = 78;
      break;
    } else if (($221 | 0) == 10) {
      __label__ = 85;
      break;
    } else {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 52:
    var $223 = $_1 + 1 | 0;
    var $225 = HEAP32[$_pre_phi >> 2];
    var $226 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $225, $223);
    var $227 = _js_GetSrcNoteOffset($226, 0);
    var $228 = $227 + ($_1 + 1) | 0;
    var $229 = HEAP8[$228];
    if ($229 << 24 >> 24 == 8 || $229 << 24 >> 24 == -113) {
      __label__ = 53;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 53:
    _js_printf($16, STRING_TABLE.__str412714 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $232 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $232;
    var $233 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $223, $227);
    if (($233 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    var $237 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $237;
    var $248 = (HEAP32[_js_CodeSpec + ((HEAPU8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 1) | 0] & 255) << 3) + 4 >> 2] & 256 | 0) != 0 ? 7 : 0;
    var $249 = __ZL6PopStrP11SprintStack4JSOp($ss, $248);
    _js_printf($16, STRING_TABLE.__str422715 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $249, tempInt));
    var $254 = HEAP8[_js_CodeSpec + ((HEAPU8[$228] & 255) << 3) | 0] << 24 >> 24;
    HEAP32[$todo >> 2] = -2;
    var $_16 = $228;
    var $len_10 = $254;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 55:
    var $rval_1;
    var $sn_0;
    var $op_3;
    var $_2;
    var $256 = $_2 + 1 | 0;
    var $257 = _js_GetSrcNoteOffset($sn_0, 0);
    var $258 = _js_GetSrcNoteOffset($sn_0, 1);
    var $259 = _js_GetSrcNoteOffset($sn_0, 2);
    var $260 = ($257 | 0) != ($259 | 0);
    if ($260) {
      __label__ = 56;
      break;
    } else {
      var $pc2_0 = $256;
      __label__ = 58;
      break;
    }
   case 56:
    var $262 = HEAP8[$256];
    if ($262 << 24 >> 24 == 6 || $262 << 24 >> 24 == -115) {
      __label__ = 57;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 57:
    var $_sum94 = $262 << 24 >> 24 == 6 ? 4 : 6;
    var $pc2_0 = $_2 + $_sum94 | 0;
    __label__ = 58;
    break;
   case 58:
    var $pc2_0;
    var $267 = $259 + ($_2 + 1) | 0;
    var $_val10 = HEAP8[$267];
    var $268 = __ZL13GetJumpOffsetPhS_($_val10, $267);
    var $272 = $pc2_0 - $256 | 0;
    if (($268 + $259 | 0) == ($272 | 0)) {
      __label__ = 59;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 59:
    _js_printf($16, STRING_TABLE.__str432716 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $rval_1, tempInt));
    if ($260) {
      __label__ = 60;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 60:
    var $276 = $257 + ($_2 + 1) | 0;
    var $277 = $259 - $257 | 0;
    var $278 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $276, $277);
    if (($278 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    var $281 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_3);
    _js_printf($16, STRING_TABLE.__str442717 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $281, tempInt));
    __label__ = 62;
    break;
   case 62:
    _js_puts($16, STRING_TABLE.__str452718 | 0);
    if (($258 | 0) == ($257 | 0)) {
      var $rval_2 = $rval_1;
      __label__ = 69;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $285 = HEAPU32[$30 >> 2];
    var $286 = $258 + ($_2 + 1) | 0;
    var $288 = $257 - 1 - $258 | 0;
    var $289 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $286, $288);
    if (($289 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    var $292 = HEAPU32[$30 >> 2];
    if (($292 - $285 | 0) >>> 0 < 2) {
      __label__ = 65;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 65:
    if (($292 | 0) == ($285 | 0)) {
      __label__ = 66;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 66:
    var $304 = HEAP32[$37 >> 2] + HEAP32[$38 >> 2] | 0;
    __label__ = 68;
    break;
   case 67:
    var $302 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_3);
    var $304 = $302;
    __label__ = 68;
    break;
   case 68:
    var $304;
    _js_printf($16, STRING_TABLE.__str442717 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $304, tempInt));
    var $rval_2 = $304;
    __label__ = 69;
    break;
   case 69:
    var $rval_2;
    _js_printf($16, STRING_TABLE.__str312704 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $307 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $307;
    var $308 = $258 - $272 | 0;
    var $309 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $pc2_0, $308);
    if (($309 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    var $313 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $313;
    _js_printf($16, STRING_TABLE.__str462719 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_16 = $256;
    var $len_10 = (HEAP8[_js_CodeSpec + ((HEAPU8[$267] & 255) << 3) | 0] << 24 >> 24) + $259 | 0;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_2;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 71:
    var $321 = _js_GetSrcNoteOffset($214, 0);
    var $322 = HEAPU32[$_pre_phi >> 2];
    if ($321 >>> 0 < HEAPU32[$322 + 40 >> 2] >>> 0) {
      __label__ = 72;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 72:
    var $330 = HEAP32[HEAP32[$322 + 56 >> 2] + ($321 << 2) >> 2];
    var $332 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $332;
    var $333 = $330 | 0;
    var $334 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $333, 0);
    if (($334 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    var $340 = $334 - HEAP32[$37 >> 2] | 0;
    HEAP32[$38 >> 2] = $340;
    _js_printf($16, STRING_TABLE.__str472720 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $334, tempInt));
    var $342 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $342;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $334;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 74:
    var $344 = _js_GetSrcNoteOffset($214, 0);
    var $345 = HEAPU32[$_pre_phi >> 2];
    if ($344 >>> 0 < HEAPU32[$345 + 40 >> 2] >>> 0) {
      __label__ = 75;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 75:
    var $354 = HEAP32[HEAP32[$345 + 56 >> 2] + ($344 << 2) >> 2] | 0;
    var $355 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $354, 0);
    if (($355 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 76:
    var $361 = $355 - HEAP32[$37 >> 2] | 0;
    HEAP32[$38 >> 2] = $361;
    _js_printf($16, STRING_TABLE.__str482721 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $355, tempInt));
    var $363 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $363;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $355;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 77:
    var $366 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $366;
    _js_printf($16, STRING_TABLE.__str462719 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 78:
    var $368 = HEAP32[$_pre_phi >> 2];
    var $369 = _js_GetSrcNoteOffset($214, 0);
    var $_idx28_val = HEAP32[$368 + 4 >> 2];
    var $_idx29_val = HEAP8[$368 + 16 | 0];
    var $370 = __ZN8JSScript11getFunctionEj($_idx28_val, $_idx29_val, $369);
    var $fun_0 = $370;
    __label__ = 79;
    break;
   case 79:
    var $fun_0;
    _js_puts($16, STRING_TABLE.__str130423 | 0);
    var $372 = HEAP32[$35 >> 2];
    var $375 = HEAP8[$39] & 1 & 255;
    var $378 = HEAP8[$40] & 1 & 255;
    var $381 = HEAP8[$41] & 1 & 255;
    var $382 = _js_NewPrinter($8, $fun_0, $372, $375, $378, $381);
    if (($382 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 80:
    var $385 = _js_DecompileFunction($382);
    if (($385 | 0) == 0) {
      __label__ = 83;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 81:
    var $389 = HEAP32[$382 + 8 >> 2];
    if (($389 | 0) == 0) {
      __label__ = 84;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 82:
    _js_puts($16, $389);
    __label__ = 84;
    break;
   case 83:
    _js_DestroyPrinter($382);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 84:
    _js_DestroyPrinter($382);
    _js_puts($16, STRING_TABLE.__str1652 | 0);
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 85:
    _js_printf($16, STRING_TABLE.__str522725 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $395 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $395;
    var $396 = _js_GetSrcNoteOffset($214, 0);
    var $397 = $396 - $89 | 0;
    var $398 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $108, $397);
    if (($398 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 86;
      break;
    }
   case 86:
    var $402 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $402;
    _js_printf($16, STRING_TABLE.__str462719 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_16 = $_1;
    var $len_10 = $396;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 87:
    var $405 = HEAP32[$_pre_phi >> 2];
    var $406 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $405, $_1);
    if (($406 | 0) == 0) {
      __label__ = 91;
      break;
    } else {
      __label__ = 88;
      break;
    }
   case 88:
    var $409 = HEAPU8[$406];
    if (($409 & 255) < 192 & ($409 & -8) << 24 >> 24 == 56) {
      __label__ = 89;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 89:
    var $412 = __ZL24DecompileGroupAssignmentP11SprintStackPhS1_S1_Pi($ss, $_1, $29, $406, $todo);
    if (($412 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 90:
    if (HEAP8[$412] << 24 >> 24 == 11) {
      var $_3 = $412;
      var $oplen_0 = 3;
      __label__ = 117;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 91:
    var $417 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, __str17668 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$todo >> 2] = $417;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 92:
    _js_printf($16, STRING_TABLE.__str532726 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $420 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $420;
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 93:
    var $423 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $423;
    _js_printf($16, STRING_TABLE.__str542727 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $425 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $425;
    var $426 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16exception_cookie | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$todo >> 2] = $426;
    if (($426 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 94;
      break;
    }
   case 94:
    var $429 = __ZL7PushOffP11SprintStacki4JSOp($ss, $426, 135);
    if (($429 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 95;
      break;
    }
   case 95:
    var $432 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16retsub_pc_cookie | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$todo >> 2] = $432;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 96:
    var $434 = __ZL6PopStrP11SprintStack4JSOp($ss, 117);
    var $435 = _strcmp($434, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16retsub_pc_cookie | 0);
    if (($435 | 0) == 0) {
      __label__ = 97;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 97:
    var $438 = __ZL6PopStrP11SprintStack4JSOp($ss, 117);
    var $439 = _strcmp($438, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16exception_cookie | 0);
    if (($439 | 0) == 0) {
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 98:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $434;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 99:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 100:
    var $444 = HEAPU32[$30 >> 2];
    var $452 = (HEAPU8[$_1 + 1 | 0] & 255) << 8 | HEAPU8[$_1 + 2 | 0] & 255;
    var $453 = $444 - $452 | 0;
    if ($453 >>> 0 > $444 >>> 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 101;
      break;
    }
   case 101:
    HEAP32[$todo >> 2] = -2;
    var $457 = HEAP32[$_pre_phi >> 2];
    var $458 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $457, $_1);
    if (($458 | 0) == 0) {
      __label__ = 136;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 102:
    var $461 = HEAPU8[$458];
    var $462 = ($461 & 255) < 192;
    var $_mask116 = $461 & -8;
    if ($462 & $_mask116 << 24 >> 24 == 88) {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 103;
      break;
    }
   case 103:
    if ($462 & $_mask116 << 24 >> 24 == 56) {
      __label__ = 104;
      break;
    } else {
      __label__ = 136;
      break;
    }
   case 104:
    var $464 = __ZL9VarPrefixPh($458);
    var $465 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str552728 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $464, tempInt));
    HEAP32[$todo >> 2] = $465;
    if (($465 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 105;
      break;
    }
   case 105:
    var $467 = $444 - 1 | 0;
    var $i2_0 = $453;
    __label__ = 106;
    break;
   case 106:
    var $i2_0;
    if ($i2_0 >>> 0 < $444 >>> 0) {
      __label__ = 107;
      break;
    } else {
      __label__ = 112;
      break;
    }
   case 107:
    var $475 = HEAP32[$37 >> 2] + HEAP32[HEAP32[$42 >> 2] + ($i2_0 << 2) >> 2] | 0;
    var $477 = ($i2_0 | 0) == ($453 | 0) ? __str17668 | 0 : STRING_TABLE.__str296 | 0;
    if (($i2_0 | 0) == ($467 | 0)) {
      __label__ = 108;
      break;
    } else {
      __label__ = 109;
      break;
    }
   case 108:
    if (HEAP8[$475] << 24 >> 24 == 0) {
      var $484 = STRING_TABLE.__str296 | 0;
      __label__ = 110;
      break;
    } else {
      __label__ = 109;
      break;
    }
   case 109:
    var $484 = $475;
    __label__ = 110;
    break;
   case 110:
    var $484;
    var $485 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str283576 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $477, HEAP32[tempInt + 4 >> 2] = $484, tempInt));
    if (($485 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 111;
      break;
    }
   case 111:
    var $i2_0 = $i2_0 + 1 | 0;
    __label__ = 106;
    break;
   case 112:
    var $490 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str562729 | 0, 1);
    if (($490 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 113:
    if (($452 | 0) == 0) {
      __label__ = 114;
      break;
    } else {
      __label__ = 115;
      break;
    }
   case 114:
    var $495 = HEAP32[$todo >> 2];
    HEAP32[$38 >> 2] = $495;
    var $_3 = $_1;
    var $oplen_0 = $89;
    __label__ = 117;
    break;
   case 115:
    if ($453 >>> 0 < $444 >>> 0) {
      __label__ = 116;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 116:
    var $499 = __ZL6GetOffP11SprintStackj($ss, $453);
    HEAP32[$38 >> 2] = $499;
    HEAP32[$30 >> 2] = $453;
    var $_3 = $_1;
    var $oplen_0 = $89;
    __label__ = 117;
    break;
   case 117:
    var $oplen_0;
    var $_3;
    if (HEAP8[$_3] << 24 >> 24 == 11) {
      __label__ = 118;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 118:
    var $506 = HEAP32[$37 >> 2] + HEAP32[$todo >> 2] | 0;
    HEAP32[$todo >> 2] = -2;
    var $507 = $_3 + $oplen_0 | 0;
    if (HEAP8[$507] << 24 >> 24 == 0) {
      __label__ = 119;
      break;
    } else {
      var $pc2_1 = $507;
      __label__ = 122;
      break;
    }
   case 119:
    var $512 = HEAP8[$oplen_0 + ($_3 + 1) | 0];
    if ($512 << 24 >> 24 == -67) {
      __label__ = 120;
      break;
    } else if ($512 << 24 >> 24 == -68) {
      __label__ = 121;
      break;
    } else {
      var $pc2_1 = $507;
      __label__ = 122;
      break;
    }
   case 120:
    var $pc2_1 = $oplen_0 + ($_3 + 2) | 0;
    __label__ = 122;
    break;
   case 121:
    var $pc2_1 = $oplen_0 + ($_3 + 4) | 0;
    __label__ = 122;
    break;
   case 122:
    var $pc2_1;
    if (HEAP8[$pc2_1] << 24 >> 24 == 0) {
      __label__ = 123;
      break;
    } else {
      __label__ = 135;
      break;
    }
   case 123:
    var $522 = HEAP32[$_pre_phi >> 2];
    var $523 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $522, $pc2_1);
    if (($523 | 0) == 0) {
      __label__ = 132;
      break;
    } else {
      __label__ = 124;
      break;
    }
   case 124:
    var $526 = HEAPU8[$523];
    var $527 = ($526 & 255) < 192;
    var $_mask87 = $526 & -8;
    if ($527 & $_mask87 << 24 >> 24 == 24) {
      var $_2 = $pc2_1;
      var $op_3 = 0;
      var $sn_0 = $523;
      var $rval_1 = $506;
      __label__ = 55;
      break;
    } else {
      __label__ = 125;
      break;
    }
   case 125:
    if ($527 & $_mask87 << 24 >> 24 == 48) {
      __label__ = 127;
      break;
    } else {
      __label__ = 126;
      break;
    }
   case 126:
    var $558 = HEAP32[$todo >> 2];
    __label__ = 134;
    break;
   case 127:
    var $529 = HEAP32[$30 >> 2];
    var $530 = HEAP32[$_pre_phi >> 2];
    var $_idx20_val = HEAP16[$530 + 14 >> 1];
    var $_idx21_val = HEAP16[$530 + 44 >> 1];
    var $531 = __ZL10StackDepthP8JSScript($_idx20_val, $_idx21_val);
    if (($529 | 0) == ($531 | 0)) {
      __label__ = 128;
      break;
    } else {
      __label__ = 130;
      break;
    }
   case 128:
    var $534 = _js_GetSrcNoteOffset($523, 0);
    if (HEAP8[$534 + ($pc2_1 + 1) | 0] << 24 >> 24 == -54) {
      __label__ = 129;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 129:
    var $539 = $pc2_1 + 1 | 0;
    _js_printf($16, STRING_TABLE.__str572730 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $506, tempInt));
    _js_printf($16, STRING_TABLE.__str462719 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_16 = $539;
    var $len_10 = $534;
    var $cs_3 = $cs_0;
    var $rval_18 = $506;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 130:
    var $541 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, $506);
    HEAP32[$todo >> 2] = $541;
    if (($541 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 131;
      break;
    }
   case 131:
    var $544 = __ZL7PushOffP11SprintStacki4JSOp($ss, $541, 0);
    if (($544 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $pc2_1_pn = $pc2_1;
      var $op_6 = 81;
      var $sn_1 = $523;
      var $rval_3 = $506;
      __label__ = 147;
      break;
    }
   case 132:
    if (((HEAPU8[$_3 + 1 | 0] & 255) << 8 | HEAPU8[$_3 + 2 | 0] & 255 | 0) == 0) {
      var $_16 = $_3;
      var $len_10 = $oplen_0;
      var $cs_3 = $cs_0;
      var $rval_18 = $506;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 133;
      break;
    }
   case 133:
    var $557 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, $506);
    HEAP32[$todo >> 2] = $557;
    HEAP32[$saveop >> 2] = 0;
    var $558 = $557;
    __label__ = 134;
    break;
   case 134:
    var $558;
    if (($558 | 0) == -2) {
      __label__ = 135;
      break;
    } else {
      var $_16 = $_3;
      var $len_10 = $oplen_0;
      var $cs_3 = $cs_0;
      var $rval_18 = $506;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 135:
    _js_printf($16, STRING_TABLE.__str582731 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $506, tempInt));
    var $_16 = $_3;
    var $len_10 = $oplen_0;
    var $cs_3 = $cs_0;
    var $rval_18 = $506;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 136:
    if ($453 >>> 0 < $444 >>> 0) {
      __label__ = 137;
      break;
    } else {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 137:
    var $562 = __ZL6GetOffP11SprintStackj($ss, $453);
    HEAP32[$38 >> 2] = $562;
    HEAP32[$30 >> 2] = $453;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 138:
    var $565 = HEAP32[$_pre_phi >> 2];
    var $566 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $565, $_1);
    if (($566 | 0) == 0) {
      __label__ = 154;
      break;
    } else {
      __label__ = 139;
      break;
    }
   case 139:
    var $569 = HEAPU8[$566];
    if (($569 & 255) > 191) {
      __label__ = 154;
      break;
    } else {
      __label__ = 140;
      break;
    }
   case 140:
    var $573 = ($569 & 255) >>> 3;
    if (($573 | 0) == 3) {
      __label__ = 141;
      break;
    } else if (($573 | 0) == 7) {
      __label__ = 142;
      break;
    } else if (($573 | 0) == 11) {
      __label__ = 146;
      break;
    } else if (($573 | 0) == 6) {
      var $pc2_1_pn = $_1;
      var $op_6 = 2;
      var $sn_1 = $566;
      var $rval_3 = $rval_0;
      __label__ = 147;
      break;
    } else {
      __label__ = 154;
      break;
    }
   case 141:
    var $op_5 = HEAP8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 1) | 0] << 24 >> 24 == 113 ? 24 : 2;
    var $581 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_5);
    HEAP32[$todo >> 2] = -2;
    var $_2 = $_1;
    var $op_3 = $op_5;
    var $sn_0 = $566;
    var $rval_1 = $581;
    __label__ = 55;
    break;
   case 142:
    var $583 = __ZL6PopStrP11SprintStack4JSOp($ss, 81);
    var $584 = _JS_strdup($8, $583);
    if (($584 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 143:
    var $587 = _js_GetSrcNoteOffset($566, 0);
    var $588 = $_1 + $587 | 0;
    var $591 = $588 - $108 | 0;
    var $592 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $108, $591);
    if (($592 | 0) == 0) {
      __label__ = 144;
      break;
    } else {
      __label__ = 145;
      break;
    }
   case 144:
    __ZN9JSContext5free_EPv($584);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 145:
    var $596 = __ZL6PopStrP11SprintStack4JSOp($ss, 81);
    var $597 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str592732 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $584, HEAP32[tempInt + 4 >> 2] = $596, tempInt));
    HEAP32[$todo >> 2] = $597;
    __ZN9JSContext5free_EPv($584);
    var $_16 = $588;
    var $len_10 = 0;
    var $cs_3 = $cs_0;
    var $rval_18 = $596;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 146:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 147:
    var $rval_3;
    var $sn_1;
    var $op_6;
    var $pc2_1_pn;
    var $_4 = $pc2_1_pn + 1 | 0;
    var $600 = _js_GetSrcNoteOffset($sn_1, 0);
    var $602 = HEAP8[$600 + ($pc2_1_pn + 1) | 0];
    if ($602 << 24 >> 24 == -54) {
      __label__ = 148;
      break;
    } else if ($602 << 24 >> 24 == -46) {
      __label__ = 150;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 148:
    var $604 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_6);
    _js_printf($16, STRING_TABLE.__str572730 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $604, tempInt));
    var $606 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $606;
    var $607 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $_4, $600);
    if (($607 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 149;
      break;
    }
   case 149:
    var $611 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $611;
    _js_printf($16, STRING_TABLE.__str462719 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_4;
    var $len_10 = $600;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_3;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 150:
    var $613 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $614 = _JS_strdup($8, $613);
    if (($614 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 151;
      break;
    }
   case 151:
    HEAP32[$saveop >> 2] = 210;
    var $617 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $_4, $600);
    if (($617 | 0) == 0) {
      __label__ = 152;
      break;
    } else {
      __label__ = 153;
      break;
    }
   case 152:
    __ZN9JSContext5free_EPv($614);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 153:
    var $621 = __ZL6PopStrP11SprintStack4JSOp($ss, 111);
    var $624 = HEAP8[$621] << 24 >> 24 == 123 ? STRING_TABLE.__str602733 | 0 : STRING_TABLE.__str612734 | 0;
    var $625 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $624, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $614, HEAP32[tempInt + 4 >> 2] = $621, tempInt));
    HEAP32[$todo >> 2] = $625;
    __ZN9JSContext5free_EPv($614);
    var $_16 = $_4;
    var $len_10 = $600;
    var $cs_3 = $cs_0;
    var $rval_18 = $621;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 154:
    var $op_7 = HEAP8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 1) | 0] << 24 >> 24 == -50 ? 0 : 2;
    var $632 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_7);
    var $633 = HEAP8[$632];
    if ($633 << 24 >> 24 == 47) {
      __label__ = 155;
      break;
    } else if ($633 << 24 >> 24 == 123) {
      var $645 = STRING_TABLE.__str622735 | 0;
      __label__ = 158;
      break;
    } else if ($633 << 24 >> 24 == 0) {
      __label__ = 160;
      break;
    } else {
      __label__ = 156;
      break;
    }
   case 155:
    if (HEAP8[$632 + 1 | 0] << 24 >> 24 == 42) {
      __label__ = 159;
      break;
    } else {
      __label__ = 156;
      break;
    }
   case 156:
    var $638 = _strncmp($632, STRING_TABLE.__str252545 | 0, 8);
    if (($638 | 0) == 0) {
      __label__ = 157;
      break;
    } else {
      var $645 = STRING_TABLE.__str582731 | 0;
      __label__ = 158;
      break;
    }
   case 157:
    var $phitmp112 = HEAP8[$632 + 8 | 0] << 24 >> 24 == 32 ? STRING_TABLE.__str622735 | 0 : STRING_TABLE.__str582731 | 0;
    var $645 = $phitmp112;
    __label__ = 158;
    break;
   case 158:
    var $645;
    _js_printf($16, $645, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $632, tempInt));
    __label__ = 160;
    break;
   case 159:
    var $647 = _strcmp($632, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16exception_cookie | 0);
    if (($647 | 0) == 0) {
      __label__ = 160;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 160:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $632;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 161:
    var $651 = HEAP32[$_pre_phi >> 2];
    var $652 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $651, $_1);
    if (($652 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 162:
    var $655 = __ZL6PopStrP11SprintStack4JSOp($ss, 3);
    _js_printf($16, STRING_TABLE.__str632736 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $655, tempInt));
    var $657 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $657;
    var $658 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE11with_cookie | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$todo >> 2] = $658;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $655;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 163:
    var $661 = HEAP32[$_pre_phi >> 2];
    var $662 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $661, $_1);
    HEAP32[$todo >> 2] = -2;
    if (($662 | 0) == 0) {
      __label__ = 165;
      break;
    } else {
      __label__ = 164;
      break;
    }
   case 164:
    var $665 = HEAPU8[$662];
    if (($665 & 255) < 192 & ($665 & -8) << 24 >> 24 == 88) {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 165;
      break;
    }
   case 165:
    var $667 = __ZL6PopStrP11SprintStack4JSOp($ss, 4);
    var $668 = _strcmp($667, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE11with_cookie | 0);
    if (($668 | 0) == 0) {
      __label__ = 166;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 166:
    var $672 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $672;
    _js_printf($16, STRING_TABLE.__str462719 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $667;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 167:
    var $674 = HEAP32[$_pre_phi >> 2];
    var $675 = _js_GetIndexFromBytecode($674, $_1, 0);
    var $676 = HEAP32[$_pre_phi >> 2];
    var $_idx13_val = HEAP32[$676 + 4 >> 2];
    var $_idx14_val = HEAP8[$676 + 16 | 0];
    var $677 = __ZN8JSScript9getObjectEj($_idx13_val, $_idx14_val, $675);
    var $678 = $677;
    var $679 = __ZNK8JSObject13propertyCountEv($678);
    if ($679 >>> 0 < 6) {
      var $atomv_0 = $43;
      __label__ = 169;
      break;
    } else {
      __label__ = 168;
      break;
    }
   case 168:
    var $682 = $679 << 2;
    var $683 = __ZN9JSContext7malloc_Ej($8, $682);
    var $684 = $683;
    if (($683 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $atomv_0 = $684;
      __label__ = 169;
      break;
    }
   case 169:
    var $atomv_0;
    var $_idx15_val = HEAP32[$677 >> 2];
    var $687 = __ZNK8JSObject12lastPropertyEv($_idx15_val);
    var $688 = $687;
    __ZNK2js5Shape3allEv($44, $688);
    __label__ = 170;
    break;
   case 170:
    var $_idx16_val = HEAP32[$_idx16 >> 2];
    var $_idx16_val_idx_val = HEAP32[$_idx16_val + 32 >> 2];
    var $690 = __ZNK2js5Shape5Range5emptyEv($_idx16_val_idx_val);
    if ($690) {
      var $rval_5 = $rval_0;
      var $storemerge104 = 0;
      __label__ = 175;
      break;
    } else {
      __label__ = 171;
      break;
    }
   case 171:
    var $692 = $_idx16_val;
    var $693 = __ZNK2js5Shape5Range5frontEv($692);
    var $_idx63_val = HEAP8[$693 + 29 | 0];
    var $695 = __ZNK2js5Shape10hasShortIDEv($_idx63_val);
    if ($695) {
      __label__ = 172;
      break;
    } else {
      __label__ = 174;
      break;
    }
   case 172:
    var $699 = HEAP16[$693 + 30 >> 1] << 16 >> 16;
    if (($699 | 0) < ($679 | 0)) {
      __label__ = 173;
      break;
    } else {
      var $_10 = $_1;
      var $len_3 = $89;
      var $rval_7 = $rval_0;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    }
   case 173:
    var $703 = HEAP32[$693 + 12 >> 2];
    var $704 = __ZL12JSID_TO_ATOMi2841($703);
    var $705 = $atomv_0 + ($699 << 2) | 0;
    HEAP32[$705 >> 2] = $704;
    __label__ = 174;
    break;
   case 174:
    __ZN2js5Shape5Range8popFrontEv($r);
    __label__ = 170;
    break;
   case 175:
    var $storemerge104;
    var $rval_5;
    HEAP32[$i >> 2] = $storemerge104;
    if (($storemerge104 | 0) < ($679 | 0)) {
      __label__ = 176;
      break;
    } else {
      __label__ = 179;
      break;
    }
   case 176:
    var $711 = HEAP32[$atomv_0 + ($storemerge104 << 2) >> 2] | 0;
    var $712 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $711, 0);
    if (($712 | 0) == 0) {
      var $_10 = $_1;
      var $len_3 = $89;
      var $rval_7 = 0;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    } else {
      __label__ = 177;
      break;
    }
   case 177:
    var $718 = $712 - HEAP32[$37 >> 2] | 0;
    var $719 = __ZL7PushOffP11SprintStacki4JSOp($ss, $718, 201);
    if (($719 | 0) == 0) {
      var $_10 = $_1;
      var $len_3 = $89;
      var $rval_7 = $712;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    } else {
      __label__ = 178;
      break;
    }
   case 178:
    var $rval_5 = $712;
    var $storemerge104 = HEAP32[$i >> 2] + 1 | 0;
    __label__ = 175;
    break;
   case 179:
    var $726 = HEAP32[$_pre_phi >> 2];
    var $727 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $726, $_1);
    if (($727 | 0) == 0) {
      var $_9 = $_1;
      var $len_2 = $89;
      var $rval_6 = $rval_5;
      var $ok_1 = 1;
      __label__ = 205;
      break;
    } else {
      __label__ = 180;
      break;
    }
   case 180:
    var $730 = HEAPU8[$727];
    if (($730 & 255) > 191) {
      var $_9 = $_1;
      var $len_2 = $89;
      var $rval_6 = $rval_5;
      var $ok_1 = 1;
      __label__ = 205;
      break;
    } else {
      __label__ = 181;
      break;
    }
   case 181:
    var $734 = ($730 & 255) >>> 3;
    if (($734 | 0) == 10) {
      __label__ = 182;
      break;
    } else if (($734 | 0) == 20) {
      __label__ = 184;
      break;
    } else {
      var $_9 = $_1;
      var $len_2 = $89;
      var $rval_6 = $rval_5;
      var $ok_1 = 1;
      __label__ = 205;
      break;
    }
   case 182:
    _js_printf($16, STRING_TABLE.__str522725 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $737 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $737;
    var $738 = _js_GetSrcNoteOffset($727, 0);
    var $739 = $738 - $89 | 0;
    var $740 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $108, $739);
    var $741 = ($740 | 0) != 0;
    var $742 = $741 & 1;
    if ($741) {
      __label__ = 183;
      break;
    } else {
      var $_10 = $_1;
      var $len_3 = $738;
      var $rval_7 = $rval_5;
      var $ok_2 = $742;
      __label__ = 206;
      break;
    }
   case 183:
    var $745 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $745;
    _js_printf($16, STRING_TABLE.__str462719 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_9 = $_1;
    var $len_2 = $738;
    var $rval_6 = $rval_5;
    var $ok_1 = $742;
    __label__ = 205;
    break;
   case 184:
    var $748 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $748;
    _js_printf($16, STRING_TABLE.__str642737 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    if (HEAP8[$108] << 24 >> 24 == 118) {
      __label__ = 185;
      break;
    } else {
      var $_10 = $108;
      var $len_3 = $89;
      var $rval_7 = $rval_5;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    }
   case 185:
    var $752 = $89 + ($_1 + 1) | 0;
    var $753 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16exception_cookie | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$todo >> 2] = $753;
    if (($753 | 0) < 0) {
      var $_10 = $752;
      var $len_3 = $89;
      var $rval_7 = $rval_5;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    } else {
      __label__ = 186;
      break;
    }
   case 186:
    var $756 = __ZL7PushOffP11SprintStacki4JSOp($ss, $753, 118);
    if (($756 | 0) == 0) {
      var $_10 = $752;
      var $len_3 = $89;
      var $rval_7 = $rval_5;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    } else {
      __label__ = 187;
      break;
    }
   case 187:
    if (HEAP8[$752] << 24 >> 24 == 12) {
      __label__ = 188;
      break;
    } else {
      var $_6 = $752;
      __label__ = 193;
      break;
    }
   case 188:
    var $763 = HEAP32[$_pre_phi >> 2];
    var $764 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $763, $752);
    if (($764 | 0) == 0) {
      __label__ = 190;
      break;
    } else {
      __label__ = 189;
      break;
    }
   case 189:
    var $767 = HEAPU8[$764];
    if (($767 & 255) > 191 | ($767 & -8) << 24 >> 24 != 48) {
      __label__ = 190;
      break;
    } else {
      var $_6 = $752;
      __label__ = 193;
      break;
    }
   case 190:
    var $769 = _js_GetSrcNoteOffset($727, 0);
    if (($769 | 0) == 0) {
      var $_10 = $752;
      var $len_3 = $89;
      var $rval_7 = $rval_5;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    } else {
      __label__ = 191;
      break;
    }
   case 191:
    var $772 = $89 + ($_1 + 2) | 0;
    var $773 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16exception_cookie | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$todo >> 2] = $773;
    if (($773 | 0) < 0) {
      var $_10 = $772;
      var $len_3 = $89;
      var $rval_7 = $rval_5;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    } else {
      __label__ = 192;
      break;
    }
   case 192:
    var $776 = __ZL7PushOffP11SprintStacki4JSOp($ss, $773, 118);
    if (($776 | 0) == 0) {
      var $_10 = $772;
      var $len_3 = $89;
      var $rval_7 = $rval_5;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    } else {
      var $_6 = $772;
      __label__ = 193;
      break;
    }
   case 193:
    var $_6;
    var $778 = HEAP8[$_6];
    if ($778 << 24 >> 24 == 12) {
      __label__ = 194;
      break;
    } else if ($778 << 24 >> 24 == -124) {
      __label__ = 197;
      break;
    } else {
      var $_10 = $_6;
      var $len_3 = $89;
      var $rval_7 = $rval_5;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    }
   case 194:
    var $780 = __ZL22DecompileDestructuringP11SprintStackPhS1_($ss, $_6, $29);
    if (($780 | 0) == 0) {
      var $_10 = 0;
      var $len_3 = $89;
      var $rval_7 = $rval_5;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    } else {
      __label__ = 195;
      break;
    }
   case 195:
    if (HEAP8[$780] << 24 >> 24 == 81) {
      __label__ = 196;
      break;
    } else {
      var $_10 = $780;
      var $len_3 = $89;
      var $rval_7 = $rval_5;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    }
   case 196:
    var $786 = $780 + 1 | 0;
    var $787 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    _js_puts($16, $787);
    var $_7 = $786;
    __label__ = 198;
    break;
   case 197:
    var $801 = ((HEAPU8[$_6 + 1 | 0] & 255) << 8 | HEAPU8[$_6 + 2 | 0] & 255) - (HEAPU16[HEAP32[$_pre_phi >> 2] + 14 >> 1] & 65535) | 0;
    HEAP32[$i >> 2] = $801;
    var $802 = $_6 + 3 | 0;
    var $803 = __ZNK8JSObject12getFixedSlotEj($677, 0);
    var $_idx = $803 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $804 = __ZNK2JS5Value7toInt32Ev($_idx_val$0, $_idx_val$1);
    var $808 = HEAP32[$atomv_0 + ($801 - $804 << 2) >> 2] | 0;
    var $809 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($45, $808, 0);
    if (($809 | 0) == 0) {
      var $_10 = $802;
      var $len_3 = $89;
      var $rval_7 = $rval_5;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    } else {
      var $_7 = $802;
      __label__ = 198;
      break;
    }
   case 198:
    var $_7;
    var $812 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $813 = _strcmp($812, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16exception_cookie | 0);
    if (($813 | 0) == 0) {
      __label__ = 199;
      break;
    } else {
      var $_10 = $_7;
      var $len_3 = $89;
      var $rval_7 = $812;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    }
   case 199:
    var $816 = _js_GetSrcNoteOffset($727, 0);
    if (($816 | 0) == 0) {
      var $_8 = $_7;
      var $ok_0 = 1;
      __label__ = 204;
      break;
    } else {
      __label__ = 200;
      break;
    }
   case 200:
    var $822 = $816 + ($_1 - $_7) | 0;
    if (($822 | 0) > 0) {
      __label__ = 201;
      break;
    } else {
      var $_10 = $_7;
      var $len_3 = $822;
      var $rval_7 = $812;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    }
   case 201:
    _js_printf($16, STRING_TABLE.__str652738 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $825 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $_7, $822);
    var $826 = ($825 | 0) != 0;
    var $827 = $826 & 1;
    if ($826) {
      __label__ = 202;
      break;
    } else {
      var $_10 = $_7;
      var $len_3 = $822;
      var $rval_7 = $812;
      var $ok_2 = $827;
      __label__ = 206;
      break;
    }
   case 202:
    var $829 = __ZL6PopStrP11SprintStack4JSOp($ss, 201);
    _js_printf($16, STRING_TABLE.__str382711 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $829, tempInt));
    var $830 = $_7 + $822 | 0;
    var $831 = HEAPU8[$830];
    if ($831 << 24 >> 24 == 7 || $831 << 24 >> 24 == -114) {
      __label__ = 203;
      break;
    } else {
      var $_10 = $830;
      var $len_3 = $822;
      var $rval_7 = $812;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    }
   case 203:
    var $_8 = $_7 + ((HEAP8[_js_CodeSpec + (($831 & 255) << 3) | 0] << 24 >> 24) + $822) | 0;
    var $ok_0 = $827;
    __label__ = 204;
    break;
   case 204:
    var $ok_0;
    var $_8;
    _js_printf($16, STRING_TABLE.__str312704 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $840 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $840;
    var $_9 = $_8;
    var $len_2 = 0;
    var $rval_6 = $812;
    var $ok_1 = $ok_0;
    __label__ = 205;
    break;
   case 205:
    var $ok_1;
    var $rval_6;
    var $len_2;
    var $_9;
    HEAP32[$todo >> 2] = -2;
    var $_10 = $_9;
    var $len_3 = $len_2;
    var $rval_7 = $rval_6;
    var $ok_2 = $ok_1;
    __label__ = 206;
    break;
   case 206:
    var $ok_2;
    var $rval_7;
    var $len_3;
    var $_10;
    if (($atomv_0 | 0) == ($43 | 0)) {
      __label__ = 208;
      break;
    } else {
      __label__ = 207;
      break;
    }
   case 207:
    __ZN9JSContext5free_EPv($atomv_0);
    __label__ = 208;
    break;
   case 208:
    if (($ok_2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $_16 = $_10;
      var $len_10 = $len_3;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_7;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 209:
    var $848 = HEAP32[$_pre_phi >> 2];
    var $849 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $848, $_1);
    HEAP32[$todo >> 2] = -2;
    var $850 = ($op_2 | 0) == 210;
    if ($850) {
      __label__ = 210;
      break;
    } else {
      __label__ = 212;
      break;
    }
   case 210:
    var $852 = HEAPU8[$849];
    if (($852 & 255) < 192 & ($852 & -8) << 24 >> 24 == 96) {
      __label__ = 211;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 211:
    var $855 = __ZL6PopStrP11SprintStack4JSOp($ss, 210);
    var $rval_8 = $855;
    __label__ = 219;
    break;
   case 212:
    if (($849 | 0) == 0) {
      var $rval_8 = $rval_0;
      __label__ = 219;
      break;
    } else {
      __label__ = 213;
      break;
    }
   case 213:
    if (($op_2 | 0) == 202) {
      __label__ = 214;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 214:
    var $861 = HEAPU8[$849];
    var $862 = ($861 & 255) < 192;
    var $_mask99 = $861 & -8;
    if ($862 & $_mask99 << 24 >> 24 == 88) {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 215;
      break;
    }
   case 215:
    if ($862 & $_mask99 << 24 >> 24 == -96) {
      __label__ = 216;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 216:
    var $864 = _js_GetSrcNoteOffset($849, 0);
    var $865 = HEAP32[$30 >> 2];
    if (($864 | 0) == ($865 | 0)) {
      var $rval_8 = $rval_0;
      __label__ = 219;
      break;
    } else {
      __label__ = 217;
      break;
    }
   case 217:
    if (($864 | 0) == ($865 - 1 | 0)) {
      __label__ = 218;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 218:
    var $871 = __ZL6PopStrP11SprintStack4JSOp($ss, 202);
    var $872 = _strcmp($871, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16exception_cookie | 0);
    if (($872 | 0) == 0) {
      var $rval_8 = $871;
      __label__ = 219;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 219:
    var $rval_8;
    var $874 = HEAPU32[$30 >> 2];
    var $882 = (HEAPU8[$_1 + 1 | 0] & 255) << 8 | HEAPU8[$_1 + 2 | 0] & 255;
    if ($874 >>> 0 < $882 >>> 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 220;
      break;
    }
   case 220:
    var $885 = $874 - $882 | 0;
    HEAP32[$30 >> 2] = $885;
    var $886 = __ZL6GetOffP11SprintStackj($ss, $885);
    HEAP32[$38 >> 2] = $886;
    if ($850) {
      __label__ = 221;
      break;
    } else {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_8;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 221:
    var $888 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, $rval_8);
    HEAP32[$todo >> 2] = $888;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_8;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 222:
    var $890 = HEAP32[$46 >> 2];
    if (($890 | 0) == 0) {
      __label__ = 223;
      break;
    } else {
      var $898 = $890;
      __label__ = 224;
      break;
    }
   case 223:
    var $894 = HEAP32[$_pre_phi >> 2];
    var $895 = __ZN8JSScript17getCallerFunctionEv($894);
    var $896 = $895;
    HEAP32[$46 >> 2] = $896;
    var $898 = $896;
    __label__ = 224;
    break;
   case 224:
    var $898;
    if ((HEAP32[$47 >> 2] | 0) == 0) {
      __label__ = 225;
      break;
    } else {
      var $912 = $898;
      __label__ = 228;
      break;
    }
   case 225:
    var $902 = __ZN9JSContext4new_IN2js6VectorIP6JSAtomLj0ENS1_15TempAllocPolicyEEEPS_EEPT_T0_($8, $8);
    HEAP32[$47 >> 2] = $902;
    if (($902 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 226;
      break;
    }
   case 226:
    var $905 = HEAP32[$46 >> 2];
    var $906 = __ZNK10JSFunction6scriptEv($905);
    var $908 = $906 + 64 | 0;
    var $909 = $902;
    var $910 = __ZN2js8Bindings17getLocalNameArrayEP9JSContextPNS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEE($908, $909);
    if ($910) {
      __label__ = 227;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 227:
    var $912 = HEAP32[$46 >> 2];
    __label__ = 228;
    break;
   case 228:
    var $912;
    var $920 = (HEAPU8[$_1 + 1 | 0] & 255) << 8 | HEAPU8[$_1 + 2 | 0] & 255;
    var $921 = __ZNK10JSFunction6scriptEv($912);
    var $_idx64_val = HEAP16[$921 + 72 >> 1];
    var $922 = __ZNK2js8Bindings11countUpvarsEv($_idx64_val);
    if ($920 >>> 0 < ($922 & 65535) >>> 0) {
      __label__ = 229;
      break;
    } else {
      __label__ = 230;
      break;
    }
   case 229:
    var $_idx65_val = HEAP16[$921 + 68 >> 1];
    var $_idx66_val = HEAP16[$921 + 70 >> 1];
    var $926 = __ZNK2js8Bindings16countArgsAndVarsEv($_idx65_val, $_idx66_val);
    var $index_0 = $926 + $920 | 0;
    __label__ = 231;
    break;
   case 230:
    var $929 = HEAP32[$_pre_phi >> 2];
    var $_idx67_val = HEAP32[$929 + 4 >> 2];
    var $_idx68_val = HEAP8[$929 + 17 | 0];
    var $930 = __ZN8JSScript6upvarsEv($_idx67_val, $_idx68_val);
    var $_idx69_val = HEAP32[HEAP32[$930 >> 2] + ($920 << 2) >> 2];
    var $933 = __ZNK2js11UpvarCookie4slotEv($_idx69_val);
    var $index_0 = $933 & 65535;
    __label__ = 231;
    break;
   case 231:
    var $index_0;
    var $936 = __ZL15GetArgOrVarAtomP9JSPrinterj($16, $index_0);
    var $len_6 = $89;
    var $lval_6 = __str17668 | 0;
    var $atom_10 = $936;
    __label__ = 516;
    break;
   case 232:
    var $_1_idx61_val = HEAP8[$_1 + 1 | 0];
    var $_1_idx62_val = HEAP8[$_1 + 2 | 0];
    var $938 = __ZL9IsVarSlotP9JSPrinterPhPi($16, $_1_idx61_val, $_1_idx62_val, $i);
    var $940 = HEAPU32[$i >> 2];
    if (($938 | 0) == 0) {
      __label__ = 234;
      break;
    } else {
      __label__ = 233;
      break;
    }
   case 233:
    var $942 = __ZL15GetArgOrVarAtomP9JSPrinterj($16, $940);
    if (($942 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $len_6 = $89;
      var $lval_6 = __str17668 | 0;
      var $atom_10 = $942;
      __label__ = 516;
      break;
    }
   case 234:
    if ($940 >>> 0 < HEAPU32[$30 >> 2] >>> 0) {
      __label__ = 235;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 235:
    var $949 = HEAP32[$_pre_phi >> 2];
    var $950 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $949, $_1);
    if (($950 | 0) == 0) {
      var $sn_2 = 0;
      __label__ = 240;
      break;
    } else {
      __label__ = 236;
      break;
    }
   case 236:
    var $953 = HEAPU8[$950];
    if (($953 & 255) < 192 & ($953 & -8) << 24 >> 24 == 56) {
      __label__ = 237;
      break;
    } else {
      var $sn_2 = $950;
      __label__ = 240;
      break;
    }
   case 237:
    if (($48 - $_1 | 0) > 3 | $_1 >>> 0 > $pc >>> 0) {
      __label__ = 238;
      break;
    } else {
      var $sn_2 = 0;
      __label__ = 240;
      break;
    }
   case 238:
    var $961 = __ZL24DecompileGroupAssignmentP11SprintStackPhS1_S1_Pi($ss, $_1, $29, $950, $todo);
    if (($961 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 239;
      break;
    }
   case 239:
    if (HEAP8[$961] << 24 >> 24 == 11) {
      var $_3 = $961;
      var $oplen_0 = 3;
      __label__ = 117;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 240:
    var $sn_2;
    var $966 = HEAP32[$i >> 2];
    var $967 = __Z8GetLocalP11SprintStacki($ss, $966);
    var $968 = __ZL9VarPrefixPh($sn_2);
    var $969 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str283576 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $968, HEAP32[tempInt + 4 >> 2] = $967, tempInt));
    HEAP32[$todo >> 2] = $969;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $967;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 241:
    var $_1_idx59_val = HEAP8[$_1 + 1 | 0];
    var $_1_idx60_val = HEAP8[$_1 + 2 | 0];
    var $971 = __ZL9IsVarSlotP9JSPrinterPhPi($16, $_1_idx59_val, $_1_idx60_val, $i);
    var $973 = HEAP32[$i >> 2];
    if (($971 | 0) == 0) {
      __label__ = 243;
      break;
    } else {
      __label__ = 242;
      break;
    }
   case 242:
    var $975 = __ZL15GetArgOrVarAtomP9JSPrinterj($16, $973);
    if (($975 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $atom_0 = $975;
      __label__ = 386;
      break;
    }
   case 243:
    var $978 = __Z8GetLocalP11SprintStacki($ss, $973);
    var $979 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $op_8 = $op_2;
    var $cs_1 = $cs_0;
    var $lval_1 = $978;
    var $rval_13 = $979;
    __label__ = 389;
    break;
   case 244:
    var $_1_idx57_val = HEAP8[$_1 + 1 | 0];
    var $_1_idx58_val = HEAP8[$_1 + 2 | 0];
    var $981 = __ZL9IsVarSlotP9JSPrinterPhPi($16, $_1_idx57_val, $_1_idx58_val, $i);
    var $983 = HEAP32[$i >> 2];
    if (($981 | 0) == 0) {
      __label__ = 246;
      break;
    } else {
      __label__ = 245;
      break;
    }
   case 245:
    var $985 = __ZL15GetArgOrVarAtomP9JSPrinterj($16, $983);
    if (($985 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $atom_3 = $985;
      __label__ = 442;
      break;
    }
   case 246:
    var $988 = __Z8GetLocalP11SprintStacki($ss, $983);
    var $lval_4 = $988;
    __label__ = 444;
    break;
   case 247:
    var $_1_idx_val = HEAP8[$_1 + 1 | 0];
    var $_1_idx56_val = HEAP8[$_1 + 2 | 0];
    var $990 = __ZL9IsVarSlotP9JSPrinterPhPi($16, $_1_idx_val, $_1_idx56_val, $i);
    var $992 = HEAP32[$i >> 2];
    if (($990 | 0) == 0) {
      __label__ = 249;
      break;
    } else {
      __label__ = 248;
      break;
    }
   case 248:
    var $994 = __ZL15GetArgOrVarAtomP9JSPrinterj($16, $992);
    if (($994 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $atom_5 = $994;
      __label__ = 461;
      break;
    }
   case 249:
    var $997 = __Z8GetLocalP11SprintStacki($ss, $992);
    var $lval_5 = $997;
    __label__ = 463;
    break;
   case 250:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 251:
    var $1000 = HEAP32[$46 >> 2];
    if (($1000 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 252;
      break;
    }
   case 252:
    var $1003 = $1000 + 58 | 0;
    if ((HEAP16[$1003 >> 1] & 4096) << 16 >> 16 == 0) {
      __label__ = 256;
      break;
    } else {
      __label__ = 253;
      break;
    }
   case 253:
    var $1008 = __ZL6PopStrP11SprintStack4JSOp($ss, 111);
    var $1011 = HEAP8[$1008] << 24 >> 24 == 123 ? STRING_TABLE.__str662739 | 0 : STRING_TABLE.__str283576 | 0;
    if ((HEAP16[$1003 >> 1] & 8) << 16 >> 16 == 0) {
      __label__ = 254;
      break;
    } else {
      var $1020 = __str17668 | 0;
      __label__ = 255;
      break;
    }
   case 254:
    var $phitmp83 = (HEAP32[$1000 + 72 >> 2] | 0) == 0 ? __str17668 | 0 : STRING_TABLE.__str452718 | 0;
    var $1020 = $phitmp83;
    __label__ = 255;
    break;
   case 255:
    var $1020;
    _js_printf($16, $1011, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $1008, HEAP32[tempInt + 4 >> 2] = $1020, tempInt));
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $1008;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 256:
    var $1022 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    if (HEAP8[$1022] << 24 >> 24 == 0) {
      __label__ = 258;
      break;
    } else {
      __label__ = 257;
      break;
    }
   case 257:
    _js_printf($16, STRING_TABLE.__str672740 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = STRING_TABLE.__str30460 | 0, HEAP32[tempInt + 4 >> 2] = $1022, tempInt));
    __label__ = 259;
    break;
   case 258:
    _js_printf($16, STRING_TABLE.__str582731 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str30460 | 0, tempInt));
    __label__ = 259;
    break;
   case 259:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $1022;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 260:
    if ((HEAP32[$49 >> 2] | 0) == 0) {
      __label__ = 262;
      break;
    } else {
      __label__ = 261;
      break;
    }
   case 261:
    var $1033 = HEAP32[$_pre_phi >> 2];
    var $1034 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $1033, $_1);
    if (($1034 | 0) == 0) {
      __label__ = 262;
      break;
    } else {
      __label__ = 269;
      break;
    }
   case 262:
    var $1037 = __ZL6PopStrP11SprintStack4JSOp($ss, 111);
    if (HEAP8[$1037] << 24 >> 24 == 0) {
      __label__ = 267;
      break;
    } else {
      __label__ = 263;
      break;
    }
   case 263:
    var $1041 = _strncmp($1037, STRING_TABLE._js_yield_str | 0, 5);
    if (($1041 | 0) == 0) {
      __label__ = 264;
      break;
    } else {
      var $1050 = STRING_TABLE.__str692742 | 0;
      __label__ = 266;
      break;
    }
   case 264:
    var $1045 = HEAP8[$1037 + 5 | 0];
    if ($1045 << 24 >> 24 == 32) {
      var $1050 = STRING_TABLE.__str682741 | 0;
      __label__ = 266;
      break;
    } else {
      __label__ = 265;
      break;
    }
   case 265:
    var $phitmp80 = $1045 << 24 >> 24 == 0 ? STRING_TABLE.__str682741 | 0 : STRING_TABLE.__str692742 | 0;
    var $1050 = $phitmp80;
    __label__ = 266;
    break;
   case 266:
    var $1050;
    var $1051 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $1050, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = STRING_TABLE._js_yield_str | 0, HEAP32[tempInt + 4 >> 2] = $1037, tempInt));
    var $1055 = $1051;
    __label__ = 268;
    break;
   case 267:
    var $1053 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, STRING_TABLE._js_yield_str | 0);
    var $1055 = $1053;
    __label__ = 268;
    break;
   case 268:
    var $1055;
    HEAP32[$todo >> 2] = $1055;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $1037;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 269:
    var $1057 = HEAPU8[$1034];
    if (($1057 & 255) < 192 & ($1057 & -8) << 24 >> 24 == 88) {
      __label__ = 270;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 270:
    var $1060 = __ZL6PopStrP11SprintStack4JSOp($ss, 111);
    var $1061 = HEAPU32[$30 >> 2];
    var $pos_0 = $1061;
    __label__ = 271;
    break;
   case 271:
    var $pos_0;
    if (($pos_0 | 0) == 0) {
      var $pos_1 = 0;
      __label__ = 273;
      break;
    } else {
      __label__ = 272;
      break;
    }
   case 272:
    var $1065 = $pos_0 - 1 | 0;
    if (HEAP8[HEAP32[$36 >> 2] + $1065 | 0] << 24 >> 24 == -55) {
      var $pos_1 = $1065;
      __label__ = 273;
      break;
    } else {
      var $pos_0 = $1065;
      __label__ = 271;
      break;
    }
   case 273:
    var $pos_1;
    var $1071 = $pos_1 + 1 | 0;
    if ($1071 >>> 0 < $1061 >>> 0) {
      __label__ = 274;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 274:
    var $1073 = HEAPU32[$36 >> 2];
    var $1075 = HEAPU8[$1073 + $pos_1 | 0];
    var $1077 = ($pos_1 | 0) == 0;
    if ($1075 << 24 >> 24 != -55 | $1077) {
      var $pos_2_lcssa = $pos_1;
      var $_lcssa = $1075;
      var $_lcssa248 = $1077;
      __label__ = 276;
      break;
    } else {
      var $pos_2250 = $pos_1;
      __label__ = 275;
      break;
    }
   case 275:
    var $pos_2250;
    var $1078 = $pos_2250 - 1 | 0;
    var $1080 = HEAP8[$1073 + $1078 | 0];
    var $1082 = ($1078 | 0) == 0;
    if ($1080 << 24 >> 24 != -55 | $1082) {
      var $pos_2_lcssa = $1078;
      var $_lcssa = $1080;
      var $_lcssa248 = $1082;
      __label__ = 276;
      break;
    } else {
      var $pos_2250 = $1078;
      __label__ = 275;
      break;
    }
   case 276:
    var $_lcssa248;
    var $_lcssa;
    var $pos_2_lcssa;
    if ((HEAP32[$saveop >> 2] | 0) == 206) {
      __label__ = 277;
      break;
    } else {
      __label__ = 280;
      break;
    }
   case 277:
    if ($_lcssa248) {
      __label__ = 278;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 278:
    var $1091 = HEAP32[$37 >> 2] + HEAP32[HEAP32[$42 >> 2] + ($1071 << 2) >> 2] | 0;
    HEAP32[$38 >> 2] = 3;
    var $1092 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str283576 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $1060, HEAP32[tempInt + 4 >> 2] = $1091, tempInt));
    HEAP32[$todo >> 2] = $1092;
    if (($1092 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 279;
      break;
    }
   case 279:
    var $1095 = HEAP32[$42 >> 2];
    HEAP32[$1095 >> 2] = $1092;
    var $1097 = HEAP32[$30 >> 2] + 1 | 0;
    HEAP32[$30 >> 2] = $1097;
    var $_0 = $_1;
    __label__ = 742;
    break;
   case 280:
    if ($_lcssa << 24 >> 24 == 89) {
      __label__ = 281;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 281:
    var $1101 = HEAP32[$42 >> 2];
    var $1103 = HEAP32[$1101 + ($pos_2_lcssa << 2) >> 2];
    var $1104 = HEAP32[$37 >> 2];
    var $1105 = $1104 + $1103 | 0;
    var $1106 = HEAP8[$1105];
    if ($1106 << 24 >> 24 == 91 || $1106 << 24 >> 24 == 35) {
      __label__ = 282;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 282:
    var $1110 = $1104 + HEAP32[$1101 + ($1071 << 2) >> 2] | 0;
    HEAP32[$38 >> 2] = $1103;
    var $1111 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE10sss_format | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1105, HEAP32[tempInt + 4 >> 2] = $1060, HEAP32[tempInt + 8 >> 2] = $1110, tempInt));
    HEAP32[$todo >> 2] = $1111;
    if (($1111 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 283;
      break;
    }
   case 283:
    var $1115 = HEAP32[$42 >> 2] + ($pos_2_lcssa << 2) | 0;
    HEAP32[$1115 >> 2] = $1111;
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $1060;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 284:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 285:
    var $1119 = HEAP32[$_pre_phi >> 2];
    var $1120 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $1119, $_1);
    HEAP32[$todo >> 2] = -2;
    if (($1120 | 0) == 0) {
      __label__ = 287;
      break;
    } else {
      __label__ = 286;
      break;
    }
   case 286:
    var $1123 = HEAPU8[$1120];
    if (($1123 & 255) < 192 & ($1123 & -8) << 24 >> 24 == 88) {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 287;
      break;
    }
   case 287:
    var $1125 = __ZL6PopStrP11SprintStack4JSOp($ss, 112);
    _js_printf($16, STRING_TABLE.__str672740 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = STRING_TABLE.__str31461 | 0, HEAP32[tempInt + 4 >> 2] = $1125, tempInt));
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $1125;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 288:
    var $1131 = (HEAP8[$_1 + 1 | 0] & 6) << 24 >> 24 == 2 & 1;
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $1131;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 289:
    var $1134 = HEAP32[$_pre_phi >> 2];
    var $1135 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $1134, $_1);
    HEAP32[$todo >> 2] = -2;
    if (($1135 | 0) == 0) {
      __label__ = 291;
      break;
    } else {
      __label__ = 290;
      break;
    }
   case 290:
    var $1138 = HEAPU8[$1135];
    if (($1138 & 255) < 192 & ($1138 & -8) << 24 >> 24 == 88) {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 291;
      break;
    }
   case 291:
    var $1140 = __ZL6PopOffP11SprintStack4JSOp($ss, 78);
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 292:
    var $1143 = HEAP32[$_pre_phi >> 2];
    var $1144 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $1143, $_1);
    if (($1144 | 0) == 0) {
      __label__ = 322;
      break;
    } else {
      __label__ = 293;
      break;
    }
   case 293:
    var $1147 = HEAPU8[$1144];
    if (($1147 & 255) > 191) {
      __label__ = 322;
      break;
    } else {
      __label__ = 294;
      break;
    }
   case 294:
    var $1151 = ($1147 & 255) >>> 3;
    if (($1151 | 0) == 2) {
      __label__ = 295;
      break;
    } else if (($1151 | 0) == 4) {
      __label__ = 311;
      break;
    } else if (($1151 | 0) == 17) {
      __label__ = 315;
      break;
    } else if (($1151 | 0) == 5) {
      __label__ = 318;
      break;
    } else if (($1151 | 0) == 16) {
      __label__ = 319;
      break;
    } else if (($1151 | 0) == 11) {
      var $_11 = $_1;
      var $len_4 = $89;
      var $rval_10 = $rval_0;
      __label__ = 323;
      break;
    } else {
      __label__ = 322;
      break;
    }
   case 295:
    var $_1_val9 = HEAP8[$_1];
    var $1153 = __ZL13GetJumpOffsetPhS_($_1_val9, $_1);
    var $1154 = _js_GetSrcNoteOffset($1144, 0);
    var $1155 = _js_GetSrcNoteOffset($1144, 1);
    var $1156 = $1154 - $89 | 0;
    var $1157 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $108, $1156);
    if (($1157 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 296;
      break;
    }
   case 296:
    var $1160 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $1161 = _strlen($1160);
    HEAP8[$1160 + ($1161 - 9) | 0] = 0;
    var $1164 = HEAPU32[$30 >> 2];
    if (($1164 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 297;
      break;
    }
   case 297:
    if ((HEAP32[$50 >> 2] | 0) == 0) {
      __label__ = 298;
      break;
    } else {
      __label__ = 299;
      break;
    }
   case 298:
    if ((HEAP32[$49 >> 2] | 0) == 0) {
      __label__ = 307;
      break;
    } else {
      __label__ = 299;
      break;
    }
   case 299:
    var $1173 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $1174 = HEAP32[$30 >> 2];
    if (($1174 | 0) == 0) {
      __label__ = 303;
      break;
    } else {
      __label__ = 300;
      break;
    }
   case 300:
    if (HEAP8[HEAP32[$36 >> 2] + ($1174 - 1) | 0] << 24 >> 24 == -22) {
      __label__ = 301;
      break;
    } else {
      __label__ = 303;
      break;
    }
   case 301:
    var $1186 = HEAP32[HEAP32[$42 >> 2] + ($1174 << 2) >> 2] - 3 | 0;
    HEAP32[$38 >> 2] = $1186;
    var $1188 = ($foreach_0 | 0) != 0 ? STRING_TABLE.__ZL15js_for_each_str | 0 : STRING_TABLE.__str51111 | 0;
    var $1189 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str702743 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1188, HEAP32[tempInt + 4 >> 2] = $1160, HEAP32[tempInt + 8 >> 2] = $1173, tempInt));
    if (($1189 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 302;
      break;
    }
   case 302:
    var $storemerge74 = HEAP32[HEAP32[$42 >> 2] + (HEAP32[$30 >> 2] - 1 << 2) >> 2];
    __label__ = 304;
    break;
   case 303:
    var $1199 = ($foreach_0 | 0) != 0 ? STRING_TABLE.__ZL15js_for_each_str | 0 : STRING_TABLE.__str51111 | 0;
    var $1200 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str702743 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1199, HEAP32[tempInt + 4 >> 2] = $1160, HEAP32[tempInt + 8 >> 2] = $1173, tempInt));
    var $storemerge74 = $1200;
    __label__ = 304;
    break;
   case 304:
    var $storemerge74;
    HEAP32[$todo >> 2] = $storemerge74;
    if (($storemerge74 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 305;
      break;
    }
   case 305:
    var $1204 = __ZL7PushOffP11SprintStacki4JSOp($ss, $storemerge74, 234);
    if (($1204 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 306;
      break;
    }
   case 306:
    var $1207 = $1154 + ($_1 + 1) | 0;
    var $1209 = $1153 - 1 - $1154 | 0;
    var $1210 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $1207, $1209);
    if (($1210 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $rval_9 = $1173;
      __label__ = 309;
      break;
    }
   case 307:
    var $1213 = $1164 - 1 | 0;
    var $1214 = __ZL6GetStrP11SprintStackj($ss, $1213);
    var $1216 = $_1 + $1154 | 0;
    var $1217 = HEAP32[$_pre_phi >> 2];
    var $1218 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $1217, $1216);
    var $1219 = __ZL9VarPrefixPh($1218);
    var $1221 = ($foreach_0 | 0) != 0 ? STRING_TABLE.__ZL15js_for_each_str | 0 : STRING_TABLE.__str51111 | 0;
    _js_printf($16, STRING_TABLE.__str712744 | 0, (tempInt = STACKTOP, STACKTOP += 16, HEAP32[tempInt >> 2] = $1221, HEAP32[tempInt + 4 >> 2] = $1219, HEAP32[tempInt + 8 >> 2] = $1160, HEAP32[tempInt + 12 >> 2] = $1214, tempInt));
    var $1223 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $1223;
    var $1224 = $1154 + ($_1 + 1) | 0;
    var $1226 = $1153 - 1 - $1154 | 0;
    var $1227 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $1224, $1226);
    if (($1227 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 308;
      break;
    }
   case 308:
    var $1231 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $1231;
    _js_printf($16, STRING_TABLE.__str462719 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $rval_9 = $1214;
    __label__ = 309;
    break;
   case 309:
    var $rval_9;
    var $1233 = $_1 + $1155 | 0;
    var $1234 = HEAPU8[$1233];
    if ($1234 << 24 >> 24 == 8 || $1234 << 24 >> 24 == -113) {
      __label__ = 310;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 310:
    var $_11 = $1233;
    var $len_4 = HEAP8[_js_CodeSpec + (($1234 & 255) << 3) | 0] << 24 >> 24;
    var $rval_10 = $rval_9;
    __label__ = 323;
    break;
   case 311:
    var $_1_val8 = HEAP8[$_1];
    var $1241 = __ZL13GetJumpOffsetPhS_($_1_val8, $_1);
    var $1242 = _js_GetSrcNoteOffset($1144, 0);
    var $1243 = $_1 + $1241 | 0;
    var $1244 = $1242 - $1241 | 0;
    var $1245 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $1243, $1244);
    if (($1245 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 312;
      break;
    }
   case 312:
    var $1258 = (HEAP32[_js_CodeSpec + ((HEAPU8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 1) | 0] & 255) << 3) + 4 >> 2] & 256 | 0) != 0 ? 7 : 0;
    var $1259 = __ZL6PopStrP11SprintStack4JSOp($ss, $1258);
    _js_printf($16, STRING_TABLE.__str722745 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $1259, tempInt));
    var $1261 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $1261;
    var $1262 = $1241 - $89 | 0;
    var $1263 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $108, $1262);
    if (($1263 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 313;
      break;
    }
   case 313:
    var $1267 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $1267;
    _js_printf($16, STRING_TABLE.__str462719 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $1268 = $_1 + $1242 | 0;
    var $1269 = HEAPU8[$1268];
    if ($1269 << 24 >> 24 == 8 || $1269 << 24 >> 24 == -113) {
      __label__ = 314;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 314:
    var $1274 = HEAP8[_js_CodeSpec + (($1269 & 255) << 3) | 0] << 24 >> 24;
    HEAP32[$todo >> 2] = -2;
    var $_11 = $1268;
    var $len_4 = $1274;
    var $rval_10 = $rval_0;
    __label__ = 323;
    break;
   case 315:
    var $1276 = _js_GetSrcNoteOffset($1144, 0);
    var $1277 = HEAPU32[$_pre_phi >> 2];
    if ($1276 >>> 0 < HEAPU32[$1277 + 40 >> 2] >>> 0) {
      __label__ = 316;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 316:
    var $1286 = HEAP32[HEAP32[$1277 + 56 >> 2] + ($1276 << 2) >> 2] | 0;
    var $1287 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $1286, 0);
    if (($1287 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 317;
      break;
    }
   case 317:
    var $1293 = $1287 - HEAP32[$37 >> 2] | 0;
    HEAP32[$38 >> 2] = $1293;
    _js_printf($16, STRING_TABLE.__str732746 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $1287, tempInt));
    var $_11 = $_1;
    var $len_4 = $89;
    var $rval_10 = $1287;
    __label__ = 323;
    break;
   case 318:
    _js_printf($16, STRING_TABLE.__str742747 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_11 = $_1;
    var $len_4 = $89;
    var $rval_10 = $rval_0;
    __label__ = 323;
    break;
   case 319:
    var $1296 = _js_GetSrcNoteOffset($1144, 0);
    var $1297 = HEAPU32[$_pre_phi >> 2];
    if ($1296 >>> 0 < HEAPU32[$1297 + 40 >> 2] >>> 0) {
      __label__ = 320;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 320:
    var $1306 = HEAP32[HEAP32[$1297 + 56 >> 2] + ($1296 << 2) >> 2] | 0;
    var $1307 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $1306, 0);
    if (($1307 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 321;
      break;
    }
   case 321:
    var $1313 = $1307 - HEAP32[$37 >> 2] | 0;
    HEAP32[$38 >> 2] = $1313;
    _js_printf($16, STRING_TABLE.__str752748 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $1307, tempInt));
    var $_11 = $_1;
    var $len_4 = $89;
    var $rval_10 = $1307;
    __label__ = 323;
    break;
   case 322:
    _js_printf($16, STRING_TABLE.__str762749 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_11 = $_1;
    var $len_4 = $89;
    var $rval_10 = $rval_0;
    __label__ = 323;
    break;
   case 323:
    var $rval_10;
    var $len_4;
    var $_11;
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_11;
    var $len_10 = $len_4;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_10;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 324:
    var $_12_val;
    var $elseif_0;
    var $rval_11;
    var $oplen_1;
    var $_12;
    var $1315 = __ZL13GetJumpOffsetPhS_($_12_val, $_12);
    var $1317 = HEAP32[$_pre_phi >> 2];
    var $1318 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $1317, $_12);
    if (($1318 | 0) == 0) {
      var $_16 = $_12;
      var $len_10 = $1315;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_11;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 325;
      break;
    }
   case 325:
    var $1321 = HEAPU8[$1318];
    if (($1321 & 255) > 191) {
      var $_16 = $_12;
      var $len_10 = $1315;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_11;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 326;
      break;
    }
   case 326:
    var $1325 = ($1321 & 255) >>> 3;
    if (($1325 | 0) == 1 || ($1325 | 0) == 2) {
      __label__ = 327;
      break;
    } else if (($1325 | 0) == 9) {
      __label__ = 347;
      break;
    } else {
      var $_16 = $_12;
      var $len_10 = $1315;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_11;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 327:
    var $1337 = (HEAP32[_js_CodeSpec + ((HEAPU8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 1) | 0] & 255) << 3) + 4 >> 2] & 256 | 0) != 0 ? 7 : 0;
    var $1338 = __ZL6PopStrP11SprintStack4JSOp($ss, $1337);
    if ((HEAP32[$50 >> 2] | 0) == 0) {
      __label__ = 328;
      break;
    } else {
      __label__ = 329;
      break;
    }
   case 328:
    if ((HEAP32[$49 >> 2] | 0) == 0) {
      __label__ = 332;
      break;
    } else {
      __label__ = 329;
      break;
    }
   case 329:
    var $1345 = HEAPU8[$1318];
    if (($1345 & 255) < 192 & ($1345 & -8) << 24 >> 24 == 8) {
      __label__ = 330;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 330:
    var $1349 = HEAP32[$38 >> 2] - 3 | 0;
    HEAP32[$38 >> 2] = $1349;
    var $1350 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str772750 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $1338, tempInt));
    if (($1350 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 331;
      break;
    }
   case 331:
    __ZL12AddParenSlopP11SprintStack($ss);
    __label__ = 333;
    break;
   case 332:
    var $_str782751__str792752 = ($elseif_0 | 0) != 0 ? STRING_TABLE.__str782751 : STRING_TABLE.__str792752;
    var $1355 = $_str782751__str792752 | 0;
    _js_printf($16, $1355, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $1338, tempInt));
    var $1357 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $1357;
    __label__ = 333;
    break;
   case 333:
    var $1359 = HEAPU8[$1318];
    if (($1359 & 255) < 192 & ($1359 & -8) << 24 >> 24 == 8) {
      __label__ = 334;
      break;
    } else {
      __label__ = 335;
      break;
    }
   case 334:
    var $1363 = $1315 - $oplen_1 | 0;
    var $1364 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $_12 + $oplen_1 | 0, $1363);
    if (($1364 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $_13 = $_12;
      var $len_5 = $1315;
      __label__ = 343;
      break;
    }
   case 335:
    if ((HEAP32[$50 >> 2] | 0) == 0) {
      __label__ = 336;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 336:
    if ((HEAP32[$49 >> 2] | 0) == 0) {
      __label__ = 337;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 337:
    var $1372 = _js_GetSrcNoteOffset($1318, 0);
    var $1374 = $1372 - $oplen_1 | 0;
    var $1375 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $_12 + $oplen_1 | 0, $1374);
    if (($1375 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 338;
      break;
    }
   case 338:
    var $1379 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $1379;
    var $1380 = $_12 + $1372 | 0;
    var $1381 = HEAPU8[$1380];
    if ($1381 << 24 >> 24 == 6 || $1381 << 24 >> 24 == -115) {
      __label__ = 339;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 339:
    var $1386 = HEAP8[_js_CodeSpec + (($1381 & 255) << 3) | 0] << 24 >> 24;
    var $1387 = __ZL13GetJumpOffsetPhS_($1381, $1380);
    _js_printf($16, STRING_TABLE.__str802753 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $1388 = _js_GetSrcNoteOffset($1318, 1);
    if (($1388 | 0) == 0) {
      __label__ = 342;
      break;
    } else {
      __label__ = 340;
      break;
    }
   case 340:
    var $_sum69 = $1386 + $1372 | 0;
    var $1391 = $_12 + $_sum69 | 0;
    var $1392 = $1388 - $_sum69 | 0;
    var $1393 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $1391, $1392);
    if (($1393 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 341;
      break;
    }
   case 341:
    var $1396 = $_12 + $1388 | 0;
    var $1397 = HEAPU8[$1396];
    var $1401 = HEAP8[_js_CodeSpec + (($1397 & 255) << 3) | 0] << 24 >> 24;
    var $_12 = $1396;
    var $oplen_1 = $1401;
    var $rval_11 = $1338;
    var $elseif_0 = 1;
    var $_12_val = $1397;
    __label__ = 324;
    break;
   case 342:
    _js_printf($16, STRING_TABLE.__str812754 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $1404 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $1404;
    var $1405 = $_12 + ($1386 + $1372) | 0;
    var $1406 = $1387 - $1386 | 0;
    var $1407 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $1405, $1406);
    if (($1407 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $_13 = $1380;
      var $len_5 = $1387;
      __label__ = 343;
      break;
    }
   case 343:
    var $len_5;
    var $_13;
    if ((HEAP32[$50 >> 2] | 0) == 0) {
      __label__ = 344;
      break;
    } else {
      __label__ = 346;
      break;
    }
   case 344:
    if ((HEAP32[$49 >> 2] | 0) == 0) {
      __label__ = 345;
      break;
    } else {
      __label__ = 346;
      break;
    }
   case 345:
    var $1417 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $1417;
    _js_printf($16, STRING_TABLE.__str462719 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 346;
    break;
   case 346:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_13;
    var $len_10 = $len_5;
    var $cs_3 = $cs_0;
    var $rval_18 = $1338;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 347:
    var $1420 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $1421 = _JS_strdup($8, $1420);
    if (($1421 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 348;
      break;
    }
   case 348:
    var $1424 = _js_GetSrcNoteOffset($1318, 0);
    var $1426 = $1424 - $oplen_1 | 0;
    var $1427 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $_12 + $oplen_1 | 0, $1426);
    if (($1427 | 0) == 0) {
      __label__ = 353;
      break;
    } else {
      __label__ = 349;
      break;
    }
   case 349:
    var $1430 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $1431 = _JS_strdup($8, $1430);
    if (($1431 | 0) == 0) {
      __label__ = 353;
      break;
    } else {
      __label__ = 350;
      break;
    }
   case 350:
    var $1434 = $_12 + $1424 | 0;
    var $1435 = HEAPU8[$1434];
    if ($1435 << 24 >> 24 == 6 || $1435 << 24 >> 24 == -115) {
      __label__ = 351;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 351:
    var $1440 = HEAP8[_js_CodeSpec + (($1435 & 255) << 3) | 0] << 24 >> 24;
    var $1441 = __ZL13GetJumpOffsetPhS_($1435, $1434);
    var $1442 = $_12 + ($1440 + $1424) | 0;
    var $1443 = $1441 - $1440 | 0;
    var $1444 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $1442, $1443);
    if (($1444 | 0) == 0) {
      __label__ = 354;
      break;
    } else {
      __label__ = 352;
      break;
    }
   case 352:
    var $1447 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $1448 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str822755 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1421, HEAP32[tempInt + 4 >> 2] = $1431, HEAP32[tempInt + 8 >> 2] = $1447, tempInt));
    HEAP32[$todo >> 2] = $1448;
    __ZN9JSContext5free_EPv($1421);
    __ZN9JSContext5free_EPv($1431);
    var $_16 = $1434;
    var $len_10 = $1441;
    var $cs_3 = $cs_0;
    var $rval_18 = $1447;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 353:
    __ZN9JSContext5free_EPv($1421);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 354:
    __ZN9JSContext5free_EPv($1421);
    __ZN9JSContext5free_EPv($1431);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 355:
    var $xval_0;
    var $1451 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $1452 = _JS_strdup($8, $1451);
    if (($1452 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 356;
      break;
    }
   case 356:
    var $_1_val5 = HEAP8[$_1];
    var $1455 = __ZL13GetJumpOffsetPhS_($_1_val5, $_1);
    var $1459 = $_1 + $1455 - $108 | 0;
    var $1460 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $108, $1459);
    if (($1460 | 0) == 0) {
      __label__ = 357;
      break;
    } else {
      __label__ = 358;
      break;
    }
   case 357:
    __ZN9JSContext5free_EPv($1452);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 358:
    var $1464 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    if ((HEAP8[$39] & 1) << 24 >> 24 == 0) {
      __label__ = 363;
      break;
    } else {
      __label__ = 359;
      break;
    }
   case 359:
    var $1469 = HEAP32[$35 >> 2];
    var $1470 = _strlen($1452);
    var $1471 = _strlen($1464);
    if (($1471 + ($1470 + ($1469 + 8)) | 0) >>> 0 > 75) {
      __label__ = 360;
      break;
    } else {
      __label__ = 363;
      break;
    }
   case 360:
    var $1477 = _JS_strdup($8, $1464);
    if (($1477 | 0) == 0) {
      __label__ = 362;
      break;
    } else {
      __label__ = 361;
      break;
    }
   case 361:
    var $1480 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str842757 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $1452, HEAP32[tempInt + 4 >> 2] = $xval_0, tempInt));
    HEAP32[$todo >> 2] = $1480;
    var $1482 = HEAP32[$35 >> 2] + 4 | 0;
    var $1483 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str852758 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1482, HEAP32[tempInt + 4 >> 2] = __str17668 | 0, HEAP32[tempInt + 8 >> 2] = $1477, tempInt));
    __ZN9JSContext5free_EPv($1477);
    if (($1483 | 0) < 0) {
      __label__ = 362;
      break;
    } else {
      var $rval_12 = $1477;
      __label__ = 364;
      break;
    }
   case 362:
    HEAP32[$todo >> 2] = -1;
    var $rval_12 = $1477;
    __label__ = 364;
    break;
   case 363:
    var $1485 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str402713 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1452, HEAP32[tempInt + 4 >> 2] = $xval_0, HEAP32[tempInt + 8 >> 2] = $1464, tempInt));
    HEAP32[$todo >> 2] = $1485;
    var $rval_12 = $1464;
    __label__ = 364;
    break;
   case 364:
    var $rval_12;
    __ZN9JSContext5free_EPv($1452);
    var $_16 = $108;
    var $len_10 = $1459;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_12;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 365:
    var $xval_0 = STRING_TABLE.__str2073359 | 0;
    __label__ = 355;
    break;
   case 366:
    var $1489 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $1490 = __ZL6PopStrP11SprintStack4JSOp($ss, 55);
    var $1491 = HEAP32[$saveop >> 2];
    var $1492 = __ZL6PopStrP11SprintStack4JSOp($ss, $1491);
    var $1493 = _strcmp($1492, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE14forelem_cookie | 0);
    if (($1493 | 0) == 0) {
      __label__ = 367;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 367:
    if (HEAP8[$1489] << 24 >> 24 == 0) {
      __label__ = 368;
      break;
    } else {
      __label__ = 369;
      break;
    }
   case 368:
    var $1499 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, $1490);
    HEAP32[$todo >> 2] = $1499;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $1492;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 369:
    var $1503 = ($67 - 164 | 0) >>> 0 < 5 ? STRING_TABLE.__str1392812 | 0 : STRING_TABLE.__str1402813 | 0;
    var $1504 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $1503, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $1490, HEAP32[tempInt + 4 >> 2] = $1489, tempInt));
    HEAP32[$todo >> 2] = $1504;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $1492;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 370:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 371:
    var $1508 = HEAP32[$30 >> 2] - 2 | 0;
    var $1509 = __ZL6GetStrP11SprintStackj($ss, $1508);
    var $1510 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, $1509);
    HEAP32[$todo >> 2] = $1510;
    if (($1510 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 372;
      break;
    }
   case 372:
    var $1518 = HEAPU8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 2) | 0] & 255;
    var $1519 = __ZL7PushOffP11SprintStacki4JSOp($ss, $1510, $1518);
    if (($1519 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 373;
      break;
    }
   case 373:
    var $1523 = HEAP32[$_pre_phi >> 2];
    var $1524 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $1523, $_1);
    if (($1524 | 0) == 0) {
      __label__ = 380;
      break;
    } else {
      __label__ = 374;
      break;
    }
   case 374:
    var $1527 = HEAPU8[$1524];
    if (($1527 & 255) < 192 & ($1527 & -8) << 24 >> 24 == 48) {
      __label__ = 375;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 375:
    var $1530 = __ZL22DecompileDestructuringP11SprintStackPhS1_($ss, $_1, $29);
    if (($1530 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 376;
      break;
    }
   case 376:
    var $1533 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    HEAP32[$saveop >> 2] = 124;
    var $1534 = __ZL6PopStrP11SprintStack4JSOp($ss, 124);
    var $1535 = _strcmp($1534, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE14forelem_cookie | 0);
    var $1536 = ($1535 | 0) == 0;
    var $1537 = __ZL9VarPrefixPh($1524);
    if ($1536) {
      __label__ = 377;
      break;
    } else {
      __label__ = 379;
      break;
    }
   case 377:
    var $1539 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str283576 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $1537, HEAP32[tempInt + 4 >> 2] = $1533, tempInt));
    HEAP32[$todo >> 2] = $1539;
    if (HEAP8[$1530] << 24 >> 24 == 81) {
      __label__ = 378;
      break;
    } else {
      var $_16 = $1530;
      var $len_10 = 0;
      var $cs_3 = $cs_0;
      var $rval_18 = $1534;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 378:
    var $_16 = $1530;
    var $len_10 = 1;
    var $cs_3 = $cs_0;
    var $rval_18 = $1534;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 379:
    var $1544 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str872760 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1537, HEAP32[tempInt + 4 >> 2] = $1533, HEAP32[tempInt + 8 >> 2] = $1534, tempInt));
    HEAP32[$todo >> 2] = $1544;
    var $_16 = $1530;
    var $len_10 = 0;
    var $cs_3 = $cs_0;
    var $rval_18 = $1534;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 380:
    var $1547 = HEAP32[$30 >> 2] - 1 | 0;
    var $1548 = __ZL6GetStrP11SprintStackj($ss, $1547);
    var $1554 = HEAPU8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 1) | 0] & 255;
    HEAP32[$saveop >> 2] = $1554;
    var $1555 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, $1548);
    HEAP32[$todo >> 2] = $1555;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $1548;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 381:
    var $1564 = (HEAPU8[$_1 + 1 | 0] & 255) << 8 | HEAPU8[$_1 + 2 | 0] & 255;
    var $1565 = __ZL15GetArgOrVarAtomP9JSPrinterj($16, $1564);
    if (($1565 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $atom_0 = $1565;
      __label__ = 386;
      break;
    }
   case 382:
    var $1568 = HEAP32[$_pre_phi >> 2];
    var $1569 = _js_GetIndexFromBytecode($1568, $_1, 0);
    var $1570 = HEAPU32[$_pre_phi >> 2];
    var $1572 = HEAPU32[$1570 >> 2];
    if ($_1 >>> 0 < $1572 >>> 0) {
      __label__ = 384;
      break;
    } else {
      __label__ = 383;
      break;
    }
   case 383:
    if (($1572 + HEAP32[$1570 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 385;
      break;
    } else {
      __label__ = 384;
      break;
    }
   case 384:
    var $1581 = HEAP32[$51 >> 2] + 209948 | 0;
    var $1582 = __ZN11JSAtomState16commonAtomsStartEv($1581);
    var $atom_0 = HEAP32[$1582 + ($1569 << 2) >> 2];
    __label__ = 386;
    break;
   case 385:
    var $_idx46_val = HEAP32[$1570 + 56 >> 2];
    var $1586 = __ZN8JSScript7getAtomEj($_idx46_val, $1569);
    var $atom_0 = $1586;
    __label__ = 386;
    break;
   case 386:
    var $atom_0;
    var $1589 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_0 | 0, 0);
    if (($1589 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 387;
      break;
    }
   case 387:
    var $1592 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    if (($op_2 | 0) == 157 || ($op_2 | 0) == 111) {
      __label__ = 388;
      break;
    } else {
      var $op_8 = $op_2;
      var $cs_1 = $cs_0;
      var $lval_1 = $1589;
      var $rval_13 = $1592;
      __label__ = 389;
      break;
    }
   case 388:
    var $1594 = __ZL6PopOffP11SprintStack4JSOp($ss, $op_2);
    var $op_8 = $op_2;
    var $cs_1 = $cs_0;
    var $lval_1 = $1589;
    var $rval_13 = $1592;
    __label__ = 389;
    break;
   case 389:
    var $rval_13;
    var $lval_1;
    var $cs_1;
    var $op_8;
    var $1598 = HEAP32[$_pre_phi >> 2];
    var $1599 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $1598, $_1 - 1 | 0);
    if (($1599 | 0) == 0) {
      __label__ = 395;
      break;
    } else {
      __label__ = 390;
      break;
    }
   case 390:
    var $1602 = HEAPU8[$1599];
    if (($1602 & 255) < 192 & ($1602 & -8) << 24 >> 24 == 64) {
      __label__ = 391;
      break;
    } else {
      __label__ = 395;
      break;
    }
   case 391:
    if (($67 | 0) == 125) {
      var $1612 = STRING_TABLE.__str12882 | 0;
      __label__ = 394;
      break;
    } else {
      __label__ = 392;
      break;
    }
   case 392:
    if (($67 | 0) == 126) {
      var $1612 = STRING_TABLE.__str42885 | 0;
      __label__ = 394;
      break;
    } else {
      __label__ = 393;
      break;
    }
   case 393:
    var $1612 = HEAP32[__ZL9CodeToken + ($67 << 2) >> 2];
    __label__ = 394;
    break;
   case 394:
    var $1612;
    var $1613 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str882761 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $lval_1, HEAP32[tempInt + 4 >> 2] = $1612, HEAP32[tempInt + 8 >> 2] = $rval_13, tempInt));
    var $storemerge = $1613;
    __label__ = 396;
    break;
   case 395:
    var $1615 = HEAP32[$_pre_phi >> 2];
    var $1616 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $1615, $_1);
    var $1617 = __ZL9VarPrefixPh($1616);
    var $1618 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str872760 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1617, HEAP32[tempInt + 4 >> 2] = $lval_1, HEAP32[tempInt + 8 >> 2] = $rval_13, tempInt));
    var $storemerge = $1618;
    __label__ = 396;
    break;
   case 396:
    var $storemerge;
    HEAP32[$todo >> 2] = $storemerge;
    if (($op_8 | 0) == 132) {
      __label__ = 397;
      break;
    } else {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_1;
      var $rval_18 = $rval_13;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 397:
    var $1622 = HEAP32[$saveop >> 2];
    var $1623 = __ZL7PushOffP11SprintStacki4JSOp($ss, $storemerge, $1622);
    if (($1623 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 398;
      break;
    }
   case 398:
    var $1626 = __ZL6PopStrP11SprintStack4JSOp($ss, 132);
    if (HEAP8[$1626] << 24 >> 24 == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 399;
      break;
    }
   case 399:
    _js_printf($16, STRING_TABLE.__str582731 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $1626, tempInt));
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_1;
    var $rval_18 = $1626;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 400:
    var $1638 = (HEAPU8[$_1 + 1 | 0] & 255) << 8 | HEAPU8[$_1 + 2 | 0] & 255;
    var $1640 = ($1638 << 2) + 4 | 0;
    var $1641 = __ZN9JSContext7malloc_Ej($8, $1640);
    var $1642 = $1641;
    if (($1641 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 401;
      break;
    }
   case 401:
    HEAP32[$i >> 2] = $1638;
    var $1644 = ($1638 | 0) == 0;
    if ($1644) {
      __label__ = 403;
      break;
    } else {
      __label__ = 402;
      break;
    }
   case 402:
    var $1645 = __ZL6PopStrP11SprintStack4JSOp($ss, 111);
    var $1646 = _JS_strdup($8, $1645);
    var $1648 = $1642 + (HEAP32[$i >> 2] << 2) | 0;
    HEAP32[$1648 >> 2] = $1646;
    var $1650 = HEAP32[$i >> 2] - 1 | 0;
    HEAP32[$i >> 2] = $1650;
    if (($1650 | 0) > 0) {
      __label__ = 402;
      break;
    } else {
      __label__ = 403;
      break;
    }
   case 403:
    if (HEAPU32[$30 >> 2] >>> 0 > 1) {
      __label__ = 404;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 404:
    var $1655 = __ZL6PopOffP11SprintStack4JSOp($ss, 111);
    var $1660 = HEAPU8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 1) | 0];
    var $1661 = $1660 & 255;
    var $1662 = HEAPU32[$saveop >> 2];
    if (($1662 | 0) == 82) {
      __label__ = 405;
      break;
    } else {
      __label__ = 407;
      break;
    }
   case 405:
    if ($1660 << 24 >> 24 == 123 || $1660 << 24 >> 24 == 108 || $1660 << 24 >> 24 == 79 || $1660 << 24 >> 24 == 58) {
      var $1672 = 59;
      __label__ = 408;
      break;
    } else {
      __label__ = 406;
      break;
    }
   case 406:
    if ((HEAP32[_js_CodeSpec + ($1661 << 3) + 4 >> 2] & 524288 | 0) == 0) {
      __label__ = 407;
      break;
    } else {
      var $1672 = 59;
      __label__ = 408;
      break;
    }
   case 407:
    var $1672 = $1662;
    __label__ = 408;
    break;
   case 408:
    var $1672;
    var $1673 = __ZL6PopStrP11SprintStack4JSOp($ss, $1672);
    var $1674 = HEAP32[$saveop >> 2];
    var $1675 = _JS_strdup($8, $1673);
    HEAP32[$1642 >> 2] = $1675;
    var $ok_3 = ($1675 | 0) != 0 & 1;
    if (($1674 | 0) == 82) {
      __label__ = 409;
      break;
    } else {
      __label__ = 410;
      break;
    }
   case 409:
    var $rval_14 = $1644 ? __str17668 | 0 : STRING_TABLE.__str362709 | 0;
    var $lval_2 = $1644 ? __str17668 | 0 : STRING_TABLE.__str292702 | 0;
    var $1678 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str892762 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE._js_new_str | 0, HEAP32[tempInt + 4 >> 2] = $1675, HEAP32[tempInt + 8 >> 2] = $lval_2, tempInt));
    var $rval_15 = $rval_14;
    var $storemerge59 = $1678;
    __label__ = 411;
    break;
   case 410:
    var $1680 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str283576 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $1675, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str292702 | 0, tempInt));
    var $rval_15 = STRING_TABLE.__str362709 | 0;
    var $storemerge59 = $1680;
    __label__ = 411;
    break;
   case 411:
    var $storemerge59;
    var $rval_15;
    HEAP32[$todo >> 2] = $storemerge59;
    var $ok_4 = ($storemerge59 | 0) < 0 ? 0 : $ok_3;
    var $storemerge60 = 1;
    __label__ = 412;
    break;
   case 412:
    var $storemerge60;
    HEAP32[$i >> 2] = $storemerge60;
    if (($storemerge60 | 0) > ($1638 | 0)) {
      var $ok_5 = $ok_4;
      __label__ = 416;
      break;
    } else {
      __label__ = 413;
      break;
    }
   case 413:
    var $1687 = HEAP32[$1642 + ($storemerge60 << 2) >> 2];
    if (($1687 | 0) == 0) {
      var $ok_5 = 0;
      __label__ = 416;
      break;
    } else {
      __label__ = 414;
      break;
    }
   case 414:
    var $1691 = ($storemerge60 | 0) < ($1638 | 0) ? STRING_TABLE.__str296 | 0 : __str17668 | 0;
    var $1692 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str283576 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $1687, HEAP32[tempInt + 4 >> 2] = $1691, tempInt));
    if (($1692 | 0) < 0) {
      var $ok_5 = 0;
      __label__ = 416;
      break;
    } else {
      __label__ = 415;
      break;
    }
   case 415:
    var $storemerge60 = HEAP32[$i >> 2] + 1 | 0;
    __label__ = 412;
    break;
   case 416:
    var $ok_5;
    var $1698 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $rval_15, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$i >> 2] = 0;
    var $storemerge61246 = 0;
    __label__ = 417;
    break;
   case 417:
    var $storemerge61246;
    var $1701 = HEAP32[$1642 + ($storemerge61246 << 2) >> 2];
    __ZN9JSContext5free_EPv($1701);
    var $1703 = HEAP32[$i >> 2] + 1 | 0;
    HEAP32[$i >> 2] = $1703;
    if (($1703 | 0) > ($1638 | 0)) {
      __label__ = 418;
      break;
    } else {
      var $storemerge61246 = $1703;
      __label__ = 417;
      break;
    }
   case 418:
    var $1706 = ($1698 | 0) < 0;
    __ZN9JSContext5free_EPv($1641);
    if ($1706 | ($ok_5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_15;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 419:
    var $1710 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, __str17668 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$todo >> 2] = $1710;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 420:
    var $1712 = HEAP32[$_pre_phi >> 2];
    var $1713 = _js_GetIndexFromBytecode($1712, $_1, 0);
    var $1714 = HEAPU32[$_pre_phi >> 2];
    var $1716 = HEAPU32[$1714 >> 2];
    if ($_1 >>> 0 < $1716 >>> 0) {
      __label__ = 422;
      break;
    } else {
      __label__ = 421;
      break;
    }
   case 421:
    if (($1716 + HEAP32[$1714 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 423;
      break;
    } else {
      __label__ = 422;
      break;
    }
   case 422:
    var $1725 = HEAP32[$51 >> 2] + 209948 | 0;
    var $1726 = __ZN11JSAtomState16commonAtomsStartEv($1725);
    var $atom_1 = HEAP32[$1726 + ($1713 << 2) >> 2];
    __label__ = 424;
    break;
   case 423:
    var $_idx45_val = HEAP32[$1714 + 56 >> 2];
    var $1730 = __ZN8JSScript7getAtomEj($_idx45_val, $1713);
    var $atom_1 = $1730;
    __label__ = 424;
    break;
   case 424:
    var $atom_1;
    var $1733 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_1 | 0, 0);
    if (($1733 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 425;
      break;
    }
   case 425:
    var $1739 = $1733 - HEAP32[$37 >> 2] | 0;
    HEAP32[$38 >> 2] = $1739;
    var $lval_3 = $1733;
    __label__ = 426;
    break;
   case 426:
    var $lval_3;
    var $1741 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str692742 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = STRING_TABLE.__str34080 | 0, HEAP32[tempInt + 4 >> 2] = $lval_3, tempInt));
    HEAP32[$todo >> 2] = $1741;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 427:
    var $1743 = HEAP32[$_pre_phi >> 2];
    var $1744 = _js_GetIndexFromBytecode($1743, $_1, 0);
    var $1745 = HEAPU32[$_pre_phi >> 2];
    var $1747 = HEAPU32[$1745 >> 2];
    if ($_1 >>> 0 < $1747 >>> 0) {
      __label__ = 429;
      break;
    } else {
      __label__ = 428;
      break;
    }
   case 428:
    if (($1747 + HEAP32[$1745 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 430;
      break;
    } else {
      __label__ = 429;
      break;
    }
   case 429:
    var $1756 = HEAP32[$51 >> 2] + 209948 | 0;
    var $1757 = __ZN11JSAtomState16commonAtomsStartEv($1756);
    var $atom_2 = HEAP32[$1757 + ($1744 << 2) >> 2];
    __label__ = 431;
    break;
   case 430:
    var $_idx44_val = HEAP32[$1745 + 56 >> 2];
    var $1761 = __ZN8JSScript7getAtomEj($_idx44_val, $1744);
    var $atom_2 = $1761;
    __label__ = 431;
    break;
   case 431:
    var $atom_2;
    var $1764 = __Z15js_IsIdentifierP14JSLinearString($atom_2 | 0);
    var $1765 = ($1764 | 0) == 0;
    var $_150 = $1765 ? 39 : 0;
    var $1767 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_2 | 0, $_150);
    if (($1767 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 432;
      break;
    }
   case 432:
    var $_151 = $1765 ? STRING_TABLE.__str902763 | 0 : STRING_TABLE.__str912764 | 0;
    var $1770 = __ZL6PopStrP11SprintStack4JSOp($ss, 53);
    var $1771 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $_151, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str34080 | 0, HEAP32[tempInt + 4 >> 2] = $1770, HEAP32[tempInt + 8 >> 2] = $1767, tempInt));
    HEAP32[$todo >> 2] = $1771;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $1767;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 433:
    var $1773 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $1774 = __ZL6PopStrP11SprintStack4JSOp($ss, 53);
    if (HEAP8[$1773] << 24 >> 24 == 0) {
      var $lval_3 = $1774;
      __label__ = 426;
      break;
    } else {
      __label__ = 434;
      break;
    }
   case 434:
    var $1780 = ($67 - 164 | 0) >>> 0 < 5 ? STRING_TABLE.__str912764 | 0 : STRING_TABLE.__str902763 | 0;
    var $1781 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $1780, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str34080 | 0, HEAP32[tempInt + 4 >> 2] = $1774, HEAP32[tempInt + 8 >> 2] = $1773, tempInt));
    HEAP32[$todo >> 2] = $1781;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 435:
    var $1783 = __ZL6PopStrP11SprintStack4JSOp($ss, 186);
    var $1784 = __ZL6PopStrP11SprintStack4JSOp($ss, 53);
    var $1785 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str922765 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str34080 | 0, HEAP32[tempInt + 4 >> 2] = $1784, HEAP32[tempInt + 8 >> 2] = $1783, tempInt));
    HEAP32[$todo >> 2] = $1785;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 436:
    var $1787 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $_ = ($op_2 | 0) == 40 ? STRING_TABLE.__str383190 : STRING_TABLE.__str373189;
    var $1789 = $_ | 0;
    var $1790 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str692742 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $1789, HEAP32[tempInt + 4 >> 2] = $1787, tempInt));
    HEAP32[$todo >> 2] = $1790;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $1787;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 437:
    var $1799 = (HEAPU8[$_1 + 1 | 0] & 255) << 8 | HEAPU8[$_1 + 2 | 0] & 255;
    var $1800 = __ZL15GetArgOrVarAtomP9JSPrinterj($16, $1799);
    if (($1800 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $atom_3 = $1800;
      __label__ = 442;
      break;
    }
   case 438:
    var $1803 = HEAP32[$_pre_phi >> 2];
    var $1804 = _js_GetIndexFromBytecode($1803, $_1, 0);
    var $1805 = HEAPU32[$_pre_phi >> 2];
    var $1807 = HEAPU32[$1805 >> 2];
    if ($_1 >>> 0 < $1807 >>> 0) {
      __label__ = 440;
      break;
    } else {
      __label__ = 439;
      break;
    }
   case 439:
    if (($1807 + HEAP32[$1805 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 441;
      break;
    } else {
      __label__ = 440;
      break;
    }
   case 440:
    var $1816 = HEAP32[$51 >> 2] + 209948 | 0;
    var $1817 = __ZN11JSAtomState16commonAtomsStartEv($1816);
    var $atom_3 = HEAP32[$1817 + ($1804 << 2) >> 2];
    __label__ = 442;
    break;
   case 441:
    var $_idx43_val = HEAP32[$1805 + 56 >> 2];
    var $1821 = __ZN8JSScript7getAtomEj($_idx43_val, $1804);
    var $atom_3 = $1821;
    __label__ = 442;
    break;
   case 442:
    var $atom_3;
    var $1824 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_3 | 0, 0);
    if (($1824 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 443;
      break;
    }
   case 443:
    var $1830 = $1824 - HEAP32[$37 >> 2] | 0;
    HEAP32[$38 >> 2] = $1830;
    var $lval_4 = $1824;
    __label__ = 444;
    break;
   case 444:
    var $lval_4;
    var $1836 = STRING_TABLE.__ZL13js_incop_strs + (HEAPU32[$cs_0 + 4 >> 2] >>> 11 & 1 ^ 1) * 3 | 0;
    var $1837 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str283576 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $1836, HEAP32[tempInt + 4 >> 2] = $lval_4, tempInt));
    HEAP32[$todo >> 2] = $1837;
    var $1839 = HEAPU8[$_1] & 255;
    if ((HEAP32[_js_CodeSpec + ($1839 << 3) + 4 >> 2] & 134217728 | 0) == 0) {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 445;
      break;
    }
   case 445:
    var $1847 = HEAP8[_js_CodeSpec + ($1839 << 3) | 0] << 24 >> 24;
    var $1848 = __ZN2jsL18GetDecomposeLengthEPhj2861($_1, $1847);
    var $_16 = $_1;
    var $len_10 = $1848 + $89 | 0;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 446:
    var $1851 = HEAP32[$_pre_phi >> 2];
    var $1852 = _js_GetIndexFromBytecode($1851, $_1, 0);
    var $1853 = HEAPU32[$_pre_phi >> 2];
    var $1855 = HEAPU32[$1853 >> 2];
    if ($_1 >>> 0 < $1855 >>> 0) {
      __label__ = 448;
      break;
    } else {
      __label__ = 447;
      break;
    }
   case 447:
    if (($1855 + HEAP32[$1853 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 449;
      break;
    } else {
      __label__ = 448;
      break;
    }
   case 448:
    var $1864 = HEAP32[$51 >> 2] + 209948 | 0;
    var $1865 = __ZN11JSAtomState16commonAtomsStartEv($1864);
    var $atom_4 = HEAP32[$1865 + ($1852 << 2) >> 2];
    __label__ = 450;
    break;
   case 449:
    var $_idx42_val = HEAP32[$1853 + 56 >> 2];
    var $1869 = __ZN8JSScript7getAtomEj($_idx42_val, $1852);
    var $atom_4 = $1869;
    __label__ = 450;
    break;
   case 450:
    var $atom_4;
    var $1872 = __Z15js_IsIdentifierP14JSLinearString($atom_4 | 0);
    var $1873 = ($1872 | 0) == 0;
    var $_152 = $1873 ? 39 : 0;
    var $1875 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_4 | 0, $_152);
    if (($1875 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 451;
      break;
    }
   case 451:
    var $_153 = $1873 ? STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE15preindex_format | 0 : STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE13predot_format | 0;
    var $1878 = __ZL6PopStrP11SprintStack4JSOp($ss, 53);
    var $1883 = STRING_TABLE.__ZL13js_incop_strs + (HEAPU32[$cs_0 + 4 >> 2] >>> 11 & 1 ^ 1) * 3 | 0;
    var $1884 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $_153, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1883, HEAP32[tempInt + 4 >> 2] = $1878, HEAP32[tempInt + 8 >> 2] = $1875, tempInt));
    HEAP32[$todo >> 2] = $1884;
    var $1885 = __ZN2jsL18GetDecomposeLengthEPhj2861($_1, 4);
    var $_16 = $_1;
    var $len_10 = $1885 + $89 | 0;
    var $cs_3 = $cs_0;
    var $rval_18 = $1875;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 452:
    var $1888 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $1889 = __ZL6PopStrP11SprintStack4JSOp($ss, 55);
    if (HEAP8[$1888] << 24 >> 24 == 0) {
      __label__ = 454;
      break;
    } else {
      __label__ = 453;
      break;
    }
   case 453:
    var $1895 = ($67 - 164 | 0) >>> 0 < 5 ? STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE13predot_format | 0 : STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE15preindex_format | 0;
    var $1900 = STRING_TABLE.__ZL13js_incop_strs + (HEAPU32[$cs_0 + 4 >> 2] >>> 11 & 1 ^ 1) * 3 | 0;
    var $1901 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $1895, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1900, HEAP32[tempInt + 4 >> 2] = $1889, HEAP32[tempInt + 8 >> 2] = $1888, tempInt));
    var $storemerge54 = $1901;
    __label__ = 455;
    break;
   case 454:
    var $1907 = STRING_TABLE.__ZL13js_incop_strs + (HEAPU32[$cs_0 + 4 >> 2] >>> 11 & 1 ^ 1) * 3 | 0;
    var $1908 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str283576 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $1907, HEAP32[tempInt + 4 >> 2] = $1889, tempInt));
    var $storemerge54 = $1908;
    __label__ = 455;
    break;
   case 455:
    var $storemerge54;
    HEAP32[$todo >> 2] = $storemerge54;
    var $1910 = __ZN2jsL18GetDecomposeLengthEPhj2861($_1, 2);
    var $_16 = $_1;
    var $len_10 = $1910 + $89 | 0;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 456:
    var $1920 = (HEAPU8[$_1 + 1 | 0] & 255) << 8 | HEAPU8[$_1 + 2 | 0] & 255;
    var $1921 = __ZL15GetArgOrVarAtomP9JSPrinterj($16, $1920);
    if (($1921 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $atom_5 = $1921;
      __label__ = 461;
      break;
    }
   case 457:
    var $1924 = HEAP32[$_pre_phi >> 2];
    var $1925 = _js_GetIndexFromBytecode($1924, $_1, 0);
    var $1926 = HEAPU32[$_pre_phi >> 2];
    var $1928 = HEAPU32[$1926 >> 2];
    if ($_1 >>> 0 < $1928 >>> 0) {
      __label__ = 459;
      break;
    } else {
      __label__ = 458;
      break;
    }
   case 458:
    if (($1928 + HEAP32[$1926 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 460;
      break;
    } else {
      __label__ = 459;
      break;
    }
   case 459:
    var $1937 = HEAP32[$51 >> 2] + 209948 | 0;
    var $1938 = __ZN11JSAtomState16commonAtomsStartEv($1937);
    var $atom_5 = HEAP32[$1938 + ($1925 << 2) >> 2];
    __label__ = 461;
    break;
   case 460:
    var $_idx41_val = HEAP32[$1926 + 56 >> 2];
    var $1942 = __ZN8JSScript7getAtomEj($_idx41_val, $1925);
    var $atom_5 = $1942;
    __label__ = 461;
    break;
   case 461:
    var $atom_5;
    var $1945 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_5 | 0, 0);
    if (($1945 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 462;
      break;
    }
   case 462:
    var $1951 = $1945 - HEAP32[$37 >> 2] | 0;
    HEAP32[$38 >> 2] = $1951;
    var $lval_5 = $1945;
    __label__ = 463;
    break;
   case 463:
    var $lval_5;
    var $1957 = STRING_TABLE.__ZL13js_incop_strs + (HEAPU32[$cs_0 + 4 >> 2] >>> 11 & 1 ^ 1) * 3 | 0;
    var $1958 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str283576 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $lval_5, HEAP32[tempInt + 4 >> 2] = $1957, tempInt));
    HEAP32[$todo >> 2] = $1958;
    var $1960 = HEAPU8[$_1] & 255;
    if ((HEAP32[_js_CodeSpec + ($1960 << 3) + 4 >> 2] & 134217728 | 0) == 0) {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 464;
      break;
    }
   case 464:
    var $1968 = HEAP8[_js_CodeSpec + ($1960 << 3) | 0] << 24 >> 24;
    var $1969 = __ZN2jsL18GetDecomposeLengthEPhj2861($_1, $1968);
    var $_16 = $_1;
    var $len_10 = $1969 + $89 | 0;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 465:
    var $1972 = HEAP32[$_pre_phi >> 2];
    var $1973 = _js_GetIndexFromBytecode($1972, $_1, 0);
    var $1974 = HEAPU32[$_pre_phi >> 2];
    var $1976 = HEAPU32[$1974 >> 2];
    if ($_1 >>> 0 < $1976 >>> 0) {
      __label__ = 467;
      break;
    } else {
      __label__ = 466;
      break;
    }
   case 466:
    if (($1976 + HEAP32[$1974 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 468;
      break;
    } else {
      __label__ = 467;
      break;
    }
   case 467:
    var $1985 = HEAP32[$51 >> 2] + 209948 | 0;
    var $1986 = __ZN11JSAtomState16commonAtomsStartEv($1985);
    var $atom_6 = HEAP32[$1986 + ($1973 << 2) >> 2];
    __label__ = 469;
    break;
   case 468:
    var $_idx40_val = HEAP32[$1974 + 56 >> 2];
    var $1990 = __ZN8JSScript7getAtomEj($_idx40_val, $1973);
    var $atom_6 = $1990;
    __label__ = 469;
    break;
   case 469:
    var $atom_6;
    var $1993 = __Z15js_IsIdentifierP14JSLinearString($atom_6 | 0);
    var $1994 = ($1993 | 0) == 0;
    var $_154 = $1994 ? 39 : 0;
    var $1996 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_6 | 0, $_154);
    if (($1996 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 470;
      break;
    }
   case 470:
    var $_155 = $1994 ? STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16postindex_format | 0 : STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE14postdot_format | 0;
    var $1999 = __ZL6PopStrP11SprintStack4JSOp($ss, 53);
    var $2004 = STRING_TABLE.__ZL13js_incop_strs + (HEAPU32[$cs_0 + 4 >> 2] >>> 11 & 1 ^ 1) * 3 | 0;
    var $2005 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $_155, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1999, HEAP32[tempInt + 4 >> 2] = $1996, HEAP32[tempInt + 8 >> 2] = $2004, tempInt));
    HEAP32[$todo >> 2] = $2005;
    var $2006 = __ZN2jsL18GetDecomposeLengthEPhj2861($_1, 4);
    var $_16 = $_1;
    var $len_10 = $2006 + $89 | 0;
    var $cs_3 = $cs_0;
    var $rval_18 = $1996;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 471:
    var $2009 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $2010 = __ZL6PopStrP11SprintStack4JSOp($ss, 55);
    if (HEAP8[$2009] << 24 >> 24 == 0) {
      __label__ = 473;
      break;
    } else {
      __label__ = 472;
      break;
    }
   case 472:
    var $2016 = ($67 - 164 | 0) >>> 0 < 5 ? STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE14postdot_format | 0 : STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16postindex_format | 0;
    var $2021 = STRING_TABLE.__ZL13js_incop_strs + (HEAPU32[$cs_0 + 4 >> 2] >>> 11 & 1 ^ 1) * 3 | 0;
    var $2022 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $2016, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $2010, HEAP32[tempInt + 4 >> 2] = $2009, HEAP32[tempInt + 8 >> 2] = $2021, tempInt));
    var $storemerge49 = $2022;
    __label__ = 474;
    break;
   case 473:
    var $2028 = STRING_TABLE.__ZL13js_incop_strs + (HEAPU32[$cs_0 + 4 >> 2] >>> 11 & 1 ^ 1) * 3 | 0;
    var $2029 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str283576 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $2010, HEAP32[tempInt + 4 >> 2] = $2028, tempInt));
    var $storemerge49 = $2029;
    __label__ = 474;
    break;
   case 474:
    var $storemerge49;
    HEAP32[$todo >> 2] = $storemerge49;
    var $2031 = __ZN2jsL18GetDecomposeLengthEPhj2861($_1, 2);
    var $_16 = $_1;
    var $len_10 = $2031 + $89 | 0;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 475:
    var $2034 = __ZL6PopOffP11SprintStack4JSOp($ss, $67);
    var $op_9 = 53;
    __label__ = 476;
    break;
   case 476:
    var $op_9;
    var $2036 = HEAP32[$_pre_phi >> 2];
    var $2037 = _js_GetIndexFromBytecode($2036, $_1, 0);
    var $2038 = HEAPU32[$_pre_phi >> 2];
    var $2040 = HEAPU32[$2038 >> 2];
    if ($_1 >>> 0 < $2040 >>> 0) {
      __label__ = 478;
      break;
    } else {
      __label__ = 477;
      break;
    }
   case 477:
    if (($2040 + HEAP32[$2038 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 479;
      break;
    } else {
      __label__ = 478;
      break;
    }
   case 478:
    var $2049 = HEAP32[$51 >> 2] + 209948 | 0;
    var $2050 = __ZN11JSAtomState16commonAtomsStartEv($2049);
    var $atom_7 = HEAP32[$2050 + ($2037 << 2) >> 2];
    __label__ = 480;
    break;
   case 479:
    var $_idx39_val = HEAP32[$2038 + 56 >> 2];
    var $2054 = __ZN8JSScript7getAtomEj($_idx39_val, $2037);
    var $atom_7 = $2054;
    __label__ = 480;
    break;
   case 480:
    var $atom_7;
    var $2057 = __Z15js_IsIdentifierP14JSLinearString($atom_7 | 0);
    var $2058 = ($2057 | 0) == 0;
    var $_156 = $2058 ? 39 : 0;
    var $_157 = $2058 ? STRING_TABLE.__str1402813 | 0 : STRING_TABLE.__str1392812 | 0;
    var $2060 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_7 | 0, $_156);
    if (($2060 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 481;
      break;
    }
   case 481:
    var $2067 = HEAP8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 1) | 0];
    if ($2067 << 24 >> 24 == 58 || $2067 << 24 >> 24 == 123 || $2067 << 24 >> 24 == 108 || $2067 << 24 >> 24 == 79) {
      __label__ = 482;
      break;
    } else {
      __label__ = 483;
      break;
    }
   case 482:
    HEAP32[$saveop >> 2] = 58;
    __label__ = 483;
    break;
   case 483:
    var $2070 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_9);
    var $2071 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $_157, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $2070, HEAP32[tempInt + 4 >> 2] = $2060, tempInt));
    HEAP32[$todo >> 2] = $2071;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $2060;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 484:
    var $2073 = HEAP32[$_pre_phi >> 2];
    var $2074 = _js_GetIndexFromBytecode($2073, $_1, 0);
    var $2075 = HEAPU32[$_pre_phi >> 2];
    var $2077 = HEAPU32[$2075 >> 2];
    if ($_1 >>> 0 < $2077 >>> 0) {
      __label__ = 486;
      break;
    } else {
      __label__ = 485;
      break;
    }
   case 485:
    if (($2077 + HEAP32[$2075 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 487;
      break;
    } else {
      __label__ = 486;
      break;
    }
   case 486:
    var $2086 = HEAP32[$51 >> 2] + 209948 | 0;
    var $2087 = __ZN11JSAtomState16commonAtomsStartEv($2086);
    var $atom_8 = HEAP32[$2087 + ($2074 << 2) >> 2];
    __label__ = 488;
    break;
   case 487:
    var $_idx38_val = HEAP32[$2075 + 56 >> 2];
    var $2091 = __ZN8JSScript7getAtomEj($_idx38_val, $2074);
    var $atom_8 = $2091;
    __label__ = 488;
    break;
   case 488:
    var $atom_8;
    var $2094 = __Z15js_IsIdentifierP14JSLinearString($atom_8 | 0);
    var $2095 = ($2094 | 0) == 0;
    var $_158 = $2095 ? 39 : 0;
    var $_159 = $2095 ? STRING_TABLE.__str932766 | 0 : STRING_TABLE.__str942767 | 0;
    var $2097 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_8 | 0, $_158);
    if (($2097 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 489;
      break;
    }
   case 489:
    var $2100 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $2101 = __ZL6PopStrP11SprintStack4JSOp($ss, 53);
    var $2104 = HEAP32[$_pre_phi >> 2];
    var $2105 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2104, $_1 - 1 | 0);
    if (($2105 | 0) == 0) {
      var $2117 = __str17668 | 0;
      __label__ = 494;
      break;
    } else {
      __label__ = 490;
      break;
    }
   case 490:
    var $2108 = HEAPU8[$2105];
    if (($2108 & 255) < 192 & ($2108 & -8) << 24 >> 24 == 64) {
      __label__ = 491;
      break;
    } else {
      var $2117 = __str17668 | 0;
      __label__ = 494;
      break;
    }
   case 491:
    if (($67 | 0) == 125) {
      var $2117 = STRING_TABLE.__str12882 | 0;
      __label__ = 494;
      break;
    } else {
      __label__ = 492;
      break;
    }
   case 492:
    if (($67 | 0) == 126) {
      var $2117 = STRING_TABLE.__str42885 | 0;
      __label__ = 494;
      break;
    } else {
      __label__ = 493;
      break;
    }
   case 493:
    var $2117 = HEAP32[__ZL9CodeToken + ($67 << 2) >> 2];
    __label__ = 494;
    break;
   case 494:
    var $2117;
    var $2118 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $_159, (tempInt = STACKTOP, STACKTOP += 16, HEAP32[tempInt >> 2] = $2101, HEAP32[tempInt + 4 >> 2] = $2097, HEAP32[tempInt + 8 >> 2] = $2117, HEAP32[tempInt + 12 >> 2] = $2100, tempInt));
    HEAP32[$todo >> 2] = $2118;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $2100;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 495:
    var $2120 = __ZL6PopOffP11SprintStack4JSOp($ss, $67);
    __label__ = 496;
    break;
   case 496:
    var $2122 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $2123 = HEAP32[$saveop >> 2];
    var $2128 = HEAP8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 1) | 0];
    if ($2128 << 24 >> 24 == 58 || $2128 << 24 >> 24 == 123 || $2128 << 24 >> 24 == 108 || $2128 << 24 >> 24 == 79) {
      __label__ = 497;
      break;
    } else {
      __label__ = 498;
      break;
    }
   case 497:
    HEAP32[$saveop >> 2] = 58;
    __label__ = 498;
    break;
   case 498:
    var $2131 = __ZL6PopStrP11SprintStack4JSOp($ss, $2123);
    if (HEAP8[$2122] << 24 >> 24 == 0) {
      __label__ = 499;
      break;
    } else {
      __label__ = 500;
      break;
    }
   case 499:
    var $2135 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str382711 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $2131, tempInt));
    HEAP32[$todo >> 2] = $2135;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 500:
    var $2139 = ($67 - 164 | 0) >>> 0 < 5 ? STRING_TABLE.__str1392812 | 0 : STRING_TABLE.__str1402813 | 0;
    var $2140 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $2139, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $2131, HEAP32[tempInt + 4 >> 2] = $2122, tempInt));
    HEAP32[$todo >> 2] = $2140;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 501:
    var $2142 = __ZL6PopStrP11SprintStack4JSOp($ss, 56);
    var $2143 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $2148 = HEAPU8[HEAP32[$36 >> 2] + HEAP32[$30 >> 2] | 0] & 255;
    var $2149 = _js_CodeSpec + ($2148 << 3) | 0;
    var $2150 = __ZL6PopStrP11SprintStack4JSOp($ss, 55);
    if (HEAP8[$2143] << 24 >> 24 == 0) {
      var $op_8 = HEAP32[$saveop >> 2];
      var $cs_1 = $2149;
      var $lval_1 = $2150;
      var $rval_13 = $2142;
      __label__ = 389;
      break;
    } else {
      __label__ = 502;
      break;
    }
   case 502:
    var $2157 = HEAP32[$_pre_phi >> 2];
    var $2158 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2157, $_1 - 1 | 0);
    var $2161 = ($2148 - 164 | 0) >>> 0 < 5 ? STRING_TABLE.__str942767 | 0 : STRING_TABLE.__str932766 | 0;
    if (($2158 | 0) == 0) {
      var $2173 = __str17668 | 0;
      __label__ = 507;
      break;
    } else {
      __label__ = 503;
      break;
    }
   case 503:
    var $2164 = HEAPU8[$2158];
    if (($2164 & 255) < 192 & ($2164 & -8) << 24 >> 24 == 64) {
      __label__ = 504;
      break;
    } else {
      var $2173 = __str17668 | 0;
      __label__ = 507;
      break;
    }
   case 504:
    if (($67 | 0) == 125) {
      var $2173 = STRING_TABLE.__str12882 | 0;
      __label__ = 507;
      break;
    } else {
      __label__ = 505;
      break;
    }
   case 505:
    if (($67 | 0) == 126) {
      var $2173 = STRING_TABLE.__str42885 | 0;
      __label__ = 507;
      break;
    } else {
      __label__ = 506;
      break;
    }
   case 506:
    var $2173 = HEAP32[__ZL9CodeToken + ($67 << 2) >> 2];
    __label__ = 507;
    break;
   case 507:
    var $2173;
    var $2174 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $2161, (tempInt = STACKTOP, STACKTOP += 16, HEAP32[tempInt >> 2] = $2150, HEAP32[tempInt + 4 >> 2] = $2143, HEAP32[tempInt + 8 >> 2] = $2173, HEAP32[tempInt + 12 >> 2] = $2142, tempInt));
    HEAP32[$todo >> 2] = $2174;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $2149;
    var $rval_18 = $2142;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 508:
    var $2183 = (HEAPU8[$_1 + 1 | 0] & 255) << 8 | HEAPU8[$_1 + 2 | 0] & 255;
    HEAP32[$i >> 2] = $2183;
    var $2184 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str952768 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = STRING_TABLE.__str142435 | 0, HEAP32[tempInt + 4 >> 2] = $2183, tempInt));
    HEAP32[$todo >> 2] = $2184;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 509:
    var $2186 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1392812 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = STRING_TABLE.__str142435 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str353798 | 0, tempInt));
    HEAP32[$todo >> 2] = $2186;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 510:
    var $2195 = (HEAPU8[$_1 + 1 | 0] & 255) << 8 | HEAPU8[$_1 + 2 | 0] & 255;
    HEAP32[$i >> 2] = $2195;
    var $2196 = __ZL15GetArgOrVarAtomP9JSPrinterj($16, $2195);
    if (($2196 | 0) == 0) {
      __label__ = 511;
      break;
    } else {
      var $len_6 = $89;
      var $lval_6 = __str17668 | 0;
      var $atom_10 = $2196;
      __label__ = 516;
      break;
    }
   case 511:
    var $2199 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str952768 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = STRING_TABLE.__str142435 | 0, HEAP32[tempInt + 4 >> 2] = $2195, tempInt));
    HEAP32[$todo >> 2] = $2199;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 512:
    var $2201 = HEAP32[$_pre_phi >> 2];
    var $2202 = _js_GetIndexFromBytecode($2201, $_1, 0);
    var $2203 = HEAPU32[$_pre_phi >> 2];
    var $2205 = HEAPU32[$2203 >> 2];
    if ($_1 >>> 0 < $2205 >>> 0) {
      __label__ = 514;
      break;
    } else {
      __label__ = 513;
      break;
    }
   case 513:
    if (($2205 + HEAP32[$2203 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 515;
      break;
    } else {
      __label__ = 514;
      break;
    }
   case 514:
    var $2214 = HEAP32[$51 >> 2] + 209948 | 0;
    var $2215 = __ZN11JSAtomState16commonAtomsStartEv($2214);
    var $len_6 = $89;
    var $lval_6 = __str17668 | 0;
    var $atom_10 = HEAP32[$2215 + ($2202 << 2) >> 2];
    __label__ = 516;
    break;
   case 515:
    var $_idx37_val = HEAP32[$2203 + 56 >> 2];
    var $2219 = __ZN8JSScript7getAtomEj($_idx37_val, $2202);
    var $len_6 = $89;
    var $lval_6 = __str17668 | 0;
    var $atom_10 = $2219;
    __label__ = 516;
    break;
   case 516:
    var $atom_10;
    var $lval_6;
    var $len_6;
    var $2221 = HEAP32[$_pre_phi >> 2];
    var $2222 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2221, $_1);
    var $2225 = ($inXML_0 | 0) != 0 ? 65536 : 0;
    var $2226 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_10 | 0, $2225);
    if (($2226 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 517;
      break;
    }
   case 517:
    var $2232 = $2226 - HEAP32[$37 >> 2] | 0;
    HEAP32[$38 >> 2] = $2232;
    var $2233 = __ZL9VarPrefixPh($2222);
    var $2234 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE10sss_format | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $2233, HEAP32[tempInt + 4 >> 2] = $lval_6, HEAP32[tempInt + 8 >> 2] = $2226, tempInt));
    HEAP32[$todo >> 2] = $2234;
    var $_16 = $_1;
    var $len_10 = $len_6;
    var $cs_3 = $cs_0;
    var $rval_18 = $2226;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 518:
    var $2243 = (HEAPU8[$_1 + 1 | 0] & 255) << 8 | HEAPU8[$_1 + 2 | 0] & 255;
    HEAP32[$i >> 2] = $2243;
    var $2282 = $2243;
    __label__ = 522;
    break;
   case 519:
    var $2257 = HEAPU8[$_1 + 3 | 0] & 255 | (HEAPU8[$_1 + 1 | 0] & 255) << 16 | (HEAPU8[$_1 + 2 | 0] & 255) << 8;
    HEAP32[$i >> 2] = $2257;
    var $2282 = $2257;
    __label__ = 522;
    break;
   case 520:
    var $2261 = HEAP8[$_1 + 1 | 0] << 24 >> 24;
    HEAP32[$i >> 2] = $2261;
    var $2282 = $2261;
    __label__ = 522;
    break;
   case 521:
    var $2280 = (HEAPU8[$_1 + 2 | 0] & 255) << 16 | (HEAPU8[$_1 + 1 | 0] & 255) << 24 | HEAPU8[$_1 + 4 | 0] & 255 | (HEAPU8[$_1 + 3 | 0] & 255) << 8;
    HEAP32[$i >> 2] = $2280;
    var $2282 = $2280;
    __label__ = 522;
    break;
   case 522:
    var $2282;
    var $2283 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str4498 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $2282, tempInt));
    HEAP32[$todo >> 2] = $2283;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 523:
    var $2285 = HEAP32[$_pre_phi >> 2];
    var $2286 = _js_GetIndexFromBytecode($2285, $_1, 0);
    var $2287 = HEAP32[$_pre_phi >> 2];
    var $_idx54_val = HEAP32[$2287 + 4 >> 2];
    var $_idx55_val = HEAP8[$2287 + 21 | 0];
    var $2288 = __ZN8JSScript8getConstEj($_idx54_val, $_idx55_val, $2286);
    var $2289 = __ZNK2JS5Value8toDoubleEv($2288);
    _DOUBLE_TO_JSVAL2862($2, $2289);
    var $2290$0 = HEAP32[$52 >> 2];
    var $2290$1 = HEAP32[$52 + 4 >> 2];
    HEAP32[$53 >> 2] = $2290$0;
    HEAP32[$53 + 4 >> 2] = $2290$1;
    var $2291 = __ZL17SprintDoubleValuePN2js8SprinterEN2JS5ValueEP4JSOp($6, $2290$0, $2290$1, $saveop);
    HEAP32[$todo >> 2] = $2291;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 524:
    var $2293 = HEAP32[$_pre_phi >> 2];
    var $2294 = _js_GetIndexFromBytecode($2293, $_1, 0);
    var $2295 = HEAPU32[$_pre_phi >> 2];
    var $2297 = HEAPU32[$2295 >> 2];
    if ($_1 >>> 0 < $2297 >>> 0) {
      __label__ = 526;
      break;
    } else {
      __label__ = 525;
      break;
    }
   case 525:
    if (($2297 + HEAP32[$2295 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 527;
      break;
    } else {
      __label__ = 526;
      break;
    }
   case 526:
    var $2306 = HEAP32[$51 >> 2] + 209948 | 0;
    var $2307 = __ZN11JSAtomState16commonAtomsStartEv($2306);
    var $atom_11 = HEAP32[$2307 + ($2294 << 2) >> 2];
    __label__ = 528;
    break;
   case 527:
    var $_idx36_val = HEAP32[$2295 + 56 >> 2];
    var $2311 = __ZN8JSScript7getAtomEj($_idx36_val, $2294);
    var $atom_11 = $2311;
    __label__ = 528;
    break;
   case 528:
    var $atom_11;
    var $2315 = ($inXML_0 | 0) != 0 ? 65536 : 34;
    var $2316 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_11 | 0, $2315);
    if (($2316 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 529;
      break;
    }
   case 529:
    var $2322 = $2316 - HEAP32[$37 >> 2] | 0;
    HEAP32[$todo >> 2] = $2322;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $2316;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 530:
    var $2325 = HEAP32[$_pre_phi >> 2];
    var $2326 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2325, $_1);
    if (($2326 | 0) == 0) {
      __label__ = 569;
      break;
    } else {
      __label__ = 531;
      break;
    }
   case 531:
    var $2329 = HEAPU8[$2326];
    if (($2329 & 255) < 192 & ($2329 & -8) << 24 >> 24 == 8) {
      __label__ = 532;
      break;
    } else {
      __label__ = 569;
      break;
    }
   case 532:
    var $2332 = HEAP32[$_pre_phi >> 2];
    var $2333 = _js_GetIndexFromBytecode($2332, $_1, 0);
    var $2334 = HEAP32[$_pre_phi >> 2];
    var $_idx26_val = HEAP32[$2334 + 4 >> 2];
    var $_idx27_val = HEAP8[$2334 + 16 | 0];
    var $2335 = __ZN8JSScript11getFunctionEj($_idx26_val, $_idx27_val, $2333);
    var $2338 = HEAPU32[HEAP32[$55 >> 2] + 12 >> 2];
    var $2339 = $2338;
    var $2340 = __ZNK10JSFunction6scriptEv($2335);
    var $_idx49_val = HEAP16[$2340 + 68 >> 1];
    var $_idx50_val = HEAP16[$2340 + 70 >> 1];
    var $_idx51_val = HEAP16[$2340 + 72 >> 1];
    var $2344 = __ZNK2js8Bindings13hasLocalNamesEv($_idx49_val, $_idx50_val, $_idx51_val);
    if ($2344) {
      __label__ = 533;
      break;
    } else {
      var $innerLocalNames_0 = 0;
      __label__ = 535;
      break;
    }
   case 533:
    var $2346 = __ZN9JSContext4new_IN2js6VectorIP6JSAtomLj0ENS1_15TempAllocPolicyEEEPS_EEPT_T0_($8, $8);
    if (($2346 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 534;
      break;
    }
   case 534:
    var $2349 = __ZNK10JSFunction6scriptEv($2335);
    var $2351 = $2349 + 64 | 0;
    var $2352 = $2346;
    var $2353 = __ZN2js8Bindings17getLocalNameArrayEP9JSContextPNS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEE($2351, $2352);
    if ($2353) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $innerLocalNames_0 = $2346;
      __label__ = 535;
      break;
    }
   case 535:
    var $innerLocalNames_0;
    var $2355 = __ZNK10JSFunction6scriptEv($2335);
    var $_idx18_val = HEAP16[$2355 + 14 >> 1];
    var $_idx19_val = HEAP16[$2355 + 44 >> 1];
    var $2356 = __ZL10StackDepthP8JSScript($_idx18_val, $_idx19_val);
    var $2357 = __ZL15InitSprintStackP9JSContextP11SprintStackP9JSPrinterj($8, $ss2, $16, $2356);
    if (($2357 | 0) == 0) {
      __label__ = 536;
      break;
    } else {
      __label__ = 540;
      break;
    }
   case 536:
    var $2360 = HEAP32[$55 >> 2];
    if (($2360 | 0) == ($59 | 0)) {
      __label__ = 539;
      break;
    } else {
      __label__ = 537;
      break;
    }
   case 537:
    var $2364 = HEAP32[$2360 + 4 >> 2];
    var $2366 = $2360 + 12 | 0;
    if (($2338 - $2364 | 0) >>> 0 > (HEAP32[$2366 >> 2] - $2364 | 0) >>> 0) {
      __label__ = 539;
      break;
    } else {
      __label__ = 538;
      break;
    }
   case 538:
    var $2371 = HEAPU32[$60 >> 2];
    var $2374 = $2371 + $2338 & ($2371 ^ -1);
    HEAP32[$2366 >> 2] = $2374;
    var $_0 = 0;
    __label__ = 742;
    break;
   case 539:
    _JS_ArenaRelease($54, $2339);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 540:
    HEAP32[$56 >> 2] = 1;
    var $2377 = HEAPU32[$_pre_phi >> 2];
    var $2379 = $2377 | 0;
    var $2383 = $2377 + 8 | 0;
    if (($_1 - HEAP32[$2379 >> 2] | 0) >>> 0 > HEAPU32[$2383 >> 2] >>> 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 541;
      break;
    }
   case 541:
    var $2387 = HEAP32[$47 >> 2];
    var $2388 = HEAP32[$46 >> 2];
    HEAP32[$_pre_phi >> 2] = $2355;
    HEAP32[$46 >> 2] = $2335;
    HEAP32[$47 >> 2] = $innerLocalNames_0;
    var $_idx47_val = HEAP32[$2355 >> 2];
    var $_idx48_val = HEAP32[$2355 + 32 >> 2];
    var $2389 = __ZN8JSScript4mainEv($_idx47_val, $_idx48_val);
    var $2392 = HEAP32[$2355 + 8 >> 2] - $_idx48_val | 0;
    var $2393 = __ZL9DecompileP11SprintStackPhi4JSOp($ss2, $2389, $2392);
    var $2394 = ($2393 | 0) == 0;
    HEAP32[$_pre_phi >> 2] = $2377;
    HEAP32[$46 >> 2] = $2388;
    HEAP32[$47 >> 2] = $2387;
    if ($2394) {
      __label__ = 542;
      break;
    } else {
      __label__ = 546;
      break;
    }
   case 542:
    var $2396 = HEAP32[$55 >> 2];
    if (($2396 | 0) == ($59 | 0)) {
      __label__ = 545;
      break;
    } else {
      __label__ = 543;
      break;
    }
   case 543:
    var $2400 = HEAP32[$2396 + 4 >> 2];
    var $2402 = $2396 + 12 | 0;
    if (($2338 - $2400 | 0) >>> 0 > (HEAP32[$2402 >> 2] - $2400 | 0) >>> 0) {
      __label__ = 545;
      break;
    } else {
      __label__ = 544;
      break;
    }
   case 544:
    var $2407 = HEAPU32[$60 >> 2];
    var $2410 = $2407 + $2338 & ($2407 ^ -1);
    HEAP32[$2402 >> 2] = $2410;
    var $_0 = 0;
    __label__ = 742;
    break;
   case 545:
    _JS_ArenaRelease($54, $2339);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 546:
    var $2413 = HEAP8[$108];
    if ($2413 << 24 >> 24 == -68) {
      __label__ = 547;
      break;
    } else if ($2413 << 24 >> 24 == -67) {
      __label__ = 548;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 547:
    var $_sum39_pn = $89 + 3 | 0;
    __label__ = 549;
    break;
   case 548:
    var $_sum39_pn = $89 + 1 | 0;
    __label__ = 549;
    break;
   case 549:
    var $_sum39_pn;
    if (HEAP8[$_1 + $_sum39_pn | 0] << 24 >> 24 == 1) {
      __label__ = 550;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 550:
    var $2420 = $_sum39_pn + ($_1 + 1) | 0;
    if (HEAP8[$2420] << 24 >> 24 == 58) {
      __label__ = 551;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 551:
    if (((HEAPU8[$_sum39_pn + ($_1 + 2) | 0] & 255) << 8 | HEAPU8[$_sum39_pn + ($_1 + 3) | 0] & 255 | 0) == 0) {
      __label__ = 552;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 552:
    var $2434 = $_sum39_pn + ($_1 + 4) | 0;
    var $2435 = HEAP8[$2434];
    if ($2435 << 24 >> 24 == 109 || $2435 << 24 >> 24 == 0) {
      __label__ = 553;
      break;
    } else {
      var $pc2_2 = $2434;
      __label__ = 554;
      break;
    }
   case 553:
    var $pc2_2 = $_sum39_pn + ($_1 + 5) | 0;
    __label__ = 554;
    break;
   case 554:
    var $pc2_2;
    if ($pc2_2 >>> 0 < $29 >>> 0) {
      __label__ = 556;
      break;
    } else {
      __label__ = 555;
      break;
    }
   case 555:
    if ($29 >>> 0 < (HEAP32[$2379 >> 2] + HEAP32[$2383 >> 2] | 0) >>> 0) {
      __label__ = 556;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 556:
    if ((HEAP32[$57 >> 2] | 0) == 1) {
      __label__ = 557;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 557:
    HEAP8[HEAP32[$58 >> 2]] = 81;
    if (($pc2_2 | 0) == ($29 | 0)) {
      var $op_10 = 111;
      __label__ = 563;
      break;
    } else {
      __label__ = 558;
      break;
    }
   case 558:
    var $2455 = HEAPU32[_js_CodeSpec + ((HEAPU8[$pc2_2] & 255) << 3) + 4 >> 2];
    if (($2455 & 1048576 | 0) == 0) {
      __label__ = 559;
      break;
    } else {
      var $2472 = 81;
      __label__ = 561;
      break;
    }
   case 559:
    if (($2455 & 2097152 | 0) == 0) {
      var $2472 = 111;
      __label__ = 561;
      break;
    } else {
      __label__ = 560;
      break;
    }
   case 560:
    var $phitmp38 = ((HEAPU8[$pc2_2 + 1 | 0] & 255) << 8 | HEAPU8[$pc2_2 + 2 | 0] & 255 | 0) == 1 ? 81 : 111;
    var $2472 = $phitmp38;
    __label__ = 561;
    break;
   case 561:
    var $2472;
    if (HEAP8[_js_CodeSpec + (HEAP32[$saveop >> 2] << 3) + 3 | 0] << 24 >> 24 == 19) {
      __label__ = 562;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 562:
    HEAP32[$saveop >> 2] = 59;
    var $op_10 = $2472;
    __label__ = 563;
    break;
   case 563:
    var $op_10;
    var $2479 = __ZL6PopStrP11SprintStack4JSOp($ss2, $op_10);
    var $2480 = _JS_strdup($8, $2479);
    var $2481 = HEAP32[$55 >> 2];
    if (($2481 | 0) == ($59 | 0)) {
      __label__ = 566;
      break;
    } else {
      __label__ = 564;
      break;
    }
   case 564:
    var $2485 = HEAP32[$2481 + 4 >> 2];
    var $2487 = $2481 + 12 | 0;
    if (($2338 - $2485 | 0) >>> 0 > (HEAP32[$2487 >> 2] - $2485 | 0) >>> 0) {
      __label__ = 566;
      break;
    } else {
      __label__ = 565;
      break;
    }
   case 565:
    var $2492 = HEAPU32[$60 >> 2];
    var $2495 = $2492 + $2338 & ($2492 ^ -1);
    HEAP32[$2487 >> 2] = $2495;
    __label__ = 567;
    break;
   case 566:
    _JS_ArenaRelease($54, $2339);
    __label__ = 567;
    break;
   case 567:
    if (($2480 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 568;
      break;
    }
   case 568:
    var $2500 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, $2480);
    HEAP32[$todo >> 2] = $2500;
    __ZN9JSContext5free_EPv($2480);
    var $_16 = $2420;
    var $len_10 = 3;
    var $cs_3 = $cs_0;
    var $rval_18 = $2480;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 569:
    var $2501 = HEAP32[$_pre_phi >> 2];
    var $2502 = _js_GetIndexFromBytecode($2501, $_1, 0);
    var $2503 = HEAP32[$_pre_phi >> 2];
    var $_idx24_val = HEAP32[$2503 + 4 >> 2];
    var $_idx25_val = HEAP8[$2503 + 16 | 0];
    var $2504 = __ZN8JSScript11getFunctionEj($_idx24_val, $_idx25_val, $2502);
    var $2513 = ((HEAPU16[$2504 + 58 >> 1] & 65535) >>> 12 & 1 ^ 1) & 65535;
    var $2514 = (HEAPU8[$2503 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $2515 = _js_DecompileToString($8, $2504, 0, 0, $2513, $2514);
    if (($2515 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $str_0 = $2515;
      __label__ = 570;
      break;
    }
   case 570:
    var $str_0;
    var $2518 = __ZN2js12SprintStringEPNS_8SprinterEP8JSString($6, $str_0);
    HEAP32[$todo >> 2] = $2518;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 571:
    var $2523 = HEAP32[HEAP32[$46 >> 2] + 72 >> 2] | 0;
    var $2524 = __ZN2js12SprintStringEPNS_8SprinterEP8JSString($6, $2523);
    HEAP32[$todo >> 2] = $2524;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 572:
    var $2526 = HEAP32[$_pre_phi >> 2];
    var $2527 = _js_GetIndexFromBytecode($2526, $_1, 0);
    var $2528 = HEAP32[$_pre_phi >> 2];
    var $_idx11_val = HEAP32[$2528 + 4 >> 2];
    var $_idx12_val = HEAP8[$2528 + 16 | 0];
    var $2529 = __ZN8JSScript9getObjectEj($_idx11_val, $_idx12_val, $2527);
    __ZN2JSL11ObjectValueER8JSObject2863($3, $2529);
    var $2530 = __Z16js_ValueToSourceP9JSContextRKN2JS5ValueE($61, $3);
    if (($2530 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $str_0 = $2530;
      __label__ = 570;
      break;
    }
   case 573:
    var $2533 = HEAP32[$_pre_phi >> 2];
    var $2534 = _js_GetIndexFromBytecode($2533, $_1, 0);
    var $2535 = HEAP32[$_pre_phi >> 2];
    var $2536 = __ZN8JSScript9getRegExpEj($2535, $2534);
    var $2537 = $2536;
    var $2538 = __Z18js_regexp_toStringP9JSContextP8JSObjectPN2JS5ValueE($62, $2537, $val);
    if (($2538 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 574;
      break;
    }
   case 574:
    var $2541$0 = HEAP32[$53 >> 2];
    var $2541$1 = HEAP32[$53 + 4 >> 2];
    var $2542 = _JSVAL_TO_STRING2864($2541$0, $2541$1);
    var $str_0 = $2542;
    __label__ = 570;
    break;
   case 575:
    var $2545 = HEAP32[$_pre_phi >> 2];
    var $2546 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2545, $_1);
    if (($2546 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 576;
      break;
    }
   case 576:
    var $2549 = HEAPU8[$2546];
    if (($2549 & 255) < 192 & ($2549 & -8) << 24 >> 24 == -112) {
      __label__ = 577;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 577:
    var $2552 = _js_GetSrcNoteOffset($2546, 0);
    var $2554 = ($op_2 | 0) == 70 ? 2 : 4;
    var $_1_val4 = HEAP8[$_1];
    var $2555 = __ZL13GetJumpOffsetPhS_($_1_val4, $_1);
    var $2564 = ((HEAPU8[$_1 + ($2554 | 1) | 0] & 255) << 8 | HEAPU8[$2554 + ($_1 + 2) | 0] & 255) << 16 >> 16;
    var $2569 = $2554 + ($_1 + 4) | 0;
    var $2575 = (((HEAPU8[$2554 + ($_1 + 3) | 0] & 255) << 8 | HEAPU8[$2569] & 255) << 16 >> 16) - $2564 + 1 | 0;
    if (($2575 | 0) == 0) {
      var $j_2233 = 0;
      var $table_0234 = 0;
      __label__ = 590;
      break;
    } else {
      __label__ = 578;
      break;
    }
   case 578:
    var $2578 = $2575 * 24 | 0;
    var $2579 = __ZN9JSContext7malloc_Ej($8, $2578);
    var $2580 = $2579;
    if (($2579 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $pc2_3 = $2569;
      var $j_0 = 0;
      var $storemerge32 = 0;
      __label__ = 579;
      break;
    }
   case 579:
    var $storemerge32;
    var $j_0;
    var $pc2_3;
    HEAP32[$i >> 2] = $storemerge32;
    if (($storemerge32 | 0) < ($2575 | 0)) {
      __label__ = 580;
      break;
    } else {
      __label__ = 587;
      break;
    }
   case 580:
    var $2584 = $2580 + $j_0 * 24 + 12 | 0;
    HEAP32[$2584 >> 2] = 0;
    var $_1_val3 = HEAP8[$_1];
    var $2585 = __ZL13GetJumpOffsetPhS_($_1_val3, $pc2_3);
    if (($2585 | 0) == 0) {
      var $j_1 = $j_0;
      __label__ = 586;
      break;
    } else {
      __label__ = 581;
      break;
    }
   case 581:
    var $2589 = HEAP32[$_pre_phi >> 2];
    var $2590 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2589, $pc2_3);
    if (($2590 | 0) == 0) {
      __label__ = 585;
      break;
    } else {
      __label__ = 582;
      break;
    }
   case 582:
    var $2593 = HEAPU8[$2590];
    if (($2593 & 255) < 192 & ($2593 & -8) << 24 >> 24 == 104) {
      __label__ = 583;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 583:
    var $2596 = _js_GetSrcNoteOffset($2590, 0);
    var $2597 = HEAPU32[$_pre_phi >> 2];
    if ($2596 >>> 0 < HEAPU32[$2597 + 40 >> 2] >>> 0) {
      __label__ = 584;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 584:
    var $2605 = HEAP32[HEAP32[$2597 + 56 >> 2] + ($2596 << 2) >> 2];
    HEAP32[$2584 >> 2] = $2605;
    __label__ = 585;
    break;
   case 585:
    var $2608 = HEAP32[$i >> 2] + $2564 | 0;
    _INT_TO_JSVAL2865($4, $2608);
    var $st$3$0 = $63 | 0;
    var $2609$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $63 + 4 | 0;
    var $2609$1 = HEAP32[$st$3$1 >> 2];
    var $2610 = $2580 + $j_0 * 24 | 0;
    var $st$8$0 = $2610 | 0;
    HEAP32[$st$8$0 >> 2] = $2609$0;
    var $st$8$1 = $2610 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $2609$1;
    HEAP32[$2580 + $j_0 * 24 + 8 >> 2] = $2585;
    HEAP32[$2580 + $j_0 * 24 + 16 >> 2] = $j_0;
    var $j_1 = $j_0 + 1 | 0;
    __label__ = 586;
    break;
   case 586:
    var $j_1;
    var $pc2_3 = $pc2_3 + $2554 | 0;
    var $j_0 = $j_1;
    var $storemerge32 = HEAP32[$i >> 2] + 1 | 0;
    __label__ = 579;
    break;
   case 587:
    var $2620 = __ZN9JSContext7malloc_Ej($8, $j_0 * 24 | 0);
    if (($2620 | 0) == 0) {
      __label__ = 589;
      break;
    } else {
      __label__ = 588;
      break;
    }
   case 588:
    var $2623 = __Z12js_MergeSortPvjjPFiS_PKvS1_PiES_S_19JSMergeSortElemType($2579, $j_0, 24, 198, 0, $2620, 1);
    __ZN9JSContext5free_EPv($2620);
    if ($2623) {
      var $j_2233 = $j_0;
      var $table_0234 = $2580;
      __label__ = 590;
      break;
    } else {
      __label__ = 589;
      break;
    }
   case 589:
    __ZN9JSContext5free_EPv($2579);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 590:
    var $table_0234;
    var $j_2233;
    var $2624 = __ZL15DecompileSwitchP11SprintStackP10TableEntryjPhiii($ss, $table_0234, $j_2233, $_1, $2552, $2555, 0);
    __ZN9JSContext5free_EPv($table_0234);
    if (($2624 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 591;
      break;
    }
   case 591:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $2552;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 592:
    var $2630 = HEAP32[$_pre_phi >> 2];
    var $2631 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2630, $_1);
    if (($2631 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 593;
      break;
    }
   case 593:
    var $2634 = HEAPU8[$2631];
    if (($2634 & 255) < 192 & ($2634 & -8) << 24 >> 24 == -112) {
      __label__ = 594;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 594:
    var $2637 = _js_GetSrcNoteOffset($2631, 0);
    var $2639 = ($op_2 | 0) == 71 ? 2 : 4;
    var $_1_val2 = HEAP8[$_1];
    var $2640 = __ZL13GetJumpOffsetPhS_($_1_val2, $_1);
    var $_sum21 = $2639 + 2 | 0;
    var $2645 = $_1 + $_sum21 | 0;
    var $2648 = (HEAPU8[$_1 + ($2639 | 1) | 0] & 255) << 8 | HEAPU8[$2645] & 255;
    var $2649 = $2648 * 24 | 0;
    var $2650 = __ZN9JSContext7malloc_Ej($8, $2649);
    var $2651 = $2650;
    if (($2650 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $k_0 = 0;
      var $pc2_4 = $2645;
      __label__ = 595;
      break;
    }
   case 595:
    var $pc2_4;
    var $k_0;
    if ($k_0 >>> 0 < $2648 >>> 0) {
      __label__ = 596;
      break;
    } else {
      __label__ = 602;
      break;
    }
   case 596:
    var $2656 = HEAP32[$_pre_phi >> 2];
    var $2657 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2656, $pc2_4);
    if (($2657 | 0) == 0) {
      __label__ = 600;
      break;
    } else {
      __label__ = 597;
      break;
    }
   case 597:
    var $2660 = HEAPU8[$2657];
    if (($2660 & 255) < 192 & ($2660 & -8) << 24 >> 24 == 104) {
      __label__ = 598;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 598:
    var $2663 = _js_GetSrcNoteOffset($2657, 0);
    var $2664 = HEAPU32[$_pre_phi >> 2];
    if ($2663 >>> 0 < HEAPU32[$2664 + 40 >> 2] >>> 0) {
      __label__ = 599;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 599:
    var $2672 = HEAP32[HEAP32[$2664 + 56 >> 2] + ($2663 << 2) >> 2];
    HEAP32[$2651 + $k_0 * 24 + 12 >> 2] = $2672;
    __label__ = 601;
    break;
   case 600:
    HEAP32[$2651 + $k_0 * 24 + 12 >> 2] = 0;
    __label__ = 601;
    break;
   case 601:
    var $2681 = $pc2_4 + 2 | 0;
    var $2684 = (HEAPU8[$pc2_4 + 1 | 0] & 255) << 8 | HEAPU8[$2681] & 255;
    var $_1_val = HEAP8[$_1];
    var $2685 = __ZL13GetJumpOffsetPhS_($_1_val, $2681);
    var $2686 = $pc2_4 + $_sum21 | 0;
    var $2687 = HEAP32[$_pre_phi >> 2];
    var $_idx52_val = HEAP32[$2687 + 4 >> 2];
    var $_idx53_val = HEAP8[$2687 + 21 | 0];
    var $2688 = __ZN8JSScript8getConstEj($_idx52_val, $_idx53_val, $2684);
    var $2689 = $2688 | 0;
    var $2690$0 = HEAP32[$2689 >> 2];
    var $2690$1 = HEAP32[$2689 + 4 >> 2];
    var $2691 = $2651 + $k_0 * 24 | 0;
    HEAP32[$2691 >> 2] = $2690$0;
    HEAP32[$2691 + 4 >> 2] = $2690$1;
    HEAP32[$2651 + $k_0 * 24 + 8 >> 2] = $2685;
    var $k_0 = $k_0 + 1 | 0;
    var $pc2_4 = $2686;
    __label__ = 595;
    break;
   case 602:
    var $2695 = __ZL15DecompileSwitchP11SprintStackP10TableEntryjPhiii($ss, $2651, $2648, $_1, $2637, $2640, 0);
    __ZN9JSContext5free_EPv($2650);
    if (($2695 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 603;
      break;
    }
   case 603:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $2637;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 604:
    var $2700 = HEAP32[$_pre_phi >> 2];
    var $2701 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2700, $_1);
    if (($2701 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 605;
      break;
    }
   case 605:
    var $2704 = HEAPU8[$2701];
    if (($2704 & 255) < 192 & ($2704 & -8) << 24 >> 24 == -112) {
      __label__ = 606;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 606:
    var $2707 = _js_GetSrcNoteOffset($2701, 0);
    var $2708 = _js_GetSrcNoteOffset($2701, 1);
    var $ncases_0 = 0;
    var $off236_0 = $2708;
    var $pc2_5 = $_1;
    __label__ = 607;
    break;
   case 607:
    var $pc2_5;
    var $off236_0;
    var $ncases_0;
    if (($off236_0 | 0) == 0) {
      __label__ = 613;
      break;
    } else {
      __label__ = 608;
      break;
    }
   case 608:
    var $2712 = $pc2_5 + $off236_0 | 0;
    var $2713 = HEAP8[$2712];
    if ($2713 << 24 >> 24 == 121 || $2713 << 24 >> 24 == -109) {
      __label__ = 609;
      break;
    } else if ($2713 << 24 >> 24 == 122 || $2713 << 24 >> 24 == -108) {
      var $off236_1 = 0;
      __label__ = 612;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 609:
    var $2716 = HEAP32[$_pre_phi >> 2];
    var $2717 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2716, $2712);
    if (($2717 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 610;
      break;
    }
   case 610:
    var $2720 = HEAPU8[$2717];
    if (($2720 & 255) < 192 & ($2720 & -8) << 24 >> 24 == 56) {
      __label__ = 611;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 611:
    var $2723 = _js_GetSrcNoteOffset($2717, 0);
    var $off236_1 = $2723;
    __label__ = 612;
    break;
   case 612:
    var $off236_1;
    var $ncases_0 = $ncases_0 + 1 | 0;
    var $off236_0 = $off236_1;
    var $pc2_5 = $2712;
    __label__ = 607;
    break;
   case 613:
    var $2728 = __ZN9JSContext7malloc_Ej($8, $ncases_0 * 24 | 0);
    var $2729 = $2728;
    if (($2728 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 614;
      break;
    }
   case 614:
    var $2731 = $_1;
    var $off236_2 = $2708;
    var $pc2_6 = $_1;
    var $2733 = 0;
    __label__ = 615;
    break;
   case 615:
    var $2733;
    var $pc2_6;
    var $off236_2;
    HEAP32[$i >> 2] = $2733;
    if (($2733 | 0) < ($ncases_0 | 0)) {
      __label__ = 616;
      break;
    } else {
      __label__ = 622;
      break;
    }
   case 616:
    var $2736 = $pc2_6 + $off236_2 | 0;
    var $2737 = HEAP8[$2736];
    if ($2737 << 24 >> 24 == 121 || $2737 << 24 >> 24 == 122 || $2737 << 24 >> 24 == -109 || $2737 << 24 >> 24 == -108) {
      __label__ = 617;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 617:
    var $2740 = $2736 - $2731 | 0;
    _INT_TO_JSVAL2865($5, $2740);
    var $st$3$0 = $64 | 0;
    var $2741$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $64 + 4 | 0;
    var $2741$1 = HEAP32[$st$3$1 >> 2];
    var $2742 = $2729 + $2733 * 24 | 0;
    var $st$8$0 = $2742 | 0;
    HEAP32[$st$8$0 >> 2] = $2741$0;
    var $st$8$1 = $2742 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $2741$1;
    var $_val1 = HEAP8[$2736];
    var $2743 = __ZL13GetJumpOffsetPhS_($_val1, $2736);
    var $2746 = $2729 + HEAP32[$i >> 2] * 24 + 8 | 0;
    HEAP32[$2746 >> 2] = $2743 + $2740 | 0;
    var $2747 = HEAP8[$2736];
    if ($2747 << 24 >> 24 == 121 || $2747 << 24 >> 24 == -109) {
      __label__ = 618;
      break;
    } else {
      var $off236_3 = $off236_2;
      __label__ = 621;
      break;
    }
   case 618:
    var $2750 = HEAP32[$_pre_phi >> 2];
    var $2751 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2750, $2736);
    if (($2751 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 619;
      break;
    }
   case 619:
    var $2754 = HEAPU8[$2751];
    if (($2754 & 255) < 192 & ($2754 & -8) << 24 >> 24 == 56) {
      __label__ = 620;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 620:
    var $2757 = _js_GetSrcNoteOffset($2751, 0);
    var $off236_3 = $2757;
    __label__ = 621;
    break;
   case 621:
    var $off236_3;
    var $off236_2 = $off236_3;
    var $pc2_6 = $2736;
    var $2733 = HEAP32[$i >> 2] + 1 | 0;
    __label__ = 615;
    break;
   case 622:
    var $2763 = $2729 + ($ncases_0 - 1) * 24 | 0;
    var $2764$0 = HEAP32[$2763 >> 2];
    var $2764$1 = HEAP32[$2763 + 4 >> 2];
    var $2765 = _JSVAL_TO_INT($2764$0, $2764$1);
    var $2766 = $_1 + $2765 | 0;
    var $_val = HEAP8[$2766];
    var $2767 = __ZL13GetJumpOffsetPhS_($_val, $2766);
    var $2768 = $2767 + $2765 | 0;
    var $2769 = __ZL15DecompileSwitchP11SprintStackP10TableEntryjPhiii($ss, $2729, $ncases_0, $_1, $2707, $2768, 1);
    __ZN9JSContext5free_EPv($2728);
    if (($2769 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 623;
      break;
    }
   case 623:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $2707;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 624:
    var $2773 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    if (($2773 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 625;
      break;
    }
   case 625:
    _js_printf($16, STRING_TABLE.__str982771 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $2773, tempInt));
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 626:
    var $2777 = HEAP32[$_pre_phi >> 2];
    var $2778 = _js_GetIndexFromBytecode($2777, $_1, 0);
    var $2779 = HEAP32[$_pre_phi >> 2];
    var $_idx22_val = HEAP32[$2779 + 4 >> 2];
    var $_idx23_val = HEAP8[$2779 + 16 | 0];
    var $2780 = __ZN8JSScript11getFunctionEj($_idx22_val, $_idx23_val, $2778);
    HEAP32[$todo >> 2] = -2;
    var $fun_0 = $2780;
    __label__ = 79;
    break;
   case 627:
    var $2783 = HEAP32[$_pre_phi >> 2];
    var $2784 = _JS_GetTrapOpcode($2783, $_1);
    HEAP32[$saveop >> 2] = $2784;
    HEAP8[$_1] = $2784 & 255;
    var $2786 = _js_CodeSpec + ($2784 << 3) | 0;
    var $2789 = HEAP8[$2786 | 0] << 24 >> 24;
    var $2790 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $_1, $2789);
    if (($2790 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 628;
      break;
    }
   case 628:
    var $2794 = HEAPU8[$_1] & 255;
    if ((HEAP32[_js_CodeSpec + ($2794 << 3) + 4 >> 2] & 134217728 | 0) == 0) {
      var $len_7 = $2789;
      __label__ = 630;
      break;
    } else {
      __label__ = 629;
      break;
    }
   case 629:
    var $2802 = HEAP8[_js_CodeSpec + ($2794 << 3) | 0] << 24 >> 24;
    var $2803 = __ZN2jsL18GetDecomposeLengthEPhj2861($_1, $2802);
    var $len_7 = $2803 + $2789 | 0;
    __label__ = 630;
    break;
   case 630:
    var $len_7;
    HEAP8[$_1] = 83;
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $len_7;
    var $cs_3 = $2786;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 631:
    var $2807 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, __str17668 | 0, 0);
    HEAP32[$todo >> 2] = $2807;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 632:
    var $2810 = HEAPU8[$_1 + 1 | 0];
    var $2811 = $2810 & 255;
    HEAP32[$i >> 2] = $2811;
    if ($2810 << 24 >> 24 == 3 || $2810 << 24 >> 24 == 1) {
      __label__ = 633;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 633:
    var $2813 = HEAP32[$38 >> 2];
    HEAP32[$todo >> 2] = $2813;
    var $2814 = HEAPU8[$108];
    if ($2814 << 24 >> 24 == -26) {
      __label__ = 634;
      break;
    } else {
      var $len_8 = $89;
      var $op_11_in = $2814;
      __label__ = 635;
      break;
    }
   case 634:
    var $2817 = $89 + 3 | 0;
    var $len_8 = $2817;
    var $op_11_in = HEAP8[$_1 + $2817 | 0];
    __label__ = 635;
    break;
   case 635:
    var $op_11_in;
    var $len_8;
    if ($op_11_in << 24 >> 24 == 95) {
      __label__ = 636;
      break;
    } else {
      var $_1517 = $_1;
      var $len_9 = $len_8;
      var $cs_2 = $cs_0;
      var $2835 = $2811;
      __label__ = 638;
      break;
    }
   case 636:
    var $2830 = (HEAPU8[$len_8 + ($_1 + 3) | 0] & 255) << 8 | HEAPU8[$len_8 + ($_1 + 4) | 0] & 255;
    var $2831 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str992772 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $2830, tempInt));
    if (($2831 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 637;
      break;
    }
   case 637:
    var $_1517 = $_1 + $len_8 | 0;
    var $len_9 = 5;
    var $cs_2 = _js_CodeSpec + 760 | 0;
    var $2835 = HEAP32[$i >> 2];
    __label__ = 638;
    break;
   case 638:
    var $2835;
    var $cs_2;
    var $len_9;
    var $_1517;
    if (($2835 | 0) == 3) {
      __label__ = 639;
      break;
    } else {
      __label__ = 640;
      break;
    }
   case 639:
    var $2839 = HEAP32[$50 >> 2] + 1 | 0;
    HEAP32[$50 >> 2] = $2839;
    var $2840 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, STRING_TABLE.__str1002773 | 0);
    if (($2840 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $_16 = $_1517;
      var $len_10 = $len_9;
      var $cs_3 = $cs_2;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 640:
    var $2843 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, STRING_TABLE.__str1012774 | 0);
    if (($2843 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $_16 = $_1517;
      var $len_10 = $len_9;
      var $cs_3 = $cs_2;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 641:
    var $2846 = HEAP32[$38 >> 2];
    HEAP32[$todo >> 2] = $2846;
    var $2848 = HEAP32[$50 >> 2] + 1 | 0;
    HEAP32[$50 >> 2] = $2848;
    var $2849 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, STRING_TABLE.__str1002773 | 0);
    if (($2849 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 642:
    var $2852 = HEAP32[$38 >> 2];
    HEAP32[$todo >> 2] = $2852;
    var $2853 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, STRING_TABLE.__str1012774 | 0);
    if (($2853 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 643:
    var $2856 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $2858 = HEAP32[$_pre_phi >> 2];
    var $2859 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2858, $_1);
    var $xval_1 = $2856;
    __label__ = 644;
    break;
   case 644:
    var $xval_1;
    var $2861 = HEAP8[$xval_1];
    if ($2861 << 24 >> 24 == 91 || $2861 << 24 >> 24 == 123) {
      __label__ = 646;
      break;
    } else {
      __label__ = 645;
      break;
    }
   case 645:
    var $xval_1 = $xval_1 + 1 | 0;
    __label__ = 644;
    break;
   case 646:
    var $2864 = $2861 << 24 >> 24 == 91;
    if ($2864) {
      __label__ = 647;
      break;
    } else {
      __label__ = 648;
      break;
    }
   case 647:
    var $2867 = HEAP32[$50 >> 2] - 1 | 0;
    HEAP32[$50 >> 2] = $2867;
    __label__ = 648;
    break;
   case 648:
    if (($2859 | 0) == 0) {
      var $2875 = __str17668 | 0;
      __label__ = 651;
      break;
    } else {
      __label__ = 649;
      break;
    }
   case 649:
    var $2871 = HEAPU8[$2859];
    if (($2871 & 255) > 191) {
      var $2875 = __str17668 | 0;
      __label__ = 651;
      break;
    } else {
      __label__ = 650;
      break;
    }
   case 650:
    var $phitmp5 = ($2871 & -8) << 24 >> 24 == 40 ? STRING_TABLE.__str296 | 0 : __str17668 | 0;
    var $2875 = $phitmp5;
    __label__ = 651;
    break;
   case 651:
    var $2875;
    var $2876 = $2864 ? 93 : 125;
    var $2877 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1022775 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $2856, HEAP32[tempInt + 4 >> 2] = $2875, HEAP32[tempInt + 8 >> 2] = $2876, tempInt));
    HEAP32[$todo >> 2] = $2877;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $2856;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 652:
    var $2883 = HEAP8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 3) | 0];
    var $2884 = __ZL15IsInitializerOph($2883);
    var $2885 = __ZL6PopStrP11SprintStack4JSOp($ss, 111);
    var $2886 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $2887 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $2889 = HEAP32[$_pre_phi >> 2];
    var $2890 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2889, $_1);
    if (($2890 | 0) == 0) {
      __label__ = 654;
      break;
    } else {
      __label__ = 653;
      break;
    }
   case 653:
    var $2894 = HEAPU8[$2890];
    if (($2894 & 255) < 192 & ($2894 & -8) << 24 >> 24 == 8) {
      var $isFirst_0 = $2884 & 1;
      var $lval_7 = $2887;
      var $rval_16 = $2885;
      var $xval_2 = $2886;
      __label__ = 661;
      break;
    } else {
      __label__ = 654;
      break;
    }
   case 654:
    var $2896 = $2884 ? __str17668 | 0 : STRING_TABLE.__str296 | 0;
    var $2897 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE10sss_format | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $2887, HEAP32[tempInt + 4 >> 2] = $2896, HEAP32[tempInt + 8 >> 2] = $2885, tempInt));
    HEAP32[$todo >> 2] = $2897;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $2885;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 655:
    var $2899 = HEAP32[$_pre_phi >> 2];
    var $2900 = _js_GetIndexFromBytecode($2899, $_1, 0);
    var $2901 = HEAPU32[$_pre_phi >> 2];
    var $2903 = HEAPU32[$2901 >> 2];
    if ($_1 >>> 0 < $2903 >>> 0) {
      __label__ = 657;
      break;
    } else {
      __label__ = 656;
      break;
    }
   case 656:
    if (($2903 + HEAP32[$2901 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 658;
      break;
    } else {
      __label__ = 657;
      break;
    }
   case 657:
    var $2912 = HEAP32[$51 >> 2] + 209948 | 0;
    var $2913 = __ZN11JSAtomState16commonAtomsStartEv($2912);
    var $atom_12 = HEAP32[$2913 + ($2900 << 2) >> 2];
    __label__ = 659;
    break;
   case 658:
    var $_idx35_val = HEAP32[$2901 + 56 >> 2];
    var $2917 = __ZN8JSScript7getAtomEj($_idx35_val, $2900);
    var $atom_12 = $2917;
    __label__ = 659;
    break;
   case 659:
    var $atom_12;
    var $2919 = $atom_12 | 0;
    var $2921 = __Z15js_IsIdentifierP14JSLinearString($atom_12 | 0);
    var $2923 = ($2921 | 0) != 0 ? 0 : 39;
    var $2924 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $2919, $2923);
    if (($2924 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 660;
      break;
    }
   case 660:
    var $2931 = HEAP8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 2) | 0];
    var $2932 = __ZL15IsInitializerOph($2931);
    var $2933 = $2932 & 1;
    var $2934 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $2935 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $isFirst_0 = $2933;
    var $lval_7 = $2935;
    var $rval_16 = $2934;
    var $xval_2 = $2924;
    __label__ = 661;
    break;
   case 661:
    var $xval_2;
    var $rval_16;
    var $lval_7;
    var $isFirst_0;
    var $2938 = ($isFirst_0 | 0) != 0 ? __str17668 | 0 : STRING_TABLE.__str296 | 0;
    var $2939 = ($67 | 0) == 125;
    if (($67 - 125 | 0) >>> 0 < 2) {
      __label__ = 662;
      break;
    } else {
      __label__ = 669;
      break;
    }
   case 662:
    var $2942 = _strlen($rval_16);
    if (HEAP8[$rval_16] << 24 >> 24 == 40) {
      __label__ = 663;
      break;
    } else {
      var $_sum_pn = $2942;
      var $rval_17 = $rval_16;
      __label__ = 664;
      break;
    }
   case 663:
    var $_sum_pn = $2942 - 1 | 0;
    var $rval_17 = $rval_16 + 1 | 0;
    __label__ = 664;
    break;
   case 664:
    var $rval_17;
    var $_sum_pn;
    var $end_0 = $rval_16 + $_sum_pn | 0;
    var $2948 = _strncmp($rval_17, STRING_TABLE.__str252545 | 0, 8);
    if (($2948 | 0) == 0) {
      __label__ = 665;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 665:
    if (HEAP8[$rval_17 + 8 | 0] << 24 >> 24 == 32) {
      __label__ = 666;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 666:
    var $2955 = $rval_17 + 9 | 0;
    var $2956 = HEAP8[$end_0];
    if ($2956 << 24 >> 24 == 0) {
      __label__ = 667;
      break;
    } else if ($2956 << 24 >> 24 == 41) {
      __label__ = 668;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 667:
    if (HEAP8[$rval_16 + ($_sum_pn - 1) | 0] << 24 >> 24 == 125) {
      __label__ = 668;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 668:
    var $_15 = $2939 ? STRING_TABLE.__str24079 : STRING_TABLE.__str44081;
    var $2962 = $_15 | 0;
    var $2965 = HEAP8[$2955] << 24 >> 24 != 40 ? STRING_TABLE.__str284577 | 0 : __str17668 | 0;
    var $2969 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1032776 | 0, (tempInt = STACKTOP, STACKTOP += 28, HEAP32[tempInt >> 2] = $lval_7, HEAP32[tempInt + 4 >> 2] = $2938, HEAP32[tempInt + 8 >> 2] = $2962, HEAP32[tempInt + 12 >> 2] = $xval_2, HEAP32[tempInt + 16 >> 2] = $2965, HEAP32[tempInt + 20 >> 2] = $end_0 - $2955 | 0, HEAP32[tempInt + 24 >> 2] = $2955, tempInt));
    HEAP32[$todo >> 2] = $2969;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $2955;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 669:
    var $2971 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1052778 | 0, (tempInt = STACKTOP, STACKTOP += 16, HEAP32[tempInt >> 2] = $lval_7, HEAP32[tempInt + 4 >> 2] = $2938, HEAP32[tempInt + 8 >> 2] = $xval_2, HEAP32[tempInt + 12 >> 2] = $rval_16, tempInt));
    HEAP32[$todo >> 2] = $2971;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_16;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 670:
    HEAP32[$i >> 2] = (HEAPU8[$_1 + 3 | 0] & 255) << 8 | HEAPU8[$_1 + 4 | 0] & 255;
    var $2981 = __ZL6PopStrP11SprintStack4JSOp($ss, 95);
    var $2982 = HEAP32[$i >> 2];
    var $2983 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1062779 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $2982, HEAP32[tempInt + 4 >> 2] = $2981, tempInt));
    HEAP32[$todo >> 2] = $2983;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $2981;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 671:
    var $2992 = (HEAPU8[$_1 + 3 | 0] & 255) << 8 | HEAPU8[$_1 + 4 | 0] & 255;
    HEAP32[$i >> 2] = $2992;
    var $2993 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1072780 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $2992, tempInt));
    HEAP32[$todo >> 2] = $2993;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 672:
    _js_printf($16, STRING_TABLE.__str1082781 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 673:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = ($op_2 | 0) == 194 & 1;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 674:
    var $2999 = __ZL6PopStrP11SprintStack4JSOp($ss, 163);
    _js_printf($16, STRING_TABLE.__str1092782 | 0, (tempInt = STACKTOP, STACKTOP += 16, HEAP32[tempInt >> 2] = STRING_TABLE._js_default_str | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str269562 | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str2333385 | 0, HEAP32[tempInt + 12 >> 2] = $2999, tempInt));
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $2999;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 675:
    if (HEAP8[$_1 + 1 | 0] << 24 >> 24 == -88) {
      __label__ = 676;
      break;
    } else {
      __label__ = 677;
      break;
    }
   case 676:
    var $3005 = $89 + 1 | 0;
    var $3006 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str1102783 | 0, 2);
    HEAP32[$todo >> 2] = $3006;
    var $_16 = $_1;
    var $len_10 = $3005;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 677:
    var $3008 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str253177 | 0, 1);
    HEAP32[$todo >> 2] = $3008;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 678:
    var $3010 = HEAP32[$_pre_phi >> 2];
    var $3011 = _js_GetIndexFromBytecode($3010, $_1, 0);
    var $3012 = HEAPU32[$_pre_phi >> 2];
    var $3014 = HEAPU32[$3012 >> 2];
    if ($_1 >>> 0 < $3014 >>> 0) {
      __label__ = 680;
      break;
    } else {
      __label__ = 679;
      break;
    }
   case 679:
    if (($3014 + HEAP32[$3012 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 681;
      break;
    } else {
      __label__ = 680;
      break;
    }
   case 680:
    var $3023 = HEAP32[$51 >> 2] + 209948 | 0;
    var $3024 = __ZN11JSAtomState16commonAtomsStartEv($3023);
    var $atom_13 = HEAP32[$3024 + ($3011 << 2) >> 2];
    __label__ = 682;
    break;
   case 681:
    var $_idx34_val = HEAP32[$3012 + 56 >> 2];
    var $3028 = __ZN8JSScript7getAtomEj($_idx34_val, $3011);
    var $atom_13 = $3028;
    __label__ = 682;
    break;
   case 682:
    var $atom_13;
    if (HEAP8[$_1 + 3 | 0] << 24 >> 24 == -88) {
      __label__ = 683;
      break;
    } else {
      var $len_6 = $89;
      var $lval_6 = __str17668 | 0;
      var $atom_10 = $atom_13;
      __label__ = 516;
      break;
    }
   case 683:
    HEAP32[$saveop >> 2] = 168;
    var $len_6 = $89 + 1 | 0;
    var $lval_6 = STRING_TABLE.__str1112784 | 0;
    var $atom_10 = $atom_13;
    __label__ = 516;
    break;
   case 684:
    var $3036 = HEAP32[$_pre_phi >> 2];
    var $3037 = _js_GetIndexFromBytecode($3036, $_1, 0);
    var $3038 = HEAPU32[$_pre_phi >> 2];
    var $3040 = HEAPU32[$3038 >> 2];
    if ($_1 >>> 0 < $3040 >>> 0) {
      __label__ = 686;
      break;
    } else {
      __label__ = 685;
      break;
    }
   case 685:
    if (($3040 + HEAP32[$3038 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 687;
      break;
    } else {
      __label__ = 686;
      break;
    }
   case 686:
    var $3049 = HEAP32[$51 >> 2] + 209948 | 0;
    var $3050 = __ZN11JSAtomState16commonAtomsStartEv($3049);
    var $atom_14 = HEAP32[$3050 + ($3037 << 2) >> 2];
    __label__ = 688;
    break;
   case 687:
    var $_idx33_val = HEAP32[$3038 + 56 >> 2];
    var $3054 = __ZN8JSScript7getAtomEj($_idx33_val, $3037);
    var $atom_14 = $3054;
    __label__ = 688;
    break;
   case 688:
    var $atom_14;
    var $3057 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_14 | 0, 0);
    if (($3057 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 689;
      break;
    }
   case 689:
    var $3063 = $3057 - HEAP32[$37 >> 2] | 0;
    HEAP32[$38 >> 2] = $3063;
    var $3064 = __ZL6PopStrP11SprintStack4JSOp($ss, 166);
    var $3065 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1122785 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $3064, HEAP32[tempInt + 4 >> 2] = $3057, tempInt));
    HEAP32[$todo >> 2] = $3065;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $3057;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 690:
    var $3067 = __ZL6PopStrP11SprintStack4JSOp($ss, 167);
    var $3068 = __ZL6PopStrP11SprintStack4JSOp($ss, 167);
    var $3069 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1132786 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $3068, HEAP32[tempInt + 4 >> 2] = $3067, tempInt));
    HEAP32[$todo >> 2] = $3069;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $3067;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 691:
    var $3071 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $3072 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1142787 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $3071, tempInt));
    HEAP32[$todo >> 2] = $3072;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $3071;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 692:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 693:
    var $3075 = __ZL6PopStrP11SprintStack4JSOp($ss, 170);
    var $3076 = __ZL6PopStrP11SprintStack4JSOp($ss, 170);
    var $3077 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str692742 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $3076, HEAP32[tempInt + 4 >> 2] = $3075, tempInt));
    HEAP32[$todo >> 2] = $3077;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $3075;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = 1;
    __label__ = 735;
    break;
   case 694:
    var $3079 = __ZL6PopStrP11SprintStack4JSOp($ss, 171);
    var $3080 = __ZL6PopStrP11SprintStack4JSOp($ss, 171);
    if (($quoteAttr_0 | 0) == 0) {
      __label__ = 696;
      break;
    } else {
      __label__ = 695;
      break;
    }
   case 695:
    var $3083 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1152788 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $3080, HEAP32[tempInt + 4 >> 2] = $3079, tempInt));
    HEAP32[$todo >> 2] = $3083;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $3079;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 696:
    var $3085 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1162789 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $3080, HEAP32[tempInt + 4 >> 2] = $3079, tempInt));
    HEAP32[$todo >> 2] = $3085;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $3079;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = 0;
    __label__ = 735;
    break;
   case 697:
    var $3087 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, __str17668 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$todo >> 2] = $3087;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 698:
    var $3089 = __ZL6PopStrP11SprintStack4JSOp($ss, 173);
    var $3090 = __ZL6PopOffP11SprintStack4JSOp($ss, 173);
    var $3091 = __ZL6PopStrP11SprintStack4JSOp($ss, 173);
    var $op_8 = 173;
    var $cs_1 = $cs_0;
    var $lval_1 = $3091;
    var $rval_13 = $3089;
    __label__ = 389;
    break;
   case 699:
    var $3093 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $3094 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1172790 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $3093, tempInt));
    HEAP32[$todo >> 2] = $3094;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = 1;
    var $quoteAttr_1 = 0;
    __label__ = 735;
    break;
   case 700:
    var $3096 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $3097 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1182791 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $3096, tempInt));
    HEAP32[$todo >> 2] = $3097;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = 0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 701:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = 0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 702:
    var $3100 = __ZL6PopStrP11SprintStack4JSOp($ss, 177);
    var $3105 = HEAP8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 1) | 0];
    if ($3105 << 24 >> 24 == 58 || $3105 << 24 >> 24 == 123 || $3105 << 24 >> 24 == 108 || $3105 << 24 >> 24 == 79) {
      __label__ = 703;
      break;
    } else {
      __label__ = 704;
      break;
    }
   case 703:
    HEAP32[$saveop >> 2] = 58;
    __label__ = 704;
    break;
   case 704:
    var $3108 = __ZL6PopStrP11SprintStack4JSOp($ss, 177);
    var $3109 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1192792 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $3108, HEAP32[tempInt + 4 >> 2] = $3100, tempInt));
    HEAP32[$todo >> 2] = $3109;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $3100;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 705:
    var $3111 = __ZL6PopStrP11SprintStack4JSOp($ss, 175);
    var $3116 = HEAP8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 1) | 0];
    if ($3116 << 24 >> 24 == 58 || $3116 << 24 >> 24 == 123 || $3116 << 24 >> 24 == 108 || $3116 << 24 >> 24 == 79) {
      __label__ = 706;
      break;
    } else {
      __label__ = 707;
      break;
    }
   case 706:
    HEAP32[$saveop >> 2] = 58;
    __label__ = 707;
    break;
   case 707:
    var $3119 = __ZL6PopStrP11SprintStack4JSOp($ss, 175);
    var $3120 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1202793 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $3119, HEAP32[tempInt + 4 >> 2] = $3111, tempInt));
    HEAP32[$todo >> 2] = $3120;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $3111;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 708:
    var $3122 = HEAP32[$_pre_phi >> 2];
    var $3123 = _js_GetIndexFromBytecode($3122, $_1, 0);
    var $3124 = HEAPU32[$_pre_phi >> 2];
    var $3126 = HEAPU32[$3124 >> 2];
    if ($_1 >>> 0 < $3126 >>> 0) {
      __label__ = 710;
      break;
    } else {
      __label__ = 709;
      break;
    }
   case 709:
    if (($3126 + HEAP32[$3124 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 711;
      break;
    } else {
      __label__ = 710;
      break;
    }
   case 710:
    var $3135 = HEAP32[$51 >> 2] + 209948 | 0;
    var $3136 = __ZN11JSAtomState16commonAtomsStartEv($3135);
    var $atom_15 = HEAP32[$3136 + ($3123 << 2) >> 2];
    __label__ = 712;
    break;
   case 711:
    var $_idx32_val = HEAP32[$3124 + 56 >> 2];
    var $3140 = __ZN8JSScript7getAtomEj($_idx32_val, $3123);
    var $atom_15 = $3140;
    __label__ = 712;
    break;
   case 712:
    var $atom_15;
    var $3142 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str1212794 | 0, 9);
    HEAP32[$todo >> 2] = $3142;
    var $3144 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_15 | 0, 65536);
    if (($3144 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 713;
      break;
    }
   case 713:
    var $3147 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str1222795 | 0, 3);
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 714:
    var $3149 = HEAP32[$_pre_phi >> 2];
    var $3150 = _js_GetIndexFromBytecode($3149, $_1, 0);
    var $3151 = HEAPU32[$_pre_phi >> 2];
    var $3153 = HEAPU32[$3151 >> 2];
    if ($_1 >>> 0 < $3153 >>> 0) {
      __label__ = 716;
      break;
    } else {
      __label__ = 715;
      break;
    }
   case 715:
    if (($3153 + HEAP32[$3151 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 717;
      break;
    } else {
      __label__ = 716;
      break;
    }
   case 716:
    var $3162 = HEAP32[$51 >> 2] + 209948 | 0;
    var $3163 = __ZN11JSAtomState16commonAtomsStartEv($3162);
    var $atom_16 = HEAP32[$3163 + ($3150 << 2) >> 2];
    __label__ = 718;
    break;
   case 717:
    var $_idx31_val = HEAP32[$3151 + 56 >> 2];
    var $3167 = __ZN8JSScript7getAtomEj($_idx31_val, $3150);
    var $atom_16 = $3167;
    __label__ = 718;
    break;
   case 718:
    var $atom_16;
    var $3169 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str1232796 | 0, 4);
    HEAP32[$todo >> 2] = $3169;
    var $3171 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_16 | 0, 65536);
    if (($3171 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 719;
      break;
    }
   case 719:
    var $3174 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str1242797 | 0, 3);
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 720:
    var $3176 = HEAP32[$_pre_phi >> 2];
    var $3177 = _js_GetIndexFromBytecode($3176, $_1, 0);
    var $3178 = HEAPU32[$_pre_phi >> 2];
    var $3180 = HEAPU32[$3178 >> 2];
    if ($_1 >>> 0 < $3180 >>> 0) {
      __label__ = 722;
      break;
    } else {
      __label__ = 721;
      break;
    }
   case 721:
    if (($3180 + HEAP32[$3178 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 723;
      break;
    } else {
      __label__ = 722;
      break;
    }
   case 722:
    var $3189 = HEAP32[$51 >> 2] + 209948 | 0;
    var $3190 = __ZN11JSAtomState16commonAtomsStartEv($3189);
    var $atom_17 = HEAP32[$3190 + ($3177 << 2) >> 2];
    __label__ = 724;
    break;
   case 723:
    var $_idx30_val = HEAP32[$3178 + 56 >> 2];
    var $3194 = __ZN8JSScript7getAtomEj($_idx30_val, $3177);
    var $atom_17 = $3194;
    __label__ = 724;
    break;
   case 724:
    var $atom_17;
    var $3196 = __ZL6PopStrP11SprintStack4JSOp($ss, 185);
    var $3197 = _JS_strdup($8, $3196);
    if (($3197 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 725;
      break;
    }
   case 725:
    var $3200 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str1252798 | 0, 2);
    HEAP32[$todo >> 2] = $3200;
    var $3202 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_17 | 0, 0);
    if (($3202 | 0) == 0) {
      __label__ = 729;
      break;
    } else {
      __label__ = 726;
      break;
    }
   case 726:
    if (HEAP8[$3197] << 24 >> 24 == 0) {
      __label__ = 731;
      break;
    } else {
      __label__ = 727;
      break;
    }
   case 727:
    var $3208 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str284577 | 0, 1);
    if (($3208 | 0) > -1) {
      __label__ = 728;
      break;
    } else {
      __label__ = 730;
      break;
    }
   case 728:
    var $3211 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, $3197);
    var $3212 = ($3211 | 0) == 0;
    __ZN9JSContext5free_EPv($3197);
    if ($3212) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 732;
      break;
    }
   case 729:
    __ZN9JSContext5free_EPv($3197);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 730:
    __ZN9JSContext5free_EPv($3197);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 731:
    __ZN9JSContext5free_EPv($3197);
    __label__ = 732;
    break;
   case 732:
    var $3214 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str1262799 | 0, 2);
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $3197;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 733:
    var $3216 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str252545 | 0, 8);
    HEAP32[$todo >> 2] = $3216;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 734:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 735:
    var $quoteAttr_1;
    var $inXML_1;
    var $foreach_1;
    var $rval_18;
    var $cs_3;
    var $len_10;
    var $_16;
    var $3218 = HEAP32[$todo >> 2];
    if (($3218 | 0) < 0) {
      __label__ = 736;
      break;
    } else {
      __label__ = 737;
      break;
    }
   case 736:
    if (($3218 | 0) == -1) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 738;
      break;
    }
   case 737:
    var $3223 = HEAP32[$saveop >> 2];
    var $3224 = __ZL7PushOffP11SprintStacki4JSOp($ss, $3218, $3223);
    if (($3224 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 738;
      break;
    }
   case 738:
    if ((HEAP32[$cs_3 + 4 >> 2] & 524288 | 0) == 0) {
      __label__ = 741;
      break;
    } else {
      __label__ = 739;
      break;
    }
   case 739:
    var $3232 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, __str17668 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$todo >> 2] = $3232;
    if (($3232 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 740;
      break;
    }
   case 740:
    var $3235 = HEAP32[$saveop >> 2];
    var $3236 = __ZL7PushOffP11SprintStacki4JSOp($ss, $3232, $3235);
    if (($3236 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 741;
      break;
    }
   case 741:
    var $_016 = $_16 + $len_10 | 0;
    var $rval_0 = $rval_18;
    var $foreach_0 = $foreach_1;
    var $inXML_0 = $inXML_1;
    var $quoteAttr_0 = $quoteAttr_1;
    __label__ = 7;
    break;
   case 742:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9DecompileP11SprintStackPhi4JSOp["X"] = 1;

function _JSVAL_TO_INT32_IMPL2866($l_0$0, $l_0$1) {
  return $l_0$0;
}

function __ZL15IsInitializerOph($op) {
  return ($op - 89 & 255 & 255) < 3;
}

function _JSVAL_IS_STRING_IMPL2869($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -123) & 1;
}

function _JSVAL_IS_DOUBLE_IMPL2870($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 < 4294967169 & 1;
}

function _JSVAL_TO_STRING_IMPL2873($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSDOUBLE_IS_NEGZERO2875($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d != 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $_0 = tempDoubleI32[1] >>> 31 | 0 << 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18JSDOUBLE_IS_FINITEd2876($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function __ZL15JSDOUBLE_IS_NaNd2877($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZL9IsVarSlotP9JSPrinterPhPi($jp, $pc_1_val, $pc_2_val, $indexp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = ($pc_1_val & 255) << 8 | $pc_2_val & 255;
    var $9 = HEAPU16[HEAP32[$jp + 56 >> 2] + 14 >> 1] & 65535;
    if ($4 >>> 0 < $9 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = 1;
    var $storemerge = (HEAPU16[HEAP32[$jp + 68 >> 2] + 56 >> 1] & 65535) + $4 | 0;
    __label__ = 4;
    break;
   case 3:
    var $_0 = 0;
    var $storemerge = $4 - $9 | 0;
    __label__ = 4;
    break;
   case 4:
    var $storemerge;
    var $_0;
    HEAP32[$indexp >> 2] = $storemerge;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18GetDecomposeLengthEPhj2861($pc, $len) {
  return HEAPU8[$pc + ($len - 1) | 0] & 255;
}

function __ZL14CompareOffsetsPvPKvS1_Pi($arg, $v1, $v2, $result) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$v1 + 8 >> 2];
    var $6 = HEAP32[$v2 + 8 >> 2];
    if (($3 | 0) == ($6 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $21 = HEAP32[$v1 + 16 >> 2] - HEAP32[$v2 + 16 >> 2] | 0;
    __label__ = 4;
    break;
   case 3:
    var $21 = $3 - $6 >> 31 | 1;
    __label__ = 4;
    break;
   case 4:
    var $21;
    HEAP32[$result >> 2] = $21;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13JSVAL_TO_IMPLN2JS5ValueE2867($agg_result, $_0_0_0_val$0, $_0_0_0_val$1) {
  var $agg_result_0 = $agg_result | 0;
  HEAP32[$agg_result_0 >> 2] = $_0_0_0_val$0;
  HEAP32[$agg_result_0 + 4 >> 2] = $_0_0_0_val$1;
  return;
}

function __ZL13IMPL_TO_JSVAL12jsval_layout2871($agg_result, $l_0$0, $l_0$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $l_0$0;
  HEAP32[$1 + 4 >> 2] = $l_0$1;
  return;
}

function _INT32_TO_JSVAL_IMPL2872($agg_result, $i) {
  HEAP32[$agg_result + 4 >> 2] = -127;
  HEAP32[$agg_result >> 2] = $i;
  return;
}

function __ZL6PopOffP11SprintStack4JSOp($ss, $op) {
  var $2 = HEAP8[_js_CodeSpec + ($op << 3) + 3 | 0];
  var $3 = __ZL10PopOffPrecP11SprintStackh($ss, $2);
  return $3;
}

function __ZL10PopOffPrecP11SprintStackh($ss, $prec) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $ss + 28 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 - 1 | 0;
    HEAP32[$1 >> 2] = $5;
    var $6 = __ZL6GetOffP11SprintStackj($ss, $5);
    var $13 = HEAPU8[_js_CodeSpec + ((HEAPU8[HEAP32[$ss + 24 >> 2] + $5 | 0] & 255) << 3) + 3 | 0];
    if ($13 << 24 >> 24 != 0 & ($13 & 255) < ($prec & 255)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $17 = $6 - 2 | 0;
    var $20 = HEAP32[$ss + 20 >> 2] + ($5 << 2) | 0;
    HEAP32[$20 >> 2] = $17;
    var $21 = $ss | 0;
    HEAP32[$ss + 16 >> 2] = $17;
    var $25 = HEAP32[$ss + 8 >> 2] + $6 | 0;
    var $26 = __ZN2js6SprintEPNS_8SprinterEPKcz($21, STRING_TABLE.__str392712 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $25, tempInt));
    var $_0 = $26;
    __label__ = 5;
    break;
   case 4:
    HEAP32[$ss + 16 >> 2] = $6;
    var $_0 = $6;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL6GetOffP11SprintStackj($ss, $i) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $ss + 20 | 0;
    var $4 = HEAP32[HEAP32[$1 >> 2] + ($i << 2) >> 2];
    if (($4 | 0) > -1) {
      var $_0 = $4;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($4 | 0) < -1) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 3:
    var $10 = HEAP32[$ss + 40 >> 2];
    var $12 = HEAP32[$10 + 64 >> 2];
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = HEAP32[$12 + (-2 - $4 << 2) >> 2];
    var $18 = $ss | 0;
    var $20 = HEAP32[$ss >> 2];
    var $22 = HEAP32[$10 + 56 >> 2];
    var $24 = HEAP32[$10 + 68 >> 2];
    var $25 = __ZL19DecompileExpressionP9JSContextP8JSScriptP10JSFunctionPh($20, $22, $24, $17);
    var $magicptr = $25;
    if (($magicptr | 0) == 1) {
      __label__ = 6;
      break;
    } else if (($magicptr | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $27 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($18, $25);
    var $off_0 = ($27 | 0) < 0 ? 0 : $27;
    var $30 = HEAP32[$1 >> 2] + ($i << 2) | 0;
    HEAP32[$30 >> 2] = $off_0;
    __ZN9JSContext5free_EPv($25);
    var $_0 = $off_0;
    __label__ = 9;
    break;
   case 6:
    var $32 = $ss + 8 | 0;
    if ((HEAP32[$32 >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $36 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($18, __str17668 | 0, 0);
    if (($36 | 0) > -1) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $39 = HEAP32[$32 >> 2];
    var $41 = HEAP32[$ss + 16 >> 2];
    _memset($39, 0, $41, 1);
    var $43 = HEAP32[$1 >> 2] + ($i << 2) | 0;
    HEAP32[$43 >> 2] = -1;
    var $_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL6GetOffP11SprintStackj["X"] = 1;

function __ZL10PopStrPrecP11SprintStackh($ss, $prec) {
  var $1 = __ZL10PopOffPrecP11SprintStackh($ss, $prec);
  return HEAP32[$ss + 8 >> 2] + $1 | 0;
}

function __ZL24DecompileGroupAssignmentP11SprintStackPhS1_S1_Pi($ss, $pc, $endpc, $sn, $todop) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $hole = __stackBase__;
    var $1 = HEAPU8[$pc];
    var $4 = HEAP8[_js_CodeSpec + (($1 & 255) << 3) | 0];
    if ($1 << 24 >> 24 == 86 || $1 << 24 >> 24 == 1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 2:
    var $6 = $ss | 0;
    var $7 = __ZL9VarPrefixPh($sn);
    var $8 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1362809 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $7, tempInt));
    if (($8 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZL7PushOffP11SprintStacki4JSOp($ss, $8, 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $ss + 16 | 0;
    var $16 = HEAP32[$14 >> 2] - 3 | 0;
    HEAP32[$14 >> 2] = $16;
    var $_04 = $pc;
    var $oplen_0_in = $4;
    __label__ = 5;
    break;
   case 5:
    var $oplen_0_in;
    var $_04;
    var $17 = $_04 + ($oplen_0_in << 24 >> 24) | 0;
    if (($17 | 0) == ($endpc | 0)) {
      var $_0 = $17;
      __label__ = 21;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = __ZL25DecompileDestructuringLHSP11SprintStackPhS1_Pi($ss, $17, $endpc, $hole);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($20 | 0) == ($endpc | 0)) {
      var $_0 = $20;
      __label__ = 21;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $25 = HEAPU8[$20];
    var $28 = HEAP8[_js_CodeSpec + (($25 & 255) << 3) | 0];
    if ($25 << 24 >> 24 == 86 || $25 << 24 >> 24 == 1) {
      __label__ = 9;
      break;
    } else if ($25 << 24 >> 24 == 11) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 9:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_04 = $20;
      var $oplen_0_in = $28;
      __label__ = 5;
      break;
    }
   case 10:
    var $33 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str296 | 0, 2);
    if (($33 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      var $_04 = $20;
      var $oplen_0_in = $28;
      __label__ = 5;
      break;
    }
   case 11:
    var $36 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str1372810 | 0, 5);
    if (($36 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $39 = $ss + 28 | 0;
    var $40 = HEAPU32[$39 >> 2];
    var $41 = $40 - 1 | 0;
    var $50 = $41 - ((HEAPU8[$20 + 1 | 0] & 255) << 8 | HEAPU8[$20 + 2 | 0] & 255) | 0;
    var $51 = $40 - 2 | 0;
    var $i_0 = $50;
    __label__ = 13;
    break;
   case 13:
    var $i_0;
    if ($i_0 >>> 0 < $41 >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 14:
    var $55 = __ZL6GetStrP11SprintStackj($ss, $i_0);
    var $57 = ($i_0 | 0) == ($50 | 0) ? STRING_TABLE.__str382711 | 0 : STRING_TABLE.__str1382811 | 0;
    if (($i_0 | 0) == ($51 | 0)) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    if (HEAP8[$55] << 24 >> 24 == 0) {
      var $64 = STRING_TABLE.__str296 | 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $64 = $55;
    __label__ = 17;
    break;
   case 17:
    var $64;
    var $65 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $57, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $64, tempInt));
    if (($65 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 13;
    break;
   case 19:
    var $70 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str562729 | 0, 1);
    if (($70 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $76 = HEAP32[HEAP32[$ss + 20 >> 2] + ($i_0 << 2) >> 2];
    HEAP32[$14 >> 2] = $76;
    HEAP32[$39 >> 2] = $50;
    HEAP32[$todop >> 2] = $8;
    var $_0 = $20;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL24DecompileGroupAssignmentP11SprintStackPhS1_S1_Pi["X"] = 1;

function __ZL7PushOffP11SprintStacki4JSOp($ss, $off, $op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $ss | 0;
    var $2 = __ZL18SprintEnsureBufferPN2js8SprinterEj($1, 3);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $ss + 28 | 0;
    var $6 = HEAPU32[$5 >> 2];
    var $10 = HEAP32[HEAP32[$ss + 40 >> 2] + 56 >> 2];
    var $_idx_val = HEAP16[$10 + 14 >> 1];
    var $_idx1_val = HEAP16[$10 + 44 >> 1];
    var $11 = __ZL10StackDepthP8JSScript($_idx_val, $_idx1_val);
    if ($6 >>> 0 < $11 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = HEAP32[$ss >> 2];
    _JS_ReportOutOfMemory($15);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 4:
    var $19 = HEAP32[$ss + 20 >> 2] + ($6 << 2) | 0;
    HEAP32[$19 >> 2] = $off;
    if (($op | 0) == 232) {
      var $25 = 53;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $phitmp = ($op | 0) == 233 ? 55 : $op & 255;
    var $25 = $phitmp;
    __label__ = 6;
    break;
   case 6:
    var $25;
    HEAP8[HEAP32[$ss + 24 >> 2] + $6 | 0] = $25;
    HEAP32[$5 >> 2] = $6 + 1 | 0;
    __ZL12AddParenSlopP11SprintStack($ss);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9VarPrefixPh($sn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($sn | 0) == 0) {
      var $_0 = __str17668 | 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = HEAPU8[$sn];
    var $_mask = $3 & -8;
    if (($3 & 255) < 192 & ($_mask << 24 >> 24 == 48 | $_mask << 24 >> 24 == 56)) {
      __label__ = 3;
      break;
    } else {
      var $_0 = __str17668 | 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $6 = _js_GetSrcNoteOffset($sn, 0);
    if ($6 >>> 0 < 3) {
      __label__ = 4;
      break;
    } else {
      var $_0 = __str17668 | 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = HEAP32[__ZL10var_prefix + ($6 << 2) >> 2];
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12AddParenSlopP11SprintStack($ss) {
  var $3 = $ss + 16 | 0;
  var $5 = HEAP32[$ss + 8 >> 2] + HEAP32[$3 >> 2] | 0;
  HEAP8[$5] = 0;
  HEAP8[$5 + 1] = 0;
  HEAP8[$5 + 2] = 0;
  var $7 = HEAP32[$3 >> 2] + 3 | 0;
  HEAP32[$3 >> 2] = $7;
  return;
}

function _DOUBLE_TO_JSVAL2862($agg_result, $d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = isNaN($d) || isNaN(0);
    if ($1) {
      var $l_0_0$1 = 2146959360;
      var $l_0_0$0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $l_0_0$1 = tempDoubleI32[1];
    var $l_0_0$0 = tempDoubleI32[0];
    __label__ = 3;
    break;
   case 3:
    var $l_0_0$0;
    var $l_0_0$1;
    __ZL13IMPL_TO_JSVAL12jsval_layout2871($agg_result, $l_0_0$0, $l_0_0$1);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17SprintDoubleValuePN2js8SprinterEN2JS5ValueEP4JSOp($sp, $_0_0_0_val$0, $_0_0_0_val$1, $opp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cbuf = __stackBase__;
    var $1 = _JSVAL_TO_DOUBLE($_0_0_0_val$0, $_0_0_0_val$1);
    var $2 = _JSDOUBLE_IS_NEGZERO2875($1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($sp, STRING_TABLE.__str1292802 | 0);
    HEAP32[$opp >> 2] = 34;
    var $_1 = $5;
    __label__ = 10;
    break;
   case 3:
    var $7 = __ZL18JSDOUBLE_IS_FINITEd2876($1);
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $10 = __ZL15JSDOUBLE_IS_NaNd2877($1);
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $16 = STRING_TABLE.__str1302803 | 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $14 = $1 < 0 ? STRING_TABLE.__str1312804 | 0 : STRING_TABLE.__str1322805 | 0;
    var $16 = $14;
    __label__ = 6;
    break;
   case 6:
    var $16;
    var $17 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($sp, $16);
    HEAP32[$opp >> 2] = 30;
    var $_1 = $17;
    __label__ = 10;
    break;
   case 7:
    __ZN2js12ToCStringBufC2Ev($cbuf);
    var $19 = $sp | 0;
    var $20 = HEAP32[$19 >> 2];
    var $21 = __ZN2js15NumberToCStringEP9JSContextPNS_12ToCStringBufEdi($20, $cbuf, $1);
    if (($21 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $23 = HEAP32[$19 >> 2];
    _JS_ReportOutOfMemory($23);
    var $cbuf_idx1_val = HEAP32[$cbuf + 36 >> 2];
    __ZN2js12ToCStringBufD2Ev($cbuf_idx1_val);
    var $_1 = -1;
    __label__ = 10;
    break;
   case 9:
    var $25 = __ZN2js6SprintEPNS_8SprinterEPKcz($sp, $21, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $cbuf_idx_val = HEAP32[$cbuf + 36 >> 2];
    __ZN2js12ToCStringBufD2Ev($cbuf_idx_val);
    var $_1 = $25;
    __label__ = 10;
    break;
   case 10:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11ObjectValueER8JSObject2863($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function _JSVAL_TO_STRING2864($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE2867($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_STRING_IMPL2873($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _INT_TO_JSVAL2865($agg_result, $i) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _INT32_TO_JSVAL_IMPL2872($1, $i);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout2871($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZL15DecompileSwitchP11SprintStackP10TableEntryjPhiii($ss, $table, $tableLength, $pc, $switchLength, $defaultOffset, $isCondSwitch) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $junk = __stackBase__;
    var $1 = $ss | 0;
    var $3 = HEAP32[$ss >> 2];
    var $5 = HEAPU32[$ss + 40 >> 2];
    var $6 = ($isCondSwitch | 0) != 0;
    if ($6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = HEAP32[$ss + 28 >> 2] - 1 | 0;
    var $11 = __ZL6GetOffP11SprintStackj($ss, $10);
    var $15 = $11;
    __label__ = 4;
    break;
   case 3:
    var $13 = __ZL6PopOffP11SprintStack4JSOp($ss, 0);
    var $15 = $13;
    __label__ = 4;
    break;
   case 4:
    var $15;
    var $16 = $ss + 8 | 0;
    var $18 = HEAP32[$16 >> 2] + $15 | 0;
    _js_printf($5, STRING_TABLE.__str1272800 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $18, tempInt));
    if (($tableLength | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = HEAP32[$table + 8 >> 2] - $defaultOffset | 0;
    var $25 = $5 + 48 | 0;
    if (($23 | 0) > 0) {
      __label__ = 6;
      break;
    } else {
      var $_pre_phi = $25;
      __label__ = 8;
      break;
    }
   case 6:
    var $28 = HEAP32[$25 >> 2] + 2 | 0;
    HEAP32[$25 >> 2] = $28;
    _js_printf($5, STRING_TABLE.__str472720 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_default_str | 0, tempInt));
    var $30 = HEAP32[$25 >> 2] + 2 | 0;
    HEAP32[$25 >> 2] = $30;
    var $31 = $pc + $defaultOffset | 0;
    var $32 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $31, $23);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $36 = HEAP32[$25 >> 2] - 4 | 0;
    HEAP32[$25 >> 2] = $36;
    var $_pre_phi = $25;
    __label__ = 8;
    break;
   case 8:
    var $_pre_phi;
    var $38 = $ss + 28 | 0;
    var $39 = $3;
    var $40 = $ss + 16 | 0;
    var $i_0 = 0;
    var $caseExprOff_0 = $6 & 1;
    __label__ = 9;
    break;
   case 9:
    var $caseExprOff_0;
    var $i_0;
    if ($i_0 >>> 0 < $tableLength >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 10:
    var $44 = HEAP32[$table + $i_0 * 24 + 8 >> 2];
    var $45 = $i_0 + 1 | 0;
    if ($45 >>> 0 < $tableLength >>> 0) {
      __label__ = 11;
      break;
    } else {
      var $51 = $switchLength;
      __label__ = 12;
      break;
    }
   case 11:
    var $51 = HEAP32[$table + $45 * 24 + 8 >> 2];
    __label__ = 12;
    break;
   case 12:
    var $51;
    var $52 = $table + $i_0 * 24 | 0;
    var $st$2$0 = $52 | 0;
    var $53$0 = HEAPU32[$st$2$0 >> 2];
    var $st$2$1 = $52 + 4 | 0;
    var $53$1 = HEAPU32[$st$2$1 >> 2];
    if ($6) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $55 = _JSVAL_TO_INT($53$0, $53$1);
    var $62 = (HEAP8[_js_CodeSpec + ((HEAPU8[$pc + $55 | 0] & 255) << 3) | 0] << 24 >> 24) + $55 | 0;
    var $64 = HEAP32[$_pre_phi >> 2] + 2 | 0;
    HEAP32[$_pre_phi >> 2] = $64;
    var $65 = $pc + $caseExprOff_0 | 0;
    var $66 = $62 - $caseExprOff_0 | 0;
    var $67 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $65, $66);
    if (($67 | 0) == 0) {
      var $_0 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $71 = HEAP32[$38 >> 2] - 1 | 0;
    HEAP32[$38 >> 2] = $71;
    var $caseExprOff_1 = $62;
    __label__ = 24;
    break;
   case 15:
    var $74 = HEAP32[$table + $i_0 * 24 + 12 >> 2];
    if (($74 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$2$0 = $$emscripten$temp$0 | 0;
    var $st$2$1 = $$emscripten$temp$0 + 4 | 0;
    var $str_0_ph = $74 | 0;
    var $key_0_0_0$1 = HEAP32[$st$2$1 >> 2];
    var $key_0_0_0$0 = HEAP32[$st$2$0 >> 2];
    __label__ = 21;
    break;
   case 17:
    var $80 = _JSVAL_IS_DOUBLE($53$0, $53$1);
    if (($80 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $83 = __ZL17SprintDoubleValuePN2js8SprinterEN2JS5ValueEP4JSOp($1, $53$0, $53$1, $junk);
    if (($83 | 0) < 0) {
      var $_0 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $86 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($39, $53$0, $53$1);
    if (($86 | 0) == 0) {
      var $_0 = 0;
      __label__ = 36;
      break;
    } else {
      var $str_0_ph = $86;
      var $key_0_0_0$1 = $53$1;
      var $key_0_0_0$0 = $53$0;
      __label__ = 21;
      break;
    }
   case 20:
    var $89 = HEAP32[$16 >> 2];
    var $rval_0 = $89 + $83 | 0;
    var $98 = $89;
    __label__ = 23;
    break;
   case 21:
    var $key_0_0_0$0;
    var $key_0_0_0$1;
    var $str_0_ph;
    var $92 = _JSVAL_IS_STRING2868($key_0_0_0$0, $key_0_0_0$1);
    var $94 = ($92 | 0) != 0 ? 34 : 0;
    var $95 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($1, $str_0_ph, $94);
    if (($95 | 0) == 0) {
      var $_0 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $rval_0 = $95;
    var $98 = HEAP32[$16 >> 2];
    __label__ = 23;
    break;
   case 23:
    var $98;
    var $rval_0;
    HEAP32[$40 >> 2] = $rval_0 - $98 | 0;
    var $103 = HEAP32[$_pre_phi >> 2] + 2 | 0;
    HEAP32[$_pre_phi >> 2] = $103;
    _js_printf($5, STRING_TABLE.__str982771 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $rval_0, tempInt));
    var $caseExprOff_1 = $caseExprOff_0;
    __label__ = 24;
    break;
   case 24:
    var $caseExprOff_1;
    var $106 = HEAP32[$_pre_phi >> 2] + 2 | 0;
    HEAP32[$_pre_phi >> 2] = $106;
    if (($44 | 0) <= ($defaultOffset | 0) & ($51 | 0) > ($defaultOffset | 0)) {
      __label__ = 25;
      break;
    } else {
      var $off_1 = $44;
      __label__ = 29;
      break;
    }
   case 25:
    if (($44 | 0) == ($defaultOffset | 0)) {
      var $off_0 = $44;
      var $117 = $106;
      __label__ = 28;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $112 = $defaultOffset - $44 | 0;
    var $113 = $pc + $44 | 0;
    var $114 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $113, $112);
    if (($114 | 0) == 0) {
      var $_0 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $off_0 = $defaultOffset;
    var $117 = HEAP32[$_pre_phi >> 2];
    __label__ = 28;
    break;
   case 28:
    var $117;
    var $off_0;
    HEAP32[$_pre_phi >> 2] = $117 - 2 | 0;
    _js_printf($5, STRING_TABLE.__str472720 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_default_str | 0, tempInt));
    var $120 = HEAP32[$_pre_phi >> 2] + 2 | 0;
    HEAP32[$_pre_phi >> 2] = $120;
    var $off_1 = $off_0;
    __label__ = 29;
    break;
   case 29:
    var $off_1;
    var $122 = $pc + $off_1 | 0;
    var $124 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $122, $51 - $off_1 | 0);
    if (($124 | 0) == 0) {
      var $_0 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $128 = HEAP32[$_pre_phi >> 2] - 4 | 0;
    HEAP32[$_pre_phi >> 2] = $128;
    if ($6) {
      __label__ = 31;
      break;
    } else {
      var $i_0 = $45;
      var $caseExprOff_0 = $caseExprOff_1;
      __label__ = 9;
      break;
    }
   case 31:
    var $131 = HEAP32[$38 >> 2] + 1 | 0;
    HEAP32[$38 >> 2] = $131;
    var $i_0 = $45;
    var $caseExprOff_0 = $caseExprOff_1;
    __label__ = 9;
    break;
   case 32:
    if (($defaultOffset | 0) == ($switchLength | 0)) {
      __label__ = 33;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 33:
    var $134 = $5 + 48 | 0;
    var $136 = HEAP32[$134 >> 2] + 2 | 0;
    HEAP32[$134 >> 2] = $136;
    _js_printf($5, STRING_TABLE.__str1282801 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_default_str | 0, tempInt));
    var $138 = HEAP32[$134 >> 2] - 2 | 0;
    HEAP32[$134 >> 2] = $138;
    __label__ = 34;
    break;
   case 34:
    _js_printf($5, STRING_TABLE.__str462719 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    if ($6) {
      __label__ = 35;
      break;
    } else {
      var $_0 = 1;
      __label__ = 36;
      break;
    }
   case 35:
    var $141 = $ss + 28 | 0;
    var $143 = HEAP32[$141 >> 2] - 1 | 0;
    HEAP32[$141 >> 2] = $143;
    var $_0 = 1;
    __label__ = 36;
    break;
   case 36:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15DecompileSwitchP11SprintStackP10TableEntryjPhiii["X"] = 1;

function _JSVAL_TO_INT($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE2867($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_INT32_IMPL2866($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_IS_DOUBLE($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE2867($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_DOUBLE_IMPL2870($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_IS_STRING2868($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE2867($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_STRING_IMPL2869($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_DOUBLE($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE2867($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $tmp$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = (tempDoubleI32[0] = HEAP32[$_0 >> 2], tempDoubleI32[1] = $tmp$1, tempDoubleF64[0]);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSID_TO_STRING2878($iden) {
  return $iden;
}

function _JSID_IS_STRING2879($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function __ZNK13JSFunctionBox17scopeIsExtensibleEv($this_0_9_val) {
  return ($this_0_9_val & 536870912 | 0) != 0;
}

function __ZN2js6Parser13setPrincipalsEP12JSPrincipals($this, $prin) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($prin | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $prin + 12 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 3;
    break;
   case 3:
    HEAP32[$this + 956 >> 2] = $prin;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK13JSFunctionBox17inAnyDynamicScopeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $funbox_0 = $this;
    __label__ = 2;
    break;
   case 2:
    var $funbox_0;
    if (($funbox_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$funbox_0 + 60 >> 2] & 805306368 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $funbox_0 = HEAP32[$funbox_0 + 36 >> 2];
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK13JSFunctionBox13shouldUnbrandEjj($this, $slowMethods) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($slowMethods | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      var $funbox_0 = $this;
      __label__ = 2;
      break;
    }
   case 2:
    var $funbox_0;
    if (($funbox_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$funbox_0 + 60 >> 2] & 2097152 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP32[$funbox_0 + 56 >> 2] & 2 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 5:
    var $funbox_0 = HEAP32[$funbox_0 + 36 >> 2];
    __label__ = 2;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL25DecompileDestructuringLHSP11SprintStackPhS1_Pi($ss, $pc, $endpc, $hole) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $bytes = __stackBase__ + 4;
    HEAP32[$hole >> 2] = 0;
    var $1 = $ss | 0;
    var $3 = HEAP32[$ss >> 2];
    var $5 = HEAP32[$ss + 40 >> 2];
    var $6 = HEAPU8[$pc];
    var $7 = $6 & 255;
    var $10 = HEAP8[_js_CodeSpec + ($7 << 3) | 0] << 24 >> 24;
    if (($7 | 0) == 81) {
      __label__ = 2;
      break;
    } else if (($7 | 0) == 12) {
      __label__ = 3;
      break;
    } else if (($7 | 0) == 85 || ($7 | 0) == 87) {
      __label__ = 7;
      break;
    } else if (($7 | 0) == 132) {
      __label__ = 8;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 2:
    HEAP32[$hole >> 2] = 1;
    var $12 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($1, STRING_TABLE.__str296 | 0, 2);
    var $_03 = $pc;
    var $todo_1 = $12;
    var $oplen_0 = $10;
    __label__ = 28;
    break;
   case 3:
    var $14 = __ZL22DecompileDestructuringP11SprintStackPhS1_($ss, $pc, $endpc);
    if (($14 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($14 | 0) == ($endpc | 0)) {
      var $_1 = $14;
      __label__ = 30;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = HEAPU8[$14];
    var $22 = HEAP8[_js_CodeSpec + (($19 & 255) << 3) | 0];
    var $23 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $24 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($1, $23);
    if ($19 << 24 >> 24 == 11) {
      var $_1 = $14;
      __label__ = 30;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (HEAP8[$14] << 24 >> 24 == 81) {
      var $_03 = $14;
      var $todo_1 = $24;
      var $oplen_0 = $22 << 24 >> 24;
      __label__ = 28;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 7:
    var $32 = HEAP8[$pc + $10 | 0];
    if ($32 << 24 >> 24 == 81 || $32 << 24 >> 24 == 11) {
      __label__ = 8;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 8:
    var $36 = HEAPU8[$pc + 1 | 0];
    if ($6 << 24 >> 24 == 85) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $43 = ($36 & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255;
    var $44 = __ZL15GetArgOrVarAtomP9JSPrinterj($5, $43);
    if (($44 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      var $atom_0_ph = $44;
      __label__ = 13;
      break;
    }
   case 10:
    var $pc_idx1_val = HEAP8[$pc + 2 | 0];
    var $47 = __ZL9IsVarSlotP9JSPrinterPhPi($5, $36, $pc_idx1_val, $i);
    var $49 = HEAP32[$i >> 2];
    if (($47 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $51 = __ZL15GetArgOrVarAtomP9JSPrinterj($5, $49);
    if (($51 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      var $atom_0_ph = $51;
      __label__ = 13;
      break;
    }
   case 12:
    var $54 = __Z8GetLocalP11SprintStacki($ss, $49);
    __ZN16JSAutoByteStringC1Ev($bytes);
    var $lval_1 = $54;
    __label__ = 14;
    break;
   case 13:
    var $atom_0_ph;
    __ZN16JSAutoByteStringC1Ev($bytes);
    var $56 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($3, $atom_0_ph, $bytes);
    var $lval_1 = $56;
    __label__ = 14;
    break;
   case 14:
    var $lval_1;
    if (($lval_1 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $bytes_idx2_val = HEAP32[$bytes >> 2];
    __ZN16JSAutoByteStringD1Ev($bytes_idx2_val);
    var $_1 = 0;
    __label__ = 30;
    break;
   case 16:
    var $60 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($1, $lval_1);
    var $bytes_idx_val = HEAP32[$bytes >> 2];
    __ZN16JSAutoByteStringD1Ev($bytes_idx_val);
    if ($6 << 24 >> 24 == -124) {
      var $_03 = $pc;
      var $todo_1 = $60;
      var $oplen_0 = $10;
      __label__ = 28;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $63 = $pc + $10 | 0;
    if (($63 | 0) == ($endpc | 0)) {
      var $_1 = $63;
      __label__ = 30;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $66 = HEAPU8[$63];
    if ($66 << 24 >> 24 == 11) {
      var $_1 = $63;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    if ($66 << 24 >> 24 == 81) {
      var $_03 = $63;
      var $todo_1 = $60;
      var $oplen_0 = HEAP8[_js_CodeSpec + (($66 & 255) << 3) | 0] << 24 >> 24;
      __label__ = 28;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 20:
    var $75 = $ss + 16 | 0;
    var $76 = HEAPU32[$75 >> 2];
    HEAP32[$75 >> 2] = $76 + 3 | 0;
    var $78 = $ss + 28 | 0;
    var $80 = -HEAP32[$78 >> 2] | 0;
    var $81 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $pc, $80);
    if (($81 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    if (($81 | 0) == ($endpc | 0)) {
      var $_1 = $81;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $86 = HEAPU8[$81];
    var $90 = HEAP8[_js_CodeSpec + (($86 & 255) << 3) | 0] << 24 >> 24;
    if ($86 << 24 >> 24 == -47 || $86 << 24 >> 24 == 124) {
      __label__ = 23;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 23:
    var $92 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $93 = __ZL6PopStrP11SprintStack4JSOp($ss, 53);
    HEAP32[$75 >> 2] = $76;
    if (HEAP8[$93] << 24 >> 24 == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $97 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($1, $92);
    var $_03 = $81;
    var $todo_1 = $97;
    var $oplen_0 = $90;
    __label__ = 28;
    break;
   case 25:
    if (HEAP8[$92] << 24 >> 24 == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $102 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($1, $93);
    var $_03 = $81;
    var $todo_1 = $102;
    var $oplen_0 = $90;
    __label__ = 28;
    break;
   case 27:
    var $113 = ((HEAPU8[HEAP32[$ss + 24 >> 2] + (HEAP32[$78 >> 2] + 1) | 0] & 255) - 164 | 0) >>> 0 < 5 ? STRING_TABLE.__str1392812 | 0 : STRING_TABLE.__str1402813 | 0;
    var $114 = __ZN2js6SprintEPNS_8SprinterEPKcz($1, $113, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $93, HEAP32[tempInt + 4 >> 2] = $92, tempInt));
    var $_03 = $81;
    var $todo_1 = $114;
    var $oplen_0 = $90;
    __label__ = 28;
    break;
   case 28:
    var $oplen_0;
    var $todo_1;
    var $_03;
    if (($todo_1 | 0) > -1 & $_03 >>> 0 < $endpc >>> 0) {
      __label__ = 29;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 29:
    var $_1 = $_03 + $oplen_0 | 0;
    __label__ = 30;
    break;
   case 30:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL25DecompileDestructuringLHSP11SprintStackPhS1_Pi["X"] = 1;

function __ZN19AutoScriptUntrapperD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 12 >> 2];
    var $4 = HEAP32[$this + 8 >> 2];
    if (($2 | 0) == ($4 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $this + 4 | 0;
    var $12 = HEAP32[HEAP32[$9 >> 2] >> 2];
    var $14 = $12 + ($4 - $2) | 0;
    __ZN9JSContext5free_EPv($12);
    var $16 = HEAP32[$9 >> 2] | 0;
    HEAP32[$16 >> 2] = $14;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN19AutoScriptUntrapperC2EP9JSContextP8JSScriptPPh($this, $cx, $script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this >> 2] = $cx;
    HEAP32[$this + 4 >> 2] = $script;
    var $3 = $this + 8 | 0;
    var $4 = HEAP32[$pc >> 2];
    HEAP32[$3 >> 2] = $4;
    var $5 = $cx;
    var $6 = $script;
    var $7 = _js_UntrapScriptCode($5, $6);
    var $8 = $script | 0;
    var $9 = HEAP32[$8 >> 2];
    var $11 = HEAP32[$3 >> 2];
    if (($7 | 0) == ($9 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$this + 12 >> 2] = $11;
    __label__ = 4;
    break;
   case 3:
    var $18 = $11 + ($7 - $9) | 0;
    HEAP32[$this + 12 >> 2] = $18;
    HEAP32[$pc >> 2] = $18;
    HEAP32[$8 >> 2] = $7;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11JSParseNode6becomeEPS_($this, $pn2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode6isUsedEv($pn2);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $22 = HEAP32[$pn2 >> 2];
    var $_pre_phi = $this;
    __label__ = 6;
    break;
   case 3:
    var $5 = HEAP32[$pn2 + 36 >> 2] + 28 | 0;
    var $6 = HEAP32[$5 >> 2];
    if (($6 | 0) == ($pn2 | 0)) {
      var $pnup_0_lcssa = $5;
      __label__ = 5;
      break;
    } else {
      var $8 = $6;
      __label__ = 4;
      break;
    }
   case 4:
    var $8;
    var $9 = $8 + 28 | 0;
    var $10 = HEAP32[$9 >> 2];
    if (($10 | 0) == ($pn2 | 0)) {
      var $pnup_0_lcssa = $9;
      __label__ = 5;
      break;
    } else {
      var $8 = $10;
      __label__ = 4;
      break;
    }
   case 5:
    var $pnup_0_lcssa;
    HEAP32[$pnup_0_lcssa >> 2] = $this;
    var $12 = $pn2 + 28 | 0;
    var $13 = HEAP32[$12 >> 2];
    HEAP32[$this + 28 >> 2] = $13;
    var $15 = $this;
    var $17 = HEAP32[$15 >> 2] | 1073741824;
    HEAP32[$15 >> 2] = $17;
    HEAP32[$12 >> 2] = 0;
    var $18 = $pn2;
    var $20 = HEAP32[$18 >> 2] & -1073741825;
    HEAP32[$18 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $15;
    __label__ = 6;
    break;
   case 6:
    var $_pre_phi;
    var $22;
    var $23 = $pn2;
    var $27 = HEAP32[$_pre_phi >> 2] & -65536 | $22 & 65535;
    HEAP32[$_pre_phi >> 2] = $27;
    var $31 = $27 & -16711681 | HEAP32[$23 >> 2] & 16711680;
    HEAP32[$_pre_phi >> 2] = $31;
    var $33 = HEAP32[$23 >> 2] & 520093696;
    var $35 = $31 & -520093697 | $33;
    HEAP32[$_pre_phi >> 2] = $35;
    var $39 = $35 & -536870913 | HEAP32[$23 >> 2] & 536870912;
    HEAP32[$_pre_phi >> 2] = $39;
    var $40 = $this + 32 | 0;
    var $42 = $40;
    var $43 = $pn2 + 32 | 0;
    HEAP32[$42 >> 2] = HEAP32[$43 >> 2];
    HEAP32[$42 + 4 >> 2] = HEAP32[$43 + 4 >> 2];
    HEAP32[$42 + 8 >> 2] = HEAP32[$43 + 8 >> 2];
    HEAP32[$42 + 12 >> 2] = HEAP32[$43 + 12 >> 2];
    var $44 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($this, 34);
    if ($44) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $46 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($this, 4);
    if ($46) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $50 = HEAP32[$40 >> 2] + 24 | 0;
    HEAP32[$50 >> 2] = $this;
    __label__ = 12;
    break;
   case 9:
    if (($33 | 0) == 83886080) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $54 = $40 | 0;
    if ((HEAP32[$54 >> 2] | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$this + 36 >> 2] = $54;
    __label__ = 12;
    break;
   case 12:
    __ZN11JSParseNode5clearEv($pn2);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN11JSParseNode6becomeEPS_["X"] = 1;

function __ZN11JSParseNode5clearEv($this) {
  var $1 = $this;
  var $3 = HEAP32[$1 >> 2] & -65536;
  HEAP32[$1 >> 2] = $3;
  __ZN11JSParseNode5setOpE4JSOp($this, 0);
  var $5 = HEAP32[$1 >> 2] & 16777215;
  HEAP32[$1 >> 2] = $5;
  return;
}

function __ZN2js6ParserC2EP9JSContextP12JSPrincipalsPNS_10StackFrameEb($this, $cx, $prin, $cfp, $foldConstants) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    __ZN2js12AutoGCRooterC2EP9JSContexti($1, $cx, -3);
    HEAP32[$this + 12 >> 2] = $cx;
    var $3 = $this + 40 | 0;
    __ZN2js11TokenStreamC2EP9JSContext($3, $cx);
    HEAP32[$this + 956 >> 2] = 0;
    HEAP32[$this + 960 >> 2] = $cfp;
    var $6 = $this + 964 | 0;
    if (($cfp | 0) == 0) {
      var $11 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js10StackFrame6varObjEv($cfp);
    var $11 = $9;
    __label__ = 3;
    break;
   case 3:
    var $11;
    HEAP32[$6 >> 2] = $11;
    HEAP32[$this + 968 >> 2] = 0;
    HEAP32[$this + 972 >> 2] = 0;
    HEAP32[$this + 976 >> 2] = 0;
    HEAP32[$this + 980 >> 2] = 0;
    var $16 = $this + 984 | 0;
    var $18 = HEAP32[$cx + 52 >> 2];
    __ZN2js13AutoKeepAtomsC1EP9JSRuntime($16, $18);
    HEAP8[$this + 988 | 0] = $foldConstants & 1;
    var $21 = $cx + 308 | 0;
    var $23 = HEAP32[$21 >> 2] + 1 | 0;
    HEAP32[$21 >> 2] = $23;
    var $24 = $this + 16 | 0;
    __ZN2jsL12PodArrayZeroIPvLj6EEEvRAT0__T_($24);
    __ZN2js6Parser13setPrincipalsEP12JSPrincipals($this, $prin);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL12PodArrayZeroIPvLj6EEEvRAT0__T_($t) {
  var $1 = $t;
  _memset($1, 0, 24, 1);
  return;
}

function __ZN2js6Parser4initEPKtjPKcj9JSVersion($this, $base, $length, $filename, $lineno, $version) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 12 >> 2];
    var $3 = __ZN9JSContext18ensureParseMapPoolEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = HEAP32[HEAP32[$2 + 88 >> 2] + 12 >> 2];
    HEAP32[$this + 952 >> 2] = $9;
    var $11 = $this + 40 | 0;
    __ZN2js11TokenStream4initEPKtjPKcj9JSVersion($11, $base, $length, $filename, $lineno, $version);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext18ensureParseMapPoolEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 100 | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZN2js11OffTheBooks4new_INS_12ParseMapPoolEP9JSContextEEPT_T0_($this);
    HEAP32[$1 >> 2] = $5;
    var $_0 = ($5 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6ParserD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 12 >> 2];
    var $3 = $this + 956 | 0;
    var $4 = HEAP32[$3 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4 + 12 | 0;
    var $9 = HEAP32[$7 >> 2] - 1 | 0;
    HEAP32[$7 >> 2] = $9;
    var $11 = HEAP32[$3 >> 2];
    if (($9 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $14 = HEAP32[$11 + 16 >> 2];
    FUNCTION_TABLE[$14]($2, $11);
    __label__ = 4;
    break;
   case 4:
    var $17 = HEAPU32[$this + 952 >> 2];
    var $18 = $2 + 72 | 0;
    var $20 = HEAP32[$2 + 88 >> 2];
    if (($20 | 0) == ($18 | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = $17;
    var $26 = HEAP32[$20 + 4 >> 2];
    var $28 = $20 + 12 | 0;
    if (($24 - $26 | 0) >>> 0 > (HEAP32[$28 >> 2] - $26 | 0) >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $34 = HEAP32[$2 + 96 >> 2];
    var $37 = $34 + $24 & ($34 ^ -1);
    HEAP32[$28 >> 2] = $37;
    __label__ = 8;
    break;
   case 7:
    _JS_ArenaRelease($18, $17);
    __label__ = 8;
    break;
   case 8:
    var $40 = $2 + 308 | 0;
    var $42 = HEAP32[$40 >> 2] - 1 | 0;
    HEAP32[$40 >> 2] = $42;
    var $_idx_val = HEAP32[$this + 984 >> 2];
    __ZN2js13AutoKeepAtomsD1Ev($_idx_val);
    var $43 = $this + 40 | 0;
    __ZN2js11TokenStreamD2Ev($43);
    var $_idx1_val = HEAP32[$this >> 2];
    var $_idx2_val = HEAP32[$this + 8 >> 2];
    __ZN2js12AutoGCRooterD2Ev($_idx1_val, $_idx2_val);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6ParserD2Ev["X"] = 1;

function __ZN2js6Parser12newObjectBoxEP8JSObject($this, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $4 = HEAP32[$2 + 88 >> 2];
    var $6 = HEAP32[$2 + 96 >> 2];
    var $9 = $6 + 24 & ($6 ^ -1);
    var $10 = $4 + 12 | 0;
    var $11 = HEAPU32[$10 >> 2];
    if ($11 >>> 0 > (HEAP32[$4 + 8 >> 2] - $9 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = $2 + 72 | 0;
    var $18 = _JS_ArenaAllocate($17, $9);
    var $_p_0 = $18;
    __label__ = 4;
    break;
   case 3:
    var $21 = $9 + $11 | 0;
    HEAP32[$10 >> 2] = $21;
    var $_p_0 = $11;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    var $23 = $_p_0;
    if (($_p_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $26 = HEAP32[$1 >> 2];
    __Z20js_ReportOutOfMemoryP9JSContext($26);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $28 = $this + 976 | 0;
    var $29 = HEAP32[$28 >> 2];
    HEAP32[$23 >> 2] = $29;
    HEAP32[$28 >> 2] = $23;
    HEAP32[$23 + 4 >> 2] = 0;
    HEAP32[$23 + 8 >> 2] = $obj;
    HEAP8[$23 + 20 | 0] = 0;
    var $_0 = $23;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser14newFunctionBoxEP8JSObjectP11JSParseNodeP13JSTreeContext($this, $obj, $fn, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $4 = HEAP32[$2 + 88 >> 2];
    var $6 = HEAP32[$2 + 96 >> 2];
    var $9 = $6 + 64 & ($6 ^ -1);
    var $10 = $4 + 12 | 0;
    var $11 = HEAPU32[$10 >> 2];
    if ($11 >>> 0 > (HEAP32[$4 + 8 >> 2] - $9 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = $2 + 72 | 0;
    var $18 = _JS_ArenaAllocate($17, $9);
    var $_p_0 = $18;
    __label__ = 4;
    break;
   case 3:
    var $21 = $9 + $11 | 0;
    HEAP32[$10 >> 2] = $21;
    var $_p_0 = $11;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    var $23 = $_p_0;
    if (($_p_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $26 = HEAP32[$1 >> 2];
    __Z20js_ReportOutOfMemoryP9JSContext($26);
    var $_0 = 0;
    __label__ = 15;
    break;
   case 6:
    var $28 = $this + 976 | 0;
    var $29 = HEAP32[$28 >> 2];
    HEAP32[$23 >> 2] = $29;
    HEAP32[$28 >> 2] = $23 | 0;
    HEAP32[$23 + 4 >> 2] = 0;
    HEAP32[$23 + 8 >> 2] = $obj;
    HEAP8[$23 + 20 | 0] = 1;
    HEAP32[$23 + 24 >> 2] = $fn;
    var $36 = $tc + 84 | 0;
    var $37 = HEAP32[$36 >> 2];
    HEAP32[$23 + 28 >> 2] = $37;
    HEAP32[$36 >> 2] = $23;
    var $41 = HEAP32[$tc + 48 >> 2] + 972 | 0;
    var $43 = HEAP32[$41 >> 2] + 1 | 0;
    HEAP32[$41 >> 2] = $43;
    HEAP32[$23 + 32 >> 2] = 0;
    var $46 = HEAP32[$tc + 80 >> 2];
    HEAP32[$23 + 36 >> 2] = $46;
    HEAP32[$23 + 40 >> 2] = 0;
    var $49 = $23 + 44 | 0;
    if (($49 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2js8BindingsC1EP9JSContext($49);
    __label__ = 8;
    break;
   case 8:
    var $55 = $_p_0 + 56 | 0;
    var $57 = HEAP32[$55 >> 2] & -4;
    HEAP32[$55 >> 2] = $57;
    var $stmt_0_in = $tc + 24 | 0;
    __label__ = 9;
    break;
   case 9:
    var $stmt_0_in;
    var $stmt_0 = HEAPU32[$stmt_0_in >> 2];
    if (($stmt_0 | 0) == 0) {
      var $69 = $57;
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ((HEAPU16[$stmt_0 >> 1] & 65535) > 10) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $66 = $57 | 2;
    HEAP32[$55 >> 2] = $66;
    var $69 = $66;
    __label__ = 13;
    break;
   case 12:
    var $stmt_0_in = $stmt_0 + 24 | 0;
    __label__ = 9;
    break;
   case 13:
    var $69;
    var $75 = $69 & -65533 | HEAP32[$tc + 76 >> 2] << 2 & 65532;
    HEAP32[$55 >> 2] = $75;
    var $78 = HEAP32[$tc >> 2] & 270336;
    var $79 = $78 | 2;
    var $80 = $23 + 60 | 0;
    HEAP32[$80 >> 2] = $79;
    if ((HEAP32[$tc + 88 >> 2] | 0) == 0) {
      var $_0 = $23;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $85 = $78 | 268435458;
    HEAP32[$80 >> 2] = $85;
    var $_0 = $23;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser14newFunctionBoxEP8JSObjectP11JSParseNodeP13JSTreeContext["X"] = 1;

function __ZNK13JSFunctionBox8joinableEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 8 >> 2];
    var $1 = __ZNK13JSFunctionBox8functionEv($this_idx_val);
    var $_idx_val = HEAP16[$1 + 58 >> 1];
    var $2 = __ZNK10JSFunction13isNullClosureEv($_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $9 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = (HEAP32[$this + 60 >> 2] & 9344 | 0) == 8192;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser5traceEP8JSTracer($this, $trc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $objbox_03 = HEAP32[$this + 976 >> 2];
    if (($objbox_03 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $trc;
    var $objbox_04 = $objbox_03;
    __label__ = 3;
    break;
   case 3:
    var $objbox_04;
    var $6 = HEAP32[$objbox_04 + 8 >> 2];
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $6);
    if ((HEAP8[$objbox_04 + 20 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$objbox_04 + 44 >> 2];
    __ZN2js8Bindings5traceEP8JSTracer($_idx_val, $3);
    __label__ = 5;
    break;
   case 5:
    var $objbox_0 = HEAP32[$objbox_04 >> 2];
    if (($objbox_0 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $objbox_04 = $objbox_0;
      __label__ = 3;
      break;
    }
   case 6:
    var $tc_01 = HEAP32[$this + 980 >> 2];
    if (($tc_01 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $tc_02 = $tc_01;
      __label__ = 7;
      break;
    }
   case 7:
    var $tc_02;
    __ZN13JSTreeContext5traceEP8JSTracer($tc_02, $trc);
    var $tc_0 = HEAP32[$tc_02 + 72 >> 2];
    if (($tc_0 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $tc_02 = $tc_0;
      __label__ = 7;
      break;
    }
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser17cleanFunctionListEPP13JSFunctionBox($this, $funboxHead) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $link_0_ph = $funboxHead;
    __label__ = 2;
    break;
   case 2:
    var $link_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $1 = HEAP32[$link_0_ph >> 2];
    __label__ = 4;
    break;
   case 4:
    var $1;
    if (($1 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $4 = $1 + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $9 = HEAP32[$1 + 28 >> 2];
    HEAP32[$link_0_ph >> 2] = $9;
    var $1 = $9;
    __label__ = 4;
    break;
   case 7:
    if ((HEAP32[$5 + 32 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $17 = HEAP32[$1 + 28 >> 2];
    HEAP32[$link_0_ph >> 2] = $17;
    var $18 = HEAP32[$4 >> 2];
    __ZL17AddNodeToFreeListP11JSParseNodePN2js6ParserE($18, $this);
    __label__ = 3;
    break;
   case 9:
    var $methodLink_0_ph = $1 + 40 | 0;
    __label__ = 10;
    break;
   case 10:
    var $methodLink_0_ph;
    var $22 = HEAP32[$methodLink_0_ph >> 2];
    __label__ = 11;
    break;
   case 11:
    var $22;
    if (($22 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $29 = $22 + 28 | 0;
    if ((HEAP32[$22 + 32 >> 2] | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $methodLink_0_ph = $29;
      __label__ = 10;
      break;
    }
   case 13:
    var $31 = HEAP32[$29 >> 2];
    HEAP32[$methodLink_0_ph >> 2] = $31;
    var $22 = $31;
    __label__ = 11;
    break;
   case 14:
    __ZN2js6Parser17cleanFunctionListEPP13JSFunctionBox($this, $1 + 32 | 0);
    var $link_0_ph = $1 + 28 | 0;
    __label__ = 2;
    break;
   case 15:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11JSParseNode8initListEPS_($this, $pn) {
  HEAP32[$this + 32 >> 2] = $pn;
  HEAP32[$this + 36 >> 2] = $pn + 24 | 0;
  HEAP32[$this + 40 >> 2] = 1;
  HEAP32[$this + 44 >> 2] = 0;
  return;
}

function __ZN11JSParseNode6appendEPS_($this, $pn) {
  var $1 = $this + 36 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$2 >> 2] = $pn;
  HEAP32[$1 >> 2] = $pn + 24 | 0;
  var $4 = $this + 40 | 0;
  var $6 = HEAP32[$4 >> 2] + 1 | 0;
  HEAP32[$4 >> 2] = $6;
  return;
}

function __ZN13JSTreeContext13setScopeChainEP8JSObject($this, $scopeChain) {
  HEAP32[$this + 60 >> 2] = $scopeChain;
  return;
}

function __ZL17AddNodeToFreeListP11JSParseNodePN2js6ParserE($pn, $parser) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 7);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $pn + 32 | 0;
    var $_idx_val = HEAP32[$3 >> 2];
    var $4 = __ZNK2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE6hasMapEv($_idx_val);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = $3;
    var $8 = HEAP32[$parser + 12 >> 2];
    __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE10releaseMapEP9JSContext($6, $8);
    __label__ = 4;
    break;
   case 4:
    var $10 = $parser + 968 | 0;
    var $11 = HEAP32[$10 >> 2];
    HEAP32[$pn + 24 >> 2] = $11;
    HEAP32[$10 >> 2] = $pn;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11JSParseNode6createE16JSParseNodeArityP13JSTreeContext($arity, $tc_0_11_val) {
  var $1 = $tc_0_11_val + 40 | 0;
  var $2 = __ZNK2js11TokenStream12currentTokenEv($1);
  var $4 = HEAP32[$2 >> 2];
  var $5 = $2 + 4 | 0;
  var $6 = __ZN11JSParseNode6createE16JSParseNodeArityN2js9TokenKindE4JSOpRKNS1_8TokenPosEP13JSTreeContext($arity, $4, 0, $5, $tc_0_11_val);
  return $6;
}

function __ZN11JSParseNode6createE16JSParseNodeArityN2js9TokenKindE4JSOpRKNS1_8TokenPosEP13JSTreeContext($arity, $type, $op, $pos, $tc_0_11_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL17NewOrRecycledNodeP13JSTreeContext($tc_0_11_val);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN11JSParseNode4initEN2js9TokenKindE4JSOp16JSParseNodeArity($1, $type, $op, $arity);
    var $5 = $1 + 4 | 0;
    var $6 = $pos;
    HEAP32[$5 >> 2] = HEAP32[$6 >> 2];
    HEAP32[$5 + 4 >> 2] = HEAP32[$6 + 4 >> 2];
    HEAP32[$5 + 8 >> 2] = HEAP32[$6 + 8 >> 2];
    HEAP32[$5 + 12 >> 2] = HEAP32[$6 + 12 >> 2];
    var $_0 = $1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17NewOrRecycledNodeP13JSTreeContext($tc_0_11_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $tc_0_11_val + 968 | 0;
    var $2 = HEAPU32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $6 = HEAPU32[$tc_0_11_val + 12 >> 2];
    var $8 = HEAP32[$6 + 88 >> 2];
    var $10 = HEAP32[$6 + 96 >> 2];
    var $13 = $10 + 48 & ($10 ^ -1);
    var $14 = $8 + 12 | 0;
    var $15 = HEAPU32[$14 >> 2];
    if ($15 >>> 0 > (HEAP32[$8 + 8 >> 2] - $13 | 0) >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $21 = $6 + 72 | 0;
    var $22 = _JS_ArenaAllocate($21, $13);
    var $_p_0 = $22;
    __label__ = 5;
    break;
   case 4:
    var $25 = $13 + $15 | 0;
    HEAP32[$14 >> 2] = $25;
    var $_p_0 = $15;
    __label__ = 5;
    break;
   case 5:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $pn_01 = $_p_0;
      __label__ = 8;
      break;
    }
   case 6:
    __Z20js_ReportOutOfMemoryP9JSContext($6);
    var $pn_02 = 0;
    __label__ = 9;
    break;
   case 7:
    var $30 = HEAP32[$2 + 24 >> 2];
    HEAP32[$1 >> 2] = $30;
    var $pn_01 = $2;
    __label__ = 8;
    break;
   case 8:
    var $pn_01;
    __ZN11JSParseNode7setUsedEb($pn_01, 0);
    __ZN11JSParseNode7setDefnEb($pn_01, 0);
    var $33 = $pn_01 + 32 | 0;
    for (var $$dest = $33, $$stop = $$dest + 16; $$dest < $$stop; $$dest++) {
      HEAP8[$$dest] = 0;
    }
    HEAP32[$pn_01 + 24 >> 2] = 0;
    var $pn_02 = $pn_01;
    __label__ = 9;
    break;
   case 9:
    var $pn_02;
    return $pn_02;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11JSParseNode4initEN2js9TokenKindE4JSOp16JSParseNodeArity($this, $type, $op, $arity) {
  var $2 = $this;
  var $11 = $op << 16 & 16711680 | $type & 65535 | $arity << 24 & 520093696 | HEAP32[$2 >> 2] & -1073741824;
  HEAP32[$2 >> 2] = $11;
  var $13 = $this + 32 | 0;
  __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE4initEv($13);
  HEAP32[$this + 28 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  return;
}

function __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext($tt, $op, $left, $right, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($left | 0) == 0 | ($right | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($left, $tt);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 3:
    var $6 = __ZNK11JSParseNode4isOpE4JSOp($left, $op);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 4:
    if ((HEAP32[_js_CodeSpec + ($op << 3) + 4 >> 2] & 65536 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = $left;
    if ((HEAP32[$13 >> 2] & 520093696 | 0) == 83886080) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $_pre_phi = ($tt | 0) == 15;
    __label__ = 16;
    break;
   case 7:
    var $19 = HEAP32[$left + 32 >> 2];
    var $22 = HEAP32[$left + 36 >> 2];
    __ZN11JSParseNode8setArityE16JSParseNodeArity($left, 5);
    var $24 = HEAP32[$13 >> 2] & -536870913;
    HEAP32[$13 >> 2] = $24;
    __ZN11JSParseNode8initListEPS_($left, $19);
    __ZN11JSParseNode6appendEPS_($left, $22);
    var $25 = ($tt | 0) == 15;
    if ($25) {
      __label__ = 8;
      break;
    } else {
      var $_pre_phi = $25;
      __label__ = 16;
      break;
    }
   case 8:
    var $27 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($19, 31);
    if ($27) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $30 = $left + 44 | 0;
    var $32 = HEAP32[$30 >> 2] | 1;
    HEAP32[$30 >> 2] = $32;
    __label__ = 12;
    break;
   case 10:
    var $34 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($19, 30);
    if ($34) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $37 = $left + 44 | 0;
    var $39 = HEAP32[$37 >> 2] | 2;
    HEAP32[$37 >> 2] = $39;
    __label__ = 12;
    break;
   case 12:
    var $41 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($22, 31);
    if ($41) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $43 = $left + 44 | 0;
    var $45 = HEAP32[$43 >> 2] | 1;
    HEAP32[$43 >> 2] = $45;
    __ZN11JSParseNode6appendEPS_($left, $right);
    var $48 = $right + 12 | 0;
    var $49 = $left + 12 | 0;
    var $st$10$0 = $48 | 0;
    var $50$0 = HEAP32[$st$10$0 >> 2];
    var $st$10$1 = $48 + 4 | 0;
    var $50$1 = HEAP32[$st$10$1 >> 2];
    var $st$14$0 = $49 | 0;
    HEAP32[$st$14$0 >> 2] = $50$0;
    var $st$14$1 = $49 + 4 | 0;
    HEAP32[$st$14$1 >> 2] = $50$1;
    __label__ = 18;
    break;
   case 14:
    var $52 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($22, 30);
    if ($52) {
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $54 = $left + 44 | 0;
    var $56 = HEAP32[$54 >> 2] | 2;
    HEAP32[$54 >> 2] = $56;
    __ZN11JSParseNode6appendEPS_($left, $right);
    var $59 = $right + 12 | 0;
    var $60 = $left + 12 | 0;
    var $st$10$0 = $59 | 0;
    var $61$0 = HEAP32[$st$10$0 >> 2];
    var $st$10$1 = $59 + 4 | 0;
    var $61$1 = HEAP32[$st$10$1 >> 2];
    var $st$14$0 = $60 | 0;
    HEAP32[$st$14$0 >> 2] = $61$0;
    var $st$14$1 = $60 + 4 | 0;
    HEAP32[$st$14$1 >> 2] = $61$1;
    __label__ = 18;
    break;
   case 16:
    var $_pre_phi;
    __ZN11JSParseNode6appendEPS_($left, $right);
    var $65 = $right + 12 | 0;
    var $66 = $left + 12 | 0;
    var $67$0 = HEAP32[$65 >> 2];
    var $67$1 = HEAP32[$65 + 4 >> 2];
    var $st$10$0 = $66 | 0;
    HEAP32[$st$10$0 >> 2] = $67$0;
    var $st$10$1 = $66 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $67$1;
    if ($_pre_phi) {
      __label__ = 18;
      break;
    } else {
      var $_0 = $left;
      __label__ = 29;
      break;
    }
   case 17:
    __ZN11JSParseNode6appendEPS_($left, $right);
    var $70 = $right + 12 | 0;
    var $71 = $left + 12 | 0;
    var $st$5$0 = $70 | 0;
    var $72$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $70 + 4 | 0;
    var $72$1 = HEAP32[$st$5$1 >> 2];
    var $st$9$0 = $71 | 0;
    HEAP32[$st$9$0 >> 2] = $72$0;
    var $st$9$1 = $71 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $72$1;
    __label__ = 18;
    break;
   case 18:
    var $74 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($right, 31);
    if ($74) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $77 = $left + 44 | 0;
    var $79 = HEAP32[$77 >> 2] | 1;
    HEAP32[$77 >> 2] = $79;
    var $_0 = $left;
    __label__ = 29;
    break;
   case 20:
    var $81 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($right, 30);
    if ($81) {
      var $_0 = $left;
      __label__ = 29;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $84 = $left + 44 | 0;
    var $86 = HEAP32[$84 >> 2] | 2;
    HEAP32[$84 >> 2] = $86;
    var $_0 = $left;
    __label__ = 29;
    break;
   case 22:
    if (($tt | 0) == 15) {
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 23:
    var $90 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($left, 30);
    if ($90) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $92 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($right, 30);
    if ($92) {
      __label__ = 25;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 25:
    if ((HEAP8[HEAP32[$tc + 48 >> 2] + 988 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $102 = $right + 32 | 0;
    var $103 = (tempDoubleI32[0] = HEAP32[$102 >> 2], tempDoubleI32[1] = HEAP32[$102 + 4 >> 2], tempDoubleF64[0]);
    var $105 = $left + 32 | 0;
    var $106 = (tempDoubleI32[0] = HEAP32[$105 >> 2], tempDoubleI32[1] = HEAP32[$105 + 4 >> 2], tempDoubleF64[0]);
    var $107 = $106 + $103;
    tempDoubleF64[0] = $107, HEAP32[$105 >> 2] = tempDoubleI32[0], HEAP32[$105 + 4 >> 2] = tempDoubleI32[1];
    var $110 = $right + 12 | 0;
    var $111 = $left + 12 | 0;
    var $112$0 = HEAP32[$110 >> 2];
    var $112$1 = HEAP32[$110 + 4 >> 2];
    HEAP32[$111 >> 2] = $112$0;
    HEAP32[$111 + 4 >> 2] = $112$1;
    var $113 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($right, $tc);
    var $_0 = $left;
    __label__ = 29;
    break;
   case 27:
    var $tc_idx_val = HEAP32[$tc + 48 >> 2];
    var $114 = __ZL17NewOrRecycledNodeP13JSTreeContext($tc_idx_val);
    if (($114 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    __ZN11JSParseNode4initEN2js9TokenKindE4JSOp16JSParseNodeArity($114, $tt, $op, 2);
    var $119 = $left + 4 | 0;
    var $120 = $114 + 4 | 0;
    var $st$5$0 = $119 | 0;
    var $121$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $119 + 4 | 0;
    var $121$1 = HEAP32[$st$5$1 >> 2];
    var $st$9$0 = $120 | 0;
    HEAP32[$st$9$0 >> 2] = $121$0;
    var $st$9$1 = $120 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $121$1;
    var $124 = $right + 12 | 0;
    var $125 = $114 + 12 | 0;
    var $126$0 = HEAP32[$124 >> 2];
    var $126$1 = HEAP32[$124 + 4 >> 2];
    var $st$21$0 = $125 | 0;
    HEAP32[$st$21$0 >> 2] = $126$0;
    var $st$21$1 = $125 + 4 | 0;
    HEAP32[$st$21$1 >> 2] = $126$1;
    var $127 = $114 + 32 | 0;
    HEAP32[$127 >> 2] = $left;
    var $128 = $114 + 36 | 0;
    HEAP32[$128 >> 2] = $right;
    var $_0 = $114;
    __label__ = 29;
    break;
   case 29:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext["X"] = 1;

function __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn, $tc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stack = __stackBase__;
    if (($pn | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$pn + 24 >> 2];
    __ZN2js9NodeStackC1Ev($stack);
    var $tc_idx = $tc + 48 | 0;
    var $stack_idx = $stack | 0;
    var $_01 = $pn;
    __label__ = 3;
    break;
   case 3:
    var $_01;
    var $6 = __ZL16PushNodeChildrenP11JSParseNodePN2js9NodeStackE($_01, $stack);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $tc_idx_val = HEAP32[$tc_idx >> 2];
    __ZL17AddNodeToFreeListP11JSParseNodeP13JSTreeContext($_01, $tc_idx_val);
    __label__ = 5;
    break;
   case 5:
    var $stack_idx_val = HEAP32[$stack_idx >> 2];
    var $9 = __ZN2js9NodeStack5emptyEv($stack_idx_val);
    if ($9) {
      var $_0 = $4;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $11 = __ZN2js9NodeStack3popEv($stack);
    var $_01 = $11;
    __label__ = 3;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8NameNode6createEP6JSAtomP13JSTreeContext($atom, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tc_idx_val = HEAP32[$tc + 48 >> 2];
    var $1 = __ZN11JSParseNode6createE16JSParseNodeArityP13JSTreeContext(6, $tc_idx_val);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_pre_phi = $1;
    __label__ = 4;
    break;
   case 3:
    var $4 = $1 + 32 | 0;
    HEAP32[$4 >> 2] = $atom;
    var $5 = $1;
    __ZN2js8NameNode10initCommonEP13JSTreeContext($5, $tc);
    var $_pre_phi = $5;
    __label__ = 4;
    break;
   case 4:
    var $_pre_phi;
    return $_pre_phi;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8NameNode10initCommonEP13JSTreeContext($this, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this + 36 >> 2] = 0;
    var $3 = $this + 40 | 0;
    __ZN2js11UpvarCookie8makeFreeEv($3);
    var $5 = HEAP32[$tc + 24 >> 2];
    if (($5 | 0) == 0) {
      var $12 = 32;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $phitmp = HEAP16[$5 >> 1] << 16 >> 16 == 4 ? 32 : 0;
    var $12 = $phitmp;
    __label__ = 3;
    break;
   case 3:
    var $12;
    var $14 = $this + 44 | 0;
    var $17 = HEAP32[$14 >> 2] & -4096 | $12;
    HEAP32[$14 >> 2] = $17;
    var $18 = $tc;
    var $19 = __ZN13JSTreeContext7blockidEv($18);
    HEAP32[$14 >> 2] = $19 << 12 | $12;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser5parseEP8JSObject($this, $chain) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 108;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $globaltc = __stackBase__;
    __ZN13JSTreeContextC1EPN2js6ParserE($globaltc, $this);
    var $1 = $this + 12 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $globaltc;
    var $4 = __ZN13JSTreeContext4initEP9JSContextNS_12InitBehaviorE($3, $2, 0);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    __ZN13JSTreeContext13setScopeChainEP8JSObject($globaltc, $chain);
    var $6 = $globaltc + 4 | 0;
    var $7 = __ZL15GenerateBlockIdP13JSTreeContextRj($globaltc, $6);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 3:
    var $9 = __ZN2js6Parser10statementsEv($this);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $this + 40 | 0;
    var $13 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($12, 0);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 133, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 6:
    if ((HEAP8[$this + 988 | 0] & 1) << 24 >> 24 == 0) {
      var $_0 = $9;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = HEAP32[$1 >> 2];
    var $23 = _js_FoldConstants($22, $9, $globaltc, 0);
    if (($23 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $_0 = $9;
      __label__ = 9;
      break;
    }
   case 8:
    var $_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    __ZN13JSTreeContextD1Ev($globaltc);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSTreeContextC1EPN2js6ParserE($this, $prs) {
  var $1 = $this;
  var $2 = $prs;
  __ZN13JSTreeContextC2EPN2js6ParserE($1, $2);
  return;
}

function __ZL15GenerateBlockIdP13JSTreeContextRj($tc, $blockid) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $tc + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 1048576) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = HEAP32[HEAP32[$tc + 48 >> 2] + 12 >> 2];
    _JS_ReportErrorNumber($8, 4, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str1073259 | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $10 = $2 + 1 | 0;
    HEAP32[$1 >> 2] = $10;
    HEAP32[$blockid >> 2] = $2;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser10statementsEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $inDirectivePrologue = __stackBase__ + 4;
    var $3 = HEAPU32[$this + 12 >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$3 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($3);
    var $_0 = 0;
    __label__ = 20;
    break;
   case 3:
    var $9 = $this + 980 | 0;
    var $_idx2_val = HEAP32[HEAP32[$9 >> 2] + 48 >> 2];
    var $11 = __ZN2js8ListNode6createEP13JSTreeContext($_idx2_val);
    var $12 = $11 | 0;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($12, 25);
    __ZN11JSParseNode9makeEmptyEv($12);
    var $16 = HEAP32[$9 >> 2];
    var $17 = __ZN13JSTreeContext7blockidEv($16);
    var $19 = $11 + 44 | 0;
    var $23 = HEAP32[$19 >> 2] & 4095 | $17 << 12;
    HEAP32[$19 >> 2] = $23;
    var $25 = HEAP32[$9 >> 2] + 36 | 0;
    var $26 = HEAP32[$25 >> 2];
    HEAP32[$25 >> 2] = $12;
    var $_idx1_val = HEAP32[HEAP32[$9 >> 2] + 24 >> 2];
    var $28 = __ZN13JSTreeContext11atBodyLevelEv($_idx1_val);
    HEAP8[$inDirectivePrologue] = $28 & 1;
    var $30 = $this + 40 | 0;
    __ZN2js11TokenStream23setOctalCharacterEscapeEb($30, 0);
    __label__ = 5;
    break;
   case 5:
    var $32 = __ZN2js11TokenStream9peekTokenEj($30, 8);
    if (($32 | 0) < 1 | ($32 | 0) == 26) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    if (($32 | 0) == -1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 7:
    var $_idx4_val = HEAP32[$this + 184 >> 2];
    var $38 = __ZNK2js11TokenStream5isEOFEv($_idx4_val);
    if ($38) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 20;
      break;
    }
   case 8:
    __ZN2js11TokenStream16setUnexpectedEOFEb($30);
    var $_0 = 0;
    __label__ = 20;
    break;
   case 9:
    var $41 = __ZN2js6Parser9statementEv($this);
    if (($41 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $_idx3_val = HEAP32[$this + 184 >> 2];
    var $44 = __ZNK2js11TokenStream5isEOFEv($_idx3_val);
    if ($44) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 20;
      break;
    }
   case 11:
    __ZN2js11TokenStream16setUnexpectedEOFEb($30);
    var $_0 = 0;
    __label__ = 20;
    break;
   case 12:
    if ((HEAP8[$inDirectivePrologue] & 1) << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $51 = __ZN2js6Parser26recognizeDirectivePrologueEP11JSParseNodePb($this, $41, $inDirectivePrologue);
    if ($51) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 20;
      break;
    }
   case 14:
    var $53 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($41, 34);
    if ($53) {
      __label__ = 15;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 15:
    var $55 = HEAP32[$9 >> 2];
    var $_idx_val = HEAP32[$55 + 24 >> 2];
    var $56 = __ZN13JSTreeContext11atBodyLevelEv($_idx_val);
    if ($56) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $59 = HEAP32[$19 >> 2] | 256;
    HEAP32[$19 >> 2] = $59;
    __label__ = 18;
    break;
   case 17:
    var $61 = $55 | 0;
    var $63 = HEAP32[$61 >> 2] | 2048;
    HEAP32[$61 >> 2] = $63;
    var $64 = HEAP32[$9 >> 2];
    __ZN13JSTreeContext22noteHasExtensibleScopeEv($64);
    __label__ = 18;
    break;
   case 18:
    __ZN11JSParseNode6appendEPS_($12, $41);
    __label__ = 5;
    break;
   case 19:
    var $68 = HEAP32[$9 >> 2] + 36 | 0;
    var $69 = HEAP32[$68 >> 2];
    HEAP32[$68 >> 2] = $26;
    var $70 = $69 + 12 | 0;
    var $71 = __ZNK2js11TokenStream12currentTokenEv($30);
    var $73 = $71 + 12 | 0;
    var $74 = $70;
    var $75$0 = HEAP32[$73 >> 2];
    var $75$1 = HEAP32[$73 + 4 >> 2];
    var $st$13$0 = $74 | 0;
    HEAP32[$st$13$0 >> 2] = $75$0;
    var $st$13$1 = $74 + 4 | 0;
    HEAP32[$st$13$1 >> 2] = $75$1;
    var $_0 = $69;
    __label__ = 20;
    break;
   case 20:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser10statementsEv["X"] = 1;

function __ZN2js11TokenStream10matchTokenENS_9TokenKindE($this, $tt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11TokenStream8getTokenEv($this);
    if (($1 | 0) == ($tt | 0)) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js11TokenStream10ungetTokenEv($this);
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $pn, $flags, $errorNumber) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $args = __stackBase__;
  HEAP32[$args >> 2] = arguments[__ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz.length];
  var $2 = $this + 40 | 0;
  var $3 = HEAP32[$args >> 2];
  var $4 = __ZN2js11TokenStream26reportCompileErrorNumberVAEP11JSParseNodejjPc($2, $pn, $flags, $errorNumber, $3);
  STACKTOP = __stackBase__;
  return $4;
}

function _js_FoldConstants($cx, $pn, $tc, $inCond) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 146;
    break;
   case 3:
    var $7 = __ZNK11JSParseNode8getArityEv($pn);
    if (($7 | 0) == 4) {
      __label__ = 4;
      break;
    } else if (($7 | 0) == 5) {
      __label__ = 6;
      break;
    } else if (($7 | 0) == 3) {
      __label__ = 16;
      break;
    } else if (($7 | 0) == 2) {
      __label__ = 25;
      break;
    } else if (($7 | 0) == 1) {
      __label__ = 32;
      break;
    } else if (($7 | 0) == 6) {
      __label__ = 37;
      break;
    } else if (($7 | 0) == 7) {
      __label__ = 44;
      break;
    } else {
      var $pn1_1 = 0;
      var $pn2_1 = 0;
      var $pn3_0 = 0;
      __label__ = 45;
      break;
    }
   case 4:
    var $9 = $tc | 0;
    var $10 = HEAP32[$9 >> 2];
    var $11 = $tc + 84 | 0;
    var $12 = HEAP32[$11 >> 2];
    var $14 = $pn + 32 | 0;
    var $17 = HEAP32[HEAP32[$14 >> 2] + 60 >> 2];
    HEAP32[$9 >> 2] = $17;
    var $20 = HEAP32[HEAP32[$14 >> 2] + 32 >> 2];
    HEAP32[$11 >> 2] = $20;
    var $23 = HEAP32[$pn + 36 >> 2];
    var $24 = _js_FoldConstants($cx, $23, $tc, 0);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $27 = HEAP32[$11 >> 2];
    var $29 = HEAP32[$14 >> 2] + 32 | 0;
    HEAP32[$29 >> 2] = $27;
    HEAP32[$9 >> 2] = $10;
    HEAP32[$11 >> 2] = $12;
    var $pn1_1 = 0;
    var $pn2_1 = 0;
    var $pn3_0 = 0;
    __label__ = 45;
    break;
   case 6:
    if ($inCond) {
      __label__ = 7;
      break;
    } else {
      var $36 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $32 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 7);
    if ($32) {
      var $36 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $34 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 8);
    var $36 = $34;
    __label__ = 9;
    break;
   case 9:
    var $36;
    var $38 = HEAPU32[$pn + 32 >> 2];
    var $39 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 27);
    if ($39) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $41 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 49);
    if ($41) {
      __label__ = 11;
      break;
    } else {
      var $pn2_0 = $38;
      __label__ = 13;
      break;
    }
   case 11:
    var $43 = __ZNK11JSParseNode10isInParensEv($38);
    if ($43) {
      __label__ = 12;
      break;
    } else {
      var $pn2_0 = $38;
      __label__ = 13;
      break;
    }
   case 12:
    var $pn2_0 = HEAP32[$38 + 24 >> 2];
    __label__ = 13;
    break;
   case 13:
    var $pn2_0;
    if (($pn2_0 | 0) == 0) {
      var $pn1_1 = $38;
      var $pn2_1 = 0;
      var $pn3_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $49 = _js_FoldConstants($cx, $pn2_0, $tc, $36);
    if (($49 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $pn2_0 = HEAP32[$pn2_0 + 24 >> 2];
    __label__ = 13;
    break;
   case 16:
    var $56 = HEAPU32[$pn + 32 >> 2];
    var $57 = $pn + 36 | 0;
    var $58 = HEAP32[$57 >> 2];
    var $59 = $58;
    var $62 = HEAPU32[$pn + 40 >> 2];
    if (($56 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $65 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 35);
    var $66 = _js_FoldConstants($cx, $56, $tc, $65);
    if (($66 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if (($58 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $71 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 83);
    var $72 = _js_FoldConstants($cx, $59, $tc, $71);
    if (($72 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $75 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 83);
    if ($75) {
      __label__ = 21;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 21:
    var $77 = __ZNK11JSParseNode4isOpE4JSOp($59, 67);
    if ($77) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    var $79 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($59, $tc);
    HEAP32[$57 >> 2] = 0;
    __label__ = 23;
    break;
   case 23:
    if (($62 | 0) == 0) {
      var $pn1_1 = $56;
      var $pn2_1 = $59;
      var $pn3_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $83 = _js_FoldConstants($cx, $62, $tc, 0);
    if (($83 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      var $pn1_1 = $56;
      var $pn2_1 = $59;
      var $pn3_0 = $62;
      __label__ = 45;
      break;
    }
   case 25:
    var $87 = HEAP32[$pn + 32 >> 2];
    var $90 = HEAP32[$pn + 36 >> 2];
    var $91 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 7);
    if ($91) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $93 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 8);
    if ($93) {
      __label__ = 27;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 27:
    var $95 = _js_FoldConstants($cx, $87, $tc, $inCond);
    if (($95 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $98 = _js_FoldConstants($cx, $90, $tc, $inCond);
    if (($98 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      var $pn1_1 = $87;
      var $pn2_1 = $90;
      var $pn3_0 = 0;
      __label__ = 45;
      break;
    }
   case 29:
    if (($87 | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $103 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 40);
    var $104 = _js_FoldConstants($cx, $87, $tc, $103);
    if (($104 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $107 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 41);
    var $108 = _js_FoldConstants($cx, $90, $tc, $107);
    if (($108 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      var $pn1_1 = $87;
      var $pn2_1 = $90;
      var $pn3_0 = 0;
      __label__ = 45;
      break;
    }
   case 32:
    var $112 = HEAP32[$pn + 32 >> 2];
    var $113 = __ZNK11JSParseNode4isOpE4JSOp($pn, 39);
    if ($113) {
      __label__ = 33;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 33:
    var $115 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($112, 29);
    if ($115) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    __ZN11JSParseNode5setOpE4JSOp($pn, 200);
    __label__ = 35;
    break;
   case 35:
    if (($112 | 0) == 0) {
      var $pn1_1 = 0;
      var $pn2_1 = 0;
      var $pn3_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $120 = __ZNK11JSParseNode4isOpE4JSOp($pn, 32);
    var $121 = _js_FoldConstants($cx, $112, $tc, $120);
    if (($121 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      var $pn1_1 = $112;
      var $pn2_1 = 0;
      var $pn3_0 = 0;
      __label__ = 45;
      break;
    }
   case 37:
    var $124 = __ZNK11JSParseNode6isUsedEv($pn);
    if ($124) {
      var $pn1_1 = 0;
      var $pn2_1 = 0;
      var $pn3_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $pn1_0_in = HEAP32[$pn + 36 >> 2];
    __label__ = 39;
    break;
   case 39:
    var $pn1_0_in;
    var $pn1_0 = $pn1_0_in;
    if (($pn1_0_in | 0) == 0) {
      var $pn1_1 = $pn1_0;
      var $pn2_1 = 0;
      var $pn3_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $131 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn1_0, 6);
    if ($131) {
      __label__ = 41;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 41:
    var $133 = __ZNK11JSParseNode6isUsedEv($pn1_0);
    if ($133) {
      __label__ = 43;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $pn1_0_in = HEAP32[$pn1_0_in + 36 >> 2];
    __label__ = 39;
    break;
   case 43:
    var $138 = _js_FoldConstants($cx, $pn1_0, $tc, 0);
    if (($138 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      var $pn1_1 = $pn1_0;
      var $pn2_1 = 0;
      var $pn3_0 = 0;
      __label__ = 45;
      break;
    }
   case 44:
    var $143 = HEAP32[$pn + 36 >> 2];
    var $144 = _js_FoldConstants($cx, $143, $tc, 0);
    if (($144 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      var $pn1_1 = $143;
      var $pn2_1 = 0;
      var $pn3_0 = 0;
      __label__ = 45;
      break;
    }
   case 45:
    var $pn3_0;
    var $pn2_1;
    var $pn1_1;
    var $146 = __ZNK11JSParseNode7getKindEv($pn);
    if (($146 | 0) == 35) {
      __label__ = 46;
      break;
    } else if (($146 | 0) == 5) {
      __label__ = 48;
      break;
    } else if (($146 | 0) == 7 || ($146 | 0) == 8) {
      __label__ = 66;
      break;
    } else if (($146 | 0) == 4) {
      __label__ = 86;
      break;
    } else if (($146 | 0) == 15) {
      __label__ = 88;
      break;
    } else if (($146 | 0) == 17 || ($146 | 0) == 14 || ($146 | 0) == 16 || ($146 | 0) == 18) {
      __label__ = 110;
      break;
    } else if (($146 | 0) == 19) {
      __label__ = 124;
      break;
    } else if (($146 | 0) == 75 || ($146 | 0) == 76 || ($146 | 0) == 61 || ($146 | 0) == 59 || ($146 | 0) == 60 || ($146 | 0) == 63) {
      __label__ = 137;
      break;
    } else if (($146 | 0) == 70) {
      __label__ = 139;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 46:
    var $148 = __ZL12ContainsStmtP11JSParseNodeN2js9TokenKindE($pn2_1);
    if (($148 | 0) == 0) {
      __label__ = 47;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 47:
    var $151 = __ZL12ContainsStmtP11JSParseNodeN2js9TokenKindE($pn3_0);
    if (($151 | 0) == 0) {
      __label__ = 48;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 48:
    var $154 = __ZNK11JSParseNode7getKindEv($pn1_1);
    if (($154 | 0) == 30) {
      __label__ = 49;
      break;
    } else if (($154 | 0) == 31) {
      __label__ = 52;
      break;
    } else if (($154 | 0) == 33) {
      __label__ = 54;
      break;
    } else {
      var $_0 = 1;
      __label__ = 146;
      break;
    }
   case 49:
    var $157 = $pn1_1 + 32 | 0;
    var $158 = (tempDoubleI32[0] = HEAP32[$157 >> 2], tempDoubleI32[1] = HEAP32[$157 + 4 >> 2], tempDoubleF64[0]);
    if ($158 == 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    var $161 = __ZL15JSDOUBLE_IS_NaNd2908($158);
    if (($161 | 0) == 0) {
      var $pn2_2 = $pn2_1;
      __label__ = 57;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $pn2_2 = $pn3_0;
    __label__ = 57;
    break;
   case 52:
    var $_idx2_val = HEAP32[HEAP32[$pn1_1 + 32 >> 2] >> 2];
    var $168 = __ZNK8JSString6lengthEv($_idx2_val);
    if (($168 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      var $pn2_2 = $pn2_1;
      __label__ = 57;
      break;
    }
   case 53:
    var $pn2_2 = $pn3_0;
    __label__ = 57;
    break;
   case 54:
    var $172 = __ZNK11JSParseNode4isOpE4JSOp($pn1_1, 67);
    if ($172) {
      var $pn2_2 = $pn2_1;
      __label__ = 57;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    var $174 = __ZNK11JSParseNode4isOpE4JSOp($pn1_1, 66);
    if ($174) {
      var $pn2_2 = $pn3_0;
      __label__ = 57;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    var $176 = __ZNK11JSParseNode4isOpE4JSOp($pn1_1, 64);
    if ($176) {
      var $pn2_2 = $pn3_0;
      __label__ = 57;
      break;
    } else {
      var $_0 = 1;
      __label__ = 146;
      break;
    }
   case 57:
    var $pn2_2;
    if (($pn2_2 | 0) == 0) {
      __label__ = 58;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 58:
    if ((HEAP32[$tc >> 2] & 4096 | 0) == 0) {
      __label__ = 63;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 59:
    var $184 = __ZNK11JSParseNode6isDefnEv($pn2_2);
    if ($184) {
      __label__ = 61;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 60:
    __ZN11JSParseNode6becomeEPS_($pn, $pn2_2);
    __label__ = 61;
    break;
   case 61:
    var $186 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 2);
    if ($186) {
      __label__ = 62;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 62:
    if ((HEAP32[$pn + 32 >> 2] | 0) == 0) {
      __label__ = 63;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 63:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 25);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn, 5);
    __ZN11JSParseNode9makeEmptyEv($pn);
    __label__ = 64;
    break;
   case 64:
    var $192 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn2_2, $tc);
    if (($pn3_0 | 0) == 0 | ($pn3_0 | 0) == ($pn2_2 | 0)) {
      __label__ = 143;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 65:
    var $196 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn3_0, $tc);
    __label__ = 143;
    break;
   case 66:
    if ($inCond) {
      __label__ = 67;
      break;
    } else {
      var $_0 = 1;
      __label__ = 146;
      break;
    }
   case 67:
    var $199 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 5);
    if ($199) {
      __label__ = 68;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 68:
    var $201 = $pn + 32 | 0;
    var $202 = $pn + 40 | 0;
    var $pnp_0 = $201;
    var $pn1_2 = $pn1_1;
    __label__ = 69;
    break;
   case 69:
    var $pn1_2;
    var $pnp_0;
    var $204 = __ZL7BoolishP11JSParseNode($pn1_2);
    var $205 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 7);
    if (($204 | 0) == ($205 & 1 | 0)) {
      __label__ = 70;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 70:
    var $209 = $pn1_2 + 24 | 0;
    var $210 = HEAP32[$209 >> 2];
    if (($210 | 0) == 0) {
      __label__ = 72;
      break;
    } else {
      var $pn2_325 = $210;
      __label__ = 71;
      break;
    }
   case 71:
    var $pn2_325;
    var $213 = HEAP32[$pn2_325 + 24 >> 2];
    var $214 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn2_325, $tc);
    var $216 = HEAP32[$202 >> 2] - 1 | 0;
    HEAP32[$202 >> 2] = $216;
    if (($213 | 0) == 0) {
      __label__ = 72;
      break;
    } else {
      var $pn2_325 = $213;
      __label__ = 71;
      break;
    }
   case 72:
    HEAP32[$209 >> 2] = 0;
    __label__ = 79;
    break;
   case 73:
    if (($204 | 0) == -1) {
      __label__ = 77;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 74:
    if ((HEAP32[$202 >> 2] | 0) == 1) {
      __label__ = 75;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 75:
    var $241 = HEAP32[$201 >> 2];
    __label__ = 81;
    break;
   case 76:
    var $226 = HEAP32[$pn1_2 + 24 >> 2];
    HEAP32[$pnp_0 >> 2] = $226;
    var $227 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn1_2, $tc);
    var $229 = HEAP32[$202 >> 2] - 1 | 0;
    HEAP32[$202 >> 2] = $229;
    var $pnp_1 = $pnp_0;
    __label__ = 78;
    break;
   case 77:
    var $pnp_1 = $pn1_2 + 24 | 0;
    __label__ = 78;
    break;
   case 78:
    var $pnp_1;
    var $233 = HEAPU32[$pnp_1 >> 2];
    if (($233 | 0) == 0) {
      __label__ = 79;
      break;
    } else {
      var $pnp_0 = $pnp_1;
      var $pn1_2 = $233;
      __label__ = 69;
      break;
    }
   case 79:
    var $_pr = HEAP32[$202 >> 2];
    var $235 = HEAP32[$201 >> 2];
    if (($_pr | 0) == 2) {
      __label__ = 80;
      break;
    } else if (($_pr | 0) == 1) {
      var $241 = $235;
      __label__ = 81;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 80:
    var $237 = $235 + 24 | 0;
    var $238 = HEAP32[$237 >> 2];
    HEAP32[$237 >> 2] = 0;
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn, 2);
    HEAP32[$201 >> 2] = $235;
    var $_c3 = $238;
    HEAP32[$pn + 36 >> 2] = $_c3;
    __label__ = 143;
    break;
   case 81:
    var $241;
    __ZN11JSParseNode6becomeEPS_($pn, $241);
    var $242 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($241, $tc);
    __label__ = 143;
    break;
   case 82:
    var $244 = __ZL7BoolishP11JSParseNode($pn1_1);
    var $245 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 7);
    if (($244 | 0) == ($245 & 1 | 0)) {
      __label__ = 83;
      break;
    } else {
      __label__ = 84;
      break;
    }
   case 83:
    var $248 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn2_1, $tc);
    __ZN11JSParseNode6becomeEPS_($pn, $pn1_1);
    __label__ = 144;
    break;
   case 84:
    if (($244 | 0) == -1) {
      __label__ = 143;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 85:
    var $252 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn1_1, $tc);
    __ZN11JSParseNode6becomeEPS_($pn, $pn2_1);
    __label__ = 143;
    break;
   case 86:
    var $254 = __ZNK11JSParseNode4isOpE4JSOp($pn, 0);
    if ($254) {
      __label__ = 143;
      break;
    } else {
      __label__ = 87;
      break;
    }
   case 87:
    var $256 = __ZNK11JSParseNode4isOpE4JSOp($pn, 27);
    if ($256) {
      __label__ = 88;
      break;
    } else {
      __label__ = 110;
      break;
    }
   case 88:
    var $258 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 5);
    if ($258) {
      __label__ = 89;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 89:
    var $262 = HEAP32[$pn + 44 >> 2];
    if (($262 & 2 | 0) == 0) {
      __label__ = 90;
      break;
    } else {
      var $_0 = 1;
      __label__ = 146;
      break;
    }
   case 90:
    if (($262 & 4095 | 0) == 1) {
      var $length_0 = 0;
      var $pn2_4 = $pn1_1;
      __label__ = 91;
      break;
    } else {
      __label__ = 110;
      break;
    }
   case 91:
    var $pn2_4;
    var $length_0;
    if (($pn2_4 | 0) == 0) {
      __label__ = 95;
      break;
    } else {
      __label__ = 92;
      break;
    }
   case 92:
    var $270 = __ZL8FoldTypeP9JSContextP11JSParseNodeN2js9TokenKindE($cx, $pn2_4, 31);
    if (($270 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 93;
      break;
    }
   case 93:
    var $273 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_4, 31);
    if ($273) {
      __label__ = 94;
      break;
    } else {
      var $_0 = 1;
      __label__ = 146;
      break;
    }
   case 94:
    var $_idx1_val = HEAP32[HEAP32[$pn2_4 + 32 >> 2] >> 2];
    var $278 = __ZNK8JSString6lengthEv($_idx1_val);
    var $length_0 = $278 + $length_0 | 0;
    var $pn2_4 = HEAP32[$pn2_4 + 24 >> 2];
    __label__ = 91;
    break;
   case 95:
    var $285 = __ZN9JSContext7malloc_Ej($cx, ($length_0 << 1) + 2 | 0);
    var $286 = $285;
    if (($285 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 96;
      break;
    }
   case 96:
    HEAP16[$286 + ($length_0 << 1) >> 1] = 0;
    var $290 = $cx;
    var $291 = __Z12js_NewStringP9JSContextPtj($290, $286, $length_0);
    var $292 = $291 | 0;
    if (($291 | 0) == 0) {
      __label__ = 98;
      break;
    } else {
      __label__ = 97;
      break;
    }
   case 97:
    if (($pn1_1 | 0) == 0) {
      __label__ = 100;
      break;
    } else {
      var $pn2_519 = $pn1_1;
      var $chars_020 = $286;
      __label__ = 99;
      break;
    }
   case 98:
    __ZN9JSContext5free_EPv($285);
    var $_0 = 0;
    __label__ = 146;
    break;
   case 99:
    var $chars_020;
    var $pn2_519;
    var $298 = HEAP32[$pn2_519 + 32 >> 2];
    var $_idx_val = HEAP32[$298 >> 2];
    var $299 = __ZNK8JSString6lengthEv($_idx_val);
    var $300 = $chars_020;
    var $_idx3_val = HEAP32[$298 + 4 >> 2];
    var $301 = __ZNK14JSLinearString5charsEv($_idx3_val);
    var $302 = $301;
    var $303 = $299 << 1;
    _memcpy($300, $302, $303, 1);
    var $304 = $chars_020 + ($299 << 1) | 0;
    var $305 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn2_519, $tc);
    if (($305 | 0) == 0) {
      __label__ = 100;
      break;
    } else {
      var $pn2_519 = $305;
      var $chars_020 = $304;
      __label__ = 99;
      break;
    }
   case 100:
    var $307 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($cx, $292);
    HEAP32[$pn + 32 >> 2] = $307;
    if (($307 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 101;
      break;
    }
   case 101:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 31);
    __ZN11JSParseNode5setOpE4JSOp($pn, 61);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn, 0);
    __label__ = 143;
    break;
   case 102:
    var $312 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 31);
    if ($312) {
      __label__ = 104;
      break;
    } else {
      __label__ = 103;
      break;
    }
   case 103:
    var $314 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_1, 31);
    if ($314) {
      __label__ = 104;
      break;
    } else {
      __label__ = 110;
      break;
    }
   case 104:
    var $316 = $312 ? $pn2_1 : $pn1_1;
    var $317 = __ZL8FoldTypeP9JSContextP11JSParseNodeN2js9TokenKindE($cx, $316, 31);
    if (($317 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 105;
      break;
    }
   case 105:
    var $320 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 31);
    if ($320) {
      __label__ = 106;
      break;
    } else {
      var $_0 = 1;
      __label__ = 146;
      break;
    }
   case 106:
    var $322 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_1, 31);
    if ($322) {
      __label__ = 107;
      break;
    } else {
      var $_0 = 1;
      __label__ = 146;
      break;
    }
   case 107:
    var $327 = HEAP32[$pn1_1 + 32 >> 2] | 0;
    var $331 = HEAP32[$pn2_1 + 32 >> 2] | 0;
    var $332 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($cx, $327, $331);
    if (($332 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 108:
    var $335 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($cx, $332);
    var $_c1 = $335;
    HEAP32[$pn + 32 >> 2] = $_c1;
    if (($335 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 109;
      break;
    }
   case 109:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 31);
    __ZN11JSParseNode5setOpE4JSOp($pn, 61);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn, 0);
    var $339 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn1_1, $tc);
    var $340 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn2_1, $tc);
    __label__ = 143;
    break;
   case 110:
    var $342 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 5);
    if ($342) {
      var $pn2_6 = $pn1_1;
      __label__ = 111;
      break;
    } else {
      __label__ = 119;
      break;
    }
   case 111:
    var $pn2_6;
    if (($pn2_6 | 0) == 0) {
      var $pn2_7 = $pn1_1;
      __label__ = 114;
      break;
    } else {
      __label__ = 112;
      break;
    }
   case 112:
    var $345 = __ZL8FoldTypeP9JSContextP11JSParseNodeN2js9TokenKindE($cx, $pn2_6, 30);
    if (($345 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 113:
    var $pn2_6 = HEAP32[$pn2_6 + 24 >> 2];
    __label__ = 111;
    break;
   case 114:
    var $pn2_7;
    if (($pn2_7 | 0) == 0) {
      __label__ = 117;
      break;
    } else {
      __label__ = 115;
      break;
    }
   case 115:
    var $352 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_7, 30);
    if ($352) {
      __label__ = 116;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 116:
    var $pn2_7 = HEAP32[$pn2_7 + 24 >> 2];
    __label__ = 114;
    break;
   case 117:
    var $356 = __ZNK11JSParseNode5getOpEv($pn);
    var $358 = HEAP32[$pn1_1 + 24 >> 2];
    var $360 = HEAP32[$358 + 24 >> 2];
    __ZL17FoldBinaryNumericP9JSContext4JSOpP11JSParseNodeS3_S3_P13JSTreeContext($356, $pn1_1, $358, $pn, $tc);
    if (($360 | 0) == 0) {
      __label__ = 143;
      break;
    } else {
      var $pn3_113 = $360;
      __label__ = 118;
      break;
    }
   case 118:
    var $pn3_113;
    var $363 = HEAP32[$pn3_113 + 24 >> 2];
    __ZL17FoldBinaryNumericP9JSContext4JSOpP11JSParseNodeS3_S3_P13JSTreeContext($356, $pn, $pn3_113, $pn, $tc);
    if (($363 | 0) == 0) {
      __label__ = 143;
      break;
    } else {
      var $pn3_113 = $363;
      __label__ = 118;
      break;
    }
   case 119:
    var $366 = __ZL8FoldTypeP9JSContextP11JSParseNodeN2js9TokenKindE($cx, $pn1_1, 30);
    if (($366 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 120;
      break;
    }
   case 120:
    var $369 = __ZL8FoldTypeP9JSContextP11JSParseNodeN2js9TokenKindE($cx, $pn2_1, 30);
    if (($369 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 121;
      break;
    }
   case 121:
    var $372 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 30);
    if ($372) {
      __label__ = 122;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 122:
    var $374 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_1, 30);
    if ($374) {
      __label__ = 123;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 123:
    var $376 = __ZNK11JSParseNode5getOpEv($pn);
    __ZL17FoldBinaryNumericP9JSContext4JSOpP11JSParseNodeS3_S3_P13JSTreeContext($376, $pn1_1, $pn2_1, $pn, $tc);
    __label__ = 143;
    break;
   case 124:
    var $378 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 30);
    if ($378) {
      __label__ = 125;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 125:
    var $381 = $pn1_1 + 32 | 0;
    var $382 = (tempDoubleI32[0] = HEAP32[$381 >> 2], tempDoubleI32[1] = HEAP32[$381 + 4 >> 2], tempDoubleF64[0]);
    var $383 = __ZNK11JSParseNode5getOpEv($pn);
    if (($383 | 0) == 33) {
      __label__ = 126;
      break;
    } else if (($383 | 0) == 34) {
      __label__ = 127;
      break;
    } else if (($383 | 0) == 32) {
      __label__ = 128;
      break;
    } else if (($383 | 0) == 35) {
      var $d_0 = $382;
      __label__ = 131;
      break;
    } else {
      var $_0 = 1;
      __label__ = 146;
      break;
    }
   case 126:
    var $385 = __ZL20js_DoubleToECMAInt32d2909($382);
    var $d_0 = $385 ^ -1 | 0;
    __label__ = 131;
    break;
   case 127:
    var $d_0 = -$382;
    __label__ = 131;
    break;
   case 128:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 33);
    if ($382 == 0) {
      var $396 = 67;
      __label__ = 130;
      break;
    } else {
      __label__ = 129;
      break;
    }
   case 129:
    var $393 = __ZL15JSDOUBLE_IS_NaNd2908($382);
    var $phitmp = ($393 | 0) != 0 ? 67 : 66;
    var $396 = $phitmp;
    __label__ = 130;
    break;
   case 130:
    var $396;
    __ZN11JSParseNode5setOpE4JSOp($pn, $396);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn, 0);
    var $_0 = 1;
    __label__ = 146;
    break;
   case 131:
    var $d_0;
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 30);
    __ZN11JSParseNode5setOpE4JSOp($pn, 60);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn, 0);
    var $399 = $pn + 32 | 0;
    tempDoubleF64[0] = $d_0, HEAP32[$399 >> 2] = tempDoubleI32[0], HEAP32[$399 + 4 >> 2] = tempDoubleI32[1];
    var $400 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn1_1, $tc);
    __label__ = 143;
    break;
   case 132:
    var $402 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 33);
    if ($402) {
      __label__ = 133;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 133:
    var $404 = __ZNK11JSParseNode4isOpE4JSOp($pn, 32);
    if ($404) {
      __label__ = 134;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 134:
    var $406 = __ZNK11JSParseNode4isOpE4JSOp($pn1_1, 67);
    if ($406) {
      __label__ = 136;
      break;
    } else {
      __label__ = 135;
      break;
    }
   case 135:
    var $408 = __ZNK11JSParseNode4isOpE4JSOp($pn1_1, 66);
    if ($408) {
      __label__ = 136;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 136:
    __ZN11JSParseNode6becomeEPS_($pn, $pn1_1);
    var $410 = __ZNK11JSParseNode4isOpE4JSOp($pn, 67);
    var $411 = $410 ? 66 : 67;
    __ZN11JSParseNode5setOpE4JSOp($pn, $411);
    var $412 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn1_1, $tc);
    __label__ = 143;
    break;
   case 137:
    var $414 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 5);
    if ($414) {
      __label__ = 138;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 138:
    var $416 = __ZL16FoldXMLConstantsP9JSContextP11JSParseNodeP13JSTreeContext($cx, $pn, $tc);
    var $417 = ($416 | 0) == 0;
    if ($417 | $inCond ^ 1) {
      var $_0 = $417 & 1 ^ 1;
      __label__ = 146;
      break;
    } else {
      __label__ = 144;
      break;
    }
   case 139:
    var $420 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 63);
    if ($420) {
      __label__ = 140;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 140:
    var $425 = HEAP32[$pn1_1 + 32 >> 2] | 0;
    __ZN2JSL11StringValueEP8JSString2910($v, $425);
    var $426 = $cx;
    var $427 = __Z18js_ToAttributeNameP9JSContextPN2JS5ValueE($426, $v);
    if (($427 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 141;
      break;
    }
   case 141:
    var $431 = HEAP32[$tc + 48 >> 2];
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $432 = __ZNK2JS5Value8toObjectEv($v_idx_val$0, $v_idx_val$1);
    var $433 = __ZN2js6Parser12newObjectBoxEP8JSObject($431, $432);
    if (($433 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 142;
      break;
    }
   case 142:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 63);
    __ZN11JSParseNode5setOpE4JSOp($pn, 80);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn, 0);
    var $_c = $433;
    HEAP32[$pn + 32 >> 2] = $_c;
    var $437 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn1_1, $tc);
    __label__ = 143;
    break;
   case 143:
    if ($inCond) {
      __label__ = 144;
      break;
    } else {
      var $_0 = 1;
      __label__ = 146;
      break;
    }
   case 144:
    var $439 = __ZL7BoolishP11JSParseNode($pn);
    if (($439 | 0) > -1) {
      __label__ = 145;
      break;
    } else {
      var $_0 = 1;
      __label__ = 146;
      break;
    }
   case 145:
    __ZL22PrepareNodeForMutationP11JSParseNodeP13JSTreeContext($pn, $tc);
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 33);
    var $443 = ($439 | 0) != 0 ? 67 : 66;
    __ZN11JSParseNode5setOpE4JSOp($pn, $443);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn, 0);
    var $_0 = 1;
    __label__ = 146;
    break;
   case 146:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_FoldConstants["X"] = 1;

function __ZN13JSTreeContextD1Ev($this) {
  var $1 = $this;
  __ZN13JSTreeContextD2Ev($1);
  return;
}

function __ZN2js8CompilerC2EP9JSContextP12JSPrincipalsPNS_10StackFrameE($this, $cx, $prin, $cfp) {
  var $1 = $this | 0;
  __ZN2js6ParserC2EP9JSContextP12JSPrincipalsPNS_10StackFrameEb($1, $cx, $prin, $cfp, 1);
  HEAP32[$this + 992 >> 2] = 0;
  return;
}

function __ZNK2js11TokenStream9getLinenoEv($this_0_4_val) {
  return $this_0_4_val;
}

function __ZN2js8Compiler13compileScriptEP9JSContextP8JSObjectPNS_10StackFrameEP12JSPrincipalsjPKtjPKcj9JSVersionP8JSStringj($cx, $scopeChain, $callerFrame, $principals, $tcflags, $chars, $length, $filename, $lineno, $version, $source, $staticLevel) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 2068;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $inDirectivePrologue = __stackBase__;
    var $compiler = __stackBase__ + 4;
    var $cg = __stackBase__ + 1e3;
    var $globalScope = __stackBase__ + 1616;
    var $_ = __stackBase__ + 2060;
    var $bodyid = __stackBase__ + 2064;
    __ZN2js8CompilerC2EP9JSContextP12JSPrincipalsPNS_10StackFrameE($compiler, $cx, $principals, $callerFrame);
    var $1 = __ZN2js8Compiler4initEPKtjPKcj9JSVersion($compiler, $chars, $length, $filename, $lineno, $version);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 57;
      break;
    }
   case 2:
    var $3 = $compiler | 0;
    var $4 = $compiler + 40 | 0;
    var $_idx_val = HEAP32[$compiler + 180 >> 2];
    var $5 = __ZNK2js11TokenStream9getLinenoEv($_idx_val);
    var $6 = $cg;
    var $7 = $compiler;
    __ZN15JSCodeGeneratorC2EPN2js6ParserEj($6, $7, $5);
    var $8 = __ZN15JSCodeGenerator4initEP9JSContextN13JSTreeContext12InitBehaviorE($6, $cx, 0);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 56;
      break;
    }
   case 3:
    if (($scopeChain | 0) == 0) {
      var $19 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $scopeChain;
    var $13 = __ZNK8JSObject9getGlobalEv($12);
    if (($13 | 0) == ($scopeChain | 0)) {
      __label__ = 5;
      break;
    } else {
      var $19 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $19 = $13;
    __label__ = 6;
    break;
   case 6:
    var $19;
    __ZN2js11GlobalScopeC1EP9JSContextP8JSObjectP15JSCodeGenerator($globalScope, $cx, $19 | 0, $cg);
    var $21 = $cg | 0;
    var $22 = $cg | 0;
    var $24 = HEAP32[$22 >> 2] | $tcflags;
    HEAP32[$22 >> 2] = $24;
    __ZN13JSTreeContext13setScopeChainEP8JSObject($21, $scopeChain);
    HEAP32[$compiler + 992 >> 2] = $globalScope;
    var $26 = __ZL14SetStaticLevelP13JSTreeContextj($21, $staticLevel);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $script_0 = 0;
      __label__ = 54;
      break;
    }
   case 7:
    var $28 = ($callerFrame | 0) != 0;
    if ($28) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $callerFrame_idx1_val = HEAP32[$callerFrame >> 2];
    var $30 = __ZNK2js10StackFrame13isScriptFrameEv($callerFrame_idx1_val);
    if ($30) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $32 = __ZNK2js10StackFrame6scriptEv($callerFrame);
    if ((HEAP8[$32 + 36 | 0] & 8) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $39 = HEAP32[$22 >> 2] | 262144;
    HEAP32[$22 >> 2] = $39;
    __ZN2js11TokenStream13setStrictModeEb($4, 1);
    __label__ = 11;
    break;
   case 11:
    if (($tcflags & 8192 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (($source | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $46 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($cx, $source);
    if (($46 | 0) == 0) {
      var $script_0 = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $49 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($6, $46, $_);
    if ($49) {
      __label__ = 15;
      break;
    } else {
      var $script_0 = 0;
      __label__ = 54;
      break;
    }
   case 15:
    if ($28) {
      __label__ = 16;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 16:
    var $callerFrame_idx_val = HEAP32[$callerFrame >> 2];
    var $52 = __ZNK2js10StackFrame15isFunctionFrameEv($callerFrame_idx_val);
    if ($52) {
      __label__ = 17;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 17:
    var $54 = __ZNK2js10StackFrame3funEv($callerFrame);
    var $55 = $54 | 0;
    var $56 = __ZN2js6Parser12newObjectBoxEP8JSObject($3, $55);
    if (($56 | 0) == 0) {
      var $script_0 = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $59 = $cg + 296 | 0;
    var $60 = HEAP32[$59 >> 2];
    HEAP32[$56 + 4 >> 2] = $60;
    HEAP32[$59 >> 2] = $56;
    var $62 = $cg + 292 | 0;
    var $64 = HEAP32[$62 >> 2] + 1 | 0;
    HEAP32[$62 >> 2] = $64;
    __label__ = 19;
    break;
   case 19:
    var $66 = __ZL15GenerateBlockIdP13JSTreeContextRj($21, $bodyid);
    if ($66) {
      __label__ = 20;
      break;
    } else {
      var $script_0 = 0;
      __label__ = 54;
      break;
    }
   case 20:
    var $68 = HEAP32[$bodyid >> 2];
    HEAP32[$cg + 4 >> 2] = $68;
    HEAP8[$inDirectivePrologue] = 1;
    __ZN2js11TokenStream23setOctalCharacterEscapeEb($4, 0);
    var $70 = $cg + 84 | 0;
    var $onlyXML_0 = 1;
    var $pn_0 = 0;
    __label__ = 21;
    break;
   case 21:
    var $pn_0;
    var $onlyXML_0;
    var $72 = __ZN2js11TokenStream9peekTokenEj($4, 8);
    if (($72 | 0) < 1) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    if (($72 | 0) == 0) {
      __label__ = 34;
      break;
    } else {
      var $script_0 = 0;
      __label__ = 54;
      break;
    }
   case 23:
    var $77 = __ZN2js6Parser9statementEv($3);
    if (($77 | 0) == 0) {
      var $script_0 = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    if ((HEAP8[$inDirectivePrologue] & 1) << 24 >> 24 == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $84 = __ZN2js6Parser26recognizeDirectivePrologueEP11JSParseNodePb($3, $77, $inDirectivePrologue);
    if ($84) {
      __label__ = 26;
      break;
    } else {
      var $script_0 = 0;
      __label__ = 54;
      break;
    }
   case 26:
    var $86 = _js_FoldConstants($cx, $77, $21, 0);
    if (($86 | 0) == 0) {
      var $script_0 = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $89 = __ZN2js6Parser16analyzeFunctionsEP13JSTreeContext($3, $21);
    if ($89) {
      __label__ = 28;
      break;
    } else {
      var $script_0 = 0;
      __label__ = 54;
      break;
    }
   case 28:
    HEAP32[$70 >> 2] = 0;
    var $91 = _js_EmitTree($cx, $6, $77);
    if (($91 | 0) == 0) {
      var $script_0 = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $94 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($77, 2);
    if ($94) {
      __label__ = 30;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 30:
    var $97 = HEAP32[$77 + 32 >> 2];
    if (($97 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $100 = __ZNK11JSParseNode7getKindEv($97);
    var $101 = __ZN2jsL13TreeTypeIsXMLENS_9TokenKindE($100);
    if ($101) {
      var $onlyXML_1 = $onlyXML_0;
      __label__ = 33;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $onlyXML_1 = 0;
    __label__ = 33;
    break;
   case 33:
    var $onlyXML_1;
    var $104 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($77, $21);
    var $onlyXML_0 = $onlyXML_1;
    var $pn_0 = $77;
    __label__ = 21;
    break;
   case 34:
    if (($pn_0 | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    if (($onlyXML_0 & 1) << 24 >> 24 == 0 | $28) {
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $111 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($3, 0, 0, 79, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $script_0 = 0;
    __label__ = 54;
    break;
   case 37:
    var $_idx2_val = HEAP32[$22 >> 2];
    var $113 = __ZNK15JSCodeGenerator9hasSharpsEv($_idx2_val);
    if ($113) {
      __label__ = 38;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 38:
    var $116 = HEAP32[$cg + 172 >> 2];
    var $118 = HEAP32[$116 >> 2];
    var $124 = $118 + (HEAP32[$116 + 8 >> 2] - $118) | 0;
    var $code_0 = $118;
    __label__ = 39;
    break;
   case 39:
    var $code_0;
    if (($code_0 | 0) == ($124 | 0)) {
      __label__ = 50;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $129 = HEAPU8[$code_0] & 255;
    var $131 = HEAPU8[_js_CodeSpec + ($129 << 3) | 0];
    if ($131 << 24 >> 24 > 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 41:
    var $138 = $131 << 24 >> 24;
    __label__ = 43;
    break;
   case 42:
    var $136 = __Z28js_GetVariableBytecodeLengthPh($code_0);
    var $138 = $136;
    __label__ = 43;
    break;
   case 43:
    var $138;
    var $140 = HEAP32[_js_CodeSpec + ($129 << 3) + 4 >> 2];
    var $142 = ($140 & 16777216 | 0) == 0;
    if ($142) {
      __label__ = 44;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 44:
    if ((($140 & 31) - 7 | 0) >>> 0 < 2) {
      __label__ = 45;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 45:
    var $146 = $code_0 + 1 | 0;
    var $150 = $code_0 + 2 | 0;
    var $153 = (HEAPU8[$146] & 255) << 8 | HEAPU8[$150] & 255;
    if ($142) {
      __label__ = 46;
      break;
    } else {
      var $slot_0 = $153;
      __label__ = 47;
      break;
    }
   case 46:
    var $155 = __ZNK15JSCodeGenerator10sharpSlotsEv($cg);
    var $slot_0 = $155 + $153 | 0;
    __label__ = 47;
    break;
   case 47:
    var $slot_0;
    if ($slot_0 >>> 0 > 65535) {
      __label__ = 55;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    HEAP8[$146] = $slot_0 >>> 8 & 255;
    HEAP8[$150] = $slot_0 & 255;
    __label__ = 49;
    break;
   case 49:
    var $code_0 = $code_0 + $138 | 0;
    __label__ = 39;
    break;
   case 50:
    var $165 = _js_Emit1($cx, $6, 197);
    if (($165 | 0) < 0) {
      var $script_0 = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $168 = $cx;
    var $169 = $cg;
    var $170 = __ZN8JSScript15NewScriptFromCGEP9JSContextP15JSCodeGenerator($168, $169);
    var $171 = $170;
    if (($170 | 0) == 0) {
      var $script_0 = $171;
      __label__ = 54;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 52:
    var $174 = __ZN2js8Compiler13defineGlobalsEP9JSContextRNS_11GlobalScopeEP8JSScript($cx, $globalScope, $171);
    if ($174) {
      var $script_0 = $171;
      __label__ = 54;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    var $script_0 = 0;
    __label__ = 54;
    break;
   case 54:
    var $script_0;
    __ZN2js11GlobalScopeD1Ev($globalScope);
    var $_0 = $script_0;
    __label__ = 56;
    break;
   case 55:
    var $177 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($3, 0, 0, 199, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $script_0 = 0;
    __label__ = 54;
    break;
   case 56:
    var $_0;
    __ZN15JSCodeGeneratorD2Ev($6);
    var $_1 = $_0;
    __label__ = 57;
    break;
   case 57:
    var $_1;
    __ZN2js8CompilerD1Ev($compiler);
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Compiler13compileScriptEP9JSContextP8JSObjectPNS_10StackFrameEP12JSPrincipalsjPKtjPKcj9JSVersionP8JSStringj["X"] = 1;

function __ZN2js8Compiler4initEPKtjPKcj9JSVersion($this, $base, $length, $filename, $lineno, $version) {
  var $1 = $this | 0;
  var $2 = __ZN2js6Parser4initEPKtjPKcj9JSVersion($1, $base, $length, $filename, $lineno, $version);
  return $2;
}

function __ZN2js11GlobalScopeC1EP9JSContextP8JSObjectP15JSCodeGenerator($this, $cx, $globalObj, $cg) {
  __ZN2js11GlobalScopeC2EP9JSContextP8JSObjectP15JSCodeGenerator($this, $cx, $globalObj, $cg);
  return;
}

function __ZL14SetStaticLevelP13JSTreeContextj($tc, $staticLevel) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $staticLevel & 65535;
    var $2 = __ZN2js11UpvarCookie15isLevelReservedEt($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = HEAP32[HEAP32[$tc + 48 >> 2] + 12 >> 2];
    _JS_ReportErrorNumber($7, 4, 25, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str252545 | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    HEAP32[$tc + 76 >> 2] = $staticLevel;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream13setStrictModeEb($this, $enabled) {
  __ZN2js11TokenStream7setFlagEbNS_16TokenStreamFlagsE($this, $enabled, 64);
  return;
}

function __ZN2js11TokenStream23setOctalCharacterEscapeEb($this, $enabled) {
  __ZN2js11TokenStream7setFlagEbNS_16TokenStreamFlagsE($this, $enabled, 4096);
  return;
}

function __ZN2js11TokenStream9peekTokenEj($this, $withFlags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $flagger = __stackBase__;
  __ZN2js11TokenStream7FlaggerC1EPS0_j($flagger, $this, $withFlags);
  var $1 = __ZN2js11TokenStream9peekTokenEv($this);
  var $flagger_idx_val = HEAP32[$flagger >> 2];
  var $flagger_idx1_val = HEAP32[$flagger + 4 >> 2];
  __ZN2js11TokenStream7FlaggerD1Ev($flagger_idx_val, $flagger_idx1_val);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE6lengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZN2jsL13TreeTypeIsXMLENS_9TokenKindE($tt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($tt - 67 | 0) >>> 0 < 3 | ($tt | 0) == 75) {
      var $6 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = ($tt | 0) == 76;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser9statementEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 132;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmtInfo = __stackBase__ + 4;
    var $stmtInfo1 = __stackBase__ + 36;
    var $stmtInfo4 = __stackBase__ + 68;
    var $stmtInfo11 = __stackBase__ + 100;
    var $2 = $this + 12 | 0;
    var $3 = HEAPU32[$2 >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$3 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($3);
    var $_0 = 0;
    __label__ = 96;
    break;
   case 3:
    var $9 = $this + 40 | 0;
    var $10 = __ZN2js11TokenStream8getTokenEj($9, 8);
    if (($10 | 0) == 34) {
      __label__ = 4;
      break;
    } else if (($10 | 0) == 35) {
      __label__ = 6;
      break;
    } else if (($10 | 0) == 37) {
      __label__ = 14;
      break;
    } else if (($10 | 0) == 40) {
      __label__ = 15;
      break;
    } else if (($10 | 0) == 41) {
      __label__ = 19;
      break;
    } else if (($10 | 0) == 42) {
      __label__ = 26;
      break;
    } else if (($10 | 0) == 53) {
      __label__ = 27;
      break;
    } else if (($10 | 0) == 56) {
      __label__ = 28;
      break;
    } else if (($10 | 0) == 54) {
      __label__ = 33;
      break;
    } else if (($10 | 0) == 55) {
      __label__ = 34;
      break;
    } else if (($10 | 0) == 43) {
      __label__ = 35;
      break;
    } else if (($10 | 0) == 44) {
      __label__ = 49;
      break;
    } else if (($10 | 0) == 47) {
      __label__ = 66;
      break;
    } else if (($10 | 0) == 46) {
      __label__ = 67;
      break;
    } else if (($10 | 0) == 81) {
      __label__ = 69;
      break;
    } else if (($10 | 0) == 48) {
      __label__ = 70;
      break;
    } else if (($10 | 0) == 25) {
      __label__ = 71;
      break;
    } else if (($10 | 0) == 2) {
      __label__ = 80;
      break;
    } else if (($10 | 0) == 58) {
      __label__ = 82;
      break;
    } else if (($10 | 0) == 39) {
      __label__ = 84;
      break;
    } else if (($10 | 0) == -1) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 94;
      break;
    }
   case 4:
    var $12 = __ZN2js11TokenStream9peekTokenEj($9, 32);
    if (($12 | 0) == 71) {
      __label__ = 94;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = __ZN2js6Parser12functionStmtEv($this);
    var $_0 = $15;
    __label__ = 96;
    break;
   case 6:
    var $17 = $this + 980 | 0;
    var $_idx8_val = HEAP32[HEAP32[$17 >> 2] + 48 >> 2];
    var $19 = __ZN2js11TernaryNode6createEP13JSTreeContext($_idx8_val);
    var $20 = $19 | 0;
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = __ZN2js6Parser9conditionEv($this);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = HEAP32[$17 >> 2];
    var $28 = $stmtInfo;
    _js_PushStatement($27, $28, 1, -1);
    var $29 = __ZN2js6Parser9statementEv($this);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = __ZN2js11TokenStream10matchTokenENS_9TokenKindEj($9, 36, 8);
    if ($32) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    HEAP16[$stmtInfo >> 1] = 2;
    var $35 = __ZN2js6Parser9statementEv($this);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $40 = $35 + 12 | 0;
    var $41 = $19 + 12 | 0;
    var $st$4$0 = $40 | 0;
    var $42$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $40 + 4 | 0;
    var $42$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $41 | 0;
    HEAP32[$st$8$0 >> 2] = $42$0;
    var $st$8$1 = $41 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $42$1;
    var $pn3_0 = $35;
    __label__ = 13;
    break;
   case 12:
    var $46 = $29 + 12 | 0;
    var $47 = $19 + 12 | 0;
    var $st$4$0 = $46 | 0;
    var $48$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $46 + 4 | 0;
    var $48$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $47 | 0;
    HEAP32[$st$8$0 >> 2] = $48$0;
    var $st$8$1 = $47 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $48$1;
    var $pn3_0 = 0;
    __label__ = 13;
    break;
   case 13:
    var $pn3_0;
    var $50 = HEAP32[$17 >> 2];
    __ZL12PopStatementP13JSTreeContext($50);
    var $51 = $19 + 32 | 0;
    HEAP32[$51 >> 2] = $23;
    var $52 = $19 + 36 | 0;
    HEAP32[$52 >> 2] = $29;
    var $53 = $19 + 40 | 0;
    HEAP32[$53 >> 2] = $pn3_0;
    var $_0 = $20;
    __label__ = 96;
    break;
   case 14:
    var $55 = __ZN2js6Parser15switchStatementEv($this);
    var $_0 = $55;
    __label__ = 96;
    break;
   case 15:
    var $57 = $this + 980 | 0;
    var $_idx7_val = HEAP32[HEAP32[$57 >> 2] + 48 >> 2];
    var $59 = __ZN2js10BinaryNode6createEP13JSTreeContext($_idx7_val);
    var $60 = $59 | 0;
    if (($59 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $64 = HEAP32[$57 >> 2];
    _js_PushStatement($64, $stmtInfo1, 14, -1);
    var $65 = __ZN2js6Parser9conditionEv($this);
    if (($65 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $68 = $59 + 32 | 0;
    HEAP32[$68 >> 2] = $65;
    var $69 = __ZN2js6Parser9statementEv($this);
    if (($69 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $72 = HEAP32[$57 >> 2];
    __ZL12PopStatementP13JSTreeContext($72);
    var $75 = $69 + 12 | 0;
    var $76 = $59 + 12 | 0;
    var $st$6$0 = $75 | 0;
    var $77$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $75 + 4 | 0;
    var $77$1 = HEAP32[$st$6$1 >> 2];
    var $st$10$0 = $76 | 0;
    HEAP32[$st$10$0 >> 2] = $77$0;
    var $st$10$1 = $76 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $77$1;
    var $78 = $59 + 36 | 0;
    HEAP32[$78 >> 2] = $69;
    var $_0 = $60;
    __label__ = 96;
    break;
   case 19:
    var $80 = $this + 980 | 0;
    var $_idx6_val = HEAP32[HEAP32[$80 >> 2] + 48 >> 2];
    var $82 = __ZN2js10BinaryNode6createEP13JSTreeContext($_idx6_val);
    var $83 = $82 | 0;
    if (($82 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $87 = HEAP32[$80 >> 2];
    _js_PushStatement($87, $stmtInfo4, 11, -1);
    var $88 = __ZN2js6Parser9statementEv($this);
    if (($88 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $91 = $82 + 32 | 0;
    HEAP32[$91 >> 2] = $88;
    var $92 = __ZN2js11TokenStream8getTokenEj($9, 0);
    if (($92 | 0) == 40) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $95 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 84, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 96;
    break;
   case 23:
    var $97 = __ZN2js6Parser9conditionEv($this);
    if (($97 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $100 = HEAP32[$80 >> 2];
    __ZL12PopStatementP13JSTreeContext($100);
    var $103 = $97 + 12 | 0;
    var $104 = $82 + 12 | 0;
    var $st$6$0 = $103 | 0;
    var $105$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $103 + 4 | 0;
    var $105$1 = HEAP32[$st$6$1 >> 2];
    var $st$10$0 = $104 | 0;
    HEAP32[$st$10$0 >> 2] = $105$0;
    var $st$10$1 = $104 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $105$1;
    var $106 = $82 + 36 | 0;
    HEAP32[$106 >> 2] = $97;
    var $107 = __ZNK2js6Parser13versionNumberEv($this);
    if (($107 | 0) == 148) {
      var $pn_0 = $83;
      __label__ = 95;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $110 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($9, 2);
    var $_0 = $83;
    __label__ = 96;
    break;
   case 26:
    var $112 = __ZN2js6Parser12forStatementEv($this);
    var $_0 = $112;
    __label__ = 96;
    break;
   case 27:
    var $114 = __ZN2js6Parser12tryStatementEv($this);
    var $_0 = $114;
    __label__ = 96;
    break;
   case 28:
    var $_idx5_val = HEAP32[HEAP32[$this + 980 >> 2] + 48 >> 2];
    var $118 = __ZN2js9UnaryNode6createEP13JSTreeContext($_idx5_val);
    var $119 = $118 | 0;
    if (($118 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $122 = __ZN2js11TokenStream17peekTokenSameLineEj($9);
    if (($122 | 0) == 26 || ($122 | 0) == 2 || ($122 | 0) == 1 || ($122 | 0) == 0) {
      __label__ = 30;
      break;
    } else if (($122 | 0) == -1) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    var $124 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 133, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 96;
    break;
   case 31:
    var $126 = __ZN2js6Parser4exprEv($this);
    if (($126 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $131 = $126 + 12 | 0;
    var $132 = $118 + 12 | 0;
    var $st$4$0 = $131 | 0;
    var $133$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $131 + 4 | 0;
    var $133$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $132 | 0;
    HEAP32[$st$8$0 >> 2] = $133$0;
    var $st$8$1 = $132 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $133$1;
    __ZN11JSParseNode5setOpE4JSOp($119, 112);
    var $134 = $118 + 32 | 0;
    HEAP32[$134 >> 2] = $126;
    var $pn_0 = $119;
    __label__ = 95;
    break;
   case 33:
    var $136 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 119, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 96;
    break;
   case 34:
    var $138 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 120, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 96;
    break;
   case 35:
    var $140 = $this + 980 | 0;
    var $_idx2_val = HEAP32[HEAP32[$140 >> 2] + 48 >> 2];
    var $142 = __ZN2js11NullaryNode6createEP13JSTreeContext($_idx2_val);
    var $143 = $142 | 0;
    if (($142 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $146 = __ZL10MatchLabelP9JSContextPN2js11TokenStreamEP11JSParseNode($9, $143);
    if (($146 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $151 = HEAP32[HEAP32[$140 >> 2] + 24 >> 2];
    var $154 = HEAP32[$142 + 32 >> 2];
    var $155 = ($154 | 0) != 0;
    if ($155) {
      var $stmt_0 = $151;
      __label__ = 38;
      break;
    } else {
      var $stmt_1 = $151;
      __label__ = 43;
      break;
    }
   case 38:
    var $stmt_0;
    if (($stmt_0 | 0) == 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 39:
    var $158 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 121, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 96;
    break;
   case 40:
    if (HEAP16[$stmt_0 >> 1] << 16 >> 16 == 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 41:
    if ((HEAP32[$stmt_0 + 20 >> 2] | 0) == ($154 | 0)) {
      __label__ = 47;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $stmt_0 = HEAP32[$stmt_0 + 24 >> 2];
    __label__ = 38;
    break;
   case 43:
    var $stmt_1;
    if (($stmt_1 | 0) == 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 44:
    var $172 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 122, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 96;
    break;
   case 45:
    var $175 = HEAPU16[$stmt_1 >> 1];
    if (($175 & 65535) > 10 | $175 << 16 >> 16 == 5) {
      __label__ = 47;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $stmt_1 = HEAP32[$stmt_1 + 24 >> 2];
    __label__ = 43;
    break;
   case 47:
    if ($155) {
      __label__ = 48;
      break;
    } else {
      var $pn_0 = $143;
      __label__ = 95;
      break;
    }
   case 48:
    var $182 = $142 + 12 | 0;
    var $183 = __ZNK2js11TokenStream12currentTokenEv($9);
    var $185 = $183 + 12 | 0;
    var $186 = $182;
    var $st$5$0 = $185 | 0;
    var $187$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $185 + 4 | 0;
    var $187$1 = HEAP32[$st$5$1 >> 2];
    var $st$9$0 = $186 | 0;
    HEAP32[$st$9$0 >> 2] = $187$0;
    var $st$9$1 = $186 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $187$1;
    var $pn_0 = $143;
    __label__ = 95;
    break;
   case 49:
    var $189 = $this + 980 | 0;
    var $_idx1_val = HEAP32[HEAP32[$189 >> 2] + 48 >> 2];
    var $191 = __ZN2js11NullaryNode6createEP13JSTreeContext($_idx1_val);
    var $192 = $191 | 0;
    if (($191 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    var $195 = __ZL10MatchLabelP9JSContextPN2js11TokenStreamEP11JSParseNode($9, $192);
    if (($195 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $200 = HEAPU32[HEAP32[$189 >> 2] + 24 >> 2];
    var $203 = HEAP32[$191 + 32 >> 2];
    var $204 = ($203 | 0) != 0;
    if ($204) {
      var $stmt2_0 = 0;
      var $stmt9_0 = $200;
      __label__ = 52;
      break;
    } else {
      var $stmt9_1 = $200;
      __label__ = 60;
      break;
    }
   case 52:
    var $stmt9_0;
    var $stmt2_0;
    if (($stmt9_0 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 53:
    var $207 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 121, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 96;
    break;
   case 54:
    if (HEAP16[$stmt9_0 >> 1] << 16 >> 16 == 0) {
      __label__ = 55;
      break;
    } else {
      var $stmt2_1 = $stmt9_0;
      __label__ = 59;
      break;
    }
   case 55:
    if ((HEAP32[$stmt9_0 + 20 >> 2] | 0) == ($203 | 0)) {
      __label__ = 56;
      break;
    } else {
      var $stmt2_1 = $stmt2_0;
      __label__ = 59;
      break;
    }
   case 56:
    if (($stmt2_0 | 0) == 0) {
      __label__ = 58;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    if ((HEAPU16[$stmt2_0 >> 1] & 65535) > 10) {
      __label__ = 64;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 58:
    var $223 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 123, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 96;
    break;
   case 59:
    var $stmt2_1;
    var $stmt2_0 = $stmt2_1;
    var $stmt9_0 = HEAP32[$stmt9_0 + 24 >> 2];
    __label__ = 52;
    break;
   case 60:
    var $stmt9_1;
    if (($stmt9_1 | 0) == 0) {
      __label__ = 61;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 61:
    var $229 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 123, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 96;
    break;
   case 62:
    if ((HEAPU16[$stmt9_1 >> 1] & 65535) > 10) {
      __label__ = 64;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $stmt9_1 = HEAP32[$stmt9_1 + 24 >> 2];
    __label__ = 60;
    break;
   case 64:
    if ($204) {
      __label__ = 65;
      break;
    } else {
      var $pn_0 = $192;
      __label__ = 95;
      break;
    }
   case 65:
    var $238 = $191 + 12 | 0;
    var $239 = __ZNK2js11TokenStream12currentTokenEv($9);
    var $241 = $239 + 12 | 0;
    var $242 = $238;
    var $st$5$0 = $241 | 0;
    var $243$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $241 + 4 | 0;
    var $243$1 = HEAP32[$st$5$1 >> 2];
    var $st$9$0 = $242 | 0;
    HEAP32[$st$9$0 >> 2] = $243$0;
    var $st$9$1 = $242 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $243$1;
    var $pn_0 = $192;
    __label__ = 95;
    break;
   case 66:
    var $245 = __ZN2js6Parser13withStatementEv($this);
    var $_0 = $245;
    __label__ = 96;
    break;
   case 67:
    var $247 = __ZN2js6Parser9variablesEb($this, 0);
    if (($247 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 68:
    var $251 = $247 + 44 | 0;
    var $253 = HEAP32[$251 >> 2] | 4;
    HEAP32[$251 >> 2] = $253;
    var $pn_0 = $247;
    __label__ = 95;
    break;
   case 69:
    var $255 = __ZN2js6Parser12letStatementEv($this);
    var $_0 = $255;
    __label__ = 96;
    break;
   case 70:
    var $257 = __ZN2js6Parser13returnOrYieldEb($this, 0);
    if (($257 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      var $pn_0 = $257;
      __label__ = 95;
      break;
    }
   case 71:
    var $260 = $this + 980 | 0;
    var $262 = HEAP32[$260 >> 2] | 0;
    var $263 = HEAPU32[$262 >> 2];
    var $264 = $263 & -2049;
    HEAP32[$262 >> 2] = $264;
    var $265 = HEAP32[$260 >> 2];
    var $266 = __ZL22PushBlocklikeStatementP10JSStmtInfo10JSStmtTypeP13JSTreeContext($stmtInfo11, 4, $265);
    if ($266) {
      __label__ = 72;
      break;
    } else {
      var $_0 = 0;
      __label__ = 96;
      break;
    }
   case 72:
    var $268 = __ZN2js6Parser10statementsEv($this);
    if (($268 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    var $271 = __ZN2js11TokenStream8getTokenEj($9, 0);
    if (($271 | 0) == 26) {
      __label__ = 75;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 74:
    var $274 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 101, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 96;
    break;
   case 75:
    var $276 = HEAP32[$260 >> 2];
    __ZL12PopStatementP13JSTreeContext($276);
    var $277 = HEAP32[$260 >> 2];
    var $279 = HEAP32[$277 >> 2];
    if (($279 & 2048 | 0) == 0) {
      var $297 = $277;
      var $296 = $279;
      __label__ = 79;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 76:
    var $284 = HEAP32[$277 + 24 >> 2];
    if (($284 | 0) == 0) {
      __label__ = 78;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 77:
    if (HEAP16[$284 >> 1] << 16 >> 16 == 4) {
      __label__ = 78;
      break;
    } else {
      var $297 = $277;
      var $296 = $279;
      __label__ = 79;
      break;
    }
   case 78:
    var $292 = $268 + 44 | 0;
    var $294 = HEAP32[$292 >> 2] | 128;
    HEAP32[$292 >> 2] = $294;
    var $_pre = HEAP32[$260 >> 2];
    var $297 = $_pre;
    var $296 = HEAP32[$_pre >> 2];
    __label__ = 79;
    break;
   case 79:
    var $296;
    var $297;
    var $300 = $296 & 629442540 | $263;
    HEAP32[$297 >> 2] = $300;
    var $_0 = $268;
    __label__ = 96;
    break;
   case 80:
    var $_idx4_val = HEAP32[HEAP32[$this + 980 >> 2] + 48 >> 2];
    var $304 = __ZN2js9UnaryNode6createEP13JSTreeContext($_idx4_val);
    var $305 = $304 | 0;
    if (($304 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 81:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($305, 2);
    var $_0 = $305;
    __label__ = 96;
    break;
   case 82:
    var $309 = $this + 980 | 0;
    var $_idx_val = HEAP32[HEAP32[$309 >> 2] + 48 >> 2];
    var $311 = __ZN2js11NullaryNode6createEP13JSTreeContext($_idx_val);
    var $312 = $311 | 0;
    if (($311 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 83;
      break;
    }
   case 83:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($312, 58);
    var $316 = HEAP32[$309 >> 2] | 0;
    var $318 = HEAP32[$316 >> 2] | 256;
    HEAP32[$316 >> 2] = $318;
    var $pn_0 = $312;
    __label__ = 95;
    break;
   case 84:
    var $320 = $this + 980 | 0;
    var $_idx3_val = HEAP32[HEAP32[$320 >> 2] + 48 >> 2];
    var $322 = __ZN2js9UnaryNode6createEP13JSTreeContext($_idx3_val);
    var $323 = $322 | 0;
    if (($322 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 85:
    var $326 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($9, 29);
    if ($326) {
      __label__ = 86;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 86:
    var $328 = __ZNK2js11TokenStream12currentTokenEv($9);
    if ((HEAP32[$328 + 28 >> 2] | 0) == (HEAP32[HEAP32[HEAP32[$2 >> 2] + 52 >> 2] + 210424 >> 2] | 0)) {
      __label__ = 87;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 87:
    var $339 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($9, 29);
    if ($339) {
      __label__ = 88;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 88:
    var $341 = __ZNK2js11TokenStream12currentTokenEv($9);
    if ((HEAP32[$341 + 28 >> 2] | 0) == (HEAP32[HEAP32[HEAP32[$2 >> 2] + 52 >> 2] + 210392 >> 2] | 0)) {
      __label__ = 89;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 89:
    var $352 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($9, 4);
    if ($352) {
      __label__ = 90;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 90:
    var $354 = __ZNK2js11TokenStream12currentTokenEv($9);
    if ((HEAP32[$354 + 24 >> 2] | 0) == 0) {
      __label__ = 92;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 91:
    var $359 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 172, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 96;
    break;
   case 92:
    var $362 = HEAP32[$320 >> 2] | 0;
    var $364 = HEAP32[$362 >> 2] | 256;
    HEAP32[$362 >> 2] = $364;
    var $365 = __ZN2js6Parser4exprEv($this);
    if (($365 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 93;
      break;
    }
   case 93:
    __ZN11JSParseNode5setOpE4JSOp($323, 163);
    var $370 = $365 + 12 | 0;
    var $371 = $322 + 12 | 0;
    var $st$5$0 = $370 | 0;
    var $372$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $370 + 4 | 0;
    var $372$1 = HEAP32[$st$5$1 >> 2];
    var $st$9$0 = $371 | 0;
    HEAP32[$st$9$0 >> 2] = $372$0;
    var $st$9$1 = $371 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $372$1;
    var $373 = $322 + 32 | 0;
    HEAP32[$373 >> 2] = $365;
    var $pn_0 = $323;
    __label__ = 95;
    break;
   case 94:
    var $375 = __ZN2js6Parser19expressionStatementEv($this);
    var $_0 = $375;
    __label__ = 96;
    break;
   case 95:
    var $pn_0;
    var $377 = __ZL22MatchOrInsertSemicolonP9JSContextPN2js11TokenStreamE($9);
    var $379 = ($377 | 0) != 0 ? $pn_0 : 0;
    var $_0 = $379;
    __label__ = 96;
    break;
   case 96:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser9statementEv["X"] = 1;

function __ZN2js6Parser26recognizeDirectivePrologueEP11JSParseNodePb($this, $pn, $isDirectivePrologueMember) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode21isStringExprStatementEv($pn);
    HEAP8[$isDirectivePrologueMember] = $1 & 1;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 2:
    var $5 = HEAPU32[$pn + 32 >> 2];
    var $6 = __ZNK11JSParseNode25isEscapeFreeStringLiteralEv($5);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 3:
    HEAP32[$pn + 40 >> 2] = 1;
    if ((HEAP32[$5 + 32 >> 2] | 0) == (HEAP32[HEAP32[HEAP32[$this + 12 >> 2] + 52 >> 2] + 210364 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this + 184 >> 2];
    var $21 = __ZNK2js11TokenStream23hasOctalCharacterEscapeEv($_idx_val);
    if ($21) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $23 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 232, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $25 = $this + 40 | 0;
    var $28 = HEAP32[$this + 980 >> 2] | 0;
    var $30 = HEAP32[$28 >> 2] | 262144;
    HEAP32[$28 >> 2] = $30;
    __ZN2js11TokenStream13setStrictModeEb($25, 1);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser16analyzeFunctionsEP13JSTreeContext($this, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $tc + 84 | 0;
    __ZN2js6Parser17cleanFunctionListEPP13JSFunctionBox($this, $1);
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js6Parser11markFunArgsEP13JSFunctionBox($this, $2);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = HEAP32[$1 >> 2];
    __ZN2js6Parser30markExtensibleScopeDescendantsEP13JSFunctionBoxb($7, 0);
    var $8 = HEAP32[$1 >> 2];
    var $9 = $tc | 0;
    __ZN2js6Parser16setFunctionKindsEP13JSFunctionBoxPj($8, $9);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK15JSCodeGenerator10sharpSlotsEv($this) {
  var $_idx_val = HEAP32[$this >> 2];
  var $1 = __ZNK15JSCodeGenerator9hasSharpsEv($_idx_val);
  var $2 = $1 ? 2 : 0;
  return $2;
}

function __ZN2js8Compiler13defineGlobalsEP9JSContextRNS_11GlobalScopeEP8JSScript($cx, $globalScope, $script) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 92;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $rval = __stackBase__;
    var $worklist = __stackBase__ + 8;
    var $1 = __stackBase__ + 88;
    var $3 = HEAPU32[$globalScope >> 2];
    var $4 = $cx;
    var $5 = $3;
    var $_idx9 = $globalScope + 16 | 0;
    var $_idx8 = $globalScope + 12 | 0;
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    var $_idx9_val = HEAP32[$_idx9 >> 2];
    var $7 = __ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE6lengthEv($_idx9_val);
    if ($i_0 >>> 0 < $7 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 3:
    var $_idx8_val = HEAP32[$_idx8 >> 2];
    var $10 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEEixEj($_idx8_val, $i_0);
    var $12 = HEAP32[$10 >> 2];
    if (($12 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = __ZL12ATOM_TO_JSIDP6JSAtom2903($12);
    var $17 = HEAP32[$10 + 4 >> 2];
    if (($17 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx6_val = HEAP32[$17 + 8 >> 2];
    var $20 = __ZNK13JSFunctionBox8functionEv($_idx6_val);
    var $21 = $20 | 0;
    __ZN2JS5Value9setObjectER8JSObject($rval, $21);
    __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiRKN2JS5ValueE($cx, $3, $15, $rval);
    __label__ = 7;
    break;
   case 6:
    __ZN2JS5Value12setUndefinedEv($rval);
    __label__ = 7;
    break;
   case 7:
    var $24 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($4, $5, $15, $rval, 10, 12, 5, 0, 0, 16);
    if (($24 | 0) == 0) {
      var $_1 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $28 = HEAP32[$24 + 24 >> 2];
    var $29 = $10 + 8 | 0;
    HEAP32[$29 >> 2] = $28;
    __label__ = 9;
    break;
   case 9:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 10:
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
    var $_010_val = HEAP32[$1 >> 2];
    __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEEC1ES3_($worklist, $_010_val);
    var $33 = __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE6appendIS2_EEbT_($worklist, $script);
    if ($33) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 27;
      break;
    }
   case 11:
    var $worklist_idx = $worklist + 8 | 0;
    var $worklist_idx11 = $worklist + 4 | 0;
    __label__ = 12;
    break;
   case 12:
    var $worklist_idx_val = HEAP32[$worklist_idx >> 2];
    var $34 = __ZNK2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE6lengthEv($worklist_idx_val);
    if (($34 | 0) == 0) {
      var $_0 = 1;
      __label__ = 27;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $worklist_idx11_val = HEAP32[$worklist_idx11 >> 2];
    var $37 = __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE4backEv($worklist_idx11_val, $worklist_idx_val);
    var $38 = HEAPU32[$37 >> 2];
    __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE7popBackEv($worklist);
    var $40 = HEAP8[$38 + 16 | 0];
    var $41 = __ZN8JSScript13isValidOffsetEh($40);
    if ($41) {
      __label__ = 14;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 14:
    var $_idx2_val = HEAP32[$38 + 4 >> 2];
    var $43 = __ZN8JSScript7objectsEv($_idx2_val, $40);
    var $49 = $43 + 4 | 0;
    var $50 = $43 | 0;
    var $51 = $38 + 37 | 0;
    var $i1_0 = (HEAPU8[$38 + 36 | 0] & 255) >>> 1 & 1 & 255;
    __label__ = 15;
    break;
   case 15:
    var $i1_0;
    if ($i1_0 >>> 0 < HEAPU32[$49 >> 2] >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 16:
    var $58 = HEAPU32[HEAP32[$50 >> 2] + ($i1_0 << 2) >> 2];
    var $_idx_val = HEAP32[$58 + 4 >> 2];
    var $59 = __ZNK8JSObject10isFunctionEv($_idx_val);
    if ($59) {
      __label__ = 17;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 17:
    var $_idx1_val = HEAP32[$58 + 24 >> 2];
    var $61 = __ZNK8JSObject18getFunctionPrivateEv($_idx1_val);
    var $62 = __ZNK10JSFunction6scriptEv($61);
    var $63 = HEAP8[$51];
    if (($63 & 8) << 24 >> 24 == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $67 = $63 | 16;
    HEAP8[$51] = $67;
    var $68 = $62 + 37 | 0;
    var $70 = HEAP8[$68] | 32;
    HEAP8[$68] = $70;
    __label__ = 19;
    break;
   case 19:
    var $73 = HEAP8[$62 + 20 | 0];
    var $74 = __ZN8JSScript13isValidOffsetEh($73);
    if ($74) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $77 = HEAP8[$62 + 16 | 0];
    var $78 = __ZN8JSScript13isValidOffsetEh($77);
    if ($78) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    var $80 = __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE6appendIS2_EEbT_($worklist, $62);
    if ($80) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 27;
      break;
    }
   case 22:
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 15;
    break;
   case 23:
    var $84 = HEAP8[$38 + 20 | 0];
    var $85 = __ZN8JSScript13isValidOffsetEh($84);
    if ($85) {
      __label__ = 24;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 24:
    var $_idx4_val = HEAP32[$38 + 4 >> 2];
    var $87 = __ZN8JSScript7globalsEv($_idx4_val, $84);
    var $89 = HEAP32[$87 + 4 >> 2];
    if (($89 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $91 = $87 | 0;
    var $i3_01 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i3_01;
    var $94 = HEAP32[$91 >> 2] + ($i3_01 << 3) + 4 | 0;
    var $95 = HEAP32[$94 >> 2];
    var $_idx7_val = HEAP32[$_idx8 >> 2];
    var $96 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEEixEj($_idx7_val, $95);
    var $98 = HEAP32[$96 + 8 >> 2];
    HEAP32[$94 >> 2] = $98;
    var $99 = $i3_01 + 1 | 0;
    if (($99 | 0) == ($89 | 0)) {
      __label__ = 12;
      break;
    } else {
      var $i3_01 = $99;
      __label__ = 26;
      break;
    }
   case 27:
    var $_0;
    __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEED1Ev($worklist);
    var $_1 = $_0;
    __label__ = 28;
    break;
   case 28:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Compiler13defineGlobalsEP9JSContextRNS_11GlobalScopeEP8JSScript["X"] = 1;

function __ZN2js11GlobalScopeD1Ev($this) {
  __ZN2js11GlobalScopeD2Ev($this);
  return;
}

function __ZN2js8CompilerD1Ev($this) {
  __ZN2js8CompilerD2Ev($this);
  return;
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEEixEj($this_0_1_val, $i) {
  var $1 = __ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE5beginEv($this_0_1_val);
  return $1 + $i * 12 | 0;
}

function __ZNK2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE6lengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE7popBackEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN8JSScript7globalsEv($this_0_1_val, $this_0_9_val) {
  return $this_0_1_val + ($this_0_9_val & 255) | 0;
}

function __ZN10JSFunction11setArgCountEt($this, $nargs) {
  HEAP16[$this + 56 >> 1] = $nargs;
  return;
}

function __ZN2js11TokenStream17mungeCurrentTokenENS_9TokenKindE($this, $newKind) {
  var $3 = $this + 4 + (HEAP32[$this + 132 >> 2] << 5) | 0;
  HEAP32[$3 >> 2] = $newKind;
  return;
}

function __ZL12ATOM_TO_JSIDP6JSAtom2903($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj2961($1);
  return $2;
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEEC1ES3_($this, $ap_01) {
  __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEEC2ES3_($this, $ap_01);
  return;
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE13growStorageByEj($this);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE4backEv($this_0_1_val, $this_0_2_val) {
  var $1 = __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val);
  return $1 - 4 | 0;
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __Z21CheckStrictAssignmentP9JSContextP13JSTreeContextP11JSParseNode($cx, $tc, $lhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $name = __stackBase__;
    var $1 = $tc;
    var $2 = __ZN13JSTreeContext16needStrictChecksEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 1;
      __label__ = 10;
      break;
    }
   case 2:
    var $4 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($lhs, 29);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 1;
      __label__ = 10;
      break;
    }
   case 3:
    var $8 = HEAP32[$lhs + 32 >> 2];
    var $10 = HEAP32[$cx + 52 >> 2];
    if (($8 | 0) == (HEAP32[$10 + 210212 >> 2] | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($8 | 0) == (HEAP32[$10 + 210176 >> 2] | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_1 = 1;
      __label__ = 10;
      break;
    }
   case 5:
    __ZN16JSAutoByteStringC1Ev($name);
    var $21 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $8, $name);
    if (($21 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $name_idx1_val = HEAP32[$name >> 2];
    __label__ = 8;
    break;
   case 7:
    var $26 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $name_idx2_val = HEAP32[$name >> 2];
    var $27 = __ZNK16JSAutoByteString3ptrEv($name_idx2_val);
    var $28 = __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($cx, $26, $1, $lhs, 236, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $27, tempInt));
    if ($28) {
      __label__ = 9;
      break;
    } else {
      var $name_idx1_val = $name_idx2_val;
      __label__ = 8;
      break;
    }
   case 8:
    var $name_idx1_val;
    __ZN16JSAutoByteStringD1Ev($name_idx1_val);
    var $_1 = 0;
    __label__ = 10;
    break;
   case 9:
    __ZN16JSAutoByteStringD1Ev($name_idx2_val);
    var $_1 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18CheckStrictBindingP9JSContextP13JSTreeContextP6JSAtomP11JSParseNode($cx, $tc, $atom, $pn) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $name = __stackBase__;
    var $1 = $tc;
    var $2 = __ZN13JSTreeContext16needStrictChecksEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 1;
      __label__ = 9;
      break;
    }
   case 2:
    var $5 = HEAP32[$cx + 52 >> 2];
    if ((HEAP32[$5 + 210212 >> 2] | 0) == ($atom | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$5 + 210176 >> 2] | 0) == ($atom | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = $atom | 0;
    var $17 = __ZNK12JSFlatString6charsZEv($16);
    var $_idx_val = HEAP32[$atom >> 2];
    var $18 = __ZNK8JSString6lengthEv($_idx_val);
    var $19 = __ZN2js11FindKeywordEPKtj($17, $18);
    if (($19 | 0) == 0) {
      var $_1 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN16JSAutoByteStringC1Ev($name);
    var $22 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $atom, $name);
    if (($22 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $_0 = 0;
    var $name_idx_val = HEAP32[$name >> 2];
    __label__ = 8;
    break;
   case 7:
    var $27 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $name_idx1_val = HEAP32[$name >> 2];
    var $28 = __ZNK16JSAutoByteString3ptrEv($name_idx1_val);
    var $29 = __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($cx, $27, $1, $pn, 237, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $28, tempInt));
    var $_0 = $29;
    var $name_idx_val = $name_idx1_val;
    __label__ = 8;
    break;
   case 8:
    var $name_idx_val;
    var $_0;
    __ZN16JSAutoByteStringD1Ev($name_idx_val);
    var $_1 = $_0;
    __label__ = 9;
    break;
   case 9:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser12functionBodyEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmtInfo = __stackBase__;
    var $1 = $this + 980 | 0;
    var $3 = HEAP32[$1 >> 2];
    var $4 = $stmtInfo;
    _js_PushStatement($3, $4, 4, -1);
    HEAP16[$stmtInfo + 2 >> 1] = 2;
    var $7 = HEAP32[$1 >> 2] | 0;
    var $8 = HEAP32[$7 >> 2];
    var $9 = $8 & -13;
    HEAP32[$7 >> 2] = $9;
    var $10 = $this + 40 | 0;
    var $11 = __ZNK2js11TokenStream12currentTokenEv($10);
    if ((HEAP32[$11 >> 2] | 0) == 25) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = __ZN2js6Parser10statementsEv($this);
    var $pn_0 = $16;
    __label__ = 8;
    break;
   case 3:
    var $_idx1_val = HEAP32[HEAP32[$1 >> 2] + 48 >> 2];
    var $19 = __ZN2js9UnaryNode6createEP13JSTreeContext($_idx1_val);
    var $20 = $19 | 0;
    if (($19 | 0) == 0) {
      var $pn_0 = $20;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $23 = __ZN2js6Parser10assignExprEv($this);
    var $24 = $19 + 32 | 0;
    HEAP32[$24 >> 2] = $23;
    if (($23 | 0) == 0) {
      var $pn_1 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $27 = HEAP32[$1 >> 2];
    if ((HEAP32[$27 >> 2] & 512 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $34 = HEAP32[$this + 12 >> 2];
    var $35 = __ZL15ReportBadReturnP9JSContextP13JSTreeContextP11JSParseNodejjj($34, $27, $20, 0, 208, 209);
    var $pn_1 = 0;
    __label__ = 13;
    break;
   case 7:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($20, 48);
    __ZN11JSParseNode5setOpE4JSOp($20, 5);
    var $40 = HEAP32[$24 >> 2] + 12 | 0;
    var $41 = $19 + 12 | 0;
    var $42$0 = HEAP32[$40 >> 2];
    var $42$1 = HEAP32[$40 + 4 >> 2];
    var $st$11$0 = $41 | 0;
    HEAP32[$st$11$0 >> 2] = $42$0;
    var $st$11$1 = $41 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $42$1;
    var $pn_0 = $20;
    __label__ = 8;
    break;
   case 8:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      var $pn_1 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $47 = HEAP32[$1 >> 2];
    _js_PopStatement($47);
    var $49 = HEAP32[$this + 12 >> 2];
    var $_idx_val = HEAP32[$49 + 32 >> 2];
    var $50 = __ZNK9JSContext15hasStrictOptionEv($_idx_val);
    if ($50) {
      __label__ = 10;
      break;
    } else {
      var $pn_1 = $pn_0;
      __label__ = 13;
      break;
    }
   case 10:
    var $52 = HEAP32[$1 >> 2];
    if ((HEAP32[$52 >> 2] & 4 | 0) == 0) {
      var $pn_1 = $pn_0;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $58 = __ZL16CheckFinalReturnP9JSContextP13JSTreeContextP11JSParseNode($49, $52, $pn_0);
    if (($58 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $pn_1 = $pn_0;
      __label__ = 13;
      break;
    }
   case 12:
    var $pn_1 = 0;
    __label__ = 13;
    break;
   case 13:
    var $pn_1;
    var $62 = HEAP32[$1 >> 2] | 0;
    var $65 = HEAP32[$62 >> 2] & 629442528 | $8;
    HEAP32[$62 >> 2] = $65;
    STACKTOP = __stackBase__;
    return $pn_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser12functionBodyEv["X"] = 1;

function __ZN2js9UnaryNode6createEP13JSTreeContext($tc_0_11_val) {
  var $1 = __ZN11JSParseNode6createE16JSParseNodeArityP13JSTreeContext(1, $tc_0_11_val);
  return $1;
}

function __ZN2js6Parser10assignExprEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAPU32[$this + 12 >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$3 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($3);
    var $_0 = 0;
    __label__ = 15;
    break;
   case 3:
    var $9 = $this + 40 | 0;
    var $10 = __ZN2js11TokenStream10matchTokenENS_9TokenKindEj($9, 77, 8);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $12 = __ZN2js6Parser13returnOrYieldEb($this, 1);
    var $_0 = $12;
    __label__ = 15;
    break;
   case 5:
    var $14 = __ZN2js6Parser9condExpr1Ev($this);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($9, 4);
    if ($17) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2js11TokenStream10ungetTokenEv($9);
    var $_0 = $14;
    __label__ = 15;
    break;
   case 8:
    var $20 = __ZNK2js11TokenStream12currentTokenEv($9);
    var $22 = HEAPU32[$20 + 24 >> 2];
    var $23 = __ZN2js6Parser19setAssignmentLhsOpsEP11JSParseNode4JSOp($this, $14, $22);
    if ($23) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 9:
    var $25 = __ZN2js6Parser10assignExprEv($this);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $28 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($14, 29);
    if ($28) {
      __label__ = 11;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 11:
    var $30 = __ZNK11JSParseNode6isUsedEv($14);
    if ($30) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $33 = HEAP32[$14 + 36 >> 2];
    var $34 = $33;
    var $35 = __ZNK11JSParseNode10isAssignedEv($34);
    if ($35) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $39 = $25 + 12 | 0;
    var $40 = $33 + 12 | 0;
    var $41$0 = HEAP32[$39 >> 2];
    var $41$1 = HEAP32[$39 + 4 >> 2];
    var $st$8$0 = $40 | 0;
    HEAP32[$st$8$0 >> 2] = $41$0;
    var $st$8$1 = $40 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $41$1;
    __label__ = 14;
    break;
   case 14:
    var $44 = HEAP32[$this + 980 >> 2];
    var $45 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(4, $22, $14, $25, $44);
    var $_0 = $45;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser10assignExprEv["X"] = 1;

function __ZL15ReportBadReturnP9JSContextP13JSTreeContextP11JSParseNodejjj($cx, $tc, $pn, $flags, $errnum, $anonerrnum) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $name = __stackBase__;
    __ZN16JSAutoByteStringC1Ev($name);
    var $_idx_val = HEAP32[$tc + 60 >> 2];
    var $2 = __ZNK13JSTreeContext3funEv($_idx_val);
    var $4 = HEAP32[$2 + 72 >> 2];
    if (($4 | 0) == 0) {
      var $_01 = $anonerrnum;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $4, $name);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_01 = $errnum;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 0;
    var $name_idx_val = HEAP32[$name >> 2];
    __label__ = 5;
    break;
   case 4:
    var $_01;
    var $12 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $name_idx1_val = HEAPU32[$name >> 2];
    var $13 = __ZNK16JSAutoByteString3ptrEv($name_idx1_val);
    var $14 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($12, $pn, $flags, $_01, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $13, tempInt));
    var $_0 = $14 & 1;
    var $name_idx_val = $name_idx1_val;
    __label__ = 5;
    break;
   case 5:
    var $name_idx_val;
    var $_0;
    __ZN16JSAutoByteStringD1Ev($name_idx_val);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16CheckFinalReturnP9JSContextP13JSTreeContextP11JSParseNode($cx, $tc, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL14HasFinalReturnP11JSParseNode($pn);
    if (($1 | 0) == 1) {
      var $7 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZL15ReportBadReturnP9JSContextP13JSTreeContextP11JSParseNodejjj($cx, $tc, $pn, 5, 110, 157);
    var $7 = ($4 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Compiler19compileFunctionBodyEP9JSContextP10JSFunctionP12JSPrincipalsPNS_8BindingsEPKtjPKcj9JSVersion($cx, $fun, $principals, $bindings, $chars, $length, $filename, $lineno, $version) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 1640;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $compiler = __stackBase__;
    var $funcg = __stackBase__ + 996;
    var $names = __stackBase__ + 1612;
    var $1 = __stackBase__ + 1636;
    __ZN2js8CompilerC2EP9JSContextP12JSPrincipalsPNS_10StackFrameE($compiler, $cx, $principals, 0);
    var $2 = __ZN2js8Compiler4initEPKtjPKcj9JSVersion($compiler, $chars, $length, $filename, $lineno, $version);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 25;
      break;
    }
   case 2:
    var $4 = $compiler | 0;
    var $5 = $compiler + 40 | 0;
    var $_idx2_val = HEAP32[$compiler + 180 >> 2];
    var $6 = __ZNK2js11TokenStream9getLinenoEv($_idx2_val);
    var $7 = $funcg;
    var $8 = $compiler;
    __ZN15JSCodeGeneratorC2EPN2js6ParserEj($7, $8, $6);
    var $9 = __ZN15JSCodeGenerator4initEP9JSContextN13JSTreeContext12InitBehaviorE($7, $cx, 0);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 3:
    var $11 = $funcg | 0;
    var $12 = $funcg | 0;
    var $14 = HEAP32[$12 >> 2] | 2;
    HEAP32[$12 >> 2] = $14;
    var $15 = $funcg;
    __ZN13JSTreeContext11setFunctionEP10JSFunction($15, $fun);
    var $16 = $funcg + 92 | 0;
    __ZN2js8Bindings8transferEP9JSContextPS0_($16, $bindings);
    var $_idx_val = HEAP16[$funcg + 96 >> 1];
    var $17 = __ZNK2js8Bindings9countArgsEv($_idx_val);
    __ZN10JSFunction11setArgCountEt($fun, $17);
    var $18 = $funcg + 4 | 0;
    var $19 = __ZL15GenerateBlockIdP13JSTreeContextRj($11, $18);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 4:
    __ZN2js11TokenStream17mungeCurrentTokenENS_9TokenKindE($5, 29);
    var $_idx3_val = HEAP32[$funcg + 48 >> 2];
    var $21 = __ZN2js12FunctionNode6createEP13JSTreeContext($_idx3_val);
    var $22 = $21 | 0;
    if (($21 | 0) == 0) {
      var $fn_1 = $22;
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $25 = $21 + 36 | 0;
    HEAP32[$25 >> 2] = 0;
    var $27 = $21 + 40 | 0;
    __ZN2js11UpvarCookie8makeFreeEv($27);
    var $29 = HEAPU16[$fun + 56 >> 1];
    var $30 = $29 & 65535;
    if ($29 << 16 >> 16 == 0) {
      var $fn_1 = $22;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
    var $_01_val = HEAP32[$1 >> 2];
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEC1ES3_($names, $_01_val);
    var $33 = $16;
    var $34 = $names;
    var $35 = __ZN2js8Bindings17getLocalNameArrayEP9JSContextPNS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEE($33, $34);
    if ($35) {
      __label__ = 7;
      break;
    } else {
      var $fn_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $names_idx = $names + 4 | 0;
    var $i_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $i_0;
    if ($i_0 >>> 0 < $30 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $fn_0 = $22;
      __label__ = 11;
      break;
    }
   case 9:
    var $names_idx_val = HEAP32[$names_idx >> 2];
    var $38 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEixEj($names_idx_val, $i_0);
    var $39 = HEAP32[$38 >> 2];
    var $40 = __ZL9DefineArgP11JSParseNodeP6JSAtomjP13JSTreeContext($22, $39, $i_0, $11);
    if ($40) {
      __label__ = 10;
      break;
    } else {
      var $fn_0 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 8;
    break;
   case 11:
    var $fn_0;
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev($names);
    var $fn_1 = $fn_0;
    __label__ = 12;
    break;
   case 12:
    var $fn_1;
    __ZN2js11TokenStream17mungeCurrentTokenENS_9TokenKindE($5, 25);
    if (($fn_1 | 0) == 0) {
      var $pn_1 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $46 = __ZN2js6Parser12functionBodyEv($4);
    if (($46 | 0) == 0) {
      var $pn_1 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $49 = __ZL21CheckStrictParametersP9JSContextP13JSTreeContext($cx, $11);
    if ($49) {
      __label__ = 15;
      break;
    } else {
      var $pn_1 = 0;
      __label__ = 23;
      break;
    }
   case 15:
    var $51 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($5, 0);
    if ($51) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $53 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($4, 0, 0, 133, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $pn_1 = 0;
    __label__ = 23;
    break;
   case 17:
    var $55 = _js_FoldConstants($cx, $46, $11, 0);
    if (($55 | 0) == 0) {
      var $pn_1 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $58 = __ZN2js6Parser16analyzeFunctionsEP13JSTreeContext($4, $11);
    if ($58) {
      __label__ = 19;
      break;
    } else {
      var $pn_1 = 0;
      __label__ = 23;
      break;
    }
   case 19:
    var $60 = $fn_1 + 36 | 0;
    var $61 = HEAP32[$60 >> 2];
    if (($61 | 0) == 0) {
      var $pn_0 = $46;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $64 = $61;
    __ZN11JSParseNode6appendEPS_($64, $46);
    var $68 = HEAP32[$60 >> 2] + 4 | 0;
    var $69 = $46 + 4 | 0;
    HEAP32[$68 >> 2] = HEAP32[$69 >> 2];
    HEAP32[$68 + 4 >> 2] = HEAP32[$69 + 4 >> 2];
    HEAP32[$68 + 8 >> 2] = HEAP32[$69 + 8 >> 2];
    HEAP32[$68 + 12 >> 2] = HEAP32[$69 + 12 >> 2];
    var $pn_0 = HEAP32[$60 >> 2];
    __label__ = 21;
    break;
   case 21:
    var $pn_0;
    var $73 = _js_EmitFunctionScript($cx, $7, $pn_0);
    if (($73 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      var $pn_1 = $pn_0;
      __label__ = 23;
      break;
    }
   case 22:
    var $pn_1 = 0;
    __label__ = 23;
    break;
   case 23:
    var $pn_1;
    var $_0 = ($pn_1 | 0) != 0;
    __label__ = 24;
    break;
   case 24:
    var $_0;
    __ZN15JSCodeGeneratorD2Ev($7);
    var $_1 = $_0;
    __label__ = 25;
    break;
   case 25:
    var $_1;
    __ZN2js8CompilerD1Ev($compiler);
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Compiler19compileFunctionBodyEP9JSContextP10JSFunctionP12JSPrincipalsPNS_8BindingsEPKtjPKcj9JSVersion["X"] = 1;

function __ZN2js12FunctionNode6createEP13JSTreeContext($tc_0_11_val) {
  var $1 = __ZN11JSParseNode6createE16JSParseNodeArityP13JSTreeContext(4, $tc_0_11_val);
  return $1;
}

function __ZL9DefineArgP11JSParseNodeP6JSAtomjP13JSTreeContext($pn, $atom, $i, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $tc + 48 | 0;
    if ((HEAP32[HEAP32[HEAP32[HEAP32[$1 >> 2] + 12 >> 2] + 52 >> 2] + 210176 >> 2] | 0) == ($atom | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $12 = $tc | 0;
    var $14 = HEAP32[$12 >> 2] | 64;
    HEAP32[$12 >> 2] = $14;
    __label__ = 3;
    break;
   case 3:
    var $16 = __ZN2js8NameNode6createEP6JSAtomP13JSTreeContext($atom, $tc);
    var $17 = $16 | 0;
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $21 = $16 + 44 | 0;
    var $23 = HEAP32[$21 >> 2] | 4;
    HEAP32[$21 >> 2] = $23;
    var $24 = __ZL6DefineP11JSParseNodeP6JSAtomP13JSTreeContextb($17, $atom, $tc, 0);
    if ($24) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $26 = $pn + 36 | 0;
    var $27 = HEAP32[$26 >> 2];
    var $28 = $27;
    if (($27 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $argsbody_0 = $28;
      __label__ = 8;
      break;
    }
   case 6:
    var $tc_idx_val = HEAP32[$1 >> 2];
    var $31 = __ZN2js8ListNode6createEP13JSTreeContext($tc_idx_val);
    var $32 = $31 | 0;
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($32, 84);
    __ZN11JSParseNode5setOpE4JSOp($32, 0);
    __ZN11JSParseNode9makeEmptyEv($32);
    var $_c = $31;
    HEAP32[$26 >> 2] = $_c;
    var $argsbody_0 = $32;
    __label__ = 8;
    break;
   case 8:
    var $argsbody_0;
    __ZN11JSParseNode6appendEPS_($argsbody_0, $17);
    __ZN11JSParseNode5setOpE4JSOp($17, 84);
    var $37 = $16 + 40 | 0;
    var $40 = HEAP32[$tc + 76 >> 2] & 65535;
    var $41 = $i & 65535;
    __ZN2js11UpvarCookie3setEtt($37, $40, $41);
    var $43 = HEAP32[$21 >> 2] | 512;
    HEAP32[$21 >> 2] = $43;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9DefineArgP11JSParseNodeP6JSAtomjP13JSTreeContext["X"] = 1;

function __ZL21CheckStrictParametersP9JSContextP13JSTreeContext($cx, $tc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $parameters = __stackBase__;
    var $1 = __stackBase__ + 28;
    var $r = __stackBase__ + 32;
    var $name = __stackBase__ + 40;
    var $p = __stackBase__ + 44;
    var $2 = __stackBase__ + 52;
    var $3 = __stackBase__ + 60;
    var $4 = $tc;
    var $5 = __ZN13JSTreeContext16needStrictChecksEv($4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 1;
      __label__ = 19;
      break;
    }
   case 2:
    var $7 = $tc + 92 | 0;
    var $_idx3 = $tc + 96 | 0;
    var $_idx3_val = HEAP16[$_idx3 >> 1];
    var $8 = __ZNK2js8Bindings9countArgsEv($_idx3_val);
    if ($8 << 16 >> 16 == 0) {
      var $_1 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAP32[$cx + 52 >> 2];
    var $15 = HEAP32[$12 + 210176 >> 2] | 0;
    var $18 = HEAP32[$12 + 210212 >> 2] | 0;
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
    var $_05_val = HEAP32[$1 >> 2];
    __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_($parameters, $_05_val);
    var $_idx2_val = HEAP16[$_idx3 >> 1];
    var $19 = __ZNK2js8Bindings9countArgsEv($_idx2_val);
    var $20 = $19 & 65535;
    var $21 = __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($parameters, $20);
    if ($21) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 4:
    var $_idx6_val = HEAP32[$7 >> 2];
    var $_idx7_val = HEAP16[$tc + 100 >> 1];
    var $24 = __ZNK2js8Bindings12lastVariableEv($_idx6_val, $_idx7_val);
    var $25 = $24;
    __ZN2js5Shape5RangeC1EPKS0_($r, $25);
    var $26 = $2 | 0;
    var $_idx = $r;
    var $_idx4 = $tc | 0;
    var $_idx8 = $p | 0;
    __label__ = 5;
    break;
   case 5:
    var $_idx_val = HEAP32[$_idx >> 2];
    var $_idx_val_idx_val = HEAP32[$_idx_val + 32 >> 2];
    var $28 = __ZNK2js5Shape5Range5emptyEv($_idx_val_idx_val);
    if ($28) {
      var $_0 = 1;
      __label__ = 18;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $30 = $_idx_val;
    var $31 = __ZNK2js5Shape5Range5frontEv($30);
    var $33 = HEAP32[$31 + 12 >> 2];
    var $34 = __ZL12JSID_IS_ATOMi2955($33);
    if (($34 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $37 = __ZL12JSID_TO_ATOMi2949($33);
    HEAP32[$name >> 2] = $37;
    if (($37 | 0) == ($15 | 0) | ($37 | 0) == ($18 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $41 = __ZL18ReportBadParameterP9JSContextP13JSTreeContextP6JSAtomj($cx, $tc, $37, 237);
    if ($41) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 9:
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $43 = __ZNK13JSTreeContext12inStrictModeEv($_idx4_val);
    if ($43) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $45 = $37 | 0;
    var $46 = __ZNK12JSFlatString6charsZEv($45);
    var $_idx1_val = HEAP32[$37 >> 2];
    var $47 = __ZNK8JSString6lengthEv($_idx1_val);
    var $48 = __ZN2js11FindKeywordEPKtj($46, $47);
    if (($48 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $51 = __ZL18ReportBadParameterP9JSContextP13JSTreeContextP6JSAtomj($cx, $tc, $37, 132);
    var $_0 = 0;
    __label__ = 18;
    break;
   case 12:
    __ZNK2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($p, $parameters, $name);
    var $_idx8_val = HEAP32[$_idx8 >> 2];
    var $_idx8_val_idx_val = HEAP32[$_idx8_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($2, $_idx8_val_idx_val);
    if ((HEAP32[$26 >> 2] | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $56 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($_idx8_val);
    var $57 = $56 + 4 | 0;
    if ((HEAP8[$57] & 1) << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $62 = HEAP32[$name >> 2];
    var $63 = __ZL18ReportBadParameterP9JSContextP13JSTreeContextP6JSAtomj($cx, $tc, $62, 111);
    if ($63) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 15:
    HEAP8[$57] = 1;
    __label__ = 17;
    break;
   case 16:
    HEAP8[$3] = 0;
    var $66 = __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_bEENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKb($parameters, $p, $name, $3);
    if ($66) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 17:
    __ZN2js5Shape5Range8popFrontEv($r);
    __label__ = 5;
    break;
   case 18:
    var $_0;
    __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev($parameters);
    var $_1 = $_0;
    __label__ = 19;
    break;
   case 19:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL21CheckStrictParametersP9JSContextP13JSTreeContext["X"] = 1;

function __ZN2js6Parser11newFunctionEP13JSTreeContextP6JSAtomNS_18FunctionSyntaxKindE($this, $tc, $atom, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_0 = $tc;
    __label__ = 2;
    break;
   case 2:
    var $_0;
    var $3 = HEAP32[$_0 + 72 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $3;
      __label__ = 2;
      break;
    }
   case 3:
    var $_idx = $_0 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $6 = __ZNK13JSTreeContext10inFunctionEv($_idx_val);
    if ($6) {
      var $11 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZNK13JSTreeContext10scopeChainEv($_0);
    var $11 = $9;
    __label__ = 5;
    break;
   case 5:
    var $11;
    var $13 = HEAP32[$this + 12 >> 2];
    var $15 = ($kind | 0) == 0 ? 16392 : 16384;
    var $16 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($13, 0, 0, 0, $15, $11, $atom);
    if (($16 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx1_val = HEAP32[$_idx >> 2];
    var $19 = __ZNK13JSTreeContext12compileAndGoEv($_idx1_val);
    if ($19) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $21 = $16 | 0;
    __ZN8JSObject11clearParentEv($21);
    __ZN8JSObject9clearTypeEv($21);
    __label__ = 8;
    break;
   case 8:
    return $16;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Entry5valueEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZN18JSFunctionBoxQueue4pullEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == (HEAP32[$this + 4 >> 2] | 0)) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $2 + 1 | 0;
    HEAP32[$1 >> 2] = $7;
    var $14 = HEAP32[HEAP32[$this >> 2] + ((HEAP32[$this + 12 >> 2] & $2) << 2) >> 2];
    var $16 = $14 + 56 | 0;
    var $18 = HEAP32[$16 >> 2] & -2;
    HEAP32[$16 >> 2] = $18;
    var $_0 = $14;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11JSParseNode9setFunArgEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this >> 2] & 1073741824 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$this + 36 >> 2] + 44 | 0;
    var $_c = HEAP32[$8 >> 2] | 256;
    HEAP32[$8 >> 2] = $_c;
    __label__ = 3;
    break;
   case 3:
    var $14 = $this + 44 | 0;
    var $16 = HEAP32[$14 >> 2] | 256;
    HEAP32[$14 >> 2] = $16;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18JSFunctionBoxQueue4pushEP13JSFunctionBox($this, $funbox) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $funbox + 56 | 0;
    if ((HEAP32[$2 >> 2] & 1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $this + 4 | 0;
    var $8 = HEAP32[$7 >> 2];
    var $9 = $8 + 1 | 0;
    HEAP32[$7 >> 2] = $9;
    var $15 = HEAP32[$this >> 2] + ((HEAP32[$this + 12 >> 2] & $8) << 2) | 0;
    HEAP32[$15 >> 2] = $funbox;
    var $17 = HEAP32[$2 >> 2] | 1;
    HEAP32[$2 >> 2] = $17;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSFunction7setKindEt($this, $k) {
  var $1 = $this + 58 | 0;
  var $4 = HEAP16[$1 >> 1] & 16383 | $k;
  HEAP16[$1 >> 1] = $4;
  return;
}

function __ZN2js6Parser11markFunArgsEP13JSFunctionBox($this, $funbox) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $queue = __stackBase__;
    var $r = __stackBase__ + 16;
    var $1 = __stackBase__ + 36;
    __ZN18JSFunctionBoxQueueC1Ev($queue);
    var $3 = HEAP32[$this + 972 >> 2];
    var $4 = __ZN18JSFunctionBoxQueue4initEj($queue, $3);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 12 >> 2];
    __Z20js_ReportOutOfMemoryP9JSContext($7);
    var $_0 = 0;
    __label__ = 21;
    break;
   case 3:
    var $9 = __ZL11FindFunArgsP13JSFunctionBoxiP18JSFunctionBoxQueue($funbox, -1, $queue);
    var $10 = __ZN18JSFunctionBoxQueue4pullEv($queue);
    if (($10 | 0) == 0) {
      var $_0 = 1;
      __label__ = 21;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx2 = $1 + 4 | 0;
    var $12 = $10;
    __label__ = 5;
    break;
   case 5:
    var $12;
    var $16 = HEAP32[HEAP32[$12 + 24 >> 2] + 36 >> 2];
    var $17 = $16;
    var $18 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($17, 85);
    if ($18) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = __ZN18JSFunctionBoxQueue4pullEv($queue);
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 21;
      break;
    } else {
      var $12 = $19;
      __label__ = 5;
      break;
    }
   case 7:
    var $24 = HEAP32[$16 + 32 >> 2];
    var $25 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($24);
    __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3allEv($r, $25);
    var $26 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv($r);
    if ($26) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $28 = $12 + 56 | 0;
    __label__ = 9;
    break;
   case 9:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5frontEv($1, $r);
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $30 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Entry5valueEv($_idx2_val);
    var $31 = HEAP32[$30 >> 2];
    var $32 = __ZN12JSDefinition7resolveEv($31);
    var $33 = __ZNK12JSDefinition9isFreeVarEv($32);
    if ($33) {
      __label__ = 20;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $35 = $32 | 0;
    var $36 = __ZNK11JSParseNode8isFunArgEv($35);
    if ($36) {
      __label__ = 20;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $38 = __ZN12JSDefinition4kindEv($32);
    if (($38 | 0) == 3) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $41 = __ZNK11JSParseNode4isOpE4JSOp($35, 131);
    if ($41) {
      __label__ = 13;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 13:
    __ZN11JSParseNode9setFunArgEv($35);
    var $43 = __ZNK11JSParseNode4isOpE4JSOp($35, 131);
    if ($43) {
      __label__ = 14;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 14:
    var $_idx1_val = HEAP32[$32 + 40 >> 2];
    var $46 = __ZNK2js11UpvarCookie5levelEv($_idx1_val);
    var $47 = $46 & 65535;
    var $51 = (HEAPU32[$28 >> 2] >>> 2 & 16383) + 1 | 0;
    if (($51 | 0) == ($47 | 0)) {
      var $afunbox_0_lcssa = $12;
      __label__ = 16;
      break;
    } else {
      var $afunbox_01 = $12;
      var $staticLevel_02 = $51;
      __label__ = 15;
      break;
    }
   case 15:
    var $staticLevel_02;
    var $afunbox_01;
    var $54 = HEAP32[$afunbox_01 + 36 >> 2];
    var $55 = $staticLevel_02 - 1 | 0;
    if (($55 | 0) == ($47 | 0)) {
      var $afunbox_0_lcssa = $54;
      __label__ = 16;
      break;
    } else {
      var $afunbox_01 = $54;
      var $staticLevel_02 = $55;
      __label__ = 15;
      break;
    }
   case 16:
    var $afunbox_0_lcssa;
    var $58 = HEAP32[$afunbox_0_lcssa + 24 >> 2];
    __ZN11JSParseNode9setFunArgEv($58);
    var $afunbox_1 = $afunbox_0_lcssa;
    __label__ = 18;
    break;
   case 17:
    var $afunbox_1 = HEAP32[$32 + 32 >> 2];
    __label__ = 18;
    break;
   case 18:
    var $afunbox_1;
    __ZN18JSFunctionBoxQueue4pushEP13JSFunctionBox($queue, $afunbox_1);
    var $65 = HEAPU32[$afunbox_1 + 32 >> 2];
    if (($65 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $72 = HEAPU32[$afunbox_1 + 56 >> 2] >>> 2 & 16383;
    var $73 = __ZL11FindFunArgsP13JSFunctionBoxiP18JSFunctionBoxQueue($65, $72, $queue);
    __label__ = 20;
    break;
   case 20:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range8popFrontEv($r);
    var $75 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv($r);
    if ($75) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 21:
    var $_0;
    var $queue_idx_val = HEAP32[$queue >> 2];
    __ZN18JSFunctionBoxQueueD1Ev($queue_idx_val);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser11markFunArgsEP13JSFunctionBox["X"] = 1;

function __ZN2js6Parser30markExtensibleScopeDescendantsEP13JSFunctionBoxb($funbox, $hasExtensibleParent) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($funbox | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $_01 = $funbox;
      __label__ = 2;
      break;
    }
   case 2:
    var $_01;
    if ($hasExtensibleParent) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js8Bindings20setExtensibleParentsEv($_01 + 44 | 0);
    __label__ = 4;
    break;
   case 4:
    var $6 = HEAP32[$_01 + 32 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ($hasExtensibleParent) {
      var $12 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_01_idx_val = HEAP32[$_01 + 60 >> 2];
    var $10 = __ZNK13JSFunctionBox17scopeIsExtensibleEv($_01_idx_val);
    var $12 = $10;
    __label__ = 7;
    break;
   case 7:
    var $12;
    __ZN2js6Parser30markExtensibleScopeDescendantsEP13JSFunctionBoxb($6, $12);
    __label__ = 8;
    break;
   case 8:
    var $15 = HEAP32[$_01 + 28 >> 2];
    if (($15 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $_01 = $15;
      __label__ = 2;
      break;
    }
   case 9:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser16setFunctionKindsEP13JSFunctionBoxPj($funbox, $tcflags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = __stackBase__ + 20;
    var $r2 = __stackBase__ + 28;
    var $2 = __stackBase__ + 48;
    if (($funbox | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx4 = $1 + 4 | 0;
    var $_idx3 = $2 + 4 | 0;
    var $_06 = $funbox;
    __label__ = 3;
    break;
   case 3:
    var $_06;
    var $5 = HEAP32[$_06 + 24 >> 2];
    var $7 = HEAP32[$5 + 36 >> 2];
    var $8 = $7;
    var $10 = HEAP32[$_06 + 32 >> 2];
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6Parser16setFunctionKindsEP13JSFunctionBoxPj($10, $tcflags);
    __ZL18ConsiderUnbrandingP13JSFunctionBox($_06);
    __label__ = 5;
    break;
   case 5:
    var $_06_idx_val = HEAP32[$_06 + 8 >> 2];
    var $14 = __ZNK13JSFunctionBox8functionEv($_06_idx_val);
    if ((HEAP32[$_06 + 60 >> 2] & 256 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 6:
    var $20 = __ZNK13JSFunctionBox17inAnyDynamicScopeEv($_06);
    if ($20) {
      __label__ = 19;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($8, 85);
    if ($22) {
      __label__ = 8;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 8:
    var $26 = HEAP32[$7 + 32 >> 2];
    var $27 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($26);
    __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3allEv($r, $27);
    var $hasUpvars_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $hasUpvars_0;
    var $29 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv($r);
    if ($29) {
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5frontEv($1, $r);
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $31 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Entry5valueEv($_idx4_val);
    var $32 = HEAP32[$31 >> 2];
    var $33 = __ZN12JSDefinition7resolveEv($32);
    var $34 = __ZNK12JSDefinition9isFreeVarEv($33);
    if ($34) {
      var $hasUpvars_1 = $hasUpvars_0;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $36 = HEAP32[$tcflags >> 2];
    var $37 = __ZL15CanFlattenUpvarP12JSDefinitionP13JSFunctionBoxj($33, $_06, $36);
    if ($37) {
      var $hasUpvars_1 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 12:
    var $hasUpvars_1;
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range8popFrontEv($r);
    var $hasUpvars_0 = $hasUpvars_1;
    __label__ = 9;
    break;
   case 13:
    if (($hasUpvars_0 & 1) << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    __ZN10JSFunction7setKindEt($14, -16384);
    __label__ = 19;
    break;
   case 15:
    __ZN10JSFunction7setKindEt($14, -32768);
    var $43 = __ZNK11JSParseNode5getOpEv($5);
    if (($43 | 0) == 127) {
      __label__ = 16;
      break;
    } else if (($43 | 0) == 140) {
      __label__ = 17;
      break;
    } else if (($43 | 0) == 130) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 16:
    __ZN11JSParseNode5setOpE4JSOp($5, 222);
    __label__ = 19;
    break;
   case 17:
    __ZN11JSParseNode5setOpE4JSOp($5, 223);
    __label__ = 19;
    break;
   case 18:
    __ZN11JSParseNode5setOpE4JSOp($5, 224);
    __label__ = 19;
    break;
   case 19:
    var $_idx_val = HEAP16[$14 + 58 >> 1];
    var $47 = __ZNK10JSFunction4kindEv($_idx_val);
    if ($47 << 16 >> 16 == 16384) {
      __label__ = 20;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 20:
    var $50 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($8, 85);
    if ($50) {
      __label__ = 21;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 21:
    var $54 = HEAP32[$7 + 32 >> 2];
    var $55 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($54);
    __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3allEv($r2, $55);
    var $56 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv($r2);
    if ($56) {
      __label__ = 25;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5frontEv($2, $r2);
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $57 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Entry5valueEv($_idx3_val);
    var $58 = HEAP32[$57 >> 2];
    var $59 = __ZN12JSDefinition7resolveEv($58);
    var $60 = __ZNK12JSDefinition9isFreeVarEv($59);
    if ($60) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    __ZL16FlagHeavyweightsP12JSDefinitionP13JSFunctionBoxPj($59, $_06, $tcflags);
    __label__ = 24;
    break;
   case 24:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range8popFrontEv($r2);
    var $63 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv($r2);
    if ($63) {
      __label__ = 25;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 25:
    var $64 = __ZNK13JSFunctionBox8joinableEv($_06);
    if ($64) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    __ZN10JSFunction11setJoinableEv($14);
    __label__ = 27;
    break;
   case 27:
    var $68 = HEAP32[$_06 + 28 >> 2];
    if (($68 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      var $_06 = $68;
      __label__ = 3;
      break;
    }
   case 28:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser16setFunctionKindsEP13JSFunctionBoxPj["X"] = 1;

function __ZN18JSFunctionBoxQueueC1Ev($this) {
  __ZN18JSFunctionBoxQueueC2Ev($this);
  return;
}

function __ZN18JSFunctionBoxQueue4initEj($this, $count) {
  var $1 = _JS_CeilingLog2($count);
  var $3 = (1 << $1) - 1 | 0;
  HEAP32[$this + 12 >> 2] = $3;
  var $5 = __ZN18JSFunctionBoxQueue6lengthEv($3);
  var $6 = $5 << 6;
  var $7 = __ZN2js11OffTheBooks7malloc_Ej($6);
  HEAP32[$this >> 2] = $7;
  return ($7 | 0) != 0;
}

function __ZL11FindFunArgsP13JSFunctionBoxiP18JSFunctionBoxQueue($funbox, $level, $queue) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = __stackBase__ + 20;
    var $_idx1 = $1 + 4 | 0;
    var $_0 = $funbox;
    var $allskipmin_0 = 16383;
    __label__ = 2;
    break;
   case 2:
    var $allskipmin_0;
    var $_0;
    var $4 = HEAPU32[$_0 + 24 >> 2];
    var $_0_idx_val = HEAP32[$_0 + 8 >> 2];
    var $5 = __ZNK13JSFunctionBox8functionEv($_0_idx_val);
    if ((HEAP32[$_0 + 60 >> 2] & 768 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN11JSParseNode9setFunArgEv($4);
    var $kid_03 = HEAP32[$_0 + 32 >> 2];
    if (($kid_03 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $kid_04 = $kid_03;
      __label__ = 4;
      break;
    }
   case 4:
    var $kid_04;
    var $14 = HEAP32[$kid_04 + 24 >> 2];
    __ZN11JSParseNode9setFunArgEv($14);
    var $kid_0 = HEAP32[$kid_04 + 28 >> 2];
    if (($kid_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $kid_04 = $kid_0;
      __label__ = 4;
      break;
    }
   case 5:
    var $18 = HEAP32[$4 + 36 >> 2];
    var $19 = $18;
    var $20 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($19, 85);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $skipmin_2 = 16383;
      __label__ = 14;
      break;
    }
   case 6:
    var $_idx_val = HEAP32[$18 + 32 >> 2];
    var $23 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($_idx_val);
    __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3allEv($r, $23);
    var $24 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv($r);
    if ($24) {
      var $skipmin_2 = 16383;
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $26 = $_0 + 56 | 0;
    var $skipmin_01 = 16383;
    __label__ = 8;
    break;
   case 8:
    var $skipmin_01;
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5frontEv($1, $r);
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $28 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Entry5valueEv($_idx1_val);
    var $29 = HEAP32[$28 >> 2];
    var $30 = __ZN12JSDefinition7resolveEv($29);
    var $31 = __ZNK12JSDefinition9isFreeVarEv($30);
    if ($31) {
      var $skipmin_1 = $skipmin_01;
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $33 = $30 | 0;
    var $34 = __ZNK11JSParseNode10frameLevelEv($33);
    if (($34 | 0) > ($level | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN11JSParseNode9setFunArgEv($4);
    __label__ = 11;
    break;
   case 11:
    var $42 = 1 - $34 + (HEAPU32[$26 >> 2] >>> 2 & 16383) | 0;
    if ($42 >>> 0 < $skipmin_01 >>> 0) {
      __label__ = 12;
      break;
    } else {
      var $skipmin_1 = $skipmin_01;
      __label__ = 13;
      break;
    }
   case 12:
    var $skipmin_1 = $42;
    __label__ = 13;
    break;
   case 13:
    var $skipmin_1;
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range8popFrontEv($r);
    var $46 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv($r);
    if ($46) {
      var $skipmin_2 = $skipmin_1;
      __label__ = 14;
      break;
    } else {
      var $skipmin_01 = $skipmin_1;
      __label__ = 8;
      break;
    }
   case 14:
    var $skipmin_2;
    var $47 = __ZNK11JSParseNode8isFunArgEv($4);
    if ($47) {
      __label__ = 15;
      break;
    } else {
      var $fnlevel_0 = $level;
      __label__ = 16;
      break;
    }
   case 15:
    __ZN18JSFunctionBoxQueue4pushEP13JSFunctionBox($queue, $_0);
    var $fnlevel_0 = HEAPU32[$_0 + 56 >> 2] >>> 2 & 16383;
    __label__ = 16;
    break;
   case 16:
    var $fnlevel_0;
    var $55 = HEAP32[$_0 + 32 >> 2];
    if (($55 | 0) == 0) {
      var $skipmin_3 = $skipmin_2;
      __label__ = 20;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $58 = __ZL11FindFunArgsP13JSFunctionBoxiP18JSFunctionBoxQueue($55, $fnlevel_0, $queue);
    if (($58 | 0) == 16383) {
      var $skipmin_3 = $skipmin_2;
      __label__ = 20;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $61 = $58 - 1 | 0;
    if (($61 | 0) != 0 & $61 >>> 0 < $skipmin_2 >>> 0) {
      __label__ = 19;
      break;
    } else {
      var $skipmin_3 = $skipmin_2;
      __label__ = 20;
      break;
    }
   case 19:
    var $skipmin_3 = $61;
    __label__ = 20;
    break;
   case 20:
    var $skipmin_3;
    if (($skipmin_3 | 0) == 16383) {
      var $allskipmin_1 = $allskipmin_0;
      __label__ = 23;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    HEAP16[$5 + 64 >> 1] = $skipmin_3 & 65535;
    if ($skipmin_3 >>> 0 < $allskipmin_0 >>> 0) {
      __label__ = 22;
      break;
    } else {
      var $allskipmin_1 = $allskipmin_0;
      __label__ = 23;
      break;
    }
   case 22:
    var $allskipmin_1 = $skipmin_3;
    __label__ = 23;
    break;
   case 23:
    var $allskipmin_1;
    var $75 = HEAPU32[$_0 + 28 >> 2];
    if (($75 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      var $_0 = $75;
      var $allskipmin_0 = $allskipmin_1;
      __label__ = 2;
      break;
    }
   case 24:
    STACKTOP = __stackBase__;
    return $allskipmin_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11FindFunArgsP13JSFunctionBoxiP18JSFunctionBoxQueue["X"] = 1;

function __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3allEv($agg_result, $this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $this_idx_val = HEAP32[$this >> 2];
    var $2 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE8usingMapEv($this_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this + 200 | 0;
    __ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3allEv($1, $4);
    var $_0_val = HEAP32[$1 >> 2];
    var $_1_val = HEAP32[$1 + 4 >> 2];
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E5RangeE($agg_result, $_0_val, $_1_val);
    __label__ = 4;
    break;
   case 3:
    var $6 = $this + 8 | 0;
    var $7 = $this + 8 + ($this_idx_val << 3) | 0;
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC1EPKNS5_10InlineElemES9_($agg_result, $6, $7);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP8[$this + 16 | 0];
    var $1 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range13isInlineRangeEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = (HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0);
    __label__ = 4;
    break;
   case 3:
    var $_idx_val = HEAP32[$this >> 2];
    var $_idx1_val = HEAP32[$this + 4 >> 2];
    var $9 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($_idx_val, $_idx1_val);
    var $11 = $9;
    __label__ = 4;
    break;
   case 4:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5frontEv($agg_result, $this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP8[$this + 16 | 0];
    var $1 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range13isInlineRangeEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$this + 8 >> 2];
    var $5 = $4 | 0;
    var $6 = $4 + 4 | 0;
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5EntryC1ERKS2_RKS4_($agg_result, $5, $6);
    __label__ = 4;
    break;
   case 3:
    var $_idx_val = HEAP32[$this >> 2];
    var $8 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($_idx_val);
    var $9 = $8 | 0;
    var $10 = $8 + 4 | 0;
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5EntryC1ERKS2_RKS4_($agg_result, $9, $10);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN12JSDefinition7resolveEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZNK11JSParseNode6isDefnEv($1);
    if ($2) {
      var $pn_0_lcssa = $1;
      __label__ = 6;
      break;
    } else {
      var $pn_01 = $1;
      __label__ = 2;
      break;
    }
   case 2:
    var $pn_01;
    var $3 = __ZNK11JSParseNode7getKindEv($pn_01);
    if (($3 | 0) == 4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $pn_0_be = HEAP32[$pn_01 + 32 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $pn_0_be;
    var $8 = __ZNK11JSParseNode6isDefnEv($pn_0_be);
    if ($8) {
      var $pn_0_lcssa = $pn_0_be;
      __label__ = 6;
      break;
    } else {
      var $pn_01 = $pn_0_be;
      __label__ = 2;
      break;
    }
   case 5:
    var $pn_01_idx_val = HEAP32[$pn_01 + 36 >> 2];
    var $10 = __ZNK11JSParseNode6lexdefEv($pn_01_idx_val);
    var $pn_0_be = $10 | 0;
    __label__ = 4;
    break;
   case 6:
    var $pn_0_lcssa;
    return $pn_0_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK12JSDefinition9isFreeVarEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this + 40 >> 2];
    var $2 = __ZNK2js11UpvarCookie6isFreeEv($_idx_val);
    if ($2) {
      var $7 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $this | 0;
    var $5 = __ZNK11JSParseNode4testEj($4, 64);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK11JSParseNode8isFunArgEv($this) {
  var $1 = __ZNK11JSParseNode4testEj($this, 256);
  return $1;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP8[$this + 16 | 0];
    var $1 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range13isInlineRangeEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range10bumpCurPtrEv($this);
    __label__ = 4;
    break;
   case 3:
    var $4 = $this | 0;
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($4);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18JSFunctionBoxQueueD1Ev($this_0_0_val) {
  __ZN18JSFunctionBoxQueueD2Ev($this_0_0_val);
  return;
}

function __ZL18ConsiderUnbrandingP13JSFunctionBox($funbox) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $funbox + 60 | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $6 = HEAP32[HEAP32[$funbox + 24 >> 2] + 36 >> 2];
    var $7 = $6;
    var $8 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($7, 85);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $pn2_0 = $7;
      __label__ = 3;
      break;
    }
   case 2:
    var $pn2_0 = HEAP32[$6 + 36 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $pn2_0;
    var $13 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_0, 84);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      var $pn2_1 = $pn2_0;
      __label__ = 5;
      break;
    }
   case 4:
    var $pn2_0_idx_val = HEAP32[$pn2_0 + 36 >> 2];
    var $15 = __ZNK11JSParseNode4lastEv($pn2_0_idx_val);
    var $pn2_1 = $15;
    __label__ = 5;
    break;
   case 5:
    var $pn2_1;
    var $17 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_1, 25);
    if ($17 & ($2 & 4 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $method_01 = HEAP32[$funbox + 40 >> 2];
    if (($method_01 | 0) == 0) {
      var $slowMethodSets_0_lcssa = 0;
      __label__ = 8;
      break;
    } else {
      var $slowMethodSets_02 = 0;
      var $method_03 = $method_01;
      __label__ = 7;
      break;
    }
   case 7:
    var $method_03;
    var $slowMethodSets_02;
    var $26 = HEAP32[$method_03 + 32 >> 2];
    var $27 = __ZNK13JSFunctionBox8joinableEv($26);
    var $slowMethodSets_0_ = ($27 & 1 ^ 1) + $slowMethodSets_02 | 0;
    var $method_0 = HEAPU32[$method_03 + 28 >> 2];
    if (($method_0 | 0) == 0) {
      var $slowMethodSets_0_lcssa = $slowMethodSets_0_;
      __label__ = 8;
      break;
    } else {
      var $slowMethodSets_02 = $slowMethodSets_0_;
      var $method_03 = $method_0;
      __label__ = 7;
      break;
    }
   case 8:
    var $slowMethodSets_0_lcssa;
    var $32 = __ZNK13JSFunctionBox13shouldUnbrandEjj($funbox, $slowMethodSets_0_lcssa);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    HEAP32[$1 >> 2] = $2 | 1048576;
    __label__ = 10;
    break;
   case 10:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15CanFlattenUpvarP12JSDefinitionP13JSFunctionBoxj($dn, $funbox, $tcflags) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $dn | 0;
    var $2 = __ZNK11JSParseNode10frameLevelEv($1);
    var $afunbox_0 = $funbox;
    __label__ = 2;
    break;
   case 2:
    var $afunbox_0;
    var $6 = HEAPU32[$afunbox_0 + 56 >> 2];
    if (($6 >>> 2 & 16383 | 0) == ($2 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAPU32[$afunbox_0 + 36 >> 2];
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = HEAP32[$12 + 24 >> 2];
    var $17 = __ZNK11JSParseNode8isFunArgEv($16);
    if ($17) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$12 + 60 >> 2] & 512 | 0) == 0) {
      var $afunbox_0 = $12;
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 6:
    if (($6 & 2 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $28 = HEAPU32[$afunbox_0 + 36 >> 2];
    var $29 = ($28 | 0) == 0;
    if ($29) {
      var $34 = $tcflags;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $34 = HEAP32[$28 + 60 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $34;
    if (($34 & 256 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 10:
    var $afunbox_0_idx_val = HEAP32[$afunbox_0 + 8 >> 2];
    var $38 = __ZNK13JSFunctionBox8functionEv($afunbox_0_idx_val);
    if ((HEAP16[$38 + 58 >> 1] & 8) << 16 >> 16 == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $44 = __ZN12JSDefinition13isBindingFormEv($dn);
    if ($44) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $46 = $dn + 4 | 0;
    var $49 = HEAP32[$afunbox_0 + 24 >> 2] + 4 | 0;
    var $50 = __ZN2js8TokenPosgeERKS0_($46, $49);
    if ($50) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $52 = __ZNK11JSParseNode13isInitializedEv($1);
    if ($52) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 14:
    var $54 = __ZN12JSDefinition4kindEv($dn);
    if (($54 | 0) == 1) {
      __label__ = 20;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $56 = __ZNK11JSParseNode10isAssignedEv($1);
    if ($56) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if (($54 | 0) == 4) {
      __label__ = 17;
      break;
    } else if (($54 | 0) == 3) {
      __label__ = 22;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 17:
    if ($29) {
      var $63 = $tcflags;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $63 = HEAP32[$28 + 60 >> 2];
    __label__ = 19;
    break;
   case 19:
    var $63;
    if (($63 & 128 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 20:
    var $66 = $dn + 12 | 0;
    var $68 = HEAPU32[$afunbox_0 + 24 >> 2];
    var $69 = $68 + 12 | 0;
    var $70 = __ZN2js8TokenPtrgeERKS0_($66, $69);
    if ($70) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $75 = HEAPU32[$dn + 44 >> 2] >>> 12;
    var $76 = __ZL10MinBlockIdP11JSParseNodej($68, $75);
    if (($76 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15CanFlattenUpvarP12JSDefinitionP13JSFunctionBoxj["X"] = 1;

function __ZN2js8Bindings20setExtensibleParentsEv($this) {
  HEAP8[$this + 10 | 0] = 1;
  return;
}

function __ZN12JSDefinition10kindStringENS_4KindE($kind) {
  return HEAP32[_table + ($kind << 2) >> 2];
}

function __ZN11JSParseNode9makeEmptyEv($this) {
  var $1 = $this + 32 | 0;
  HEAP32[$1 >> 2] = 0;
  HEAP32[$this + 36 >> 2] = $1;
  HEAP32[$this + 40 >> 2] = 0;
  HEAP32[$this + 44 >> 2] = 0;
  return;
}

function __ZN13JSTreeContext11atBodyLevelEv($this_0_6_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_6_val | 0) == 0) {
      var $8 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = (HEAP16[$this_0_6_val + 2 >> 1] & 2) << 16 >> 16 != 0;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16FlagHeavyweightsP12JSDefinitionP13JSFunctionBoxPj($dn, $funbox, $tcflags) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $dn | 0;
    var $2 = __ZNK11JSParseNode10frameLevelEv($1);
    var $3 = ($2 | 0) == 0;
    var $_0 = $funbox;
    __label__ = 2;
    break;
   case 2:
    var $_0;
    var $6 = HEAPU32[$_0 + 36 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (((HEAPU32[$6 + 56 >> 2] >>> 2 & 16383) + 1 | 0) == ($2 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = $6 + 60 | 0;
    var $18 = HEAP32[$16 >> 2] | 256;
    HEAP32[$16 >> 2] = $18;
    __label__ = 11;
    break;
   case 5:
    if ($3) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $21 = __ZNK11JSParseNode5isLetEv($1);
    if ($21) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $23 = $6 + 60 | 0;
    var $25 = HEAP32[$23 >> 2] | 256;
    HEAP32[$23 >> 2] = $25;
    __label__ = 11;
    break;
   case 8:
    var $27 = $6 + 60 | 0;
    var $29 = HEAP32[$27 >> 2] | 4194304;
    HEAP32[$27 >> 2] = $29;
    var $_0 = $6;
    __label__ = 2;
    break;
   case 9:
    var $30 = HEAP32[$tcflags >> 2];
    if (($30 & 2 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $34 = $30 | 256;
    HEAP32[$tcflags >> 2] = $34;
    __label__ = 11;
    break;
   case 11:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSFunction11setJoinableEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2JSL9NullValueEv2953($1);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, 0, $_idx_val$0, $_idx_val$1);
  var $3 = $this + 58 | 0;
  var $5 = HEAP16[$3 >> 1] | 1;
  HEAP16[$3 >> 1] = $5;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6Parser17functionArgumentsER13JSTreeContextP13JSFunctionBoxPP11JSParseNode($this, $funtc, $funbox, $listp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $data = __stackBase__;
    var $slot = __stackBase__ + 20;
    var $slot1 = __stackBase__ + 24;
    var $1 = $this + 40 | 0;
    var $2 = __ZN2js11TokenStream8getTokenEv($1);
    if (($2 | 0) == 27) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 69, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 3:
    var $7 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($1, 28);
    if ($7) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = $data | 0;
    var $9 = $data + 4 | 0;
    var $10 = $data + 8 | 0;
    var $11 = $funtc + 92 | 0;
    var $12 = $this + 12 | 0;
    var $13 = $funtc + 76 | 0;
    var $14 = $funbox + 24 | 0;
    var $funtc_idx = $funtc + 48 | 0;
    var $_idx1 = $funtc + 44 | 0;
    var $list_0 = 0;
    var $destructuringArg_0 = 0;
    var $duplicatedArg_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $duplicatedArg_0;
    var $destructuringArg_0;
    var $list_0;
    var $16 = __ZN2js11TokenStream8getTokenEv($1);
    if (($16 | 0) == 23 || ($16 | 0) == 25) {
      __label__ = 6;
      break;
    } else if (($16 | 0) == 29) {
      __label__ = 15;
      break;
    } else if (($16 | 0) == -1) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 6:
    if (($duplicatedArg_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $duplicatedArg_2 = $duplicatedArg_0;
      __label__ = 20;
      break;
    }
   case 7:
    __ZN8BindDataC1Ev($data);
    HEAP32[$8 >> 2] = 0;
    HEAP32[$9 >> 2] = 129;
    HEAP32[$10 >> 2] = 200;
    var $20 = __ZN2js6Parser17destructuringExprEP8BindDataNS_9TokenKindE($this, $data, $16);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $23 = HEAP32[$12 >> 2];
    var $24 = __ZN2js8Bindings16addDestructuringEP9JSContextPt($11, $23, $slot);
    if ($24) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 9:
    var $31 = HEAP32[HEAP32[HEAP32[$12 >> 2] + 52 >> 2] + 209972 >> 2] | 0;
    var $32 = __ZN2js8NameNode6createEP6JSAtomP13JSTreeContext($31, $funtc);
    var $33 = $32 | 0;
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($33, 29);
    __ZN11JSParseNode5setOpE4JSOp($33, 84);
    var $37 = $32 + 40 | 0;
    var $39 = HEAP32[$13 >> 2] & 65535;
    var $40 = HEAP16[$slot >> 1];
    __ZN2js11UpvarCookie3setEtt($37, $39, $40);
    var $42 = $32 + 44 | 0;
    var $44 = HEAP32[$42 >> 2] | 512;
    HEAP32[$42 >> 2] = $44;
    var $45 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(4, 0, $20, $33, $funtc);
    if (($45 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    if (($list_0 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $list_1 = $list_0;
      __label__ = 14;
      break;
    }
   case 12:
    var $funtc_idx_val = HEAP32[$funtc_idx >> 2];
    var $50 = __ZN2js8ListNode6createEP13JSTreeContext($funtc_idx_val);
    var $51 = $50 | 0;
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($51, 46);
    __ZN11JSParseNode9makeEmptyEv($51);
    HEAP32[$listp >> 2] = $51;
    var $list_1 = $51;
    __label__ = 14;
    break;
   case 14:
    var $list_1;
    __ZN11JSParseNode6appendEPS_($list_1, $45);
    var $list_2 = $list_1;
    var $destructuringArg_1 = 1;
    var $duplicatedArg_3 = $duplicatedArg_0;
    __label__ = 21;
    break;
   case 15:
    var $56 = __ZNK2js11TokenStream12currentTokenEv($1);
    var $58 = HEAPU32[$56 + 28 >> 2];
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $59 = __ZN2js9AtomDecls11lookupFirstEP6JSAtom($_idx1_val, $58);
    if (($59 | 0) == 0) {
      var $duplicatedArg_1 = $duplicatedArg_0;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if (($destructuringArg_0 & 1) << 24 >> 24 == 0) {
      var $duplicatedArg_1 = $58;
      __label__ = 17;
      break;
    } else {
      var $duplicatedArg_2 = $58;
      __label__ = 20;
      break;
    }
   case 17:
    var $duplicatedArg_1;
    var $65 = HEAP32[$12 >> 2];
    var $66 = __ZN2js8Bindings11addArgumentEP9JSContextP6JSAtomPt($11, $65, $58, $slot1);
    if ($66) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 18:
    var $68 = HEAP32[$14 >> 2];
    var $70 = HEAPU16[$slot1 >> 1] & 65535;
    var $71 = __ZL9DefineArgP11JSParseNodeP6JSAtomjP13JSTreeContext($68, $58, $70, $funtc);
    if ($71) {
      var $list_2 = $list_0;
      var $destructuringArg_1 = $destructuringArg_0;
      var $duplicatedArg_3 = $duplicatedArg_1;
      __label__ = 21;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 19:
    var $73 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 70, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 20:
    var $duplicatedArg_2;
    var $_idx_val = HEAP32[$_idx1 >> 2];
    var $75 = __ZN2js9AtomDecls11lookupFirstEP6JSAtom($_idx_val, $duplicatedArg_2);
    var $76 = $75 | 0;
    var $77 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $76, 0, 76, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 21:
    var $duplicatedArg_3;
    var $destructuringArg_1;
    var $list_2;
    var $79 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($1, 3);
    if ($79) {
      var $list_0 = $list_2;
      var $destructuringArg_0 = $destructuringArg_1;
      var $duplicatedArg_0 = $duplicatedArg_3;
      __label__ = 5;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $81 = __ZN2js11TokenStream8getTokenEv($1);
    if (($81 | 0) == 28) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $84 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 71, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 24:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser17functionArgumentsER13JSTreeContextP13JSFunctionBoxPP11JSParseNode["X"] = 1;

function __ZN8BindDataC1Ev($this) {
  __ZN8BindDataC2Ev($this);
  return;
}

function __ZL20BindDestructuringArgP9JSContextP8BindDataP6JSAtomP13JSTreeContext($cx, $data, $atom, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $tc + 48 | 0;
    if ((HEAP32[HEAP32[HEAP32[HEAP32[$1 >> 2] + 12 >> 2] + 52 >> 2] + 210176 >> 2] | 0) == ($atom | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $12 = $tc | 0;
    var $14 = HEAP32[$12 >> 2] | 64;
    HEAP32[$12 >> 2] = $14;
    __label__ = 3;
    break;
   case 3:
    var $_idx_val = HEAP32[$tc + 44 >> 2];
    var $16 = __ZN2js9AtomDecls11lookupFirstEP6JSAtom($_idx_val, $atom);
    if (($16 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $20 = HEAP32[$1 >> 2] + 40 | 0;
    var $21 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($20, 0, 0, 76, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 5:
    var $24 = HEAP32[$data >> 2];
    __ZN11JSParseNode5setOpE4JSOp($24, 87);
    var $26 = $24 + 44 | 0;
    var $28 = HEAP32[$26 >> 2] | 512;
    HEAP32[$26 >> 2] = $28;
    var $29 = __ZL6DefineP11JSParseNodeP6JSAtomP13JSTreeContextb($24, $atom, $tc, 0);
    var $_0 = $29 & 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser17destructuringExprEP8BindDataNS_9TokenKindE($this, $data, $tt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 980 | 0;
    var $3 = HEAP32[$1 >> 2] | 0;
    var $5 = HEAP32[$3 >> 2] | 65536;
    HEAP32[$3 >> 2] = $5;
    var $6 = __ZN2js6Parser11primaryExprENS_9TokenKindEi($this, $tt, 0);
    var $8 = HEAP32[$1 >> 2] | 0;
    var $10 = HEAP32[$8 >> 2] & -65537;
    HEAP32[$8 >> 2] = $10;
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = HEAP32[$this + 12 >> 2];
    var $15 = HEAP32[$1 >> 2];
    var $16 = __ZL18CheckDestructuringP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($14, $data, $6, $15);
    var $_ = $16 ? $6 : 0;
    var $_0 = $_;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Bindings16addDestructuringEP9JSContextPt($this, $cx, $slotp) {
  var $2 = HEAP16[$this + 4 >> 1];
  HEAP16[$slotp >> 1] = $2;
  var $3 = $this;
  var $4 = $cx;
  var $5 = __ZN2js8Bindings3addEP9JSContextP6JSAtomNS_11BindingKindE($3, $4, 0, 1);
  return $5;
}

function __ZN2js8ListNode6createEP13JSTreeContext($tc_0_11_val) {
  var $1 = __ZN11JSParseNode6createE16JSParseNodeArityP13JSTreeContext(5, $tc_0_11_val);
  return $1;
}

function __ZN2js9AtomDecls11lookupFirstEP6JSAtom($this_0_1_val, $atom) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $atom;
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6lookupERKS2_($p, $this_0_1_val, $1);
    var $2 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrcvPPPPPPPS5_Ev($p);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3Ptr5valueEv($p);
    var $6 = $5;
    var $7 = __ZNK2js12DefnOrHeader8isHeaderEv($6);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = __ZNK2js12DefnOrHeader6headerEv($6);
    var $_0 = HEAP32[$9 >> 2];
    __label__ = 5;
    break;
   case 4:
    var $_idx_val = HEAP32[$5 >> 2];
    var $13 = __ZNK2js12DefnOrHeader4defnEv($_idx_val);
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser11functionDefEP6JSAtomNS0_12FunctionTypeENS_18FunctionSyntaxKindE($this, $funAtom, $type, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 148;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $name = __stackBase__ + 4;
    var $index = __stackBase__ + 8;
    var $funtc = __stackBase__ + 12;
    var $prelude = __stackBase__ + 120;
    var $iter = __stackBase__ + 124;
    HEAP32[$1 >> 2] = $funAtom;
    var $2 = $this + 40 | 0;
    __ZN2js11TokenStream17mungeCurrentTokenENS_9TokenKindE4JSOp($2, 34, 0);
    var $3 = $this + 980 | 0;
    var $_idx7_val = HEAP32[HEAP32[$3 >> 2] + 48 >> 2];
    var $5 = __ZN2js12FunctionNode6createEP13JSTreeContext($_idx7_val);
    var $6 = $5 | 0;
    if (($5 | 0) == 0) {
      var $_2 = 0;
      __label__ = 72;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $5 + 36 | 0;
    HEAP32[$9 >> 2] = 0;
    var $11 = $5 + 40 | 0;
    __ZN2js11UpvarCookie8makeFreeEv($11);
    var $_idx5_val = HEAP32[HEAP32[$3 >> 2] + 24 >> 2];
    var $13 = __ZN13JSTreeContext11atBodyLevelEv($_idx5_val);
    var $14 = ($kind | 0) == 0;
    if ($14) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $16 = $5 + 44 | 0;
    var $19 = HEAP32[$16 >> 2] & -4096 | 256;
    HEAP32[$16 >> 2] = $19;
    var $pn_2 = $6;
    var $115 = 0;
    __label__ = 22;
    break;
   case 4:
    var $phitmp = $13 ? 0 : 256;
    var $22 = $5 + 44 | 0;
    var $25 = HEAP32[$22 >> 2] & -4096 | $phitmp;
    HEAP32[$22 >> 2] = $25;
    var $26 = ($kind | 0) == 1;
    if ($26) {
      __label__ = 5;
      break;
    } else {
      var $pn_2 = $6;
      var $115 = 0;
      __label__ = 22;
      break;
    }
   case 5:
    var $_idx8_val = HEAP32[HEAP32[$3 >> 2] + 44 >> 2];
    var $29 = __ZN2js9AtomDecls11lookupFirstEP6JSAtom($_idx8_val, $funAtom);
    if (($29 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $32 = __ZN12JSDefinition4kindEv($29);
    var $33 = $this + 12 | 0;
    var $_idx_val = HEAP32[HEAP32[$33 >> 2] + 32 >> 2];
    var $35 = __ZNK9JSContext15hasStrictOptionEv($_idx_val);
    if ($35 | ($32 | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 7:
    __ZN16JSAutoByteStringC1Ev($name);
    var $38 = HEAP32[$33 >> 2];
    var $39 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($38, $funAtom, $name);
    if (($39 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $name_idx1_val = HEAP32[$name >> 2];
    __label__ = 10;
    break;
   case 9:
    var $43 = ($32 | 0) != 1 ? 5 : 0;
    var $44 = __ZN12JSDefinition10kindStringENS_4KindE($32);
    var $name_idx4_val = HEAP32[$name >> 2];
    var $45 = __ZNK16JSAutoByteString3ptrEv($name_idx4_val);
    var $46 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, $43, 155, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $44, HEAP32[tempInt + 4 >> 2] = $45, tempInt));
    if ($46) {
      __label__ = 11;
      break;
    } else {
      var $name_idx1_val = $name_idx4_val;
      __label__ = 10;
      break;
    }
   case 10:
    var $name_idx1_val;
    __ZN16JSAutoByteStringD1Ev($name_idx1_val);
    var $_2 = 0;
    __label__ = 72;
    break;
   case 11:
    __ZN16JSAutoByteStringD1Ev($name_idx4_val);
    __label__ = 12;
    break;
   case 12:
    if ($13) {
      __label__ = 13;
      break;
    } else {
      var $pn_2 = $6;
      var $115 = $26;
      __label__ = 22;
      break;
    }
   case 13:
    var $51 = $5;
    var $_idx9_val = HEAP32[HEAP32[$3 >> 2] + 44 >> 2];
    __ZN2js9AtomDecls11updateFirstEP6JSAtomP12JSDefinition($_idx9_val, $funAtom, $51);
    __ZN11JSParseNode7setDefnEb($6, 1);
    var $52 = $29 | 0;
    var $53 = $5 + 28 | 0;
    HEAP32[$53 >> 2] = $52;
    var $54 = HEAP32[$3 >> 2];
    var $55 = __ZL14MakeDefIntoUseP12JSDefinitionP11JSParseNodeP6JSAtomP13JSTreeContext($29, $6, $funAtom, $54);
    if (($55 | 0) == 0) {
      var $_2 = 0;
      __label__ = 72;
      break;
    } else {
      var $pn_19 = $6;
      var $85 = $funAtom;
      __label__ = 18;
      break;
    }
   case 14:
    if ($13) {
      __label__ = 15;
      break;
    } else {
      var $pn_2 = $6;
      var $115 = 1;
      __label__ = 22;
      break;
    }
   case 15:
    var $_idx10_val = HEAP32[HEAP32[$3 >> 2] + 64 >> 2];
    var $60 = __ZN2js14AtomDefnMapPtr10lookupDefnEP6JSAtom($_idx10_val, $funAtom);
    if (($60 | 0) == 0) {
      var $pn_0 = $6;
      var $82 = $funAtom;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $63 = $60 | 0;
    __ZN11JSParseNode7setKindEN2js9TokenKindE($63, 34);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($63, 4);
    var $66 = $5 + 4 | 0;
    var $67 = $60 + 4 | 0;
    var $68$0 = HEAP32[$66 >> 2];
    var $68$1 = HEAP32[$66 + 4 >> 2];
    var $st$11$0 = $67 | 0;
    HEAP32[$st$11$0 >> 2] = $68$0;
    var $st$11$1 = $67 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $68$1;
    var $71 = $5 + 12 | 0;
    var $72 = $60 + 12 | 0;
    var $73$0 = HEAP32[$71 >> 2];
    var $73$1 = HEAP32[$71 + 4 >> 2];
    var $st$23$0 = $72 | 0;
    HEAP32[$st$23$0 >> 2] = $73$0;
    var $st$23$1 = $72 + 4 | 0;
    HEAP32[$st$23$1 >> 2] = $73$1;
    var $74 = $60 + 36 | 0;
    HEAP32[$74 >> 2] = 0;
    var $76 = $60 + 40 | 0;
    __ZN2js11UpvarCookie8makeFreeEv($76);
    var $_idx11_val = HEAP32[HEAP32[$3 >> 2] + 64 >> 2];
    var $78 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($_idx11_val);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6removeERKS2_($78, $1);
    var $79 = HEAP32[$3 >> 2];
    var $80 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($6, $79);
    var $pn_0 = $63;
    var $82 = HEAP32[$1 >> 2];
    __label__ = 17;
    break;
   case 17:
    var $82;
    var $pn_0;
    var $83 = HEAP32[$3 >> 2];
    var $84 = __ZL6DefineP11JSParseNodeP6JSAtomP13JSTreeContextb($pn_0, $82, $83, 0);
    if ($84) {
      var $pn_19 = $pn_0;
      var $85 = $82;
      __label__ = 18;
      break;
    } else {
      var $_2 = 0;
      __label__ = 72;
      break;
    }
   case 18:
    var $85;
    var $pn_19;
    var $86 = HEAP32[$3 >> 2];
    var $_idx13_val = HEAP32[$86 >> 2];
    var $87 = __ZNK13JSTreeContext10inFunctionEv($_idx13_val);
    if ($87) {
      __label__ = 19;
      break;
    } else {
      var $pn_2 = $pn_19;
      var $115 = $26;
      __label__ = 22;
      break;
    }
   case 19:
    var $90 = $this + 12 | 0;
    var $92 = $86 + 92 | 0;
    var $93 = HEAP32[$90 >> 2];
    var $94 = __ZNK2js8Bindings6lookupEP9JSContextP6JSAtomPj($92, $93, $85, $index);
    if (($94 | 0) == 0 || ($94 | 0) == 1) {
      __label__ = 20;
      break;
    } else if (($94 | 0) == 2) {
      __label__ = 21;
      break;
    } else {
      var $pn_2 = $pn_19;
      var $115 = $26;
      __label__ = 22;
      break;
    }
   case 20:
    var $96 = HEAPU32[$3 >> 2];
    var $_idx3_val = HEAP16[$96 + 98 >> 1];
    var $97 = __ZNK2js8Bindings9countVarsEv($_idx3_val);
    HEAP32[$index >> 2] = $97 & 65535;
    var $99 = $96 + 92 | 0;
    var $100 = HEAP32[$90 >> 2];
    var $101 = __ZN2js8Bindings11addVariableEP9JSContextP6JSAtom($99, $100, $85);
    if ($101) {
      __label__ = 21;
      break;
    } else {
      var $_2 = 0;
      __label__ = 72;
      break;
    }
   case 21:
    var $108 = HEAP32[HEAP32[$3 >> 2] + 76 >> 2] & 65535;
    var $110 = HEAP32[$index >> 2] & 65535;
    __ZN2js11UpvarCookie3setEtt($pn_19 + 40 | 0, $108, $110);
    var $112 = $pn_19 + 44 | 0;
    var $114 = HEAP32[$112 >> 2] | 512;
    HEAP32[$112 >> 2] = $114;
    var $pn_2 = $pn_19;
    var $115 = $26;
    __label__ = 22;
    break;
   case 22:
    var $115;
    var $pn_2;
    var $116 = HEAPU32[$3 >> 2];
    var $117 = $116 + 48 | 0;
    var $118 = HEAP32[$117 >> 2];
    __ZN13JSTreeContextC1EPN2js6ParserE($funtc, $118);
    var $119 = $this + 12 | 0;
    var $120 = HEAP32[$119 >> 2];
    var $121 = $funtc;
    var $122 = __ZN13JSTreeContext4initEP9JSContextNS_12InitBehaviorE($121, $120, 0);
    if ($122) {
      __label__ = 23;
      break;
    } else {
      var $_1 = 0;
      __label__ = 71;
      break;
    }
   case 23:
    var $124 = HEAPU32[$1 >> 2];
    var $125 = __ZL13EnterFunctionP11JSParseNodeP13JSTreeContextP6JSAtomN2js18FunctionSyntaxKindE($pn_2, $funtc, $124, $kind);
    if (($125 | 0) == 0) {
      var $_1 = 0;
      __label__ = 71;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $_idx14_val = HEAP32[$125 + 8 >> 2];
    var $128 = __ZNK13JSFunctionBox8functionEv($_idx14_val);
    HEAP32[$prelude >> 2] = 0;
    var $129 = __ZN2js6Parser17functionArgumentsER13JSTreeContextP13JSFunctionBoxPP11JSParseNode($this, $funtc, $125, $prelude);
    if ($129) {
      __label__ = 25;
      break;
    } else {
      var $_1 = 0;
      __label__ = 71;
      break;
    }
   case 25:
    var $_idx2_val = HEAP16[$funtc + 96 >> 1];
    var $131 = __ZNK2js8Bindings9countArgsEv($_idx2_val);
    __ZN10JSFunction11setArgCountEt($128, $131);
    var $132 = HEAPU32[$prelude >> 2];
    var $133 = ($132 | 0) == 0;
    if ($133) {
      __label__ = 30;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $_idx18_val = HEAP32[$funtc + 44 >> 2];
    __ZN2js13AtomDeclsIterC1EPNS_9AtomDeclsE($iter, $_idx18_val);
    __label__ = 27;
    break;
   case 27:
    var $135 = __ZN2js13AtomDeclsIterclEv($iter);
    if (($135 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $138 = $135 | 0;
    var $139 = __ZNK11JSParseNode4isOpE4JSOp($138, 87);
    if ($139) {
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 29:
    var $141 = HEAP32[$119 >> 2];
    var $142 = __ZL17BindLocalVariableP9JSContextP13JSTreeContextP11JSParseNodeN2js11BindingKindE($141, $funtc, $138, 2);
    if ($142) {
      __label__ = 27;
      break;
    } else {
      var $_1 = 0;
      __label__ = 71;
      break;
    }
   case 30:
    if (($type | 0) == 0) {
      __label__ = 31;
      break;
    } else if (($type | 0) == 1) {
      __label__ = 33;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 31:
    if (HEAP16[$128 + 56 >> 1] << 16 >> 16 == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $148 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 251, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str12882 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str22883 | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str226519 | 0, tempInt));
    var $_1 = 0;
    __label__ = 71;
    break;
   case 33:
    if (HEAP16[$128 + 56 >> 1] << 16 >> 16 == 1) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $154 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 251, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str42885 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str52886 | 0, HEAP32[tempInt + 8 >> 2] = __str17668 | 0, tempInt));
    var $_1 = 0;
    __label__ = 71;
    break;
   case 35:
    var $156 = __ZN2js11TokenStream8getTokenEj($2, 8);
    var $157 = ($156 | 0) == 25;
    if ($157) {
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    __ZN2js11TokenStream10ungetTokenEv($2);
    var $159 = $128 + 58 | 0;
    var $161 = HEAP16[$159 >> 1] | 4096;
    HEAP16[$159 >> 1] = $161;
    __label__ = 37;
    break;
   case 37:
    var $163 = __ZN2js6Parser12functionBodyEv($this);
    if (($163 | 0) == 0) {
      var $_1 = 0;
      __label__ = 71;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    if (($124 | 0) == 0) {
      __label__ = 40;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $168 = HEAP32[$119 >> 2];
    var $169 = __Z18CheckStrictBindingP9JSContextP13JSTreeContextP6JSAtomP11JSParseNode($168, $funtc, $124, $pn_2);
    if ($169) {
      __label__ = 40;
      break;
    } else {
      var $_1 = 0;
      __label__ = 71;
      break;
    }
   case 40:
    var $171 = HEAP32[$119 >> 2];
    var $172 = __ZL21CheckStrictParametersP9JSContextP13JSTreeContext($171, $funtc);
    if ($172) {
      __label__ = 41;
      break;
    } else {
      var $_1 = 0;
      __label__ = 71;
      break;
    }
   case 41:
    if ($157) {
      __label__ = 42;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 42:
    var $175 = __ZN2js11TokenStream8getTokenEj($2, 0);
    if (($175 | 0) == 26) {
      __label__ = 46;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    var $178 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 73, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 71;
    break;
   case 44:
    if ($115) {
      __label__ = 45;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 45:
    var $181 = __ZL22MatchOrInsertSemicolonP9JSContextPN2js11TokenStreamE($2);
    if (($181 | 0) == 0) {
      var $_1 = 0;
      __label__ = 71;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $184 = $pn_2 + 12 | 0;
    var $185 = __ZNK2js11TokenStream12currentTokenEv($2);
    var $187 = $185 + 12 | 0;
    var $188 = $184;
    var $189$0 = HEAP32[$187 >> 2];
    var $189$1 = HEAP32[$187 + 4 >> 2];
    HEAP32[$188 >> 2] = $189$0;
    HEAP32[$188 + 4 >> 2] = $189$1;
    var $_idx17 = $funtc | 0;
    var $_idx17_val = HEAP32[$_idx17 >> 2];
    var $190 = __ZNK13JSTreeContext9callsEvalEv($_idx17_val);
    if ($190) {
      __label__ = 47;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 47:
    __ZN13JSTreeContext13noteCallsEvalEv($116);
    __label__ = 48;
    break;
   case 48:
    if ($133) {
      var $body_1 = $163;
      __label__ = 56;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $194 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($163, 5);
    if ($194) {
      var $body_0 = $163;
      __label__ = 52;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    var $_idx16_val = HEAP32[$117 >> 2];
    var $196 = __ZN2js8ListNode6createEP13JSTreeContext($_idx16_val);
    var $197 = $196 | 0;
    if (($196 | 0) == 0) {
      var $_1 = 0;
      __label__ = 71;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($197, 82);
    var $202 = $196 + 4 | 0;
    var $203 = $163 + 4 | 0;
    HEAP32[$202 >> 2] = HEAP32[$203 >> 2];
    HEAP32[$202 + 4 >> 2] = HEAP32[$203 + 4 >> 2];
    HEAP32[$202 + 8 >> 2] = HEAP32[$203 + 8 >> 2];
    HEAP32[$202 + 12 >> 2] = HEAP32[$203 + 12 >> 2];
    __ZN11JSParseNode8initListEPS_($197, $163);
    var $body_0 = $197;
    __label__ = 52;
    break;
   case 52:
    var $body_0;
    var $_idx15_val = HEAP32[$117 >> 2];
    var $205 = __ZN2js9UnaryNode6createEP13JSTreeContext($_idx15_val);
    var $206 = $205 | 0;
    if (($205 | 0) == 0) {
      var $_1 = 0;
      __label__ = 71;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($206, 2);
    var $209 = $205 + 4 | 0;
    var $212 = $body_0 + 4 | 0;
    var $213 = $205 + 12 | 0;
    var $214$0 = HEAP32[$212 >> 2];
    var $214$1 = HEAP32[$212 + 4 >> 2];
    var $st$10$0 = $213 | 0;
    HEAP32[$st$10$0 >> 2] = $214$0;
    var $st$10$1 = $213 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $214$1;
    var $215 = $209;
    var $st$15$0 = $215 | 0;
    HEAP32[$st$15$0 >> 2] = $214$0;
    var $st$15$1 = $215 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $214$1;
    var $216 = $205 + 32 | 0;
    HEAP32[$216 >> 2] = $132;
    var $217 = $body_0 + 32 | 0;
    var $218 = HEAP32[$217 >> 2];
    var $219 = $205 + 24 | 0;
    HEAP32[$219 >> 2] = $218;
    HEAP32[$217 >> 2] = $206;
    var $220 = $body_0 + 36 | 0;
    if ((HEAP32[$220 >> 2] | 0) == ($217 | 0)) {
      __label__ = 54;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 54:
    HEAP32[$220 >> 2] = $219;
    __label__ = 55;
    break;
   case 55:
    var $225 = $body_0 + 40 | 0;
    var $227 = HEAP32[$225 >> 2] + 1 | 0;
    HEAP32[$225 >> 2] = $227;
    var $229 = $body_0 + 44 | 0;
    var $231 = HEAP32[$229 >> 2] | 512;
    HEAP32[$229 >> 2] = $231;
    var $body_1 = $body_0;
    __label__ = 56;
    break;
   case 56:
    var $body_1;
    if ((HEAP32[$_idx17 >> 2] & 256 | 0) == 0) {
      __label__ = 58;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    var $236 = $128 + 58 | 0;
    var $238 = HEAP16[$236 >> 1] | 128;
    HEAP16[$236 >> 1] = $238;
    var $239 = $116 | 0;
    var $241 = HEAP32[$239 >> 2] | 256;
    HEAP32[$239 >> 2] = $241;
    __label__ = 60;
    break;
   case 58:
    if ($13 | $115 ^ 1) {
      __label__ = 60;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 59:
    var $244 = $116 | 0;
    var $246 = HEAP32[$244 >> 2] | 256;
    HEAP32[$244 >> 2] = $246;
    __label__ = 60;
    break;
   case 60:
    var $_mux = $14 ? 130 : 0;
    if ($14 | $13) {
      var $op_0 = $_mux;
      __label__ = 62;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    __ZN13JSTreeContext20noteMightAliasLocalsEv($116);
    var $op_0 = 127;
    __label__ = 62;
    break;
   case 62:
    var $op_0;
    var $251 = HEAP32[$funtc + 84 >> 2];
    HEAP32[$125 + 32 >> 2] = $251;
    HEAP32[$pn_2 + 32 >> 2] = $125;
    __ZN11JSParseNode5setOpE4JSOp($pn_2, $op_0);
    var $254 = $pn_2 + 36 | 0;
    var $255 = HEAP32[$254 >> 2];
    if (($255 | 0) == 0) {
      __label__ = 64;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $258 = $255;
    __ZN11JSParseNode6appendEPS_($258, $body_1);
    var $262 = HEAP32[$254 >> 2] + 4 | 0;
    var $263 = $body_1 + 4 | 0;
    HEAP32[$262 >> 2] = HEAP32[$263 >> 2];
    HEAP32[$262 + 4 >> 2] = HEAP32[$263 + 4 >> 2];
    HEAP32[$262 + 8 >> 2] = HEAP32[$263 + 8 >> 2];
    HEAP32[$262 + 12 >> 2] = HEAP32[$263 + 12 >> 2];
    __label__ = 65;
    break;
   case 64:
    HEAP32[$254 >> 2] = $body_1;
    __label__ = 65;
    break;
   case 65:
    var $266 = $116;
    var $_idx12 = $116 | 0;
    var $_idx12_val = HEAP32[$_idx12 >> 2];
    var $267 = __ZNK13JSTreeContext10inFunctionEv($_idx12_val);
    if ($267 | $13 ^ 1 | $115 ^ 1) {
      __label__ = 68;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 66:
    var $269 = __ZNK13JSTreeContext9compilingEv($_idx12_val);
    if ($269) {
      __label__ = 67;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 67:
    var $271 = __ZN13JSTreeContext15asCodeGeneratorEv($266);
    var $272 = $271;
    var $273 = HEAP32[$1 >> 2];
    var $274 = __ZL12DefineGlobalP11JSParseNodeP15JSCodeGeneratorP6JSAtom($pn_2, $272, $273);
    if ($274) {
      __label__ = 68;
      break;
    } else {
      var $_1 = 0;
      __label__ = 71;
      break;
    }
   case 68:
    var $276 = __ZN13JSTreeContext7blockidEv($266);
    var $278 = $pn_2 + 44 | 0;
    var $282 = HEAP32[$278 >> 2] & 4095 | $276 << 12;
    HEAP32[$278 >> 2] = $282;
    var $283 = HEAP32[$1 >> 2];
    var $284 = __ZL13LeaveFunctionP11JSParseNodeP13JSTreeContextP6JSAtomN2js18FunctionSyntaxKindE($pn_2, $funtc, $283, $kind);
    if ($284) {
      __label__ = 69;
      break;
    } else {
      var $_1 = 0;
      __label__ = 71;
      break;
    }
   case 69:
    var $_idx6_val = HEAP32[$_idx12 >> 2];
    var $286 = __ZNK13JSTreeContext12inStrictModeEv($_idx6_val);
    if ($286) {
      var $_1 = $pn_2;
      __label__ = 71;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    __ZN2js11TokenStream13setStrictModeEb($2, 0);
    var $_1 = $pn_2;
    __label__ = 71;
    break;
   case 71:
    var $_1;
    __ZN13JSTreeContextD1Ev($funtc);
    var $_2 = $_1;
    __label__ = 72;
    break;
   case 72:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser11functionDefEP6JSAtomNS0_12FunctionTypeENS_18FunctionSyntaxKindE["X"] = 1;

function __ZN2js11TokenStream17mungeCurrentTokenENS_9TokenKindE4JSOp($this, $newKind, $newOp) {
  __ZN2js11TokenStream17mungeCurrentTokenENS_9TokenKindE($this, $newKind);
  __ZN2js11TokenStream17mungeCurrentTokenE4JSOp($this, $newOp);
  return;
}

function __ZNK13JSTreeContext9compilingEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function __ZN11JSParseNode7setDefnEb($this, $enabled) {
  var $2 = $this;
  var $6 = HEAP32[$2 >> 2] & 2147483647 | ($enabled & 1) << 31;
  HEAP32[$2 >> 2] = $6;
  return;
}

function __ZN2js11TokenStream10ungetTokenEv($this) {
  var $1 = $this + 136 | 0;
  var $3 = HEAP32[$1 >> 2] + 1 | 0;
  HEAP32[$1 >> 2] = $3;
  var $4 = $this + 132 | 0;
  var $7 = HEAP32[$4 >> 2] + 3 & 3;
  HEAP32[$4 >> 2] = $7;
  return;
}

function __ZN13JSTreeContext13noteCallsEvalEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 8388608;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN13JSTreeContext20noteMightAliasLocalsEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 67108864;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js9AtomDecls11updateFirstEP6JSAtomP12JSDefinition($this_0_1_val, $atom, $defn) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 16;
    HEAP32[$1 >> 2] = $atom;
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6lookupERKS2_($p, $this_0_1_val, $1);
    var $3 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3Ptr5valueEv($p);
    var $4 = $3;
    var $5 = __ZNK2js12DefnOrHeader8isHeaderEv($4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZNK2js12DefnOrHeader6headerEv($4);
    HEAP32[$7 >> 2] = $defn;
    __label__ = 4;
    break;
   case 3:
    __ZN2js12DefnOrHeaderC1EP12JSDefinition($2, $defn);
    var $11 = HEAP32[$2 >> 2];
    HEAP32[$3 >> 2] = $11;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14MakeDefIntoUseP12JSDefinitionP11JSParseNodeP6JSAtomP13JSTreeContext($dn, $pn, $atom, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN12JSDefinition13isBindingFormEv($dn);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$dn + 36 >> 2];
    var $3 = __ZNK11JSParseNode4exprEv($_idx_val);
    if (($3 | 0) == 0) {
      var $_01 = $dn;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = $dn | 0;
    var $tc_idx_val = HEAP32[$tc + 48 >> 2];
    var $7 = __ZL14MakeAssignmentP11JSParseNodeS0_P13JSTreeContext($6, $3, $tc_idx_val);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_01 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_01;
    var $12 = $_01 | 0;
    var $13 = __ZNK11JSParseNode5getOpEv($12);
    var $18 = (HEAP32[_js_CodeSpec + ($13 << 3) + 4 >> 2] & 256 | 0) != 0 ? 111 : 59;
    __ZN11JSParseNode5setOpE4JSOp($12, $18);
    var $_1 = $_01;
    __label__ = 8;
    break;
   case 6:
    var $20 = __ZN12JSDefinition4kindEv($dn);
    if (($20 | 0) == 3) {
      __label__ = 7;
      break;
    } else {
      var $_1 = $dn;
      __label__ = 8;
      break;
    }
   case 7:
    var $23 = $dn | 0;
    __ZL22PrepareNodeForMutationP11JSParseNodeP13JSTreeContext($23, $tc);
    __ZN11JSParseNode7setKindEN2js9TokenKindE($23, 29);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($23, 6);
    HEAP32[$dn + 32 >> 2] = $atom;
    var $_1 = $dn;
    __label__ = 8;
    break;
   case 8:
    var $_1;
    var $26 = $_1 | 0;
    var $pnu_03 = HEAP32[$_1 + 28 >> 2];
    if (($pnu_03 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $41 = HEAP32[$pn + 44 >> 2];
    var $_c_pre_phi = $pn;
    __label__ = 12;
    break;
   case 10:
    var $_c2 = $pn;
    var $30 = $pn + 44 | 0;
    var $pnu_04 = $pnu_03;
    __label__ = 11;
    break;
   case 11:
    var $pnu_04;
    HEAP32[$pnu_04 + 36 >> 2] = $_c2;
    var $38 = HEAP32[$30 >> 2] | HEAP32[$pnu_04 + 44 >> 2] & 2312;
    HEAP32[$30 >> 2] = $38;
    var $pnu_0 = HEAP32[$pnu_04 + 28 >> 2];
    if (($pnu_0 | 0) == 0) {
      var $41 = $38;
      var $_c_pre_phi = $_c2;
      __label__ = 12;
      break;
    } else {
      var $pnu_04 = $pnu_0;
      __label__ = 11;
      break;
    }
   case 12:
    var $_c_pre_phi;
    var $41;
    var $43 = $_1 + 44 | 0;
    var $48 = $41 | HEAP32[$43 >> 2] & 2312;
    HEAP32[$pn + 44 >> 2] = $48;
    HEAP32[$pn + 28 >> 2] = $26;
    __ZN11JSParseNode7setDefnEb($26, 0);
    __ZN11JSParseNode7setUsedEb($26, 1);
    HEAP32[$_1 + 36 >> 2] = $_c_pre_phi;
    __ZN2js11UpvarCookie8makeFreeEv($_1 + 40 | 0);
    var $54 = HEAP32[$43 >> 2] & -513;
    HEAP32[$43 >> 2] = $54;
    var $_0 = $26;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14MakeDefIntoUseP12JSDefinitionP11JSParseNodeP6JSAtomP13JSTreeContext["X"] = 1;

function __ZN2js14AtomDefnMapPtr10lookupDefnEP6JSAtom($this_0_0_0_val, $atom) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $atom;
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6lookupERKS2_($p, $this_0_0_0_val, $1);
    var $2 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrcvPPPPPPPS6_Ev($p);
    if (($2 | 0) == 0) {
      var $8 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3Ptr5valueEv($p);
    var $8 = HEAP32[$5 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6removeERKS2_($this, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6lookupERKS2_($p, $this, $key);
    var $1 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrcvPPPPPPPS6_Ev($p);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $p_idx_val = HEAP32[$p >> 2];
    var $p_idx1_val = HEAP32[$p + 4 >> 2];
    var $p_idx2_val = HEAP8[$p + 8 | 0];
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6removeENS5_3PtrE($this, $p_idx_val, $p_idx1_val, $p_idx2_val);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL6DefineP11JSParseNodeP6JSAtomP13JSTreeContextb($pn, $atom, $tc, $let) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $atom;
    if ($let) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$tc + 44 >> 2];
    var $3 = __ZN2js9AtomDecls11lookupFirstEP6JSAtom($_idx_val, $atom);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $dn_1 = $3;
      var $foundLexdep_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_idx1_val = HEAP32[$tc + 64 >> 2];
    var $5 = __ZN2js14AtomDefnMapPtr10lookupDefnEP6JSAtom($_idx1_val, $atom);
    var $dn_1 = $5;
    var $foundLexdep_0 = ($5 | 0) != 0;
    __label__ = 4;
    break;
   case 4:
    var $foundLexdep_0;
    var $dn_1;
    if (($dn_1 | 0) == 0 | ($dn_1 | 0) == ($pn | 0)) {
      var $55 = $atom;
      __label__ = 17;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $dn_1 + 28 | 0;
    if ($let) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $15 = $pn + 44 | 0;
    var $22 = HEAPU32[$15 >> 2] >>> 12;
    var $_pre_phi5 = $15;
    __label__ = 8;
    break;
   case 7:
    var $22 = HEAP32[$tc + 4 >> 2];
    var $_pre_phi5 = $pn + 44 | 0;
    __label__ = 8;
    break;
   case 8:
    var $_pre_phi5;
    var $22;
    var $_c = $pn;
    var $pnup_0 = $12;
    __label__ = 9;
    break;
   case 9:
    var $pnup_0;
    var $24 = HEAPU32[$pnup_0 >> 2];
    var $25 = ($24 | 0) != 0;
    if ($25) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $29 = HEAPU32[$24 + 44 >> 2];
    if ($29 >>> 12 >>> 0 < $22 >>> 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    HEAP32[$24 + 36 >> 2] = $_c;
    var $36 = HEAP32[$_pre_phi5 >> 2] | $29 & 2312;
    HEAP32[$_pre_phi5 >> 2] = $36;
    var $pnup_0 = $24 + 28 | 0;
    __label__ = 9;
    break;
   case 12:
    if (($24 | 0) == (HEAP32[$12 >> 2] | 0)) {
      var $55 = $atom;
      __label__ = 17;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $41 = $pn + 28 | 0;
    var $42 = HEAP32[$41 >> 2];
    HEAP32[$pnup_0 >> 2] = $42;
    var $43 = HEAP32[$12 >> 2];
    HEAP32[$41 >> 2] = $43;
    HEAP32[$12 >> 2] = $24;
    if ($25) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    if (HEAPU32[$24 + 44 >> 2] >>> 12 >>> 0 >= HEAPU32[$tc + 4 >> 2] >>> 0 | $foundLexdep_0 ^ 1) {
      var $55 = $atom;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    if ($foundLexdep_0) {
      __label__ = 16;
      break;
    } else {
      var $55 = $atom;
      __label__ = 17;
      break;
    }
   case 16:
    var $_idx2_val = HEAP32[$tc + 64 >> 2];
    var $53 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($_idx2_val);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6removeERKS2_($53, $1);
    var $55 = HEAP32[$1 >> 2];
    __label__ = 17;
    break;
   case 17:
    var $55;
    var $56 = $tc + 40 | 0;
    if ($let) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $58 = $56;
    var $59 = $pn;
    var $60 = __ZN2js9AtomDecls9addShadowEP6JSAtomP12JSDefinition($58, $55, $59);
    if ($60) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 19:
    var $62 = $pn;
    var $63 = __ZN2js9AtomDecls9addUniqueEP6JSAtomP12JSDefinition($56, $55, $62);
    if ($63) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 20:
    __ZN11JSParseNode7setDefnEb($pn, 1);
    var $66 = $pn + 44 | 0;
    var $67 = HEAP32[$66 >> 2];
    var $68 = $67 & -129;
    HEAP32[$66 >> 2] = $68;
    if ((HEAP32[$tc + 72 >> 2] | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 1;
      __label__ = 22;
      break;
    }
   case 21:
    var $74 = $67 & -145 | 16;
    HEAP32[$66 >> 2] = $74;
    var $_0 = 1;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL6DefineP11JSParseNodeP6JSAtomP13JSTreeContextb["X"] = 1;

function __ZL13EnterFunctionP11JSParseNodeP13JSTreeContextP6JSAtomN2js18FunctionSyntaxKindE($fn, $funtc, $funAtom, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$funtc + 72 >> 2];
    var $3 = $2 + 48 | 0;
    var $4 = HEAP32[$3 >> 2];
    var $5 = __ZN2js6Parser11newFunctionEP13JSTreeContextP6JSAtomNS_18FunctionSyntaxKindE($4, $2, $funAtom, $kind);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$3 >> 2];
    var $9 = $5 | 0;
    var $10 = __ZN2js6Parser14newFunctionBoxEP8JSObjectP11JSParseNodeP13JSTreeContext($8, $9, $fn, $2);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = $funtc | 0;
    var $17 = HEAP32[$15 >> 2] | HEAP32[$10 + 60 >> 2];
    HEAP32[$15 >> 2] = $17;
    var $19 = HEAP32[$2 + 8 >> 2];
    HEAP32[$funtc + 8 >> 2] = $19;
    var $21 = $funtc + 4 | 0;
    var $22 = __ZL15GenerateBlockIdP13JSTreeContextRj($funtc, $21);
    if ($22) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $24 = $funtc;
    __ZN13JSTreeContext11setFunctionEP10JSFunction($24, $5);
    HEAP32[$funtc + 80 >> 2] = $10;
    var $28 = HEAP32[$2 + 76 >> 2] + 1 | 0;
    var $29 = __ZL14SetStaticLevelP13JSTreeContextj($funtc, $28);
    var $_ = $29 ? $10 : 0;
    var $_0 = $_;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13AtomDeclsIterC1EPNS_9AtomDeclsE($this, $decls_0_1_val) {
  __ZN2js13AtomDeclsIterC2EPNS_9AtomDeclsE($this, $decls_0_1_val);
  return;
}

function __ZN2js13AtomDeclsIterclEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$3 >> 2];
    var $9 = HEAP32[$3 + 4 >> 2];
    HEAP32[$2 >> 2] = $9;
    var $_0 = $7;
    __label__ = 7;
    break;
   case 3:
    var $11 = $this | 0;
    var $12 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range5emptyEv($11);
    if ($12) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range5frontEv($1, $11);
    var $_idx1_val = HEAP32[$1 + 4 >> 2];
    var $14 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Entry5valueEv($_idx1_val);
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range8popFrontEv($11);
    var $15 = $14;
    var $16 = __ZNK2js12DefnOrHeader8isHeaderEv($15);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx_val = HEAP32[$14 >> 2];
    var $18 = __ZNK2js12DefnOrHeader4defnEv($_idx_val);
    var $_0 = $18;
    __label__ = 7;
    break;
   case 6:
    var $21 = __ZNK2js12DefnOrHeader6headerEv($15);
    var $24 = HEAP32[$21 + 4 >> 2];
    HEAP32[$2 >> 2] = $24;
    var $_0 = HEAP32[$21 >> 2];
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17BindLocalVariableP9JSContextP13JSTreeContextP11JSParseNodeN2js11BindingKindE($cx, $tc, $pn, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP16[$tc + 98 >> 1];
    var $4 = HEAP32[$pn + 32 >> 2];
    var $5 = $tc + 92 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8Bindings3addEP9JSContextP6JSAtomNS_11BindingKindE($5, $6, $4, $kind);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = __ZNK2js8Bindings9countVarsEv($_idx_val);
    var $11 = $pn + 40 | 0;
    var $14 = HEAP32[$tc + 76 >> 2] & 65535;
    __ZN2js11UpvarCookie3setEtt($11, $14, $9);
    var $16 = $pn + 44 | 0;
    var $18 = HEAP32[$16 >> 2] | 512;
    HEAP32[$16 >> 2] = $18;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream8getTokenEj($this, $withFlags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $flagger = __stackBase__;
  __ZN2js11TokenStream7FlaggerC1EPS0_j($flagger, $this, $withFlags);
  var $1 = __ZN2js11TokenStream8getTokenEv($this);
  var $flagger_idx_val = HEAP32[$flagger >> 2];
  var $flagger_idx1_val = HEAP32[$flagger + 4 >> 2];
  __ZN2js11TokenStream7FlaggerD1Ev($flagger_idx_val, $flagger_idx1_val);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZL22MatchOrInsertSemicolonP9JSContextPN2js11TokenStreamE($ts) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11TokenStream17peekTokenSameLineEj($ts);
    if (($1 | 0) == 26 || ($1 | 0) == 2 || ($1 | 0) == 1 || ($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else if (($1 | 0) == -1) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2js11TokenStream8getTokenEj($ts, 8);
    var $4 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($ts, 0, 0, 109, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($ts, 2);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12DefineGlobalP11JSParseNodeP15JSCodeGeneratorP6JSAtom($pn, $cg, $atom) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $holder = __stackBase__ + 20;
    var $prop = __stackBase__ + 24;
    var $def = __stackBase__ + 28;
    var $index = __stackBase__ + 40;
    HEAP32[$1 >> 2] = $atom;
    var $_idx4 = $cg + 48 | 0;
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $3 = __ZN13JSTreeContext8compilerEv($_idx4_val);
    var $5 = HEAP32[$3 + 992 >> 2];
    var $7 = HEAP32[$5 >> 2];
    var $_idx3_val = HEAP32[$cg >> 2];
    var $8 = __ZNK13JSTreeContext12compileAndGoEv($_idx3_val);
    if (($7 | 0) == 0 | $8 ^ 1) {
      var $_0 = 1;
      __label__ = 21;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = __ZNK15JSCodeGenerator16compilingForEvalEv($_idx3_val);
    if ($11) {
      var $_0 = 1;
      __label__ = 21;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = $5 + 216 | 0;
    __ZN2js9InlineMapIP6JSAtomjLj24EE12lookupForAddERKS2_($p, $13, $1);
    var $14 = __ZNK2js9InlineMapIP6JSAtomjLj24EE6AddPtrcvPPPPPPPS4_Ev($p);
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 4:
    var $19 = HEAP32[HEAP32[$_idx4 >> 2] + 12 >> 2];
    var $20 = HEAP32[$1 >> 2];
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom2903($20);
    var $22 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($7, $19, $21, $holder, $prop);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $25 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 34);
    if ($25) {
      __label__ = 6;
      break;
    } else {
      var $31 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $31 = HEAP32[$pn + 32 >> 2];
    __label__ = 7;
    break;
   case 7:
    var $31;
    var $32 = HEAP32[$prop >> 2];
    if (($32 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $35 = $32;
    if (($31 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 1;
      __label__ = 21;
      break;
    }
   case 9:
    if (($7 | 0) == (HEAP32[$holder >> 2] | 0)) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 21;
      break;
    }
   case 10:
    var $_idx_val = HEAP8[$32 + 28 | 0];
    var $42 = __ZNK2js5Shape12configurableEv($_idx_val);
    if ($42) {
      var $_0 = 1;
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $44 = __ZNK2js5Shape7hasSlotEv($_idx_val);
    if ($44) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 1;
      __label__ = 21;
      break;
    }
   case 12:
    var $46 = __ZNK2js5Shape26hasDefaultGetterOrIsMethodEv($35);
    if ($46) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 1;
      __label__ = 21;
      break;
    }
   case 13:
    var $_idx2_val = HEAP32[$35 + 20 >> 2];
    var $48 = __ZNK2js5Shape16hasDefaultSetterEv($_idx2_val);
    if ($48) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 1;
      __label__ = 21;
      break;
    }
   case 14:
    var $51 = HEAP32[$35 + 24 >> 2];
    __ZN2js11GlobalScope9GlobalDefC1Ej($def, $51);
    __label__ = 16;
    break;
   case 15:
    __ZN2js11GlobalScope9GlobalDefC1EP6JSAtomP13JSFunctionBox($def, $20, $31);
    __label__ = 16;
    break;
   case 16:
    var $55 = $5 + 8 | 0;
    var $def_0_val = HEAP32[$def >> 2];
    var $def_1_val = HEAP32[$def + 4 >> 2];
    var $def_2_val = HEAP32[$def + 8 >> 2];
    var $56 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE6appendIS2_EEbT_($55, $def_0_val, $def_1_val, $def_2_val);
    if ($56) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 17:
    var $58 = __ZN2js9InlineMapIP6JSAtomjLj24EE5countEv($13);
    HEAP32[$index >> 2] = $58;
    var $59 = __ZN2js9InlineMapIP6JSAtomjLj24EE3addERNS3_6AddPtrERKS2_RKj($13, $p, $1, $index);
    if ($59) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 18:
    var $61 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 34);
    if ($61) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $63 = __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtr5valueEv($p);
    var $64 = HEAP32[$63 >> 2];
    var $67 = HEAP32[$pn + 32 >> 2];
    var $_idx5_val = HEAP32[$5 + 12 >> 2];
    var $69 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEEixEj($_idx5_val, $64);
    var $70 = $69 + 4 | 0;
    HEAP32[$70 >> 2] = $67;
    __label__ = 20;
    break;
   case 20:
    var $73 = $pn + 44 | 0;
    var $75 = HEAP32[$73 >> 2] | 64;
    HEAP32[$73 >> 2] = $75;
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12DefineGlobalP11JSParseNodeP15JSCodeGeneratorP6JSAtom["X"] = 1;

function __ZNK2js11TokenStream23hasOctalCharacterEscapeEv($this_0_5_val) {
  return ($this_0_5_val & 4096 | 0) != 0;
}

function __ZNK2js11TokenStream5isEOFEv($this_0_5_val) {
  return ($this_0_5_val & 2 | 0) != 0;
}

function __ZNK11JSParseNode10isInParensEv($this) {
  return (HEAP32[$this >> 2] & 536870912 | 0) != 0;
}

function __ZN13JSTreeContext22noteHasExtensibleScopeEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 536870912;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZL13LeaveFunctionP11JSParseNodeP13JSTreeContextP6JSAtomN2js18FunctionSyntaxKindE($fn, $funtc, $funAtom, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 88;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $r = __stackBase__ + 4;
    var $atom = __stackBase__ + 24;
    var $2 = __stackBase__ + 28;
    var $3 = __stackBase__ + 36;
    var $outer_dn = __stackBase__ + 44;
    var $p = __stackBase__ + 48;
    var $iter = __stackBase__ + 64;
    HEAP32[$1 >> 2] = $funAtom;
    var $5 = HEAPU32[$funtc + 72 >> 2];
    var $7 = HEAP32[$funtc + 8 >> 2];
    HEAP32[$5 + 8 >> 2] = $7;
    var $11 = HEAPU32[$fn + 32 >> 2];
    var $12 = $funtc | 0;
    var $15 = $11 + 60 | 0;
    var $17 = HEAP32[$15 >> 2] | HEAP32[$12 >> 2] & 629450724;
    HEAP32[$15 >> 2] = $17;
    var $19 = $fn + 44 | 0;
    var $20 = HEAP32[$19 >> 2];
    var $21 = $20 | 4;
    HEAP32[$19 >> 2] = $21;
    var $23 = HEAP32[$5 + 24 >> 2];
    if (($23 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (HEAP16[$23 >> 1] << 16 >> 16 == 4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $30 = $20 | 36;
    HEAP32[$19 >> 2] = $30;
    __label__ = 4;
    break;
   case 4:
    var $32 = $funtc + 64 | 0;
    var $33 = $32 | 0;
    var $_idx7 = $32 | 0;
    var $_idx7_val = HEAP32[$_idx7 >> 2];
    var $34 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($_idx7_val);
    var $35 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5countEv($34);
    if (($35 | 0) == 0) {
      __label__ = 43;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3allEv($r, $34);
    var $38 = ($kind | 0) == 0;
    var $39 = $funtc + 76 | 0;
    var $40 = $funtc + 4 | 0;
    var $41 = $fn + 4 | 0;
    var $42 = $5 + 88 | 0;
    var $_idx8 = $2 | 0;
    var $_idx9 = $3 + 4 | 0;
    var $_idx2 = $5 + 44 | 0;
    var $_idx6 = $5 + 64 | 0;
    var $foundCallee_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $foundCallee_0;
    var $44 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv($r);
    if ($44) {
      __label__ = 37;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5frontEv($2, $r);
    var $_idx8_val = HEAP32[$_idx8 >> 2];
    var $46 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Entry3keyEv($_idx8_val);
    var $47 = HEAPU32[$46 >> 2];
    HEAP32[$atom >> 2] = $47;
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5frontEv($3, $r);
    var $_idx9_val = HEAP32[$_idx9 >> 2];
    var $48 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Entry5valueEv($_idx9_val);
    var $49 = HEAPU32[$48 >> 2];
    if (($47 | 0) == ($funAtom | 0) & $38) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $52 = $49 | 0;
    __ZN11JSParseNode5setOpE4JSOp($52, 131);
    var $54 = $49 + 40 | 0;
    var $56 = HEAP32[$39 >> 2] & 65535;
    __ZN2js11UpvarCookie3setEtt($54, $56, -1);
    var $58 = $49 + 44 | 0;
    var $60 = HEAP32[$58 >> 2] | 512;
    HEAP32[$58 >> 2] = $60;
    var $61 = __ZNK11JSParseNode8isFunArgEv($52);
    if ($61) {
      __label__ = 9;
      break;
    } else {
      var $foundCallee_1 = 1;
      __label__ = 36;
      break;
    }
   case 9:
    var $64 = HEAP32[$15 >> 2] | 1024;
    HEAP32[$15 >> 2] = $64;
    var $foundCallee_1 = 1;
    __label__ = 36;
    break;
   case 10:
    var $66 = HEAPU32[$15 >> 2];
    if (($66 & 32 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 11:
    var $70 = $49 | 0;
    var $71 = __ZNK11JSParseNode10isAssignedEv($70);
    if ($71) {
      __label__ = 12;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 12:
    var $pnu_0_in = $49 + 28 | 0;
    __label__ = 13;
    break;
   case 13:
    var $pnu_0_in;
    var $pnu_0 = HEAPU32[$pnu_0_in >> 2];
    if (($pnu_0 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $77 = __ZNK11JSParseNode10isAssignedEv($pnu_0);
    if ($77) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    if (HEAPU32[$pnu_0 + 44 >> 2] >>> 12 >>> 0 < HEAPU32[$40 >> 2] >>> 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    HEAP32[$15 >> 2] = $66 | 32;
    __label__ = 18;
    break;
   case 17:
    var $pnu_0_in = $pnu_0 + 28 | 0;
    __label__ = 13;
    break;
   case 18:
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $89 = __ZN2js9AtomDecls11lookupFirstEP6JSAtom($_idx2_val, $47);
    HEAP32[$outer_dn >> 2] = $89;
    var $_idx10_val = HEAP32[$12 >> 2];
    var $90 = __ZNK13JSTreeContext9callsEvalEv($_idx10_val);
    var $_pre15_pre = ($89 | 0) == 0;
    if ($90) {
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    if ($_pre15_pre) {
      __label__ = 24;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $93 = HEAP32[$42 >> 2];
    if (($93 | 0) == 0) {
      var $113 = $89;
      __label__ = 29;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $96 = $89 + 4 | 0;
    var $97 = $93 + 4 | 0;
    var $98 = __ZN2js8TokenPosltERKS0_($96, $97);
    if ($98) {
      __label__ = 22;
      break;
    } else {
      var $113 = $89;
      __label__ = 29;
      break;
    }
   case 22:
    var $_idx11_val24 = HEAP32[$49 + 28 >> 2];
    __ZL20DeoptimizeUsesWithinP12JSDefinitionRKN2js8TokenPosE($_idx11_val24, $41);
    var $113 = $89;
    __label__ = 29;
    break;
   case 23:
    var $_idx11_val = HEAP32[$49 + 28 >> 2];
    __ZL20DeoptimizeUsesWithinP12JSDefinitionRKN2js8TokenPosE($_idx11_val, $41);
    if ($_pre15_pre) {
      __label__ = 24;
      break;
    } else {
      var $113 = $89;
      __label__ = 29;
      break;
    }
   case 24:
    var $_idx6_val = HEAP32[$_idx6 >> 2];
    var $100 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($_idx6_val);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE12lookupForAddERKS2_($p, $100, $atom);
    var $101 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrcvPPPPPPPS6_Ev($p);
    if (($101 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $104 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtr5valueEv($p);
    var $105 = HEAP32[$104 >> 2];
    HEAP32[$outer_dn >> 2] = $105;
    var $113 = $105;
    __label__ = 29;
    break;
   case 26:
    var $107 = $49 | 0;
    var $108 = __ZL15MakePlaceholderP11JSParseNodeP13JSTreeContext($107, $5);
    HEAP32[$outer_dn >> 2] = $108;
    if (($108 | 0) == 0) {
      var $_0 = 0;
      __label__ = 51;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $_idx5_val = HEAP32[$_idx6 >> 2];
    var $111 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($_idx5_val);
    var $112 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3addERNS5_6AddPtrERKS2_RKS4_($111, $p, $atom, $outer_dn);
    if ($112) {
      __label__ = 28;
      break;
    } else {
      var $_0 = 0;
      __label__ = 51;
      break;
    }
   case 28:
    var $113 = HEAP32[$outer_dn >> 2];
    __label__ = 29;
    break;
   case 29:
    var $113;
    if (($49 | 0) == ($113 | 0)) {
      __label__ = 30;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    var $_pre_phi20 = $113 + 44 | 0;
    __label__ = 35;
    break;
   case 31:
    var $116 = $49 | 0;
    var $117 = $49 + 28 | 0;
    var $118 = HEAP32[$117 >> 2];
    if (($118 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      var $120 = $118;
      __label__ = 33;
      break;
    }
   case 32:
    var $pnup_0_lcssa = $117;
    var $_c1_pre_phi = $113;
    __label__ = 34;
    break;
   case 33:
    var $120;
    var $_c2 = $113;
    HEAP32[$120 + 36 >> 2] = $_c2;
    var $122 = $120 + 28 | 0;
    var $123 = HEAP32[$122 >> 2];
    if (($123 | 0) == 0) {
      var $pnup_0_lcssa = $122;
      var $_c1_pre_phi = $_c2;
      __label__ = 34;
      break;
    } else {
      var $120 = $123;
      __label__ = 33;
      break;
    }
   case 34:
    var $_c1_pre_phi;
    var $pnup_0_lcssa;
    var $125 = $113 + 28 | 0;
    var $126 = HEAP32[$125 >> 2];
    HEAP32[$pnup_0_lcssa >> 2] = $126;
    HEAP32[$125 >> 2] = $116;
    var $132 = $113 + 44 | 0;
    var $134 = HEAP32[$132 >> 2] | HEAP32[$49 + 44 >> 2] & 3967;
    HEAP32[$132 >> 2] = $134;
    __ZN11JSParseNode7setDefnEb($116, 0);
    __ZN11JSParseNode7setUsedEb($116, 1);
    var $135 = $49 + 36 | 0;
    HEAP32[$135 >> 2] = $_c1_pre_phi;
    var $_pre_phi20 = $132;
    __label__ = 35;
    break;
   case 35:
    var $_pre_phi20;
    var $138 = HEAP32[$_pre_phi20 >> 2] | 2048;
    HEAP32[$_pre_phi20 >> 2] = $138;
    var $foundCallee_1 = $foundCallee_0;
    __label__ = 36;
    break;
   case 36:
    var $foundCallee_1;
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range8popFrontEv($r);
    var $foundCallee_0 = $foundCallee_1;
    __label__ = 6;
    break;
   case 37:
    var $_idx4_val = HEAP32[$_idx7 >> 2];
    var $141 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($_idx4_val);
    var $142 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5countEv($141);
    if (($142 | 0) == ($foundCallee_0 | 0)) {
      __label__ = 42;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $145 = $fn + 36 | 0;
    var $146 = HEAP32[$145 >> 2];
    var $147 = $146;
    var $_idx12_val = HEAP32[$5 + 48 >> 2];
    var $148 = __ZN2js11NameSetNode6createEP13JSTreeContext($_idx12_val);
    var $_c = $148;
    HEAP32[$145 >> 2] = $_c;
    if (($148 | 0) == 0) {
      var $_0 = 0;
      __label__ = 51;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $151 = $148 | 0;
    __ZN11JSParseNode7setKindEN2js9TokenKindE($151, 85);
    var $155 = HEAP32[$145 >> 2] + 4 | 0;
    var $156 = $146 + 4 | 0;
    HEAP32[$155 >> 2] = HEAP32[$156 >> 2];
    HEAP32[$155 + 4 >> 2] = HEAP32[$156 + 4 >> 2];
    HEAP32[$155 + 8 >> 2] = HEAP32[$156 + 8 >> 2];
    HEAP32[$155 + 12 >> 2] = HEAP32[$156 + 12 >> 2];
    if (($foundCallee_0 | 0) == 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $_idx3_val = HEAP32[$_idx7 >> 2];
    var $159 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($_idx3_val);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6removeERKS2_($159, $1);
    __label__ = 41;
    break;
   case 41:
    var $162 = HEAP32[$145 >> 2] + 32 | 0;
    var $164 = HEAP32[$32 >> 2];
    HEAP32[$162 >> 2] = $164;
    __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE8clearMapEv($33);
    var $166 = HEAP32[$145 >> 2] + 36 | 0;
    HEAP32[$166 >> 2] = $147;
    __label__ = 43;
    break;
   case 42:
    var $171 = HEAP32[HEAP32[$funtc + 48 >> 2] + 12 >> 2];
    __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE10releaseMapEP9JSContext($33, $171);
    __label__ = 43;
    break;
   case 43:
    var $_idx1_val = HEAP32[$12 >> 2];
    var $173 = __ZNK13JSTreeContext12inStrictModeEv($_idx1_val);
    if ($173) {
      __label__ = 44;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 44:
    var $_idx_val = HEAP32[HEAP32[$11 + 8 >> 2] + 24 >> 2];
    var $177 = __ZNK8JSObject18getFunctionPrivateEv($_idx_val);
    if (HEAP16[$177 + 56 >> 1] << 16 >> 16 == 0) {
      __label__ = 50;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $_idx13_val = HEAP32[$funtc + 44 >> 2];
    __ZN2js13AtomDeclsIterC1EPNS_9AtomDeclsE($iter, $_idx13_val);
    __label__ = 46;
    break;
   case 46:
    var $182 = __ZN2js13AtomDeclsIterclEv($iter);
    if (($182 | 0) == 0) {
      __label__ = 50;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $185 = __ZN12JSDefinition4kindEv($182);
    if (($185 | 0) == 4) {
      __label__ = 48;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 48:
    var $188 = $182 | 0;
    var $189 = __ZNK11JSParseNode10isAssignedEv($188);
    if ($189) {
      __label__ = 49;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 49:
    var $192 = HEAP32[$15 >> 2] | 16777216;
    HEAP32[$15 >> 2] = $192;
    __label__ = 50;
    break;
   case 50:
    var $193 = $11 + 44 | 0;
    var $194 = $funtc + 92 | 0;
    __ZN2js8Bindings8transferEP9JSContextPS0_($193, $194);
    var $_0 = 1;
    __label__ = 51;
    break;
   case 51:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13LeaveFunctionP11JSParseNodeP13JSTreeContextP6JSAtomN2js18FunctionSyntaxKindE["X"] = 1;

function __ZN2js6Parser12functionStmtEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 40 | 0;
    var $2 = __ZN2js11TokenStream8getTokenEj($1, 32);
    if (($2 | 0) == 29) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZNK2js11TokenStream12currentTokenEv($1);
    var $7 = HEAP32[$5 + 28 >> 2];
    var $9 = HEAP32[$this + 980 >> 2];
    var $_idx_val = HEAP32[$9 + 24 >> 2];
    var $10 = __ZN13JSTreeContext11atBodyLevelEv($_idx_val);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 273, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 4:
    var $_idx1_val = HEAP32[$9 >> 2];
    var $14 = __ZNK13JSTreeContext12inStrictModeEv($_idx1_val);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 8, 267, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $18 = __ZN2js6Parser11functionDefEP6JSAtomNS0_12FunctionTypeENS_18FunctionSyntaxKindE($this, $7, 2, 1);
    var $_0 = $18;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser12functionExprEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 40 | 0;
    var $2 = __ZN2js11TokenStream8getTokenEj($1, 32);
    if (($2 | 0) == 29) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZNK2js11TokenStream12currentTokenEv($1);
    var $name_0 = HEAP32[$5 + 28 >> 2];
    __label__ = 4;
    break;
   case 3:
    __ZN2js11TokenStream10ungetTokenEv($1);
    var $name_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $name_0;
    var $10 = __ZN2js6Parser11functionDefEP6JSAtomNS0_12FunctionTypeENS_18FunctionSyntaxKindE($this, $name_0, 2, 0);
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK11JSParseNode21isStringExprStatementEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode7getKindEv($this);
    if (($1 | 0) == 2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $5 = HEAP32[$this + 32 >> 2];
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK11JSParseNode7getKindEv($5);
    if (($8 | 0) == 31) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = (HEAP32[$5 >> 2] & 536870912 | 0) == 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK11JSParseNode25isEscapeFreeStringLiteralEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 16 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      var $19 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAP32[$this + 4 >> 2];
    var $_idx_val = HEAP32[HEAP32[$this + 32 >> 2] >> 2];
    var $12 = __ZNK8JSString6lengthEv($_idx_val);
    var $19 = ($12 + ($11 + 2) | 0) == (HEAP32[$this + 12 >> 2] | 0);
    __label__ = 3;
    break;
   case 3:
    var $19;
    return $19;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream16setUnexpectedEOFEb($this) {
  __ZN2js11TokenStream7setFlagEbNS_16TokenStreamFlagsE($this, 1, 16);
  return;
}

function __ZN2js6Parser9conditionEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 40 | 0;
    var $2 = __ZN2js11TokenStream8getTokenEj($1, 0);
    if (($2 | 0) == 27) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 74, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 11;
    break;
   case 3:
    var $7 = __ZN2js6Parser9parenExprEPi($this, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZN2js11TokenStream8getTokenEj($1, 0);
    if (($10 | 0) == 28) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 75, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 11;
    break;
   case 6:
    var $15 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($7, 4);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    var $17 = __ZNK11JSParseNode4isOpE4JSOp($7, 0);
    if ($17) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $19 = __ZNK11JSParseNode10isInParensEv($7);
    if ($19) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $21 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 5, 112, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = __str17668 | 0, tempInt));
    if ($21) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $_0 = $7;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser9parenExprEPi($this, $genexp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $guard = __stackBase__;
    var $1 = $this + 40 | 0;
    var $2 = __ZNK2js11TokenStream12currentTokenEv($1);
    var $tmp4 = HEAP32[$2 + 4 >> 2];
    var $tmp6 = HEAP32[$2 + 8 >> 2];
    var $3 = ($genexp | 0) != 0;
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$genexp >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    var $7 = HEAP32[$this + 980 >> 2];
    __ZN11GenexpGuardC1EP13JSTreeContext($guard, $7);
    var $8 = __ZN2js6Parser13bracketedExprEv($this);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $guard_idx_val = HEAP32[$guard >> 2];
    __ZN11GenexpGuard7endBodyEv($guard_idx_val);
    var $11 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($1, 42);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 5:
    var $guard_idx2_val = HEAP32[$guard + 4 >> 2];
    var $guard_idx3_val = HEAP32[$guard + 8 >> 2];
    var $13 = __ZN11GenexpGuard14checkValidBodyEP11JSParseNode($guard_idx_val, $guard_idx2_val, $guard_idx3_val, $8);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 6:
    var $15 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($8, 3);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $17 = __ZNK11JSParseNode10isInParensEv($8);
    if ($17) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx_val = HEAP32[$8 + 36 >> 2];
    var $19 = __ZNK11JSParseNode4lastEv($_idx_val);
    var $20 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $19, 0, 215, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str2323384 | 0, tempInt));
    var $_0 = 0;
    __label__ = 16;
    break;
   case 9:
    var $22 = __ZN2js6Parser13generatorExprEP11JSParseNode($this, $8);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    HEAP32[$22 + 4 >> 2] = $tmp4;
    HEAP32[$22 + 8 >> 2] = $tmp6;
    if ($3) {
      __label__ = 11;
      break;
    } else {
      var $pn_0 = $22;
      __label__ = 15;
      break;
    }
   case 11:
    var $26 = __ZN2js11TokenStream8getTokenEv($1);
    if (($26 | 0) == 28) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $29 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 215, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str2323384 | 0, tempInt));
    var $_0 = 0;
    __label__ = 16;
    break;
   case 13:
    var $31 = $22 + 12 | 0;
    var $32 = __ZNK2js11TokenStream12currentTokenEv($1);
    var $34 = $32 + 12 | 0;
    var $35 = $31;
    var $36$0 = HEAP32[$34 >> 2];
    var $36$1 = HEAP32[$34 + 4 >> 2];
    HEAP32[$35 >> 2] = $36$0;
    HEAP32[$35 + 4 >> 2] = $36$1;
    HEAP32[$genexp >> 2] = 1;
    var $pn_0 = $22;
    __label__ = 15;
    break;
   case 14:
    var $38 = __ZN11GenexpGuard18maybeNoteGeneratorEP11JSParseNode($guard, $8);
    if ($38) {
      var $pn_0 = $8;
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 15:
    var $pn_0;
    var $_0 = $pn_0;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser9parenExprEPi["X"] = 1;

function __ZN2js6Parser11primaryExprENS_9TokenKindEi($this, $tt, $afterDot) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 308;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $seen = __stackBase__ + 4;
    var $atom = __stackBase__ + 232;
    var $1 = __stackBase__ + 236;
    var $2 = __stackBase__ + 244;
    var $p = __stackBase__ + 252;
    var $name = __stackBase__ + 268;
    var $3 = __stackBase__ + 272;
    var $genexp = __stackBase__ + 276;
    var $mdl = __stackBase__ + 280;
    var $dn = __stackBase__ + 288;
    var $p2 = __stackBase__ + 292;
    var $5 = $this + 12 | 0;
    var $6 = HEAPU32[$5 >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$6 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($6);
    var $_5 = 0;
    __label__ = 154;
    break;
   case 3:
    if (($tt | 0) == 34) {
      __label__ = 4;
      break;
    } else if (($tt | 0) == 23) {
      __label__ = 8;
      break;
    } else if (($tt | 0) == 25) {
      __label__ = 30;
      break;
    } else if (($tt | 0) == 81) {
      __label__ = 74;
      break;
    } else if (($tt | 0) == 51) {
      __label__ = 75;
      break;
    } else if (($tt | 0) == 52) {
      __label__ = 84;
      break;
    } else if (($tt | 0) == 27) {
      __label__ = 87;
      break;
    } else if (($tt | 0) == 17) {
      __label__ = 91;
      break;
    } else if (($tt | 0) == 70) {
      __label__ = 92;
      break;
    } else if (($tt | 0) == 59) {
      __label__ = 93;
      break;
    } else if (($tt | 0) == 31 || ($tt | 0) == 68 || ($tt | 0) == 67 || ($tt | 0) == 69) {
      __label__ = 94;
      break;
    } else if (($tt | 0) == 29) {
      __label__ = 98;
      break;
    } else if (($tt | 0) == 32) {
      __label__ = 139;
      break;
    } else if (($tt | 0) == 30) {
      __label__ = 148;
      break;
    } else if (($tt | 0) == 33) {
      __label__ = 150;
      break;
    } else if (($tt | 0) == -1) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 152;
      break;
    }
   case 4:
    var $13 = $this + 40 | 0;
    var $14 = __ZN2js11TokenStream10matchTokenENS_9TokenKindEj($13, 71, 32);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $_idx21_val = HEAP32[HEAP32[$this + 980 >> 2] + 48 >> 2];
    var $18 = __ZN2js11NullaryNode6createEP13JSTreeContext($_idx21_val);
    var $19 = $18 | 0;
    if (($18 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($19, 34);
    var $22 = __ZN2js6Parser15qualifiedSuffixEP11JSParseNode($this, $19);
    if (($22 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      var $pn_0 = $22;
      __label__ = 153;
      break;
    }
   case 7:
    var $25 = __ZN2js6Parser12functionExprEv($this);
    if (($25 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      var $pn_0 = $25;
      __label__ = 153;
      break;
    }
   case 8:
    var $28 = $this + 980 | 0;
    var $_idx24_val = HEAP32[HEAP32[$28 >> 2] + 48 >> 2];
    var $30 = __ZN2js8ListNode6createEP13JSTreeContext($_idx24_val);
    var $31 = $30 | 0;
    if (($30 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($31, 24);
    __ZN11JSParseNode5setOpE4JSOp($31, 89);
    __ZN11JSParseNode9makeEmptyEv($31);
    var $38 = $30 + 44 | 0;
    var $42 = HEAP32[$38 >> 2] & 4095 | HEAP32[HEAP32[$28 >> 2] + 8 >> 2] << 12;
    HEAP32[$38 >> 2] = $42;
    var $43 = $this + 40 | 0;
    var $44 = __ZN2js11TokenStream10matchTokenENS_9TokenKindEj($43, 24, 8);
    if ($44) {
      __label__ = 29;
      break;
    } else {
      var $index_0 = 0;
      __label__ = 10;
      break;
    }
   case 10:
    var $index_0;
    if (($index_0 | 0) == 491520) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $47 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 200, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_5 = 0;
    __label__ = 154;
    break;
   case 12:
    var $49 = __ZN2js11TokenStream9peekTokenEj($43, 8);
    if (($49 | 0) == 24) {
      __label__ = 13;
      break;
    } else if (($49 | 0) == 3) {
      __label__ = 17;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $52 = HEAP32[$38 >> 2] | 16;
    HEAP32[$38 >> 2] = $52;
    __label__ = 22;
    break;
   case 14:
    var $54 = __ZN2js6Parser10assignExprEv($this);
    if (($54 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $57 = __ZN11JSParseNode10isConstantEv($54);
    if ($57) {
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $60 = HEAP32[$38 >> 2] | 2048;
    HEAP32[$38 >> 2] = $60;
    __label__ = 19;
    break;
   case 17:
    var $62 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($43, 3);
    var $_idx20_val = HEAP32[HEAP32[$28 >> 2] + 48 >> 2];
    var $64 = __ZN2js11NullaryNode6createEP13JSTreeContext($_idx20_val);
    var $66 = HEAP32[$38 >> 2] | 3072;
    HEAP32[$38 >> 2] = $66;
    if (($64 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $68 = $64 | 0;
    __ZN11JSParseNode6appendEPS_($31, $68);
    __label__ = 21;
    break;
   case 19:
    __ZN11JSParseNode6appendEPS_($31, $54);
    if (($49 | 0) == 3) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $72 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($43, 3);
    if ($72) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    var $index_0 = $index_0 + 1 | 0;
    __label__ = 10;
    break;
   case 22:
    if (($index_0 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 23:
    var $77 = $30 + 40 | 0;
    if ((HEAP32[$77 >> 2] | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $81 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($43, 42);
    if ($81) {
      __label__ = 25;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 25:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($31, 78);
    var $_idx25 = $30 + 36 | 0;
    var $_idx25_val = HEAP32[$_idx25 >> 2];
    var $83 = __ZNK11JSParseNode4lastEv($_idx25_val);
    HEAP32[$77 >> 2] = 0;
    var $84 = $30 + 32 | 0;
    HEAP32[$_idx25 >> 2] = $84;
    HEAP32[$84 >> 2] = 0;
    var $86 = HEAPU32[$38 >> 2] >>> 12;
    var $87 = __ZN2js6Parser17comprehensionTailEP11JSParseNodejbNS_9TokenKindE4JSOp($this, $83, $86, 0, 79, 207);
    if (($87 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    __ZN11JSParseNode6appendEPS_($31, $87);
    __label__ = 27;
    break;
   case 27:
    var $91 = __ZN2js11TokenStream8getTokenEj($43, 0);
    if (($91 | 0) == 24) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $94 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 105, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_5 = 0;
    __label__ = 154;
    break;
   case 29:
    var $96 = $30 + 12 | 0;
    var $97 = __ZNK2js11TokenStream12currentTokenEv($43);
    var $99 = $97 + 12 | 0;
    var $100 = $96;
    var $st$5$0 = $99 | 0;
    var $101$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $99 + 4 | 0;
    var $101$1 = HEAP32[$st$5$1 >> 2];
    var $st$9$0 = $100 | 0;
    HEAP32[$st$9$0 >> 2] = $101$0;
    var $st$9$1 = $100 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $101$1;
    var $_5 = $31;
    __label__ = 154;
    break;
   case 30:
    __ZN2js9InlineMapIP6JSAtomjLj24EEC1EP9JSContext($seen, $6);
    var $103 = $this + 980 | 0;
    var $_idx23_val = HEAP32[HEAP32[$103 >> 2] + 48 >> 2];
    var $105 = __ZN2js8ListNode6createEP13JSTreeContext($_idx23_val);
    var $106 = $105 | 0;
    if (($105 | 0) == 0) {
      var $_4 = 0;
      __label__ = 73;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($106, 26);
    __ZN11JSParseNode5setOpE4JSOp($106, 89);
    __ZN11JSParseNode9makeEmptyEv($106);
    var $109 = $this + 40 | 0;
    var $111 = $105 + 44 | 0;
    var $_idx34 = $1 | 0;
    var $name_idx2 = $name | 0;
    var $_idx33 = $2 | 0;
    __label__ = 32;
    break;
   case 32:
    var $113 = __ZN2js11TokenStream8getTokenEj($109, 32);
    if (($113 | 0) == 30) {
      __label__ = 33;
      break;
    } else if (($113 | 0) == 29) {
      __label__ = 35;
      break;
    } else if (($113 | 0) == 31) {
      __label__ = 43;
      break;
    } else if (($113 | 0) == 26) {
      __label__ = 71;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 33:
    var $_idx19_val = HEAP32[HEAP32[$103 >> 2] + 48 >> 2];
    var $116 = __ZN2js11NullaryNode6createEP13JSTreeContext($_idx19_val);
    if (($116 | 0) == 0) {
      var $_4 = 0;
      __label__ = 73;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $119 = __ZNK2js11TokenStream12currentTokenEv($109);
    var $121 = $119 + 24 | 0;
    var $122 = (tempDoubleI32[0] = HEAP32[$121 >> 2], tempDoubleI32[1] = HEAP32[$121 + 4 >> 2], tempDoubleF64[0]);
    var $124 = $116 + 32 | 0;
    tempDoubleF64[0] = $122, HEAP32[$124 >> 2] = tempDoubleI32[0], HEAP32[$124 + 4 >> 2] = tempDoubleI32[1];
    var $125 = HEAP32[$5 >> 2];
    __ZN2JSL11DoubleValueEd2907($1, $122);
    var $st$9$0 = $_idx34 | 0;
    var $_idx34_val$0 = HEAP32[$st$9$0 >> 2];
    var $st$9$1 = $_idx34 + 4 | 0;
    var $_idx34_val$1 = HEAP32[$st$9$1 >> 2];
    var $126 = __Z14js_ValueToAtomP9JSContextRKN2JS5ValueEPP6JSAtom($125, $_idx34_val$0, $_idx34_val$1, $atom);
    if ($126) {
      var $_pn = $116;
      __label__ = 46;
      break;
    } else {
      var $_4 = 0;
      __label__ = 73;
      break;
    }
   case 35:
    var $128 = __ZNK2js11TokenStream12currentTokenEv($109);
    var $130 = HEAP32[$128 + 28 >> 2];
    HEAP32[$atom >> 2] = $130;
    var $133 = HEAP32[HEAP32[$5 >> 2] + 52 >> 2];
    if (($130 | 0) == (HEAP32[$133 + 210220 >> 2] | 0)) {
      var $op_0 = 125;
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    if (($130 | 0) == (HEAP32[$133 + 210296 >> 2] | 0)) {
      var $op_0 = 126;
      __label__ = 37;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 37:
    var $op_0;
    var $144 = __ZN2js11TokenStream8getTokenEj($109, 32);
    if (($144 | 0) == 31 || ($144 | 0) == 29) {
      __label__ = 38;
      break;
    } else if (($144 | 0) == 30) {
      __label__ = 39;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 38:
    var $146 = __ZNK2js11TokenStream12currentTokenEv($109);
    var $148 = HEAP32[$146 + 28 >> 2];
    HEAP32[$atom >> 2] = $148;
    var $149 = HEAP32[$103 >> 2];
    var $150 = __ZN2js8NameNode6createEP6JSAtomP13JSTreeContext($148, $149);
    var $151 = $150 | 0;
    if (($150 | 0) == 0) {
      var $_4 = 0;
      __label__ = 73;
      break;
    } else {
      var $pn3_0 = $151;
      __label__ = 42;
      break;
    }
   case 39:
    var $_idx18_val = HEAP32[HEAP32[$103 >> 2] + 48 >> 2];
    var $155 = __ZN2js11NullaryNode6createEP13JSTreeContext($_idx18_val);
    if (($155 | 0) == 0) {
      var $_4 = 0;
      __label__ = 73;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $158 = $155 | 0;
    var $159 = __ZNK2js11TokenStream12currentTokenEv($109);
    var $161 = $159 + 24 | 0;
    var $162 = (tempDoubleI32[0] = HEAP32[$161 >> 2], tempDoubleI32[1] = HEAP32[$161 + 4 >> 2], tempDoubleF64[0]);
    var $164 = $155 + 32 | 0;
    tempDoubleF64[0] = $162, HEAP32[$164 >> 2] = tempDoubleI32[0], HEAP32[$164 + 4 >> 2] = tempDoubleI32[1];
    var $165 = HEAP32[$5 >> 2];
    __ZN2JSL11DoubleValueEd2907($2, $162);
    var $_idx33_val$0 = HEAP32[$_idx33 >> 2];
    var $_idx33_val$1 = HEAP32[$_idx33 + 4 >> 2];
    var $166 = __Z14js_ValueToAtomP9JSContextRKN2JS5ValueEPP6JSAtom($165, $_idx33_val$0, $_idx33_val$1, $atom);
    if ($166) {
      var $pn3_0 = $158;
      __label__ = 42;
      break;
    } else {
      var $_4 = 0;
      __label__ = 73;
      break;
    }
   case 41:
    __ZN2js11TokenStream10ungetTokenEv($109);
    __label__ = 43;
    break;
   case 42:
    var $pn3_0;
    var $170 = HEAP32[$111 >> 2] | 2048;
    HEAP32[$111 >> 2] = $170;
    var $172 = __ZN2js6Parser11functionDefEP6JSAtomNS0_12FunctionTypeENS_18FunctionSyntaxKindE($this, 0, ($op_0 | 0) != 125 & 1, 0);
    var $173 = HEAP32[$103 >> 2];
    var $174 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(6, $op_0, $pn3_0, $172, $173);
    var $pn2_1 = $174;
    var $op_1 = $op_0;
    __label__ = 55;
    break;
   case 43:
    var $176 = __ZNK2js11TokenStream12currentTokenEv($109);
    var $178 = HEAPU32[$176 + 28 >> 2];
    HEAP32[$atom >> 2] = $178;
    var $_idx17_val = HEAP32[HEAP32[$103 >> 2] + 48 >> 2];
    var $180 = __ZN2js11NullaryNode6createEP13JSTreeContext($_idx17_val);
    if (($180 | 0) == 0) {
      var $_4 = 0;
      __label__ = 73;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $183 = $180 + 32 | 0;
    HEAP32[$183 >> 2] = $178;
    var $_pn = $180;
    __label__ = 46;
    break;
   case 45:
    var $185 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 131, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_4 = 0;
    __label__ = 73;
    break;
   case 46:
    var $_pn;
    var $pn3_1 = $_pn | 0;
    var $187 = __ZN2js11TokenStream8getTokenEv($109);
    if (($187 | 0) == 6) {
      __label__ = 47;
      break;
    } else if (($187 | 0) == 26 || ($187 | 0) == 3) {
      __label__ = 52;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 47:
    var $189 = __ZN2js6Parser10assignExprEv($this);
    if (($189 | 0) == 0) {
      __label__ = 49;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    var $192 = __ZN11JSParseNode10isConstantEv($189);
    if ($192) {
      __label__ = 49;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 49:
    if ((HEAP32[$atom >> 2] | 0) == (HEAP32[HEAP32[HEAP32[$5 >> 2] + 52 >> 2] + 210292 >> 2] | 0)) {
      __label__ = 50;
      break;
    } else {
      var $pnval_0 = $189;
      __label__ = 54;
      break;
    }
   case 50:
    var $203 = HEAP32[$111 >> 2] | 2048;
    HEAP32[$111 >> 2] = $203;
    var $pnval_0 = $189;
    __label__ = 54;
    break;
   case 51:
    var $205 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 106, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_4 = 0;
    __label__ = 73;
    break;
   case 52:
    __ZN2js11TokenStream10ungetTokenEv($109);
    var $208 = HEAP32[$111 >> 2] | 2560;
    HEAP32[$111 >> 2] = $208;
    var $209 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn3_1, 29);
    if ($209) {
      __label__ = 53;
      break;
    } else {
      var $pnval_0 = $pn3_1;
      __label__ = 54;
      break;
    }
   case 53:
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn3_1, 6);
    var $212 = HEAP32[$103 >> 2];
    __ZN2js8NameNode10initCommonEP13JSTreeContext($_pn, $212);
    var $pnval_0 = $pn3_1;
    __label__ = 54;
    break;
   case 54:
    var $pnval_0;
    var $214 = HEAP32[$103 >> 2];
    var $215 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(6, 93, $pn3_1, $pnval_0, $214);
    var $pn2_1 = $215;
    var $op_1 = 93;
    __label__ = 55;
    break;
   case 55:
    var $op_1;
    var $pn2_1;
    if (($pn2_1 | 0) == 0) {
      var $_4 = 0;
      __label__ = 73;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    __ZN11JSParseNode6appendEPS_($106, $pn2_1);
    if (($op_1 | 0) == 125) {
      __label__ = 57;
      break;
    } else if (($op_1 | 0) == 126) {
      __label__ = 58;
      break;
    } else {
      var $assignType_0 = 7;
      __label__ = 59;
      break;
    }
   case 57:
    var $assignType_0 = 1;
    __label__ = 59;
    break;
   case 58:
    var $assignType_0 = 2;
    __label__ = 59;
    break;
   case 59:
    var $assignType_0;
    __ZN2js9InlineMapIP6JSAtomjLj24EE12lookupForAddERKS2_($p, $seen, $atom);
    var $222 = __ZNK2js9InlineMapIP6JSAtomjLj24EE6AddPtrcvPPPPPPPS4_Ev($p);
    if (($222 | 0) == 0) {
      __label__ = 68;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 60:
    var $225 = __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtr5valueEv($p);
    var $226 = HEAPU32[$225 >> 2];
    if (($226 & $assignType_0 | 0) == 0) {
      __label__ = 67;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    var $or_cond = ($226 | 0) == 7 & ($assignType_0 | 0) == 7;
    if ($or_cond) {
      __label__ = 62;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 62:
    var $234 = HEAP32[$103 >> 2];
    var $235 = __ZN13JSTreeContext16needStrictChecksEv($234);
    if ($235) {
      __label__ = 63;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 63:
    __ZN16JSAutoByteStringC1Ev($name);
    var $237 = HEAP32[$5 >> 2];
    var $238 = HEAP32[$atom >> 2];
    var $239 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($237, $238, $name);
    if (($239 | 0) == 0) {
      __label__ = 72;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    if ($or_cond) {
      __label__ = 65;
      break;
    } else {
      var $247 = 0;
      __label__ = 66;
      break;
    }
   case 65:
    var $_idx7_val = HEAP32[HEAP32[$103 >> 2] >> 2];
    var $244 = __ZNK13JSTreeContext12inStrictModeEv($_idx7_val);
    var $247 = $244 ^ 1;
    __label__ = 66;
    break;
   case 66:
    var $247;
    var $248 = $247 & 1;
    var $name_idx2_val = HEAP32[$name_idx2 >> 2];
    var $249 = __ZNK16JSAutoByteString3ptrEv($name_idx2_val);
    var $250 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($109, 0, $248, 234, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $249, tempInt));
    __ZN16JSAutoByteStringD1Ev($name_idx2_val);
    if ($250) {
      __label__ = 67;
      break;
    } else {
      var $_4 = 0;
      __label__ = 73;
      break;
    }
   case 67:
    var $252 = $226 | $assignType_0;
    var $253 = __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtr5valueEv($p);
    HEAP32[$253 >> 2] = $252;
    __label__ = 69;
    break;
   case 68:
    HEAP32[$3 >> 2] = $assignType_0;
    var $255 = __ZN2js9InlineMapIP6JSAtomjLj24EE3addERNS3_6AddPtrERKS2_RKj($seen, $p, $atom, $3);
    if ($255) {
      __label__ = 69;
      break;
    } else {
      var $_4 = 0;
      __label__ = 73;
      break;
    }
   case 69:
    var $257 = __ZN2js11TokenStream8getTokenEv($109);
    if (($257 | 0) == 3) {
      __label__ = 32;
      break;
    } else if (($257 | 0) == 26) {
      __label__ = 71;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    var $259 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 107, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_4 = 0;
    __label__ = 73;
    break;
   case 71:
    var $261 = $105 + 12 | 0;
    var $262 = __ZNK2js11TokenStream12currentTokenEv($109);
    var $264 = $262 + 12 | 0;
    var $265 = $261;
    var $st$5$0 = $264 | 0;
    var $266$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $264 + 4 | 0;
    var $266$1 = HEAP32[$st$5$1 >> 2];
    var $st$9$0 = $265 | 0;
    HEAP32[$st$9$0 >> 2] = $266$0;
    var $st$9$1 = $265 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $266$1;
    var $_4 = $106;
    __label__ = 73;
    break;
   case 72:
    var $name_idx_val = HEAP32[$name_idx2 >> 2];
    __ZN16JSAutoByteStringD1Ev($name_idx_val);
    var $_4 = 0;
    __label__ = 73;
    break;
   case 73:
    var $_4;
    __ZN2js9InlineMapIP6JSAtomjLj24EED1Ev($seen);
    var $_5 = $_4;
    __label__ = 154;
    break;
   case 74:
    var $268 = __ZN2js6Parser8letBlockEi($this, 0);
    if (($268 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      var $pn_0 = $268;
      __label__ = 153;
      break;
    }
   case 75:
    var $271 = $this + 980 | 0;
    var $_idx22_val = HEAP32[HEAP32[$271 >> 2] + 48 >> 2];
    var $273 = __ZN2js9UnaryNode6createEP13JSTreeContext($_idx22_val);
    var $274 = $273 | 0;
    if (($273 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 76:
    var $277 = $this + 40 | 0;
    var $278 = __ZNK2js11TokenStream12currentTokenEv($277);
    var $280 = $278 + 24 | 0;
    var $281 = (tempDoubleI32[0] = HEAP32[$280 >> 2], tempDoubleI32[1] = HEAP32[$280 + 4 >> 2], tempDoubleF64[0]);
    var $283 = $273 + 36 | 0;
    var $_c8 = $281 & -1;
    HEAP32[$283 >> 2] = $_c8;
    var $284 = __ZN2js11TokenStream8getTokenEj($277, 8);
    var $285 = __ZN2js6Parser11primaryExprENS_9TokenKindEi($this, $284, 0);
    var $286 = $273 + 32 | 0;
    HEAP32[$286 >> 2] = $285;
    if (($285 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 77:
    var $289 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($285, 52);
    if ($289) {
      __label__ = 82;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 78:
    var $291 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($285, 51);
    if ($291) {
      __label__ = 82;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 79:
    var $293 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($285, 31);
    if ($293) {
      __label__ = 82;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 80:
    var $295 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($285, 30);
    if ($295) {
      __label__ = 82;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 81:
    var $297 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($285, 33);
    if ($297) {
      __label__ = 82;
      break;
    } else {
      __label__ = 83;
      break;
    }
   case 82:
    var $299 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $285, 0, 134, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_5 = 0;
    __label__ = 154;
    break;
   case 83:
    var $302 = HEAP32[$271 >> 2];
    var $303 = __ZN13JSTreeContext16ensureSharpSlotsEv($302);
    if ($303) {
      var $pn_0 = $274;
      __label__ = 153;
      break;
    } else {
      var $_5 = 0;
      __label__ = 154;
      break;
    }
   case 84:
    var $305 = $this + 980 | 0;
    var $_idx16_val = HEAP32[HEAP32[$305 >> 2] + 48 >> 2];
    var $307 = __ZN2js11NullaryNode6createEP13JSTreeContext($_idx16_val);
    var $308 = $307 | 0;
    if (($307 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 85:
    var $312 = HEAP32[$305 >> 2];
    var $313 = __ZN13JSTreeContext16ensureSharpSlotsEv($312);
    if ($313) {
      __label__ = 86;
      break;
    } else {
      var $_5 = 0;
      __label__ = 154;
      break;
    }
   case 86:
    var $315 = $this + 40 | 0;
    var $316 = __ZNK2js11TokenStream12currentTokenEv($315);
    var $318 = $316 + 24 | 0;
    var $319 = (tempDoubleI32[0] = HEAP32[$318 >> 2], tempDoubleI32[1] = HEAP32[$318 + 4 >> 2], tempDoubleF64[0]);
    var $321 = $307 + 36 | 0;
    var $_c7 = $319 & -1;
    HEAP32[$321 >> 2] = $_c7;
    var $pn_0 = $308;
    __label__ = 153;
    break;
   case 87:
    var $323 = __ZN2js6Parser9parenExprEPi($this, $genexp);
    if (($323 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 88;
      break;
    }
   case 88:
    __ZN11JSParseNode11setInParensEb($323, 1);
    if ((HEAP32[$genexp >> 2] | 0) == 0) {
      __label__ = 89;
      break;
    } else {
      var $pn_0 = $323;
      __label__ = 153;
      break;
    }
   case 89:
    var $329 = $this + 40 | 0;
    var $330 = __ZN2js11TokenStream8getTokenEj($329, 0);
    if (($330 | 0) == 28) {
      var $pn_0 = $323;
      __label__ = 153;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 90:
    var $333 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 108, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_5 = 0;
    __label__ = 154;
    break;
   case 91:
    var $335 = __ZN2js6Parser19qualifiedIdentifierEv($this);
    if (($335 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      var $pn_0 = $335;
      __label__ = 153;
      break;
    }
   case 92:
    var $338 = __ZN2js6Parser19attributeIdentifierEv($this);
    if (($338 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      var $pn_0 = $338;
      __label__ = 153;
      break;
    }
   case 93:
    var $341 = __ZN2js6Parser20xmlElementOrListRootEi($this, 1);
    if (($341 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      var $pn_0 = $341;
      __label__ = 153;
      break;
    }
   case 94:
    var $_idx15_val = HEAP32[HEAP32[$this + 980 >> 2] + 48 >> 2];
    var $346 = __ZN2js11NullaryNode6createEP13JSTreeContext($_idx15_val);
    var $347 = $346 | 0;
    if (($346 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 95;
      break;
    }
   case 95:
    var $350 = $this + 40 | 0;
    var $351 = __ZNK2js11TokenStream12currentTokenEv($350);
    var $354 = $346 + 32 | 0;
    var $_c5 = HEAP32[$351 + 28 >> 2];
    HEAP32[$354 >> 2] = $_c5;
    var $355 = ($tt | 0) == 69;
    var $356 = __ZNK2js11TokenStream12currentTokenEv($350);
    if ($355) {
      __label__ = 96;
      break;
    } else {
      __label__ = 97;
      break;
    }
   case 96:
    var $361 = $346 + 36 | 0;
    var $_c6 = HEAP32[$356 + 24 >> 2];
    HEAP32[$361 >> 2] = $_c6;
    var $pn_0 = $347;
    __label__ = 153;
    break;
   case 97:
    var $364 = HEAP32[$356 + 24 >> 2];
    __ZN11JSParseNode5setOpE4JSOp($347, $364);
    var $pn_0 = $347;
    __label__ = 153;
    break;
   case 98:
    var $366 = $this + 40 | 0;
    var $367 = __ZNK2js11TokenStream12currentTokenEv($366);
    var $369 = HEAP32[$367 + 28 >> 2];
    var $370 = $this + 980 | 0;
    var $371 = HEAP32[$370 >> 2];
    var $372 = __ZN2js8NameNode6createEP6JSAtomP13JSTreeContext($369, $371);
    var $373 = $372 | 0;
    if (($372 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 99;
      break;
    }
   case 99:
    __ZN11JSParseNode5setOpE4JSOp($373, 59);
    var $376 = HEAP32[$370 >> 2];
    var $378 = HEAP32[$376 >> 2];
    if (($378 & 66 | 0) == 2) {
      __label__ = 100;
      break;
    } else {
      __label__ = 105;
      break;
    }
   case 100:
    if ((HEAP32[$372 + 32 >> 2] | 0) == (HEAP32[HEAP32[HEAP32[$5 >> 2] + 52 >> 2] + 210176 >> 2] | 0)) {
      __label__ = 101;
      break;
    } else {
      __label__ = 105;
      break;
    }
   case 101:
    __ZN13JSTreeContext16noteArgumentsUseEP11JSParseNode($376, $373);
    if (($afterDot | 0) == 0) {
      __label__ = 102;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 102:
    var $395 = HEAP32[$370 >> 2];
    if ((HEAP32[$395 >> 2] & 65536 | 0) == 0) {
      __label__ = 103;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 103:
    var $401 = $395;
    var $402 = __ZN13JSTreeContext11inStatementE10JSStmtType($401);
    if ($402) {
      __label__ = 132;
      break;
    } else {
      __label__ = 104;
      break;
    }
   case 104:
    __ZN11JSParseNode5setOpE4JSOp($373, 9);
    var $405 = $372 + 44 | 0;
    var $407 = HEAP32[$405 >> 2] | 512;
    HEAP32[$405 >> 2] = $407;
    __label__ = 132;
    break;
   case 105:
    if (($afterDot | 0) == 0) {
      var $415 = $376;
      var $414 = $378;
      __label__ = 108;
      break;
    } else {
      __label__ = 106;
      break;
    }
   case 106:
    var $411 = __ZN2js11TokenStream9peekTokenEv($366);
    if (($411 | 0) == 71) {
      __label__ = 107;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 107:
    var $_pre44 = HEAP32[$370 >> 2];
    var $415 = $_pre44;
    var $414 = HEAP32[$_pre44 >> 2];
    __label__ = 108;
    break;
   case 108:
    var $414;
    var $415;
    if (($414 & 65536 | 0) == 0) {
      __label__ = 109;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 109:
    var $419 = __ZNK13JSTreeContext10inFunctionEv($414);
    var $_pre51 = $372 + 32 | 0;
    if ($419) {
      var $430 = $415;
      var $_pre_phi52 = $_pre51;
      __label__ = 112;
      break;
    } else {
      __label__ = 110;
      break;
    }
   case 110:
    if ((HEAP32[$_pre51 >> 2] | 0) == (HEAP32[HEAP32[HEAP32[$5 >> 2] + 52 >> 2] + 210176 >> 2] | 0)) {
      __label__ = 111;
      break;
    } else {
      var $430 = $415;
      var $_pre_phi52 = $_pre51;
      __label__ = 112;
      break;
    }
   case 111:
    __ZN13JSTreeContext17countArgumentsUseEP11JSParseNode($415, $373);
    var $430 = HEAP32[$370 >> 2];
    var $_pre_phi52 = $_pre51;
    __label__ = 112;
    break;
   case 112:
    var $_pre_phi52;
    var $430;
    var $431 = HEAP32[$_pre_phi52 >> 2];
    var $433 = _js_LexicalLookup($430, $431, 0);
    var $435 = HEAP32[$_pre_phi52 >> 2];
    var $_idx26_val = HEAP32[HEAP32[$370 >> 2] + 44 >> 2];
    __ZN2js9AtomDecls11lookupMultiEP6JSAtom($mdl, $_idx26_val, $435);
    var $mdl_idx28 = $mdl + 4 | 0;
    var $mdl_idx28_val = HEAPU32[$mdl_idx28 >> 2];
    var $436 = __ZNK2js14MultiDeclRange5emptyEv($mdl_idx28_val);
    if ($436) {
      var $mdl_idx29_val = $mdl_idx28_val;
      __label__ = 119;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 113:
    var $438 = __ZN2js14MultiDeclRange5frontEv($mdl_idx28_val);
    var $storemerge = $438;
    var $mdl_idx_val37 = $mdl_idx28_val;
    __label__ = 114;
    break;
   case 114:
    var $mdl_idx_val37;
    var $storemerge;
    var $441 = __ZNK11JSParseNode5isLetEv($storemerge | 0);
    if ($441) {
      __label__ = 115;
      break;
    } else {
      var $mdl_idx_val36 = $mdl_idx_val37;
      __label__ = 118;
      break;
    }
   case 115:
    var $446 = HEAPU32[$storemerge + 44 >> 2] >>> 12;
    var $447 = HEAP32[$370 >> 2];
    var $448 = __ZL14BlockIdInScopejP13JSTreeContext($446, $447);
    if ($448) {
      var $mdl_idx_val36 = $mdl_idx_val37;
      __label__ = 118;
      break;
    } else {
      __label__ = 116;
      break;
    }
   case 116:
    __ZN2js14MultiDeclRange8popFrontEv($mdl);
    var $mdl_idx27_val = HEAPU32[$mdl_idx28 >> 2];
    var $450 = __ZNK2js14MultiDeclRange5emptyEv($mdl_idx27_val);
    if ($450) {
      var $mdl_idx_val36 = $mdl_idx27_val;
      __label__ = 118;
      break;
    } else {
      __label__ = 117;
      break;
    }
   case 117:
    var $452 = __ZN2js14MultiDeclRange5frontEv($mdl_idx27_val);
    var $storemerge = $452;
    var $mdl_idx_val37 = $mdl_idx27_val;
    __label__ = 114;
    break;
   case 118:
    var $mdl_idx_val36;
    HEAP32[$dn >> 2] = $storemerge;
    var $mdl_idx29_val = $mdl_idx_val36;
    __label__ = 119;
    break;
   case 119:
    var $mdl_idx29_val;
    var $453 = __ZNK2js14MultiDeclRange5emptyEv($mdl_idx29_val);
    if ($453) {
      __label__ = 121;
      break;
    } else {
      __label__ = 120;
      break;
    }
   case 120:
    var $455 = __ZN2js14MultiDeclRange5frontEv($mdl_idx29_val);
    HEAP32[$dn >> 2] = $455;
    var $482 = $455;
    __label__ = 127;
    break;
   case 121:
    var $_idx9_val = HEAP32[HEAP32[$370 >> 2] + 64 >> 2];
    var $458 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($_idx9_val);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE12lookupForAddERKS2_($p2, $458, $_pre_phi52);
    var $459 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrcvPPPPPPPS6_Ev($p2);
    if (($459 | 0) == 0) {
      __label__ = 123;
      break;
    } else {
      __label__ = 122;
      break;
    }
   case 122:
    var $462 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtr5valueEv($p2);
    var $463 = HEAP32[$462 >> 2];
    HEAP32[$dn >> 2] = $463;
    var $482 = $463;
    __label__ = 127;
    break;
   case 123:
    var $465 = HEAP32[$370 >> 2];
    var $466 = __ZL15MakePlaceholderP11JSParseNodeP13JSTreeContext($373, $465);
    HEAP32[$dn >> 2] = $466;
    if (($466 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 124;
      break;
    }
   case 124:
    var $_idx8_val = HEAP32[HEAP32[$370 >> 2] + 64 >> 2];
    var $470 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($_idx8_val);
    var $472 = $466 + 32 | 0;
    var $473 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3addERNS5_6AddPtrERKS2_RKS4_($470, $p2, $472, $dn);
    if ($473) {
      __label__ = 125;
      break;
    } else {
      var $_5 = 0;
      __label__ = 154;
      break;
    }
   case 125:
    var $475 = __ZN2js11TokenStream9peekTokenEv($366);
    var $_pre46 = HEAP32[$dn >> 2];
    if (($475 | 0) == 27) {
      var $482 = $_pre46;
      __label__ = 127;
      break;
    } else {
      __label__ = 126;
      break;
    }
   case 126:
    var $479 = $_pre46 + 44 | 0;
    var $481 = HEAP32[$479 >> 2] | 256;
    HEAP32[$479 >> 2] = $481;
    var $482 = $_pre46;
    __label__ = 127;
    break;
   case 127:
    var $482;
    __ZL12LinkUseToDefP11JSParseNodeP12JSDefinitionP13JSTreeContext($373, $482);
    var $483 = __ZN2js11TokenStream9peekTokenEv($366);
    var $_phi_trans_insert48 = $482 + 44 | 0;
    var $_pre49 = HEAP32[$_phi_trans_insert48 >> 2];
    if (($483 | 0) == 27) {
      var $487 = $_pre49;
      __label__ = 129;
      break;
    } else {
      __label__ = 128;
      break;
    }
   case 128:
    var $486 = $_pre49 | 256;
    HEAP32[$_phi_trans_insert48 >> 2] = $486;
    var $487 = $486;
    __label__ = 129;
    break;
   case 129:
    var $487;
    var $488 = $487 & 256;
    var $490 = $372 + 44 | 0;
    var $491 = HEAP32[$490 >> 2];
    var $492 = $491 & 3071;
    var $493 = $491 & -4096;
    var $494 = $491 | $488;
    HEAP32[$490 >> 2] = $494;
    if (($433 | 0) == 0) {
      __label__ = 132;
      break;
    } else {
      __label__ = 130;
      break;
    }
   case 130:
    if (HEAP16[$433 >> 1] << 16 >> 16 == 6) {
      __label__ = 131;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 131:
    var $503 = $488 | $493 | $492 | 1024;
    HEAP32[$490 >> 2] = $503;
    __label__ = 132;
    break;
   case 132:
    var $505 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($366, 71);
    if ($505) {
      __label__ = 133;
      break;
    } else {
      var $pn_0 = $373;
      __label__ = 153;
      break;
    }
   case 133:
    if (($afterDot | 0) == 0) {
      __label__ = 138;
      break;
    } else {
      __label__ = 134;
      break;
    }
   case 134:
    var $511 = HEAP32[$372 + 32 >> 2];
    var $512 = $511 | 0;
    var $513 = __ZNK12JSFlatString6charsZEv($512);
    var $_idx_val = HEAP32[$511 >> 2];
    var $514 = __ZNK8JSString6lengthEv($_idx_val);
    var $515 = __ZN2js11FindKeywordEPKtj($513, $514);
    if (($515 | 0) == 0) {
      __label__ = 138;
      break;
    } else {
      __label__ = 135;
      break;
    }
   case 135:
    if ((HEAP32[$515 + 4 >> 2] | 0) == 34) {
      __label__ = 137;
      break;
    } else {
      __label__ = 136;
      break;
    }
   case 136:
    var $522 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 213, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_5 = 0;
    __label__ = 154;
    break;
   case 137:
    __ZN11JSParseNode8setArityE16JSParseNodeArity($373, 0);
    __ZN11JSParseNode7setKindEN2js9TokenKindE($373, 34);
    __label__ = 138;
    break;
   case 138:
    var $525 = __ZN2js6Parser15qualifiedSuffixEP11JSParseNode($this, $373);
    if (($525 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      var $pn_0 = $525;
      __label__ = 153;
      break;
    }
   case 139:
    var $528 = $this + 980 | 0;
    var $_idx14_val = HEAP32[HEAP32[$528 >> 2] + 48 >> 2];
    var $530 = __ZN2js11NullaryNode6createEP13JSTreeContext($_idx14_val);
    var $531 = $530 | 0;
    if (($530 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 140;
      break;
    }
   case 140:
    var $534 = HEAP32[$5 >> 2];
    var $535 = __ZNK9JSContext5hasfpEv($534);
    if ($535) {
      __label__ = 141;
      break;
    } else {
      __label__ = 142;
      break;
    }
   case 141:
    var $537 = __ZN9JSContext13regExpStaticsEv($534);
    var $538 = $this + 40 | 0;
    var $539 = __ZNK2js11TokenStream11getTokenbufEv($538);
    var $_idx6_val = HEAP32[$539 + 4 >> 2];
    var $540 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5beginEv($_idx6_val);
    var $_idx4_val = HEAP32[$539 + 8 >> 2];
    var $541 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv($_idx4_val);
    var $542 = __ZNK2js11TokenStream12currentTokenEv($538);
    var $544 = HEAP32[$542 + 24 >> 2];
    var $_idx32_val = HEAP32[$537 + 100 >> 2];
    var $545 = __ZN2js6RegExp12createObjectEP9JSContextPNS_13RegExpStaticsEPKtjjPNS_11TokenStreamE($534, $_idx32_val, $540, $541, $544);
    var $obj_0 = $545;
    __label__ = 143;
    break;
   case 142:
    var $547 = $this + 40 | 0;
    var $548 = __ZNK2js11TokenStream11getTokenbufEv($547);
    var $_idx5_val = HEAP32[$548 + 4 >> 2];
    var $549 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5beginEv($_idx5_val);
    var $_idx3_val = HEAP32[$548 + 8 >> 2];
    var $550 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv($_idx3_val);
    var $551 = __ZNK2js11TokenStream12currentTokenEv($547);
    var $553 = HEAP32[$551 + 24 >> 2];
    var $554 = __ZN2js6RegExp21createObjectNoStaticsEP9JSContextPKtjjPNS_11TokenStreamE($534, $549, $550, $553);
    var $obj_0 = $554;
    __label__ = 143;
    break;
   case 143:
    var $obj_0;
    if (($obj_0 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 144;
      break;
    }
   case 144:
    var $558 = HEAP32[$528 >> 2];
    var $_idx11_val = HEAP32[$558 >> 2];
    var $559 = __ZNK13JSTreeContext12compileAndGoEv($_idx11_val);
    if ($559) {
      var $562 = $558;
      __label__ = 146;
      break;
    } else {
      __label__ = 145;
      break;
    }
   case 145:
    __ZN8JSObject11clearParentEv($obj_0);
    __ZN8JSObject9clearTypeEv($obj_0);
    var $562 = HEAP32[$528 >> 2];
    __label__ = 146;
    break;
   case 146:
    var $562;
    var $564 = HEAP32[$562 + 48 >> 2];
    var $565 = __ZN2js6Parser12newObjectBoxEP8JSObject($564, $obj_0);
    var $566 = $530 + 32 | 0;
    var $_c = $565;
    HEAP32[$566 >> 2] = $_c;
    if (($565 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 147;
      break;
    }
   case 147:
    __ZN11JSParseNode5setOpE4JSOp($531, 162);
    var $pn_0 = $531;
    __label__ = 153;
    break;
   case 148:
    var $_idx13_val = HEAP32[HEAP32[$this + 980 >> 2] + 48 >> 2];
    var $572 = __ZN2js11NullaryNode6createEP13JSTreeContext($_idx13_val);
    var $573 = $572 | 0;
    if (($572 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 149;
      break;
    }
   case 149:
    __ZN11JSParseNode5setOpE4JSOp($573, 60);
    var $576 = $this + 40 | 0;
    var $577 = __ZNK2js11TokenStream12currentTokenEv($576);
    var $579 = $577 + 24 | 0;
    var $580 = (tempDoubleI32[0] = HEAP32[$579 >> 2], tempDoubleI32[1] = HEAP32[$579 + 4 >> 2], tempDoubleF64[0]);
    var $582 = $572 + 32 | 0;
    tempDoubleF64[0] = $580, HEAP32[$582 >> 2] = tempDoubleI32[0], HEAP32[$582 + 4 >> 2] = tempDoubleI32[1];
    var $pn_0 = $573;
    __label__ = 153;
    break;
   case 150:
    var $_idx12_val = HEAP32[HEAP32[$this + 980 >> 2] + 48 >> 2];
    var $586 = __ZN2js11NullaryNode6createEP13JSTreeContext($_idx12_val);
    var $587 = $586 | 0;
    if (($586 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 151;
      break;
    }
   case 151:
    var $590 = $this + 40 | 0;
    var $591 = __ZNK2js11TokenStream12currentTokenEv($590);
    var $593 = HEAP32[$591 + 24 >> 2];
    __ZN11JSParseNode5setOpE4JSOp($587, $593);
    var $pn_0 = $587;
    __label__ = 153;
    break;
   case 152:
    var $595 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 133, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_5 = 0;
    __label__ = 154;
    break;
   case 153:
    var $pn_0;
    var $_5 = $pn_0;
    __label__ = 154;
    break;
   case 154:
    var $_5;
    STACKTOP = __stackBase__;
    return $_5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser11primaryExprENS_9TokenKindEi["X"] = 1;

function __ZL18CheckDestructuringP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($cx, $data, $left, $tc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($left, 78);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $7 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($6, $left, 0, 216, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 33;
    break;
   case 3:
    var $9 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($left, 24);
    var $11 = HEAPU32[$left + 32 >> 2];
    var $12 = ($data | 0) == 0;
    if ($9) {
      var $pn_0 = $11;
      __label__ = 4;
      break;
    } else {
      var $pair_0 = $11;
      __label__ = 17;
      break;
    }
   case 4:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_0, 3);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $17 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn_0, 0);
    if ($17) {
      __label__ = 16;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_0, 24);
    if ($19) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_0, 26);
    if ($21) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $23 = __ZL18CheckDestructuringP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($cx, $data, $pn_0, $tc);
    var $ok_0 = $23 & 1;
    __label__ = 15;
    break;
   case 10:
    if ($12) {
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $27 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_0, 29);
    if ($27) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $31 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $32 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($31, $pn_0, 0, 102, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 33;
    break;
   case 13:
    var $34 = __ZL20BindDestructuringVarP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($cx, $data, $pn_0, $tc);
    var $ok_0 = ($34 | 0) != 0 & 1;
    __label__ = 15;
    break;
   case 14:
    var $38 = __ZL20BindDestructuringLHSP9JSContextP11JSParseNodeP13JSTreeContext($cx, $pn_0, $tc);
    var $ok_0 = ($38 | 0) != 0 & 1;
    __label__ = 15;
    break;
   case 15:
    var $ok_0;
    if ($ok_0 << 24 >> 24 == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $pn_0 = HEAP32[$pn_0 + 24 >> 2];
    __label__ = 4;
    break;
   case 17:
    var $pair_0;
    if (($pair_0 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $50 = HEAP32[$pair_0 + 36 >> 2];
    var $51 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($50, 24);
    if ($51) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $53 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($50, 26);
    if ($53) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $55 = __ZL18CheckDestructuringP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($cx, $data, $50, $tc);
    var $ok_1 = $55 & 1;
    __label__ = 26;
    break;
   case 21:
    if ($12) {
      __label__ = 25;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $59 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($50, 29);
    if ($59) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $63 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $64 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($63, $50, 0, 102, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 33;
    break;
   case 24:
    var $66 = __ZL20BindDestructuringVarP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($cx, $data, $50, $tc);
    var $ok_1 = ($66 | 0) != 0 & 1;
    __label__ = 26;
    break;
   case 25:
    var $70 = __ZL20BindDestructuringLHSP9JSContextP11JSParseNodeP13JSTreeContext($cx, $50, $tc);
    var $ok_1 = ($70 | 0) != 0 & 1;
    __label__ = 26;
    break;
   case 26:
    var $ok_1;
    if ($ok_1 << 24 >> 24 == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $pair_0 = HEAP32[$pair_0 + 24 >> 2];
    __label__ = 17;
    break;
   case 28:
    if ($12) {
      __label__ = 32;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    if ((HEAP32[$data + 8 >> 2] | 0) == 202) {
      __label__ = 30;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 30:
    var $83 = $tc + 32 | 0;
    var $_idx1_val = HEAP32[$83 >> 2];
    var $84 = __ZN13JSTreeContext10blockChainEv($_idx1_val);
    var $85 = $84;
    var $86 = __ZNK8JSObject13propertyCountEv($85);
    if (($86 | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    var $_idx_val = HEAP32[$83 >> 2];
    var $89 = __ZN13JSTreeContext10blockChainEv($_idx_val);
    var $94 = HEAP32[HEAP32[$cx + 52 >> 2] + 209972 >> 2] | 0;
    var $95 = __ZL12ATOM_TO_JSIDP6JSAtom2903($94);
    __ZN2JSL14UndefinedValueEv2937($1);
    var $96 = $cx;
    var $97 = $89;
    var $98 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($96, $97, $95, $1, 0, 0, 5, 64, 0, 0);
    if (($98 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $_0 = 1;
    __label__ = 33;
    break;
   case 33:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18CheckDestructuringP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext["X"] = 1;

function __ZN2js6Parser13returnOrYieldEb($this, $useAssignExpr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 40 | 0;
    var $2 = __ZNK2js11TokenStream12currentTokenEv($1);
    var $4 = HEAP32[$2 >> 2];
    var $5 = $this + 980 | 0;
    var $6 = HEAP32[$5 >> 2];
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK13JSTreeContext10inFunctionEv($_idx1_val);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_ = ($4 | 0) == 48 ? STRING_TABLE.__str30460 : STRING_TABLE._js_yield_str;
    var $10 = $_ | 0;
    var $11 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 124, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $10, tempInt));
    var $_0 = 0;
    __label__ = 26;
    break;
   case 3:
    var $_idx2_val = HEAP32[$6 + 48 >> 2];
    var $13 = __ZN2js9UnaryNode6createEP13JSTreeContext($_idx2_val);
    var $14 = $13 | 0;
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = ($4 | 0) == 77;
    if ($17) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $19 = HEAP32[$5 >> 2];
    if ((HEAP32[$19 + 12 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $24 = $19 | 0;
    var $26 = HEAP32[$24 >> 2] | 512;
    HEAP32[$24 >> 2] = $26;
    __label__ = 8;
    break;
   case 7:
    var $28 = $19 + 16 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $32 = HEAP32[$5 >> 2] + 52 | 0;
    HEAP32[$32 >> 2] = $14;
    __label__ = 8;
    break;
   case 8:
    var $34 = __ZN2js11TokenStream17peekTokenSameLineEj($1);
    if (($34 | 0) == 26 || ($34 | 0) == 2 || ($34 | 0) == 1 || ($34 | 0) == 0) {
      __label__ = 18;
      break;
    } else if (($34 | 0) == -1) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ($17) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    if (($34 | 0) == 28 || ($34 | 0) == 24 || ($34 | 0) == 6 || ($34 | 0) == 3) {
      __label__ = 18;
      break;
    } else if (($34 | 0) == 77) {
      __label__ = 20;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    if ($useAssignExpr) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $39 = __ZN2js6Parser10assignExprEv($this);
    var $43 = $39;
    __label__ = 14;
    break;
   case 13:
    var $41 = __ZN2js6Parser4exprEv($this);
    var $43 = $41;
    __label__ = 14;
    break;
   case 14:
    var $43;
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    if (($4 | 0) == 48) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $49 = HEAP32[$5 >> 2] | 0;
    var $51 = HEAP32[$49 >> 2] | 4;
    HEAP32[$49 >> 2] = $51;
    __label__ = 17;
    break;
   case 17:
    var $55 = $43 + 12 | 0;
    var $56 = $13 + 12 | 0;
    var $57$0 = HEAP32[$55 >> 2];
    var $57$1 = HEAP32[$55 + 4 >> 2];
    var $st$8$0 = $56 | 0;
    HEAP32[$st$8$0 >> 2] = $57$0;
    var $st$8$1 = $56 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $57$1;
    var $58 = $13 + 32 | 0;
    HEAP32[$58 >> 2] = $43;
    __label__ = 20;
    break;
   case 18:
    if (($4 | 0) == 48) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $63 = HEAP32[$5 >> 2] | 0;
    var $65 = HEAP32[$63 >> 2] | 8;
    HEAP32[$63 >> 2] = $65;
    __label__ = 20;
    break;
   case 20:
    var $66 = HEAP32[$5 >> 2];
    var $68 = HEAP32[$66 >> 2];
    var $72 = HEAP32[$this + 12 >> 2];
    if (($68 & 516 | 0) == 516) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    var $74 = __ZL15ReportBadReturnP9JSContextP13JSTreeContextP11JSParseNodejjj($72, $66, $14, 0, 208, 209);
    var $_0 = 0;
    __label__ = 26;
    break;
   case 22:
    var $_idx_val = HEAP32[$72 + 32 >> 2];
    var $76 = __ZNK9JSContext15hasStrictOptionEv($_idx_val);
    if ($76) {
      __label__ = 23;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 23:
    if (($68 & 12 | 0) == 12) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $81 = __ZL15ReportBadReturnP9JSContextP13JSTreeContextP11JSParseNodejjj($72, $66, $14, 5, 110, 157);
    if (($81 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $_0 = $14;
    __label__ = 26;
    break;
   case 26:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser13returnOrYieldEb["X"] = 1;

function __ZN2js11TokenStream17peekTokenSameLineEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js11TokenStream12currentTokenEv($this);
    var $this_idx_val = HEAP32[$this + 140 >> 2];
    var $_idx_val = HEAP32[$1 + 16 >> 2];
    var $2 = __ZNK2js11TokenStream13onCurrentLineERKNS_8TokenPosE($this_idx_val, $_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 2:
    var $5 = HEAP32[$this + 136 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_0 = HEAP32[$this + 4 + ((HEAP32[$this + 132 >> 2] + $5 & 3) << 5) >> 2];
    __label__ = 7;
    break;
   case 4:
    var $15 = $this + 144 | 0;
    var $17 = HEAP32[$15 >> 2] & -5;
    HEAP32[$15 >> 2] = $17;
    var $18 = __ZN2js11TokenStream8getTokenEj($this, 8);
    var $19 = HEAP32[$15 >> 2];
    if (($19 & 4 | 0) == 0) {
      var $tt_0 = $18;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $19 & -5;
    HEAP32[$15 >> 2] = $23;
    var $tt_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $tt_0;
    __ZN2js11TokenStream10ungetTokenEv($this);
    var $_0 = $tt_0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser4exprEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser10assignExprEv($this);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $this + 40 | 0;
    var $5 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($4, 3);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $1;
      __label__ = 11;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[HEAP32[$this + 980 >> 2] + 48 >> 2];
    var $9 = __ZN2js8ListNode6createEP13JSTreeContext($_idx_val);
    var $10 = $9 | 0;
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = $1 + 4 | 0;
    var $16 = $9 + 4 | 0;
    var $17$0 = HEAP32[$15 >> 2];
    var $17$1 = HEAP32[$15 + 4 >> 2];
    var $st$8$0 = $16 | 0;
    HEAP32[$st$8$0 >> 2] = $17$0;
    var $st$8$1 = $16 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $17$1;
    __ZN11JSParseNode8initListEPS_($10, $1);
    var $_idx2 = $9 + 36 | 0;
    __label__ = 5;
    break;
   case 5:
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $19 = __ZNK11JSParseNode4lastEv($_idx2_val);
    var $20 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($19, 77);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = __ZNK11JSParseNode10isInParensEv($19);
    if ($22) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $19, 0, 215, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_yield_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 11;
    break;
   case 8:
    var $26 = __ZN2js6Parser10assignExprEv($this);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN11JSParseNode6appendEPS_($10, $26);
    var $29 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($4, 3);
    if ($29) {
      __label__ = 5;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $31 = $9 + 12 | 0;
    var $_idx1_val = HEAP32[$_idx2 >> 2];
    var $32 = __ZNK11JSParseNode4lastEv($_idx1_val);
    var $34 = $32 + 12 | 0;
    var $35 = $31;
    var $36$0 = HEAP32[$34 >> 2];
    var $36$1 = HEAP32[$34 + 4 >> 2];
    var $st$10$0 = $35 | 0;
    HEAP32[$st$10$0 >> 2] = $36$0;
    var $st$10$1 = $35 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $36$1;
    var $_0 = $10;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser4exprEv["X"] = 1;

function __ZN2js6Parser8letBlockEi($this, $statement) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmtInfo = __stackBase__;
    var $1 = $this + 980 | 0;
    var $_idx1_val = HEAP32[HEAP32[$1 >> 2] + 48 >> 2];
    var $3 = __ZN2js10BinaryNode6createEP13JSTreeContext($_idx1_val);
    var $4 = $3 | 0;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this + 40 | 0;
    var $8 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($8 | 0) == 27) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 34, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 4:
    var $13 = $this + 12 | 0;
    var $14 = HEAP32[$13 >> 2];
    var $15 = HEAP32[$1 >> 2];
    var $16 = __ZL16PushLexicalScopeP9JSContextPN2js11TokenStreamEP13JSTreeContextP10JSStmtInfo($14, $15, $stmtInfo);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = $16 + 36 | 0;
    var $_c = $3;
    HEAP32[$19 >> 2] = $_c;
    var $20 = __ZN2js6Parser9variablesEb($this, 1);
    var $21 = $3 + 32 | 0;
    HEAP32[$21 >> 2] = $20;
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $25 = $20 + 44 | 0;
    var $28 = HEAP32[$25 >> 2] & -4096 | 4;
    HEAP32[$25 >> 2] = $28;
    var $29 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($29 | 0) == 28) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $32 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 52, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 8:
    if (($statement | 0) == 0) {
      var $pn_0_ph = $16;
      __label__ = 16;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $36 = __ZN2js11TokenStream10matchTokenENS_9TokenKindEj($7, 25, 8);
    if ($36) {
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = HEAP32[$13 >> 2];
    var $40 = HEAP32[$1 >> 2];
    var $41 = __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($38, $7, $40, $4, 258, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    if ($41) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 11:
    var $_idx_val = HEAP32[HEAP32[$1 >> 2] + 48 >> 2];
    var $44 = __ZN2js9UnaryNode6createEP13JSTreeContext($_idx_val);
    var $45 = $44 | 0;
    if (($44 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($45, 2);
    var $48 = $44 + 36 | 0;
    HEAP32[$48 >> 2] = -1;
    var $49 = $44 + 32 | 0;
    HEAP32[$49 >> 2] = $16;
    var $pn_0_ph = $45;
    __label__ = 16;
    break;
   case 13:
    var $51 = __ZN2js6Parser10statementsEv($this);
    var $52 = $3 + 36 | 0;
    HEAP32[$52 >> 2] = $51;
    if (($51 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $55 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($55 | 0) == 26) {
      var $pn_04 = $16;
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $58 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 53, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 16:
    var $pn_0_ph;
    __ZN11JSParseNode5setOpE4JSOp($16, 210);
    var $60 = __ZN2js6Parser10assignExprEv($this);
    var $61 = $3 + 36 | 0;
    HEAP32[$61 >> 2] = $60;
    if (($60 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      var $pn_04 = $pn_0_ph;
      __label__ = 17;
      break;
    }
   case 17:
    var $pn_04;
    var $64 = HEAP32[$1 >> 2];
    __ZL12PopStatementP13JSTreeContext($64);
    var $_0 = $pn_04;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser8letBlockEi["X"] = 1;

function __ZN2js10BinaryNode6createEP13JSTreeContext($tc_0_11_val) {
  var $1 = __ZN11JSParseNode6createE16JSParseNodeArityP13JSTreeContext(2, $tc_0_11_val);
  return $1;
}

function __ZL16PushLexicalScopeP9JSContextPN2js11TokenStreamEP13JSTreeContextP10JSStmtInfo($cx, $tc, $stmt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tc_idx = $tc + 48 | 0;
    var $tc_idx_val = HEAP32[$tc_idx >> 2];
    var $1 = __ZN2js16LexicalScopeNode6createEP13JSTreeContext($tc_idx_val);
    var $2 = $1 | 0;
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $cx;
    var $6 = __Z17js_NewBlockObjectP9JSContext($5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $6;
    var $10 = HEAP32[$tc_idx >> 2];
    var $11 = __ZN2js6Parser12newObjectBoxEP8JSObject($10, $9);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $tc;
    var $15 = $stmt;
    _js_PushBlockScope($14, $15, $11, -1);
    __ZN11JSParseNode7setKindEN2js9TokenKindE($2, 80);
    __ZN11JSParseNode5setOpE4JSOp($2, 202);
    var $16 = $1 + 32 | 0;
    var $_c = $11;
    HEAP32[$16 >> 2] = $_c;
    var $18 = $1 + 40 | 0;
    __ZN2js11UpvarCookie8makeFreeEv($18);
    var $20 = $1 + 44 | 0;
    var $22 = HEAP32[$20 >> 2] & -4096;
    HEAP32[$20 >> 2] = $22;
    var $23 = $stmt + 4 | 0;
    var $24 = __ZL15GenerateBlockIdP13JSTreeContextRj($tc, $23);
    if ($24) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $30 = HEAP32[$20 >> 2] & 4095 | HEAP32[$23 >> 2] << 12;
    HEAP32[$20 >> 2] = $30;
    var $_0 = $2;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser9variablesEb($this, $inLetHead) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $data = __stackBase__;
    __ZN8BindDataC1Ev($data);
    var $1 = $this + 40 | 0;
    var $2 = __ZNK2js11TokenStream12currentTokenEv($1);
    var $4 = HEAP32[$2 >> 2];
    var $5 = ($4 | 0) == 81;
    var $6 = ($4 | 0) == 27;
    var $7 = $5 | $6;
    var $_pre = HEAP32[$this + 980 >> 2];
    if ($inLetHead | ($5 | $6) ^ 1) {
      var $13 = $inLetHead;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = (HEAP32[$_pre >> 2] & 16 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $13;
    var $14 = $this + 980 | 0;
    var $16 = HEAP32[$_pre + 24 >> 2];
    var $18 = HEAP32[$_pre + 28 >> 2];
    if (($4 | 0) == 81 || ($4 | 0) == 27) {
      var $scopeStmt_0 = $18;
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $scopeStmt_0;
    if (($scopeStmt_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP16[$scopeStmt_0 + 2 >> 1] & 1) << 16 >> 16 == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $scopeStmt_0 = HEAP32[$scopeStmt_0 + 28 >> 2];
    __label__ = 4;
    break;
   case 7:
    if (($4 | 0) == 81 || ($4 | 0) == 27) {
      var $32 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $28 = __ZNK2js11TokenStream12currentTokenEv($1);
    var $32 = HEAP32[$28 + 24 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $32;
    var $33 = $data + 4 | 0;
    HEAP32[$33 >> 2] = $32;
    var $_idx2_val = HEAP32[$_pre + 48 >> 2];
    var $34 = __ZN2js8ListNode6createEP13JSTreeContext($_idx2_val);
    var $35 = $34 | 0;
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 53;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = HEAP32[$33 >> 2];
    __ZN11JSParseNode5setOpE4JSOp($35, $38);
    __ZN11JSParseNode9makeEmptyEv($35);
    var $39 = $data + 8 | 0;
    if (($4 | 0) == 81 || ($4 | 0) == 27) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$39 >> 2] = 202;
    HEAP32[$data + 12 >> 2] = 199;
    __label__ = 13;
    break;
   case 12:
    HEAP32[$39 >> 2] = 204;
    __label__ = 13;
    break;
   case 13:
    var $43 = $this + 12 | 0;
    var $44 = $16 + 24 | 0;
    var $45 = $18 + 28 | 0;
    var $46 = $data | 0;
    var $47 = $data + 16 | 0;
    __label__ = 14;
    break;
   case 14:
    var $49 = __ZN2js11TokenStream8getTokenEv($1);
    if (($49 | 0) == 25 || ($49 | 0) == 23) {
      __label__ = 15;
      break;
    } else if (($49 | 0) == 29) {
      __label__ = 30;
      break;
    } else if (($49 | 0) == -1) {
      var $_0 = 0;
      __label__ = 53;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 15:
    var $52 = HEAP32[$14 >> 2] | 0;
    var $54 = HEAP32[$52 >> 2] | 65536;
    HEAP32[$52 >> 2] = $54;
    var $55 = __ZN2js6Parser11primaryExprENS_9TokenKindEi($this, $49, 0);
    var $57 = HEAP32[$14 >> 2] | 0;
    var $59 = HEAP32[$57 >> 2] & -65537;
    HEAP32[$57 >> 2] = $59;
    if (($55 | 0) == 0) {
      var $_0 = 0;
      __label__ = 53;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $62 = HEAP32[$43 >> 2];
    var $63 = HEAP32[$14 >> 2];
    var $64 = __ZL18CheckDestructuringP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($62, $data, $55, $63);
    if ($64) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 53;
      break;
    }
   case 17:
    if ((HEAP32[HEAP32[$14 >> 2] >> 2] & 16 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $72 = __ZN2js11TokenStream9peekTokenEv($1);
    if (($72 | 0) == 45) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    __ZN11JSParseNode6appendEPS_($35, $55);
    __label__ = 50;
    break;
   case 20:
    var $76 = __ZN2js11TokenStream8getTokenEj($1, 0);
    if (($76 | 0) == 4) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $79 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 50, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 53;
    break;
   case 22:
    var $81 = __ZNK2js11TokenStream12currentTokenEv($1);
    if ((HEAP32[$81 + 24 >> 2] | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 23:
    if ($13) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $86 = __ZN2js6Parser10assignExprEv($this);
    var $100 = $86;
    __label__ = 26;
    break;
   case 25:
    var $88 = HEAP32[$44 >> 2];
    var $90 = HEAP32[$14 >> 2] + 24 | 0;
    HEAP32[$90 >> 2] = $88;
    var $91 = HEAP32[$45 >> 2];
    var $93 = HEAP32[$14 >> 2] + 28 | 0;
    HEAP32[$93 >> 2] = $91;
    var $94 = __ZN2js6Parser10assignExprEv($this);
    var $96 = HEAP32[$14 >> 2] + 24 | 0;
    HEAP32[$96 >> 2] = $16;
    var $98 = HEAP32[$14 >> 2] + 28 | 0;
    HEAP32[$98 >> 2] = $18;
    var $100 = $94;
    __label__ = 26;
    break;
   case 26:
    var $100;
    if (($100 | 0) == 0) {
      var $_0 = 0;
      __label__ = 53;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZL22UndominateInitializersP11JSParseNodeRKN2js8TokenPtrEP13JSTreeContext($55, $100 + 12 | 0);
    var $104 = HEAP32[$14 >> 2];
    var $105 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(4, 0, $55, $100, $104);
    if (($105 | 0) == 0) {
      var $_0 = 0;
      __label__ = 53;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    __ZN11JSParseNode6appendEPS_($35, $105);
    __label__ = 50;
    break;
   case 29:
    var $109 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 102, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 53;
    break;
   case 30:
    var $111 = __ZNK2js11TokenStream12currentTokenEv($1);
    var $113 = HEAP32[$111 + 28 >> 2];
    var $114 = HEAP32[$14 >> 2];
    var $115 = __ZL14NewBindingNodeP6JSAtomP13JSTreeContextb($113, $114, $7);
    if (($115 | 0) == 0) {
      var $_0 = 0;
      __label__ = 53;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    if ((HEAP32[$33 >> 2] | 0) == 128) {
      __label__ = 32;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 32:
    var $122 = $115 + 44 | 0;
    var $124 = HEAP32[$122 >> 2] | 2;
    HEAP32[$122 >> 2] = $124;
    __label__ = 33;
    break;
   case 33:
    HEAP32[$46 >> 2] = $115;
    var $126 = HEAP32[$39 >> 2];
    var $127 = HEAP32[$43 >> 2];
    var $128 = HEAP32[$14 >> 2];
    var $129 = FUNCTION_TABLE[$126]($127, $data, $113, $128);
    if (($129 | 0) == 0) {
      var $_0 = 0;
      __label__ = 53;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    __ZN11JSParseNode6appendEPS_($35, $115);
    var $132 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($1, 4);
    if ($132) {
      __label__ = 35;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 35:
    var $134 = __ZNK2js11TokenStream12currentTokenEv($1);
    if ((HEAP32[$134 + 24 >> 2] | 0) == 0) {
      __label__ = 36;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 36:
    if ($13) {
      __label__ = 38;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $139 = __ZN2js6Parser10assignExprEv($this);
    var $153 = $139;
    __label__ = 39;
    break;
   case 38:
    var $141 = HEAP32[$44 >> 2];
    var $143 = HEAP32[$14 >> 2] + 24 | 0;
    HEAP32[$143 >> 2] = $141;
    var $144 = HEAP32[$45 >> 2];
    var $146 = HEAP32[$14 >> 2] + 28 | 0;
    HEAP32[$146 >> 2] = $144;
    var $147 = __ZN2js6Parser10assignExprEv($this);
    var $149 = HEAP32[$14 >> 2] + 24 | 0;
    HEAP32[$149 >> 2] = $16;
    var $151 = HEAP32[$14 >> 2] + 28 | 0;
    HEAP32[$151 >> 2] = $18;
    var $153 = $147;
    __label__ = 39;
    break;
   case 39:
    var $153;
    if (($153 | 0) == 0) {
      var $_0 = 0;
      __label__ = 53;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $156 = __ZNK11JSParseNode6isUsedEv($115);
    if ($156) {
      __label__ = 41;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 41:
    var $_idx_val = HEAP32[HEAP32[$14 >> 2] + 48 >> 2];
    var $159 = __ZL14MakeAssignmentP11JSParseNodeS0_P13JSTreeContext($115, $153, $_idx_val);
    if (($159 | 0) == 0) {
      var $_0 = 0;
      __label__ = 53;
      break;
    } else {
      var $pn2_0 = $159;
      __label__ = 43;
      break;
    }
   case 42:
    var $162 = $115 + 36 | 0;
    HEAP32[$162 >> 2] = $153;
    var $pn2_0 = $115;
    __label__ = 43;
    break;
   case 43:
    var $pn2_0;
    var $164 = __ZNK11JSParseNode4isOpE4JSOp($pn2_0, 9);
    if ($164) {
      var $176 = 111;
      __label__ = 46;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    if ((HEAP32[$pn2_0 + 44 >> 2] & 512 | 0) == 0) {
      __label__ = 45;
      break;
    } else {
      var $176 = 87;
      __label__ = 46;
      break;
    }
   case 45:
    var $174 = (HEAP32[$33 >> 2] | 0) == 128 ? 14 : 111;
    var $176 = $174;
    __label__ = 46;
    break;
   case 46:
    var $176;
    __ZN11JSParseNode5setOpE4JSOp($pn2_0, $176);
    var $177 = HEAP32[$43 >> 2];
    var $178 = HEAP32[$14 >> 2];
    var $182 = (HEAP8[$47] & 1) << 24 >> 24 != 0 ? 4 : 8;
    __ZL10NoteLValueP9JSContextP11JSParseNodeP13JSTreeContextj($177, $pn2_0, $178, $182);
    var $185 = $153 + 12 | 0;
    var $186 = $pn2_0 + 12 | 0;
    var $187$0 = HEAP32[$185 >> 2];
    var $187$1 = HEAP32[$185 + 4 >> 2];
    HEAP32[$186 >> 2] = $187$0;
    HEAP32[$186 + 4 >> 2] = $187$1;
    var $188 = HEAP32[$14 >> 2];
    var $_idx1_val = HEAP32[$188 >> 2];
    var $189 = __ZNK13JSTreeContext10inFunctionEv($_idx1_val);
    if ($189) {
      __label__ = 47;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 47:
    if (($113 | 0) == (HEAP32[HEAP32[HEAP32[$43 >> 2] + 52 >> 2] + 210176 >> 2] | 0)) {
      __label__ = 48;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 48:
    __ZN13JSTreeContext16noteArgumentsUseEP11JSParseNode($188, $pn2_0);
    if (($4 | 0) == 81 || ($4 | 0) == 27) {
      __label__ = 50;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $201 = HEAP32[$14 >> 2] | 0;
    var $203 = HEAP32[$201 >> 2] | 256;
    HEAP32[$201 >> 2] = $203;
    __label__ = 50;
    break;
   case 50:
    var $205 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($1, 3);
    if ($205) {
      __label__ = 14;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $207 = $34 + 12 | 0;
    var $_idx3_val = HEAP32[$34 + 36 >> 2];
    var $208 = __ZNK11JSParseNode4lastEv($_idx3_val);
    var $210 = $208 + 12 | 0;
    var $211 = $207;
    var $212$0 = HEAP32[$210 >> 2];
    var $212$1 = HEAP32[$210 + 4 >> 2];
    var $st$11$0 = $211 | 0;
    HEAP32[$st$11$0 >> 2] = $212$0;
    var $st$11$1 = $211 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $212$1;
    var $_0 = $35;
    __label__ = 53;
    break;
   case 52:
    var $214 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 128, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 53;
    break;
   case 53:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser9variablesEb["X"] = 1;

function __ZN2js11TokenStream10matchTokenENS_9TokenKindEj($this, $tt, $withFlags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $flagger = __stackBase__;
  __ZN2js11TokenStream7FlaggerC1EPS0_j($flagger, $this, $withFlags);
  var $1 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($this, $tt);
  var $flagger_idx_val = HEAP32[$flagger >> 2];
  var $flagger_idx1_val = HEAP32[$flagger + 4 >> 2];
  __ZN2js11TokenStream7FlaggerD1Ev($flagger_idx_val, $flagger_idx1_val);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZL12PopStatementP13JSTreeContext($tc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $2 = HEAP32[$tc + 24 >> 2];
    if ((HEAP16[$2 + 2 >> 1] & 1) << 16 >> 16 == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[HEAP32[HEAP32[$2 + 20 >> 2] + 8 >> 2] >> 2];
    var $13 = __ZNK8JSObject12lastPropertyEv($_idx_val);
    var $14 = $r;
    var $15 = $13;
    __ZNK2js5Shape3allEv($14, $15);
    var $_idx2 = $r;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $_idx2_val_idx_val = HEAP32[$_idx2_val + 32 >> 2];
    var $16 = __ZNK2js5Shape5Range5emptyEv($_idx2_val_idx_val);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $tc + 48 | 0;
    var $18 = $tc + 40 | 0;
    var $r_idx_val_in = $_idx2_val;
    __label__ = 4;
    break;
   case 4:
    var $r_idx_val_in;
    var $20 = __ZNK2js5Shape5Range5frontEv($r_idx_val_in);
    var $22 = HEAP32[$20 + 12 >> 2];
    var $23 = __ZL12JSID_TO_ATOMi2949($22);
    if (($23 | 0) == (HEAP32[HEAP32[HEAP32[HEAP32[$17 >> 2] + 12 >> 2] + 52 >> 2] + 209972 >> 2] | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js9AtomDecls6removeEP6JSAtom($18, $23);
    __label__ = 6;
    break;
   case 6:
    __ZN2js5Shape5Range8popFrontEv($r);
    var $_idx1_val = HEAP32[$_idx2 >> 2];
    var $_idx1_val_idx_val = HEAP32[$_idx1_val + 32 >> 2];
    var $35 = __ZNK2js5Shape5Range5emptyEv($_idx1_val_idx_val);
    if ($35) {
      __label__ = 7;
      break;
    } else {
      var $r_idx_val_in = $_idx1_val;
      __label__ = 4;
      break;
    }
   case 7:
    var $36 = $tc;
    _js_PopStatement($36);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12PopStatementP13JSTreeContext["X"] = 1;

function __ZN2js6Parser15switchStatementEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmtInfo = __stackBase__;
    var $1 = $this + 980 | 0;
    var $_idx3_val = HEAP32[HEAP32[$1 >> 2] + 48 >> 2];
    var $3 = __ZN2js10BinaryNode6createEP13JSTreeContext($_idx3_val);
    var $4 = $3 | 0;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this + 40 | 0;
    var $8 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($8 | 0) == 27) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 80, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 33;
    break;
   case 4:
    var $13 = __ZN2js6Parser9parenExprEPi($this, 0);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($16 | 0) == 28) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 81, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 33;
    break;
   case 7:
    var $21 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($21 | 0) == 25) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $24 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 82, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 33;
    break;
   case 9:
    var $27 = HEAP32[$1 >> 2];
    _js_PushStatement($27, $stmtInfo, 5, -1);
    var $_idx1_val = HEAP32[HEAP32[$1 >> 2] + 48 >> 2];
    var $29 = __ZN2js8ListNode6createEP13JSTreeContext($_idx1_val);
    var $30 = $29 | 0;
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN11JSParseNode9makeEmptyEv($30);
    var $33 = HEAP32[$1 >> 2];
    var $34 = __ZL26GenerateBlockIdForStmtNodeP11JSParseNodeP13JSTreeContext($30, $33);
    if ($34) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 33;
      break;
    }
   case 11:
    var $37 = HEAP32[$1 >> 2] + 36 | 0;
    var $38 = HEAP32[$37 >> 2];
    HEAP32[$37 >> 2] = $30;
    var $39 = $29 + 40 | 0;
    var $seenDefault_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $seenDefault_0;
    var $41 = __ZN2js11TokenStream8getTokenEv($7);
    if (($41 | 0) == 39) {
      __label__ = 13;
      break;
    } else if (($41 | 0) == 38) {
      var $seenDefault_1 = $seenDefault_0;
      __label__ = 15;
      break;
    } else if (($41 | 0) == 26) {
      __label__ = 32;
      break;
    } else if (($41 | 0) == -1) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 13:
    if (($seenDefault_0 | 0) == 0) {
      var $seenDefault_1 = 1;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $45 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 114, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 33;
    break;
   case 15:
    var $seenDefault_1;
    var $_idx2_val = HEAP32[HEAP32[$1 >> 2] + 48 >> 2];
    var $48 = __ZN2js10BinaryNode6createEP13JSTreeContext($_idx2_val);
    var $49 = $48 | 0;
    if (($48 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if (($41 | 0) == 38) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $54 = __ZN2js6Parser4exprEv($this);
    var $55 = $48 + 32 | 0;
    HEAP32[$55 >> 2] = $54;
    if (($54 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZN11JSParseNode6appendEPS_($30, $49);
    if ((HEAP32[$39 >> 2] | 0) == 65536) {
      __label__ = 19;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 19:
    var $61 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 115, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 33;
    break;
   case 20:
    var $63 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 116, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 33;
    break;
   case 21:
    var $65 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($65 | 0) == 6) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $68 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 83, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 33;
    break;
   case 23:
    var $_idx_val = HEAP32[HEAP32[$1 >> 2] + 48 >> 2];
    var $71 = __ZN2js8ListNode6createEP13JSTreeContext($_idx_val);
    var $72 = $71 | 0;
    if (($71 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($72, 25);
    __ZN11JSParseNode9makeEmptyEv($72);
    var $76 = $71 + 12 | 0;
    __label__ = 25;
    break;
   case 25:
    var $78 = __ZN2js11TokenStream9peekTokenEj($7, 8);
    if (($78 | 0) != 26 & ($78 - 38 | 0) >>> 0 > 1) {
      __label__ = 26;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 26:
    if (($78 | 0) == -1) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $84 = __ZN2js6Parser9statementEv($this);
    if (($84 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $88 = $84 + 12 | 0;
    var $st$2$0 = $88 | 0;
    var $89$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $88 + 4 | 0;
    var $89$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $76 | 0;
    HEAP32[$st$6$0 >> 2] = $89$0;
    var $st$6$1 = $76 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $89$1;
    __ZN11JSParseNode6appendEPS_($72, $84);
    __label__ = 25;
    break;
   case 29:
    var $91 = HEAP32[$71 + 32 >> 2];
    if (($91 | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $96 = $91 + 4 | 0;
    var $97 = $71 + 4 | 0;
    var $98$0 = HEAP32[$96 >> 2];
    var $98$1 = HEAP32[$96 + 4 >> 2];
    var $st$8$0 = $97 | 0;
    HEAP32[$st$8$0 >> 2] = $98$0;
    var $st$8$1 = $97 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $98$1;
    __label__ = 31;
    break;
   case 31:
    var $101 = $48 + 12 | 0;
    var $st$2$0 = $76 | 0;
    var $102$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $76 + 4 | 0;
    var $102$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $101 | 0;
    HEAP32[$st$6$0 >> 2] = $102$0;
    var $st$6$1 = $101 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $102$1;
    var $103 = $48 + 36 | 0;
    var $_c = $71;
    HEAP32[$103 >> 2] = $_c;
    var $seenDefault_0 = $seenDefault_1;
    __label__ = 12;
    break;
   case 32:
    var $106 = HEAP32[$1 >> 2] + 36 | 0;
    var $107 = HEAP32[$106 >> 2];
    HEAP32[$106 >> 2] = $38;
    var $108 = HEAP32[$1 >> 2];
    __ZL12PopStatementP13JSTreeContext($108);
    var $109 = $3 + 12 | 0;
    var $110 = $107 + 12 | 0;
    var $111 = __ZNK2js11TokenStream12currentTokenEv($7);
    var $113 = $111 + 12 | 0;
    var $114 = $110;
    var $115$0 = HEAP32[$113 >> 2];
    var $115$1 = HEAP32[$113 + 4 >> 2];
    var $st$16$0 = $114 | 0;
    HEAP32[$st$16$0 >> 2] = $115$0;
    var $st$16$1 = $114 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $115$1;
    var $116 = $109;
    var $st$21$0 = $116 | 0;
    HEAP32[$st$21$0 >> 2] = $115$0;
    var $st$21$1 = $116 + 4 | 0;
    HEAP32[$st$21$1 >> 2] = $115$1;
    var $117 = $3 + 32 | 0;
    HEAP32[$117 >> 2] = $13;
    var $118 = $3 + 36 | 0;
    var $pn2_0_c = $107;
    HEAP32[$118 >> 2] = $pn2_0_c;
    var $_0 = $4;
    __label__ = 33;
    break;
   case 33:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser15switchStatementEv["X"] = 1;

function __ZL26GenerateBlockIdForStmtNodeP11JSParseNodeP13JSTreeContext($pn, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $tc + 24 | 0;
    var $3 = HEAP32[$1 >> 2] + 4 | 0;
    var $4 = __ZL15GenerateBlockIdP13JSTreeContextRj($tc, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = $pn + 44 | 0;
    var $14 = HEAP32[$10 >> 2] & 4095 | HEAP32[HEAP32[$1 >> 2] + 4 >> 2] << 12;
    HEAP32[$10 >> 2] = $14;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL15TokenKindIsDeclENS_9TokenKindE2906($tt) {
  return ($tt | 0) == 46 | ($tt | 0) == 81;
}

function __ZN2js6Parser12forStatementEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $blockInfo = __stackBase__;
    var $stmtInfo = __stackBase__ + 32;
    var $1 = $this + 980 | 0;
    var $_idx1_val = HEAP32[HEAP32[$1 >> 2] + 48 >> 2];
    var $3 = __ZN2js10BinaryNode6createEP13JSTreeContext($_idx1_val);
    var $4 = $3 | 0;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 89;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$1 >> 2];
    var $9 = $stmtInfo;
    _js_PushStatement($8, $9, 12, -1);
    __ZN11JSParseNode5setOpE4JSOp($4, 75);
    var $11 = $3 + 44 | 0;
    HEAP32[$11 >> 2] = 0;
    var $12 = $this + 40 | 0;
    var $13 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($12, 29);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $15 = __ZNK2js11TokenStream12currentTokenEv($12);
    if ((HEAP32[$15 + 28 >> 2] | 0) == (HEAP32[HEAP32[HEAP32[$this + 12 >> 2] + 52 >> 2] + 210208 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$11 >> 2] = 2;
    __label__ = 6;
    break;
   case 5:
    __ZN2js11TokenStream10ungetTokenEv($12);
    __label__ = 6;
    break;
   case 6:
    var $29 = __ZN2js11TokenStream8getTokenEj($12, 0);
    if (($29 | 0) == 27) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $32 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 85, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 89;
    break;
   case 8:
    var $34 = __ZN2js11TokenStream9peekTokenEj($12, 8);
    if (($34 | 0) == 2) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    if ((HEAP32[$11 >> 2] & 2 | 0) == 0) {
      var $pnlet_1 = 0;
      var $tt_1 = 2;
      var $let_1 = 0;
      var $pn1_1 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $41 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $4, 0, 193, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 89;
    break;
   case 11:
    var $44 = HEAP32[$1 >> 2] | 0;
    var $46 = HEAP32[$44 >> 2] | 16;
    HEAP32[$44 >> 2] = $46;
    if (($34 | 0) == 46) {
      __label__ = 12;
      break;
    } else if (($34 | 0) == 81) {
      __label__ = 13;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 12:
    var $48 = __ZN2js11TokenStream8getTokenEv($12);
    var $49 = __ZN2js6Parser9variablesEb($this, 0);
    var $pnlet_0 = 0;
    var $tt_0 = 46;
    var $let_0 = 0;
    var $pn1_0 = $49;
    __label__ = 18;
    break;
   case 13:
    var $51 = __ZN2js11TokenStream8getTokenEv($12);
    var $52 = __ZN2js11TokenStream9peekTokenEv($12);
    if (($52 | 0) == 27) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $55 = __ZN2js6Parser8letBlockEi($this, 0);
    var $pnlet_0 = 0;
    var $tt_0 = 80;
    var $let_0 = 1;
    var $pn1_0 = $55;
    __label__ = 18;
    break;
   case 15:
    var $58 = HEAP32[$this + 12 >> 2];
    var $59 = HEAP32[$1 >> 2];
    var $60 = __ZL16PushLexicalScopeP9JSContextPN2js11TokenStreamEP13JSTreeContextP10JSStmtInfo($58, $59, $blockInfo);
    if (($60 | 0) == 0) {
      var $_0 = 0;
      __label__ = 89;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $63 = $blockInfo + 2 | 0;
    var $65 = HEAP16[$63 >> 1] | 4;
    HEAP16[$63 >> 1] = $65;
    var $66 = __ZN2js6Parser9variablesEb($this, 0);
    var $pnlet_0 = $60;
    var $tt_0 = $34;
    var $let_0 = 1;
    var $pn1_0 = $66;
    __label__ = 18;
    break;
   case 17:
    var $68 = __ZN2js6Parser4exprEv($this);
    var $pnlet_0 = 0;
    var $tt_0 = $34;
    var $let_0 = 0;
    var $pn1_0 = $68;
    __label__ = 18;
    break;
   case 18:
    var $pn1_0;
    var $let_0;
    var $tt_0;
    var $pnlet_0;
    var $71 = HEAP32[$1 >> 2] | 0;
    var $73 = HEAP32[$71 >> 2] & -17;
    HEAP32[$71 >> 2] = $73;
    if (($pn1_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 89;
      break;
    } else {
      var $pnlet_1 = $pnlet_0;
      var $tt_1 = $tt_0;
      var $let_1 = $let_0;
      var $pn1_1 = $pn1_0;
      __label__ = 19;
      break;
    }
   case 19:
    var $pn1_1;
    var $let_1;
    var $tt_1;
    var $pnlet_1;
    var $_idx2_val = HEAP32[HEAP32[$1 >> 2] + 48 >> 2];
    var $77 = __ZN2js11TernaryNode6createEP13JSTreeContext($_idx2_val);
    var $78 = $77 | 0;
    if (($77 | 0) == 0) {
      var $_0 = 0;
      __label__ = 89;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    if (($pn1_1 | 0) == 0) {
      __label__ = 70;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $83 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($12, 45);
    if ($83) {
      __label__ = 22;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 22:
    var $86 = HEAP32[$11 >> 2] | 1;
    HEAP32[$11 >> 2] = $86;
    HEAP16[$stmtInfo >> 1] = 13;
    var $88 = __ZN2jsL15TokenKindIsDeclENS_9TokenKindE2906($tt_1);
    if ($88) {
      __label__ = 23;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 23:
    if (HEAPU32[$pn1_1 + 40 >> 2] >>> 0 > 1) {
      __label__ = 47;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $94 = __ZNK11JSParseNode4isOpE4JSOp($pn1_1, 128);
    if ($94) {
      __label__ = 47;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $96 = __ZNK2js6Parser13versionNumberEv($this);
    if (($96 | 0) == 170) {
      __label__ = 26;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 26:
    var $99 = __ZNK11JSParseNode4isOpE4JSOp($4, 75);
    if ($99) {
      __label__ = 27;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 27:
    if ((HEAP32[$11 >> 2] & 2 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 28:
    var $106 = HEAP32[$pn1_1 + 32 >> 2];
    var $107 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($106, 26);
    if ($107) {
      __label__ = 47;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $109 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($106, 24);
    if ($109) {
      __label__ = 30;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    if ((HEAP32[$106 + 40 >> 2] | 0) == 2) {
      __label__ = 31;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 31:
    var $115 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($106, 4);
    if ($115) {
      __label__ = 32;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 32:
    var $118 = HEAP32[$106 + 32 >> 2];
    var $119 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($118, 24);
    if ($119) {
      __label__ = 33;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 33:
    if ((HEAP32[$118 + 40 >> 2] | 0) == 2) {
      __label__ = 48;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 34:
    var $125 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 29);
    if ($125) {
      __label__ = 58;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $127 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 22);
    if ($127) {
      __label__ = 48;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $129 = __ZNK2js6Parser13versionNumberEv($this);
    if (($129 | 0) == 170) {
      __label__ = 37;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 37:
    var $132 = __ZNK11JSParseNode4isOpE4JSOp($4, 75);
    if ($132) {
      __label__ = 38;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 38:
    if ((HEAP32[$11 >> 2] & 2 | 0) == 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 39:
    var $138 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 24);
    if ($138) {
      __label__ = 40;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 40:
    if ((HEAP32[$pn1_1 + 40 >> 2] | 0) == 2) {
      __label__ = 48;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 41:
    var $144 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 24);
    if ($144) {
      __label__ = 48;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $146 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 26);
    if ($146) {
      __label__ = 48;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    var $148 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 27);
    if ($148) {
      __label__ = 48;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $150 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 19);
    if ($150) {
      __label__ = 45;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 45:
    var $152 = __ZNK11JSParseNode4isOpE4JSOp($pn1_1, 174);
    if ($152) {
      __label__ = 48;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $154 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 23);
    if ($154) {
      __label__ = 48;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $156 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $pn1_1, 0, 117, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 89;
    break;
   case 48:
    if ($88) {
      __label__ = 49;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 49:
    var $160 = $pn1_1 + 44 | 0;
    var $162 = HEAP32[$160 >> 2] | 8;
    HEAP32[$160 >> 2] = $162;
    var $164 = HEAP32[$pn1_1 + 32 >> 2];
    var $165 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($164, 29);
    if ($165) {
      __label__ = 50;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 50:
    var $167 = __ZN11JSParseNode9maybeExprEv($164);
    if (($167 | 0) == 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 51:
    var $170 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($164, 4);
    if ($170) {
      __label__ = 52;
      break;
    } else {
      var $dflag_0 = 8;
      var $pnseq_0 = 0;
      var $pn1_2 = $pn1_1;
      var $pn2_1 = $164;
      __label__ = 57;
      break;
    }
   case 52:
    if (($tt_1 | 0) == 81) {
      __label__ = 53;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 53:
    var $174 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $164, 0, 268, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 89;
    break;
   case 54:
    var $_idx_val = HEAP32[HEAP32[$1 >> 2] + 48 >> 2];
    var $177 = __ZN2js8ListNode6createEP13JSTreeContext($_idx_val);
    var $178 = $177 | 0;
    if (($177 | 0) == 0) {
      var $_0 = 0;
      __label__ = 89;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($178, 82);
    var $183 = $3 + 4 | 0;
    var $184 = $177 + 4 | 0;
    var $185$0 = HEAP32[$183 >> 2];
    var $185$1 = HEAP32[$183 + 4 >> 2];
    var $st$9$0 = $184 | 0;
    HEAP32[$st$9$0 >> 2] = $185$0;
    var $st$9$1 = $184 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $185$1;
    var $188 = HEAP32[$160 >> 2] & -13 | 4;
    HEAP32[$160 >> 2] = $188;
    __ZN11JSParseNode8initListEPS_($178, $pn1_1);
    var $189 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($164, 4);
    if ($189) {
      __label__ = 56;
      break;
    } else {
      var $dflag_0 = 4;
      var $pnseq_0 = $178;
      var $pn1_2 = 0;
      var $pn2_1 = $164;
      __label__ = 57;
      break;
    }
   case 56:
    var $dflag_0 = 4;
    var $pnseq_0 = $178;
    var $pn1_2 = 0;
    var $pn2_1 = HEAP32[$164 + 32 >> 2];
    __label__ = 57;
    break;
   case 57:
    var $pn2_1;
    var $pn1_2;
    var $pnseq_0;
    var $dflag_0;
    var $194 = HEAP32[$1 >> 2];
    var $195 = __ZL17CloneLeftHandSideP11JSParseNodeP13JSTreeContext($pn2_1, $194);
    if (($195 | 0) == 0) {
      var $_0 = 0;
      __label__ = 89;
      break;
    } else {
      var $dflag_1 = $dflag_0;
      var $pnseq_1 = $pnseq_0;
      var $pn1_3 = $pn1_2;
      var $pn2_2 = $195;
      __label__ = 59;
      break;
    }
   case 58:
    var $197 = __ZN2js6Parser19setAssignmentLhsOpsEP11JSParseNode4JSOp($this, $pn1_1, 0);
    if ($197) {
      var $dflag_1 = 8;
      var $pnseq_1 = 0;
      var $pn1_3 = 0;
      var $pn2_2 = $pn1_1;
      __label__ = 59;
      break;
    } else {
      var $_0 = 0;
      __label__ = 89;
      break;
    }
   case 59:
    var $pn2_2;
    var $pn1_3;
    var $pnseq_1;
    var $dflag_1;
    var $199 = __ZNK11JSParseNode7getKindEv($pn2_2);
    if (($199 | 0) == 29) {
      __label__ = 60;
      break;
    } else if (($199 | 0) == 26 || ($199 | 0) == 24) {
      __label__ = 61;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 60:
    var $202 = HEAP32[$this + 12 >> 2];
    var $203 = HEAP32[$1 >> 2];
    __ZL10NoteLValueP9JSContextP11JSParseNodeP13JSTreeContextj($202, $pn2_2, $203, $dflag_1);
    __label__ = 64;
    break;
   case 61:
    var $205 = __ZNK2js6Parser13versionNumberEv($this);
    if (($205 | 0) == 170) {
      __label__ = 62;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 62:
    var $208 = HEAP32[$11 >> 2];
    if (($208 & 2 | 0) == 0) {
      __label__ = 63;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 63:
    var $212 = $208 | 6;
    HEAP32[$11 >> 2] = $212;
    __label__ = 64;
    break;
   case 64:
    var $215 = HEAP32[$1 >> 2] + 24 | 0;
    var $216 = HEAP32[$215 >> 2];
    var $218 = ($let_1 & 1) << 24 >> 24 != 0;
    if ($218) {
      __label__ = 65;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 65:
    var $221 = HEAP32[$216 + 24 >> 2];
    HEAP32[$215 >> 2] = $221;
    __label__ = 66;
    break;
   case 66:
    var $223 = __ZN2js6Parser4exprEv($this);
    if (($223 | 0) == 0) {
      var $_0 = 0;
      __label__ = 89;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 67:
    if ($218) {
      __label__ = 68;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 68:
    var $228 = HEAP32[$1 >> 2] + 24 | 0;
    HEAP32[$228 >> 2] = $216;
    __label__ = 69;
    break;
   case 69:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($78, 45);
    var $pnseq_2 = $pnseq_1;
    var $pn1_4 = $pn1_3;
    var $pn2_4 = $pn2_2;
    var $pn3_1 = $223;
    __label__ = 81;
    break;
   case 70:
    if ((HEAP32[$11 >> 2] & 2 | 0) == 0) {
      __label__ = 72;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 71:
    var $235 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $4, 0, 193, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 89;
    break;
   case 72:
    __ZN11JSParseNode5setOpE4JSOp($4, 0);
    var $237 = __ZN2js11TokenStream8getTokenEj($12, 0);
    if (($237 | 0) == 2) {
      __label__ = 74;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    var $240 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 86, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 89;
    break;
   case 74:
    var $242 = __ZN2js11TokenStream9peekTokenEj($12, 8);
    if (($242 | 0) == 2) {
      var $pn2_3 = 0;
      __label__ = 76;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 75:
    var $245 = __ZN2js6Parser4exprEv($this);
    if (($245 | 0) == 0) {
      var $_0 = 0;
      __label__ = 89;
      break;
    } else {
      var $pn2_3 = $245;
      __label__ = 76;
      break;
    }
   case 76:
    var $pn2_3;
    var $248 = __ZN2js11TokenStream8getTokenEj($12, 0);
    if (($248 | 0) == 2) {
      __label__ = 78;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 77:
    var $251 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 87, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 89;
    break;
   case 78:
    var $253 = __ZN2js11TokenStream9peekTokenEj($12, 8);
    if (($253 | 0) == 28) {
      var $pn3_0 = 0;
      __label__ = 80;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 79:
    var $256 = __ZN2js6Parser4exprEv($this);
    if (($256 | 0) == 0) {
      var $_0 = 0;
      __label__ = 89;
      break;
    } else {
      var $pn3_0 = $256;
      __label__ = 80;
      break;
    }
   case 80:
    var $pn3_0;
    __ZN11JSParseNode7setKindEN2js9TokenKindE($78, 83);
    var $pnseq_2 = 0;
    var $pn1_4 = $pn1_1;
    var $pn2_4 = $pn2_3;
    var $pn3_1 = $pn3_0;
    __label__ = 81;
    break;
   case 81:
    var $pn3_1;
    var $pn2_4;
    var $pn1_4;
    var $pnseq_2;
    __ZN11JSParseNode5setOpE4JSOp($78, 0);
    var $260 = $77 + 32 | 0;
    HEAP32[$260 >> 2] = $pn1_4;
    var $261 = $77 + 36 | 0;
    HEAP32[$261 >> 2] = $pn2_4;
    var $262 = $77 + 40 | 0;
    HEAP32[$262 >> 2] = $pn3_1;
    var $263 = $3 + 32 | 0;
    HEAP32[$263 >> 2] = $78;
    var $264 = __ZN2js11TokenStream8getTokenEj($12, 0);
    if (($264 | 0) == 28) {
      __label__ = 83;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 82:
    var $267 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 88, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 89;
    break;
   case 83:
    var $269 = __ZN2js6Parser9statementEv($this);
    if (($269 | 0) == 0) {
      var $_0 = 0;
      __label__ = 89;
      break;
    } else {
      __label__ = 84;
      break;
    }
   case 84:
    var $272 = $3 + 36 | 0;
    HEAP32[$272 >> 2] = $269;
    var $275 = $269 + 12 | 0;
    var $276 = $3 + 12 | 0;
    var $277$0 = HEAP32[$275 >> 2];
    var $277$1 = HEAP32[$275 + 4 >> 2];
    var $st$11$0 = $276 | 0;
    HEAP32[$st$11$0 >> 2] = $277$0;
    var $st$11$1 = $276 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $277$1;
    if (($pnlet_1 | 0) == 0) {
      var $pn_0 = $4;
      __label__ = 86;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 85:
    var $280 = HEAP32[$1 >> 2];
    __ZL12PopStatementP13JSTreeContext($280);
    var $_c1 = $3;
    HEAP32[$pnlet_1 + 36 >> 2] = $_c1;
    var $pn_0 = $pnlet_1;
    __label__ = 86;
    break;
   case 86:
    var $pn_0;
    if (($pnseq_2 | 0) == 0) {
      var $pn_1 = $pn_0;
      __label__ = 88;
      break;
    } else {
      __label__ = 87;
      break;
    }
   case 87:
    var $287 = $pn_0 + 12 | 0;
    var $288 = $pnseq_2 + 12 | 0;
    var $289$0 = HEAP32[$287 >> 2];
    var $289$1 = HEAP32[$287 + 4 >> 2];
    HEAP32[$288 >> 2] = $289$0;
    HEAP32[$288 + 4 >> 2] = $289$1;
    __ZN11JSParseNode6appendEPS_($pnseq_2, $pn_0);
    var $pn_1 = $pnseq_2;
    __label__ = 88;
    break;
   case 88:
    var $pn_1;
    var $291 = HEAP32[$1 >> 2];
    __ZL12PopStatementP13JSTreeContext($291);
    var $_0 = $pn_1;
    __label__ = 89;
    break;
   case 89:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser12forStatementEv["X"] = 1;

function __ZN2js11TokenStream9peekTokenEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 136 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[$this + 4 + ((HEAP32[$this + 132 >> 2] + $2 & 3) << 5) >> 2];
    __label__ = 4;
    break;
   case 3:
    var $12 = __ZN2js11TokenStream16getTokenInternalEv($this);
    __ZN2js11TokenStream10ungetTokenEv($this);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TernaryNode6createEP13JSTreeContext($tc_0_11_val) {
  var $1 = __ZN11JSParseNode6createE16JSParseNodeArityP13JSTreeContext(3, $tc_0_11_val);
  return $1;
}

function __ZNK2js6Parser13versionNumberEv($this) {
  var $_idx_val = HEAP32[$this + 944 >> 2];
  var $1 = __ZNK2js11TokenStream13versionNumberEv($_idx_val);
  return $1;
}

function __ZL17CloneLeftHandSideP11JSParseNodeP13JSTreeContext($opn, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tc_idx = $tc + 48 | 0;
    var $tc_idx_val = HEAP32[$tc_idx >> 2];
    var $1 = __ZL17NewOrRecycledNodeP13JSTreeContext($tc_idx_val);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK11JSParseNode7getKindEv($opn);
    __ZN11JSParseNode7setKindEN2js9TokenKindE($1, $4);
    var $5 = __ZNK11JSParseNode5getOpEv($opn);
    __ZN11JSParseNode5setOpE4JSOp($1, $5);
    var $6 = __ZNK11JSParseNode6isUsedEv($opn);
    __ZN11JSParseNode7setUsedEb($1, $6);
    var $7 = __ZNK11JSParseNode6isDefnEv($opn);
    __ZN11JSParseNode7setDefnEb($1, $7);
    var $8 = __ZNK11JSParseNode8getArityEv($opn);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($1, $8);
    var $9 = __ZNK11JSParseNode10isInParensEv($opn);
    __ZN11JSParseNode11setInParensEb($1, $9);
    var $12 = $1 + 4 | 0;
    var $13 = $opn + 4 | 0;
    HEAP32[$12 >> 2] = HEAP32[$13 >> 2];
    HEAP32[$12 + 4 >> 2] = HEAP32[$13 + 4 >> 2];
    HEAP32[$12 + 8 >> 2] = HEAP32[$13 + 8 >> 2];
    HEAP32[$12 + 12 >> 2] = HEAP32[$13 + 12 >> 2];
    var $14 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($opn, 5);
    if ($14) {
      __label__ = 3;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 3:
    __ZN11JSParseNode9makeEmptyEv($1);
    var $opn2_0_in = $opn + 32 | 0;
    __label__ = 4;
    break;
   case 4:
    var $opn2_0_in;
    var $opn2_0 = HEAP32[$opn2_0_in >> 2];
    if (($opn2_0 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($opn, 26);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $23 = HEAP32[$opn2_0 + 32 >> 2];
    var $24 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($23, $tc);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $29 = HEAP32[$opn2_0 + 36 >> 2];
    var $30 = __ZL17CloneLeftHandSideP11JSParseNodeP13JSTreeContext($29, $tc);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $33 = $opn2_0 + 4 | 0;
    var $tc_idx1_val = HEAP32[$tc_idx >> 2];
    var $34 = __ZN2js10BinaryNode6createENS_9TokenKindE4JSOpRKNS_8TokenPosEP11JSParseNodeS7_P13JSTreeContext($33, $24, $30, $tc_idx1_val);
    var $pn2_0 = $34 | 0;
    __label__ = 12;
    break;
   case 9:
    var $37 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($opn2_0, 0);
    if ($37) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $39 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($opn2_0, $tc);
    var $pn2_0 = $39;
    __label__ = 12;
    break;
   case 11:
    var $41 = __ZL17CloneLeftHandSideP11JSParseNodeP13JSTreeContext($opn2_0, $tc);
    var $pn2_0 = $41;
    __label__ = 12;
    break;
   case 12:
    var $pn2_0;
    if (($pn2_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    __ZN11JSParseNode6appendEPS_($1, $pn2_0);
    var $opn2_0_in = $opn2_0 + 24 | 0;
    __label__ = 4;
    break;
   case 14:
    var $52 = $1 + 44 | 0;
    var $55 = HEAP32[$52 >> 2] & -4096 | HEAP32[$opn + 44 >> 2] & 4095;
    HEAP32[$52 >> 2] = $55;
    var $_0 = $1;
    __label__ = 19;
    break;
   case 15:
    var $59 = $1 + 32 | 0;
    var $60 = $opn + 32 | 0;
    HEAP32[$59 >> 2] = HEAP32[$60 >> 2];
    HEAP32[$59 + 4 >> 2] = HEAP32[$60 + 4 >> 2];
    HEAP32[$59 + 8 >> 2] = HEAP32[$60 + 8 >> 2];
    HEAP32[$59 + 12 >> 2] = HEAP32[$60 + 12 >> 2];
    __ZN11JSParseNode5setOpE4JSOp($1, 111);
    var $61 = __ZNK11JSParseNode6isUsedEv($opn);
    var $62 = $1 + 36 | 0;
    if ($61) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $65 = HEAP32[$62 >> 2] + 28 | 0;
    var $66 = HEAP32[$65 >> 2];
    var $67 = $1 + 28 | 0;
    HEAP32[$67 >> 2] = $66;
    HEAP32[$65 >> 2] = $1;
    var $_0 = $1;
    __label__ = 19;
    break;
   case 17:
    HEAP32[$62 >> 2] = 0;
    var $69 = __ZNK11JSParseNode6isDefnEv($opn);
    if ($69) {
      __label__ = 18;
      break;
    } else {
      var $_0 = $1;
      __label__ = 19;
      break;
    }
   case 18:
    var $72 = $1 + 40 | 0;
    __ZN2js11UpvarCookie8makeFreeEv($72);
    var $74 = $1 + 44 | 0;
    var $76 = HEAP32[$74 >> 2] & -513;
    HEAP32[$74 >> 2] = $76;
    __ZN11JSParseNode7setDefnEb($1, 0);
    var $77 = $opn;
    __ZL12LinkUseToDefP11JSParseNodeP12JSDefinitionP13JSTreeContext($1, $77);
    var $_0 = $1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17CloneLeftHandSideP11JSParseNodeP13JSTreeContext["X"] = 1;

function __ZN2js6Parser19setAssignmentLhsOpsEP11JSParseNode4JSOp($this, $pn, $op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode7getKindEv($pn);
    if (($1 | 0) == 29) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 22) {
      __label__ = 4;
      break;
    } else if (($1 | 0) == 23) {
      __label__ = 5;
      break;
    } else if (($1 | 0) == 24 || ($1 | 0) == 26) {
      __label__ = 6;
      break;
    } else if (($1 | 0) == 27) {
      __label__ = 9;
      break;
    } else if (($1 | 0) == 19) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    var $3 = $this + 12 | 0;
    var $4 = HEAP32[$3 >> 2];
    var $5 = $this + 980 | 0;
    var $6 = HEAP32[$5 >> 2];
    var $7 = __Z21CheckStrictAssignmentP9JSContextP13JSTreeContextP11JSParseNode($4, $6, $pn);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 3:
    var $9 = __ZNK11JSParseNode4isOpE4JSOp($pn, 86);
    var $10 = $9 ? 87 : 111;
    __ZN11JSParseNode5setOpE4JSOp($pn, $10);
    var $11 = HEAP32[$3 >> 2];
    var $12 = HEAP32[$5 >> 2];
    __ZL10NoteLValueP9JSContextP11JSParseNodeP13JSTreeContextj($11, $pn, $12, 8);
    __label__ = 13;
    break;
   case 4:
    __ZN11JSParseNode5setOpE4JSOp($pn, 54);
    __label__ = 13;
    break;
   case 5:
    __ZN11JSParseNode5setOpE4JSOp($pn, 56);
    __label__ = 13;
    break;
   case 6:
    if (($op | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 51, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 8:
    var $21 = HEAP32[$this + 12 >> 2];
    var $23 = HEAP32[$this + 980 >> 2];
    var $24 = __ZL18CheckDestructuringP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($21, 0, $pn, $23);
    if ($24) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 9:
    var $27 = HEAP32[$this + 12 >> 2];
    var $29 = HEAP32[$this + 980 >> 2];
    var $30 = __ZL11MakeSetCallP9JSContextP11JSParseNodeP13JSTreeContextj($27, $pn, $29, 129);
    if ($30) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 10:
    var $32 = __ZNK11JSParseNode4isOpE4JSOp($pn, 174);
    if ($32) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    __ZN11JSParseNode5setOpE4JSOp($pn, 173);
    __label__ = 13;
    break;
   case 12:
    var $35 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 129, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 13:
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10NoteLValueP9JSContextP11JSParseNodeP13JSTreeContextj($cx, $pn, $tc, $dflag) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode6isUsedEv($pn);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_1 = $dflag;
      __label__ = 12;
      break;
    }
   case 2:
    var $4 = HEAPU32[$pn + 36 >> 2];
    var $5 = $4;
    var $6 = $4 + 44 | 0;
    var $8 = HEAPU32[$6 >> 2];
    if (($8 & 134 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $dflag;
      __label__ = 9;
      break;
    }
   case 3:
    var $12 = __ZNK11JSParseNode12isBlockChildEv($5);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $dflag;
      __label__ = 9;
      break;
    }
   case 4:
    var $14 = __ZNK11JSParseNode12isBlockChildEv($pn);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $dflag;
      __label__ = 9;
      break;
    }
   case 5:
    if (($8 >>> 12 | 0) == (HEAPU32[$pn + 44 >> 2] >>> 12 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $dflag;
      __label__ = 9;
      break;
    }
   case 6:
    var $24 = $4 + 12 | 0;
    var $25 = $pn + 4 | 0;
    var $26 = __ZN2js8TokenPtrleERKS0_($24, $25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $_0 = $dflag;
      __label__ = 9;
      break;
    }
   case 7:
    if ((HEAP32[$4 + 28 >> 2] | 0) == ($pn | 0)) {
      __label__ = 8;
      break;
    } else {
      var $_0 = $dflag;
      __label__ = 9;
      break;
    }
   case 8:
    var $_0 = 4;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    HEAP32[$6 >> 2] = $_0 & 4095 | $8;
    var $_idx2_val = HEAP32[$4 + 40 >> 2];
    var $36 = __ZNK2js11UpvarCookie6isFreeEv($_idx2_val);
    if ($36) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = __ZNK11JSParseNode10frameLevelEv($5);
    if ($38 >>> 0 < HEAPU32[$tc + 76 >> 2] >>> 0) {
      __label__ = 11;
      break;
    } else {
      var $_1 = $_0;
      __label__ = 12;
      break;
    }
   case 11:
    var $43 = $tc | 0;
    var $45 = HEAP32[$43 >> 2] | 32;
    HEAP32[$43 >> 2] = $45;
    var $_1 = $_0;
    __label__ = 12;
    break;
   case 12:
    var $_1;
    var $47 = $pn + 32 | 0;
    var $49 = $pn + 44 | 0;
    var $52 = $_1 & 4095 | HEAP32[$49 >> 2];
    HEAP32[$49 >> 2] = $52;
    var $54 = HEAPU32[$47 >> 2];
    var $61 = $tc | 0;
    var $62 = HEAP32[$61 >> 2];
    if (($54 | 0) == (HEAP32[HEAP32[$cx + 52 >> 2] + 210176 >> 2] | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $64 = $62 | 256;
    HEAP32[$61 >> 2] = $64;
    __ZN13JSTreeContext17countArgumentsUseEP11JSParseNode($tc, $pn);
    __label__ = 17;
    break;
   case 14:
    var $66 = __ZNK13JSTreeContext10inFunctionEv($62);
    if ($66) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $_idx1_val = HEAP32[$tc + 60 >> 2];
    var $69 = __ZNK13JSTreeContext3funEv($_idx1_val);
    if (($54 | 0) == (HEAP32[$69 + 72 >> 2] | 0)) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $74 = $62 | 256;
    HEAP32[$61 >> 2] = $74;
    __label__ = 17;
    break;
   case 17:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10NoteLValueP9JSContextP11JSParseNodeP13JSTreeContextj["X"] = 1;

function __ZN2js6Parser12tryStatementEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmtInfo = __stackBase__;
    var $data = __stackBase__ + 32;
    var $1 = $this + 980 | 0;
    var $_idx2_val = HEAP32[HEAP32[$1 >> 2] + 48 >> 2];
    var $3 = __ZN2js11TernaryNode6createEP13JSTreeContext($_idx2_val);
    var $4 = $3 | 0;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN11JSParseNode5setOpE4JSOp($4, 0);
    var $7 = $this + 40 | 0;
    var $8 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($8 | 0) == 25) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 89, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 4:
    var $13 = HEAP32[$1 >> 2];
    var $14 = __ZL22PushBlocklikeStatementP10JSStmtInfo10JSStmtTypeP13JSTreeContext($stmtInfo, 8, $13);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 45;
      break;
    }
   case 5:
    var $16 = __ZN2js6Parser10statementsEv($this);
    var $17 = $3 + 32 | 0;
    HEAP32[$17 >> 2] = $16;
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($20 | 0) == 26) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 90, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 8:
    var $25 = HEAP32[$1 >> 2];
    __ZL12PopStatementP13JSTreeContext($25);
    var $26 = __ZN2js11TokenStream8getTokenEv($7);
    if (($26 | 0) == 54) {
      __label__ = 9;
      break;
    } else {
      var $catchList_0 = 0;
      var $tt_0 = $26;
      __label__ = 33;
      break;
    }
   case 9:
    var $_idx_val = HEAP32[HEAP32[$1 >> 2] + 48 >> 2];
    var $30 = __ZN2js8ListNode6createEP13JSTreeContext($_idx_val);
    var $31 = $30 | 0;
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($31, 86);
    __ZN11JSParseNode9makeEmptyEv($31);
    var $34 = $this + 12 | 0;
    var $35 = $stmtInfo | 0;
    var $36 = $data | 0;
    var $37 = $data + 4 | 0;
    var $38 = $data + 8 | 0;
    var $39 = $data + 12 | 0;
    var $lastCatch_0 = 0;
    __label__ = 11;
    break;
   case 11:
    var $lastCatch_0;
    __ZN8BindDataC1Ev($data);
    if (($lastCatch_0 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[$lastCatch_0 + 36 >> 2] | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $47 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 118, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 14:
    var $49 = HEAP32[$34 >> 2];
    var $50 = HEAP32[$1 >> 2];
    var $51 = __ZL16PushLexicalScopeP9JSContextPN2js11TokenStreamEP13JSTreeContextP10JSStmtInfo($49, $50, $stmtInfo);
    if (($51 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    HEAP16[$35 >> 1] = 7;
    var $_idx1_val = HEAP32[HEAP32[$1 >> 2] + 48 >> 2];
    var $55 = __ZN2js11TernaryNode6createEP13JSTreeContext($_idx1_val);
    var $56 = $55 | 0;
    if (($55 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $59 = $51 + 36 | 0;
    var $_c1 = $55;
    HEAP32[$59 >> 2] = $_c1;
    var $60 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($60 | 0) == 27) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $63 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 91, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 18:
    HEAP32[$36 >> 2] = 0;
    HEAP32[$37 >> 2] = 0;
    HEAP32[$38 >> 2] = 202;
    HEAP32[$39 >> 2] = 169;
    var $65 = __ZN2js11TokenStream8getTokenEv($7);
    if (($65 | 0) == 23 || ($65 | 0) == 25) {
      __label__ = 19;
      break;
    } else if (($65 | 0) == 29) {
      __label__ = 20;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 19:
    var $67 = __ZN2js6Parser17destructuringExprEP8BindDataNS_9TokenKindE($this, $data, $65);
    if (($67 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      var $pn3_0 = $67;
      __label__ = 23;
      break;
    }
   case 20:
    var $70 = __ZNK2js11TokenStream12currentTokenEv($7);
    var $72 = HEAP32[$70 + 28 >> 2];
    var $73 = HEAP32[$1 >> 2];
    var $74 = __ZL14NewBindingNodeP6JSAtomP13JSTreeContextb($72, $73, 1);
    if (($74 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    HEAP32[$36 >> 2] = $74;
    var $77 = HEAP32[$38 >> 2];
    var $78 = HEAP32[$34 >> 2];
    var $79 = HEAP32[$1 >> 2];
    var $80 = FUNCTION_TABLE[$77]($78, $data, $72, $79);
    if (($80 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      var $pn3_0 = $74;
      __label__ = 23;
      break;
    }
   case 22:
    var $83 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 92, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 23:
    var $pn3_0;
    var $85 = $55 + 32 | 0;
    HEAP32[$85 >> 2] = $pn3_0;
    var $86 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($7, 35);
    if ($86) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $88 = __ZN2js6Parser4exprEv($this);
    var $89 = $55 + 36 | 0;
    HEAP32[$89 >> 2] = $88;
    if (($88 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $92 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($92 | 0) == 28) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $95 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 93, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 27:
    var $97 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($97 | 0) == 25) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $100 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 94, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 29:
    var $102 = __ZN2js6Parser10statementsEv($this);
    var $103 = $55 + 40 | 0;
    HEAP32[$103 >> 2] = $102;
    if (($102 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $106 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($106 | 0) == 26) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $109 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 95, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 32:
    var $111 = HEAP32[$1 >> 2];
    __ZL12PopStatementP13JSTreeContext($111);
    __ZN11JSParseNode6appendEPS_($31, $51);
    var $112 = __ZN2js11TokenStream8getTokenEj($7, 8);
    if (($112 | 0) == 54) {
      var $lastCatch_0 = $56;
      __label__ = 11;
      break;
    } else {
      var $catchList_0 = $31;
      var $tt_0 = $112;
      __label__ = 33;
      break;
    }
   case 33:
    var $tt_0;
    var $catchList_0;
    var $114 = $3 + 36 | 0;
    HEAP32[$114 >> 2] = $catchList_0;
    if (($tt_0 | 0) == 55) {
      __label__ = 34;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 34:
    var $117 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($117 | 0) == 25) {
      __label__ = 36;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $120 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 96, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 36:
    var $122 = HEAP32[$1 >> 2];
    var $123 = __ZL22PushBlocklikeStatementP10JSStmtInfo10JSStmtTypeP13JSTreeContext($stmtInfo, 9, $122);
    if ($123) {
      __label__ = 37;
      break;
    } else {
      var $_0 = 0;
      __label__ = 45;
      break;
    }
   case 37:
    var $125 = __ZN2js6Parser10statementsEv($this);
    var $126 = $3 + 40 | 0;
    HEAP32[$126 >> 2] = $125;
    if (($125 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $129 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($129 | 0) == 26) {
      __label__ = 40;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $132 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 97, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 40:
    var $134 = HEAP32[$1 >> 2];
    __ZL12PopStatementP13JSTreeContext($134);
    __label__ = 42;
    break;
   case 41:
    __ZN2js11TokenStream10ungetTokenEv($7);
    __label__ = 42;
    break;
   case 42:
    if (($catchList_0 | 0) == 0) {
      __label__ = 43;
      break;
    } else {
      var $_0 = $4;
      __label__ = 45;
      break;
    }
   case 43:
    if ((HEAP32[$3 + 40 >> 2] | 0) == 0) {
      __label__ = 44;
      break;
    } else {
      var $_0 = $4;
      __label__ = 45;
      break;
    }
   case 44:
    var $144 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 98, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 45:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser12tryStatementEv["X"] = 1;

function __ZL22PushBlocklikeStatementP10JSStmtInfo10JSStmtTypeP13JSTreeContext($stmt, $type, $tc) {
  var $1 = $tc;
  var $2 = $stmt;
  _js_PushStatement($1, $2, $type, -1);
  var $3 = $stmt + 4 | 0;
  var $4 = __ZL15GenerateBlockIdP13JSTreeContextRj($tc, $3);
  return $4;
}

function __ZL7BindLetP9JSContextP8BindDataP6JSAtomP13JSTreeContext($cx, $data, $atom, $tc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $name = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $3 = HEAPU32[$data >> 2];
    var $4 = __Z18CheckStrictBindingP9JSContextP13JSTreeContextP6JSAtomP11JSParseNode($cx, $tc, $atom, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 2:
    var $_idx3_val = HEAP32[$tc + 32 >> 2];
    var $7 = __ZN13JSTreeContext10blockChainEv($_idx3_val);
    var $_idx2_val = HEAP32[$tc + 44 >> 2];
    var $8 = __ZN2js9AtomDecls11lookupFirstEP6JSAtom($_idx2_val, $atom);
    if (($8 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = $tc;
    var $12 = $8 | 0;
    var $16 = HEAPU32[$8 + 44 >> 2] >>> 12;
    var $17 = __ZN13JSTreeContext7blockidEv($11);
    if (($16 | 0) == ($17 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    __ZN16JSAutoByteStringC1Ev($name);
    var $20 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $atom, $name);
    if (($20 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $name_idx_val = HEAP32[$name >> 2];
    __label__ = 7;
    break;
   case 6:
    var $25 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $26 = __ZNK11JSParseNode7isConstEv($12);
    var $27 = $26 ? STRING_TABLE.__str2233375 | 0 : STRING_TABLE.__ZL15js_variable_str | 0;
    var $name_idx1_val = HEAP32[$name >> 2];
    var $28 = __ZNK16JSAutoByteString3ptrEv($name_idx1_val);
    var $29 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($25, $3, 0, 155, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $27, HEAP32[tempInt + 4 >> 2] = $28, tempInt));
    var $name_idx_val = $name_idx1_val;
    __label__ = 7;
    break;
   case 7:
    var $name_idx_val;
    __ZN16JSAutoByteStringD1Ev($name_idx_val);
    var $_0 = 0;
    __label__ = 13;
    break;
   case 8:
    var $32 = $7;
    var $33 = __ZNK8JSObject13propertyCountEv($32);
    if (($33 | 0) == 65536) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $38 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $40 = HEAP32[$data + 12 >> 2];
    var $41 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($38, $3, 0, $40, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 13;
    break;
   case 10:
    var $43 = __ZL6DefineP11JSParseNodeP6JSAtomP13JSTreeContextb($3, $atom, $tc, 1);
    if ($43) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 11:
    __ZN11JSParseNode5setOpE4JSOp($3, 86);
    var $46 = $3 + 40 | 0;
    var $49 = HEAP32[$tc + 76 >> 2] & 65535;
    var $50 = $33 & 65535;
    __ZN2js11UpvarCookie3setEtt($46, $49, $50);
    var $52 = $3 + 44 | 0;
    var $54 = HEAP32[$52 >> 2] | 513;
    HEAP32[$52 >> 2] = $54;
    var $55 = __ZL12ATOM_TO_JSIDP6JSAtom2903($atom);
    var $56 = $7;
    var $57 = $cx;
    var $58 = __ZN8JSObject19defineBlockVariableEP9JSContextii($56, $57, $55, $33);
    if (($58 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $62 = HEAP32[$58 + 24 >> 2];
    var $63 = $3 | 0;
    __ZN2JSL12PrivateValueEPv2951($1, $63);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($7, $62, $_idx_val$0, $_idx_val$1);
    var $_0 = 1;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL7BindLetP9JSContextP8BindDataP6JSAtomP13JSTreeContext["X"] = 1;

function __ZL14NewBindingNodeP6JSAtomP13JSTreeContextb($atom, $tc, $let) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $removal = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $atom;
    var $_idx_val = HEAP32[$tc + 44 >> 2];
    var $2 = __ZN2js9AtomDecls11lookupFirstEP6JSAtom($_idx_val, $atom);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_pn = $2;
      __label__ = 4;
      break;
    }
   case 2:
    var $_idx2_val = HEAP32[$tc + 64 >> 2];
    var $5 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($_idx2_val);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6lookupERKS2_($removal, $5, $1);
    var $6 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrcvPPPPPPPS6_Ev($removal);
    if (($6 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3Ptr5valueEv($removal);
    var $10 = HEAP32[$9 >> 2];
    if (($10 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $_pn = $10;
      __label__ = 4;
      break;
    }
   case 4:
    var $_pn;
    var $pn_05 = $_pn | 0;
    var $12 = __ZNK11JSParseNode13isPlaceholderEv($pn_05);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 5:
    var $15 = $_pn + 44 | 0;
    var $16 = HEAPU32[$15 >> 2];
    var $17 = $16 >>> 12;
    if ($let) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $19 = $tc;
    var $20 = __ZN13JSTreeContext7blockidEv($19);
    var $25 = $20;
    __label__ = 8;
    break;
   case 7:
    var $25 = HEAP32[$tc + 4 >> 2];
    __label__ = 8;
    break;
   case 8:
    var $25;
    if ($17 >>> 0 < $25 >>> 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ($let) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $29 = $tc;
    var $30 = __ZN13JSTreeContext7blockidEv($29);
    HEAP32[$15 >> 2] = $16 & 4095 | $30 << 12;
    __label__ = 11;
    break;
   case 11:
    var $_idx1_val = HEAP32[$tc + 64 >> 2];
    var $34 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($_idx1_val);
    var $removal_idx_val = HEAP32[$removal >> 2];
    var $removal_idx3_val = HEAP32[$removal + 4 >> 2];
    var $removal_idx4_val = HEAP8[$removal + 8 | 0];
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6removeENS5_3PtrE($34, $removal_idx_val, $removal_idx3_val, $removal_idx4_val);
    var $_0 = $pn_05;
    __label__ = 15;
    break;
   case 12:
    var $35 = HEAP32[$1 >> 2];
    var $36 = __ZN2js8NameNode6createEP6JSAtomP13JSTreeContext($35, $tc);
    var $37 = $36 | 0;
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if (($35 | 0) == (HEAP32[HEAP32[HEAP32[HEAP32[$tc + 48 >> 2] + 12 >> 2] + 52 >> 2] + 210176 >> 2] | 0)) {
      __label__ = 14;
      break;
    } else {
      var $_0 = $37;
      __label__ = 15;
      break;
    }
   case 14:
    __ZN13JSTreeContext17countArgumentsUseEP11JSParseNode($tc, $37);
    var $_0 = $37;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14NewBindingNodeP6JSAtomP13JSTreeContextb["X"] = 1;

function __ZN2js6Parser13withStatementEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmtInfo = __stackBase__;
    var $r = __stackBase__ + 32;
    var $1 = __stackBase__ + 52;
    var $2 = $this + 980 | 0;
    var $3 = HEAP32[$2 >> 2];
    if ((HEAP32[$3 >> 2] & 262144 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 233, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 13;
    break;
   case 3:
    var $_idx1_val = HEAP32[$3 + 48 >> 2];
    var $11 = __ZN2js10BinaryNode6createEP13JSTreeContext($_idx1_val);
    var $12 = $11 | 0;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = $this + 40 | 0;
    var $16 = __ZN2js11TokenStream8getTokenEj($15, 0);
    if (($16 | 0) == 27) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 99, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 13;
    break;
   case 6:
    var $21 = __ZN2js6Parser9parenExprEPi($this, 0);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = __ZN2js11TokenStream8getTokenEj($15, 0);
    if (($24 | 0) == 28) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 100, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 13;
    break;
   case 9:
    var $29 = $11 + 32 | 0;
    HEAP32[$29 >> 2] = $21;
    var $31 = HEAP32[$2 >> 2] + 88 | 0;
    var $32 = HEAP32[$31 >> 2];
    HEAP32[$31 >> 2] = $12;
    var $34 = HEAP32[$2 >> 2];
    _js_PushStatement($34, $stmtInfo, 6, -1);
    var $35 = __ZN2js6Parser9statementEv($this);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = HEAP32[$2 >> 2];
    __ZL12PopStatementP13JSTreeContext($38);
    var $39 = $11 + 4 | 0;
    var $42 = $35 + 12 | 0;
    var $43 = $11 + 12 | 0;
    var $44$0 = HEAP32[$42 >> 2];
    var $44$1 = HEAP32[$42 + 4 >> 2];
    var $st$11$0 = $43 | 0;
    HEAP32[$st$11$0 >> 2] = $44$0;
    var $st$11$1 = $43 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $44$1;
    var $45 = $11 + 36 | 0;
    HEAP32[$45 >> 2] = $35;
    var $47 = HEAP32[$2 >> 2] | 0;
    var $49 = HEAP32[$47 >> 2] | 256;
    HEAP32[$47 >> 2] = $49;
    var $51 = HEAP32[$2 >> 2] + 88 | 0;
    HEAP32[$51 >> 2] = $32;
    var $_idx_val = HEAP32[HEAP32[$2 >> 2] + 64 >> 2];
    var $53 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($_idx_val);
    __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3allEv($r, $53);
    var $54 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv($r);
    if ($54) {
      var $_0 = $12;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_idx2 = $1 + 4 | 0;
    __label__ = 12;
    break;
   case 12:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5frontEv($1, $r);
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $55 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Entry5valueEv($_idx2_val);
    var $56 = HEAP32[$55 >> 2];
    var $57 = __ZN12JSDefinition7resolveEv($56);
    var $_idx3_val = HEAP32[$57 + 28 >> 2];
    __ZL20DeoptimizeUsesWithinP12JSDefinitionRKN2js8TokenPosE($_idx3_val, $39);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range8popFrontEv($r);
    var $58 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv($r);
    if ($58) {
      var $_0 = $12;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser13withStatementEv["X"] = 1;

function __ZL20DeoptimizeUsesWithinP12JSDefinitionRKN2js8TokenPosE($dn_0_0_6_val, $pos) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($dn_0_0_6_val | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $2 = $pos | 0;
    var $3 = $pos + 8 | 0;
    var $pnu_03 = $dn_0_0_6_val;
    __label__ = 3;
    break;
   case 3:
    var $pnu_03;
    var $6 = __ZN2js8TokenPtrgeERKS0_($pnu_03 + 4 | 0, $2);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZN2js8TokenPtrleERKS0_($pnu_03 + 12 | 0, $3);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $12 = $pnu_03 + 44 | 0;
    var $14 = HEAP32[$12 >> 2] | 1024;
    HEAP32[$12 >> 2] = $14;
    __label__ = 6;
    break;
   case 6:
    var $pnu_0 = HEAP32[$pnu_03 + 28 >> 2];
    if (($pnu_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $pnu_03 = $pnu_0;
      __label__ = 3;
      break;
    }
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser12letStatementEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 40 | 0;
    var $2 = __ZN2js11TokenStream9peekTokenEv($1);
    if (($2 | 0) == 27) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = __ZN2js6Parser8letBlockEi($this, 1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK11JSParseNode4isOpE4JSOp($5, 202);
    if ($8) {
      var $_0 = $5;
      __label__ = 20;
      break;
    } else {
      var $pn_0 = $5;
      __label__ = 19;
      break;
    }
   case 4:
    var $10 = $this + 980 | 0;
    var $11 = HEAPU32[$10 >> 2];
    var $13 = HEAPU32[$11 + 24 >> 2];
    if (($13 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = HEAPU16[$13 >> 1];
    if ($17 << 16 >> 16 == 6) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((($17 & 65535) - 4 | 0) >>> 0 < 7) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $24 = $13 + 2 | 0;
    var $25 = HEAPU16[$24 >> 1];
    if (($25 & 4) << 16 >> 16 == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $29 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 223, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 20;
    break;
   case 9:
    if (($25 & 1) << 16 >> 16 == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 10:
    if (($25 & 2) << 16 >> 16 == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2js11TokenStream17mungeCurrentTokenENS_9TokenKindE4JSOp($1, 46, 129);
    var $35 = __ZN2js6Parser9variablesEb($this, 0);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $39 = $35 + 44 | 0;
    var $41 = HEAP32[$39 >> 2] | 4;
    HEAP32[$39 >> 2] = $41;
    var $pn_0 = $35;
    __label__ = 19;
    break;
   case 13:
    var $47 = HEAP32[HEAP32[$11 + 48 >> 2] + 12 >> 2];
    var $48 = __Z17js_NewBlockObjectP9JSContext($47);
    var $49 = $48;
    if (($48 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $54 = HEAP32[HEAP32[$10 >> 2] + 48 >> 2];
    var $55 = __ZN2js6Parser12newObjectBoxEP8JSObject($54, $49);
    if (($55 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $59 = HEAP16[$24 >> 1] | 1;
    HEAP16[$24 >> 1] = $59;
    var $62 = HEAP32[HEAP32[$10 >> 2] + 28 >> 2];
    HEAP32[$13 + 28 >> 2] = $62;
    var $65 = HEAP32[$10 >> 2] + 28 | 0;
    HEAP32[$65 >> 2] = $13;
    var $_idx1_val = HEAP32[HEAP32[$10 >> 2] + 32 >> 2];
    var $68 = __ZN13JSTreeContext10blockChainEv($_idx1_val);
    __ZN8JSObject9setParentEPS_($49, $68);
    var $71 = HEAP32[HEAP32[$10 >> 2] + 32 >> 2];
    var $72 = $55 + 12 | 0;
    HEAP32[$72 >> 2] = $71;
    var $74 = HEAP32[$10 >> 2] + 32 | 0;
    HEAP32[$74 >> 2] = $55;
    var $_c = $55;
    HEAP32[$13 + 20 >> 2] = $_c;
    var $_idx_val = HEAP32[HEAP32[$10 >> 2] + 48 >> 2];
    var $77 = __ZN2js16LexicalScopeNode6createEP13JSTreeContext($_idx_val);
    var $78 = $77 | 0;
    if (($77 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($78, 80);
    __ZN11JSParseNode5setOpE4JSOp($78, 202);
    var $86 = $77 + 4 | 0;
    var $87 = HEAP32[HEAP32[$10 >> 2] + 36 >> 2] + 4 | 0;
    HEAP32[$86 >> 2] = HEAP32[$87 >> 2];
    HEAP32[$86 + 4 >> 2] = HEAP32[$87 + 4 >> 2];
    HEAP32[$86 + 8 >> 2] = HEAP32[$87 + 8 >> 2];
    HEAP32[$86 + 12 >> 2] = HEAP32[$87 + 12 >> 2];
    var $88 = $77 + 32 | 0;
    var $_c1 = $55;
    HEAP32[$88 >> 2] = $_c1;
    var $92 = $77 + 36 | 0;
    var $_c2 = HEAP32[HEAP32[$10 >> 2] + 36 >> 2];
    HEAP32[$92 >> 2] = $_c2;
    var $101 = $77 + 44 | 0;
    var $104 = HEAP32[$101 >> 2] & 4095 | HEAP32[HEAP32[HEAP32[$10 >> 2] + 36 >> 2] + 44 >> 2] & -4096;
    HEAP32[$101 >> 2] = $104;
    var $106 = HEAP32[$10 >> 2] + 36 | 0;
    HEAP32[$106 >> 2] = $78;
    __label__ = 17;
    break;
   case 17:
    var $108 = __ZN2js6Parser9variablesEb($this, 0);
    if (($108 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $112 = $108 + 44 | 0;
    var $115 = HEAP32[$112 >> 2] & -4096 | 4;
    HEAP32[$112 >> 2] = $115;
    var $pn_0 = $108;
    __label__ = 19;
    break;
   case 19:
    var $pn_0;
    var $117 = __ZL22MatchOrInsertSemicolonP9JSContextPN2js11TokenStreamE($1);
    var $119 = ($117 | 0) != 0 ? $pn_0 : 0;
    var $_0 = $119;
    __label__ = 20;
    break;
   case 20:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser12letStatementEv["X"] = 1;

function __ZN2js16LexicalScopeNode6createEP13JSTreeContext($tc_0_11_val) {
  var $1 = __ZN11JSParseNode6createE16JSParseNodeArityP13JSTreeContext(6, $tc_0_11_val);
  return $1;
}

function __ZN2js6Parser19expressionStatementEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmtInfo = __stackBase__;
    var $1 = $this + 40 | 0;
    __ZN2js11TokenStream10ungetTokenEv($1);
    var $2 = __ZN2js6Parser4exprEv($this);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11TokenStream9peekTokenEv($1);
    if (($5 | 0) == 6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 3:
    var $8 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($2, 29);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 125, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 28;
    break;
   case 5:
    var $14 = HEAP32[$2 + 32 >> 2];
    var $15 = $this + 980 | 0;
    var $stmt_0_in = HEAP32[$15 >> 2] + 24 | 0;
    __label__ = 6;
    break;
   case 6:
    var $stmt_0_in;
    var $stmt_0 = HEAP32[$stmt_0_in >> 2];
    if (($stmt_0 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (HEAP16[$stmt_0 >> 1] << 16 >> 16 == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    if ((HEAP32[$stmt_0 + 20 >> 2] | 0) == ($14 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $29 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 126, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 28;
    break;
   case 10:
    var $stmt_0_in = $stmt_0 + 24 | 0;
    __label__ = 6;
    break;
   case 11:
    __ZL9ForgetUseP11JSParseNode($2);
    var $33 = __ZN2js11TokenStream8getTokenEv($1);
    var $35 = HEAP32[$15 >> 2];
    var $36 = $stmtInfo;
    _js_PushStatement($35, $36, 0, -1);
    HEAP32[$stmtInfo + 20 >> 2] = $14;
    var $38 = __ZN2js6Parser9statementEv($this);
    if (($38 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $41 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($38, 2);
    if ($41) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    if ((HEAP32[$38 + 32 >> 2] | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($38, 25);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($38, 5);
    __ZN11JSParseNode9makeEmptyEv($38);
    __label__ = 15;
    break;
   case 15:
    var $48 = HEAP32[$15 >> 2];
    __ZL12PopStatementP13JSTreeContext($48);
    __ZN11JSParseNode7setKindEN2js9TokenKindE($2, 6);
    var $51 = $38 + 12 | 0;
    var $52 = $2 + 12 | 0;
    var $53$0 = HEAP32[$51 >> 2];
    var $53$1 = HEAP32[$51 + 4 >> 2];
    HEAP32[$52 >> 2] = $53$0;
    HEAP32[$52 + 4 >> 2] = $53$1;
    HEAP32[$2 + 36 >> 2] = $38;
    var $_0 = $2;
    __label__ = 28;
    break;
   case 16:
    var $56 = $this + 980 | 0;
    var $_idx_val = HEAP32[HEAP32[$56 >> 2] + 48 >> 2];
    var $58 = __ZN2js9UnaryNode6createEP13JSTreeContext($_idx_val);
    var $59 = $58 | 0;
    if (($58 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($59, 2);
    var $64 = $58 + 4 | 0;
    var $65 = $2 + 4 | 0;
    HEAP32[$64 >> 2] = HEAP32[$65 >> 2];
    HEAP32[$64 + 4 >> 2] = HEAP32[$65 + 4 >> 2];
    HEAP32[$64 + 8 >> 2] = HEAP32[$65 + 8 >> 2];
    HEAP32[$64 + 12 >> 2] = HEAP32[$65 + 12 >> 2];
    var $66 = $58 + 32 | 0;
    HEAP32[$66 >> 2] = $2;
    var $67 = __ZNK11JSParseNode7getKindEv($2);
    if (($67 | 0) == 27) {
      __label__ = 18;
      break;
    } else if (($67 | 0) == 4) {
      __label__ = 21;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 18:
    var $70 = HEAP32[$2 + 32 >> 2];
    var $71 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($70, 34);
    if ($71) {
      __label__ = 19;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 19:
    var $75 = HEAP32[$70 + 32 >> 2];
    var $77 = HEAP32[$75 + 24 >> 2];
    var $78 = __ZNK11JSParseNode8isFunArgEv($77);
    if ($78) {
      __label__ = 27;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $80 = $75 + 60 | 0;
    var $82 = HEAP32[$80 >> 2] | 2097152;
    HEAP32[$80 >> 2] = $82;
    __label__ = 27;
    break;
   case 21:
    var $86 = HEAP32[HEAP32[$56 >> 2] + 80 >> 2];
    if (($86 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $89 = __ZNK11JSParseNode4isOpE4JSOp($2, 0);
    if ($89) {
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 23:
    var $92 = HEAP32[$2 + 32 >> 2];
    var $93 = __ZNK11JSParseNode4isOpE4JSOp($92, 54);
    if ($93) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $97 = HEAP32[$92 + 36 >> 2];
    var $98 = __ZNK11JSParseNode4isOpE4JSOp($97, 65);
    if ($98) {
      __label__ = 25;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 25:
    var $100 = $2 + 36 | 0;
    var $101 = HEAP32[$100 >> 2];
    var $102 = $101;
    var $103 = __ZNK11JSParseNode4isOpE4JSOp($102, 130);
    if ($103) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $106 = HEAP32[$86 + 40 >> 2];
    var $107 = $101 + 28 | 0;
    HEAP32[$107 >> 2] = $106;
    var $109 = HEAP32[$100 >> 2];
    var $113 = HEAP32[HEAP32[$56 >> 2] + 80 >> 2] + 40 | 0;
    HEAP32[$113 >> 2] = $109;
    __label__ = 27;
    break;
   case 27:
    var $115 = __ZL22MatchOrInsertSemicolonP9JSContextPN2js11TokenStreamE($1);
    var $117 = ($115 | 0) != 0 ? $59 : 0;
    var $_0 = $117;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser19expressionStatementEv["X"] = 1;

function __ZL9ForgetUseP11JSParseNode($pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode6isUsedEv($pn);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $pn_idx_val = HEAP32[$pn + 36 >> 2];
    var $3 = __ZNK11JSParseNode6lexdefEv($pn_idx_val);
    var $4 = $3 + 28 | 0;
    var $5 = HEAP32[$4 >> 2];
    if (($5 | 0) == ($pn | 0)) {
      var $pnup_0_lcssa = $4;
      __label__ = 4;
      break;
    } else {
      var $7 = $5;
      __label__ = 3;
      break;
    }
   case 3:
    var $7;
    var $8 = $7 + 28 | 0;
    var $9 = HEAP32[$8 >> 2];
    if (($9 | 0) == ($pn | 0)) {
      var $pnup_0_lcssa = $8;
      __label__ = 4;
      break;
    } else {
      var $7 = $9;
      __label__ = 3;
      break;
    }
   case 4:
    var $pnup_0_lcssa;
    var $12 = HEAP32[$pn + 28 >> 2];
    HEAP32[$pnup_0_lcssa >> 2] = $12;
    __ZN11JSParseNode7setUsedEb($pn, 0);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NullaryNode6createEP13JSTreeContext($tc_0_11_val) {
  var $1 = __ZN11JSParseNode6createE16JSParseNodeArityP13JSTreeContext(0, $tc_0_11_val);
  return $1;
}

function __ZL10MatchLabelP9JSContextPN2js11TokenStreamEP11JSParseNode($ts, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11TokenStream17peekTokenSameLineEj($ts);
    if (($1 | 0) == 29) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == -1) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      var $label_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js11TokenStream8getTokenEv($ts);
    var $4 = __ZNK2js11TokenStream12currentTokenEv($ts);
    var $label_0 = HEAP32[$4 + 28 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $label_0;
    HEAP32[$pn + 32 >> 2] = $label_0;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14BindVarOrConstP9JSContextP8BindDataP6JSAtomP13JSTreeContext($cx, $data, $atom, $tc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $mdl = __stackBase__ + 4;
    var $name = __stackBase__ + 12;
    var $name1 = __stackBase__ + 16;
    var $2 = __stackBase__ + 20;
    HEAP32[$1 >> 2] = $atom;
    var $4 = HEAP32[$data >> 2];
    __ZN11JSParseNode5setOpE4JSOp($4, 59);
    var $5 = __Z18CheckStrictBindingP9JSContextP13JSTreeContextP6JSAtomP11JSParseNode($cx, $tc, $atom, $4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_2 = 0;
      __label__ = 50;
      break;
    }
   case 2:
    var $7 = $tc;
    var $8 = _js_LexicalLookup($7, $atom, 0);
    var $9 = $8;
    var $10 = ($8 | 0) != 0;
    if ($10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    if (HEAP16[$8 >> 1] << 16 >> 16 == 6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP8[$data + 16 | 0] = 0;
    var $18 = $4 + 44 | 0;
    var $20 = HEAP32[$18 >> 2] | 1024;
    HEAP32[$18 >> 2] = $20;
    __ZN13JSTreeContext20noteMightAliasLocalsEv($tc);
    var $_2 = 1;
    __label__ = 50;
    break;
   case 5:
    var $22 = $tc + 40 | 0;
    var $_idx8_val = HEAP32[$tc + 44 >> 2];
    __ZN2js9AtomDecls11lookupMultiEP6JSAtom($mdl, $_idx8_val, $atom);
    var $23 = $data + 4 | 0;
    var $24 = HEAP32[$23 >> 2];
    var $mdl_idx10_val_pre = HEAP32[$mdl + 4 >> 2];
    if ($10) {
      var $mdl_idx10_val = $mdl_idx10_val_pre;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $26 = __ZNK2js14MultiDeclRange5emptyEv($mdl_idx10_val_pre);
    if ($26) {
      var $mdl_idx13_val = $mdl_idx10_val_pre;
      __label__ = 26;
      break;
    } else {
      var $mdl_idx10_val = $mdl_idx10_val_pre;
      __label__ = 7;
      break;
    }
   case 7:
    var $mdl_idx10_val;
    var $27 = __ZNK2js14MultiDeclRange5emptyEv($mdl_idx10_val);
    if ($27) {
      var $46 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $29 = __ZN2js14MultiDeclRange5frontEv($mdl_idx10_val);
    if (($29 | 0) == 0) {
      var $46 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = __ZN12JSDefinition4kindEv($29);
    if (($32 | 0) == 4) {
      __label__ = 10;
      break;
    } else {
      var $46 = $32;
      __label__ = 14;
      break;
    }
   case 10:
    __ZN16JSAutoByteStringC1Ev($name);
    var $35 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $atom, $name);
    if (($35 | 0) == 0) {
      __label__ = 49;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $38 = ($24 | 0) == 128;
    var $41 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $name_idx5_val = HEAP32[$name >> 2];
    var $42 = __ZNK16JSAutoByteString3ptrEv($name_idx5_val);
    if ($38) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $43 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($41, $4, 0, 164, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $42, tempInt));
    __ZN16JSAutoByteStringD1Ev($name_idx5_val);
    var $_2 = 0;
    __label__ = 50;
    break;
   case 13:
    var $45 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($41, $4, 5, 127, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $42, tempInt));
    __ZN16JSAutoByteStringD1Ev($name_idx5_val);
    if ($45) {
      var $mdl_idx13_val = $mdl_idx10_val;
      __label__ = 26;
      break;
    } else {
      var $_2 = 0;
      __label__ = 50;
      break;
    }
   case 14:
    var $46;
    if (($24 | 0) == 128 | ($46 | 0) == 1) {
      var $58 = 1;
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    if (($46 | 0) == 2) {
      __label__ = 16;
      break;
    } else {
      var $58 = 0;
      __label__ = 18;
      break;
    }
   case 16:
    if (HEAP16[$8 >> 1] << 16 >> 16 == 7) {
      __label__ = 17;
      break;
    } else {
      var $58 = 1;
      __label__ = 18;
      break;
    }
   case 17:
    var $56 = __ZL8OuterLetP13JSTreeContextP10JSStmtInfoP6JSAtom($tc, $9, $atom);
    var $58 = $56;
    __label__ = 18;
    break;
   case 18:
    var $58;
    var $cx_idx_val = HEAP32[$cx + 32 >> 2];
    var $59 = __ZNK9JSContext15hasStrictOptionEv($cx_idx_val);
    if ($59) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    if (($24 | 0) == 129 & ($46 | 0) == 0) {
      var $mdl_idx13_val = $mdl_idx10_val;
      __label__ = 26;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    if ($58) {
      __label__ = 21;
      break;
    } else {
      var $mdl_idx13_val = $mdl_idx10_val;
      __label__ = 26;
      break;
    }
   case 21:
    __ZN16JSAutoByteStringC1Ev($name1);
    var $65 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $atom, $name1);
    if (($65 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    var $name1_idx1_val = HEAP32[$name1 >> 2];
    __label__ = 24;
    break;
   case 23:
    var $70 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $71 = $58 ? 0 : 5;
    var $72 = __ZN12JSDefinition10kindStringENS_4KindE($46);
    var $name1_idx4_val = HEAP32[$name1 >> 2];
    var $73 = __ZNK16JSAutoByteString3ptrEv($name1_idx4_val);
    var $74 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($70, $4, $71, 155, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $72, HEAP32[tempInt + 4 >> 2] = $73, tempInt));
    if ($74) {
      __label__ = 25;
      break;
    } else {
      var $name1_idx1_val = $name1_idx4_val;
      __label__ = 24;
      break;
    }
   case 24:
    var $name1_idx1_val;
    __ZN16JSAutoByteStringD1Ev($name1_idx1_val);
    var $_2 = 0;
    __label__ = 50;
    break;
   case 25:
    __ZN16JSAutoByteStringD1Ev($name1_idx4_val);
    var $mdl_idx13_val = $mdl_idx10_val;
    __label__ = 26;
    break;
   case 26:
    var $mdl_idx13_val;
    var $mdl_idx9 = $mdl + 4 | 0;
    var $77 = __ZNK2js14MultiDeclRange5emptyEv($mdl_idx13_val);
    if ($77) {
      __label__ = 27;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 27:
    var $79 = __ZL6DefineP11JSParseNodeP6JSAtomP13JSTreeContextb($4, $atom, $tc, 0);
    if ($79) {
      var $pn_2 = $4;
      __label__ = 44;
      break;
    } else {
      var $_2 = 0;
      __label__ = 50;
      break;
    }
   case 28:
    var $81 = __ZN2js14MultiDeclRange5frontEv($mdl_idx13_val);
    HEAP8[$data + 16 | 0] = 0;
    var $83 = __ZNK11JSParseNode6isUsedEv($4);
    if ($83) {
      var $dn3_0 = $81;
      __label__ = 32;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $85 = __ZNK11JSParseNode6isDefnEv($4);
    if ($85) {
      __label__ = 30;
      break;
    } else {
      var $pnu_0 = $4;
      __label__ = 31;
      break;
    }
   case 30:
    var $87 = __ZN2js8NameNode6createEP6JSAtomP13JSTreeContext($atom, $tc);
    var $88 = $87 | 0;
    if (($87 | 0) == 0) {
      var $_2 = 0;
      __label__ = 50;
      break;
    } else {
      var $pnu_0 = $88;
      __label__ = 31;
      break;
    }
   case 31:
    var $pnu_0;
    __ZL12LinkUseToDefP11JSParseNodeP12JSDefinitionP13JSTreeContext($pnu_0, $81);
    __ZN11JSParseNode5setOpE4JSOp($pnu_0, 59);
    var $dn3_0 = $81;
    __label__ = 32;
    break;
   case 32:
    var $dn3_0;
    var $91 = __ZN12JSDefinition4kindEv($dn3_0);
    if (($91 | 0) == 2) {
      __label__ = 33;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 33:
    __ZN2js14MultiDeclRange8popFrontEv($mdl);
    var $mdl_idx_val = HEAP32[$mdl_idx9 >> 2];
    var $94 = __ZNK2js14MultiDeclRange5emptyEv($mdl_idx_val);
    if ($94) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $96 = __ZN2js14MultiDeclRange5frontEv($mdl_idx_val);
    var $dn3_0 = $96;
    __label__ = 32;
    break;
   case 35:
    if (($dn3_0 | 0) == 0) {
      __label__ = 36;
      break;
    } else {
      var $_2 = 1;
      __label__ = 50;
      break;
    }
   case 36:
    var $100 = __ZNK11JSParseNode6isDefnEv($4);
    if ($100) {
      var $pn_1 = $4;
      var $119 = $atom;
      __label__ = 42;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $_idx6 = $tc + 64 | 0;
    var $_idx6_val = HEAP32[$_idx6 >> 2];
    var $102 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($_idx6_val);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6lookupERKS2_($2, $102, $1);
    var $103 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrcvPPPPPPPS6_Ev($2);
    if (($103 | 0) == 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $_idx_val = HEAP32[$_idx6 >> 2];
    var $106 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($_idx_val);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6removeERKS2_($106, $1);
    var $pn_0 = $4;
    var $_pre = HEAP32[$1 >> 2];
    __label__ = 41;
    break;
   case 39:
    var $108 = HEAP32[$1 >> 2];
    var $109 = __ZN2js8NameNode6createEP6JSAtomP13JSTreeContext($108, $tc);
    var $110 = $109 | 0;
    if (($109 | 0) == 0) {
      var $_2 = 0;
      __label__ = 50;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($110, 29);
    var $115 = $109 + 4 | 0;
    var $116 = $4 + 4 | 0;
    HEAP32[$115 >> 2] = HEAP32[$116 >> 2];
    HEAP32[$115 + 4 >> 2] = HEAP32[$116 + 4 >> 2];
    HEAP32[$115 + 8 >> 2] = HEAP32[$116 + 8 >> 2];
    HEAP32[$115 + 12 >> 2] = HEAP32[$116 + 12 >> 2];
    var $pn_0 = $110;
    var $_pre = $108;
    __label__ = 41;
    break;
   case 41:
    var $_pre;
    var $pn_0;
    __ZN11JSParseNode5setOpE4JSOp($pn_0, 59);
    var $pn_1 = $pn_0;
    var $119 = $_pre;
    __label__ = 42;
    break;
   case 42:
    var $119;
    var $pn_1;
    var $120 = $22;
    var $122 = __ZN2js9AtomDecls8addHoistEP6JSAtomP12JSDefinition($120, $119, $pn_1);
    if ($122) {
      __label__ = 43;
      break;
    } else {
      var $_2 = 0;
      __label__ = 50;
      break;
    }
   case 43:
    __ZN11JSParseNode7setDefnEb($pn_1, 1);
    var $125 = $pn_1 + 44 | 0;
    var $127 = HEAP32[$125 >> 2] & -129;
    HEAP32[$125 >> 2] = $127;
    var $pn_2 = $pn_1;
    __label__ = 44;
    break;
   case 44:
    var $pn_2;
    if ((HEAP32[$23 >> 2] | 0) == 128) {
      __label__ = 45;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 45:
    var $133 = $pn_2 + 44 | 0;
    var $135 = HEAP32[$133 >> 2] | 2;
    HEAP32[$133 >> 2] = $135;
    __label__ = 46;
    break;
   case 46:
    var $_idx7_val = HEAP32[$tc >> 2];
    var $137 = __ZNK13JSTreeContext10inFunctionEv($_idx7_val);
    if ($137) {
      __label__ = 47;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 47:
    var $139 = __ZL17BindFunctionLocalP9JSContextP8BindDataRN2js14MultiDeclRangeEP13JSTreeContext($cx, $data, $tc);
    var $_2 = $139 & 1;
    __label__ = 50;
    break;
   case 48:
    var $142 = __ZL15BindTopLevelVarP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($pn_2, $tc);
    var $_2 = $142 & 1;
    __label__ = 50;
    break;
   case 49:
    var $name_idx_val = HEAP32[$name >> 2];
    __ZN16JSAutoByteStringD1Ev($name_idx_val);
    var $_2 = 0;
    __label__ = 50;
    break;
   case 50:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14BindVarOrConstP9JSContextP8BindDataP6JSAtomP13JSTreeContext["X"] = 1;

function __ZL22UndominateInitializersP11JSParseNodeRKN2js8TokenPtrEP13JSTreeContext($left, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($left, 24);
    var $3 = HEAP32[$left + 32 >> 2];
    var $4 = ($3 | 0) == 0;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    if ($4) {
      __label__ = 18;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = $end;
    var $pn_04 = $3;
    __label__ = 6;
    break;
   case 4:
    if ($4) {
      __label__ = 18;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $6 = $end;
    var $pair_01 = $3;
    __label__ = 13;
    break;
   case 6:
    var $pn_04;
    var $8 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_04, 3);
    if ($8) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $10 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn_04, 0);
    if ($10) {
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $12 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_04, 24);
    if ($12) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $14 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_04, 26);
    if ($14) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    __ZL22UndominateInitializersP11JSParseNodeRKN2js8TokenPtrEP13JSTreeContext($pn_04, $end);
    __label__ = 12;
    break;
   case 11:
    var $18 = $pn_04 + 12 | 0;
    var $st$2$0 = $5 | 0;
    var $19$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $5 + 4 | 0;
    var $19$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $18 | 0;
    HEAP32[$st$6$0 >> 2] = $19$0;
    var $st$6$1 = $18 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $19$1;
    __label__ = 12;
    break;
   case 12:
    var $22 = HEAP32[$pn_04 + 24 >> 2];
    if (($22 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      var $pn_04 = $22;
      __label__ = 6;
      break;
    }
   case 13:
    var $pair_01;
    var $26 = HEAP32[$pair_01 + 36 >> 2];
    var $27 = $26;
    var $28 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($27, 24);
    if ($28) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $30 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($27, 26);
    if ($30) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    __ZL22UndominateInitializersP11JSParseNodeRKN2js8TokenPtrEP13JSTreeContext($27, $end);
    __label__ = 17;
    break;
   case 16:
    var $34 = $26 + 12 | 0;
    var $st$2$0 = $6 | 0;
    var $35$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $6 + 4 | 0;
    var $35$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $34 | 0;
    HEAP32[$st$6$0 >> 2] = $35$0;
    var $st$6$1 = $34 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $35$1;
    __label__ = 17;
    break;
   case 17:
    var $38 = HEAP32[$pair_01 + 24 >> 2];
    if (($38 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      var $pair_01 = $38;
      __label__ = 13;
      break;
    }
   case 18:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL22UndominateInitializersP11JSParseNodeRKN2js8TokenPtrEP13JSTreeContext["X"] = 1;

function __ZL14MakeAssignmentP11JSParseNodeS0_P13JSTreeContext($pn, $rhs, $tc_0_11_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL17NewOrRecycledNodeP13JSTreeContext($tc_0_11_val);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1 | 0;
    var $5 = $pn | 0;
    for (var $$src = $5 >> 2, $$dest = $4 >> 2, $$stop = $$src + 12; $$src < $$stop; $$src++, $$dest++) {
      HEAP32[$$dest] = HEAP32[$$src];
    }
    var $6 = __ZNK11JSParseNode6isUsedEv($pn);
    var $7 = $pn + 36 | 0;
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_pre_phi = $7;
      __label__ = 6;
      break;
    }
   case 3:
    var $10 = HEAP32[$7 >> 2] + 28 | 0;
    var $11 = HEAP32[$10 >> 2];
    if (($11 | 0) == ($pn | 0)) {
      var $pnup_0_lcssa = $10;
      __label__ = 5;
      break;
    } else {
      var $13 = $11;
      __label__ = 4;
      break;
    }
   case 4:
    var $13;
    var $14 = $13 + 28 | 0;
    var $15 = HEAP32[$14 >> 2];
    if (($15 | 0) == ($pn | 0)) {
      var $pnup_0_lcssa = $14;
      __label__ = 5;
      break;
    } else {
      var $13 = $15;
      __label__ = 4;
      break;
    }
   case 5:
    var $pnup_0_lcssa;
    HEAP32[$pnup_0_lcssa >> 2] = $1;
    var $17 = $pn + 28 | 0;
    var $18 = HEAP32[$17 >> 2];
    HEAP32[$1 + 28 >> 2] = $18;
    HEAP32[$17 >> 2] = 0;
    var $_pre_phi = $7;
    __label__ = 6;
    break;
   case 6:
    var $_pre_phi;
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 4);
    __ZN11JSParseNode5setOpE4JSOp($pn, 0);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn, 2);
    __ZN11JSParseNode11setInParensEb($pn, 0);
    __ZN11JSParseNode7setUsedEb($pn, 0);
    __ZN11JSParseNode7setDefnEb($pn, 0);
    HEAP32[$pn + 32 >> 2] = $1;
    HEAP32[$_pre_phi >> 2] = $rhs;
    var $_0 = $1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSTreeContext16noteArgumentsUseEP11JSParseNode($this, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __ZN13JSTreeContext17countArgumentsUseEP11JSParseNode($this, $pn);
    var $1 = $this | 0;
    var $3 = HEAP32[$1 >> 2] | 128;
    HEAP32[$1 >> 2] = $3;
    var $5 = HEAP32[$this + 80 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = HEAP32[$5 + 24 >> 2] + 44 | 0;
    var $13 = HEAP32[$11 >> 2] | 256;
    HEAP32[$11 >> 2] = $13;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser9mulExpr1nEv($this) {
  var $1 = __ZN2js6Parser9mulExpr1iEv($this);
  return $1;
}

function __ZN2js6Parser9mulExpr1iEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser9unaryExprEv($this);
    var $2 = $this + 40 | 0;
    var $3 = $this + 980 | 0;
    var $pn_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZN2js11TokenStream8getTokenEv($2);
    if (($7 - 17 | 0) >>> 0 < 2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2js11TokenStream12currentTokenEv($2);
    var $10 = HEAP32[$8 >> 2];
    var $12 = HEAP32[$8 + 24 >> 2];
    var $13 = __ZN2js6Parser9unaryExprEv($this);
    var $14 = HEAP32[$3 >> 2];
    var $15 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext($10, $12, $pn_0, $13, $14);
    var $pn_0 = $15;
    __label__ = 2;
    break;
   case 5:
    return $pn_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser9addExpr1nEv($this) {
  var $1 = __ZN2js6Parser9addExpr1iEv($this);
  return $1;
}

function __ZN2js6Parser9addExpr1iEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser9mulExpr1iEv($this);
    var $2 = $this + 40 | 0;
    var $3 = $this + 980 | 0;
    var $pn_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindES1_($2);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZNK2js11TokenStream12currentTokenEv($2);
    var $11 = HEAP32[$9 >> 2];
    var $13 = ($11 | 0) == 15 ? 27 : 28;
    var $14 = __ZN2js6Parser9mulExpr1nEv($this);
    var $15 = HEAP32[$3 >> 2];
    var $16 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext($11, $13, $pn_0, $14, $15);
    var $pn_0 = $16;
    __label__ = 2;
    break;
   case 5:
    return $pn_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser11shiftExpr1nEv($this) {
  var $1 = __ZN2js6Parser11shiftExpr1iEv($this);
  return $1;
}

function __ZN2js6Parser11shiftExpr1iEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser9addExpr1iEv($this);
    var $2 = $this + 40 | 0;
    var $3 = $this + 980 | 0;
    var $pn_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($2, 14);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZNK2js11TokenStream12currentTokenEv($2);
    var $11 = HEAP32[$9 + 24 >> 2];
    var $12 = __ZN2js6Parser9addExpr1nEv($this);
    var $13 = HEAP32[$3 >> 2];
    var $14 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(14, $11, $pn_0, $12, $13);
    var $pn_0 = $14;
    __label__ = 2;
    break;
   case 5:
    return $pn_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser9relExpr1nEv($this) {
  var $1 = __ZN2js6Parser9relExpr1iEv($this);
  return $1;
}

function __ZN2js6Parser9relExpr1iEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 980 | 0;
    var $3 = HEAP32[$1 >> 2] | 0;
    var $4 = HEAP32[$3 >> 2];
    var $5 = $4 & 16;
    var $6 = $4 & -17;
    HEAP32[$3 >> 2] = $6;
    var $7 = __ZN2js6Parser11shiftExpr1iEv($this);
    var $8 = $this + 40 | 0;
    var $9 = ($5 | 0) == 0;
    var $pn_0 = $7;
    __label__ = 2;
    break;
   case 2:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($8, 13);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ($9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($8, 45);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($8, 57);
    if ($18) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $19 = __ZNK2js11TokenStream12currentTokenEv($8);
    var $21 = HEAP32[$19 >> 2];
    var $23 = HEAP32[$19 + 24 >> 2];
    var $24 = __ZN2js6Parser11shiftExpr1nEv($this);
    var $25 = HEAP32[$1 >> 2];
    var $26 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext($21, $23, $pn_0, $24, $25);
    var $pn_0 = $26;
    __label__ = 2;
    break;
   case 8:
    var $28 = HEAP32[$1 >> 2] | 0;
    var $30 = HEAP32[$28 >> 2] | $5;
    HEAP32[$28 >> 2] = $30;
    return $pn_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser8eqExpr1nEv($this) {
  var $1 = __ZN2js6Parser8eqExpr1iEv($this);
  return $1;
}

function __ZN2js6Parser8eqExpr1iEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser9relExpr1iEv($this);
    var $2 = $this + 40 | 0;
    var $3 = $this + 980 | 0;
    var $pn_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($2, 12);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZNK2js11TokenStream12currentTokenEv($2);
    var $11 = HEAP32[$9 + 24 >> 2];
    var $12 = __ZN2js6Parser9relExpr1nEv($this);
    var $13 = HEAP32[$3 >> 2];
    var $14 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(12, $11, $pn_0, $12, $13);
    var $pn_0 = $14;
    __label__ = 2;
    break;
   case 5:
    return $pn_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser12bitAndExpr1nEv($this) {
  var $1 = __ZN2js6Parser12bitAndExpr1iEv($this);
  return $1;
}

function __ZN2js6Parser12bitAndExpr1iEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser8eqExpr1iEv($this);
    var $2 = $this + 40 | 0;
    var $3 = $this + 980 | 0;
    var $pn_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($2, 11);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZN2js6Parser8eqExpr1nEv($this);
    var $10 = HEAP32[$3 >> 2];
    var $11 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(11, 17, $pn_0, $9, $10);
    var $pn_0 = $11;
    __label__ = 2;
    break;
   case 5:
    return $pn_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser12bitXorExpr1nEv($this) {
  var $1 = __ZN2js6Parser12bitXorExpr1iEv($this);
  return $1;
}

function __ZN2js6Parser12bitXorExpr1iEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser12bitAndExpr1iEv($this);
    var $2 = $this + 40 | 0;
    var $3 = $this + 980 | 0;
    var $pn_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($2, 10);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZN2js6Parser12bitAndExpr1nEv($this);
    var $10 = HEAP32[$3 >> 2];
    var $11 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(10, 16, $pn_0, $9, $10);
    var $pn_0 = $11;
    __label__ = 2;
    break;
   case 5:
    return $pn_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser11bitOrExpr1nEv($this) {
  var $1 = __ZN2js6Parser11bitOrExpr1iEv($this);
  return $1;
}

function __ZN2js6Parser11bitOrExpr1iEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser12bitXorExpr1iEv($this);
    var $2 = $this + 40 | 0;
    var $3 = $this + 980 | 0;
    var $pn_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($2, 9);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZN2js6Parser12bitXorExpr1nEv($this);
    var $10 = HEAP32[$3 >> 2];
    var $11 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(9, 15, $pn_0, $9, $10);
    var $pn_0 = $11;
    __label__ = 2;
    break;
   case 5:
    return $pn_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser9andExpr1nEv($this) {
  var $1 = __ZN2js6Parser9andExpr1iEv($this);
  return $1;
}

function __ZN2js6Parser9andExpr1iEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser11bitOrExpr1iEv($this);
    var $2 = $this + 40 | 0;
    var $3 = $this + 980 | 0;
    var $pn_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($2, 8);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZN2js6Parser11bitOrExpr1nEv($this);
    var $10 = HEAP32[$3 >> 2];
    var $11 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(8, 69, $pn_0, $9, $10);
    var $pn_0 = $11;
    __label__ = 2;
    break;
   case 5:
    return $pn_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11MakeSetCallP9JSContextP11JSParseNodeP13JSTreeContextj($cx, $pn, $tc, $msg) {
  var __stackBase__ = STACKTOP;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $tc + 48 | 0;
    var $3 = HEAP32[$1 >> 2] + 40 | 0;
    var $4 = $tc;
    var $5 = __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($cx, $3, $4, $pn, $msg, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $8 = HEAP32[$pn + 32 >> 2];
    var $9 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($8, 34);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    if ((HEAP32[HEAP32[$8 + 32 >> 2] + 60 >> 2] & 4096 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $20 = HEAP32[$1 >> 2] + 40 | 0;
    var $21 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($20, $pn, 0, $msg, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 5:
    var $24 = $pn + 44 | 0;
    var $26 = HEAP32[$24 >> 2] | 256;
    HEAP32[$24 >> 2] = $26;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser9condExpr1Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser7orExpr1Ev($this);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $this + 40 | 0;
    var $5 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($4, 5);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $1;
      __label__ = 9;
      break;
    }
   case 3:
    var $7 = $this + 980 | 0;
    var $_idx_val = HEAP32[HEAP32[$7 >> 2] + 48 >> 2];
    var $9 = __ZN2js11TernaryNode6createEP13JSTreeContext($_idx_val);
    var $10 = $9 | 0;
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = HEAP32[$7 >> 2] | 0;
    var $15 = HEAP32[$14 >> 2];
    var $16 = $15 & -17;
    HEAP32[$14 >> 2] = $16;
    var $17 = __ZN2js6Parser10assignExprEv($this);
    var $19 = HEAP32[$7 >> 2] | 0;
    var $22 = HEAP32[$19 >> 2] & 629442528 | $15;
    HEAP32[$19 >> 2] = $22;
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $25 = __ZN2js11TokenStream8getTokenEj($4, 0);
    if (($25 | 0) == 6) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $28 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 103, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 7:
    var $30 = __ZN2js6Parser10assignExprEv($this);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $35 = $1 + 4 | 0;
    var $36 = $9 + 4 | 0;
    var $37$0 = HEAP32[$35 >> 2];
    var $37$1 = HEAP32[$35 + 4 >> 2];
    var $st$8$0 = $36 | 0;
    HEAP32[$st$8$0 >> 2] = $37$0;
    var $st$8$1 = $36 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $37$1;
    var $40 = $30 + 12 | 0;
    var $41 = $9 + 12 | 0;
    var $42$0 = HEAP32[$40 >> 2];
    var $42$1 = HEAP32[$40 + 4 >> 2];
    var $st$20$0 = $41 | 0;
    HEAP32[$st$20$0 >> 2] = $42$0;
    var $st$20$1 = $41 + 4 | 0;
    HEAP32[$st$20$1 >> 2] = $42$1;
    var $43 = $9 + 32 | 0;
    HEAP32[$43 >> 2] = $1;
    var $44 = $9 + 36 | 0;
    HEAP32[$44 >> 2] = $17;
    var $45 = $9 + 40 | 0;
    HEAP32[$45 >> 2] = $30;
    var $46 = __ZN2js11TokenStream8getTokenEv($4);
    var $_0 = $10;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser9condExpr1Ev["X"] = 1;

function __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($this, $type) {
  var $1 = __ZNK2js11TokenStream12currentTokenEv($this);
  return (HEAP32[$1 >> 2] | 0) == ($type | 0);
}

function __ZNK11JSParseNode10isAssignedEv($this) {
  var $1 = __ZNK11JSParseNode4testEj($this, 8);
  return $1;
}

function __ZN2js6Parser9unaryExprEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $this + 12 | 0;
    var $3 = HEAPU32[$2 >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$3 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($3);
    var $_0 = 0;
    __label__ = 29;
    break;
   case 3:
    var $9 = $this + 40 | 0;
    var $10 = __ZN2js11TokenStream8getTokenEj($9, 8);
    if (($10 | 0) == 19 || ($10 | 0) == 15 || ($10 | 0) == 16) {
      __label__ = 4;
      break;
    } else if (($10 | 0) == 20 || ($10 | 0) == 21) {
      __label__ = 7;
      break;
    } else if (($10 | 0) == 50) {
      __label__ = 11;
      break;
    } else if (($10 | 0) == -1) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 4:
    var $_idx3_val = HEAP32[HEAP32[$this + 980 >> 2] + 48 >> 2];
    var $14 = __ZN2js9UnaryNode6createEP13JSTreeContext($_idx3_val);
    var $15 = $14 | 0;
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($15, 19);
    var $18 = __ZNK2js11TokenStream12currentTokenEv($9);
    var $20 = HEAP32[$18 + 24 >> 2];
    __ZN11JSParseNode5setOpE4JSOp($15, $20);
    var $21 = __ZN2js6Parser9unaryExprEv($this);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $26 = $21 + 12 | 0;
    var $27 = $14 + 12 | 0;
    var $st$4$0 = $26 | 0;
    var $28$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $26 + 4 | 0;
    var $28$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $27 | 0;
    HEAP32[$st$8$0 >> 2] = $28$0;
    var $st$8$1 = $27 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $28$1;
    var $29 = $14 + 32 | 0;
    HEAP32[$29 >> 2] = $21;
    var $_0 = $15;
    __label__ = 29;
    break;
   case 7:
    var $31 = $this + 980 | 0;
    var $_idx2_val = HEAP32[HEAP32[$31 >> 2] + 48 >> 2];
    var $33 = __ZN2js9UnaryNode6createEP13JSTreeContext($_idx2_val);
    var $34 = $33 | 0;
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $37 = __ZN2js6Parser10memberExprEi($this, 1);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $40 = HEAP32[$2 >> 2];
    var $41 = HEAP32[$31 >> 2];
    var $42 = __ZL11SetIncOpKidP9JSContextPN2js11TokenStreamEP13JSTreeContextP11JSParseNodeS7_NS1_9TokenKindEi($40, $9, $41, $34, $37, $10, 1);
    if (($42 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $47 = $37 + 12 | 0;
    var $48 = $33 + 12 | 0;
    var $st$4$0 = $47 | 0;
    var $49$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $47 + 4 | 0;
    var $49$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $48 | 0;
    HEAP32[$st$8$0 >> 2] = $49$0;
    var $st$8$1 = $48 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $49$1;
    var $_0 = $34;
    __label__ = 29;
    break;
   case 11:
    var $51 = $this + 980 | 0;
    var $_idx1_val = HEAP32[HEAP32[$51 >> 2] + 48 >> 2];
    var $53 = __ZN2js9UnaryNode6createEP13JSTreeContext($_idx1_val);
    var $54 = $53 | 0;
    if (($53 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $57 = __ZN2js6Parser9unaryExprEv($this);
    if (($57 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $62 = $57 + 12 | 0;
    var $63 = $53 + 12 | 0;
    var $st$4$0 = $62 | 0;
    var $64$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $62 + 4 | 0;
    var $64$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $63 | 0;
    HEAP32[$st$8$0 >> 2] = $64$0;
    var $st$8$1 = $63 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $64$1;
    if ((HEAP8[$this + 988 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $70 = HEAP32[$2 >> 2];
    var $71 = HEAP32[$51 >> 2];
    var $72 = _js_FoldConstants($70, $57, $71, 0);
    if (($72 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $75 = __ZNK11JSParseNode7getKindEv($57);
    if (($75 | 0) == 27) {
      __label__ = 16;
      break;
    } else if (($75 | 0) == 29) {
      __label__ = 19;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 16:
    var $78 = $57 + 44 | 0;
    if ((HEAP32[$78 >> 2] & 256 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 17:
    var $83 = HEAP32[$2 >> 2];
    var $84 = HEAP32[$51 >> 2];
    var $85 = __ZL11MakeSetCallP9JSContextP11JSParseNodeP13JSTreeContextj($83, $57, $84, 220);
    if ($85) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 18:
    var $88 = HEAP32[$78 >> 2] & -257;
    HEAP32[$78 >> 2] = $88;
    __label__ = 22;
    break;
   case 19:
    var $90 = HEAP32[$2 >> 2];
    var $92 = HEAP32[$51 >> 2];
    var $93 = __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($90, $9, $92, $54, 235, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    if ($93) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 20:
    __ZN11JSParseNode5setOpE4JSOp($57, 36);
    if ((HEAP32[$57 + 32 >> 2] | 0) == (HEAP32[HEAP32[HEAP32[$2 >> 2] + 52 >> 2] + 210176 >> 2] | 0)) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    var $107 = HEAP32[$51 >> 2] | 0;
    var $109 = HEAP32[$107 >> 2] | 256;
    HEAP32[$107 >> 2] = $109;
    var $110 = HEAP32[$51 >> 2];
    __ZN13JSTreeContext17countArgumentsUseEP11JSParseNode($110, $57);
    __label__ = 22;
    break;
   case 22:
    var $112 = $53 + 32 | 0;
    HEAP32[$112 >> 2] = $57;
    var $_0 = $54;
    __label__ = 29;
    break;
   case 23:
    __ZN2js11TokenStream10ungetTokenEv($9);
    var $114 = __ZN2js6Parser10memberExprEi($this, 1);
    if (($114 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $117 = $114 + 4 | 0;
    var $_idx4_val = HEAP32[$this + 180 >> 2];
    var $_idx5_val = HEAP32[$114 + 16 >> 2];
    var $118 = __ZNK2js11TokenStream13onCurrentLineERKNS_8TokenPosE($_idx4_val, $_idx5_val);
    if ($118) {
      __label__ = 25;
      break;
    } else {
      var $_0 = $114;
      __label__ = 29;
      break;
    }
   case 25:
    var $120 = __ZN2js11TokenStream17peekTokenSameLineEj($9);
    if (($120 - 20 | 0) >>> 0 < 2) {
      __label__ = 26;
      break;
    } else {
      var $_0 = $114;
      __label__ = 29;
      break;
    }
   case 26:
    var $123 = __ZN2js11TokenStream8getTokenEv($9);
    var $124 = $this + 980 | 0;
    var $_idx_val = HEAP32[HEAP32[$124 >> 2] + 48 >> 2];
    var $126 = __ZN2js9UnaryNode6createEP13JSTreeContext($_idx_val);
    var $127 = $126 | 0;
    if (($126 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $130 = HEAP32[$2 >> 2];
    var $131 = HEAP32[$124 >> 2];
    var $132 = __ZL11SetIncOpKidP9JSContextPN2js11TokenStreamEP13JSTreeContextP11JSParseNodeS7_NS1_9TokenKindEi($130, $9, $131, $127, $114, $120, 0);
    if (($132 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $136 = $117;
    var $137 = $126 + 4 | 0;
    var $138$0 = HEAP32[$136 >> 2];
    var $138$1 = HEAP32[$136 + 4 >> 2];
    var $st$7$0 = $137 | 0;
    HEAP32[$st$7$0 >> 2] = $138$0;
    var $st$7$1 = $137 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $138$1;
    var $_0 = $127;
    __label__ = 29;
    break;
   case 29:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser9unaryExprEv["X"] = 1;

function __ZN2js6Parser10memberExprEi($this, $allowCallSyntax) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmtInfo = __stackBase__ + 4;
    var $index = __stackBase__ + 36;
    var $2 = $this + 12 | 0;
    var $3 = HEAPU32[$2 >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$3 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($3);
    var $_0 = 0;
    __label__ = 69;
    break;
   case 3:
    var $9 = $this + 40 | 0;
    var $10 = __ZN2js11TokenStream8getTokenEj($9, 8);
    if (($10 | 0) == 49) {
      __label__ = 4;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 4:
    var $13 = $this + 980 | 0;
    var $_idx3_val = HEAP32[HEAP32[$13 >> 2] + 48 >> 2];
    var $15 = __ZN2js8ListNode6createEP13JSTreeContext($_idx3_val);
    var $16 = $15 | 0;
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = __ZN2js6Parser10memberExprEi($this, 0);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = __ZL32CheckForImmediatelyAppliedLambdaP11JSParseNode($19);
    __ZN11JSParseNode5setOpE4JSOp($16, 82);
    __ZN11JSParseNode8initListEPS_($16, $22);
    var $25 = $22 + 4 | 0;
    var $26 = $15 + 4 | 0;
    var $st$7$0 = $25 | 0;
    var $27$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $25 + 4 | 0;
    var $27$1 = HEAP32[$st$7$1 >> 2];
    var $st$11$0 = $26 | 0;
    HEAP32[$st$11$0 >> 2] = $27$0;
    var $st$11$1 = $26 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $27$1;
    var $28 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($9, 27);
    if ($28) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $30 = __ZN2js6Parser12argumentListEP11JSParseNode($this, $16);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if (HEAPU32[$15 + 40 >> 2] >>> 0 > 65536) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $37 = HEAP32[$2 >> 2];
    _JS_ReportErrorNumber($37, 4, 44, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 69;
    break;
   case 10:
    var $39 = $15 + 12 | 0;
    var $_idx6_val = HEAP32[$15 + 36 >> 2];
    var $40 = __ZNK11JSParseNode4lastEv($_idx6_val);
    var $42 = $40 + 12 | 0;
    var $43 = $39;
    var $st$7$0 = $42 | 0;
    var $44$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $42 + 4 | 0;
    var $44$1 = HEAP32[$st$7$1 >> 2];
    var $st$11$0 = $43 | 0;
    HEAP32[$st$11$0 >> 2] = $44$0;
    var $st$11$1 = $43 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $44$1;
    var $pn_0_ph = $16;
    var $_pre_phi = $13;
    __label__ = 18;
    break;
   case 11:
    var $46 = __ZN2js6Parser11primaryExprENS_9TokenKindEi($this, $10, 0);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $49 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($46, 72);
    if ($49) {
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $51 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($46, 70);
    if ($51) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $53 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($46, 71);
    if ($53) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $pn_0_ph = $46;
    var $_pre_phi = $this + 980 | 0;
    __label__ = 18;
    break;
   case 16:
    var $55 = $this + 980 | 0;
    var $_idx1_val = HEAP32[HEAP32[$55 >> 2] + 48 >> 2];
    var $57 = __ZL17NewOrRecycledNodeP13JSTreeContext($_idx1_val);
    if (($57 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($57, 19);
    var $62 = $57 + 4 | 0;
    var $63 = $46 + 4 | 0;
    HEAP32[$62 >> 2] = HEAP32[$63 >> 2];
    HEAP32[$62 + 4 >> 2] = HEAP32[$63 + 4 >> 2];
    HEAP32[$62 + 8 >> 2] = HEAP32[$63 + 8 >> 2];
    HEAP32[$62 + 12 >> 2] = HEAP32[$63 + 12 >> 2];
    __ZN11JSParseNode5setOpE4JSOp($57, 174);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($57, 1);
    __ZN11JSParseNode11setInParensEb($57, 0);
    var $64 = $57 + 32 | 0;
    HEAP32[$64 >> 2] = $46;
    var $pn_0_ph = $57;
    var $_pre_phi = $55;
    __label__ = 18;
    break;
   case 18:
    var $_pre_phi;
    var $pn_0_ph;
    var $65 = ($allowCallSyntax | 0) != 0;
    var $pn_0 = $pn_0_ph;
    __label__ = 19;
    break;
   case 19:
    var $pn_0;
    var $66 = __ZN2js11TokenStream8getTokenEv($9);
    if (($66 | 0) > 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 20:
    if (($66 | 0) == 22) {
      __label__ = 21;
      break;
    } else if (($66 | 0) == 73) {
      __label__ = 35;
      break;
    } else if (($66 | 0) == 23) {
      __label__ = 43;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 21:
    var $70 = HEAP32[$_pre_phi >> 2];
    var $71 = __ZN2js8NameNode6createEP6JSAtomP13JSTreeContext(0, $70);
    var $72 = $71 | 0;
    if (($71 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $75 = __ZN2js11TokenStream8getTokenEj($9, 40);
    var $77 = HEAP32[$_pre_phi >> 2] + 88 | 0;
    var $78 = HEAP32[$77 >> 2];
    var $79 = ($75 | 0) == 27;
    if ($79) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    HEAP32[$77 >> 2] = $pn_0;
    var $82 = HEAP32[$_pre_phi >> 2];
    _js_PushStatement($82, $stmtInfo, 6, -1);
    __label__ = 24;
    break;
   case 24:
    var $84 = __ZN2js6Parser11primaryExprENS_9TokenKindEi($this, $75, 1);
    if (($84 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    if ($79) {
      __label__ = 29;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    if (($75 | 0) == 29) {
      __label__ = 27;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 27:
    var $90 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($84, 29);
    if ($90) {
      __label__ = 28;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 28:
    __ZN11JSParseNode5setOpE4JSOp($72, 53);
    var $92 = $71 + 36 | 0;
    HEAP32[$92 >> 2] = $pn_0;
    var $96 = $71 + 32 | 0;
    var $_c5 = HEAP32[$84 + 32 >> 2];
    HEAP32[$96 >> 2] = $_c5;
    var $97 = HEAP32[$_pre_phi >> 2];
    var $98 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($84, $97);
    __label__ = 34;
    break;
   case 29:
    var $101 = HEAP32[$_pre_phi >> 2] + 88 | 0;
    HEAP32[$101 >> 2] = $78;
    var $102 = HEAP32[$_pre_phi >> 2];
    __ZL12PopStatementP13JSTreeContext($102);
    __ZN11JSParseNode7setKindEN2js9TokenKindE($72, 74);
    __ZN11JSParseNode5setOpE4JSOp($72, 176);
    var $104 = HEAP32[$_pre_phi >> 2] | 0;
    var $106 = HEAP32[$104 >> 2] | 256;
    HEAP32[$104 >> 2] = $106;
    __label__ = 33;
    break;
   case 30:
    var $107 = __ZNK11JSParseNode7getKindEv($84);
    var $108 = __ZN2jsL14TokenKindIsXMLENS_9TokenKindE($107);
    if ($108) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($72, 23);
    __ZN11JSParseNode5setOpE4JSOp($72, 55);
    __label__ = 33;
    break;
   case 32:
    var $111 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 77, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 69;
    break;
   case 33:
    __ZN11JSParseNode8setArityE16JSParseNodeArity($72, 2);
    var $113 = $71 + 32 | 0;
    HEAP32[$113 >> 2] = $pn_0;
    var $114 = $71 + 36 | 0;
    HEAP32[$114 >> 2] = $84;
    __label__ = 34;
    break;
   case 34:
    var $118 = $pn_0 + 4 | 0;
    var $119 = $71 + 4 | 0;
    var $st$4$0 = $118 | 0;
    var $120$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $118 + 4 | 0;
    var $120$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $119 | 0;
    HEAP32[$st$8$0 >> 2] = $120$0;
    var $st$8$1 = $119 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $120$1;
    var $121 = $71 + 12 | 0;
    var $122 = __ZNK2js11TokenStream12currentTokenEv($9);
    var $124 = $122 + 12 | 0;
    var $125 = $121;
    var $st$17$0 = $124 | 0;
    var $126$0 = HEAP32[$st$17$0 >> 2];
    var $st$17$1 = $124 + 4 | 0;
    var $126$1 = HEAP32[$st$17$1 >> 2];
    var $st$21$0 = $125 | 0;
    HEAP32[$st$21$0 >> 2] = $126$0;
    var $st$21$1 = $125 + 4 | 0;
    HEAP32[$st$21$1 >> 2] = $126$1;
    var $pn_0 = $72;
    __label__ = 19;
    break;
   case 35:
    var $_idx5_val = HEAP32[HEAP32[$_pre_phi >> 2] + 48 >> 2];
    var $129 = __ZN2js10BinaryNode6createEP13JSTreeContext($_idx5_val);
    var $130 = $129 | 0;
    if (($129 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $133 = __ZN2js11TokenStream8getTokenEj($9, 40);
    var $134 = __ZN2js6Parser11primaryExprENS_9TokenKindEi($this, $133, 1);
    if (($134 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $137 = __ZNK11JSParseNode7getKindEv($134);
    if (($137 | 0) == 29) {
      __label__ = 38;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 38:
    var $140 = __ZNK11JSParseNode10isInParensEv($134);
    if ($140) {
      __label__ = 40;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($134, 31);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($134, 0);
    __ZN11JSParseNode5setOpE4JSOp($134, 165);
    __label__ = 42;
    break;
   case 40:
    var $143 = __ZN2jsL14TokenKindIsXMLENS_9TokenKindE($137);
    if ($143) {
      __label__ = 42;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    var $145 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 77, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 69;
    break;
   case 42:
    __ZN11JSParseNode5setOpE4JSOp($130, 175);
    var $147 = $129 + 32 | 0;
    HEAP32[$147 >> 2] = $pn_0;
    var $148 = $129 + 36 | 0;
    HEAP32[$148 >> 2] = $134;
    var $151 = $pn_0 + 4 | 0;
    var $152 = $129 + 4 | 0;
    var $153$0 = HEAP32[$151 >> 2];
    var $153$1 = HEAP32[$151 + 4 >> 2];
    var $st$14$0 = $152 | 0;
    HEAP32[$st$14$0 >> 2] = $153$0;
    var $st$14$1 = $152 + 4 | 0;
    HEAP32[$st$14$1 >> 2] = $153$1;
    var $154 = $129 + 12 | 0;
    var $155 = __ZNK2js11TokenStream12currentTokenEv($9);
    var $157 = $155 + 12 | 0;
    var $158 = $154;
    var $159$0 = HEAP32[$157 >> 2];
    var $159$1 = HEAP32[$157 + 4 >> 2];
    var $st$27$0 = $158 | 0;
    HEAP32[$st$27$0 >> 2] = $159$0;
    var $st$27$1 = $158 + 4 | 0;
    HEAP32[$st$27$1 >> 2] = $159$1;
    var $pn_0 = $130;
    __label__ = 19;
    break;
   case 43:
    var $_idx4_val = HEAP32[HEAP32[$_pre_phi >> 2] + 48 >> 2];
    var $162 = __ZN2js10BinaryNode6createEP13JSTreeContext($_idx4_val);
    var $163 = $162 | 0;
    if (($162 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $166 = __ZN2js6Parser4exprEv($this);
    if (($166 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $169 = __ZN2js11TokenStream8getTokenEj($9, 0);
    if (($169 | 0) == 24) {
      __label__ = 47;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $172 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 78, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 69;
    break;
   case 47:
    var $176 = $pn_0 + 4 | 0;
    var $177 = $162 + 4 | 0;
    var $st$4$0 = $176 | 0;
    var $178$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $176 + 4 | 0;
    var $178$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $177 | 0;
    HEAP32[$st$8$0 >> 2] = $178$0;
    var $st$8$1 = $177 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $178$1;
    var $179 = $162 + 12 | 0;
    var $180 = __ZNK2js11TokenStream12currentTokenEv($9);
    var $182 = $180 + 12 | 0;
    var $183 = $179;
    var $st$17$0 = $182 | 0;
    var $184$0 = HEAP32[$st$17$0 >> 2];
    var $st$17$1 = $182 + 4 | 0;
    var $184$1 = HEAP32[$st$17$1 >> 2];
    var $st$21$0 = $183 | 0;
    HEAP32[$st$21$0 >> 2] = $184$0;
    var $st$21$1 = $183 + 4 | 0;
    HEAP32[$st$21$1 >> 2] = $184$1;
    var $185 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($166, 31);
    if ($185) {
      __label__ = 48;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 48:
    var $187 = $166 + 32 | 0;
    var $188 = $187;
    var $189 = HEAP32[$188 >> 2];
    var $190 = __ZL12ATOM_TO_JSIDP6JSAtom2903($189);
    var $191 = __Z12js_IdIsIndexiPj($190, $index);
    if (($191 | 0) == 0) {
      __label__ = 49;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 49:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($163, 22);
    __ZN11JSParseNode5setOpE4JSOp($163, 53);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($163, 6);
    var $194 = $162 + 36 | 0;
    HEAP32[$194 >> 2] = $pn_0;
    var $196 = $162 + 32 | 0;
    var $_c1 = HEAP32[$188 >> 2];
    HEAP32[$196 >> 2] = $_c1;
    var $pn_0 = $163;
    __label__ = 19;
    break;
   case 50:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($166, 30);
    __ZN11JSParseNode5setOpE4JSOp($166, 60);
    var $200 = $187;
    tempDoubleF64[0] = HEAPU32[$index >> 2] >>> 0, HEAP32[$200 >> 2] = tempDoubleI32[0], HEAP32[$200 + 4 >> 2] = tempDoubleI32[1];
    __label__ = 51;
    break;
   case 51:
    __ZN11JSParseNode5setOpE4JSOp($163, 55);
    var $202 = $162 + 32 | 0;
    HEAP32[$202 >> 2] = $pn_0;
    var $203 = $162 + 36 | 0;
    HEAP32[$203 >> 2] = $166;
    var $pn_0 = $163;
    __label__ = 19;
    break;
   case 52:
    if ($65 & ($66 | 0) == 27) {
      __label__ = 53;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 53:
    var $_idx2_val = HEAP32[HEAP32[$_pre_phi >> 2] + 48 >> 2];
    var $208 = __ZN2js8ListNode6createEP13JSTreeContext($_idx2_val);
    var $209 = $208 | 0;
    if (($208 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    __ZN11JSParseNode5setOpE4JSOp($209, 58);
    var $212 = __ZL32CheckForImmediatelyAppliedLambdaP11JSParseNode($pn_0);
    var $213 = __ZNK11JSParseNode4isOpE4JSOp($212, 59);
    if ($213) {
      __label__ = 55;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 55:
    if ((HEAP32[$212 + 32 >> 2] | 0) == (HEAP32[HEAP32[HEAP32[$2 >> 2] + 52 >> 2] + 210212 >> 2] | 0)) {
      __label__ = 56;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 56:
    __ZN11JSParseNode5setOpE4JSOp($209, 123);
    var $226 = HEAP32[$_pre_phi >> 2];
    __ZN13JSTreeContext13noteCallsEvalEv($226);
    var $228 = HEAP32[$_pre_phi >> 2] | 0;
    var $230 = HEAP32[$228 >> 2] | 256;
    HEAP32[$228 >> 2] = $230;
    var $231 = HEAP32[$_pre_phi >> 2];
    var $_idx_val = HEAP32[$231 >> 2];
    var $232 = __ZNK13JSTreeContext12inStrictModeEv($_idx_val);
    if ($232) {
      __label__ = 63;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    __ZN13JSTreeContext22noteHasExtensibleScopeEv($231);
    __label__ = 63;
    break;
   case 58:
    var $235 = __ZNK11JSParseNode4isOpE4JSOp($212, 53);
    if ($235) {
      __label__ = 59;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 59:
    var $239 = HEAP32[$212 + 32 >> 2];
    var $242 = HEAP32[HEAP32[$2 >> 2] + 52 >> 2];
    if (($239 | 0) == (HEAP32[$242 + 210172 >> 2] | 0)) {
      __label__ = 60;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 60:
    __ZN11JSParseNode5setOpE4JSOp($209, 79);
    __label__ = 63;
    break;
   case 61:
    if (($239 | 0) == (HEAP32[$242 + 210188 >> 2] | 0)) {
      __label__ = 62;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 62:
    __ZN11JSParseNode5setOpE4JSOp($209, 108);
    __label__ = 63;
    break;
   case 63:
    __ZN11JSParseNode8initListEPS_($209, $212);
    var $257 = $212 + 4 | 0;
    var $258 = $208 + 4 | 0;
    var $st$5$0 = $257 | 0;
    var $259$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $257 + 4 | 0;
    var $259$1 = HEAP32[$st$5$1 >> 2];
    var $st$9$0 = $258 | 0;
    HEAP32[$st$9$0 >> 2] = $259$0;
    var $st$9$1 = $258 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $259$1;
    var $260 = __ZN2js6Parser12argumentListEP11JSParseNode($this, $209);
    if (($260 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    if (HEAPU32[$208 + 40 >> 2] >>> 0 > 65536) {
      __label__ = 65;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 65:
    var $267 = HEAP32[$2 >> 2];
    _JS_ReportErrorNumber($267, 4, 45, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 69;
    break;
   case 66:
    var $269 = $208 + 12 | 0;
    var $270 = __ZNK2js11TokenStream12currentTokenEv($9);
    var $272 = $270 + 12 | 0;
    var $273 = $269;
    var $st$5$0 = $272 | 0;
    var $274$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $272 + 4 | 0;
    var $274$1 = HEAP32[$st$5$1 >> 2];
    var $st$9$0 = $273 | 0;
    HEAP32[$st$9$0 >> 2] = $274$0;
    var $st$9$1 = $273 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $274$1;
    var $pn_0 = $209;
    __label__ = 19;
    break;
   case 67:
    __ZN2js11TokenStream10ungetTokenEv($9);
    var $_0 = $pn_0;
    __label__ = 69;
    break;
   case 68:
    var $_pn_0 = ($66 | 0) == -1 ? 0 : $pn_0;
    var $_0 = $_pn_0;
    __label__ = 69;
    break;
   case 69:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser10memberExprEi["X"] = 1;

function __ZNK2js11TokenStream13onCurrentLineERKNS_8TokenPosE($this_0_4_val, $pos_0_1_1_val) {
  return ($this_0_4_val | 0) == ($pos_0_1_1_val | 0);
}

function __ZN13JSTreeContext17countArgumentsUseEP11JSParseNode($this, $pn) {
  var $1 = $this + 20 | 0;
  var $3 = HEAP32[$1 >> 2] + 1 | 0;
  HEAP32[$1 >> 2] = $3;
  HEAP32[$this + 56 >> 2] = $pn;
  return;
}

function __ZN11GenexpGuard7endBodyEv($this_0_0_val) {
  var $1 = $this_0_0_val + 12 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZL13AdjustBlockIdP11JSParseNodejP13JSTreeContext($pn, $adjust, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $pn + 44 | 0;
    var $3 = HEAPU32[$2 >> 2];
    var $5 = ($3 >>> 12) + $adjust | 0;
    HEAP32[$2 >> 2] = $5 << 12 | $3 & 4095;
    var $9 = $5 & 1048575;
    var $10 = $tc + 8 | 0;
    if ($9 >>> 0 < HEAPU32[$10 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$10 >> 2] = $9 + 1 | 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11SetIncOpKidP9JSContextPN2js11TokenStreamEP13JSTreeContextP11JSParseNodeS7_NS1_9TokenKindEi($cx, $ts, $tc, $pn, $kid, $tt, $preorder) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = STRING_TABLE.__ZL14incop_name_str + (($tt | 0) == 21 & 1) * 10 | 0;
    var $4 = __ZL10SetLvalKidP9JSContextPN2js11TokenStreamEP13JSTreeContextP11JSParseNodeS7_PKc($cx, $ts, $tc, $pn, $kid, $3);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK11JSParseNode7getKindEv($4);
    if (($7 | 0) == 29) {
      __label__ = 3;
      break;
    } else if (($7 | 0) == 22) {
      __label__ = 7;
      break;
    } else if (($7 | 0) == 27) {
      __label__ = 10;
      break;
    } else if (($7 | 0) == 19) {
      __label__ = 11;
      break;
    } else if (($7 | 0) == 23) {
      __label__ = 13;
      break;
    } else {
      var $op_0 = 0;
      __label__ = 16;
      break;
    }
   case 3:
    var $10 = ($preorder | 0) != 0;
    if (($tt | 0) == 20) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $12 = $10 ? 41 : 47;
    var $16 = $12;
    __label__ = 6;
    break;
   case 5:
    var $14 = $10 ? 44 : 50;
    var $16 = $14;
    __label__ = 6;
    break;
   case 6:
    var $16;
    __ZL10NoteLValueP9JSContextP11JSParseNodeP13JSTreeContextj($cx, $4, $tc, 8);
    var $op_0 = $16;
    __label__ = 16;
    break;
   case 7:
    var $19 = ($preorder | 0) != 0;
    if (($tt | 0) == 20) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $21 = $19 ? 42 : 48;
    var $op_0 = $21;
    __label__ = 16;
    break;
   case 9:
    var $23 = $19 ? 45 : 51;
    var $op_0 = $23;
    __label__ = 16;
    break;
   case 10:
    var $25 = __ZL11MakeSetCallP9JSContextP11JSParseNodeP13JSTreeContextj($cx, $4, $tc, 221);
    if ($25) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 11:
    var $27 = __ZNK11JSParseNode4isOpE4JSOp($4, 174);
    if ($27) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    __ZN11JSParseNode5setOpE4JSOp($4, 173);
    __label__ = 13;
    break;
   case 13:
    var $31 = ($preorder | 0) != 0;
    if (($tt | 0) == 20) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $33 = $31 ? 43 : 49;
    var $op_0 = $33;
    __label__ = 16;
    break;
   case 15:
    var $35 = $31 ? 46 : 52;
    var $op_0 = $35;
    __label__ = 16;
    break;
   case 16:
    var $op_0;
    __ZN11JSParseNode5setOpE4JSOp($pn, $op_0);
    var $_0 = 1;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11GenexpGuard14checkValidBodyEP11JSParseNode($this_0_0_val, $this_0_1_val, $this_0_2_val, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$this_0_0_val + 16 >> 2] >>> 0 > $this_0_1_val >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = HEAP32[$this_0_0_val + 52 >> 2];
    var $errorNode_0 = ($6 | 0) == 0 ? $pn : $6;
    var $9 = HEAP32[$this_0_0_val + 48 >> 2];
    var $10 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($9, $errorNode_0, 0, 271, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_yield_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    if (HEAPU32[$this_0_0_val + 20 >> 2] >>> 0 > $this_0_2_val >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = HEAP32[$this_0_0_val + 56 >> 2];
    var $errorNode1_0 = ($17 | 0) == 0 ? $pn : $17;
    var $20 = HEAP32[$this_0_0_val + 48 >> 2];
    var $21 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($20, $errorNode1_0, 0, 271, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str142435 | 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11GenexpGuard18maybeNoteGeneratorEP11JSParseNode($this, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    if ((HEAP32[$2 + 16 >> 2] | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $2 | 0;
    var $9 = HEAP32[$7 >> 2] | 512;
    HEAP32[$7 >> 2] = $9;
    var $10 = HEAP32[$1 >> 2];
    var $_idx_val = HEAP32[$10 >> 2];
    var $11 = __ZNK13JSTreeContext10inFunctionEv($_idx_val);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = HEAP32[$10 + 48 >> 2];
    var $15 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($14, 0, 0, 124, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_yield_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    if (($_idx_val & 4 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = HEAP32[HEAP32[$10 + 48 >> 2] + 12 >> 2];
    var $24 = __ZL15ReportBadReturnP9JSContextP13JSTreeContextP11JSParseNodejjj($23, $10, $pn, 0, 208, 209);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN20CompExprTransplanter10transplantEP11JSParseNode($this, $pn) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $dn = __stackBase__;
    var $atom = __stackBase__ + 4;
    var $dn2 = __stackBase__ + 8;
    if (($pn | 0) == 0) {
      var $_0 = 1;
      __label__ = 49;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK11JSParseNode8getArityEv($pn);
    if (($3 | 0) == 5) {
      __label__ = 3;
      break;
    } else if (($3 | 0) == 3) {
      __label__ = 9;
      break;
    } else if (($3 | 0) == 2) {
      __label__ = 12;
      break;
    } else if (($3 | 0) == 1) {
      __label__ = 15;
      break;
    } else if (($3 | 0) == 4) {
      __label__ = 16;
      break;
    } else if (($3 | 0) == 6) {
      __label__ = 21;
      break;
    } else if (($3 | 0) == 7) {
      __label__ = 47;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 3:
    var $pn2_0_in = $pn + 32 | 0;
    __label__ = 4;
    break;
   case 4:
    var $pn2_0_in;
    var $pn2_0 = HEAP32[$pn2_0_in >> 2];
    if (($pn2_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZN20CompExprTransplanter10transplantEP11JSParseNode($this, $pn2_0);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 6:
    var $pn2_0_in = $pn2_0 + 24 | 0;
    __label__ = 4;
    break;
   case 7:
    var $13 = $pn + 4 | 0;
    var $16 = HEAP32[$this >> 2] + 4 | 0;
    var $17 = __ZN2js8TokenPosgeERKS0_($13, $16);
    if ($17) {
      __label__ = 8;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 8:
    var $20 = HEAP32[$this + 12 >> 2];
    var $22 = HEAP32[$this + 4 >> 2];
    __ZL13AdjustBlockIdP11JSParseNodejP13JSTreeContext($pn, $20, $22);
    __label__ = 48;
    break;
   case 9:
    var $25 = HEAP32[$pn + 32 >> 2];
    var $26 = __ZN20CompExprTransplanter10transplantEP11JSParseNode($this, $25);
    if ($26) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 10:
    var $30 = HEAP32[$pn + 36 >> 2];
    var $31 = __ZN20CompExprTransplanter10transplantEP11JSParseNode($this, $30);
    if ($31) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 11:
    var $35 = HEAP32[$pn + 40 >> 2];
    var $36 = __ZN20CompExprTransplanter10transplantEP11JSParseNode($this, $35);
    if ($36) {
      __label__ = 48;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 12:
    var $38 = $pn + 32 | 0;
    var $39 = HEAP32[$38 >> 2];
    var $40 = __ZN20CompExprTransplanter10transplantEP11JSParseNode($this, $39);
    if ($40) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 13:
    var $44 = HEAP32[$pn + 36 >> 2];
    if (($44 | 0) == (HEAP32[$38 >> 2] | 0)) {
      __label__ = 48;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $48 = __ZN20CompExprTransplanter10transplantEP11JSParseNode($this, $44);
    if ($48) {
      __label__ = 48;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 15:
    var $51 = HEAP32[$pn + 32 >> 2];
    var $52 = __ZN20CompExprTransplanter10transplantEP11JSParseNode($this, $51);
    if ($52) {
      __label__ = 48;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 16:
    var $56 = HEAP32[$pn + 32 >> 2];
    var $57 = $this + 4 | 0;
    var $61 = $this + 16 | 0;
    var $65 = $56 + 56 | 0;
    var $70 = HEAP32[$61 >> 2] + HEAP32[HEAP32[$57 >> 2] + 76 >> 2] << 2 & 65532 | HEAP32[$65 >> 2] & -65533;
    HEAP32[$65 >> 2] = $70;
    var $71 = HEAP32[$61 >> 2];
    var $72 = $71 + 1 | 0;
    HEAP32[$61 >> 2] = $72;
    if (($71 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 17:
    if ((HEAP8[$this + 8 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $80 = HEAP32[$57 >> 2];
    var $82 = HEAP32[$80 + 80 >> 2];
    var $85 = HEAP32[$80 + 72 >> 2] + 84 | 0;
    var $86 = HEAP32[$85 >> 2];
    if (($86 | 0) == ($56 | 0)) {
      var $funboxp_0_lcssa = $85;
      __label__ = 20;
      break;
    } else {
      var $88 = $86;
      __label__ = 19;
      break;
    }
   case 19:
    var $88;
    var $89 = $88 + 28 | 0;
    var $90 = HEAP32[$89 >> 2];
    if (($90 | 0) == ($56 | 0)) {
      var $funboxp_0_lcssa = $89;
      __label__ = 20;
      break;
    } else {
      var $88 = $90;
      __label__ = 19;
      break;
    }
   case 20:
    var $funboxp_0_lcssa;
    var $92 = $56 + 28 | 0;
    var $93 = HEAP32[$92 >> 2];
    HEAP32[$funboxp_0_lcssa >> 2] = $93;
    var $94 = $56 + 36 | 0;
    HEAP32[$94 >> 2] = $82;
    var $95 = $82 + 32 | 0;
    var $96 = HEAP32[$95 >> 2];
    HEAP32[$92 >> 2] = $96;
    HEAP32[$95 >> 2] = $56;
    var $104 = HEAP32[$65 >> 2] & -65533 | HEAP32[HEAP32[$57 >> 2] + 76 >> 2] << 2 & 65532;
    HEAP32[$65 >> 2] = $104;
    __label__ = 21;
    break;
   case 21:
    var $106 = __ZN11JSParseNode9maybeExprEv($pn);
    var $107 = __ZN20CompExprTransplanter10transplantEP11JSParseNode($this, $106);
    if ($107) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 22:
    var $109 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 4);
    if ($109) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $111 = $this + 16 | 0;
    var $113 = HEAP32[$111 >> 2] - 1 | 0;
    HEAP32[$111 >> 2] = $113;
    __label__ = 24;
    break;
   case 24:
    var $115 = __ZNK11JSParseNode6isDefnEv($pn);
    if ($115) {
      __label__ = 25;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 25:
    if ((HEAP8[$this + 8 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $123 = HEAP32[$this + 4 >> 2];
    var $124 = __ZL15BumpStaticLevelP11JSParseNodeP13JSTreeContext($pn, $123);
    if ($124) {
      __label__ = 45;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 27:
    var $126 = __ZNK11JSParseNode6isUsedEv($pn);
    if ($126) {
      __label__ = 28;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 28:
    var $128 = $pn + 32 | 0;
    var $130 = HEAP32[$pn + 36 >> 2];
    var $131 = $130;
    HEAP32[$dn >> 2] = $131;
    var $132 = $130;
    var $133 = __ZNK11JSParseNode13isPlaceholderEv($132);
    if ($133) {
      __label__ = 29;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 29:
    var $136 = $130 + 4 | 0;
    var $139 = HEAP32[$this >> 2] + 4 | 0;
    var $140 = __ZN2js8TokenPosgeERKS0_($136, $139);
    if ($140) {
      __label__ = 30;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 30:
    if ((HEAP32[$130 + 28 >> 2] | 0) == ($pn | 0)) {
      __label__ = 31;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 31:
    var $_pre = $this + 4 | 0;
    if ((HEAP8[$this + 8 | 0] & 1) << 24 >> 24 == 0) {
      var $_pre_phi = $_pre;
      __label__ = 33;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $151 = HEAP32[$_pre >> 2];
    var $152 = __ZL15BumpStaticLevelP11JSParseNodeP13JSTreeContext($132, $151);
    if ($152) {
      var $_pre_phi = $_pre;
      __label__ = 33;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 33:
    var $_pre_phi;
    var $153 = $130;
    var $155 = HEAP32[$this + 12 >> 2];
    var $156 = HEAP32[$_pre_phi >> 2];
    __ZL13AdjustBlockIdP11JSParseNodejP13JSTreeContext($153, $155, $156);
    __label__ = 34;
    break;
   case 34:
    var $159 = HEAP32[$128 >> 2];
    HEAP32[$atom >> 2] = $159;
    if ((HEAP8[$this + 8 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $165 = $130;
    var $166 = __ZNK11JSParseNode4isOpE4JSOp($165, 131);
    if ($166) {
      __label__ = 45;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $169 = $130 + 4 | 0;
    var $170 = $this | 0;
    var $172 = HEAP32[$170 >> 2] + 4 | 0;
    var $173 = __ZN2js8TokenPosltERKS0_($169, $172);
    if ($173) {
      __label__ = 37;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 37:
    var $175 = $this + 4 | 0;
    var $176 = HEAP32[$175 >> 2];
    var $177 = __ZL15MakePlaceholderP11JSParseNodeP13JSTreeContext($pn, $176);
    HEAP32[$dn2 >> 2] = $177;
    if (($177 | 0) == 0) {
      var $_0 = 0;
      __label__ = 49;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $183 = $177 + 4 | 0;
    var $184 = HEAP32[$170 >> 2] + 4 | 0;
    HEAP32[$183 >> 2] = HEAP32[$184 >> 2];
    HEAP32[$183 + 4 >> 2] = HEAP32[$184 + 4 >> 2];
    HEAP32[$183 + 8 >> 2] = HEAP32[$184 + 8 >> 2];
    HEAP32[$183 + 12 >> 2] = HEAP32[$184 + 12 >> 2];
    var $185 = $130 + 28 | 0;
    var $_c = $177;
    var $187 = $177 + 44 | 0;
    var $pnup_0 = $185;
    __label__ = 39;
    break;
   case 39:
    var $pnup_0;
    var $189 = HEAP32[$pnup_0 >> 2];
    if (($189 | 0) == 0) {
      __label__ = 42;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $192 = $189 + 4 | 0;
    var $194 = HEAP32[$170 >> 2] + 4 | 0;
    var $195 = __ZN2js8TokenPosgeERKS0_($192, $194);
    if ($195) {
      __label__ = 41;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 41:
    var $197 = $189 + 36 | 0;
    HEAP32[$197 >> 2] = $_c;
    var $203 = HEAP32[$187 >> 2] | HEAP32[$189 + 44 >> 2] & 2312;
    HEAP32[$187 >> 2] = $203;
    var $pnup_0 = $189 + 28 | 0;
    __label__ = 39;
    break;
   case 42:
    var $205 = HEAP32[$185 >> 2];
    var $206 = $177 + 28 | 0;
    HEAP32[$206 >> 2] = $205;
    var $207 = HEAP32[$pnup_0 >> 2];
    HEAP32[$185 >> 2] = $207;
    HEAP32[$pnup_0 >> 2] = 0;
    var $_idx2_val = HEAP32[HEAP32[$175 >> 2] + 64 >> 2];
    var $209 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($_idx2_val);
    var $210 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3putERKS2_RKS4_($209, $atom, $dn2);
    if ($210) {
      __label__ = 45;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 43:
    var $212 = __ZNK11JSParseNode13isPlaceholderEv($165);
    if ($212) {
      __label__ = 44;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 44:
    var $214 = $this + 4 | 0;
    var $_idx1_val = HEAP32[HEAP32[HEAP32[$214 >> 2] + 72 >> 2] + 64 >> 2];
    var $218 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($_idx1_val);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6removeERKS2_($218, $atom);
    var $_idx_val = HEAP32[HEAP32[$214 >> 2] + 64 >> 2];
    var $220 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($_idx_val);
    var $221 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3putERKS2_RKS4_($220, $atom, $dn);
    if ($221) {
      __label__ = 45;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 45:
    var $222 = $pn + 4 | 0;
    var $225 = HEAP32[$this >> 2] + 4 | 0;
    var $226 = __ZN2js8TokenPosgeERKS0_($222, $225);
    if ($226) {
      __label__ = 46;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 46:
    var $229 = HEAP32[$this + 12 >> 2];
    var $231 = HEAP32[$this + 4 >> 2];
    __ZL13AdjustBlockIdP11JSParseNodejP13JSTreeContext($pn, $229, $231);
    __label__ = 48;
    break;
   case 47:
    var $235 = HEAP32[$pn + 36 >> 2];
    var $236 = __ZN20CompExprTransplanter10transplantEP11JSParseNode($this, $235);
    if ($236) {
      __label__ = 48;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 48:
    var $_0 = 1;
    __label__ = 49;
    break;
   case 49:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN20CompExprTransplanter10transplantEP11JSParseNode["X"] = 1;

function __ZN2js8TokenPosgeERKS0_($this, $bpos) {
  var $1 = __ZN2js8TokenPosltERKS0_($this, $bpos);
  return $1 ^ 1;
}

function __ZL15BumpStaticLevelP11JSParseNodeP13JSTreeContext($pn, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $pn + 40 | 0;
    var $2 = $1;
    var $_idx1_val = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js11UpvarCookie6isFreeEv($_idx1_val);
    if ($3) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2js11UpvarCookie5levelEv($_idx1_val);
    var $7 = ($5 & 65535) + 1 | 0;
    if ($7 >>> 0 > 16382) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $13 = HEAP32[HEAP32[$tc + 48 >> 2] + 12 >> 2];
    _JS_ReportErrorNumber($13, 4, 25, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str252545 | 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $15 = $7 & 65535;
    var $16 = __ZNK2js11UpvarCookie4slotEv($_idx1_val);
    __ZN2js11UpvarCookie3setEtt($2, $15, $16);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK11JSParseNode13isPlaceholderEv($this) {
  var $1 = __ZNK11JSParseNode4testEj($this, 128);
  return $1;
}

function __ZN2js8TokenPosltERKS0_($this, $bpos) {
  var $1 = $this | 0;
  var $2 = $bpos | 0;
  var $3 = __ZN2js8TokenPtrltERKS0_($1, $2);
  return $3;
}

function __ZL15MakePlaceholderP11JSParseNodeP13JSTreeContext($pn, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$pn + 32 >> 2];
    var $4 = __ZN2js8NameNode6createEP6JSAtomP13JSTreeContext($3, $tc);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4;
    var $8 = $4 | 0;
    __ZN11JSParseNode7setKindEN2js9TokenKindE($8, 29);
    __ZN11JSParseNode5setOpE4JSOp($8, 0);
    __ZN11JSParseNode7setDefnEb($8, 1);
    var $10 = $4 + 44 | 0;
    var $12 = HEAP32[$10 >> 2] | 128;
    HEAP32[$10 >> 2] = $12;
    var $_0 = $7;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3putERKS2_RKS4_($this, $key, $value) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE12lookupForAddERKS2_($p, $this, $key);
    var $1 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrcvPPPPPPPS6_Ev($p);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$value >> 2];
    var $5 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtr5valueEv($p);
    HEAP32[$5 >> 2] = $4;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $7 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3addERNS5_6AddPtrERKS2_RKS4_($this, $p, $key, $value);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL14TokenKindIsXMLENS_9TokenKindE($tt) {
  return ($tt - 70 | 0) >>> 0 < 3;
}

function __ZN11JSParseNode11setInParensEb($this, $enabled) {
  var $2 = $this;
  var $6 = HEAP32[$2 >> 2] & -536870913 | ($enabled & 1) << 29;
  HEAP32[$2 >> 2] = $6;
  return;
}

function __ZN2js6Parser17comprehensionTailEP11JSParseNodejbNS_9TokenKindE4JSOp($this, $kid, $blockid, $isGenexp, $type, $op) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 84;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmtInfo = __stackBase__;
    var $data = __stackBase__ + 32;
    var $transplanter = __stackBase__ + 52;
    var $guard = __stackBase__ + 72;
    __ZN8BindDataC1Ev($data);
    var $1 = ($type | 0) == 2;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = HEAP32[$this + 12 >> 2];
    var $6 = HEAP32[$this + 980 >> 2];
    var $7 = __ZL16PushLexicalScopeP9JSContextPN2js11TokenStreamEP13JSTreeContextP10JSStmtInfo($4, $6, $stmtInfo);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $pn_0 = $7;
    var $adjust_0 = (HEAPU32[$7 + 44 >> 2] >>> 12) - $blockid | 0;
    __label__ = 6;
    break;
   case 4:
    var $17 = HEAPU32[$this + 980 >> 2];
    var $18 = $17;
    var $19 = __ZN13JSTreeContext7blockidEv($18);
    var $21 = HEAP32[$this + 12 >> 2];
    var $22 = __ZL16PushLexicalScopeP9JSContextPN2js11TokenStreamEP13JSTreeContextP10JSStmtInfo($21, $17, $stmtInfo);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$stmtInfo + 4 >> 2] = $blockid;
    var $27 = $22 + 44 | 0;
    var $31 = HEAP32[$27 >> 2] & 4095 | $blockid << 12;
    HEAP32[$27 >> 2] = $31;
    var $pn_0 = $22;
    var $adjust_0 = $blockid - $19 | 0;
    __label__ = 6;
    break;
   case 6:
    var $adjust_0;
    var $pn_0;
    var $35 = $pn_0 + 36 | 0;
    var $36 = $this + 980 | 0;
    var $37 = HEAP32[$36 >> 2];
    __ZN20CompExprTransplanterC1EP11JSParseNodeP13JSTreeContextbj($transplanter, $kid, $37, $1, $adjust_0);
    var $38 = __ZN20CompExprTransplanter10transplantEP11JSParseNode($transplanter, $kid);
    var $39 = $data | 0;
    HEAP32[$39 >> 2] = 0;
    HEAP32[$data + 4 >> 2] = 0;
    var $41 = $data + 8 | 0;
    HEAP32[$41 >> 2] = 202;
    HEAP32[$data + 12 >> 2] = 200;
    var $43 = $this + 40 | 0;
    var $44 = $this + 12 | 0;
    var $guard_idx = $guard | 0;
    var $guard_idx6 = $guard + 4 | 0;
    var $guard_idx7 = $guard + 8 | 0;
    var $pnp_0 = $35;
    __label__ = 7;
    break;
   case 7:
    var $pnp_0;
    var $_idx2_val = HEAP32[HEAP32[$36 >> 2] + 48 >> 2];
    var $47 = __ZN2js10BinaryNode6createEP13JSTreeContext($_idx2_val);
    var $48 = $47 | 0;
    if (($47 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN11JSParseNode5setOpE4JSOp($48, 75);
    var $52 = $47 + 44 | 0;
    HEAP32[$52 >> 2] = 1;
    var $53 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($43, 29);
    if ($53) {
      __label__ = 9;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 9:
    var $55 = __ZNK2js11TokenStream12currentTokenEv($43);
    if ((HEAP32[$55 + 28 >> 2] | 0) == (HEAP32[HEAP32[HEAP32[$44 >> 2] + 52 >> 2] + 210208 >> 2] | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $67 = HEAP32[$52 >> 2] | 2;
    HEAP32[$52 >> 2] = $67;
    __label__ = 12;
    break;
   case 11:
    __ZN2js11TokenStream10ungetTokenEv($43);
    __label__ = 12;
    break;
   case 12:
    var $70 = __ZN2js11TokenStream8getTokenEj($43, 0);
    if (($70 | 0) == 27) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $73 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 85, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 14:
    var $75 = HEAP32[$36 >> 2];
    __ZN11GenexpGuardC1EP13JSTreeContext($guard, $75);
    var $76 = __ZN2js11TokenStream8getTokenEv($43);
    if (($76 | 0) == 23 || ($76 | 0) == 25) {
      __label__ = 15;
      break;
    } else if (($76 | 0) == 29) {
      __label__ = 16;
      break;
    } else if (($76 | 0) == -1) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $79 = HEAP32[$36 >> 2] | 0;
    var $81 = HEAP32[$79 >> 2] | 65536;
    HEAP32[$79 >> 2] = $81;
    var $82 = __ZN2js6Parser11primaryExprENS_9TokenKindEi($this, $76, 0);
    var $84 = HEAP32[$36 >> 2] | 0;
    var $86 = HEAP32[$84 >> 2] & -65537;
    HEAP32[$84 >> 2] = $86;
    if (($82 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      var $atom_0 = 0;
      var $pn3_0 = $82;
      __label__ = 18;
      break;
    }
   case 16:
    var $89 = __ZNK2js11TokenStream12currentTokenEv($43);
    var $91 = HEAP32[$89 + 28 >> 2];
    var $92 = HEAP32[$36 >> 2];
    var $93 = __ZL14NewBindingNodeP6JSAtomP13JSTreeContextb($91, $92, 1);
    if (($93 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      var $atom_0 = $91;
      var $pn3_0 = $93;
      __label__ = 18;
      break;
    }
   case 17:
    var $96 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 102, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 18:
    var $pn3_0;
    var $atom_0;
    var $98 = __ZN2js11TokenStream8getTokenEj($43, 0);
    if (($98 | 0) == 45) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $101 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 211, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 20:
    var $103 = __ZN2js6Parser4exprEv($this);
    if (($103 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $106 = __ZN2js11TokenStream8getTokenEj($43, 0);
    if (($106 | 0) == 28) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $109 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 88, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 23:
    var $guard_idx_val = HEAP32[$guard_idx >> 2];
    __ZN11GenexpGuard7endBodyEv($guard_idx_val);
    if ($isGenexp) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $guard_idx6_val = HEAP32[$guard_idx6 >> 2];
    var $guard_idx7_val = HEAP32[$guard_idx7 >> 2];
    var $112 = __ZN11GenexpGuard14checkValidBodyEP11JSParseNode($guard_idx_val, $guard_idx6_val, $guard_idx7_val, $48);
    if ($112) {
      __label__ = 26;
      break;
    } else {
      var $_0 = 0;
      __label__ = 45;
      break;
    }
   case 25:
    var $114 = __ZN11GenexpGuard18maybeNoteGeneratorEP11JSParseNode($guard, $48);
    if ($114) {
      __label__ = 26;
      break;
    } else {
      var $_0 = 0;
      __label__ = 45;
      break;
    }
   case 26:
    if (($76 | 0) == 23 || ($76 | 0) == 25) {
      __label__ = 27;
      break;
    } else if (($76 | 0) == 29) {
      __label__ = 34;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 27:
    var $117 = HEAP32[$44 >> 2];
    var $118 = HEAP32[$36 >> 2];
    var $119 = __ZL18CheckDestructuringP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($117, $data, $pn3_0, $118);
    if ($119) {
      __label__ = 28;
      break;
    } else {
      var $_0 = 0;
      __label__ = 45;
      break;
    }
   case 28:
    var $121 = __ZNK2js6Parser13versionNumberEv($this);
    if (($121 | 0) == 170) {
      __label__ = 29;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 29:
    var $124 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn3_0, 24);
    if ($124) {
      __label__ = 30;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    if ((HEAP32[$pn3_0 + 40 >> 2] | 0) == 2) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $130 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 117, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 32:
    var $132 = HEAP32[$52 >> 2];
    if (($132 & 2 | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 33:
    var $136 = $132 | 6;
    HEAP32[$52 >> 2] = $136;
    __label__ = 35;
    break;
   case 34:
    HEAP32[$39 >> 2] = $pn3_0;
    var $138 = HEAP32[$41 >> 2];
    var $139 = HEAP32[$44 >> 2];
    var $140 = HEAP32[$36 >> 2];
    var $141 = FUNCTION_TABLE[$138]($139, $data, $atom_0, $140);
    if (($141 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $_idx1_val = HEAP32[HEAP32[$36 >> 2] + 48 >> 2];
    var $145 = __ZN2js8ListNode6createEP13JSTreeContext($_idx1_val);
    var $146 = $145 | 0;
    if (($145 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    __ZN11JSParseNode5setOpE4JSOp($146, 0);
    __ZN11JSParseNode7setKindEN2js9TokenKindE($146, 46);
    var $151 = $145 + 4 | 0;
    var $152 = $pn3_0 + 4 | 0;
    HEAP32[$151 >> 2] = HEAP32[$152 >> 2];
    HEAP32[$151 + 4 >> 2] = HEAP32[$152 + 4 >> 2];
    HEAP32[$151 + 8 >> 2] = HEAP32[$152 + 8 >> 2];
    HEAP32[$151 + 12 >> 2] = HEAP32[$152 + 12 >> 2];
    __ZN11JSParseNode9makeEmptyEv($146);
    __ZN11JSParseNode6appendEPS_($146, $pn3_0);
    var $154 = $145 + 44 | 0;
    var $156 = HEAP32[$154 >> 2] | 8;
    HEAP32[$154 >> 2] = $156;
    var $157 = HEAP32[$36 >> 2];
    var $158 = __ZL17CloneLeftHandSideP11JSParseNodeP13JSTreeContext($pn3_0, $157);
    if (($158 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $_idx3_val = HEAP32[HEAP32[$36 >> 2] + 48 >> 2];
    var $162 = __ZN2js11TernaryNode6createENS_9TokenKindE4JSOpP11JSParseNodeS4_S4_P13JSTreeContext($146, $158, $103, $_idx3_val);
    var $163 = $162 | 0;
    var $164 = $47 + 32 | 0;
    HEAP32[$164 >> 2] = $163;
    if (($162 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    HEAP32[$pnp_0 >> 2] = $48;
    var $167 = $47 + 36 | 0;
    var $168 = $167;
    var $169 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($43, 42);
    if ($169) {
      var $pnp_0 = $168;
      __label__ = 7;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $171 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($43, 35);
    if ($171) {
      __label__ = 40;
      break;
    } else {
      var $pnp_1 = $168;
      __label__ = 43;
      break;
    }
   case 40:
    var $_idx4_val = HEAP32[HEAP32[$36 >> 2] + 48 >> 2];
    var $174 = __ZN2js11TernaryNode6createEP13JSTreeContext($_idx4_val);
    if (($174 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    var $177 = __ZN2js6Parser9conditionEv($this);
    var $178 = $174 + 32 | 0;
    HEAP32[$178 >> 2] = $177;
    if (($177 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $_c = $174;
    HEAP32[$167 >> 2] = $_c;
    var $pnp_1 = $174 + 36 | 0;
    __label__ = 43;
    break;
   case 43:
    var $pnp_1;
    var $_idx_val = HEAP32[HEAP32[$36 >> 2] + 48 >> 2];
    var $185 = __ZN2js9UnaryNode6createEP13JSTreeContext($_idx_val);
    var $186 = $185 | 0;
    if (($185 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($186, $type);
    __ZN11JSParseNode5setOpE4JSOp($186, $op);
    var $189 = $185 + 32 | 0;
    HEAP32[$189 >> 2] = $kid;
    HEAP32[$pnp_1 >> 2] = $186;
    var $190 = HEAP32[$36 >> 2];
    __ZL12PopStatementP13JSTreeContext($190);
    var $_0 = $pn_0;
    __label__ = 45;
    break;
   case 45:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser17comprehensionTailEP11JSParseNodejbNS_9TokenKindE4JSOp["X"] = 1;

function __ZN20CompExprTransplanterC1EP11JSParseNodeP13JSTreeContextbj($this, $pn, $tc, $ge, $adj) {
  __ZN20CompExprTransplanterC2EP11JSParseNodeP13JSTreeContextbj($this, $pn, $tc, $ge, $adj);
  return;
}

function __ZN11GenexpGuardC1EP13JSTreeContext($this, $tc) {
  __ZN11GenexpGuardC2EP13JSTreeContext($this, $tc);
  return;
}

function __ZN2js11TernaryNode6createENS_9TokenKindE4JSOpP11JSParseNodeS4_S4_P13JSTreeContext($kid1, $kid2, $kid3, $tc_0_11_val) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pos = __stackBase__;
    var $2 = ($kid1 | 0) != 0 ? $kid1 : $kid2;
    var $4 = $2 + 4 | 0;
    var $5 = $pos;
    var $6$0 = HEAP32[$4 >> 2];
    var $6$1 = HEAP32[$4 + 4 >> 2];
    HEAP32[$5 >> 2] = $6$0;
    HEAP32[$5 + 4 >> 2] = $6$1;
    var $9 = $kid3 + 12 | 0;
    var $10 = $pos + 8 | 0;
    var $11$0 = HEAP32[$9 >> 2];
    var $11$1 = HEAP32[$9 + 4 >> 2];
    HEAP32[$10 >> 2] = $11$0;
    HEAP32[$10 + 4 >> 2] = $11$1;
    var $12 = __ZN11JSParseNode6createE16JSParseNodeArityN2js9TokenKindE4JSOpRKNS1_8TokenPosEP13JSTreeContext(3, 45, 0, $pos, $tc_0_11_val);
    var $13 = $12;
    if (($12 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$12 + 32 >> 2] = $kid1;
    HEAP32[$12 + 36 >> 2] = $kid2;
    HEAP32[$12 + 40 >> 2] = $kid3;
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return $13;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser13generatorExprEP11JSParseNode($this, $kid) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 108;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $gentc = __stackBase__;
    var $1 = $this + 980 | 0;
    var $_idx1_val = HEAP32[HEAP32[$1 >> 2] + 48 >> 2];
    var $3 = __ZN2js9UnaryNode6createEP13JSTreeContext($_idx1_val);
    var $4 = $3 | 0;
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($4, 77);
    __ZN11JSParseNode5setOpE4JSOp($4, 206);
    __ZN11JSParseNode11setInParensEb($4, 1);
    var $8 = $kid + 4 | 0;
    var $9 = $3 + 4 | 0;
    var $10 = $8;
    HEAP32[$9 >> 2] = HEAP32[$10 >> 2];
    HEAP32[$9 + 4 >> 2] = HEAP32[$10 + 4 >> 2];
    HEAP32[$9 + 8 >> 2] = HEAP32[$10 + 8 >> 2];
    HEAP32[$9 + 12 >> 2] = HEAP32[$10 + 12 >> 2];
    var $11 = $3 + 32 | 0;
    HEAP32[$11 >> 2] = $kid;
    var $12 = $3 + 40 | 0;
    HEAP32[$12 >> 2] = 1;
    var $_idx_val = HEAP32[HEAP32[$1 >> 2] + 48 >> 2];
    var $14 = __ZN2js12FunctionNode6createEP13JSTreeContext($_idx_val);
    var $15 = $14 | 0;
    if (($14 | 0) == 0) {
      var $_1 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($15, 34);
    __ZN11JSParseNode5setOpE4JSOp($15, 130);
    var $19 = $14 + 44 | 0;
    var $22 = HEAP32[$19 >> 2] & -4096 | 256;
    HEAP32[$19 >> 2] = $22;
    var $23 = HEAP32[$1 >> 2];
    var $25 = HEAP32[$23 + 48 >> 2];
    __ZN13JSTreeContextC1EPN2js6ParserE($gentc, $25);
    var $27 = HEAP32[$this + 12 >> 2];
    var $28 = $gentc;
    var $29 = __ZN13JSTreeContext4initEP9JSContextNS_12InitBehaviorE($28, $27, 0);
    if ($29) {
      __label__ = 4;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 4:
    var $31 = __ZL13EnterFunctionP11JSParseNodeP13JSTreeContextP6JSAtomN2js18FunctionSyntaxKindE($15, $gentc, 0, 0);
    if (($31 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $34 = $23 | 0;
    var $35 = HEAP32[$34 >> 2];
    var $_pre4 = $gentc | 0;
    if (($35 & 32768 | 0) == 0) {
      var $42 = $35;
      var $_pre_phi = $_pre4;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $40 = HEAP32[$_pre4 >> 2] | 2;
    HEAP32[$_pre4 >> 2] = $40;
    var $41 = __ZN13JSTreeContext16ensureSharpSlotsEv($28);
    if ($41) {
      __label__ = 7;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 7:
    var $42 = HEAP32[$34 >> 2];
    var $_pre_phi = $_pre4;
    __label__ = 8;
    break;
   case 8:
    var $_pre_phi;
    var $42;
    var $46 = HEAP32[$_pre_phi >> 2] | $42 & 629441952 | 4608;
    HEAP32[$_pre_phi >> 2] = $46;
    var $47 = $31 + 60 | 0;
    var $49 = $46 | HEAP32[$47 >> 2];
    HEAP32[$47 >> 2] = $49;
    var $50 = $14 + 32 | 0;
    var $_c = $31;
    HEAP32[$50 >> 2] = $_c;
    var $56 = HEAP32[$19 >> 2] & 4095 | HEAP32[$gentc + 4 >> 2] << 12;
    HEAP32[$19 >> 2] = $56;
    var $57 = $23;
    var $58 = __ZN13JSTreeContext7blockidEv($57);
    var $59 = __ZN2js6Parser17comprehensionTailEP11JSParseNodejbNS_9TokenKindE4JSOp($this, $4, $58, 1, 2, 0);
    if (($59 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $62 = $14 + 36 | 0;
    var $_c2 = $59;
    HEAP32[$62 >> 2] = $_c2;
    var $63 = $14 + 4 | 0;
    var $65 = $8;
    var $66 = $59 + 4 | 0;
    var $67$0 = HEAP32[$65 >> 2];
    var $67$1 = HEAP32[$65 + 4 >> 2];
    var $st$11$0 = $66 | 0;
    HEAP32[$st$11$0 >> 2] = $67$0;
    var $st$11$1 = $66 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $67$1;
    var $68 = $63;
    var $st$16$0 = $68 | 0;
    HEAP32[$st$16$0 >> 2] = $67$0;
    var $st$16$1 = $68 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $67$1;
    var $69 = $14 + 12 | 0;
    var $70 = $59 + 12 | 0;
    var $71 = $this + 40 | 0;
    var $72 = __ZNK2js11TokenStream12currentTokenEv($71);
    var $74 = $72 + 12 | 0;
    var $75 = $70;
    var $76$0 = HEAP32[$74 >> 2];
    var $76$1 = HEAP32[$74 + 4 >> 2];
    var $st$31$0 = $75 | 0;
    HEAP32[$st$31$0 >> 2] = $76$0;
    var $st$31$1 = $75 + 4 | 0;
    HEAP32[$st$31$1 >> 2] = $76$1;
    var $77 = $69;
    var $st$36$0 = $77 | 0;
    HEAP32[$st$36$0 >> 2] = $76$0;
    var $st$36$1 = $77 + 4 | 0;
    HEAP32[$st$36$1 >> 2] = $76$1;
    var $78 = __ZL13LeaveFunctionP11JSParseNodeP13JSTreeContextP6JSAtomN2js18FunctionSyntaxKindE($15, $gentc, 0, 0);
    __ZN13JSTreeContextD1Ev($gentc);
    if ($78) {
      __label__ = 10;
      break;
    } else {
      var $_1 = 0;
      __label__ = 16;
      break;
    }
   case 10:
    var $_idx2_val = HEAP32[HEAP32[$1 >> 2] + 48 >> 2];
    var $81 = __ZN2js8ListNode6createEP13JSTreeContext($_idx2_val);
    var $82 = $81 | 0;
    if (($81 | 0) == 0) {
      var $_1 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($82, 27);
    __ZN11JSParseNode5setOpE4JSOp($82, 58);
    var $87 = $14 + 4 | 0;
    var $88 = $81 + 4 | 0;
    var $89$0 = HEAP32[$87 >> 2];
    var $89$1 = HEAP32[$87 + 4 >> 2];
    var $st$10$0 = $88 | 0;
    HEAP32[$st$10$0 >> 2] = $89$0;
    var $st$10$1 = $88 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $89$1;
    __ZN11JSParseNode8initListEPS_($82, $15);
    var $_1 = $82;
    __label__ = 16;
    break;
   case 12:
    __ZN13JSTreeContextD1Ev($gentc);
    var $_1 = 0;
    __label__ = 16;
    break;
   case 13:
    __ZN13JSTreeContextD1Ev($gentc);
    var $_1 = 0;
    __label__ = 16;
    break;
   case 14:
    __ZN13JSTreeContextD1Ev($gentc);
    var $_1 = 0;
    __label__ = 16;
    break;
   case 15:
    __ZN13JSTreeContextD1Ev($gentc);
    var $_1 = 0;
    __label__ = 16;
    break;
   case 16:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser13generatorExprEP11JSParseNode["X"] = 1;

function __ZN2js6Parser12argumentListEP11JSParseNode($this, $listNode) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $guard = __stackBase__;
    var $1 = $this + 40 | 0;
    var $2 = __ZN2js11TokenStream10matchTokenENS_9TokenKindEj($1, 28, 8);
    if ($2) {
      var $_0 = 1;
      __label__ = 21;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$this + 980 >> 2];
    __ZN11GenexpGuardC1EP13JSTreeContext($guard, $5);
    var $6 = $listNode + 40 | 0;
    var $guard_idx = $guard | 0;
    var $guard_idx2 = $guard + 4 | 0;
    var $guard_idx3 = $guard + 8 | 0;
    var $arg0_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $arg0_0;
    var $8 = __ZN2js6Parser10assignExprEv($this);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ($arg0_0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $guard_idx_val = HEAP32[$guard_idx >> 2];
    __ZN11GenexpGuard7endBodyEv($guard_idx_val);
    __label__ = 6;
    break;
   case 6:
    var $13 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($8, 77);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    var $15 = __ZNK11JSParseNode10isInParensEv($8);
    if ($15) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $17 = __ZN2js11TokenStream9peekTokenEv($1);
    if (($17 | 0) == 3) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $20 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $8, 0, 215, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_yield_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 21;
    break;
   case 10:
    var $22 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($1, 42);
    if ($22) {
      __label__ = 11;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 11:
    var $guard_idx1_val = HEAP32[$guard_idx >> 2];
    var $guard_idx2_val = HEAP32[$guard_idx2 >> 2];
    var $guard_idx3_val = HEAP32[$guard_idx3 >> 2];
    var $24 = __ZN11GenexpGuard14checkValidBodyEP11JSParseNode($guard_idx1_val, $guard_idx2_val, $guard_idx3_val, $8);
    if ($24) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 12:
    var $26 = __ZN2js6Parser13generatorExprEP11JSParseNode($this, $8);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if (HEAPU32[$6 >> 2] >>> 0 > 1) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $32 = __ZN2js11TokenStream9peekTokenEv($1);
    if (($32 | 0) == 3) {
      __label__ = 15;
      break;
    } else {
      var $argNode_0 = $26;
      __label__ = 18;
      break;
    }
   case 15:
    var $35 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $26, 0, 215, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str2323384 | 0, tempInt));
    var $_0 = 0;
    __label__ = 21;
    break;
   case 16:
    if ($arg0_0) {
      __label__ = 17;
      break;
    } else {
      var $argNode_0 = $8;
      __label__ = 18;
      break;
    }
   case 17:
    var $38 = __ZN11GenexpGuard18maybeNoteGeneratorEP11JSParseNode($guard, $8);
    if ($38) {
      var $argNode_0 = $8;
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 18:
    var $argNode_0;
    __ZN11JSParseNode6appendEPS_($listNode, $argNode_0);
    var $40 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($1, 3);
    if ($40) {
      var $arg0_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $42 = __ZN2js11TokenStream8getTokenEv($1);
    if (($42 | 0) == 28) {
      var $_0 = 1;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $45 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 104, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser12argumentListEP11JSParseNode["X"] = 1;

function __ZL32CheckForImmediatelyAppliedLambdaP11JSParseNode($pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 34);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    if ((HEAP32[HEAP32[$pn + 32 >> 2] + 60 >> 2] & 1152 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = $pn + 44 | 0;
    var $14 = HEAP32[$12 >> 2] & -257;
    HEAP32[$12 >> 2] = $14;
    __label__ = 4;
    break;
   case 4:
    return $pn;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser13bracketedExprEv($this) {
  var $1 = $this + 980 | 0;
  var $3 = HEAP32[$1 >> 2] | 0;
  var $4 = HEAP32[$3 >> 2];
  var $5 = $4 & -17;
  HEAP32[$3 >> 2] = $5;
  var $6 = __ZN2js6Parser4exprEv($this);
  var $8 = HEAP32[$1 >> 2] | 0;
  var $11 = HEAP32[$8 >> 2] & 629442528 | $4;
  HEAP32[$8 >> 2] = $11;
  return $6;
}

function __ZN2js6Parser16endBracketedExprEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser13bracketedExprEv($this);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $this + 40 | 0;
    var $5 = __ZN2js11TokenStream8getTokenEj($4, 0);
    if (($5 | 0) == 24) {
      var $_0 = $1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 174, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser16propertySelectorEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[HEAP32[$this + 980 >> 2] + 48 >> 2];
    var $3 = __ZN2js11NullaryNode6createEP13JSTreeContext($_idx_val);
    var $4 = $3 | 0;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($4, 17);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($4, 72);
    __ZN11JSParseNode5setOpE4JSOp($4, 164);
    var $15 = $3 + 32 | 0;
    var $_c1 = HEAP32[HEAP32[HEAP32[$this + 12 >> 2] + 52 >> 2] + 210412 >> 2];
    HEAP32[$15 >> 2] = $_c1;
    var $_0 = $4;
    __label__ = 5;
    break;
   case 4:
    __ZN11JSParseNode5setOpE4JSOp($4, 165);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($4, 6);
    var $17 = $this + 40 | 0;
    var $18 = __ZNK2js11TokenStream12currentTokenEv($17);
    var $21 = $3 + 32 | 0;
    var $_c = HEAP32[$18 + 28 >> 2];
    HEAP32[$21 >> 2] = $_c;
    var $23 = $3 + 40 | 0;
    __ZN2js11UpvarCookie8makeFreeEv($23);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser15qualifiedSuffixEP11JSParseNode($this, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 980 >> 2];
    var $3 = __ZN2js8NameNode6createEP6JSAtomP13JSTreeContext(0, $2);
    var $4 = $3 | 0;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK11JSParseNode4isOpE4JSOp($pn, 165);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN11JSParseNode5setOpE4JSOp($pn, 59);
    __label__ = 4;
    break;
   case 4:
    var $10 = $this + 40 | 0;
    var $11 = __ZN2js11TokenStream8getTokenEj($10, 32);
    var $12 = ($11 | 0) == 17;
    if (($11 | 0) == 29 || ($11 | 0) == 17) {
      __label__ = 5;
      break;
    } else if (($11 | 0) == 23) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 5:
    __ZN11JSParseNode5setOpE4JSOp($4, 166);
    var $16 = $pn + 4 | 0;
    var $17 = $3 + 4 | 0;
    var $18$0 = HEAP32[$16 >> 2];
    var $18$1 = HEAP32[$16 + 4 >> 2];
    var $st$9$0 = $17 | 0;
    HEAP32[$st$9$0 >> 2] = $18$0;
    var $st$9$1 = $17 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $18$1;
    if ($12) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $32 = HEAP32[HEAP32[HEAP32[$this + 12 >> 2] + 52 >> 2] + 210412 >> 2] | 0;
    __label__ = 8;
    break;
   case 7:
    var $28 = __ZNK2js11TokenStream12currentTokenEv($10);
    var $32 = HEAP32[$28 + 28 >> 2];
    __label__ = 8;
    break;
   case 8:
    var $32;
    var $33 = $3 + 32 | 0;
    HEAP32[$33 >> 2] = $32;
    var $34 = $3 + 36 | 0;
    HEAP32[$34 >> 2] = $pn;
    var $36 = $3 + 40 | 0;
    __ZN2js11UpvarCookie8makeFreeEv($36);
    var $_0 = $4;
    __label__ = 12;
    break;
   case 9:
    var $38 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 133, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 12;
    break;
   case 10:
    var $40 = __ZN2js6Parser16endBracketedExprEv($this);
    if (($40 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN11JSParseNode5setOpE4JSOp($4, 167);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($4, 2);
    var $45 = $pn + 4 | 0;
    var $46 = $3 + 4 | 0;
    var $47$0 = HEAP32[$45 >> 2];
    var $47$1 = HEAP32[$45 + 4 >> 2];
    var $st$10$0 = $46 | 0;
    HEAP32[$st$10$0 >> 2] = $47$0;
    var $st$10$1 = $46 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $47$1;
    var $50 = $40 + 12 | 0;
    var $51 = $3 + 12 | 0;
    var $52$0 = HEAP32[$50 >> 2];
    var $52$1 = HEAP32[$50 + 4 >> 2];
    var $st$22$0 = $51 | 0;
    HEAP32[$st$22$0 >> 2] = $52$0;
    var $st$22$1 = $51 + 4 | 0;
    HEAP32[$st$22$1 >> 2] = $52$1;
    var $53 = $3 + 32 | 0;
    HEAP32[$53 >> 2] = $pn;
    var $54 = $3 + 36 | 0;
    HEAP32[$54 >> 2] = $40;
    var $_0 = $4;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser15qualifiedSuffixEP11JSParseNode["X"] = 1;

function __ZN2js6Parser19qualifiedIdentifierEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser16propertySelectorEv($this);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $this + 40 | 0;
    var $5 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($4, 71);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $1;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = HEAP32[$this + 980 >> 2] | 0;
    var $11 = HEAP32[$9 >> 2] | 256;
    HEAP32[$9 >> 2] = $11;
    var $12 = __ZN2js6Parser15qualifiedSuffixEP11JSParseNode($this, $1);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser19attributeIdentifierEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[HEAP32[$this + 980 >> 2] + 48 >> 2];
    var $3 = __ZN2js9UnaryNode6createEP13JSTreeContext($_idx_val);
    var $4 = $3 | 0;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN11JSParseNode5setOpE4JSOp($4, 168);
    var $7 = $this + 40 | 0;
    var $8 = __ZN2js11TokenStream8getTokenEj($7, 32);
    if (($8 | 0) == 29 || ($8 | 0) == 17) {
      __label__ = 3;
      break;
    } else if (($8 | 0) == 23) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = __ZN2js6Parser19qualifiedIdentifierEv($this);
    var $pn2_0 = $10;
    __label__ = 6;
    break;
   case 4:
    var $12 = __ZN2js6Parser16endBracketedExprEv($this);
    var $pn2_0 = $12;
    __label__ = 6;
    break;
   case 5:
    var $14 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 133, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 8;
    break;
   case 6:
    var $pn2_0;
    if (($pn2_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = $3 + 32 | 0;
    HEAP32[$18 >> 2] = $pn2_0;
    var $_0 = $4;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14MultiDeclRange5frontEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZN2js11TokenStream12isXMLTagModeEv($this_0_5_val) {
  return ($this_0_5_val & 512 | 0) != 0;
}

function __ZNK2js14MultiDeclRange5emptyEv($this_0_1_val) {
  return ($this_0_1_val | 0) == 0;
}

function __ZN2js11TokenStream6setXMLEb($this, $enabled) {
  HEAP8[$this + 908 | 0] = $enabled & 1;
  return;
}

function __ZN2js6Parser7xmlExprEi($this, $inTag) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[HEAP32[$this + 980 >> 2] + 48 >> 2];
    var $3 = __ZN2js9UnaryNode6createEP13JSTreeContext($_idx_val);
    var $4 = $3 | 0;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this + 40 | 0;
    var $_idx1_val = HEAP32[$this + 184 >> 2];
    var $8 = __ZN2js11TokenStream12isXMLTagModeEv($_idx1_val);
    __ZN2js11TokenStream13setXMLTagModeEb($7, 0);
    var $9 = __ZN2js6Parser4exprEv($this);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($12 | 0) == 26) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 176, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 5:
    __ZN2js11TokenStream13setXMLTagModeEb($7, $8);
    var $17 = $3 + 32 | 0;
    HEAP32[$17 >> 2] = $9;
    var $19 = ($inTag | 0) != 0 ? 180 : 181;
    __ZN11JSParseNode5setOpE4JSOp($4, $19);
    var $_0 = $4;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream13setXMLTagModeEb($this, $enabled) {
  __ZN2js11TokenStream7setFlagEbNS_16TokenStreamFlagsE($this, $enabled, 512);
  return;
}

function __ZN2js6Parser11xmlAtomNodeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[HEAP32[$this + 980 >> 2] + 48 >> 2];
    var $3 = __ZN2js11NullaryNode6createEP13JSTreeContext($_idx_val);
    var $4 = $3 | 0;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this + 40 | 0;
    var $8 = __ZNK2js11TokenStream12currentTokenEv($7);
    var $9 = $8 + 24 | 0;
    var $11 = HEAP32[$9 >> 2];
    __ZN11JSParseNode5setOpE4JSOp($4, $11);
    var $14 = $3 + 32 | 0;
    var $_c = HEAP32[$8 + 28 >> 2];
    HEAP32[$14 >> 2] = $_c;
    if ((HEAP32[$8 >> 2] | 0) == 69) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $4;
      __label__ = 4;
      break;
    }
   case 3:
    var $21 = $3 + 36 | 0;
    var $_c1 = HEAP32[$9 >> 2];
    HEAP32[$21 >> 2] = $_c1;
    var $_0 = $4;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser11xmlNameExprEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 40 | 0;
    var $2 = $this + 980 | 0;
    var $pn_0 = 0;
    var $list_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $list_0;
    var $pn_0;
    var $3 = __ZNK2js11TokenStream12currentTokenEv($1);
    if ((HEAP32[$3 >> 2] | 0) == 25) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZN2js6Parser7xmlExprEi($this, 1);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      var $pn2_0 = $8;
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = __ZN2js6Parser11xmlAtomNodeEv($this);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      var $pn2_0 = $11;
      __label__ = 5;
      break;
    }
   case 5:
    var $pn2_0;
    if (($pn_0 | 0) == 0) {
      var $pn_2 = $pn2_0;
      var $list_2 = $list_0;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($list_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $pn_1 = $pn_0;
      var $list_1 = $list_0;
      __label__ = 9;
      break;
    }
   case 7:
    var $_idx_val = HEAP32[HEAP32[$2 >> 2] + 48 >> 2];
    var $19 = __ZN2js8ListNode6createEP13JSTreeContext($_idx_val);
    var $20 = $19 | 0;
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($20, 63);
    var $25 = $pn_0 + 4 | 0;
    var $26 = $19 + 4 | 0;
    var $27$0 = HEAP32[$25 >> 2];
    var $27$1 = HEAP32[$25 + 4 >> 2];
    var $st$9$0 = $26 | 0;
    HEAP32[$st$9$0 >> 2] = $27$0;
    var $st$9$1 = $26 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $27$1;
    __ZN11JSParseNode8initListEPS_($20, $pn_0);
    var $29 = $19 + 44 | 0;
    var $32 = HEAP32[$29 >> 2] & -4096 | 2;
    HEAP32[$29 >> 2] = $32;
    var $pn_1 = $20;
    var $list_1 = $20;
    __label__ = 9;
    break;
   case 9:
    var $list_1;
    var $pn_1;
    var $36 = $pn2_0 + 12 | 0;
    var $37 = $pn_1 + 12 | 0;
    var $38$0 = HEAP32[$36 >> 2];
    var $38$1 = HEAP32[$36 + 4 >> 2];
    HEAP32[$37 >> 2] = $38$0;
    HEAP32[$37 + 4 >> 2] = $38$1;
    __ZN11JSParseNode6appendEPS_($pn_1, $pn2_0);
    var $pn_2 = $pn_1;
    var $list_2 = $list_1;
    __label__ = 10;
    break;
   case 10:
    var $list_2;
    var $pn_2;
    var $40 = __ZN2js11TokenStream8getTokenEv($1);
    if (($40 | 0) == 63 || ($40 | 0) == 25) {
      var $pn_0 = $pn_2;
      var $list_0 = $list_2;
      __label__ = 2;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2js11TokenStream10ungetTokenEv($1);
    var $_0 = $pn_2;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser11xmlNameExprEv["X"] = 1;

function __ZN2js6Parser13xmlTagContentENS_9TokenKindEPP6JSAtom($this, $tagtype, $namep) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser11xmlNameExprEv($this);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($1, 0);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $10 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = HEAP32[$1 + 32 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $10;
    HEAP32[$namep >> 2] = $10;
    var $11 = $this + 40 | 0;
    var $12 = $this + 980 | 0;
    var $list_0 = 0;
    var $pn_0 = $1;
    __label__ = 5;
    break;
   case 5:
    var $pn_0;
    var $list_0;
    var $14 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($11, 65);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $pn_0;
      __label__ = 24;
      break;
    }
   case 6:
    var $16 = __ZN2js11TokenStream8getTokenEv($11);
    if (($16 | 0) == 63 || ($16 | 0) == 25) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2js11TokenStream10ungetTokenEv($11);
    var $_0 = $pn_0;
    __label__ = 24;
    break;
   case 8:
    var $19 = __ZN2js6Parser11xmlNameExprEv($this);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (($list_0 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $list_1 = $list_0;
      var $pn_1 = $pn_0;
      __label__ = 12;
      break;
    }
   case 10:
    var $_idx_val = HEAP32[HEAP32[$12 >> 2] + 48 >> 2];
    var $25 = __ZN2js8ListNode6createEP13JSTreeContext($_idx_val);
    var $26 = $25 | 0;
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($26, $tagtype);
    var $31 = $pn_0 + 4 | 0;
    var $32 = $25 + 4 | 0;
    var $33$0 = HEAP32[$31 >> 2];
    var $33$1 = HEAP32[$31 + 4 >> 2];
    var $st$9$0 = $32 | 0;
    HEAP32[$st$9$0 >> 2] = $33$0;
    var $st$9$1 = $32 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $33$1;
    __ZN11JSParseNode8initListEPS_($26, $pn_0);
    var $list_1 = $26;
    var $pn_1 = $26;
    __label__ = 12;
    break;
   case 12:
    var $pn_1;
    var $list_1;
    __ZN11JSParseNode6appendEPS_($pn_1, $19);
    var $35 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($19, 5);
    if ($35) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    if ((HEAP32[$19 + 44 >> 2] & 2 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $43 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($19, 25);
    if ($43) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $46 = $pn_1 + 44 | 0;
    var $48 = HEAP32[$46 >> 2] | 2;
    HEAP32[$46 >> 2] = $48;
    __label__ = 16;
    break;
   case 16:
    var $50 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($11, 65);
    var $51 = __ZN2js11TokenStream8getTokenEj($11, 0);
    if (($51 | 0) == 4) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $54 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 183, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 18:
    var $56 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($11, 65);
    var $57 = __ZN2js11TokenStream8getTokenEv($11);
    if (($57 | 0) == 64) {
      __label__ = 19;
      break;
    } else if (($57 | 0) == 25) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 19:
    var $59 = __ZN2js6Parser11xmlAtomNodeEv($this);
    var $pn2_0 = $59;
    __label__ = 22;
    break;
   case 20:
    var $61 = __ZN2js6Parser7xmlExprEi($this, 1);
    var $63 = $pn_1 + 44 | 0;
    var $65 = HEAP32[$63 >> 2] | 2;
    HEAP32[$63 >> 2] = $65;
    var $pn2_0 = $61;
    __label__ = 22;
    break;
   case 21:
    var $67 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 184, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 22:
    var $pn2_0;
    if (($pn2_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $73 = $pn2_0 + 12 | 0;
    var $74 = $pn_1 + 12 | 0;
    var $75$0 = HEAP32[$73 >> 2];
    var $75$1 = HEAP32[$73 + 4 >> 2];
    HEAP32[$74 >> 2] = $75$0;
    HEAP32[$74 + 4 >> 2] = $75$1;
    __ZN11JSParseNode6appendEPS_($pn_1, $pn2_0);
    var $list_0 = $list_1;
    var $pn_0 = $pn_1;
    __label__ = 5;
    break;
   case 24:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser13xmlTagContentENS_9TokenKindEPP6JSAtom["X"] = 1;

function __ZN2js6Parser17xmlElementContentEP11JSParseNode($this, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 40 | 0;
    __ZN2js11TokenStream13setXMLTagModeEb($1, 0);
    var $3 = $pn + 12 | 0;
    var $5 = $pn + 44 | 0;
    __label__ = 2;
    break;
   case 2:
    var $7 = __ZN2js11TokenStream8getTokenEj($1, 1024);
    if (($7 | 0) < 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 4:
    var $12 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 190, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 19;
    break;
   case 5:
    var $14 = __ZNK2js11TokenStream12currentTokenEv($1);
    if ((HEAP32[$14 + 28 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = __ZN2js6Parser11xmlAtomNodeEv($this);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = $19 + 12 | 0;
    var $24$0 = HEAP32[$23 >> 2];
    var $24$1 = HEAP32[$23 + 4 >> 2];
    HEAP32[$3 >> 2] = $24$0;
    HEAP32[$3 + 4 >> 2] = $24$1;
    __ZN11JSParseNode6appendEPS_($pn, $19);
    __label__ = 8;
    break;
   case 8:
    var $26 = __ZN2js11TokenStream8getTokenEj($1, 8);
    if (($26 | 0) < 1) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    if (($26 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 10:
    var $31 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 190, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 19;
    break;
   case 11:
    if (($26 | 0) == 25) {
      __label__ = 12;
      break;
    } else if (($26 | 0) == 59) {
      __label__ = 13;
      break;
    } else if (($26 | 0) == 60) {
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 12:
    var $34 = __ZN2js6Parser7xmlExprEi($this, 0);
    var $36 = HEAP32[$5 >> 2] | 2;
    HEAP32[$5 >> 2] = $36;
    var $pn21_0 = $34;
    __label__ = 16;
    break;
   case 13:
    var $38 = __ZN2js6Parser16xmlElementOrListEi($this, 0);
    if (($38 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $41 = $38 + 44 | 0;
    var $42 = HEAP32[$41 >> 2];
    var $43 = $42 & 4063;
    var $44 = $42 & -33;
    HEAP32[$41 >> 2] = $44;
    var $46 = HEAP32[$5 >> 2] | $43;
    HEAP32[$5 >> 2] = $46;
    var $pn21_02 = $38;
    __label__ = 17;
    break;
   case 15:
    var $48 = __ZN2js6Parser11xmlAtomNodeEv($this);
    var $pn21_0 = $48;
    __label__ = 16;
    break;
   case 16:
    var $pn21_0;
    if (($pn21_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      var $pn21_02 = $pn21_0;
      __label__ = 17;
      break;
    }
   case 17:
    var $pn21_02;
    var $53 = $pn21_02 + 12 | 0;
    var $54$0 = HEAP32[$53 >> 2];
    var $54$1 = HEAP32[$53 + 4 >> 2];
    HEAP32[$3 >> 2] = $54$0;
    HEAP32[$3 + 4 >> 2] = $54$1;
    __ZN11JSParseNode6appendEPS_($pn, $pn21_02);
    __label__ = 2;
    break;
   case 18:
    __ZN2js11TokenStream13setXMLTagModeEb($1, 1);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser17xmlElementContentEP11JSParseNode["X"] = 1;

function __ZN2js6Parser16xmlElementOrListEi($this, $allowList) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $startAtom = __stackBase__;
    var $endAtom = __stackBase__ + 4;
    var $3 = HEAPU32[$this + 12 >> 2];
    if (__stackBase__ + 8 >>> 0 < HEAPU32[$3 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($3);
    var $_0 = 0;
    __label__ = 51;
    break;
   case 3:
    var $9 = $this + 980 | 0;
    var $_idx3_val = HEAP32[HEAP32[$9 >> 2] + 48 >> 2];
    var $11 = __ZN2js8ListNode6createEP13JSTreeContext($_idx3_val);
    var $12 = $11 | 0;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 51;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = $this + 40 | 0;
    __ZN2js11TokenStream13setXMLTagModeEb($15, 1);
    var $16 = __ZN2js11TokenStream8getTokenEv($15);
    if (($16 | 0) == 63 || ($16 | 0) == 25) {
      __label__ = 5;
      break;
    } else if (($16 | 0) == -1) {
      var $_0 = 0;
      __label__ = 51;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 5:
    var $18 = __ZN2js6Parser13xmlTagContentENS_9TokenKindEPP6JSAtom($this, 59, $startAtom);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 51;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($15, 65);
    var $22 = __ZN2js11TokenStream8getTokenEv($15);
    if (($22 | 0) == 61) {
      __label__ = 7;
      break;
    } else if (($22 | 0) == 62) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 7:
    var $24 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($18, 59);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    __ZN11JSParseNode9makeEmptyEv($12);
    var $26 = HEAP32[$9 >> 2];
    var $27 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($12, $26);
    var $pn_0 = $18;
    __label__ = 13;
    break;
   case 9:
    __ZN11JSParseNode8initListEPS_($12, $18);
    var $29 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($18, 5);
    if ($29) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    if ((HEAP32[$18 + 44 >> 2] & 2 | 0) == 0) {
      var $pn_0 = $12;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $37 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($18, 25);
    if ($37) {
      __label__ = 12;
      break;
    } else {
      var $pn_0 = $12;
      __label__ = 13;
      break;
    }
   case 12:
    var $40 = $11 + 44 | 0;
    var $42 = HEAP32[$40 >> 2] | 2;
    HEAP32[$40 >> 2] = $42;
    var $pn_0 = $12;
    __label__ = 13;
    break;
   case 13:
    var $pn_0;
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn_0, 61);
    var $45 = $pn_0 + 44 | 0;
    var $47 = HEAP32[$45 >> 2] | 32;
    HEAP32[$45 >> 2] = $47;
    var $pn_2 = $pn_0;
    __label__ = 44;
    break;
   case 14:
    var $49 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 186, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 51;
    break;
   case 15:
    var $51 = $18 + 12 | 0;
    var $52 = __ZNK2js11TokenStream12currentTokenEv($15);
    var $54 = $52 + 12 | 0;
    var $55 = $51;
    var $56$0 = HEAP32[$54 >> 2];
    var $56$1 = HEAP32[$54 + 4 >> 2];
    HEAP32[$55 >> 2] = $56$0;
    HEAP32[$55 + 4 >> 2] = $56$1;
    var $57 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($18, 59);
    if ($57) {
      var $pn2_0 = $18;
      var $pn_1 = $12;
      __label__ = 21;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN11JSParseNode8initListEPS_($12, $18);
    var $59 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($18, 5);
    if ($59) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    if ((HEAP32[$18 + 44 >> 2] & 2 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $67 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($18, 25);
    if ($67) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $70 = $11 + 44 | 0;
    var $72 = HEAP32[$70 >> 2] | 2;
    HEAP32[$70 >> 2] = $72;
    __label__ = 20;
    break;
   case 20:
    var $_idx2_val = HEAP32[HEAP32[$9 >> 2] + 48 >> 2];
    var $75 = __ZN2js8ListNode6createEP13JSTreeContext($_idx2_val);
    var $76 = $75 | 0;
    if (($75 | 0) == 0) {
      var $_0 = 0;
      __label__ = 51;
      break;
    } else {
      var $pn2_0 = $12;
      var $pn_1 = $76;
      __label__ = 21;
      break;
    }
   case 21:
    var $pn_1;
    var $pn2_0;
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn_1, 75);
    var $81 = $pn2_0 + 4 | 0;
    var $82 = $pn_1 + 4 | 0;
    var $st$7$0 = $81 | 0;
    var $83$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $81 + 4 | 0;
    var $83$1 = HEAP32[$st$7$1 >> 2];
    var $st$11$0 = $82 | 0;
    HEAP32[$st$11$0 >> 2] = $83$0;
    var $st$11$1 = $82 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $83$1;
    __ZN11JSParseNode8initListEPS_($pn_1, $pn2_0);
    var $84 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn2_0, 5);
    if ($84) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    if ((HEAP32[$pn2_0 + 44 >> 2] & 2 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $92 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_0, 25);
    if ($92) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $95 = $pn_1 + 44 | 0;
    var $97 = HEAP32[$95 >> 2] | 2;
    HEAP32[$95 >> 2] = $97;
    __label__ = 25;
    break;
   case 25:
    var $99 = $pn_1 + 44 | 0;
    var $101 = HEAP32[$99 >> 2] | 32;
    HEAP32[$99 >> 2] = $101;
    var $102 = __ZN2js6Parser17xmlElementContentEP11JSParseNode($this, $pn_1);
    if (($102 | 0) == 0) {
      var $_0 = 0;
      __label__ = 51;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $105 = __ZN2js11TokenStream8getTokenEv($15);
    if (($105 | 0) < 1) {
      __label__ = 27;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 27:
    if (($105 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      var $_0 = 0;
      __label__ = 51;
      break;
    }
   case 28:
    var $110 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 190, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 51;
    break;
   case 29:
    if (($105 | 0) == 63 || ($105 | 0) == 25) {
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $113 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 186, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 51;
    break;
   case 31:
    var $115 = __ZN2js6Parser13xmlTagContentENS_9TokenKindEPP6JSAtom($this, 60, $endAtom);
    if (($115 | 0) == 0) {
      var $_0 = 0;
      __label__ = 51;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $118 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($115, 60);
    if ($118) {
      __label__ = 33;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 33:
    var $120 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 186, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 51;
    break;
   case 34:
    var $122 = HEAP32[$endAtom >> 2];
    if (($122 | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $125 = HEAP32[$startAtom >> 2];
    if (($125 | 0) == 0 | ($122 | 0) == ($125 | 0)) {
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $_idx_val = HEAP32[$125 + 4 >> 2];
    var $129 = __ZNK14JSLinearString5charsEv($_idx_val);
    var $130 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $115, 256, 185, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $129, tempInt));
    var $_0 = 0;
    __label__ = 51;
    break;
   case 37:
    var $_idx1_val = HEAP32[HEAP32[$9 >> 2] + 48 >> 2];
    var $133 = __ZN2js8ListNode6createEP13JSTreeContext($_idx1_val);
    var $134 = $133 | 0;
    if (($133 | 0) == 0) {
      var $_0 = 0;
      __label__ = 51;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($134, 60);
    __ZN11JSParseNode8initListEPS_($134, $115);
    __ZN11JSParseNode6appendEPS_($pn_1, $134);
    var $137 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($115, 5);
    if ($137) {
      __label__ = 39;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 39:
    if ((HEAP32[$115 + 44 >> 2] & 2 | 0) == 0) {
      __label__ = 42;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 40:
    var $145 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($115, 25);
    if ($145) {
      __label__ = 41;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 41:
    var $148 = $133 + 44 | 0;
    var $150 = HEAP32[$148 >> 2] | 2;
    HEAP32[$148 >> 2] = $150;
    var $152 = HEAP32[$99 >> 2] | 2;
    HEAP32[$99 >> 2] = $152;
    __label__ = 42;
    break;
   case 42:
    var $154 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($15, 65);
    var $155 = __ZN2js11TokenStream8getTokenEj($15, 0);
    if (($155 | 0) == 62) {
      var $pn_2 = $pn_1;
      __label__ = 44;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    var $158 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 186, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 51;
    break;
   case 44:
    var $pn_2;
    __ZN11JSParseNode5setOpE4JSOp($pn_2, 178);
    var $pn_3 = $pn_2;
    __label__ = 50;
    break;
   case 45:
    if (($allowList | 0) != 0 & ($16 | 0) == 62) {
      __label__ = 46;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 46:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($12, 76);
    __ZN11JSParseNode5setOpE4JSOp($12, 179);
    __ZN11JSParseNode9makeEmptyEv($12);
    var $165 = $11 + 44 | 0;
    var $167 = HEAP32[$165 >> 2] | 32;
    HEAP32[$165 >> 2] = $167;
    var $168 = __ZN2js6Parser17xmlElementContentEP11JSParseNode($this, $12);
    if (($168 | 0) == 0) {
      var $_0 = 0;
      __label__ = 51;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $171 = __ZN2js11TokenStream8getTokenEj($15, 0);
    if (($171 | 0) == 62) {
      var $pn_3 = $12;
      __label__ = 50;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    var $174 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 187, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 51;
    break;
   case 49:
    var $176 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 173, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 51;
    break;
   case 50:
    var $pn_3;
    __ZN2js11TokenStream13setXMLTagModeEb($15, 0);
    var $178 = $pn_3 + 12 | 0;
    var $179 = __ZNK2js11TokenStream12currentTokenEv($15);
    var $181 = $179 + 12 | 0;
    var $182 = $178;
    var $st$7$0 = $181 | 0;
    var $183$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $181 + 4 | 0;
    var $183$1 = HEAP32[$st$7$1 >> 2];
    var $st$11$0 = $182 | 0;
    HEAP32[$st$11$0 >> 2] = $183$0;
    var $st$11$1 = $182 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $183$1;
    var $_0 = $pn_3;
    __label__ = 51;
    break;
   case 51:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser16xmlElementOrListEi["X"] = 1;

function __ZN2js6Parser20xmlElementOrListRootEi($this, $allowList) {
  var $1 = $this + 40 | 0;
  var $2 = __ZNK2js11TokenStream6hasXMLEv($1);
  __ZN2js11TokenStream6setXMLEb($1, 1);
  var $3 = __ZN2js6Parser16xmlElementOrListEi($this, $allowList);
  __ZN2js11TokenStream6setXMLEb($1, $2);
  return $3;
}

function __ZNK2js11TokenStream6hasXMLEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 908 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      var $9 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 904 >> 2];
    var $6 = __ZNK2js11TokenStream13versionNumberEv($this_idx_val);
    var $7 = __ZN2jsL21VersionShouldParseXMLE9JSVersion($6);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser12parseXMLTextEP8JSObjectb($this, $chain) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 108;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $xmltc = __stackBase__;
    __ZN13JSTreeContextC1EPN2js6ParserE($xmltc, $this);
    var $2 = HEAP32[$this + 12 >> 2];
    var $3 = $xmltc;
    var $4 = __ZN13JSTreeContext4initEP9JSContextNS_12InitBehaviorE($3, $2, 0);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    __ZN13JSTreeContext13setScopeChainEP8JSObject($xmltc, $chain);
    var $6 = $this + 40 | 0;
    __ZN2js11TokenStream14setXMLOnlyModeEb($6, 1);
    var $7 = __ZN2js11TokenStream8getTokenEj($6, 8);
    if (($7 | 0) == 59) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 170, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $pn_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZN2js6Parser20xmlElementOrListRootEi($this, 0);
    var $pn_0 = $12;
    __label__ = 5;
    break;
   case 5:
    var $pn_0;
    __ZN2js11TokenStream14setXMLOnlyModeEb($6, 0);
    var $_0 = $pn_0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN13JSTreeContextD1Ev($xmltc);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream14setXMLOnlyModeEb($this, $enabled) {
  __ZN2js11TokenStream7setFlagEbNS_16TokenStreamFlagsE($this, $enabled, 2048);
  return;
}

function __ZN11JSParseNode10isConstantEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this >> 2];
    var $3 = $2 & 65535;
    if (($3 | 0) == 33) {
      __label__ = 2;
      break;
    } else if (($3 | 0) == 24 || ($3 | 0) == 26) {
      __label__ = 4;
      break;
    } else if (($3 | 0) == 30 || ($3 | 0) == 31) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $6 = $2 >>> 16 & 255;
    if (($6 | 0) == 64 || ($6 | 0) == 66 || ($6 | 0) == 67) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_0 = 0;
    __label__ = 7;
    break;
   case 4:
    var $9 = __ZNK11JSParseNode4isOpE4JSOp($this, 89);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $_0 = (HEAP32[$this + 44 >> 2] & 2048 | 0) == 0;
    __label__ = 7;
    break;
   case 6:
    var $_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11DoubleValueEd2907($agg_result, $dbl) {
  __ZN2JS5Value9setDoubleEd($agg_result, $dbl);
  return;
}

function __ZN2js9AtomDecls11lookupMultiEP6JSAtom($agg_result, $this_0_1_val, $atom) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $atom;
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6lookupERKS2_($p, $this_0_1_val, $1);
    var $2 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrcvPPPPPPPS5_Ev($p);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js14MultiDeclRangeC1EP12JSDefinition($agg_result, 0);
    __label__ = 6;
    break;
   case 3:
    var $6 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3Ptr5valueEv($p);
    var $7 = $6;
    var $8 = __ZNK2js12DefnOrHeader8isHeaderEv($7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = __ZNK2js12DefnOrHeader6headerEv($7);
    var $11 = $10;
    __ZN2js14MultiDeclRangeC1EPNS_12AtomDeclNodeE($agg_result, $11);
    __label__ = 6;
    break;
   case 5:
    var $_idx_val = HEAP32[$6 >> 2];
    var $13 = __ZNK2js12DefnOrHeader4defnEv($_idx_val);
    var $14 = $13;
    __ZN2js14MultiDeclRangeC1EP12JSDefinition($agg_result, $14);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14BlockIdInScopejP13JSTreeContext($blockid, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $tc;
    var $2 = __ZN13JSTreeContext7blockidEv($1);
    if ($2 >>> 0 < $blockid >>> 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $stmt_0_in = $tc + 28 | 0;
    __label__ = 3;
    break;
   case 3:
    var $stmt_0_in;
    var $stmt_0 = HEAPU32[$stmt_0_in >> 2];
    if (($stmt_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP32[$stmt_0 + 4 >> 2] | 0) == ($blockid | 0)) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $stmt_0_in = $stmt_0 + 28 | 0;
    __label__ = 3;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZL15JSDOUBLE_IS_NaNd2908($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZN2js14MultiDeclRange8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$this + 4 >> 2] = 0;
    __label__ = 6;
    break;
   case 3:
    var $8 = HEAP32[$2 + 4 >> 2];
    HEAP32[$1 >> 2] = $8;
    if (($8 | 0) == 0) {
      var $14 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = HEAP32[$8 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $14;
    HEAP32[$this + 4 >> 2] = $14;
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js11TokenStream11getTokenbufEv($this) {
  return $this + 184 | 0;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE12lookupForAddERKS2_($agg_result, $this, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $this_idx_val = HEAP32[$this >> 2];
    var $2 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE8usingMapEv($this_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this + 200 | 0;
    __ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($1, $4, $key);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC1ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E6AddPtrE($agg_result, $1);
    __label__ = 9;
    break;
   case 3:
    var $7 = $this + 8 + ($this_idx_val << 3) | 0;
    var $it_0 = $this + 8 | 0;
    __label__ = 4;
    break;
   case 4:
    var $it_0;
    if (($it_0 | 0) == ($7 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$it_0 >> 2] | 0) == (HEAP32[$key >> 2] | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC1EPNS5_10InlineElemEb($agg_result, $it_0, 1);
    __label__ = 9;
    break;
   case 7:
    var $it_0 = $it_0 + 8 | 0;
    __label__ = 4;
    break;
   case 8:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC1EPNS5_10InlineElemEb($agg_result, $7, 0);
    __label__ = 9;
    break;
   case 9:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrcvPPPPPPPS6_Ev($this) {
  var $1 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtr5foundEv($this);
  var $2 = $1 ? 1 : 0;
  return $2;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtr5valueEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[$this + 8 >> 2] + 4 | 0;
    __label__ = 4;
    break;
   case 3:
    var $_idx_val = HEAP32[$this >> 2];
    var $10 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($_idx_val);
    var $_0 = $10 + 4 | 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3addERNS5_6AddPtrERKS2_RKS4_($this, $p, $key, $value) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$p + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $p + 8 | 0;
    var $7 = HEAP32[$6 >> 2];
    if (($7 | 0) == ($this + 200 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE12switchAndAddERKS2_RKS4_($this, $key, $value);
    var $_0 = $11;
    __label__ = 6;
    break;
   case 4:
    var $13 = HEAP32[$key >> 2];
    var $14 = $7 | 0;
    HEAP32[$14 >> 2] = $13;
    var $15 = HEAP32[$value >> 2];
    var $17 = HEAP32[$6 >> 2] + 4 | 0;
    HEAP32[$17 >> 2] = $15;
    var $18 = $this + 4 | 0;
    var $20 = HEAP32[$18 >> 2] + 1 | 0;
    HEAP32[$18 >> 2] = $20;
    var $21 = $this | 0;
    var $23 = HEAP32[$21 >> 2] + 1 | 0;
    HEAP32[$21 >> 2] = $23;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $25 = $this + 200 | 0;
    var $26 = $p | 0;
    var $27 = __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($25, $26, $key, $value);
    var $_0 = $27;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12LinkUseToDefP11JSParseNodeP12JSDefinitionP13JSTreeContext($pn, $dn) {
  var $1 = $dn + 28 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$pn + 28 >> 2] = $2;
  HEAP32[$1 >> 2] = $pn;
  var $9 = $dn + 44 | 0;
  var $11 = HEAP32[$9 >> 2] | HEAP32[$pn + 44 >> 2] & 2312;
  HEAP32[$9 >> 2] = $11;
  __ZN11JSParseNode7setUsedEb($pn, 1);
  HEAP32[$pn + 36 >> 2] = $dn;
  return;
}

function __ZN9JSContext13regExpStaticsEv($this) {
  var $1 = __ZN2jsL22GetGlobalForScopeChainEP9JSContext2940($this);
  var $2 = $1;
  var $3 = __ZN2js13RegExpStatics11extractFromEPNS_12GlobalObjectE($2);
  return $3;
}

function __ZL12ContainsStmtP11JSParseNodeN2js9TokenKindE($pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pn_tr = $pn;
    __label__ = 2;
    break;
   case 2:
    var $pn_tr;
    if (($pn_tr | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $3 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_tr, 46);
    if ($3) {
      var $_0 = $pn_tr;
      __label__ = 19;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $5 = __ZNK11JSParseNode8getArityEv($pn_tr);
    if (($5 | 0) == 5) {
      __label__ = 5;
      break;
    } else if (($5 | 0) == 3) {
      __label__ = 9;
      break;
    } else if (($5 | 0) == 2) {
      __label__ = 12;
      break;
    } else if (($5 | 0) == 1) {
      __label__ = 15;
      break;
    } else if (($5 | 0) == 6) {
      __label__ = 17;
      break;
    } else if (($5 | 0) == 7) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 5:
    var $pn2_0_in = $pn_tr + 32 | 0;
    __label__ = 6;
    break;
   case 6:
    var $pn2_0_in;
    var $pn2_0 = HEAP32[$pn2_0_in >> 2];
    if (($pn2_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $11 = __ZL12ContainsStmtP11JSParseNodeN2js9TokenKindE($pn2_0);
    if (($11 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $_0 = $11;
      __label__ = 19;
      break;
    }
   case 8:
    var $pn2_0_in = $pn2_0 + 24 | 0;
    __label__ = 6;
    break;
   case 9:
    var $17 = HEAP32[$pn_tr + 32 >> 2];
    var $18 = __ZL12ContainsStmtP11JSParseNodeN2js9TokenKindE($17);
    if (($18 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = $18;
      __label__ = 19;
      break;
    }
   case 10:
    var $23 = HEAP32[$pn_tr + 36 >> 2];
    var $24 = __ZL12ContainsStmtP11JSParseNodeN2js9TokenKindE($23);
    if (($24 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = $24;
      __label__ = 19;
      break;
    }
   case 11:
    var $pn_tr = HEAP32[$pn_tr + 40 >> 2];
    __label__ = 2;
    break;
   case 12:
    var $31 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 0);
    if ($31) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 13:
    var $34 = HEAP32[$pn_tr + 32 >> 2];
    var $35 = __ZL12ContainsStmtP11JSParseNodeN2js9TokenKindE($34);
    if (($35 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      var $_0 = $35;
      __label__ = 19;
      break;
    }
   case 14:
    var $pn_tr = HEAP32[$pn_tr + 36 >> 2];
    __label__ = 2;
    break;
   case 15:
    var $42 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 0);
    if ($42) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 16:
    var $pn_tr = HEAP32[$pn_tr + 32 >> 2];
    __label__ = 2;
    break;
   case 17:
    var $47 = __ZN11JSParseNode9maybeExprEv($pn_tr);
    var $pn_tr = $47;
    __label__ = 2;
    break;
   case 18:
    var $pn_tr = HEAP32[$pn_tr + 36 >> 2];
    __label__ = 2;
    break;
   case 19:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12ContainsStmtP11JSParseNodeN2js9TokenKindE["X"] = 1;

function __ZL7BoolishP11JSParseNode($pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode5getOpEv($pn);
    if (($1 | 0) == 60) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 61) {
      __label__ = 5;
      break;
    } else if (($1 | 0) == 58) {
      __label__ = 6;
      break;
    } else if (($1 | 0) == 64 || ($1 | 0) == 66) {
      __label__ = 9;
      break;
    } else if (($1 | 0) == 127 || ($1 | 0) == 130 || ($1 | 0) == 67) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 2:
    var $4 = $pn + 32 | 0;
    var $5 = (tempDoubleI32[0] = HEAP32[$4 >> 2], tempDoubleI32[1] = HEAP32[$4 + 4 >> 2], tempDoubleF64[0]);
    if ($5 != 0) {
      __label__ = 3;
      break;
    } else {
      var $11 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZL15JSDOUBLE_IS_NaNd2908($5);
    var $11 = ($8 | 0) == 0;
    __label__ = 4;
    break;
   case 4:
    var $11;
    var $_0 = $11 & 1;
    __label__ = 11;
    break;
   case 5:
    var $_idx_val = HEAP32[HEAP32[$pn + 32 >> 2] >> 2];
    var $17 = __ZNK8JSString6lengthEv($_idx_val);
    var $_0 = ($17 | 0) != 0 & 1;
    __label__ = 11;
    break;
   case 6:
    if ((HEAP32[$pn + 40 >> 2] | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    var $26 = HEAP32[$pn + 32 >> 2];
    var $27 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($26, 34);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    if ((HEAP32[HEAP32[$26 + 32 >> 2] + 60 >> 2] & 4096 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 9:
    var $_0 = 0;
    __label__ = 11;
    break;
   case 10:
    var $_0 = -1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8FoldTypeP9JSContextP11JSParseNodeN2js9TokenKindE($cx, $pn, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, $type);
    if ($2) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($type | 0) == 30) {
      __label__ = 3;
      break;
    } else if (($type | 0) == 31) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 10;
      break;
    }
   case 3:
    var $5 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 31);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 10;
      break;
    }
   case 4:
    var $7 = $pn + 32 | 0;
    var $10 = HEAP32[$7 >> 2] | 0;
    __ZN2JSL11StringValueEP8JSString2910($1, $10);
    var $11 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $1, $d);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 5:
    var $13 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $14 = $7;
    tempDoubleF64[0] = $13, HEAP32[$14 >> 2] = tempDoubleI32[0], HEAP32[$14 + 4 >> 2] = tempDoubleI32[1];
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 30);
    __ZN11JSParseNode5setOpE4JSOp($pn, 60);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 6:
    var $16 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 30);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 10;
      break;
    }
   case 7:
    var $18 = $pn + 32 | 0;
    var $19 = $18;
    var $20 = (tempDoubleI32[0] = HEAP32[$19 >> 2], tempDoubleI32[1] = HEAP32[$19 + 4 >> 2], tempDoubleF64[0]);
    var $21 = __Z17js_NumberToStringP9JSContextd($cx, $20);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $24 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($cx, $21);
    var $_c = $24;
    HEAP32[$18 >> 2] = $_c;
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 31);
    __ZN11JSParseNode5setOpE4JSOp($pn, 61);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17FoldBinaryNumericP9JSContext4JSOpP11JSParseNodeS3_S3_P13JSTreeContext($op, $pn1, $pn2, $pn, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $pn1 + 32 | 0;
    var $3 = (tempDoubleI32[0] = HEAP32[$2 >> 2], tempDoubleI32[1] = HEAP32[$2 + 4 >> 2], tempDoubleF64[0]);
    var $5 = $pn2 + 32 | 0;
    var $6 = (tempDoubleI32[0] = HEAP32[$5 >> 2], tempDoubleI32[1] = HEAP32[$5 + 4 >> 2], tempDoubleF64[0]);
    if (($op | 0) == 24 || ($op | 0) == 25) {
      __label__ = 2;
      break;
    } else if (($op | 0) == 26) {
      __label__ = 3;
      break;
    } else if (($op | 0) == 27) {
      __label__ = 4;
      break;
    } else if (($op | 0) == 28) {
      __label__ = 5;
      break;
    } else if (($op | 0) == 29) {
      __label__ = 6;
      break;
    } else if (($op | 0) == 30) {
      __label__ = 7;
      break;
    } else if (($op | 0) == 31) {
      __label__ = 15;
      break;
    } else {
      var $d_0 = $3;
      __label__ = 18;
      break;
    }
   case 2:
    var $8 = __ZL20js_DoubleToECMAInt32d2909($3);
    var $9 = __ZL20js_DoubleToECMAInt32d2909($6);
    var $10 = $9 & 31;
    var $14 = ($op | 0) == 24 ? $8 << $10 : $8 >> $10;
    var $d_0 = $14 | 0;
    __label__ = 18;
    break;
   case 3:
    var $17 = __ZL20js_DoubleToECMAInt32d2909($6);
    var $18 = $17 & 31;
    var $19 = __Z21js_DoubleToECMAUint32d($3);
    var $d_0 = $19 >>> ($18 >>> 0) >>> 0;
    __label__ = 18;
    break;
   case 4:
    var $d_0 = $3 + $6;
    __label__ = 18;
    break;
   case 5:
    var $d_0 = $3 - $6;
    __label__ = 18;
    break;
   case 6:
    var $d_0 = $3 * $6;
    __label__ = 18;
    break;
   case 7:
    if ($6 == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 8:
    if ($3 == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $33 = __ZL15JSDOUBLE_IS_NaNd2908($3);
    if (($33 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $36 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $d_0 = $36;
    __label__ = 18;
    break;
   case 11:
    var $38 = __ZL15JSDOUBLE_IS_NEGd2917($3);
    var $39 = __ZL15JSDOUBLE_IS_NEGd2917($6);
    if ($38 ^ $39) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $42 = (tempDoubleI32[0] = HEAP32[_js_NegativeInfinity >> 2], tempDoubleI32[1] = HEAP32[_js_NegativeInfinity + 4 >> 2], tempDoubleF64[0]);
    var $d_0 = $42;
    __label__ = 18;
    break;
   case 13:
    var $44 = (tempDoubleI32[0] = HEAP32[_js_PositiveInfinity >> 2], tempDoubleI32[1] = HEAP32[_js_PositiveInfinity + 4 >> 2], tempDoubleF64[0]);
    var $d_0 = $44;
    __label__ = 18;
    break;
   case 14:
    var $d_0 = $3 / $6;
    __label__ = 18;
    break;
   case 15:
    if ($6 == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $50 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $d_0 = $50;
    __label__ = 18;
    break;
   case 17:
    var $52 = __ZL7js_fmoddd2918($3, $6);
    var $d_0 = $52;
    __label__ = 18;
    break;
   case 18:
    var $d_0;
    if (($pn1 | 0) == ($pn | 0)) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $56 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn1, $tc);
    __label__ = 20;
    break;
   case 20:
    if (($pn2 | 0) == ($pn | 0)) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $60 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn2, $tc);
    __label__ = 22;
    break;
   case 22:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 30);
    __ZN11JSParseNode5setOpE4JSOp($pn, 60);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn, 0);
    var $63 = $pn + 32 | 0;
    tempDoubleF64[0] = $d_0, HEAP32[$63 >> 2] = tempDoubleI32[0], HEAP32[$63 + 4 >> 2] = tempDoubleI32[1];
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17FoldBinaryNumericP9JSContext4JSOpP11JSParseNodeS3_S3_P13JSTreeContext["X"] = 1;

function __ZL20js_DoubleToECMAInt32d2909($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL18JSDOUBLE_IS_FINITEd2916($d);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $d & -1;
    if (($4 | 0) == $d) {
      var $_0 = $4;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = _fmod($d, 4294967296);
    if ($8 < 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = _floor($8);
    var $16 = $11;
    __label__ = 6;
    break;
   case 5:
    var $13 = _ceil($8);
    var $16 = $13 + 4294967296;
    __label__ = 6;
    break;
   case 6:
    var $16;
    if ($16 < 2147483648) {
      var $21 = $16;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $21 = $16 - 4294967296;
    __label__ = 8;
    break;
   case 8:
    var $21;
    var $_0 = $21 & -1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16FoldXMLConstantsP9JSContextP11JSParseNodeP13JSTreeContext($cx, $pn, $tc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZNK11JSParseNode7getKindEv($pn);
    var $2 = $pn + 32 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = $pn + 44 | 0;
    if ((HEAP32[$5 >> 2] & 2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $accum_1_ph = 0;
      __label__ = 5;
      break;
    }
   case 2:
    if (($1 | 0) == 60) {
      __label__ = 3;
      break;
    } else if (($1 | 0) == 61 || ($1 | 0) == 59) {
      __label__ = 4;
      break;
    } else {
      var $accum_1_ph = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $accum_1_ph = HEAP32[HEAP32[$cx + 52 >> 2] + 210388 >> 2] | 0;
    __label__ = 5;
    break;
   case 4:
    var $accum_1_ph = HEAP32[HEAP32[$cx + 52 >> 2] + 210408 >> 2] | 0;
    __label__ = 5;
    break;
   case 5:
    var $accum_1_ph;
    var $22 = $pn + 40 | 0;
    var $23 = $cx;
    var $j_0 = 0;
    var $i_0 = 0;
    var $accum_1 = $accum_1_ph;
    var $pnp_0 = $2;
    var $pn1_0 = $3;
    var $pn2_0 = $3;
    __label__ = 6;
    break;
   case 6:
    var $pn2_0;
    var $pn1_0;
    var $pnp_0;
    var $accum_1;
    var $i_0;
    var $j_0;
    if (($pn2_0 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $27 = __ZNK11JSParseNode7getKindEv($pn2_0);
    if (($27 | 0) == 64) {
      __label__ = 8;
      break;
    } else if (($27 | 0) == 63 || ($27 | 0) == 65 || ($27 | 0) == 66 || ($27 | 0) == 31) {
      __label__ = 9;
      break;
    } else if (($27 | 0) == 68) {
      __label__ = 11;
      break;
    } else if (($27 | 0) == 67) {
      __label__ = 12;
      break;
    } else if (($27 | 0) == 69) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 8:
    if (($accum_1 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $31 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn2_0, 5);
    if ($31) {
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $str_0 = HEAP32[$pn2_0 + 32 >> 2] | 0;
    __label__ = 22;
    break;
   case 11:
    var $41 = HEAP32[$pn2_0 + 32 >> 2] | 0;
    var $42 = __Z21js_MakeXMLCDATAStringP9JSContextP8JSString($23, $41);
    if (($42 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      var $str_0 = $42;
      __label__ = 22;
      break;
    }
   case 12:
    var $48 = HEAP32[$pn2_0 + 32 >> 2] | 0;
    var $49 = __Z23js_MakeXMLCommentStringP9JSContextP8JSString($23, $48);
    if (($49 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      var $str_0 = $49;
      __label__ = 22;
      break;
    }
   case 13:
    var $55 = HEAP32[$pn2_0 + 32 >> 2] | 0;
    var $58 = HEAP32[$pn2_0 + 36 >> 2];
    var $59 = __Z18js_MakeXMLPIStringP9JSContextP8JSStringS2_($23, $55, $58);
    if (($59 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      var $str_0 = $59;
      __label__ = 22;
      break;
    }
   case 14:
    if (($1 | 0) == 61 || ($1 | 0) == 59) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    if ((($j_0 ^ $i_0) & 1 | 0) != 0 | ($accum_1 | 0) == 0 | ($pn1_0 | 0) == ($pn2_0 | 0)) {
      __label__ = 21;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    if (($accum_1 | 0) == 0 | ($pn1_0 | 0) == ($pn2_0 | 0)) {
      __label__ = 21;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    if ((HEAP32[$pn1_0 + 24 >> 2] | 0) == ($pn2_0 | 0)) {
      var $pn1_1_lcssa = $pn1_0;
      __label__ = 19;
      break;
    } else {
      var $pn1_113 = $pn1_0;
      __label__ = 18;
      break;
    }
   case 18:
    var $pn1_113;
    var $72 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn1_113, $tc);
    var $74 = HEAP32[$22 >> 2] - 1 | 0;
    HEAP32[$22 >> 2] = $74;
    if ((HEAP32[$72 + 24 >> 2] | 0) == ($pn2_0 | 0)) {
      var $pn1_1_lcssa = $72;
      __label__ = 19;
      break;
    } else {
      var $pn1_113 = $72;
      __label__ = 18;
      break;
    }
   case 19:
    var $pn1_1_lcssa;
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn1_1_lcssa, 66);
    __ZN11JSParseNode5setOpE4JSOp($pn1_1_lcssa, 61);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn1_1_lcssa, 0);
    var $78 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($cx, $accum_1);
    HEAP32[$pn1_1_lcssa + 32 >> 2] = $78;
    if (($78 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    HEAP32[$pnp_0 >> 2] = $pn1_1_lcssa;
    __label__ = 21;
    break;
   case 21:
    var $83 = $pn2_0 + 24 | 0;
    var $j_2 = $j_0;
    var $accum_2 = 0;
    var $pnp_1 = $83;
    var $pn1_2 = HEAP32[$83 >> 2];
    __label__ = 29;
    break;
   case 22:
    var $str_0;
    if (($accum_1 | 0) == 0) {
      var $j_2 = $j_0;
      var $accum_2 = $str_0;
      var $pnp_1 = $pnp_0;
      var $pn1_2 = $pn1_0;
      __label__ = 29;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    __ZN2js16AutoStringRooterC1EP9JSContextP8JSString($tvr, $cx, $accum_1);
    if (($1 | 0) == 61 || ($1 | 0) == 59) {
      __label__ = 24;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 24:
    if (($i_0 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $92 = __Z19js_AddAttributePartP9JSContextiP8JSStringS2_($23, $i_0 & 1, $accum_1, $str_0);
    var $96 = $92;
    __label__ = 27;
    break;
   case 26:
    var $94 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($cx, $accum_1, $str_0);
    var $96 = $94;
    __label__ = 27;
    break;
   case 27:
    var $96;
    __ZN2js16AutoStringRooterD1Ev($tvr);
    if (($96 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $j_2 = $j_0 + 1 | 0;
    var $accum_2 = $96;
    var $pnp_1 = $pnp_0;
    var $pn1_2 = $pn1_0;
    __label__ = 29;
    break;
   case 29:
    var $pn1_2;
    var $pnp_1;
    var $accum_2;
    var $j_2;
    var $j_0 = $j_2;
    var $i_0 = $i_0 + 1 | 0;
    var $accum_1 = $accum_2;
    var $pnp_0 = $pnp_1;
    var $pn1_0 = $pn1_2;
    var $pn2_0 = HEAP32[$pn2_0 + 24 >> 2];
    __label__ = 6;
    break;
   case 30:
    if (($accum_1 | 0) == 0) {
      var $pn1_4 = $pn1_0;
      __label__ = 42;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    if ((HEAP32[$5 >> 2] & 2 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      var $accum_3_ph = $accum_1;
      __label__ = 38;
      break;
    }
   case 32:
    if (($1 | 0) == 61) {
      __label__ = 33;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 33:
    var $_pn_in = HEAP32[$cx + 52 >> 2] + 210396 | 0;
    __label__ = 36;
    break;
   case 34:
    if (($1 - 59 | 0) >>> 0 < 2) {
      __label__ = 35;
      break;
    } else {
      var $accum_3_ph = $accum_1;
      __label__ = 38;
      break;
    }
   case 35:
    var $_pn_in = HEAP32[$cx + 52 >> 2] + 210420 | 0;
    __label__ = 36;
    break;
   case 36:
    var $_pn_in;
    var $_pn = HEAP32[$_pn_in >> 2];
    if (($_pn | 0) == 0) {
      var $accum_3_ph = $accum_1;
      __label__ = 38;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $str_2 = $_pn | 0;
    var $124 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($cx, $accum_1, $str_2);
    if (($124 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      var $accum_3_ph = $124;
      __label__ = 38;
      break;
    }
   case 38:
    var $accum_3_ph;
    if ((HEAP32[$pn1_0 + 24 >> 2] | 0) == 0) {
      var $pn1_3_lcssa = $pn1_0;
      __label__ = 40;
      break;
    } else {
      var $pn1_312 = $pn1_0;
      __label__ = 39;
      break;
    }
   case 39:
    var $pn1_312;
    var $129 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn1_312, $tc);
    var $131 = HEAP32[$22 >> 2] - 1 | 0;
    HEAP32[$22 >> 2] = $131;
    if ((HEAP32[$129 + 24 >> 2] | 0) == 0) {
      var $pn1_3_lcssa = $129;
      __label__ = 40;
      break;
    } else {
      var $pn1_312 = $129;
      __label__ = 39;
      break;
    }
   case 40:
    var $pn1_3_lcssa;
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn1_3_lcssa, 66);
    __ZN11JSParseNode5setOpE4JSOp($pn1_3_lcssa, 61);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn1_3_lcssa, 0);
    var $135 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($cx, $accum_3_ph);
    HEAP32[$pn1_3_lcssa + 32 >> 2] = $135;
    if (($135 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    HEAP32[$pnp_0 >> 2] = $pn1_3_lcssa;
    var $pn1_4 = $pn1_3_lcssa;
    __label__ = 42;
    break;
   case 42:
    var $pn1_4;
    if (($pn1_4 | 0) == 0) {
      var $_0 = 1;
      __label__ = 48;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    if ((HEAP32[$22 >> 2] | 0) == 1) {
      __label__ = 44;
      break;
    } else {
      var $_0 = 1;
      __label__ = 48;
      break;
    }
   case 44:
    if ((HEAP32[$5 >> 2] & 32 | 0) == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 45:
    __ZN11JSParseNode6becomeEPS_($pn, $pn1_4);
    var $_0 = 1;
    __label__ = 48;
    break;
   case 46:
    if (($1 | 0) == 61) {
      __label__ = 47;
      break;
    } else {
      var $_0 = 1;
      __label__ = 48;
      break;
    }
   case 47:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 75);
    __ZN11JSParseNode5setOpE4JSOp($pn, 178);
    var $_0 = 1;
    __label__ = 48;
    break;
   case 48:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16FoldXMLConstantsP9JSContextP11JSParseNodeP13JSTreeContext["X"] = 1;

function __ZN2JSL11StringValueEP8JSString2910($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZL22PrepareNodeForMutationP11JSParseNodeP13JSTreeContext($pn, $tc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stack = __stackBase__;
    var $1 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 0);
    if ($1) {
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 4);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $7 = HEAP32[$pn + 32 >> 2];
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 + 24 | 0;
    HEAP32[$10 >> 2] = 0;
    __label__ = 5;
    break;
   case 5:
    __ZN2js9NodeStackC1Ev($stack);
    var $12 = __ZL16PushNodeChildrenP11JSParseNodePN2js9NodeStackE($pn, $stack);
    var $stack_idx1 = $stack | 0;
    var $stack_idx1_val = HEAP32[$stack_idx1 >> 2];
    var $13 = __ZN2js9NodeStack5emptyEv($stack_idx1_val);
    if ($13) {
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $tc_idx = $tc + 48 | 0;
    __label__ = 7;
    break;
   case 7:
    var $14 = __ZN2js9NodeStack3popEv($stack);
    var $15 = __ZL16PushNodeChildrenP11JSParseNodePN2js9NodeStackE($14, $stack);
    if ($15) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $tc_idx_val = HEAP32[$tc_idx >> 2];
    __ZL17AddNodeToFreeListP11JSParseNodeP13JSTreeContext($14, $tc_idx_val);
    __label__ = 9;
    break;
   case 9:
    var $stack_idx_val = HEAP32[$stack_idx1 >> 2];
    var $17 = __ZN2js9NodeStack5emptyEv($stack_idx_val);
    if ($17) {
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 10:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE12switchAndAddERKS2_RKS4_($this, $key, $value) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE11switchToMapEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this + 200 | 0;
    var $4 = __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKS4_($3, $key, $value);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefIP12JSDefinitionEcvRS2_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this_0_2_val, $this_0_3_val, $this_0_5_val) {
  return ($this_0_5_val + $this_0_3_val | 0) >>> 0 >= ($this_0_2_val * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11initializedEv($this_0_6_val) {
  return ($this_0_6_val | 0) != 0;
}

function __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range13isInlineRangeEv($this_0_3_val) {
  return ($this_0_3_val & 1) << 24 >> 24 != 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($this_0_0_val, $this_0_1_val) {
  return ($this_0_0_val | 0) == ($this_0_1_val | 0);
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEC2ERS9_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefIP12JSDefinitionEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($e) {
  return $e | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC2EPNS5_10InlineElemEb($this, $ptr, $found) {
  HEAP32[$this + 8 >> 2] = $ptr;
  HEAP8[$this + 12 | 0] = 1;
  HEAP8[$this + 13 | 0] = $found & 1;
  return;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC2ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E6AddPtrE($this, $p) {
  var $1 = $p;
  var $2 = $this;
  var $3$0 = HEAP32[$1 >> 2];
  var $3$1 = HEAP32[$1 + 4 >> 2];
  HEAP32[$2 >> 2] = $3$0;
  HEAP32[$2 + 4 >> 2] = $3$1;
  HEAP8[$this + 12 | 0] = 0;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5EntryC2ERKS2_RKS4_($this, $key, $value) {
  HEAP32[$this >> 2] = $key;
  HEAP32[$this + 4 >> 2] = $value;
  return;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range16advancePastNullsEPNS5_10InlineElemE($this, $begin) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 12 >> 2];
    var $newCur_0 = $begin;
    __label__ = 2;
    break;
   case 2:
    var $newCur_0;
    if ($newCur_0 >>> 0 < $2 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    if ((HEAP32[$newCur_0 >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $newCur_0 = $newCur_0 + 8 | 0;
    __label__ = 2;
    break;
   case 5:
    HEAP32[$this + 8 >> 2] = $newCur_0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $7 = HEAP32[$v >> 2];
    var $8 = $5 + 4 | 0;
    HEAP32[$8 >> 2] = $7;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 12 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 8 >> 2];
    var $this_idx1 = $this + 12 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 20 >> 2];
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 3:
    var $14 = $this | 0;
    var $15 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($14, $10);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $19 = $this + 16 | 0;
    var $21 = HEAP32[$19 >> 2] + 1 | 0;
    HEAP32[$19 >> 2] = $21;
    HEAP32[$2 >> 2] = $15;
    var $22 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 6;
    break;
   case 6:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isLiveEv($src_01_idx_val);
    if ($24) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $26 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE10getKeyHashEv($src_01_idx1_val);
    var $27 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $26);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEENS_7MoveRefIT_EERSB_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEaSENS_7MoveRefIS8_EE($27, $_02_val);
    __label__ = 8;
    break;
   case 8:
    var $29 = $src_01 + 12 | 0;
    if (($29 | 0) == ($22 | 0)) {
      __label__ = 9;
      break;
    } else {
      var $src_01 = $29;
      __label__ = 6;
      break;
    }
   case 9:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($3);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js15TempAllocPolicy7malloc_Ej($alloc, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEaSENS_7MoveRefIS8_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = $2 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEENS_7MoveRefIT_EERS8_($1, $7);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEaSENS_7MoveRefIS5_EE($6, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEENS_7MoveRefIT_EERSB_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEC1ERS9_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js15TempAllocPolicy5free_EPv($0);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEC1ERS9_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEC2ERS9_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEaSENS_7MoveRefIS5_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEptEv($rhs_0);
  var $4 = $3 | 0;
  __ZN2js4MoveIP6JSAtomEENS_7MoveRefIT_EERKS4_($1, $4);
  var $_idx_val = HEAP32[$1 >> 2];
  var $5 = __ZNK2js7MoveRefIP6JSAtomEcvRS2_Ev($_idx_val);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = $3 + 4 | 0;
  __ZN2js4MoveIP12JSDefinitionEENS_7MoveRefIT_EERS4_($2, $8);
  var $_idx2_val = HEAP32[$2 >> 2];
  var $9 = __ZNK2js7MoveRefIP12JSDefinitionEcvRS2_Ev($_idx2_val);
  var $10 = HEAP32[$9 >> 2];
  HEAP32[$this + 4 >> 2] = $10;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js4MoveIP12JSDefinitionEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefIP12JSDefinitionEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIP12JSDefinitionEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIP12JSDefinitionEC2ERS2_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEC1Ev($this) {
  __ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEC2Ev($this);
  return;
}

function _js_malloc2912() {
  var $1 = _malloc(284);
  return $1;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE11switchToMapEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 200 | 0;
    var $2 = __ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE11initializedEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv($1);
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5countEv($this);
    var $6 = __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($1, $5);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 4:
    var $9 = $this | 0;
    var $11 = $this + 8 + (HEAP32[$9 >> 2] << 3) | 0;
    var $it_0 = $this + 8 | 0;
    __label__ = 5;
    break;
   case 5:
    var $it_0;
    if (($it_0 | 0) == ($11 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $it_0 | 0;
    if ((HEAP32[$15 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKS4_($1, $15, $it_0 + 4 | 0);
    if ($20) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $it_0 = $it_0 + 8 | 0;
    __label__ = 5;
    break;
   case 9:
    HEAP32[$9 >> 2] = 25;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKS4_($this, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $p = __stackBase__;
  __ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($p, $this, $k);
  var $1 = __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($this, $p, $k, $v);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l_val1) {
  var $1 = __ZN2js13PointerHasherIP6JSAtomLj2EE4hashERKS2_($l_val1);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $l_val4 = HEAP32[$l >> 2];
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($6, $l_val4);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $l_val = HEAP32[$l >> 2];
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($27, $l_val);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($e, $l_val1) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($1);
  var $_val = HEAP32[$2 >> 2];
  var $3 = __ZN2js13PointerHasherIP6JSAtomLj2EE5matchERKS2_S5_($_val, $l_val1);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE10isLiveHashEj($hash);
  return $1;
}

function __ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE11initializedEv($this) {
  var $_idx_val = HEAP32[$this + 24 >> 2];
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11initializedEv($_idx_val);
  return $1;
}

function __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5clearEv($1);
  return;
}

function __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E4initEj($1, $len);
  return $2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $4 = $length * 171 | 0;
    var $capacity_0 = $4 >>> 0 < 2048 ? 16 : $4 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 5;
      break;
    }
   case 4:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $8 = $roundUp_01 << 1;
    var $9 = $roundUpLog2_02 + 1 | 0;
    if ($8 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $8;
      var $roundUpLog2_02 = $9;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = $8;
      var $roundUpLog2_0_lcssa = $9;
      __label__ = 5;
      break;
    }
   case 5:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $11 = $this | 0;
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($11, $roundUp_0_lcssa);
    HEAP32[$this + 24 >> 2] = $12;
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5clearEv($this) {
  var $3 = HEAP32[$this + 24 >> 2];
  var $6 = HEAP32[$this + 8 >> 2] * 12 | 0;
  _memset($3, 0, $6, 1);
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtr5foundEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = (HEAP8[$this + 13 | 0] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $_idx_val_idx_val = HEAP32[HEAP32[$this >> 2] >> 2];
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($_idx_val_idx_val);
    var $13 = $11;
    __label__ = 4;
    break;
   case 4:
    var $13;
    return $13;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC1ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E6AddPtrE($this, $p) {
  __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC2ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E6AddPtrE($this, $p);
  return;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC1EPNS5_10InlineElemEb($this, $ptr, $found) {
  __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC2EPNS5_10InlineElemEb($this, $ptr, $found);
  return;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5EntryC1ERKS2_RKS4_($this, $key, $value) {
  __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5EntryC2ERKS2_RKS4_($this, $key, $value);
  return;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range10bumpCurPtrEv($this) {
  var $3 = HEAP32[$this + 8 >> 2] + 8 | 0;
  __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range16advancePastNullsEPNS5_10InlineElemE($this, $3);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$5 >> 2];
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isLiveEv($_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E5RangeE($this, $r_01, $r_12) {
  __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E5RangeE($this, $r_01, $r_12);
  return;
}

function __ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3allEv($agg_result, $this) {
  var $_idx_val = HEAP32[$this + 8 >> 2];
  var $_idx1_val = HEAP32[$this + 24 >> 2];
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3allEv($agg_result, $_idx_val, $_idx1_val);
  return;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC1EPKNS5_10InlineElemES9_($this, $begin, $end_) {
  __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC2EPKNS5_10InlineElemES9_($this, $begin, $end_);
  return;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC2EPKNS5_10InlineElemES9_($this, $begin, $end_) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC1Ev($1);
  HEAP32[$this + 8 >> 2] = $begin;
  HEAP32[$this + 12 >> 2] = $end_;
  HEAP8[$this + 16 | 0] = 1;
  __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range16advancePastNullsEPNS5_10InlineElemE($this, $begin);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC2Ev($this);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3allEv($agg_result, $this_0_2_val, $this_0_6_val) {
  var $1 = $this_0_6_val + $this_0_2_val * 12 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_($agg_result, $this_0_6_val, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$4 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isLiveEv($_idx_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E5RangeE($this, $r_0, $r_1) {
  var $1 = $r_0;
  var $2 = $r_1;
  var $3 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC1Ev($3);
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP8[$this + 16 | 0] = 0;
  var $7 = $this;
  var $11$1 = $2 | 0;
  HEAP32[$7 >> 2] = 0 | $1;
  HEAP32[$7 + 4 >> 2] = $11$1;
  return;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6lookupERKS2_($agg_result, $this, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $this_idx_val = HEAP32[$this >> 2];
    var $2 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE8usingMapEv($this_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this + 200 | 0;
    __ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_($1, $4, $key);
    var $_0_val = HEAP32[$1 >> 2];
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E3PtrE($agg_result, $_0_val);
    __label__ = 9;
    break;
   case 3:
    var $7 = $this + 8 + ($this_idx_val << 3) | 0;
    var $it_0 = $this + 8 | 0;
    __label__ = 4;
    break;
   case 4:
    var $it_0;
    if (($it_0 | 0) == ($7 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$it_0 >> 2] | 0) == (HEAP32[$key >> 2] | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC1EPNS5_10InlineElemE($agg_result, $it_0);
    __label__ = 9;
    break;
   case 7:
    var $it_0 = $it_0 + 8 | 0;
    __label__ = 4;
    break;
   case 8:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC1EPNS5_10InlineElemE($agg_result, 0);
    __label__ = 9;
    break;
   case 9:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrcvPPPPPPPS6_Ev($this) {
  var $1 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3Ptr5foundEv($this);
  return $1 & 1;
}

function __ZNK2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE5beginEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE12hasCollisionEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function __ZN2js9NodeStack5emptyEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2jsL13VersionNumberE9JSVersion2944($version) {
  return $version & 4095;
}

function __ZN2jsL13VersionHasXMLE9JSVersion2945($version) {
  return ($version & 4096 | 0) != 0;
}

function _JSID_IS_STRING2948($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_TO_STRING2950($iden) {
  return $iden;
}

function __ZL18JSDOUBLE_IS_FINITEd2916($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function __ZL15JSDOUBLE_IS_NEGd2917($d) {
  tempDoubleF64[0] = $d;
  var $1$1 = tempDoubleI32[1];
  var $$emscripten$temp$0$1 = 0;
  return ($1$1 | 0) < ($$emscripten$temp$0$1 | 0) || ($1$1 | 0) == ($$emscripten$temp$0$1 | 0) && tempDoubleI32[0] >>> 0 < 0 >>> 0;
}

function __ZN11JSParseNode7setUsedEb($this, $enabled) {
  var $2 = $this;
  var $6 = HEAP32[$2 >> 2] & -1073741825 | ($enabled & 1) << 30;
  HEAP32[$2 >> 2] = $6;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 8 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 12 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEaSERKS5_($this, $rhs) {
  var $2 = HEAP32[$rhs >> 2];
  HEAP32[$this >> 2] = $2;
  var $5 = HEAP32[$rhs + 4 >> 2];
  HEAP32[$this + 4 >> 2] = $5;
  return;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC2EPNS5_10InlineElemE($this, $ie) {
  HEAP32[$this + 4 >> 2] = $ie;
  HEAP8[$this + 8 | 0] = 1;
  return;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E3PtrE($this, $p_0) {
  HEAP32[$this >> 2] = $p_0;
  HEAP8[$this + 8 | 0] = 0;
  return;
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZN2js10VectorImplIP8JSScriptLj16ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9NodeStack3popEv($this) {
  var $1 = $this | 0;
  var $2 = HEAP32[$1 >> 2];
  var $4 = HEAP32[$2 + 24 >> 2];
  HEAP32[$1 >> 2] = $4;
  return $2;
}

function __ZN2js9NodeStack8pushListEP11JSParseNode($this, $pn) {
  var $1 = $this | 0;
  var $2 = HEAP32[$1 >> 2];
  var $4 = HEAP32[$pn + 36 >> 2];
  HEAP32[$4 >> 2] = $2;
  var $6 = HEAP32[$pn + 32 >> 2];
  HEAP32[$1 >> 2] = $6;
  return;
}

function __ZN2js9NodeStack4pushEP11JSParseNode($this, $pn) {
  var $1 = $this | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$pn + 24 >> 2] = $2;
  HEAP32[$1 >> 2] = $pn;
  return;
}

function __ZN2js9NodeStackC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  return;
}

function __ZN2js14MultiDeclRangeC2EPNS_12AtomDeclNodeE($this, $node) {
  HEAP32[$this >> 2] = $node;
  var $4 = HEAP32[$node >> 2];
  HEAP32[$this + 4 >> 2] = $4;
  return;
}

function __ZN2js14MultiDeclRangeC2EP12JSDefinition($this, $defn) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = $defn;
  return;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC2EPNS4_10InlineElemE($this, $ie) {
  HEAP32[$this + 4 >> 2] = $ie;
  HEAP8[$this + 8 | 0] = 1;
  return;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E3PtrE($this, $p_0) {
  HEAP32[$this >> 2] = $p_0;
  HEAP8[$this + 8 | 0] = 0;
  return;
}

function __ZN2js11TokenStream7setFlagEbNS_16TokenStreamFlagsE($this, $enabled, $flag) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($enabled) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $2 = $this + 144 | 0;
    var $4 = HEAP32[$2 >> 2] | $flag;
    HEAP32[$2 >> 2] = $4;
    __label__ = 4;
    break;
   case 3:
    var $7 = $this + 144 | 0;
    var $9 = HEAP32[$7 >> 2] & ($flag ^ -1);
    HEAP32[$7 >> 2] = $9;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11GenexpGuardC2EP13JSTreeContext($this, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this >> 2] = $tc;
    var $2 = $tc + 12 | 0;
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = HEAP32[$tc + 16 >> 2];
    var $_pre_phi = $tc + 20 | 0;
    __label__ = 4;
    break;
   case 3:
    var $6 = $tc + 20 | 0;
    HEAP32[$6 >> 2] = 0;
    HEAP32[$tc + 16 >> 2] = 0;
    HEAP32[$tc + 56 >> 2] = 0;
    HEAP32[$tc + 52 >> 2] = 0;
    var $11 = 0;
    var $_pre_phi = $6;
    __label__ = 4;
    break;
   case 4:
    var $_pre_phi;
    var $11;
    HEAP32[$this + 4 >> 2] = $11;
    var $13 = HEAP32[$_pre_phi >> 2];
    HEAP32[$this + 8 >> 2] = $13;
    var $16 = HEAP32[$2 >> 2] + 1 | 0;
    HEAP32[$2 >> 2] = $16;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN20CompExprTransplanterC2EP11JSParseNodeP13JSTreeContextbj($this, $pn, $tc, $ge, $adj) {
  HEAP32[$this >> 2] = $pn;
  HEAP32[$this + 4 >> 2] = $tc;
  HEAP8[$this + 8 | 0] = $ge & 1;
  HEAP32[$this + 12 >> 2] = $adj;
  HEAP32[$this + 16 >> 2] = 0;
  return;
}

function __ZN2js8TokenPtrltERKS0_($this, $bptr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    var $4 = HEAPU32[$bptr + 4 >> 2];
    if ($2 >>> 0 < $4 >>> 0) {
      var $15 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($2 | 0) == ($4 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $15 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $15 = HEAPU32[$this >> 2] >>> 0 < HEAPU32[$bptr >> 2] >>> 0;
    __label__ = 4;
    break;
   case 4:
    var $15;
    return $15;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6removeENS5_3PtrE($this, $p_0_0_0_val, $p_0_1_val, $p_0_2_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p_0_2_val & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$p_0_1_val >> 2] = 0;
    var $5 = $this + 4 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    __label__ = 4;
    break;
   case 3:
    var $9 = $this + 200 | 0;
    __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE($9, $p_0_0_0_val);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE($this, $p_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE($1, $p_0);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE($this, $p_0) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE($this, $p_0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e_idx_val = HEAP32[$e >> 2];
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE12hasCollisionEv($e_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE10setRemovedEv($e);
    var $3 = $this + 20 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 12 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEC1Ev($1);
  __ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEC1Ev($1);
  __ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3Ptr5foundEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 8 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = (HEAP32[$this + 4 >> 2] | 0) != 0;
    __label__ = 4;
    break;
   case 3:
    var $_idx_val_idx_val = HEAP32[HEAP32[$this >> 2] >> 2];
    var $10 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($_idx_val_idx_val);
    var $12 = $10;
    __label__ = 4;
    break;
   case 4:
    var $12;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E3PtrE($this, $p_01) {
  __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E3PtrE($this, $p_01);
  return;
}

function __ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $1, $l);
  return;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC1EPNS5_10InlineElemE($this, $ie) {
  __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC2EPNS5_10InlineElemE($this, $ie);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry);
  return;
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE13growStorageByEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE17growHeapStorageByEj($this);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $5 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    var $5 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    HEAP32[$this_idx1 >> 2] = $5 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $4 = $this + 16 | 0;
  var $5 = __ZNK7mozilla14AlignedStorageILj64EE4addrEv($4);
  return ($2 | 0) == ($5 | 0);
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 2;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplIP8JSScriptLj16ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE17growHeapStorageByEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIP8JSScriptLj16ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj16ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, 1);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP8JSScriptLj16ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj16ES3_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $3 = $v + 4 | 0;
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($2, $5, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    var $10 = $v + 12 | 0;
    HEAP32[$3 >> 2] = $9;
    HEAP32[$10 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP8JSScriptLj16ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIP8JSScriptLj16ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEEC2ES3_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $4 = $this + 16 | 0;
  var $5 = __ZN7mozilla14AlignedStorageILj64EE4addrEv($4);
  HEAP32[$2 >> 2] = $5;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 16;
  return;
}

function __ZN2js9NodeStackC1Ev($this) {
  __ZN2js9NodeStackC2Ev($this);
  return;
}

function __ZL16PushNodeChildrenP11JSParseNodePN2js9NodeStackE($pn, $stack) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode8getArityEv($pn);
    if (($1 | 0) == 4) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 6) {
      __label__ = 3;
      break;
    } else if (($1 | 0) == 5) {
      __label__ = 7;
      break;
    } else if (($1 | 0) == 3) {
      __label__ = 8;
      break;
    } else if (($1 | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($1 | 0) == 1) {
      __label__ = 12;
      break;
    } else if (($1 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 1;
      __label__ = 15;
      break;
    }
   case 2:
    HEAP32[$pn + 32 >> 2] = 0;
    var $4 = $pn + 36 | 0;
    var $6 = HEAP32[$4 >> 2];
    __ZN2js9NodeStack14pushUnlessNullEP11JSParseNode($stack, $6);
    HEAP32[$4 >> 2] = 0;
    var $_0 = 0;
    __label__ = 15;
    break;
   case 3:
    var $8 = __ZNK11JSParseNode6isUsedEv($pn);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $pn + 36 | 0;
    var $12 = HEAP32[$10 >> 2];
    __ZN2js9NodeStack14pushUnlessNullEP11JSParseNode($stack, $12);
    HEAP32[$10 >> 2] = 0;
    __label__ = 5;
    break;
   case 5:
    var $14 = __ZNK11JSParseNode6isUsedEv($pn);
    if ($14) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = __ZNK11JSParseNode6isDefnEv($pn);
    var $_0 = $16 ^ 1;
    __label__ = 15;
    break;
   case 7:
    __ZN2js9NodeStack8pushListEP11JSParseNode($stack, $pn);
    var $_0 = 1;
    __label__ = 15;
    break;
   case 8:
    var $21 = HEAP32[$pn + 32 >> 2];
    __ZN2js9NodeStack14pushUnlessNullEP11JSParseNode($stack, $21);
    var $24 = HEAP32[$pn + 36 >> 2];
    __ZN2js9NodeStack14pushUnlessNullEP11JSParseNode($stack, $24);
    var $27 = HEAP32[$pn + 40 >> 2];
    __ZN2js9NodeStack14pushUnlessNullEP11JSParseNode($stack, $27);
    var $_0 = 1;
    __label__ = 15;
    break;
   case 9:
    var $30 = HEAP32[$pn + 32 >> 2];
    var $31 = $pn + 36 | 0;
    var $32 = HEAP32[$31 >> 2];
    if (($30 | 0) == ($32 | 0)) {
      var $37 = $32;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2js9NodeStack14pushUnlessNullEP11JSParseNode($stack, $30);
    var $37 = HEAP32[$31 >> 2];
    __label__ = 11;
    break;
   case 11:
    var $37;
    __ZN2js9NodeStack14pushUnlessNullEP11JSParseNode($stack, $37);
    var $_0 = 1;
    __label__ = 15;
    break;
   case 12:
    var $41 = HEAP32[$pn + 32 >> 2];
    __ZN2js9NodeStack14pushUnlessNullEP11JSParseNode($stack, $41);
    var $_0 = 1;
    __label__ = 15;
    break;
   case 13:
    var $43 = __ZNK11JSParseNode6isUsedEv($pn);
    if ($43) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $45 = __ZNK11JSParseNode6isDefnEv($pn);
    var $_0 = $45 ^ 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16PushNodeChildrenP11JSParseNodePN2js9NodeStackE["X"] = 1;

function __ZL17AddNodeToFreeListP11JSParseNodeP13JSTreeContext($pn, $tc_0_11_val) {
  __ZL17AddNodeToFreeListP11JSParseNodePN2js6ParserE($pn, $tc_0_11_val);
  return;
}

function __ZN2js9NodeStack14pushUnlessNullEP11JSParseNode($this, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($pn | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js9NodeStack4pushEP11JSParseNode($this, $pn);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16AutoStringRooterC1EP9JSContextP8JSString($this, $cx, $str) {
  __ZN2js16AutoStringRooterC2EP9JSContextP8JSString($this, $cx, $str);
  return;
}

function __ZN2js16AutoStringRooterD1Ev($this) {
  __ZN2js16AutoStringRooterD2Ev($this);
  return;
}

function __ZN2js16AutoStringRooterD2Ev($this) {
  var $_idx_val = HEAP32[$this >> 2];
  var $_idx1_val = HEAP32[$this + 8 >> 2];
  __ZN2js12AutoGCRooterD2Ev($_idx_val, $_idx1_val);
  return;
}

function __ZN2js16AutoStringRooterC2EP9JSContextP8JSString($this, $cx, $str) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($1, $cx, -14);
  HEAP32[$this + 12 >> 2] = $str;
  return;
}

function __ZL7js_fmoddd2918($d, $d2) {
  var $1 = _fmod($d, $d2);
  return $1;
}

function __ZN2JSL14UndefinedValueEv2937($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2jsL22GetGlobalForScopeChainEP9JSContext2940($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $scope = __stackBase__;
    var $1 = __ZNK9JSContext5hasfpEv($cx);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK9JSContext2fpEv($cx);
    var $4 = __ZNK2js10StackFrame10scopeChainEv($3);
    var $5 = $4;
    var $6 = __ZNK8JSObject9getGlobalEv($5);
    var $_0 = $6;
    __label__ = 5;
    break;
   case 3:
    var $10 = HEAP32[$cx + 132 >> 2];
    HEAP32[$scope >> 2] = $10;
    var $11 = $cx;
    var $12 = $scope;
    var $13 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($11, $12);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = HEAP32[$scope >> 2];
    var $17 = __ZN8JSObject8asGlobalEv($16);
    var $_0 = $17;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6lookupERKS2_($agg_result, $this, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $_idx_val = HEAP32[$this >> 2];
    var $2 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE8usingMapEv($_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this + 200 | 0;
    __ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_($1, $4, $key);
    var $_0_val = HEAP32[$1 >> 2];
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E3PtrE($agg_result, $_0_val);
    __label__ = 9;
    break;
   case 3:
    var $7 = $this + 8 + ($_idx_val << 3) | 0;
    var $it_0 = $this + 8 | 0;
    __label__ = 4;
    break;
   case 4:
    var $it_0;
    if (($it_0 | 0) == ($7 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$it_0 >> 2] | 0) == (HEAP32[$key >> 2] | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC1EPNS4_10InlineElemE($agg_result, $it_0);
    __label__ = 9;
    break;
   case 7:
    var $it_0 = $it_0 + 8 | 0;
    __label__ = 4;
    break;
   case 8:
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC1EPNS4_10InlineElemE($agg_result, 0);
    __label__ = 9;
    break;
   case 9:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrcvPPPPPPPS5_Ev($this) {
  var $1 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3Ptr5foundEv($this);
  return $1 & 1;
}

function __ZN2js14MultiDeclRangeC1EP12JSDefinition($this, $defn) {
  __ZN2js14MultiDeclRangeC2EP12JSDefinition($this, $defn);
  return;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3Ptr5valueEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 8 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = HEAP32[$this + 4 >> 2] + 4 | 0;
    __label__ = 4;
    break;
   case 3:
    var $_idx_val = HEAP32[$this >> 2];
    var $10 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3PtrptEv($_idx_val);
    var $14 = $10 + 4 | 0;
    __label__ = 4;
    break;
   case 4:
    var $14;
    return $14;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14MultiDeclRangeC1EPNS_12AtomDeclNodeE($this, $node) {
  __ZN2js14MultiDeclRangeC2EPNS_12AtomDeclNodeE($this, $node);
  return;
}

function __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3Ptr5foundEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 8 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = (HEAP32[$this + 4 >> 2] | 0) != 0;
    __label__ = 4;
    break;
   case 3:
    var $_idx_val_idx_val = HEAP32[HEAP32[$this >> 2] >> 2];
    var $10 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3Ptr5foundEv($_idx_val_idx_val);
    var $12 = $10;
    __label__ = 4;
    break;
   case 4:
    var $12;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E3PtrE($this, $p_01) {
  __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E3PtrE($this, $p_01);
  return;
}

function __ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6lookupERKS4_($agg_result, $1, $l);
  return;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC1EPNS4_10InlineElemE($this, $ie) {
  __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC2EPNS4_10InlineElemE($this, $ie);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6lookupERKS4_($agg_result, $this, $l) {
  var $1 = $this;
  var $l_val = HEAP32[$l >> 2];
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11prepareHashERKS4_($l_val);
  var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6lookupERKS4_jj($1, $l, $2, 0);
  var $4 = $3;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3PtrC1ERNS0_14HashTableEntryIS6_EE($agg_result, $4);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3PtrC1ERNS0_14HashTableEntryIS6_EE($this, $entry) {
  var $1 = $this;
  var $2 = $entry;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3PtrC2ERNS0_14HashTableEntryIS6_EE($1, $2);
  return;
}

function __ZN2jsL21VersionShouldParseXMLE9JSVersion($version) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL13VersionHasXMLE9JSVersion2945($version);
    if ($1) {
      var $6 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2jsL13VersionNumberE9JSVersion2944($version);
    var $6 = ($3 | 0) > 159;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js11TokenStream13versionNumberEv($this_0_16_val) {
  var $1 = __ZN2jsL13VersionNumberE9JSVersion2944($this_0_16_val);
  return $1;
}

function __ZL12JSID_TO_ATOMi2949($id) {
  var $1 = _JSID_TO_STRING2950($id);
  return $1;
}

function __ZL10SetLvalKidP9JSContextPN2js11TokenStreamEP13JSTreeContextP11JSParseNodeS7_PKc($cx, $ts, $tc, $pn, $kid, $name) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($kid, 29);
    if ($1) {
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($kid, 22);
    if ($3) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($kid, 27);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $7 = __ZNK11JSParseNode4isOpE4JSOp($kid, 58);
    if ($7) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZNK11JSParseNode4isOpE4JSOp($kid, 123);
    if ($9) {
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $11 = __ZNK11JSParseNode4isOpE4JSOp($kid, 108);
    if ($11) {
      __label__ = 12;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $13 = __ZNK11JSParseNode4isOpE4JSOp($kid, 79);
    if ($13) {
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $15 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($kid, 19);
    if ($15) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $17 = __ZNK11JSParseNode4isOpE4JSOp($kid, 174);
    if ($17) {
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $19 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($kid, 23);
    if ($19) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $21 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($ts, 0, 0, 130, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $name, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 12:
    var $23 = __Z21CheckStrictAssignmentP9JSContextP13JSTreeContextP11JSParseNode($cx, $tc, $kid);
    if ($23) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 13:
    HEAP32[$pn + 32 >> 2] = $kid;
    var $_0 = $kid;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE12hasCollisionEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function __ZNK15JSCodeGenerator16compilingForEvalEv($this_0_0_0_val) {
  return ($this_0_0_0_val & 33554432 | 0) != 0;
}

function __ZNK11JSParseNode6lexdefEv($this_0_7_0_1_val) {
  return $this_0_7_0_1_val;
}

function __ZN2js8TokenPtrleERKS0_($this, $bptr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    var $4 = HEAPU32[$bptr + 4 >> 2];
    if ($2 >>> 0 < $4 >>> 0) {
      var $15 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($2 | 0) == ($4 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $15 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $15 = HEAPU32[$this >> 2] >>> 0 <= HEAPU32[$bptr >> 2] >>> 0;
    __label__ = 4;
    break;
   case 4:
    var $15;
    return $15;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 8 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 12 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEaSERKS4_($this, $rhs) {
  var $2 = HEAP32[$rhs >> 2];
  HEAP32[$this >> 2] = $2;
  var $5 = HEAP32[$rhs + 4 >> 2];
  HEAP32[$this + 4 >> 2] = $5;
  return;
}

function __ZN2js11TokenStream7FlaggerD2Ev($this_0_0_val, $this_0_1_val) {
  var $2 = $this_0_0_val + 144 | 0;
  var $4 = HEAP32[$2 >> 2] & ($this_0_1_val ^ -1);
  HEAP32[$2 >> 2] = $4;
  return;
}

function __ZN2js11TokenStream7FlaggerC2EPS0_j($this, $parent, $withFlags) {
  HEAP32[$this >> 2] = $parent;
  HEAP32[$this + 4 >> 2] = $withFlags;
  var $3 = $parent + 144 | 0;
  var $5 = HEAP32[$3 >> 2] | $withFlags;
  HEAP32[$3 >> 2] = $5;
  return;
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + $this_0_2_val * 12 | 0;
}

function __ZN2js6Parser7orExpr1Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser9andExpr1iEv($this);
    var $2 = $this + 40 | 0;
    var $3 = $this + 980 | 0;
    var $pn_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($2, 7);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZN2js6Parser9andExpr1nEv($this);
    var $10 = HEAP32[$3 >> 2];
    var $11 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(7, 68, $pn_0, $9, $10);
    var $pn_0 = $11;
    __label__ = 2;
    break;
   case 5:
    return $pn_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindES1_($this) {
  var $1 = __ZNK2js11TokenStream12currentTokenEv($this);
  return (HEAP32[$1 >> 2] - 15 | 0) >>> 0 < 2;
}

function __ZL8OuterLetP13JSTreeContextP10JSStmtInfoP6JSAtom($tc, $stmt, $atom) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $tc;
    var $_01 = $stmt;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $4 = HEAP32[$_01 + 28 >> 2];
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $4;
    var $8 = _js_LexicalLookup($1, $atom, $7);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $8;
    if (HEAP16[$8 >> 1] << 16 >> 16 == 4) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      var $_01 = $11;
      __label__ = 2;
      break;
    }
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17BindFunctionLocalP9JSContextP8BindDataRN2js14MultiDeclRangeEP13JSTreeContext($cx, $data, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$data >> 2];
    var $5 = HEAP32[$2 + 32 >> 2];
    if (($5 | 0) == (HEAP32[HEAP32[$cx + 52 >> 2] + 210176 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN11JSParseNode5setOpE4JSOp($2, 9);
    var $14 = $2 + 44 | 0;
    var $16 = HEAP32[$14 >> 2] | 512;
    HEAP32[$14 >> 2] = $16;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $19 = $tc + 92 | 0;
    var $20 = $cx;
    var $21 = __ZNK2js8Bindings6lookupEP9JSContextP6JSAtomPj($19, $20, $5, 0);
    if (($21 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 4:
    var $27 = (HEAP32[$data + 4 >> 2] | 0) == 128 ? 3 : 2;
    var $28 = __ZL17BindLocalVariableP9JSContextP13JSTreeContextP11JSParseNodeN2js11BindingKindE($cx, $tc, $2, $27);
    if ($28) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    __ZN11JSParseNode5setOpE4JSOp($2, 86);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15BindTopLevelVarP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($pn, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tc_idx_val = HEAP32[$tc >> 2];
    var $1 = __ZNK13JSTreeContext9compilingEv($tc_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 2:
    if ((HEAP32[HEAP32[$tc + 48 >> 2] + 960 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 3:
    if ((HEAP32[$pn + 44 >> 2] & 2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = $pn + 32 | 0;
    var $16 = $tc;
    var $17 = __ZN13JSTreeContext15asCodeGeneratorEv($16);
    var $18 = $17;
    var $20 = HEAP32[$15 >> 2];
    var $21 = __ZL12DefineGlobalP11JSParseNodeP15JSCodeGeneratorP6JSAtom($pn, $18, $20);
    var $_0 = $21;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8TokenPtrgeERKS0_($this, $bptr) {
  var $1 = __ZN2js8TokenPtrltERKS0_($this, $bptr);
  return $1 ^ 1;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3Ptr5valueEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 8 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = HEAP32[$this + 4 >> 2] + 4 | 0;
    __label__ = 4;
    break;
   case 3:
    var $_idx_val = HEAP32[$this >> 2];
    var $10 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($_idx_val);
    var $13 = $10 + 4 | 0;
    __label__ = 4;
    break;
   case 4:
    var $13;
    return $13;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL12PrivateValueEPv2951($agg_result, $ptr) {
  __ZN2JS5Value10setPrivateEPv($agg_result, $ptr);
  return;
}

function __ZNK11JSParseNode12isBlockChildEv($this) {
  var $1 = __ZNK11JSParseNode4testEj($this, 32);
  return $1;
}

function __ZNK11JSParseNode10frameLevelEv($this) {
  var $_idx_val = HEAP32[$this + 40 >> 2];
  var $2 = __ZNK2js11UpvarCookie5levelEv($_idx_val);
  return $2 & 65535;
}

function __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($opn, $tc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $tc + 48 | 0;
    var $3 = HEAPU32[$2 >> 2];
    var $5 = HEAPU32[$3 + 12 >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$5 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($5);
    var $_0 = 0;
    __label__ = 32;
    break;
   case 3:
    var $11 = __ZL17NewOrRecycledNodeP13JSTreeContext($3);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = __ZNK11JSParseNode7getKindEv($opn);
    __ZN11JSParseNode7setKindEN2js9TokenKindE($11, $14);
    var $15 = __ZNK11JSParseNode5getOpEv($opn);
    __ZN11JSParseNode5setOpE4JSOp($11, $15);
    var $16 = __ZNK11JSParseNode6isUsedEv($opn);
    __ZN11JSParseNode7setUsedEb($11, $16);
    var $17 = __ZNK11JSParseNode6isDefnEv($opn);
    __ZN11JSParseNode7setDefnEb($11, $17);
    var $18 = __ZNK11JSParseNode8getArityEv($opn);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($11, $18);
    var $19 = __ZNK11JSParseNode10isInParensEv($opn);
    __ZN11JSParseNode11setInParensEb($11, $19);
    var $22 = $11 + 4 | 0;
    var $23 = $opn + 4 | 0;
    HEAP32[$22 >> 2] = HEAP32[$23 >> 2];
    HEAP32[$22 + 4 >> 2] = HEAP32[$23 + 4 >> 2];
    HEAP32[$22 + 8 >> 2] = HEAP32[$23 + 8 >> 2];
    HEAP32[$22 + 12 >> 2] = HEAP32[$23 + 12 >> 2];
    var $24 = __ZNK11JSParseNode8getArityEv($11);
    if (($24 | 0) == 4) {
      __label__ = 5;
      break;
    } else if (($24 | 0) == 5) {
      __label__ = 8;
      break;
    } else if (($24 | 0) == 3) {
      __label__ = 13;
      break;
    } else if (($24 | 0) == 2) {
      __label__ = 16;
      break;
    } else if (($24 | 0) == 1) {
      __label__ = 21;
      break;
    } else if (($24 | 0) == 6) {
      __label__ = 23;
      break;
    } else if (($24 | 0) == 7) {
      __label__ = 29;
      break;
    } else if (($24 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 5:
    var $26 = HEAP32[$2 >> 2];
    var $31 = HEAP32[HEAP32[$opn + 32 >> 2] + 8 >> 2];
    var $32 = __ZN2js6Parser14newFunctionBoxEP8JSObjectP11JSParseNodeP13JSTreeContext($26, $31, $11, $tc);
    var $_c9 = $32;
    HEAP32[$11 + 32 >> 2] = $_c9;
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $38 = HEAP32[$opn + 36 >> 2];
    var $39 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($38, $tc);
    var $_c10 = $39;
    HEAP32[$11 + 36 >> 2] = $_c10;
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $45 = HEAP32[$opn + 40 >> 2];
    HEAP32[$11 + 40 >> 2] = $45;
    var $47 = $opn + 44 | 0;
    var $49 = HEAP32[$47 >> 2] & 4095;
    var $51 = $11 + 44 | 0;
    var $54 = HEAP32[$51 >> 2] & -4096 | $49;
    HEAP32[$51 >> 2] = $54;
    var $57 = HEAP32[$47 >> 2] & -4096 | $49;
    HEAP32[$51 >> 2] = $57;
    __label__ = 31;
    break;
   case 8:
    __ZN11JSParseNode9makeEmptyEv($11);
    var $opn2_0_in = $opn + 32 | 0;
    __label__ = 9;
    break;
   case 9:
    var $opn2_0_in;
    var $opn2_0 = HEAP32[$opn2_0_in >> 2];
    if (($opn2_0 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $63 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($opn2_0, $tc);
    if (($63 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN11JSParseNode6appendEPS_($11, $63);
    var $opn2_0_in = $opn2_0 + 24 | 0;
    __label__ = 9;
    break;
   case 12:
    var $73 = $11 + 44 | 0;
    var $76 = HEAP32[$73 >> 2] & -4096 | HEAP32[$opn + 44 >> 2] & 4095;
    HEAP32[$73 >> 2] = $76;
    __label__ = 31;
    break;
   case 13:
    var $79 = HEAP32[$opn + 32 >> 2];
    var $80 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($79, $tc);
    HEAP32[$11 + 32 >> 2] = $80;
    if (($80 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $86 = HEAP32[$opn + 36 >> 2];
    var $87 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($86, $tc);
    var $_c7 = $87;
    HEAP32[$11 + 36 >> 2] = $_c7;
    if (($87 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $93 = HEAP32[$opn + 40 >> 2];
    var $94 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($93, $tc);
    var $_c8 = $94;
    HEAP32[$11 + 40 >> 2] = $_c8;
    if (($94 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 16:
    var $98 = $opn + 32 | 0;
    var $99 = HEAP32[$98 >> 2];
    var $100 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($99, $tc);
    HEAP32[$11 + 32 >> 2] = $100;
    if (($100 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $106 = HEAP32[$opn + 36 >> 2];
    if (($106 | 0) == (HEAP32[$98 >> 2] | 0)) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $110 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($106, $tc);
    var $_c6 = $110;
    HEAP32[$11 + 36 >> 2] = $_c6;
    if (($110 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $_c4 = $100;
    HEAP32[$11 + 36 >> 2] = $_c4;
    __label__ = 20;
    break;
   case 20:
    var $_c5 = HEAP32[$opn + 40 >> 2];
    HEAP32[$11 + 40 >> 2] = $_c5;
    var $122 = HEAP32[$opn + 44 >> 2];
    HEAP32[$11 + 44 >> 2] = $122;
    __label__ = 31;
    break;
   case 21:
    var $127 = HEAP32[$opn + 32 >> 2];
    var $128 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($127, $tc);
    HEAP32[$11 + 32 >> 2] = $128;
    if (($128 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $_c3 = HEAP32[$opn + 36 >> 2];
    HEAP32[$11 + 36 >> 2] = $_c3;
    var $137 = HEAP32[$opn + 40 >> 2];
    HEAP32[$11 + 40 >> 2] = $137;
    __label__ = 31;
    break;
   case 23:
    var $142 = $11 + 32 | 0;
    var $143 = $opn + 32 | 0;
    HEAP32[$142 >> 2] = HEAP32[$143 >> 2];
    HEAP32[$142 + 4 >> 2] = HEAP32[$143 + 4 >> 2];
    HEAP32[$142 + 8 >> 2] = HEAP32[$143 + 8 >> 2];
    HEAP32[$142 + 12 >> 2] = HEAP32[$143 + 12 >> 2];
    var $144 = __ZNK11JSParseNode6isUsedEv($opn);
    if ($144) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $148 = HEAP32[$11 + 36 >> 2] + 28 | 0;
    var $149 = HEAP32[$148 >> 2];
    HEAP32[$11 + 28 >> 2] = $149;
    HEAP32[$148 >> 2] = $11;
    __label__ = 31;
    break;
   case 25:
    var $153 = HEAP32[$opn + 36 >> 2];
    if (($153 | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $156 = $153;
    var $157 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($156, $tc);
    var $_c2 = $157;
    HEAP32[$11 + 36 >> 2] = $_c2;
    if (($157 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $161 = __ZNK11JSParseNode6isDefnEv($opn);
    if ($161) {
      __label__ = 28;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 28:
    __ZN11JSParseNode7setDefnEb($opn, 0);
    var $163 = $11;
    __ZL12LinkUseToDefP11JSParseNodeP12JSDefinitionP13JSTreeContext($opn, $163);
    __label__ = 31;
    break;
   case 29:
    var $_c = HEAP32[$opn + 32 >> 2];
    HEAP32[$11 + 32 >> 2] = $_c;
    var $171 = HEAP32[$opn + 36 >> 2];
    var $172 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($171, $tc);
    var $_c1 = $172;
    HEAP32[$11 + 36 >> 2] = $_c1;
    if (($172 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    var $178 = $11 + 32 | 0;
    var $179 = $opn + 32 | 0;
    HEAP32[$178 >> 2] = HEAP32[$179 >> 2];
    HEAP32[$178 + 4 >> 2] = HEAP32[$179 + 4 >> 2];
    HEAP32[$178 + 8 >> 2] = HEAP32[$179 + 8 >> 2];
    HEAP32[$178 + 12 >> 2] = HEAP32[$179 + 12 >> 2];
    __label__ = 31;
    break;
   case 31:
    var $_0 = $11;
    __label__ = 32;
    break;
   case 32:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext["X"] = 1;

function __ZN2js10BinaryNode6createENS_9TokenKindE4JSOpRKNS_8TokenPosEP11JSParseNodeS7_P13JSTreeContext($pos, $left, $right, $tc_0_11_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN11JSParseNode6createE16JSParseNodeArityN2js9TokenKindE4JSOpRKNS1_8TokenPosEP13JSTreeContext(2, 6, 93, $pos, $tc_0_11_val);
    var $2 = $1;
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 + 32 >> 2] = $left;
    HEAP32[$1 + 36 >> 2] = $right;
    __label__ = 3;
    break;
   case 3:
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9AtomDecls6removeEP6JSAtom($this, $atom) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 16;
    HEAP32[$1 >> 2] = $atom;
    var $3 = $this + 4 | 0;
    var $4 = HEAP32[$3 >> 2];
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6lookupERKS2_($p, $4, $1);
    var $5 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrcvPPPPPPPS5_Ev($p);
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3Ptr5valueEv($p);
    var $9 = $8;
    var $10 = __ZNK2js12DefnOrHeader8isHeaderEv($9);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAP32[$3 >> 2];
    var $p_idx3_val = HEAP32[$p >> 2];
    var $p_idx4_val = HEAP32[$p + 4 >> 2];
    var $p_idx5_val = HEAP8[$p + 8 | 0];
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6removeENS4_3PtrE($12, $p_idx3_val, $p_idx4_val, $p_idx5_val);
    __label__ = 7;
    break;
   case 4:
    var $14 = __ZNK2js12DefnOrHeader6headerEv($9);
    var $16 = HEAP32[$14 + 4 >> 2];
    if (($16 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = $2;
    __ZN2js12DefnOrHeaderC1EPNS_12AtomDeclNodeE($19, $16);
    var $21 = HEAP32[$2 >> 2];
    HEAP32[$8 >> 2] = $21;
    __label__ = 7;
    break;
   case 6:
    var $24 = HEAP32[$3 >> 2];
    var $p_idx_val = HEAP32[$p >> 2];
    var $p_idx1_val = HEAP32[$p + 4 >> 2];
    var $p_idx2_val = HEAP8[$p + 8 | 0];
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6removeENS4_3PtrE($24, $p_idx_val, $p_idx1_val, $p_idx2_val);
    __label__ = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6removeENS4_3PtrE($this, $p_0_0_0_val, $p_0_1_val, $p_0_2_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p_0_2_val & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$p_0_1_val >> 2] = 0;
    var $5 = $this + 4 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    __label__ = 4;
    break;
   case 3:
    var $9 = $this + 200 | 0;
    __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E3PtrE($9, $p_0_0_0_val);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E3PtrE($this, $p_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6removeENSD_3PtrE($1, $p_0);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6removeENSD_3PtrE($this, $p_0) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6removeERNS0_14HashTableEntryIS6_EE($this, $p_0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E16checkUnderloadedEv($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6removeERNS0_14HashTableEntryIS6_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e_idx_val = HEAP32[$e >> 2];
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE12hasCollisionEv($e_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE10setRemovedEv($e);
    var $3 = $this + 20 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 12 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this;
    var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E15changeTableSizeEi($3, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 4 | 0;
  var $4 = $1;
  __ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEC1Ev($4);
  __ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEaSERKS4_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  var $4 = $1;
  __ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEC1Ev($4);
  __ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEaSERKS4_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js11TokenStream7FlaggerC1EPS0_j($this, $parent, $withFlags) {
  __ZN2js11TokenStream7FlaggerC2EPS0_j($this, $parent, $withFlags);
  return;
}

function __ZN2js11TokenStream7FlaggerD1Ev($this_0_0_val, $this_0_1_val) {
  __ZN2js11TokenStream7FlaggerD2Ev($this_0_0_val, $this_0_1_val);
  return;
}

function __ZL20BindDestructuringVarP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($cx, $data, $pn, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$pn + 32 >> 2];
    if (($3 | 0) == (HEAP32[HEAP32[$cx + 52 >> 2] + 210176 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = $tc | 0;
    var $13 = HEAP32[$11 >> 2] | 256;
    HEAP32[$11 >> 2] = $13;
    __label__ = 3;
    break;
   case 3:
    HEAP32[$data >> 2] = $pn;
    var $17 = HEAP32[$data + 8 >> 2];
    var $18 = FUNCTION_TABLE[$17]($cx, $data, $3, $tc);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $pn + 44 | 0;
    if ((HEAP32[$22 >> 2] & 512 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $27 = __ZNK11JSParseNode4isOpE4JSOp($pn, 9);
    var $28 = $27 ? 111 : 87;
    __ZN11JSParseNode5setOpE4JSOp($pn, $28);
    var $_pre_phi = $data + 4 | 0;
    __label__ = 7;
    break;
   case 6:
    var $30 = $data + 4 | 0;
    var $33 = (HEAP32[$30 >> 2] | 0) == 128 ? 14 : 111;
    __ZN11JSParseNode5setOpE4JSOp($pn, $33);
    var $_pre_phi = $30;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    if ((HEAP32[$_pre_phi >> 2] | 0) == 128) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $39 = HEAP32[$22 >> 2] | 2;
    HEAP32[$22 >> 2] = $39;
    __label__ = 9;
    break;
   case 9:
    __ZL10NoteLValueP9JSContextP11JSParseNodeP13JSTreeContextj($cx, $pn, $tc, 4);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL20BindDestructuringVarP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext["X"] = 1;

function __ZL20BindDestructuringLHSP9JSContextP11JSParseNodeP13JSTreeContext($cx, $pn, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode7getKindEv($pn);
    if (($1 | 0) == 29) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 22 || ($1 | 0) == 23) {
      __label__ = 3;
      break;
    } else if (($1 | 0) == 27) {
      __label__ = 5;
      break;
    } else if (($1 | 0) == 19) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    __ZL10NoteLValueP9JSContextP11JSParseNodeP13JSTreeContextj($cx, $pn, $tc, 8);
    __label__ = 3;
    break;
   case 3:
    var $4 = __ZNK11JSParseNode5getOpEv($pn);
    if ((HEAP32[_js_CodeSpec + ($4 << 3) + 4 >> 2] & 256 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    __ZN11JSParseNode5setOpE4JSOp($pn, 111);
    __label__ = 9;
    break;
   case 5:
    var $11 = __ZL11MakeSetCallP9JSContextP11JSParseNodeP13JSTreeContextj($cx, $pn, $tc, 129);
    if ($11) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $13 = __ZNK11JSParseNode4isOpE4JSOp($pn, 174);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN11JSParseNode5setOpE4JSOp($pn, 172);
    __label__ = 9;
    break;
   case 8:
    var $18 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $19 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($18, $pn, 0, 129, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 10;
    break;
   case 9:
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11GlobalScope9GlobalDefC1Ej($this, $knownSlot) {
  __ZN2js11GlobalScope9GlobalDefC2Ej($this, $knownSlot);
  return;
}

function __ZN2js11GlobalScope9GlobalDefC1EP6JSAtomP13JSFunctionBox($this, $atom, $box) {
  __ZN2js11GlobalScope9GlobalDefC2EP6JSAtomP13JSFunctionBox($this, $atom, $box);
  return;
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE6appendIS2_EEbT_($this, $t_02, $t_13, $t_24) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE13growStorageByEj($this);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t_02, $t_13, $t_24);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE13growStorageByEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE17growHeapStorageByEj($this);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t_0, $t_1, $t_2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $5 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_04 = $1 | 0;
    HEAP32[$_04 >> 2] = $t_0;
    var $_15 = $1 + 4 | 0;
    HEAP32[$_15 >> 2] = $t_1;
    var $_27 = $1 + 8 | 0;
    HEAP32[$_27 >> 2] = $t_2;
    var $5 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    HEAP32[$this_idx1 >> 2] = $5 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj192EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 * 12 | 0;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js7MoveRefINS_11GlobalScope9GlobalDefEEcvRS2_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Entry3keyEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Entry5valueEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range13isInlineRangeEv($this_0_3_val) {
  return ($this_0_3_val & 1) << 24 >> 24 != 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($this_0_0_val, $this_0_1_val) {
  return ($this_0_0_val | 0) == ($this_0_1_val | 0);
}

function __ZN18JSFunctionBoxQueue6lengthEv($this_0_3_val) {
  return $this_0_3_val + 1 | 0;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this_0_2_val, $this_0_3_val, $this_0_5_val) {
  return ($this_0_5_val + $this_0_3_val | 0) >>> 0 >= ($this_0_2_val * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZNK7mozilla14AlignedStorageILj192EE4addrEv($this) {
  return $this;
}

function __ZN2js7MoveRefINS_11GlobalScope9GlobalDefEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js11GlobalScope9GlobalDefC2EP6JSAtomP13JSFunctionBox($this, $atom, $box) {
  HEAP32[$this >> 2] = $atom;
  HEAP32[$this + 4 >> 2] = $box;
  return;
}

function __ZN2js11GlobalScope9GlobalDefC2Ej($this, $knownSlot) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 8 >> 2] = $knownSlot;
  return;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range16advancePastNullsEPNS4_10InlineElemE($this, $begin) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 12 >> 2];
    var $newCur_0 = $begin;
    __label__ = 2;
    break;
   case 2:
    var $newCur_0;
    if ($newCur_0 >>> 0 < $2 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    if ((HEAP32[$newCur_0 >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $newCur_0 = $newCur_0 + 8 | 0;
    __label__ = 2;
    break;
   case 5:
    HEAP32[$this + 8 >> 2] = $newCur_0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5Range5frontEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5EntryC2ERKS2_RKS3_($this, $key, $value) {
  HEAP32[$this >> 2] = $key;
  HEAP32[$this + 4 >> 2] = $value;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js12DefnOrHeaderC2EP12JSDefinition($this, $defn) {
  HEAP32[$this >> 2] = $defn;
  return;
}

function __ZN2js11TokenStream17mungeCurrentTokenE4JSOp($this, $newOp) {
  var $3 = $this + 4 + (HEAP32[$this + 132 >> 2] << 5) + 24 | 0;
  HEAP32[$3 >> 2] = $newOp;
  return;
}

function __ZN8BindDataC2Ev($this) {
  HEAP8[$this + 16 | 0] = 1;
  return;
}

function __ZN18JSFunctionBoxQueueC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE17growHeapStorageByEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj16ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, 1);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 134217727) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 134217727) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj16ES3_EEj($v, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $v | 0;
    var $3 = $newcap * 12 | 0;
    var $4 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $v_idx = $v + 4 | 0;
    var $v_idx_val = HEAP32[$v_idx >> 2];
    var $8 = __ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE12beginNoCheckEv($v_idx_val);
    var $v_idx4 = $v + 8 | 0;
    var $v_idx4_val = HEAP32[$v_idx4 >> 2];
    var $9 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE10endNoCheckEv($v_idx_val, $v_idx4_val);
    if (($8 | 0) == ($9 | 0)) {
      var $21 = $v_idx_val;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx = $1 | 0;
    var $dst_01 = $5;
    var $src_02 = $8;
    var $v_idx1_val5 = $v_idx_val;
    var $v_idx2_val7 = $v_idx4_val;
    __label__ = 4;
    break;
   case 4:
    var $v_idx2_val7;
    var $v_idx1_val5;
    var $src_02;
    var $dst_01;
    if (($dst_01 | 0) == 0) {
      var $v_idx1_val = $v_idx1_val5;
      var $v_idx2_val = $v_idx2_val7;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js4MoveINS_11GlobalScope9GlobalDefEEENS_7MoveRefIT_EERS4_($1, $src_02);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $13 = __ZNK2js7MoveRefINS_11GlobalScope9GlobalDefEEcvRS2_Ev($_idx_val);
    var $14 = $dst_01;
    var $15 = $13;
    HEAP32[$14 >> 2] = HEAP32[$15 >> 2];
    HEAP32[$14 + 4 >> 2] = HEAP32[$15 + 4 >> 2];
    HEAP32[$14 + 8 >> 2] = HEAP32[$15 + 8 >> 2];
    var $v_idx1_val = HEAP32[$v_idx >> 2];
    var $v_idx2_val = HEAP32[$v_idx4 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $v_idx2_val;
    var $v_idx1_val;
    var $17 = $dst_01 + 12 | 0;
    var $18 = $src_02 + 12 | 0;
    var $19 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE10endNoCheckEv($v_idx1_val, $v_idx2_val);
    if (($18 | 0) == ($19 | 0)) {
      var $21 = $v_idx1_val;
      __label__ = 7;
      break;
    } else {
      var $dst_01 = $17;
      var $src_02 = $18;
      var $v_idx1_val5 = $v_idx1_val;
      var $v_idx2_val7 = $v_idx2_val;
      __label__ = 4;
      break;
    }
   case 7:
    var $21;
    __ZN2js15TempAllocPolicy5free_EPv($21);
    HEAP32[$v_idx >> 2] = $5;
    HEAP32[$v + 12 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_11GlobalScope9GlobalDefEEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_11GlobalScope9GlobalDefEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_11GlobalScope9GlobalDefEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefINS_11GlobalScope9GlobalDefEEC2ERS2_($this, $t);
  return;
}

function __ZN2js10VectorImplINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx = $1 | 0;
    var $p_01 = $srcbeg;
    var $_02 = $dst;
    __label__ = 3;
    break;
   case 3:
    var $_02;
    var $p_01;
    if (($_02 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js4MoveINS_11GlobalScope9GlobalDefEEENS_7MoveRefIT_EERKS4_($1, $p_01);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $5 = __ZNK2js7MoveRefINS_11GlobalScope9GlobalDefEEcvRS2_Ev($_idx_val);
    var $6 = $_02;
    var $7 = $5;
    HEAP32[$6 >> 2] = HEAP32[$7 >> 2];
    HEAP32[$6 + 4 >> 2] = HEAP32[$7 + 4 >> 2];
    HEAP32[$6 + 8 >> 2] = HEAP32[$7 + 8 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $9 = $p_01 + 12 | 0;
    if (($9 | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      var $p_01 = $9;
      var $_02 = $_02 + 12 | 0;
      __label__ = 3;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_11GlobalScope9GlobalDefEEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_11GlobalScope9GlobalDefEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js11NameSetNode6createEP13JSTreeContext($tc_0_11_val) {
  var $1 = __ZN11JSParseNode6createE16JSParseNodeArityP13JSTreeContext(7, $tc_0_11_val);
  return $1;
}

function __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range5emptyEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP8[$this + 16 | 0];
    var $1 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range13isInlineRangeEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = (HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0);
    __label__ = 4;
    break;
   case 3:
    var $_idx_val = HEAP32[$this >> 2];
    var $_idx1_val = HEAP32[$this + 4 >> 2];
    var $9 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($_idx_val, $_idx1_val);
    var $11 = $9;
    __label__ = 4;
    break;
   case 4:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range5frontEv($agg_result, $this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP8[$this + 16 | 0];
    var $1 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range13isInlineRangeEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$this + 8 >> 2];
    var $5 = $4 | 0;
    var $6 = $4 + 4 | 0;
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5EntryC1ERKS2_RKS3_($agg_result, $5, $6);
    __label__ = 4;
    break;
   case 3:
    var $_idx_val = HEAP32[$this >> 2];
    var $8 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5Range5frontEv($_idx_val);
    var $9 = $8 | 0;
    var $10 = $8 + 4 | 0;
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5EntryC1ERKS2_RKS3_($agg_result, $9, $10);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP8[$this + 16 | 0];
    var $1 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range13isInlineRangeEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range10bumpCurPtrEv($this);
    __label__ = 4;
    break;
   case 3:
    var $4 = $this | 0;
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5Range8popFrontEv($4);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range10bumpCurPtrEv($this) {
  var $3 = HEAP32[$this + 8 >> 2] + 8 | 0;
  __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range16advancePastNullsEPNS4_10InlineElemE($this, $3);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$5 >> 2];
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isLiveEv($_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5EntryC1ERKS2_RKS3_($this, $key, $value) {
  __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5EntryC2ERKS2_RKS3_($this, $key, $value);
  return;
}

function __ZN2js13AtomDeclsIterC2EPNS_9AtomDeclsE($this, $decls_0_1_val) {
  var $1 = $this | 0;
  __ZN2js9AtomDecls3allEv($1, $decls_0_1_val);
  HEAP32[$this + 20 >> 2] = 0;
  return;
}

function __ZN2js9AtomDecls3allEv($agg_result, $this_0_1_val) {
  __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3allEv($agg_result, $this_0_1_val);
  return;
}

function __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3allEv($agg_result, $this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $_idx_val = HEAP32[$this >> 2];
    var $2 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE8usingMapEv($_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this + 200 | 0;
    __ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3allEv($1, $4);
    var $_0_val = HEAP32[$1 >> 2];
    var $_1_val = HEAP32[$1 + 4 >> 2];
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E5RangeE($agg_result, $_0_val, $_1_val);
    __label__ = 4;
    break;
   case 3:
    var $6 = $this + 8 | 0;
    var $7 = $this + 8 + ($_idx_val << 3) | 0;
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC1EPKNS4_10InlineElemES8_($agg_result, $6, $7);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E5RangeE($this, $r_01, $r_12) {
  __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E5RangeE($this, $r_01, $r_12);
  return;
}

function __ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3allEv($agg_result, $this) {
  var $_idx_val = HEAP32[$this + 8 >> 2];
  var $_idx1_val = HEAP32[$this + 24 >> 2];
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3allEv($agg_result, $_idx_val, $_idx1_val);
  return;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC1EPKNS4_10InlineElemES8_($this, $begin, $end_) {
  __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC2EPKNS4_10InlineElemES8_($this, $begin, $end_);
  return;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC2EPKNS4_10InlineElemES8_($this, $begin, $end_) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC1Ev($1);
  HEAP32[$this + 8 >> 2] = $begin;
  HEAP32[$this + 12 >> 2] = $end_;
  HEAP8[$this + 16 | 0] = 1;
  __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range16advancePastNullsEPNS4_10InlineElemE($this, $begin);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC2Ev($this);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3allEv($agg_result, $this_0_2_val, $this_0_6_val) {
  var $1 = $this_0_6_val + $this_0_2_val * 12 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC1EPNS0_14HashTableEntryIS6_EESH_($agg_result, $this_0_6_val, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC1EPNS0_14HashTableEntryIS6_EESH_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC2EPNS0_14HashTableEntryIS6_EESH_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC2EPNS0_14HashTableEntryIS6_EESH_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$4 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isLiveEv($_idx_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E5RangeE($this, $r_0, $r_1) {
  var $1 = $r_0;
  var $2 = $r_1;
  var $3 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC1Ev($3);
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP8[$this + 16 | 0] = 0;
  var $7 = $this;
  var $11$1 = $2 | 0;
  HEAP32[$7 >> 2] = 0 | $1;
  HEAP32[$7 + 4 >> 2] = $11$1;
  return;
}

function __ZN2js9AtomDecls9addUniqueEP6JSAtomP12JSDefinition($this, $atom, $defn) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 20;
    var $3 = __stackBase__ + 24;
    HEAP32[$1 >> 2] = $atom;
    var $4 = $this + 4 | 0;
    var $6 = HEAP32[$4 >> 2];
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE12lookupForAddERKS2_($p, $6, $1);
    var $7 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrcvPPPPPPPS5_Ev($p);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtr5valueEv($p);
    __ZN2js12DefnOrHeaderC1EP12JSDefinition($2, $defn);
    var $12 = HEAP32[$2 >> 2];
    HEAP32[$10 >> 2] = $12;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $15 = HEAP32[$4 >> 2];
    __ZN2js12DefnOrHeaderC1EP12JSDefinition($3, $defn);
    var $16 = $15;
    var $17 = $3;
    var $18 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3addERNS4_6AddPtrERKS2_RKS3_($16, $p, $1, $17);
    var $_0 = $18;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12DefnOrHeaderC1EP12JSDefinition($this, $defn) {
  __ZN2js12DefnOrHeaderC2EP12JSDefinition($this, $defn);
  return;
}

function __ZN12JSDefinition13isBindingFormEv($this) {
  var $1 = __ZN12JSDefinition4kindEv($this);
  return ($1 | 0) < 3;
}

function __ZN2JSL9NullValueEv2953($agg_result) {
  __ZN2JS5Value7setNullEv($agg_result);
  return;
}

function __ZL10MinBlockIdP11JSParseNodej($fn, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$fn + 44 >> 2] >>> 12 >>> 0 < $id >>> 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK11JSParseNode6isDefnEv($fn);
    if ($7) {
      var $fn_pn = $fn;
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 3:
    var $fn_pn;
    var $pn_0 = HEAP32[$fn_pn + 28 >> 2];
    if (($pn_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (HEAPU32[$pn_0 + 44 >> 2] >>> 12 >>> 0 < $id >>> 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      var $fn_pn = $pn_0;
      __label__ = 3;
      break;
    }
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18JSFunctionBoxQueueD2Ev($this_0_0_val) {
  var $1 = $this_0_0_val;
  __ZN2js10Foreground5free_EPv($1);
  return;
}

function __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_($this, $a_01) {
  __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_($this, $a_01);
  return;
}

function __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E4initEj($1, $len);
  return $2;
}

function __ZL12JSID_IS_ATOMi2955($id) {
  var $1 = _JSID_IS_STRING2948($id);
  return $1;
}

function __ZL18ReportBadParameterP9JSContextP13JSTreeContextP6JSAtomj($cx, $tc, $name, $errorNumber) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $bytes = __stackBase__;
    var $_idx_val = HEAP32[$tc + 44 >> 2];
    var $1 = __ZN2js9AtomDecls11lookupFirstEP6JSAtom($_idx_val, $name);
    __ZN16JSAutoByteStringC1Ev($bytes);
    var $2 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $name, $bytes);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $13 = 0;
    var $bytes_idx_val = HEAP32[$bytes >> 2];
    __label__ = 4;
    break;
   case 3:
    var $7 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $8 = $1 | 0;
    var $bytes_idx1_val = HEAP32[$bytes >> 2];
    var $9 = __ZNK16JSAutoByteString3ptrEv($bytes_idx1_val);
    var $10 = $tc;
    var $11 = __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($cx, $7, $10, $8, $errorNumber, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $9, tempInt));
    var $13 = $11;
    var $bytes_idx_val = $bytes_idx1_val;
    __label__ = 4;
    break;
   case 4:
    var $bytes_idx_val;
    var $13;
    __ZN16JSAutoByteStringD1Ev($bytes_idx_val);
    STACKTOP = __stackBase__;
    return $13;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 206,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_bEENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKb($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $8 = HEAP8[$v] & 1;
    HEAP8[$5 + 4 | 0] = $8;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 24 >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED1Ev($this_0_6_val) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED2Ev($this_0_6_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED2Ev($this_0_6_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_6_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($this_0_6_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js15TempAllocPolicy5free_EPv($0);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 12 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 8 >> 2];
    var $this_idx1 = $this + 12 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 20 >> 2];
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 3:
    var $14 = $this | 0;
    var $15 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($14, $10);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $19 = $this + 16 | 0;
    var $21 = HEAP32[$19 >> 2] + 1 | 0;
    HEAP32[$19 >> 2] = $21;
    HEAP32[$2 >> 2] = $15;
    var $22 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 6;
    break;
   case 6:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE6isLiveEv($src_01_idx_val);
    if ($24) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $26 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE10getKeyHashEv($src_01_idx1_val);
    var $27 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $26);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEENS_7MoveRefIT_EERS9_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEaSENS_7MoveRefIS6_EE($27, $_02_val);
    __label__ = 8;
    break;
   case 8:
    var $29 = $src_01 + 12 | 0;
    if (($29 | 0) == ($22 | 0)) {
      __label__ = 9;
      break;
    } else {
      var $src_01 = $29;
      __label__ = 6;
      break;
    }
   case 9:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($3);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js15TempAllocPolicy7malloc_Ej($alloc, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEaSENS_7MoveRefIS6_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = $2 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIP6JSAtombEEEENS_7MoveRefIT_EERS6_($1, $7);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js12HashMapEntryIP6JSAtombEaSENS_7MoveRefIS3_EE($6, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtombEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefIbEcvRbEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv($this) {
  return;
}

function __ZL14JSID_FROM_BITSj2961($bits) {
  return $bits;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZN2js11UpvarCookie15isLevelReservedEt($level) {
  return ($level & 65535) > 16382;
}

function __ZNK2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE6hasMapEv($this_0_0_val) {
  return ($this_0_0_val | 0) != 0;
}

function _JSVAL_TO_OBJECT_IMPL3001($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_IS_PRIMITIVE_IMPL3003($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 < 4294967175 & 1;
}

function __ZN7mozilla14AlignedStorageILj192EE4addrEv($this) {
  return $this;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEC2ERS7_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtombEEEC2ERS4_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefIbEC2ERb($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js12HashMapEntryIP6JSAtombEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP8[$this + 4 | 0] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE12setCollisionEj($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_bEE($e) {
  return $e | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  return;
}

function __ZL13JSVAL_TO_IMPLN2JS5ValueE3002($agg_result, $_0_0_0_val$0, $_0_0_0_val$1) {
  var $agg_result_0 = $agg_result | 0;
  HEAP32[$agg_result_0 >> 2] = $_0_0_0_val$0;
  HEAP32[$agg_result_0 + 4 >> 2] = $_0_0_0_val$1;
  return;
}

function __ZL13IMPL_TO_JSVAL12jsval_layout3004($agg_result, $l_0$0, $l_0$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $l_0$0;
  HEAP32[$1 + 4 >> 2] = $l_0$1;
  return;
}

function _INT32_TO_JSVAL_IMPL3005($agg_result, $i) {
  HEAP32[$agg_result + 4 >> 2] = -127;
  HEAP32[$agg_result >> 2] = $i;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEENS_7MoveRefIT_EERS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEC1ERS7_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEC2ERS7_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIP6JSAtombEaSENS_7MoveRefIS3_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtombEEEptEv($rhs_0);
  var $4 = $3 | 0;
  __ZN2js4MoveIP6JSAtomEENS_7MoveRefIT_EERKS4_($1, $4);
  var $_idx_val = HEAP32[$1 >> 2];
  var $5 = __ZNK2js7MoveRefIP6JSAtomEcvRS2_Ev($_idx_val);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = $3 + 4 | 0;
  __ZN2js4MoveIbEENS_7MoveRefIT_EERS2_($2, $8);
  var $_idx2_val = HEAP32[$2 >> 2];
  var $9 = __ZNK2js7MoveRefIbEcvRbEv($_idx2_val);
  var $11 = HEAP8[$9] & 1;
  HEAP8[$this + 4 | 0] = $11;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIP6JSAtombEEEENS_7MoveRefIT_EERS6_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtombEEEC1ERS4_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtombEEEC1ERS4_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtombEEEC2ERS4_($this, $t);
  return;
}

function __ZN2js4MoveIbEENS_7MoveRefIT_EERS2_($agg_result, $t) {
  __ZN2js7MoveRefIbEC1ERb($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIbEC1ERb($this, $t) {
  __ZN2js7MoveRefIbEC2ERb($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP6JSAtombEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIP6JSAtombEC1Ev($this) {
  __ZN2js12HashMapEntryIP6JSAtombEC2Ev($this);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l_val1) {
  var $1 = __ZN2js13PointerHasherIP6JSAtomLj2EE4hashERKS2_($l_val1);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $l_val4 = HEAP32[$l >> 2];
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($6, $l_val4);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE12setCollisionEj($entry_0);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $l_val = HEAP32[$l >> 2];
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($27, $l_val);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($e, $l_val1) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_bEE($1);
  var $_val = HEAP32[$2 >> 2];
  var $3 = __ZN2js13PointerHasherIP6JSAtomLj2EE5matchERKS2_S5_($_val, $l_val1);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $4 = $length * 171 | 0;
    var $capacity_0 = $4 >>> 0 < 2048 ? 16 : $4 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 5;
      break;
    }
   case 4:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $8 = $roundUp_01 << 1;
    var $9 = $roundUpLog2_02 + 1 | 0;
    if ($8 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $8;
      var $roundUpLog2_02 = $9;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = $8;
      var $roundUpLog2_0_lcssa = $9;
      __label__ = 5;
      break;
    }
   case 5:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $11 = $this | 0;
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($11, $roundUp_0_lcssa);
    HEAP32[$this + 24 >> 2] = $12;
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_($this, $a_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC1ES9_($1, $a_0);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC1ES9_($this, $ap_01) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap_01);
  return;
}

function __ZL14HasFinalReturnP11JSParseNode($pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pn_tr = $pn;
    __label__ = 2;
    break;
   case 2:
    var $pn_tr;
    var $1 = __ZNK11JSParseNode7getKindEv($pn_tr);
    if (($1 | 0) == 25) {
      __label__ = 3;
      break;
    } else if (($1 | 0) == 35) {
      __label__ = 5;
      break;
    } else if (($1 | 0) == 40) {
      __label__ = 7;
      break;
    } else if (($1 | 0) == 41) {
      __label__ = 12;
      break;
    } else if (($1 | 0) == 42) {
      __label__ = 19;
      break;
    } else if (($1 | 0) == 37) {
      __label__ = 22;
      break;
    } else if (($1 | 0) == 47) {
      __label__ = 31;
      break;
    } else if (($1 | 0) == 6 || ($1 | 0) == 80) {
      __label__ = 32;
      break;
    } else if (($1 | 0) == 53) {
      __label__ = 33;
      break;
    } else if (($1 | 0) == 54) {
      __label__ = 38;
      break;
    } else if (($1 | 0) == 81) {
      __label__ = 39;
      break;
    } else if (($1 | 0) == 43) {
      var $_0_ph = 2;
      __label__ = 41;
      break;
    } else if (($1 | 0) == 48 || ($1 | 0) == 56) {
      __label__ = 42;
      break;
    } else {
      var $_0 = 0;
      __label__ = 43;
      break;
    }
   case 3:
    if ((HEAP32[$pn_tr + 32 >> 2] | 0) == 0) {
      var $_0_ph = 0;
      __label__ = 41;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $pn_tr_idx2_val = HEAP32[$pn_tr + 36 >> 2];
    var $7 = __ZNK11JSParseNode4lastEv($pn_tr_idx2_val);
    var $pn_tr = $7;
    __label__ = 2;
    break;
   case 5:
    var $11 = HEAP32[$pn_tr + 40 >> 2];
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 43;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = HEAP32[$pn_tr + 36 >> 2];
    var $17 = __ZL14HasFinalReturnP11JSParseNode($16);
    var $18 = __ZL14HasFinalReturnP11JSParseNode($11);
    return $18 & $17;
   case 7:
    var $22 = HEAP32[$pn_tr + 32 >> 2];
    var $23 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($22, 33);
    if ($23) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $25 = __ZNK11JSParseNode4isOpE4JSOp($22, 67);
    if ($25) {
      var $_0 = 1;
      __label__ = 43;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $27 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($22, 30);
    if ($27) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $30 = $22 + 32 | 0;
    var $31 = (tempDoubleI32[0] = HEAP32[$30 >> 2], tempDoubleI32[1] = HEAP32[$30 + 4 >> 2], tempDoubleF64[0]);
    if ($31 != 0) {
      var $_0 = 1;
      __label__ = 43;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_0 = 0;
    __label__ = 43;
    break;
   case 12:
    var $35 = $pn_tr + 32 | 0;
    var $37 = HEAPU32[$pn_tr + 36 >> 2];
    var $38 = $37;
    var $39 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($38, 33);
    if ($39) {
      __label__ = 13;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 13:
    var $41 = __ZNK11JSParseNode4isOpE4JSOp($38, 66);
    if ($41) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $pn_tr = HEAP32[$35 >> 2];
    __label__ = 2;
    break;
   case 15:
    var $46 = __ZNK11JSParseNode4isOpE4JSOp($38, 67);
    if ($46) {
      var $_0_ph = 1;
      __label__ = 41;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $48 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($38, 30);
    if ($48) {
      __label__ = 17;
      break;
    } else {
      var $_0_ph = 0;
      __label__ = 41;
      break;
    }
   case 17:
    var $51 = $37 + 32 | 0;
    var $52 = (tempDoubleI32[0] = HEAP32[$51 >> 2], tempDoubleI32[1] = HEAP32[$51 + 4 >> 2], tempDoubleF64[0]);
    if ($52 == 0) {
      __label__ = 18;
      break;
    } else {
      var $_0_ph = 1;
      __label__ = 41;
      break;
    }
   case 18:
    var $pn_tr = HEAP32[$35 >> 2];
    __label__ = 2;
    break;
   case 19:
    var $59 = HEAP32[$pn_tr + 32 >> 2];
    var $60 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($59, 3);
    if ($60) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    if ((HEAP32[$59 + 36 >> 2] | 0) == 0) {
      var $_0 = 1;
      __label__ = 43;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $_0 = 0;
    __label__ = 43;
    break;
   case 22:
    var $68 = HEAP32[$pn_tr + 36 >> 2];
    var $69 = $68;
    var $70 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($69, 80);
    if ($70) {
      __label__ = 23;
      break;
    } else {
      var $pn2_0 = $69;
      __label__ = 24;
      break;
    }
   case 23:
    var $_idx_val = HEAP32[$68 + 36 >> 2];
    var $73 = __ZNK11JSParseNode4exprEv($_idx_val);
    var $pn2_0 = $73;
    __label__ = 24;
    break;
   case 24:
    var $pn2_0;
    var $pn2_14 = HEAP32[$pn2_0 + 32 >> 2];
    if (($pn2_14 | 0) == 0) {
      var $rv_0_lcssa = 1;
      var $hasDefault_0_lcssa = 0;
      __label__ = 30;
      break;
    } else {
      var $rv_05 = 1;
      var $hasDefault_06 = 0;
      var $pn2_17 = $pn2_14;
      __label__ = 25;
      break;
    }
   case 25:
    var $pn2_17;
    var $hasDefault_06;
    var $rv_05;
    var $77 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_17, 39);
    var $hasDefault_1 = $77 ? 1 : $hasDefault_06;
    var $79 = HEAP32[$pn2_17 + 36 >> 2];
    if ((HEAP32[$79 + 32 >> 2] | 0) == 0) {
      var $rv_1 = $rv_05;
      __label__ = 29;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $_idx1_val = HEAP32[$79 + 36 >> 2];
    var $85 = __ZNK11JSParseNode4lastEv($_idx1_val);
    var $86 = __ZL14HasFinalReturnP11JSParseNode($85);
    if (($86 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 27:
    if ((HEAP32[$pn2_17 + 24 >> 2] | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      var $rv_1 = $rv_05;
      __label__ = 29;
      break;
    }
   case 28:
    var $rv_1 = $86 & $rv_05;
    __label__ = 29;
    break;
   case 29:
    var $rv_1;
    var $pn2_1 = HEAP32[$pn2_17 + 24 >> 2];
    if (($rv_1 | 0) == 0 | ($pn2_1 | 0) == 0) {
      var $rv_0_lcssa = $rv_1;
      var $hasDefault_0_lcssa = $hasDefault_1;
      __label__ = 30;
      break;
    } else {
      var $rv_05 = $rv_1;
      var $hasDefault_06 = $hasDefault_1;
      var $pn2_17 = $pn2_1;
      __label__ = 25;
      break;
    }
   case 30:
    var $hasDefault_0_lcssa;
    var $rv_0_lcssa;
    var $_0 = $hasDefault_0_lcssa & $rv_0_lcssa;
    __label__ = 43;
    break;
   case 31:
    var $pn_tr = HEAP32[$pn_tr + 36 >> 2];
    __label__ = 2;
    break;
   case 32:
    var $pn_tr_idx_val = HEAP32[$pn_tr + 36 >> 2];
    var $103 = __ZNK11JSParseNode4exprEv($pn_tr_idx_val);
    var $pn_tr = $103;
    __label__ = 2;
    break;
   case 33:
    var $107 = HEAP32[$pn_tr + 40 >> 2];
    if (($107 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $110 = __ZL14HasFinalReturnP11JSParseNode($107);
    if (($110 | 0) == 1) {
      var $_0 = 1;
      __label__ = 43;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $114 = HEAP32[$pn_tr + 32 >> 2];
    var $115 = __ZL14HasFinalReturnP11JSParseNode($114);
    var $117 = HEAP32[$pn_tr + 36 >> 2];
    if (($117 | 0) == 0) {
      var $_0 = $115;
      __label__ = 43;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $pn2_21 = HEAP32[$117 + 32 >> 2];
    if (($pn2_21 | 0) == 0) {
      var $_0 = $115;
      __label__ = 43;
      break;
    } else {
      var $rv_22 = $115;
      var $pn2_23 = $pn2_21;
      __label__ = 37;
      break;
    }
   case 37:
    var $pn2_23;
    var $rv_22;
    var $122 = __ZL14HasFinalReturnP11JSParseNode($pn2_23);
    var $123 = $122 & $rv_22;
    var $pn2_2 = HEAP32[$pn2_23 + 24 >> 2];
    if (($pn2_2 | 0) == 0) {
      var $_0 = $123;
      __label__ = 43;
      break;
    } else {
      var $rv_22 = $123;
      var $pn2_23 = $pn2_2;
      __label__ = 37;
      break;
    }
   case 38:
    var $pn_tr = HEAP32[$pn_tr + 40 >> 2];
    __label__ = 2;
    break;
   case 39:
    var $131 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn_tr, 2);
    if ($131) {
      __label__ = 40;
      break;
    } else {
      var $_0_ph = 0;
      __label__ = 41;
      break;
    }
   case 40:
    var $pn_tr = HEAP32[$pn_tr + 36 >> 2];
    __label__ = 2;
    break;
   case 41:
    var $_0_ph;
    var $_0 = $_0_ph;
    __label__ = 43;
    break;
   case 42:
    var $_0 = 1;
    __label__ = 43;
    break;
   case 43:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14HasFinalReturnP11JSParseNode["X"] = 1;

function __ZN2js8CompilerD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6ParserD2Ev($1);
  return;
}

function __ZN2js11GlobalScopeD2Ev($this) {
  var $1 = $this + 216 | 0;
  __ZN2js9InlineMapIP6JSAtomjLj24EED1Ev($1);
  var $2 = $this + 8 | 0;
  __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEED1Ev($2);
  return;
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11GlobalScopeC2EP9JSContextP8JSObjectP15JSCodeGenerator($this, $cx, $globalObj, $cg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = $globalObj;
  HEAP32[$this + 4 >> 2] = $cg;
  var $4 = $this + 8 | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEEC1ES3_($4, $_0_val);
  var $5 = $this + 216 | 0;
  __ZN2js9InlineMapIP6JSAtomjLj24EEC1EP9JSContext($5, $cx);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEEC1ES3_($this, $ap_01) {
  __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEEC2ES3_($this, $ap_01);
  return;
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEEC2ES3_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj192EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 16;
  return;
}

function __ZN2js11OffTheBooks4new_INS_12ParseMapPoolEP9JSContextEEPT_T0_($p1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_malloc2912();
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js12ParseMapPoolC1EP9JSContext($4, $p1);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ParseMapPoolC1EP9JSContext($this, $cx) {
  __ZN2js12ParseMapPoolC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js12ParseMapPoolC2EP9JSContext($this, $cx) {
  var $1 = $this | 0;
  __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEEC1ES2_($1);
  var $2 = $this + 140 | 0;
  __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEEC1ES2_($2);
  HEAP32[$this + 280 >> 2] = $cx;
  return;
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEEC1ES2_($this) {
  __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEEC2ES2_($this);
  return;
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEEC2ES2_($this) {
  var $1 = $this | 0;
  var $2 = $this + 12 | 0;
  var $3 = __ZN7mozilla14AlignedStorageILj128EE4addrEv($2);
  HEAP32[$1 >> 2] = $3;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 32;
  return;
}

function __ZL8pm_startP9JSContextjPN2JS5ValueE($cx, $0, $vp) {
  var $2 = __ZL13GetPMFromThisP9JSContextPN2JS5ValueE($cx, $vp);
  return ($2 | 0) != 0 & 1;
}

function __ZL7pm_stopP9JSContextjPN2JS5ValueE($cx, $0, $vp) {
  var $2 = __ZL13GetPMFromThisP9JSContextPN2JS5ValueE($cx, $vp);
  return ($2 | 0) != 0 & 1;
}

function __ZL8pm_resetP9JSContextjPN2JS5ValueE($cx, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL13GetPMFromThisP9JSContextPN2JS5ValueE($cx, $vp);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS15PerfMeasurement5resetEv($2);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL22pm_canMeasureSomethingP9JSContextjPN2JS5ValueE($cx, $0, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __stackBase__;
    var $3 = __ZL13GetPMFromThisP9JSContextPN2JS5ValueE($cx, $vp);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _BOOLEAN_TO_JSVAL3010($2);
    var $6 = $2 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $vp | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11pm_finalizeP9JSContextP8JSObject($cx, $obj) {
  var $_idx_val = HEAP32[$obj + 24 >> 2];
  var $2 = _JS_GetPrivate($_idx_val);
  var $3 = $2;
  __ZN9JSContext7delete_IN2JS15PerfMeasurementEEEvPT_($3);
  return;
}

function __ZN2JS23RegisterPerfMeasurementEP9JSContextP8JSObject($cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $cx;
    var $3 = $global;
    var $4 = _JS_InitClass($2, $3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = _JS_GetConstructor($2, $4);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx = $1 | 0;
    var $c_0 = __ZL9pm_consts | 0;
    __label__ = 4;
    break;
   case 4:
    var $c_0;
    var $11 = HEAP32[$c_0 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = HEAP32[$c_0 + 4 >> 2];
    _INT_TO_JSVAL2997($1, $15);
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $16 = _JS_DefineProperty($2, $8, $11, $_idx_val$0, $_idx_val$1, 10, 12, 7);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $c_0 = $c_0 + 8 | 0;
    __label__ = 4;
    break;
   case 7:
    var $21 = _JS_FreezeObject($2, $4);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $24 = _JS_FreezeObject($2, $8);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_0 = $5;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12pm_constructP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $mask = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = $vp + 16 | 0;
    var $3 = $cx;
    var $4 = _JS_ConvertArguments($3, $argc, $2, STRING_TABLE.__str302996 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $mask, tempInt));
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $7 = _JS_NewObjectForConstructor($3, $vp_idx_val$0, $vp_idx_val$1);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = _JS_FreezeObject($3, $7);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = __ZN9JSContext4new_IN2JS15PerfMeasurementENS2_9EventMaskEEEPT_T0_($cx);
    if (($14 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    _JS_ReportOutOfMemory($3);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $18 = $14;
    _JS_SetPrivate($7, $18);
    _OBJECT_TO_JSVAL3006($1, $8);
    var $19 = $1 | 0;
    var $20$0 = HEAP32[$19 >> 2];
    var $20$1 = HEAP32[$19 + 4 >> 2];
    HEAP32[$vp_idx >> 2] = $20$0;
    HEAP32[$vp_idx + 4 >> 2] = $20$1;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _INT_TO_JSVAL2997($agg_result, $i) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _INT32_TO_JSVAL_IMPL3005($1, $i);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout3004($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function _JSVAL_IS_PRIMITIVE2998($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE3002($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_PRIMITIVE_IMPL3003($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_OBJECT2999($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE3002($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_OBJECT_IMPL3001($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL17pm_get_cpu_cyclesP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str182984 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 8 | 0;
    var $7 = HEAP32[$5 >> 2] + HEAP32[$5 + 4 >> 2] * 4294967296;
    _JS_NewNumberValue($7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19pm_get_instructionsP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str192985 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 16 | 0;
    var $7 = HEAP32[$5 >> 2] + HEAP32[$5 + 4 >> 2] * 4294967296;
    _JS_NewNumberValue($7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23pm_get_cache_referencesP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str202986 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 24 | 0;
    var $7 = HEAP32[$5 >> 2] + HEAP32[$5 + 4 >> 2] * 4294967296;
    _JS_NewNumberValue($7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19pm_get_cache_missesP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str212987 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 32 | 0;
    var $7 = HEAP32[$5 >> 2] + HEAP32[$5 + 4 >> 2] * 4294967296;
    _JS_NewNumberValue($7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26pm_get_branch_instructionsP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str222988 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 40 | 0;
    var $7 = HEAP32[$5 >> 2] + HEAP32[$5 + 4 >> 2] * 4294967296;
    _JS_NewNumberValue($7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _OBJECT_TO_JSVAL_IMPL3007($agg_result, $obj) {
  HEAP32[$agg_result + 4 >> 2] = -121;
  HEAP32[$agg_result >> 2] = $obj;
  return;
}

function _BOOLEAN_TO_JSVAL_IMPL3011($agg_result) {
  HEAP32[$agg_result + 4 >> 2] = -125;
  HEAP32[$agg_result >> 2] = 0;
  return;
}

function __ZL20pm_get_branch_missesP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str232989 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 48 | 0;
    var $7 = HEAP32[$5 >> 2] + HEAP32[$5 + 4 >> 2] * 4294967296;
    _JS_NewNumberValue($7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17pm_get_bus_cyclesP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str242990 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 56 | 0;
    var $7 = HEAP32[$5 >> 2] + HEAP32[$5 + 4 >> 2] * 4294967296;
    _JS_NewNumberValue($7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18pm_get_page_faultsP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str252991 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 64 | 0;
    var $7 = HEAP32[$5 >> 2] + HEAP32[$5 + 4 >> 2] * 4294967296;
    _JS_NewNumberValue($7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24pm_get_major_page_faultsP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str262992 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 72 | 0;
    var $7 = HEAP32[$5 >> 2] + HEAP32[$5 + 4 >> 2] * 4294967296;
    _JS_NewNumberValue($7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23pm_get_context_switchesP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str272993 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 80 | 0;
    var $7 = HEAP32[$5 >> 2] + HEAP32[$5 + 4 >> 2] * 4294967296;
    _JS_NewNumberValue($7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21pm_get_cpu_migrationsP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str282994 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 88 | 0;
    var $7 = HEAP32[$5 >> 2] + HEAP32[$5 + 4 >> 2] * 4294967296;
    _JS_NewNumberValue($7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21pm_get_eventsMeasuredP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str292995 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAPU32[$2 + 4 >> 2] >>> 0;
    _JS_NewNumberValue($7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, $fname) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = $obj;
    var $3 = _JS_GetInstancePrivate($1, $2, 0);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = $3;
    __label__ = 4;
    break;
   case 3:
    var $8 = HEAP32[__ZL8pm_class >> 2];
    var $_idx_val = HEAP32[$obj + 4 >> 2];
    var $10 = _JS_GetClass($_idx_val);
    var $12 = HEAP32[$10 >> 2];
    _JS_ReportErrorNumber($1, 4, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $8, HEAP32[tempInt + 4 >> 2] = $fname, HEAP32[tempInt + 8 >> 2] = $12, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext4new_IN2JS15PerfMeasurementENS2_9EventMaskEEEPT_T0_($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZN9JSContext7malloc_Ej($1, 96);
    if (($2 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN2JS15PerfMeasurementC2ENS0_9EventMaskE($5);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _OBJECT_TO_JSVAL3006($agg_result, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL_IMPL3007($1, $obj);
    var $_0 = $1 | 0;
    var $_0_val$0 = HEAP32[$_0 >> 2];
    var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
    __ZL13IMPL_TO_JSVAL12jsval_layout3004($agg_result, $_0_val$0, $_0_val$1);
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $6 = $agg_result | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext7delete_IN2JS15PerfMeasurementEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $p;
    __ZN9JSContext5free_EPv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13GetPMFromThisP9JSContextPN2JS5ValueE($cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    _JS_THIS($1, $cx, $vp);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $2 = _JSVAL_TO_OBJECT2999($_idx_val$0, $_idx_val$1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = $2;
    var $8 = _JS_GetInstancePrivate($6, $7, $5);
    var $_0 = $8;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _BOOLEAN_TO_JSVAL3010($agg_result) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BOOLEAN_TO_JSVAL_IMPL3011($1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout3004($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function _JS_THIS($agg_result, $cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = _JSVAL_IS_PRIMITIVE2998($2$0, $2$1);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx;
    _JS_ComputeThis($agg_result, $6, $vp);
    __label__ = 4;
    break;
   case 3:
    var $8$0 = HEAP32[$1 >> 2];
    var $8$1 = HEAP32[$1 + 4 >> 2];
    var $9 = $agg_result | 0;
    HEAP32[$9 >> 2] = $8$0;
    HEAP32[$9 + 4 >> 2] = $8$1;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9dosprintfP15SprintfStateStrPKcPc($ss, $fmt, $ap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 200;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $u = __stackBase__;
    var $rv = __stackBase__ + 8;
    var $pattern = __stackBase__ + 172;
    var $utf8buf = __stackBase__ + 192;
    var $1 = __stackBase__ + 12 | 0;
    var $2 = __ZL13BuildArgArrayPKcPcPiP11NumArgState($fmt, $ap, $rv, $1);
    var $3 = HEAPU32[$rv >> 2];
    if (($3 | 0) < 0) {
      var $_0 = $3;
      __label__ = 77;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $ss | 0;
    var $6 = ($2 | 0) != 0;
    var $7 = $u;
    var $8 = $u | 0;
    var $9 = $u;
    var $10 = $pattern | 0;
    var $11 = $pattern + 1 | 0;
    var $12 = $u;
    var $13 = $utf8buf | 0;
    var $14 = $u;
    var $15 = $u;
    var $16 = $u;
    var $17 = $u;
    var $18 = $ss + 8 | 0;
    var $19 = $ss + 4 | 0;
    var $dolPt_0 = 0;
    var $_05 = $fmt;
    var $_06 = $ap;
    var $_pr = $3;
    __label__ = 3;
    break;
   case 3:
    var $_pr;
    var $_06;
    var $_05;
    var $dolPt_0;
    var $20 = $_05 + 1 | 0;
    var $21 = HEAP8[$_05];
    if ($21 << 24 >> 24 == 37) {
      __label__ = 5;
      break;
    } else if ($21 << 24 >> 24 == 0) {
      __label__ = 75;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $23 = HEAP32[$5 >> 2];
    var $24 = FUNCTION_TABLE[$23]($ss, $_05, 1);
    HEAP32[$rv >> 2] = $24;
    if (($24 | 0) < 0) {
      var $_0 = $24;
      __label__ = 77;
      break;
    } else {
      var $dolPt_0 = $dolPt_0;
      var $_05 = $20;
      var $_06 = $_06;
      var $_pr = $24;
      __label__ = 3;
      break;
    }
   case 5:
    var $27 = $_05 + 2 | 0;
    var $28 = HEAP8[$20];
    if ($28 << 24 >> 24 == 37) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $31 = HEAP32[$5 >> 2];
    var $32 = FUNCTION_TABLE[$31]($ss, $20, 1);
    HEAP32[$rv >> 2] = $32;
    if (($32 | 0) < 0) {
      var $_0 = $32;
      __label__ = 77;
      break;
    } else {
      var $dolPt_0 = $dolPt_0;
      var $_05 = $27;
      var $_06 = $_06;
      var $_pr = $32;
      __label__ = 3;
      break;
    }
   case 7:
    if ($6) {
      var $_1 = $27;
      var $c_0 = $28;
      var $i_0 = 0;
      __label__ = 8;
      break;
    } else {
      var $dolPt_1_ph = $dolPt_0;
      var $_2_ph = $27;
      var $_17_ph = $_06;
      var $c_1_ph = $28;
      __label__ = 14;
      break;
    }
   case 8:
    var $i_0;
    var $c_0;
    var $_1;
    if ($c_0 << 24 >> 24 == 36 || $c_0 << 24 >> 24 == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $39 = $i_0 * 10 - 48 + ($c_0 << 24 >> 24) | 0;
    var $41 = HEAP8[$_1];
    var $_1 = $_1 + 1 | 0;
    var $c_0 = $41;
    var $i_0 = $39;
    __label__ = 8;
    break;
   case 10:
    var $43 = $i_0 - 1 | 0;
    if ((HEAP32[$2 + ($43 << 3) >> 2] | 0) == 20) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    if (($2 | 0) == ($1 | 0)) {
      var $_0 = -1;
      __label__ = 77;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $50 = $2;
    __ZN2js10Foreground5free_EPv($50);
    var $_0 = -1;
    __label__ = 77;
    break;
   case 13:
    var $dolPt_1_ph = $_1;
    var $_2_ph = $_1 + 1 | 0;
    var $_17_ph = HEAP32[$2 + ($43 << 3) + 4 >> 2];
    var $c_1_ph = HEAP8[$_1];
    __label__ = 14;
    break;
   case 14:
    var $c_1_ph;
    var $_17_ph;
    var $_2_ph;
    var $dolPt_1_ph;
    var $_2 = $_2_ph;
    var $c_1 = $c_1_ph;
    var $flags_0 = 0;
    __label__ = 15;
    break;
   case 15:
    var $flags_0;
    var $c_1;
    var $_2;
    var $57 = $c_1 << 24 >> 24 == 45;
    if ($c_1 << 24 >> 24 == 48 || $c_1 << 24 >> 24 == 45 || $c_1 << 24 >> 24 == 43 || $c_1 << 24 >> 24 == 32) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $_flags_0 = $57 & 1 | $flags_0;
    var $flags_2 = $c_1 << 24 >> 24 == 43 ? $_flags_0 | 2 : $_flags_0;
    var $_flags_2 = $c_1 << 24 >> 24 == 32 ? $flags_2 | 4 : $flags_2;
    var $flags_4 = $c_1 << 24 >> 24 == 48 ? $_flags_2 | 8 : $_flags_2;
    var $66 = HEAP8[$_2];
    var $_2 = $_2 + 1 | 0;
    var $c_1 = $66;
    var $flags_0 = $flags_4;
    __label__ = 15;
    break;
   case 17:
    var $flags_0_ = ($flags_0 & 2 | 0) == 0 ? $flags_0 : $flags_0 & -5;
    var $flags_6 = ($flags_0_ & 1 | 0) == 0 ? $flags_0_ : $flags_0_ & -9;
    if ($c_1 << 24 >> 24 == 42) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if (($c_1 - 48 & 255 & 255) < 10) {
      var $width_044 = 0;
      var $c_245 = $c_1;
      var $_346 = $_2;
      __label__ = 20;
      break;
    } else {
      var $_4 = $_2;
      var $_28 = $_17_ph;
      var $c_3 = $c_1;
      var $width_1 = 0;
      __label__ = 21;
      break;
    }
   case 19:
    var $_4 = $_2 + 1 | 0;
    var $_28 = $_17_ph + 4 | 0;
    var $c_3 = HEAP8[$_2];
    var $width_1 = HEAP32[$_17_ph >> 2];
    __label__ = 21;
    break;
   case 20:
    var $_346;
    var $c_245;
    var $width_044;
    var $85 = $width_044 * 10 - 48 + ($c_245 << 24 >> 24) | 0;
    var $86 = $_346 + 1 | 0;
    var $87 = HEAPU8[$_346];
    if (($87 - 48 & 255 & 255) < 10) {
      var $width_044 = $85;
      var $c_245 = $87;
      var $_346 = $86;
      __label__ = 20;
      break;
    } else {
      var $_4 = $86;
      var $_28 = $_17_ph;
      var $c_3 = $87;
      var $width_1 = $85;
      __label__ = 21;
      break;
    }
   case 21:
    var $width_1;
    var $c_3;
    var $_28;
    var $_4;
    if ($c_3 << 24 >> 24 == 46) {
      __label__ = 22;
      break;
    } else {
      var $_6 = $_4;
      var $_39 = $_28;
      var $c_5 = $c_3;
      var $prec_1 = -1;
      __label__ = 26;
      break;
    }
   case 22:
    var $91 = $_4 + 1 | 0;
    var $92 = HEAPU8[$_4];
    if ($92 << 24 >> 24 == 42) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    if (($92 - 48 & 255 & 255) < 10) {
      var $prec_037 = 0;
      var $c_438 = $92;
      var $_539 = $91;
      __label__ = 25;
      break;
    } else {
      var $_6 = $91;
      var $_39 = $_28;
      var $c_5 = $92;
      var $prec_1 = 0;
      __label__ = 26;
      break;
    }
   case 24:
    var $_6 = $_4 + 2 | 0;
    var $_39 = $_28 + 4 | 0;
    var $c_5 = HEAP8[$91];
    var $prec_1 = HEAP32[$_28 >> 2];
    __label__ = 26;
    break;
   case 25:
    var $_539;
    var $c_438;
    var $prec_037;
    var $104 = $prec_037 * 10 - 48 + ($c_438 << 24 >> 24) | 0;
    var $105 = $_539 + 1 | 0;
    var $106 = HEAPU8[$_539];
    if (($106 - 48 & 255 & 255) < 10) {
      var $prec_037 = $104;
      var $c_438 = $106;
      var $_539 = $105;
      __label__ = 25;
      break;
    } else {
      var $_6 = $105;
      var $_39 = $_28;
      var $c_5 = $106;
      var $prec_1 = $104;
      __label__ = 26;
      break;
    }
   case 26:
    var $prec_1;
    var $c_5;
    var $_39;
    var $_6;
    if ($c_5 << 24 >> 24 == 104) {
      __label__ = 27;
      break;
    } else if ($c_5 << 24 >> 24 == 76) {
      __label__ = 28;
      break;
    } else if ($c_5 << 24 >> 24 == 108) {
      __label__ = 29;
      break;
    } else {
      var $_7 = $_6;
      var $c_6 = $c_5;
      var $type_0 = 2;
      __label__ = 31;
      break;
    }
   case 27:
    var $_7 = $_6 + 1 | 0;
    var $c_6 = HEAP8[$_6];
    var $type_0 = 0;
    __label__ = 31;
    break;
   case 28:
    var $_7 = $_6 + 1 | 0;
    var $c_6 = HEAP8[$_6];
    var $type_0 = 6;
    __label__ = 31;
    break;
   case 29:
    var $115 = $_6 + 1 | 0;
    var $116 = HEAP8[$_6];
    if ($116 << 24 >> 24 == 108) {
      __label__ = 30;
      break;
    } else {
      var $_7 = $115;
      var $c_6 = $116;
      var $type_0 = 4;
      __label__ = 31;
      break;
    }
   case 30:
    var $_7 = $_6 + 2 | 0;
    var $c_6 = HEAP8[$115];
    var $type_0 = 6;
    __label__ = 31;
    break;
   case 31:
    var $type_0;
    var $c_6;
    var $_7;
    var $122 = $c_6 << 24 >> 24;
    if (($122 | 0) == 111) {
      __label__ = 32;
      break;
    } else if (($122 | 0) == 117) {
      __label__ = 33;
      break;
    } else if (($122 | 0) == 120) {
      __label__ = 34;
      break;
    } else if (($122 | 0) == 88) {
      __label__ = 35;
      break;
    } else if (($122 | 0) == 100 || ($122 | 0) == 105) {
      var $radix_0 = 10;
      var $type_1 = $type_0;
      var $hexp_0 = STRING_TABLE.__str62084 | 0;
      __label__ = 36;
      break;
    } else if (($122 | 0) == 112) {
      var $hexp_021 = STRING_TABLE.__str62084 | 0;
      var $radix_025 = 16;
      __label__ = 45;
      break;
    } else if (($122 | 0) == 101 || ($122 | 0) == 69 || ($122 | 0) == 102 || ($122 | 0) == 103) {
      __label__ = 51;
      break;
    } else if (($122 | 0) == 99) {
      __label__ = 56;
      break;
    } else if (($122 | 0) == 115) {
      __label__ = 67;
      break;
    } else if (($122 | 0) == 110) {
      __label__ = 71;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 32:
    var $radix_0 = 8;
    var $type_1 = $type_0 | 1;
    var $hexp_0 = STRING_TABLE.__str62084 | 0;
    __label__ = 36;
    break;
   case 33:
    var $radix_0 = 10;
    var $type_1 = $type_0 | 1;
    var $hexp_0 = STRING_TABLE.__str62084 | 0;
    __label__ = 36;
    break;
   case 34:
    var $radix_0 = 16;
    var $type_1 = $type_0 | 1;
    var $hexp_0 = STRING_TABLE.__str62084 | 0;
    __label__ = 36;
    break;
   case 35:
    var $radix_0 = 16;
    var $type_1 = $type_0 | 1;
    var $hexp_0 = STRING_TABLE.__ZZL6EncodeP9JSContextP8JSStringPKtS4_PN2JS5ValueEE9HexDigits | 0;
    __label__ = 36;
    break;
   case 36:
    var $hexp_0;
    var $type_1;
    var $radix_0;
    if (($type_1 | 0) == 0) {
      __label__ = 37;
      break;
    } else if (($type_1 | 0) == 1) {
      __label__ = 39;
      break;
    } else if (($type_1 | 0) == 2) {
      __label__ = 40;
      break;
    } else if (($type_1 | 0) == 3) {
      __label__ = 42;
      break;
    } else if (($type_1 | 0) == 4) {
      __label__ = 43;
      break;
    } else if (($type_1 | 0) == 5) {
      var $hexp_021 = $hexp_0;
      var $radix_025 = $radix_0;
      __label__ = 45;
      break;
    } else if (($type_1 | 0) == 6) {
      __label__ = 47;
      break;
    } else if (($type_1 | 0) == 7) {
      __label__ = 49;
      break;
    } else {
      var $dolPt_0 = $dolPt_1_ph;
      var $_05 = $_7;
      var $_06 = $_39;
      var $_pr = $_pr;
      __label__ = 3;
      break;
    }
   case 37:
    var $134 = $_39 + 4 | 0;
    var $135 = HEAPU32[$_39 >> 2];
    HEAP32[$7 >> 2] = $135;
    if (($135 | 0) < 0) {
      __label__ = 38;
      break;
    } else {
      var $_410 = $134;
      var $flags_7 = $flags_6;
      var $hexp_020 = $hexp_0;
      var $type_122 = 0;
      var $radix_024 = $radix_0;
      var $169 = $135;
      __label__ = 46;
      break;
    }
   case 38:
    var $138 = -$135 | 0;
    HEAP32[$7 >> 2] = $138;
    var $_410 = $134;
    var $flags_7 = $flags_6 | 16;
    var $hexp_020 = $hexp_0;
    var $type_122 = $type_1;
    var $radix_024 = $radix_0;
    var $169 = $138;
    __label__ = 46;
    break;
   case 39:
    var $144 = HEAP32[$_39 >> 2] & 65535;
    HEAP32[$7 >> 2] = $144;
    var $_410 = $_39 + 4 | 0;
    var $flags_7 = $flags_6;
    var $hexp_020 = $hexp_0;
    var $type_122 = 1;
    var $radix_024 = $radix_0;
    var $169 = $144;
    __label__ = 46;
    break;
   case 40:
    var $147 = $_39 + 4 | 0;
    var $148 = HEAP32[$_39 >> 2];
    HEAP32[$7 >> 2] = $148;
    if (($148 | 0) < 0) {
      __label__ = 41;
      break;
    } else {
      var $_410 = $147;
      var $flags_7 = $flags_6;
      var $hexp_020 = $hexp_0;
      var $type_122 = 2;
      var $radix_024 = $radix_0;
      var $169 = $148;
      __label__ = 46;
      break;
    }
   case 41:
    var $151 = -$148 | 0;
    HEAP32[$7 >> 2] = $151;
    var $_410 = $147;
    var $flags_7 = $flags_6 | 16;
    var $hexp_020 = $hexp_0;
    var $type_122 = $type_1;
    var $radix_024 = $radix_0;
    var $169 = $151;
    __label__ = 46;
    break;
   case 42:
    var $156 = HEAP32[$_39 >> 2];
    HEAP32[$7 >> 2] = $156;
    var $_410 = $_39 + 4 | 0;
    var $flags_7 = $flags_6;
    var $hexp_020 = $hexp_0;
    var $type_122 = 3;
    var $radix_024 = $radix_0;
    var $169 = $156;
    __label__ = 46;
    break;
   case 43:
    var $159 = $_39 + 4 | 0;
    var $160 = HEAP32[$_39 >> 2];
    HEAP32[$7 >> 2] = $160;
    if (($160 | 0) < 0) {
      __label__ = 44;
      break;
    } else {
      var $_410 = $159;
      var $flags_7 = $flags_6;
      var $hexp_020 = $hexp_0;
      var $type_122 = 4;
      var $radix_024 = $radix_0;
      var $169 = $160;
      __label__ = 46;
      break;
    }
   case 44:
    var $163 = -$160 | 0;
    HEAP32[$7 >> 2] = $163;
    var $_410 = $159;
    var $flags_7 = $flags_6 | 16;
    var $hexp_020 = $hexp_0;
    var $type_122 = $type_1;
    var $radix_024 = $radix_0;
    var $169 = $163;
    __label__ = 46;
    break;
   case 45:
    var $radix_025;
    var $hexp_021;
    var $167 = HEAP32[$_39 >> 2];
    HEAP32[$7 >> 2] = $167;
    var $_410 = $_39 + 4 | 0;
    var $flags_7 = $flags_6;
    var $hexp_020 = $hexp_021;
    var $type_122 = 5;
    var $radix_024 = $radix_025;
    var $169 = $167;
    __label__ = 46;
    break;
   case 46:
    var $169;
    var $radix_024;
    var $type_122;
    var $hexp_020;
    var $flags_7;
    var $_410;
    var $170 = __ZL5cvt_lP15SprintfStateStrliiiiiPKc($ss, $169, $width_1, $prec_1, $radix_024, $type_122, $flags_7, $hexp_020);
    HEAP32[$rv >> 2] = $170;
    if (($170 | 0) < 0) {
      var $_0 = $170;
      __label__ = 77;
      break;
    } else {
      var $dolPt_0 = $dolPt_1_ph;
      var $_05 = $_7;
      var $_06 = $_410;
      var $_pr = $170;
      __label__ = 3;
      break;
    }
   case 47:
    var $173 = $_39;
    var $174 = $_39 + 8 | 0;
    var $st$2$0 = $173 | 0;
    var $175$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $173 + 4 | 0;
    var $175$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $8 | 0;
    HEAP32[$st$6$0 >> 2] = $175$0;
    var $st$6$1 = $8 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $175$1;
    var $$emscripten$temp$0$1 = 0;
    if (($175$1 | 0) < ($$emscripten$temp$0$1 | 0) || ($175$1 | 0) == ($$emscripten$temp$0$1 | 0) && $175$0 >>> 0 < 0 >>> 0) {
      __label__ = 48;
      break;
    } else {
      var $_511 = $174;
      var $flags_8 = $flags_6;
      var $185$1 = $175$1;
      var $185$0 = $175$0;
      __label__ = 50;
      break;
    }
   case 48:
    var $178$0 = (i64Math.subtract(0, 0, $175$0, $175$1), i64Math.result[0]);
    var $178$1 = i64Math.result[1];
    HEAP32[$8 >> 2] = $178$0;
    HEAP32[$8 + 4 >> 2] = $178$1;
    var $_511 = $174;
    var $flags_8 = $flags_6 | 16;
    var $185$1 = $178$1;
    var $185$0 = $178$0;
    __label__ = 50;
    break;
   case 49:
    var $181 = $_39;
    var $st$2$0 = $181 | 0;
    var $183$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $181 + 4 | 0;
    var $183$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $8 | 0;
    HEAP32[$st$6$0 >> 2] = $183$0;
    var $st$6$1 = $8 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $183$1;
    var $_511 = $_39 + 8 | 0;
    var $flags_8 = $flags_6;
    var $185$1 = $183$1;
    var $185$0 = $183$0;
    __label__ = 50;
    break;
   case 50:
    var $185$0;
    var $185$1;
    var $flags_8;
    var $_511;
    var $186 = __ZL6cvt_llP15SprintfStateStrxiiiiiPKc($ss, $185$0, $185$1, $width_1, $prec_1, $radix_0, $type_1, $flags_8, $hexp_0);
    HEAP32[$rv >> 2] = $186;
    if (($186 | 0) < 0) {
      var $_0 = $186;
      __label__ = 77;
      break;
    } else {
      var $dolPt_0 = $dolPt_1_ph;
      var $_05 = $_7;
      var $_06 = $_511;
      var $_pr = $186;
      __label__ = 3;
      break;
    }
   case 51:
    var $189 = $_39;
    var $190 = $_39 + 8 | 0;
    var $191 = (tempDoubleI32[0] = HEAP32[$189 >> 2], tempDoubleI32[1] = HEAP32[$189 + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $191, HEAP32[$9 >> 2] = tempDoubleI32[0], HEAP32[$9 + 4 >> 2] = tempDoubleI32[1];
    if ($6) {
      __label__ = 52;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 52:
    var $195 = $_7 - $dolPt_1_ph | 0;
    if (($195 | 0) < 20) {
      __label__ = 53;
      break;
    } else {
      var $203 = $_pr;
      __label__ = 55;
      break;
    }
   case 53:
    HEAP8[$10] = 37;
    _memcpy($11, $dolPt_1_ph, $195, 1);
    var $199 = $195 + ($pattern + 1) | 0;
    var $200 = __ZL5cvt_fP15SprintfStateStrdPKcS2_($ss, $191, $10, $199);
    HEAP32[$rv >> 2] = $200;
    var $203 = $200;
    __label__ = 55;
    break;
   case 54:
    var $202 = __ZL5cvt_fP15SprintfStateStrdPKcS2_($ss, $191, $_05, $_7);
    HEAP32[$rv >> 2] = $202;
    var $203 = $202;
    __label__ = 55;
    break;
   case 55:
    var $203;
    if (($203 | 0) < 0) {
      var $_0 = $203;
      __label__ = 77;
      break;
    } else {
      var $dolPt_0 = $dolPt_1_ph;
      var $_05 = $_7;
      var $_06 = $190;
      var $_pr = $203;
      __label__ = 3;
      break;
    }
   case 56:
    var $207 = ($flags_6 & 1 | 0) == 0;
    if ($207) {
      var $width_2 = $width_1;
      var $_pr277 = $_pr;
      __label__ = 57;
      break;
    } else {
      var $width_3 = $width_1;
      var $_pr27 = $_pr;
      __label__ = 59;
      break;
    }
   case 57:
    var $_pr277;
    var $width_2;
    var $208 = $width_2 - 1 | 0;
    if (($width_2 | 0) > 1) {
      __label__ = 58;
      break;
    } else {
      var $width_3 = $208;
      var $_pr27 = $_pr277;
      __label__ = 59;
      break;
    }
   case 58:
    var $211 = HEAP32[$5 >> 2];
    var $212 = FUNCTION_TABLE[$211]($ss, STRING_TABLE.__str284577 | 0, 1);
    HEAP32[$rv >> 2] = $212;
    if (($212 | 0) < 0) {
      var $_0 = $212;
      __label__ = 77;
      break;
    } else {
      var $width_2 = $208;
      var $_pr277 = $212;
      __label__ = 57;
      break;
    }
   case 59:
    var $_pr27;
    var $width_3;
    if (($type_0 | 0) == 0) {
      __label__ = 60;
      break;
    } else if (($type_0 | 0) == 2) {
      __label__ = 62;
      break;
    } else {
      var $_612 = $_39;
      var $231 = $_pr27;
      __label__ = 63;
      break;
    }
   case 60:
    if (HEAPU8[_js_CStringsAreUTF8_b]) {
      __label__ = 61;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 61:
    var $217 = $_39 + 4 | 0;
    var $218 = HEAP32[$_39 >> 2];
    HEAP16[$12 >> 1] = $218 & 65535;
    var $220 = $218 & 65535;
    var $221 = __Z20js_OneUcs4ToUtf8CharPhj($13, $220);
    var $222 = HEAP32[$5 >> 2];
    var $223 = FUNCTION_TABLE[$222]($ss, $13, $221);
    HEAP32[$rv >> 2] = $223;
    var $_612 = $217;
    var $231 = $223;
    __label__ = 63;
    break;
   case 62:
    var $226 = $_39 + 4 | 0;
    HEAP8[$14] = HEAP32[$_39 >> 2] & 255;
    var $229 = HEAP32[$5 >> 2];
    var $230 = FUNCTION_TABLE[$229]($ss, $14, 1);
    HEAP32[$rv >> 2] = $230;
    var $_612 = $226;
    var $231 = $230;
    __label__ = 63;
    break;
   case 63:
    var $231;
    var $_612;
    if (($231 | 0) < 0) {
      var $_0 = $231;
      __label__ = 77;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    if ($207) {
      var $dolPt_0 = $dolPt_1_ph;
      var $_05 = $_7;
      var $_06 = $_612;
      var $_pr = $231;
      __label__ = 3;
      break;
    } else {
      var $width_4 = $width_3;
      var $_pr5 = $231;
      __label__ = 65;
      break;
    }
   case 65:
    var $_pr5;
    var $width_4;
    if (($width_4 | 0) > 1) {
      __label__ = 66;
      break;
    } else {
      var $dolPt_0 = $dolPt_1_ph;
      var $_05 = $_7;
      var $_06 = $_612;
      var $_pr = $_pr5;
      __label__ = 3;
      break;
    }
   case 66:
    var $236 = $width_4 - 1 | 0;
    var $237 = HEAP32[$5 >> 2];
    var $238 = FUNCTION_TABLE[$237]($ss, STRING_TABLE.__str284577 | 0, 1);
    HEAP32[$rv >> 2] = $238;
    if (($238 | 0) < 0) {
      var $_0 = $238;
      __label__ = 77;
      break;
    } else {
      var $width_4 = $236;
      var $_pr5 = $238;
      __label__ = 65;
      break;
    }
   case 67:
    if (($type_0 | 0) == 0) {
      __label__ = 68;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 68:
    var $244 = HEAP32[$_39 >> 2];
    HEAP32[$15 >> 2] = $244;
    var $245 = __ZL6cvt_wsP15SprintfStateStrPKtiii($ss, $244, $width_1, $prec_1, $flags_6);
    var $storemerge = $245;
    __label__ = 70;
    break;
   case 69:
    var $248 = HEAP32[$_39 >> 2];
    HEAP32[$16 >> 2] = $248;
    var $249 = __ZL5cvt_sP15SprintfStateStrPKciii($ss, $248, $width_1, $prec_1, $flags_6);
    var $storemerge = $249;
    __label__ = 70;
    break;
   case 70:
    var $storemerge;
    HEAP32[$rv >> 2] = $storemerge;
    if (($storemerge | 0) < 0) {
      var $_0 = $storemerge;
      __label__ = 77;
      break;
    } else {
      var $dolPt_0 = $dolPt_1_ph;
      var $_05 = $_7;
      var $_06 = $_39 + 4 | 0;
      var $_pr = $storemerge;
      __label__ = 3;
      break;
    }
   case 71:
    var $254 = $_39 + 4 | 0;
    var $255 = HEAP32[$_39 >> 2];
    HEAP32[$17 >> 2] = $255;
    if (($255 | 0) == 0) {
      var $dolPt_0 = $dolPt_1_ph;
      var $_05 = $_7;
      var $_06 = $254;
      var $_pr = $_pr;
      __label__ = 3;
      break;
    } else {
      __label__ = 72;
      break;
    }
   case 72:
    var $262 = HEAP32[$18 >> 2] - HEAP32[$19 >> 2] | 0;
    HEAP32[$255 >> 2] = $262;
    var $dolPt_0 = $dolPt_1_ph;
    var $_05 = $_7;
    var $_06 = $254;
    var $_pr = $_pr;
    __label__ = 3;
    break;
   case 73:
    var $264 = HEAP32[$5 >> 2];
    var $265 = FUNCTION_TABLE[$264]($ss, STRING_TABLE.__str273179 | 0, 1);
    HEAP32[$rv >> 2] = $265;
    if (($265 | 0) < 0) {
      var $_0 = $265;
      __label__ = 77;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 74:
    var $268 = HEAP32[$5 >> 2];
    var $270 = FUNCTION_TABLE[$268]($ss, $_7 - 1 | 0, 1);
    HEAP32[$rv >> 2] = $270;
    if (($270 | 0) < 0) {
      var $_0 = $270;
      __label__ = 77;
      break;
    } else {
      var $dolPt_0 = $dolPt_1_ph;
      var $_05 = $_7;
      var $_06 = $_39;
      var $_pr = $270;
      __label__ = 3;
      break;
    }
   case 75:
    var $273 = HEAP32[$5 >> 2];
    var $274 = FUNCTION_TABLE[$273]($ss, __str23014 | 0, 1);
    HEAP32[$rv >> 2] = $274;
    if (($2 | 0) == 0 | ($2 | 0) == ($1 | 0)) {
      var $_0 = $274;
      __label__ = 77;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 76:
    var $278 = $2;
    __ZN2js10Foreground5free_EPv($278);
    var $_0 = $274;
    __label__ = 77;
    break;
   case 77:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9dosprintfP15SprintfStateStrPKcPc["X"] = 1;

function _JS_smprintf($fmt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $ap = __stackBase__;
  HEAP32[$ap >> 2] = arguments[_JS_smprintf.length];
  var $2 = HEAP32[$ap >> 2];
  var $3 = _JS_vsmprintf($fmt, $2);
  STACKTOP = __stackBase__;
  return $3;
}

function _JS_vsmprintf($fmt, $ap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ss = __stackBase__;
    HEAP32[$ss >> 2] = 208;
    var $2 = $ss + 4 | 0;
    HEAP32[$2 >> 2] = 0;
    HEAP32[$ss + 8 >> 2] = 0;
    HEAP32[$ss + 12 >> 2] = 0;
    var $5 = __ZL9dosprintfP15SprintfStateStrPKcPc($ss, $fmt, $ap);
    var $7 = HEAP32[$2 >> 2];
    if (($5 | 0) < 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $7;
      __label__ = 4;
      break;
    }
   case 2:
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js10Foreground5free_EPv($7);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9GrowStuffP15SprintfStateStrPKcj($ss, $sp, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $ss + 8 | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = $ss + 4 | 0;
    var $4 = HEAPU32[$3 >> 2];
    var $7 = $2 - $4 | 0;
    var $9 = $ss + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    if (($7 + $len | 0) >>> 0 < $10 >>> 0) {
      var $25 = $2;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = $len >>> 0 > 32 ? $len : 32;
    var $15 = $10 + $14 | 0;
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $18 = __ZN2js11OffTheBooks8realloc_EPvj($4, $15);
    var $newbase_0 = $18;
    __label__ = 5;
    break;
   case 4:
    var $20 = __ZN2js11OffTheBooks7malloc_Ej($15);
    var $newbase_0 = $20;
    __label__ = 5;
    break;
   case 5:
    var $newbase_0;
    if (($newbase_0 | 0) == 0) {
      var $_0 = -1;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    HEAP32[$3 >> 2] = $newbase_0;
    HEAP32[$9 >> 2] = $15;
    var $24 = $newbase_0 + $7 | 0;
    HEAP32[$1 >> 2] = $24;
    var $25 = $24;
    __label__ = 7;
    break;
   case 7:
    var $25;
    if (($len | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      var $_023 = $len;
      var $_014 = $sp;
      var $27 = $25;
      __label__ = 8;
      break;
    }
   case 8:
    var $27;
    var $_014;
    var $_023;
    var $28 = $_023 - 1 | 0;
    var $29 = HEAP8[$_014];
    HEAP32[$1 >> 2] = $27 + 1 | 0;
    HEAP8[$27] = $29;
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_023 = $28;
    var $_014 = $_014 + 1 | 0;
    var $27 = HEAP32[$1 >> 2];
    __label__ = 8;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_snprintf($out, $outlen, $fmt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ap = __stackBase__;
    if (($outlen | 0) < 1) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$ap >> 2] = arguments[_JS_snprintf.length];
    var $4 = HEAP32[$ap >> 2];
    var $5 = _JS_vsnprintf($out, $outlen, $fmt, $4);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10LimitStuffP15SprintfStateStrPKcj($ss, $sp, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $ss + 8 | 0;
    var $3 = HEAPU32[$2 >> 2];
    var $9 = HEAP32[$ss + 4 >> 2] - $3 + HEAP32[$ss + 12 >> 2] | 0;
    var $_0_ph = $9 >>> 0 < $len >>> 0 ? $9 : $len;
    if (($_0_ph | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_012 = $sp;
      var $_03 = $_0_ph;
      var $12 = $3;
      __label__ = 2;
      break;
    }
   case 2:
    var $12;
    var $_03;
    var $_012;
    var $13 = $_03 - 1 | 0;
    var $14 = HEAP8[$_012];
    HEAP32[$2 >> 2] = $12 + 1 | 0;
    HEAP8[$12] = $14;
    if (($13 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_012 = $_012 + 1 | 0;
    var $_03 = $13;
    var $12 = HEAP32[$2 >> 2];
    __label__ = 2;
    break;
   case 4:
    return 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_vsnprintf($out, $outlen, $fmt, $ap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ss = __stackBase__;
    if (($outlen | 0) < 1) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$ss >> 2] = 210;
    var $4 = $ss + 4 | 0;
    HEAP32[$4 >> 2] = $out;
    var $5 = $ss + 8 | 0;
    HEAP32[$5 >> 2] = $out;
    HEAP32[$ss + 12 >> 2] = $outlen;
    var $7 = __ZL9dosprintfP15SprintfStateStrPKcPc($ss, $fmt, $ap);
    var $8 = HEAP32[$5 >> 2];
    var $9 = HEAP32[$4 >> 2];
    if (($8 | 0) == ($9 | 0)) {
      var $18 = $8;
      var $17 = $9;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $8 - 1 | 0;
    if (HEAP8[$12] << 24 >> 24 == 0) {
      var $18 = $8;
      var $17 = $9;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP8[$12] = 0;
    var $18 = HEAP32[$5 >> 2];
    var $17 = HEAP32[$4 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $18;
    var $_0 = $18 - $17 + ((($18 | 0) != ($17 | 0)) << 31 >> 31) | 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_sprintf_append($last, $fmt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $ap = __stackBase__;
  HEAP32[$ap >> 2] = arguments[_JS_sprintf_append.length];
  var $2 = HEAP32[$ap >> 2];
  var $3 = _JS_vsprintf_append($last, $fmt, $2);
  STACKTOP = __stackBase__;
  return $3;
}

function _JS_vsprintf_append($last, $fmt, $ap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ss = __stackBase__;
    HEAP32[$ss >> 2] = 208;
    if (($last | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _strlen($last);
    HEAP32[$ss + 4 >> 2] = $last;
    HEAP32[$ss + 8 >> 2] = $last + $4 | 0;
    HEAP32[$ss + 12 >> 2] = $4;
    __label__ = 4;
    break;
   case 3:
    HEAP32[$ss + 4 >> 2] = 0;
    HEAP32[$ss + 8 >> 2] = 0;
    HEAP32[$ss + 12 >> 2] = 0;
    __label__ = 4;
    break;
   case 4:
    var $14 = __ZL9dosprintfP15SprintfStateStrPKcPc($ss, $fmt, $ap);
    var $17 = HEAP32[$ss + 4 >> 2];
    if (($14 | 0) < 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $17;
      __label__ = 7;
      break;
    }
   case 5:
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js10Foreground5free_EPv($17);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13BuildArgArrayPKcPcPiP11NumArgState($fmt, $ap, $rv, $nasArray) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $ap;
    HEAP32[$rv >> 2] = 0;
    var $p_0_ph_ph = $fmt;
    var $indvars_iv = 0;
    __label__ = 2;
    break;
   case 2:
    var $indvars_iv;
    var $p_0_ph_ph;
    var $2 = ($indvars_iv | 0) > 0;
    var $p_0_ph = $p_0_ph_ph;
    var $i_0_ph = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0_ph;
    var $p_0_ph;
    var $p_0 = $p_0_ph;
    __label__ = 4;
    break;
   case 4:
    var $p_0;
    var $3 = $p_0 + 1 | 0;
    var $4 = HEAP8[$p_0];
    if ($4 << 24 >> 24 == 37) {
      __label__ = 5;
      break;
    } else if ($4 << 24 >> 24 == 0) {
      __label__ = 15;
      break;
    } else {
      var $p_0 = $3;
      __label__ = 4;
      break;
    }
   case 5:
    var $6 = $p_0 + 2 | 0;
    var $7 = HEAP8[$3];
    if ($7 << 24 >> 24 == 37) {
      var $p_0 = $6;
      __label__ = 4;
      break;
    } else {
      var $c_0 = $7;
      var $p_1 = $6;
      __label__ = 6;
      break;
    }
   case 6:
    var $p_1;
    var $c_0;
    if ($c_0 << 24 >> 24 == 0) {
      var $p_0 = $p_1;
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($c_0 - 48 & 255 & 255) > 9) {
      __label__ = 8;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 8:
    if ($c_0 << 24 >> 24 == 36) {
      __label__ = 9;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 9:
    if (($i_0_ph | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    HEAP32[$rv >> 2] = -1;
    var $_0 = 0;
    __label__ = 72;
    break;
   case 11:
    var $p_0_ph_ph = $p_1;
    var $indvars_iv = $indvars_iv + 1 | 0;
    __label__ = 2;
    break;
   case 12:
    if ($2) {
      __label__ = 13;
      break;
    } else {
      var $p_0_ph = $p_1;
      var $i_0_ph = 1;
      __label__ = 3;
      break;
    }
   case 13:
    HEAP32[$rv >> 2] = -1;
    var $_0 = 0;
    __label__ = 72;
    break;
   case 14:
    var $c_0 = HEAP8[$p_1];
    var $p_1 = $p_1 + 1 | 0;
    __label__ = 6;
    break;
   case 15:
    if (($indvars_iv | 0) == 0) {
      var $_0 = 0;
      __label__ = 72;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if (($indvars_iv | 0) > 20) {
      __label__ = 17;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 17:
    var $29 = _malloc($indvars_iv << 3);
    var $30 = $29;
    if (($29 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      var $nas_062 = $30;
      __label__ = 20;
      break;
    }
   case 18:
    HEAP32[$rv >> 2] = -1;
    var $_0 = 0;
    __label__ = 72;
    break;
   case 19:
    if ($2) {
      var $nas_062 = $nasArray;
      __label__ = 20;
      break;
    } else {
      var $nas_061 = $nasArray;
      __label__ = 21;
      break;
    }
   case 20:
    var $nas_062;
    var $i_131 = 0;
    __label__ = 22;
    break;
   case 21:
    var $nas_061;
    var $p_2 = $fmt;
    __label__ = 23;
    break;
   case 22:
    var $i_131;
    HEAP32[$nas_062 + ($i_131 << 3) >> 2] = 20;
    var $36 = $i_131 + 1 | 0;
    if (($36 | 0) == ($indvars_iv | 0)) {
      var $nas_061 = $nas_062;
      __label__ = 21;
      break;
    } else {
      var $i_131 = $36;
      __label__ = 22;
      break;
    }
   case 23:
    var $p_2;
    var $37 = $p_2 + 1 | 0;
    var $38 = HEAP8[$p_2];
    if ($38 << 24 >> 24 == 37) {
      __label__ = 24;
      break;
    } else if ($38 << 24 >> 24 == 0) {
      __label__ = 52;
      break;
    } else {
      var $p_2 = $37;
      __label__ = 23;
      break;
    }
   case 24:
    var $40 = $p_2 + 2 | 0;
    var $41 = HEAP8[$37];
    if ($41 << 24 >> 24 == 37) {
      var $p_2 = $40;
      __label__ = 23;
      break;
    } else {
      var $c_1 = $41;
      var $p_3 = $40;
      var $cn_0 = 0;
      __label__ = 25;
      break;
    }
   case 25:
    var $cn_0;
    var $p_3;
    var $c_1;
    if ($c_1 << 24 >> 24 == 36 || $c_1 << 24 >> 24 == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $47 = $cn_0 * 10 - 48 + ($c_1 << 24 >> 24) | 0;
    var $c_1 = HEAP8[$p_3];
    var $p_3 = $p_3 + 1 | 0;
    var $cn_0 = $47;
    __label__ = 25;
    break;
   case 27:
    if ($c_1 << 24 >> 24 == 0 | ($cn_0 | 0) < 1 | ($cn_0 | 0) > ($indvars_iv | 0)) {
      __label__ = 28;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 28:
    HEAP32[$rv >> 2] = -1;
    __label__ = 54;
    break;
   case 29:
    var $55 = $nas_061 + ($cn_0 - 1 << 3) | 0;
    if ((HEAP32[$55 >> 2] | 0) == 20) {
      __label__ = 30;
      break;
    } else {
      var $p_2 = $p_3;
      __label__ = 23;
      break;
    }
   case 30:
    var $59 = HEAPU8[$p_3];
    if ($59 << 24 >> 24 == 42) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $p_420 = $p_3 + 1 | 0;
    if (($59 - 48 & 255 & 255) < 10) {
      var $p_422 = $p_420;
      __label__ = 33;
      break;
    } else {
      var $p_3_pn_lcssa = $p_3;
      var $c_2_lcssa = $59;
      var $p_4_lcssa = $p_420;
      __label__ = 34;
      break;
    }
   case 32:
    HEAP32[$rv >> 2] = -1;
    __label__ = 54;
    break;
   case 33:
    var $p_422;
    var $63 = HEAPU8[$p_422];
    var $p_4 = $p_422 + 1 | 0;
    if (($63 - 48 & 255 & 255) < 10) {
      var $p_422 = $p_4;
      __label__ = 33;
      break;
    } else {
      var $p_3_pn_lcssa = $p_422;
      var $c_2_lcssa = $63;
      var $p_4_lcssa = $p_4;
      __label__ = 34;
      break;
    }
   case 34:
    var $p_4_lcssa;
    var $c_2_lcssa;
    var $p_3_pn_lcssa;
    if ($c_2_lcssa << 24 >> 24 == 46) {
      __label__ = 35;
      break;
    } else {
      var $c_4 = $c_2_lcssa;
      var $p_6 = $p_4_lcssa;
      __label__ = 39;
      break;
    }
   case 35:
    var $67 = $p_3_pn_lcssa + 2 | 0;
    var $68 = HEAPU8[$p_4_lcssa];
    if ($68 << 24 >> 24 == 42) {
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    if (($68 - 48 & 255 & 255) < 10) {
      var $p_516 = $67;
      __label__ = 38;
      break;
    } else {
      var $c_4 = $68;
      var $p_6 = $67;
      __label__ = 39;
      break;
    }
   case 37:
    HEAP32[$rv >> 2] = -1;
    __label__ = 54;
    break;
   case 38:
    var $p_516;
    var $72 = $p_516 + 1 | 0;
    var $73 = HEAPU8[$p_516];
    if (($73 - 48 & 255 & 255) < 10) {
      var $p_516 = $72;
      __label__ = 38;
      break;
    } else {
      var $c_4 = $73;
      var $p_6 = $72;
      __label__ = 39;
      break;
    }
   case 39:
    var $p_6;
    var $c_4;
    HEAP32[$55 >> 2] = 2;
    if ($c_4 << 24 >> 24 == 104) {
      __label__ = 40;
      break;
    } else if ($c_4 << 24 >> 24 == 76) {
      __label__ = 41;
      break;
    } else if ($c_4 << 24 >> 24 == 108) {
      __label__ = 42;
      break;
    } else {
      var $c_5 = $c_4;
      var $p_7 = $p_6;
      __label__ = 44;
      break;
    }
   case 40:
    HEAP32[$55 >> 2] = 0;
    var $c_5 = HEAP8[$p_6];
    var $p_7 = $p_6 + 1 | 0;
    __label__ = 44;
    break;
   case 41:
    HEAP32[$55 >> 2] = 6;
    var $c_5 = HEAP8[$p_6];
    var $p_7 = $p_6 + 1 | 0;
    __label__ = 44;
    break;
   case 42:
    HEAP32[$55 >> 2] = 4;
    var $82 = $p_6 + 1 | 0;
    var $83 = HEAP8[$p_6];
    if ($83 << 24 >> 24 == 108) {
      __label__ = 43;
      break;
    } else {
      var $c_5 = $83;
      var $p_7 = $82;
      __label__ = 44;
      break;
    }
   case 43:
    HEAP32[$55 >> 2] = 6;
    var $c_5 = HEAP8[$82];
    var $p_7 = $p_6 + 2 | 0;
    __label__ = 44;
    break;
   case 44:
    var $p_7;
    var $c_5;
    var $89 = $c_5 << 24 >> 24;
    if (($89 | 0) == 100 || ($89 | 0) == 99 || ($89 | 0) == 105 || ($89 | 0) == 111 || ($89 | 0) == 117 || ($89 | 0) == 120 || ($89 | 0) == 88) {
      var $p_2 = $p_7;
      __label__ = 23;
      break;
    } else if (($89 | 0) == 101 || ($89 | 0) == 102 || ($89 | 0) == 103) {
      __label__ = 45;
      break;
    } else if (($89 | 0) == 112) {
      __label__ = 46;
      break;
    } else if (($89 | 0) == 67 || ($89 | 0) == 83 || ($89 | 0) == 69 || ($89 | 0) == 71) {
      __label__ = 47;
      break;
    } else if (($89 | 0) == 115) {
      __label__ = 48;
      break;
    } else if (($89 | 0) == 110) {
      __label__ = 49;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 45:
    HEAP32[$55 >> 2] = 9;
    var $p_2 = $p_7;
    __label__ = 23;
    break;
   case 46:
    HEAP32[$55 >> 2] = 5;
    var $p_2 = $p_7;
    __label__ = 23;
    break;
   case 47:
    HEAP32[$55 >> 2] = 20;
    __label__ = 51;
    break;
   case 48:
    HEAP32[$55 >> 2] = 8;
    var $p_2 = $p_7;
    __label__ = 23;
    break;
   case 49:
    HEAP32[$55 >> 2] = 10;
    var $p_2 = $p_7;
    __label__ = 23;
    break;
   case 50:
    HEAP32[$55 >> 2] = 20;
    __label__ = 51;
    break;
   case 51:
    HEAP32[$rv >> 2] = -1;
    __label__ = 54;
    break;
   case 52:
    if ((HEAP32[$rv >> 2] | 0) < 0) {
      __label__ = 54;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    var $98 = $1;
    var $cn_1 = 0;
    __label__ = 56;
    break;
   case 54:
    if (($nas_061 | 0) == ($nasArray | 0)) {
      var $_0 = 0;
      __label__ = 72;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    __ZN2js10Foreground5free_EPv($nas_061);
    var $_0 = 0;
    __label__ = 72;
    break;
   case 56:
    var $cn_1;
    if (($cn_1 | 0) < ($indvars_iv | 0)) {
      __label__ = 57;
      break;
    } else {
      var $_0 = $nas_061;
      __label__ = 72;
      break;
    }
   case 57:
    var $105 = $nas_061 + ($cn_1 << 3) | 0;
    if ((HEAP32[$105 >> 2] | 0) == 20) {
      __label__ = 58;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 58:
    var $cn_1 = $cn_1 + 1 | 0;
    __label__ = 56;
    break;
   case 59:
    _llvm_va_copy($nas_061 + ($cn_1 << 3) + 4 | 0, $98);
    var $111 = HEAP32[$105 >> 2];
    if (($111 | 0) == 0 || ($111 | 0) == 1 || ($111 | 0) == 2 || ($111 | 0) == 3) {
      __label__ = 60;
      break;
    } else if (($111 | 0) == 4) {
      __label__ = 61;
      break;
    } else if (($111 | 0) == 5) {
      __label__ = 62;
      break;
    } else if (($111 | 0) == 6) {
      __label__ = 63;
      break;
    } else if (($111 | 0) == 7) {
      __label__ = 64;
      break;
    } else if (($111 | 0) == 8) {
      __label__ = 65;
      break;
    } else if (($111 | 0) == 11) {
      __label__ = 66;
      break;
    } else if (($111 | 0) == 10) {
      __label__ = 67;
      break;
    } else if (($111 | 0) == 9) {
      __label__ = 68;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 60:
    var $114 = HEAP32[$1 >> 2] + 4 | 0;
    HEAP32[$1 >> 2] = $114;
    __label__ = 58;
    break;
   case 61:
    var $117 = HEAP32[$1 >> 2] + 4 | 0;
    HEAP32[$1 >> 2] = $117;
    __label__ = 58;
    break;
   case 62:
    var $120 = HEAP32[$1 >> 2] + 4 | 0;
    HEAP32[$1 >> 2] = $120;
    __label__ = 58;
    break;
   case 63:
    var $123 = HEAP32[$1 >> 2] + 8 | 0;
    HEAP32[$1 >> 2] = $123;
    __label__ = 58;
    break;
   case 64:
    var $126 = HEAP32[$1 >> 2] + 8 | 0;
    HEAP32[$1 >> 2] = $126;
    __label__ = 58;
    break;
   case 65:
    var $129 = HEAP32[$1 >> 2] + 4 | 0;
    HEAP32[$1 >> 2] = $129;
    __label__ = 58;
    break;
   case 66:
    var $132 = HEAP32[$1 >> 2] + 4 | 0;
    HEAP32[$1 >> 2] = $132;
    __label__ = 58;
    break;
   case 67:
    var $135 = HEAP32[$1 >> 2] + 4 | 0;
    HEAP32[$1 >> 2] = $135;
    __label__ = 58;
    break;
   case 68:
    var $138 = HEAP32[$1 >> 2] + 8 | 0;
    HEAP32[$1 >> 2] = $138;
    __label__ = 58;
    break;
   case 69:
    if (($nas_061 | 0) == ($nasArray | 0)) {
      __label__ = 71;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    __ZN2js10Foreground5free_EPv($nas_061);
    __label__ = 71;
    break;
   case 71:
    HEAP32[$rv >> 2] = -1;
    var $_0 = 0;
    __label__ = 72;
    break;
   case 72:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13BuildArgArrayPKcPcPiP11NumArgState["X"] = 1;

function __ZL5cvt_lP15SprintfStateStrliiiiiPKc($ss, $num, $width, $prec, $radix, $type, $flags, $hexp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 100;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cvtbuf = __stackBase__;
    if (($prec | $num | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cvtbuf + 100 | 0;
    if (($num | 0) == 0) {
      var $cvt_0_lcssa8 = $4;
      __label__ = 5;
      break;
    } else {
      var $cvt_02 = $4;
      var $_013 = $num;
      var $digits_04 = 0;
      __label__ = 3;
      break;
    }
   case 3:
    var $digits_04;
    var $_013;
    var $cvt_02;
    var $9 = HEAP8[$hexp + (($_013 >>> 0) % ($radix >>> 0) & 15) | 0];
    var $10 = $cvt_02 - 1 | 0;
    HEAP8[$10] = $9;
    var $11 = $digits_04 + 1 | 0;
    var $12 = Math.floor(($_013 >>> 0) / ($radix >>> 0));
    if (($12 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $cvt_02 = $10;
      var $_013 = $12;
      var $digits_04 = $11;
      __label__ = 3;
      break;
    }
   case 4:
    if (($11 | 0) == 0) {
      var $cvt_0_lcssa8 = $10;
      __label__ = 5;
      break;
    } else {
      var $digits_1 = $11;
      var $cvt_1 = $10;
      __label__ = 6;
      break;
    }
   case 5:
    var $cvt_0_lcssa8;
    var $15 = $cvt_0_lcssa8 - 1 | 0;
    HEAP8[$15] = 48;
    var $digits_1 = 1;
    var $cvt_1 = $15;
    __label__ = 6;
    break;
   case 6:
    var $cvt_1;
    var $digits_1;
    var $17 = __ZL6fill_nP15SprintfStateStrPKciiiii($ss, $cvt_1, $digits_1, $width, $prec, $type, $flags);
    var $_0 = $17;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL6cvt_llP15SprintfStateStrxiiiiiPKc($ss, $num$0, $num$1, $width, $prec, $radix, $type, $flags, $hexp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 100;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cvtbuf = __stackBase__;
    var $2 = $num$0 == 0 && $num$1 == 0;
    if (($prec | 0) == 0 & $2) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4$0 = $radix;
    var $4$1 = ($radix | 0) < 0 ? -1 : 0;
    var $5 = $cvtbuf + 100 | 0;
    if ($2) {
      var $cvt_0_lcssa8 = $5;
      __label__ = 5;
      break;
    } else {
      var $cvt_02 = $5;
      var $_013$1 = $num$1;
      var $_013$0 = $num$0;
      var $digits_04 = 0;
      __label__ = 3;
      break;
    }
   case 3:
    var $digits_04;
    var $_013$0;
    var $_013$1;
    var $cvt_02;
    var $6$0 = (i64Math.divide($_013$0, $_013$1, $4$0, $4$1, true), i64Math.result[0]);
    var $6$1 = i64Math.result[1];
    var $7$0 = (i64Math.modulo($_013$0, $_013$1, $4$0, $4$1, true), i64Math.result[0]);
    var $7$1 = i64Math.result[1];
    var $11 = HEAP8[$hexp + ($7$0 & 15) | 0];
    var $12 = $cvt_02 - 1 | 0;
    HEAP8[$12] = $11;
    var $13 = $digits_04 + 1 | 0;
    if ($6$0 == 0 && $6$1 == 0) {
      __label__ = 4;
      break;
    } else {
      var $cvt_02 = $12;
      var $_013$1 = $6$1;
      var $_013$0 = $6$0;
      var $digits_04 = $13;
      __label__ = 3;
      break;
    }
   case 4:
    if (($13 | 0) == 0) {
      var $cvt_0_lcssa8 = $12;
      __label__ = 5;
      break;
    } else {
      var $digits_1 = $13;
      var $cvt_1 = $12;
      __label__ = 6;
      break;
    }
   case 5:
    var $cvt_0_lcssa8;
    var $16 = $cvt_0_lcssa8 - 1 | 0;
    HEAP8[$16] = 48;
    var $digits_1 = 1;
    var $cvt_1 = $16;
    __label__ = 6;
    break;
   case 6:
    var $cvt_1;
    var $digits_1;
    var $18 = __ZL6fill_nP15SprintfStateStrPKciiiii($ss, $cvt_1, $digits_1, $width, $prec, $type, $flags);
    var $_0 = $18;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5cvt_fP15SprintfStateStrdPKcS2_($ss, $d, $fmt0, $fmt1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 320;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fin = __stackBase__;
    var $fout = __stackBase__ + 20;
    var $3 = $fmt1 - $fmt0 | 0;
    if (($3 | 0) > 19) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $fin | 0;
    _memcpy($6, $fmt0, $3, 1);
    HEAP8[$fin + $3 | 0] = 0;
    var $8 = $fout | 0;
    var $9 = _sprintf($8, $6, (tempInt = STACKTOP, STACKTOP += 8, tempDoubleF64[0] = $d, HEAP32[tempInt >> 2] = tempDoubleI32[0], HEAP32[tempInt + 4 >> 2] = tempDoubleI32[1], tempInt));
    var $11 = HEAP32[$ss >> 2];
    var $12 = _strlen($8);
    var $13 = FUNCTION_TABLE[$11]($ss, $8, $12);
    var $_0 = $13;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL6cvt_wsP15SprintfStateStrPKtiii($ss, $ws, $width, $prec, $flags) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($ws | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __Z9js_strlenPKt($ws);
    var $4 = __ZN2js13DeflateStringEP9JSContextPKtj(0, $ws, $3);
    if (($4 | 0) == 0) {
      var $_0 = -1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZL5cvt_sP15SprintfStateStrPKciii($ss, $4, $width, $prec, $flags);
    __ZN2js10Foreground5free_EPv($4);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 4:
    var $9 = __ZL5cvt_sP15SprintfStateStrPKciii($ss, 0, $width, $prec, $flags);
    var $_0 = $9;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5cvt_sP15SprintfStateStrPKciii($ss, $s, $width, $prec, $flags) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($prec | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = ($s | 0) != 0;
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $7 = 6;
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = _strlen($s);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    var $slen_0 = ($prec | 0) > 0 & ($7 | 0) > ($prec | 0) ? $prec : $7;
    var $10 = $3 ? $s : STRING_TABLE.__str33015 | 0;
    var $11 = __ZL5fill2P15SprintfStateStrPKciii($ss, $10, $slen_0, $width, $flags);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5fill2P15SprintfStateStrPKciii($ss, $src, $srclen, $width, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $space = __stackBase__;
    HEAP8[$space] = 32;
    var $1 = $width - $srclen | 0;
    if (($1 | 0) > 0) {
      __label__ = 2;
      break;
    } else {
      var $_1 = $1;
      __label__ = 8;
      break;
    }
   case 2:
    if (($flags & 1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_1 = $1;
      __label__ = 8;
      break;
    }
   case 3:
    if (($flags & 8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP8[$space] = 48;
    __label__ = 5;
    break;
   case 5:
    var $10 = $ss | 0;
    var $_01 = $1;
    __label__ = 6;
    break;
   case 6:
    var $_01;
    var $12 = $_01 - 1 | 0;
    if (($_01 | 0) > 0) {
      __label__ = 7;
      break;
    } else {
      var $_1 = $12;
      __label__ = 8;
      break;
    }
   case 7:
    var $15 = HEAP32[$10 >> 2];
    var $16 = FUNCTION_TABLE[$15]($ss, $space, 1);
    if (($16 | 0) < 0) {
      var $_0 = $16;
      __label__ = 13;
      break;
    } else {
      var $_01 = $12;
      __label__ = 6;
      break;
    }
   case 8:
    var $_1;
    var $18 = $ss | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = FUNCTION_TABLE[$19]($ss, $src, $srclen);
    if (($20 | 0) < 0) {
      var $_0 = $20;
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (($_1 | 0) > 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 10:
    if (($flags & 1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      var $_2 = $_1;
      __label__ = 11;
      break;
    }
   case 11:
    var $_2;
    if (($_2 | 0) > 0) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 12:
    var $29 = $_2 - 1 | 0;
    var $30 = HEAP32[$18 >> 2];
    var $31 = FUNCTION_TABLE[$30]($ss, $space, 1);
    if (($31 | 0) < 0) {
      var $_0 = $31;
      __label__ = 13;
      break;
    } else {
      var $_2 = $29;
      __label__ = 11;
      break;
    }
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL6fill_nP15SprintfStateStrPKciiiii($ss, $src, $srclen, $width, $prec, $type, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sign = __stackBase__;
    if (($type & 1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $signwidth_0 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    if (($flags & 16 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP8[$sign] = 45;
    var $signwidth_0 = 1;
    __label__ = 8;
    break;
   case 4:
    if (($flags & 2 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP8[$sign] = 43;
    var $signwidth_0 = 1;
    __label__ = 8;
    break;
   case 6:
    if (($flags & 4 | 0) == 0) {
      var $signwidth_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP8[$sign] = 32;
    var $signwidth_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $signwidth_0;
    var $or_cond = ($prec | 0) > 0 & ($prec | 0) > ($srclen | 0);
    var $_4 = $or_cond ? $prec - $srclen | 0 : 0;
    var $prec_pn = $or_cond ? $prec : $srclen;
    var $cvtwidth_0 = $signwidth_0 + $prec_pn | 0;
    if (($flags & 8 | 0) != 0 & ($prec | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      var $cvtwidth_1 = $cvtwidth_0;
      var $zerowidth_0 = 0;
      __label__ = 11;
      break;
    }
   case 9:
    var $24 = ($cvtwidth_0 | 0) < ($width | 0);
    var $_ = $24 ? $width - $cvtwidth_0 | 0 : 0;
    if ($24) {
      __label__ = 10;
      break;
    } else {
      var $cvtwidth_1 = $cvtwidth_0;
      var $zerowidth_0 = $_;
      __label__ = 11;
      break;
    }
   case 10:
    var $cvtwidth_1 = $width;
    var $zerowidth_0 = $_;
    __label__ = 11;
    break;
   case 11:
    var $zerowidth_0;
    var $cvtwidth_1;
    var $28 = ($flags & 1 | 0) == 0;
    var $_3 = ($cvtwidth_1 | 0) < ($width | 0) ? $width - $cvtwidth_1 | 0 : 0;
    var $_3_ = $28 ? $_3 : 0;
    var $__3 = $28 ? 0 : $_3;
    var $31 = $ss | 0;
    var $leftspaces_0 = $_3_;
    __label__ = 12;
    break;
   case 12:
    var $leftspaces_0;
    if (($leftspaces_0 | 0) > 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $35 = $leftspaces_0 - 1 | 0;
    var $36 = HEAP32[$31 >> 2];
    var $37 = FUNCTION_TABLE[$36]($ss, STRING_TABLE.__str284577 | 0, 1);
    if (($37 | 0) < 0) {
      var $_0 = $37;
      __label__ = 23;
      break;
    } else {
      var $leftspaces_0 = $35;
      __label__ = 12;
      break;
    }
   case 14:
    if (($signwidth_0 | 0) == 0) {
      var $precwidth_1 = $_4;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $42 = HEAP32[$31 >> 2];
    var $43 = FUNCTION_TABLE[$42]($ss, $sign, 1);
    if (($43 | 0) < 0) {
      var $_0 = $43;
      __label__ = 23;
      break;
    } else {
      var $precwidth_1 = $_4;
      __label__ = 16;
      break;
    }
   case 16:
    var $precwidth_1;
    if (($precwidth_1 | 0) > 0) {
      __label__ = 17;
      break;
    } else {
      var $zerowidth_1 = $zerowidth_0;
      __label__ = 18;
      break;
    }
   case 17:
    var $47 = $precwidth_1 - 1 | 0;
    var $48 = HEAP32[$31 >> 2];
    var $49 = FUNCTION_TABLE[$48]($ss, STRING_TABLE.__str225518 | 0, 1);
    if (($49 | 0) < 0) {
      var $_0 = $49;
      __label__ = 23;
      break;
    } else {
      var $precwidth_1 = $47;
      __label__ = 16;
      break;
    }
   case 18:
    var $zerowidth_1;
    var $52 = HEAP32[$31 >> 2];
    if (($zerowidth_1 | 0) > 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $54 = $zerowidth_1 - 1 | 0;
    var $55 = FUNCTION_TABLE[$52]($ss, STRING_TABLE.__str225518 | 0, 1);
    if (($55 | 0) < 0) {
      var $_0 = $55;
      __label__ = 23;
      break;
    } else {
      var $zerowidth_1 = $54;
      __label__ = 18;
      break;
    }
   case 20:
    var $58 = FUNCTION_TABLE[$52]($ss, $src, $srclen);
    if (($58 | 0) < 0) {
      var $_0 = $58;
      __label__ = 23;
      break;
    } else {
      var $rightspaces_1 = $__3;
      __label__ = 21;
      break;
    }
   case 21:
    var $rightspaces_1;
    if (($rightspaces_1 | 0) > 0) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 22:
    var $62 = $rightspaces_1 - 1 | 0;
    var $63 = HEAP32[$31 >> 2];
    var $64 = FUNCTION_TABLE[$63]($ss, STRING_TABLE.__str284577 | 0, 1);
    if (($64 | 0) < 0) {
      var $_0 = $64;
      __label__ = 23;
      break;
    } else {
      var $rightspaces_1 = $62;
      __label__ = 21;
      break;
    }
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL6fill_nP15SprintfStateStrPKciiiii["X"] = 1;

function __ZN8JSObject7genericEv($this_0_2_val) {
  return ($this_0_2_val & 16 | 0) != 0;
}

function __ZNK2js11KidsPointer6isNullEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZNK2js11KidsPointer7toShapeEv($this_0_0_val) {
  return $this_0_0_val & -2;
}

function __ZNK2js11KidsPointer6toHashEv($this_0_0_val) {
  return $this_0_0_val & -2;
}

function __ZNK2js11KidsPointer6isHashEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function __ZL26js_IsPropertyCacheDisabledP9JSContext3032($cx_0_11_val) {
  return HEAPU32[$cx_0_11_val + 209944 >> 2] >>> 0 > 16777215 & 1;
}

function __ZN2js5PCVal9setFunObjER8JSObject($this, $obj) {
  HEAP32[$this >> 2] = $obj;
  return;
}

function __ZN2js5PCVal7setSlotEj($this, $slot) {
  HEAP32[$this >> 2] = $slot << 1 | 1;
  return;
}

function __ZN2js5PCVal8setShapeEPKNS_5ShapeE($this, $shape) {
  HEAP32[$this >> 2] = $shape | 2;
  return;
}

function __ZN2js18PropertyCacheEntry6assignEPhjjjjNS_5PCValE($this, $kpc, $kshape, $vshape, $scopeIndex, $protoIndex, $vword_0) {
  HEAP32[$this >> 2] = $kpc;
  HEAP32[$this + 4 >> 2] = $kshape;
  HEAP32[$this + 8 >> 2] = $vshape << 8 | $protoIndex | $scopeIndex << 4;
  HEAP32[$this + 12 >> 2] = $vword_0;
  return;
}

function __ZN2js5Shape9setParentEPS0_($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAPU32[$p + 4 >> 2];
    var $7 = HEAP32[$this + 24 >> 2] + 1 | 0;
    var $_ = $4 >>> 0 > $7 >>> 0 ? $4 : $7;
    HEAP32[$this + 4 >> 2] = $_;
    __label__ = 3;
    break;
   case 3:
    HEAP32[$this + 32 >> 2] = $p;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11KidsPointer8setShapeEPNS_5ShapeE($this, $shape) {
  HEAP32[$this >> 2] = $shape;
  return;
}

function __ZN2js11KidsPointer7setHashEPNS_7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEE($this, $hash) {
  HEAP32[$this >> 2] = $hash | 1;
  return;
}

function __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrdeEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN2js13PropertyCache4fillEP9JSContextP8JSObjectjS4_PKNS_5ShapeEi($this, $cx, $obj, $scopeIndex, $pobj, $shape, $adding) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $vword = __stackBase__;
    var $pc = __stackBase__ + 4;
    var $funobj1 = __stackBase__ + 8;
    var $cx_idx9 = $cx + 52 | 0;
    var $cx_idx9_val = HEAP32[$cx_idx9 >> 2];
    var $1 = __ZL26js_IsPropertyCacheDisabledP9JSContext3032($cx_idx9_val);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 16;
      __label__ = 40;
      break;
    }
   case 2:
    var $4 = $pobj;
    var $5 = $cx;
    var $6 = $shape;
    var $7 = __ZN8JSObject14nativeContainsEP9JSContextRKN2js5ShapeE($4, $5, $6);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 16;
      __label__ = 40;
      break;
    }
   case 3:
    var $9 = ($adding | 0) != 0;
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $obj_idx_val = HEAP32[$obj >> 2];
    var $11 = __ZNK8JSObject16inDictionaryModeEv($obj_idx_val);
    if ($11) {
      var $_0 = 16;
      __label__ = 40;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = ($scopeIndex | 0) == 0;
    if ($12) {
      var $protoIndex_0 = 0;
      var $tmp_1 = $obj;
      __label__ = 7;
      break;
    } else {
      var $tmp_04 = $obj;
      var $i_05 = 0;
      __label__ = 6;
      break;
    }
   case 6:
    var $i_05;
    var $tmp_04;
    var $tmp_04_idx_val = HEAP32[$tmp_04 + 20 >> 2];
    var $13 = __ZNK8JSObject9getParentEv($tmp_04_idx_val);
    var $14 = $i_05 + 1 | 0;
    if (($14 | 0) == ($scopeIndex | 0)) {
      var $protoIndex_0 = 0;
      var $tmp_1 = $13;
      __label__ = 7;
      break;
    } else {
      var $tmp_04 = $13;
      var $i_05 = $14;
      __label__ = 6;
      break;
    }
   case 7:
    var $tmp_1;
    var $protoIndex_0;
    if (($tmp_1 | 0) == ($pobj | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $tmp_1_idx_val_idx_val = HEAP32[HEAP32[$tmp_1 + 36 >> 2] >> 2];
    var $18 = __ZNK8JSObject8getProtoEv($tmp_1_idx_val_idx_val);
    if (($18 | 0) == 0) {
      var $_0 = 16;
      __label__ = 40;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_idx_val = HEAP32[$18 >> 2];
    var $21 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($21) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 16;
      __label__ = 40;
      break;
    }
   case 10:
    var $protoIndex_0 = $protoIndex_0 + 1 | 0;
    var $tmp_1 = $18;
    __label__ = 7;
    break;
   case 11:
    if ($scopeIndex >>> 0 > 15 | $protoIndex_0 >>> 0 > 15) {
      var $_0 = 16;
      __label__ = 40;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $28 = $cx + 60 | 0;
    var $29 = __ZNK2js12ContextStack13currentScriptEPPh($28, $pc);
    var $30 = HEAP32[$pc >> 2];
    var $31 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh3033($29, $30);
    var $33 = HEAPU32[_js_CodeSpec + ($31 << 3) + 4 >> 2];
    if (($33 & 524288 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $shape_idx_val = HEAP8[$shape + 29 | 0];
    var $37 = __ZNK2js5Shape8isMethodEv($shape_idx_val);
    if ($37) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $39 = __ZNK2js5Shape12methodObjectEv($shape);
    __ZN2js5PCVal9setFunObjER8JSObject($vword, $39);
    __label__ = 35;
    break;
   case 15:
    var $pobj_idx10 = $pobj + 8 | 0;
    var $pobj_idx10_val = HEAP32[$pobj_idx10 >> 2];
    var $41 = __ZN8JSObject7genericEv($pobj_idx10_val);
    if ($41) {
      __label__ = 25;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $shape_idx4_val = HEAP32[$shape + 16 >> 2];
    var $43 = __ZNK2js5Shape16hasDefaultGetterEv($shape_idx4_val);
    if ($43) {
      __label__ = 17;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 17:
    var $46 = HEAP32[$shape + 24 >> 2];
    var $pobj_idx2_val_idx_val = HEAP32[HEAP32[$pobj >> 2] + 4 >> 2];
    var $47 = __ZNK8JSObject12containsSlotEj($pobj_idx2_val_idx_val, $46);
    if ($47) {
      __label__ = 18;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 18:
    var $cx_idx_val = HEAP8[$cx + 232 | 0];
    var $49 = __ZN9JSContext20typeInferenceEnabledEv($cx_idx_val);
    if ($49) {
      __label__ = 25;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $51 = __ZNK8JSObject13nativeGetSlotEj($pobj, $46);
    var $_idx11 = $51 | 0;
    var $_idx11_val$0 = HEAP32[$_idx11 >> 2];
    var $_idx11_val$1 = HEAP32[$_idx11 + 4 >> 2];
    var $52 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject3034($_idx11_val$0, $_idx11_val$1, $funobj1);
    if ($52) {
      __label__ = 20;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 20:
    var $_idx5_val = HEAP32[$pobj_idx10 >> 2];
    var $54 = __ZN8JSObject7brandedEv($_idx5_val);
    if ($54) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $56 = $pobj;
    var $57 = $cx;
    var $58 = __ZN8JSObject5brandEP9JSContext($56, $57);
    if ($58) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 16;
      __label__ = 40;
      break;
    }
   case 22:
    var $60 = HEAP32[$funobj1 >> 2];
    __ZN2js5PCVal9setFunObjER8JSObject($vword, $60);
    __label__ = 35;
    break;
   case 23:
    if (($33 & 11520 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $_idx12_val = HEAP32[$obj + 8 >> 2];
    var $66 = __ZNK8JSObject7watchedEv($_idx12_val);
    if ($66) {
      var $_0 = 16;
      __label__ = 40;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    if (($33 & 8448 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 26:
    if (($33 & 3072 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $shape_idx13_val = HEAP32[$shape + 20 >> 2];
    var $74 = __ZNK2js5Shape16hasDefaultSetterEv($shape_idx13_val);
    if ($74) {
      __label__ = 28;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 28:
    var $_idx14_val = HEAP8[$shape + 28 | 0];
    var $77 = __ZNK2js5Shape8writableEv($_idx14_val);
    if ($77) {
      __label__ = 29;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 29:
    var $shape_idx3_val = HEAP32[$shape + 16 >> 2];
    var $78 = __ZNK2js5Shape16hasDefaultGetterEv($shape_idx3_val);
    if ($78) {
      __label__ = 30;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 30:
    var $81 = HEAP32[$shape + 24 >> 2];
    var $pobj_idx_val_idx_val = HEAP32[HEAP32[$pobj >> 2] + 4 >> 2];
    var $82 = __ZNK8JSObject12containsSlotEj($pobj_idx_val_idx_val, $81);
    if ($82) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    __ZN2js5PCVal7setSlotEj($vword, $81);
    __label__ = 35;
    break;
   case 32:
    __ZN2js5PCVal8setShapeEPKNS_5ShapeE($vword, $shape);
    if ($9) {
      __label__ = 33;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 33:
    var $pobj_idx8_val = HEAP32[$pobj + 12 >> 2];
    var $86 = __ZNK8JSObject5shapeEv($pobj_idx8_val);
    if (($86 | 0) == (HEAP32[$shape >> 2] | 0)) {
      __label__ = 34;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 34:
    var $shape_idx1_val = HEAP32[$shape + 32 >> 2];
    var $91 = __ZNK2js5Shape8previousEv($shape_idx1_val);
    var $93 = HEAP32[$91 >> 2];
    var $96 = HEAP32[HEAP32[$cx_idx9 >> 2] + 44 >> 2];
    if (($93 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      var $vshape_1 = $96;
      var $kshape_1 = $93;
      __label__ = 36;
      break;
    }
   case 35:
    var $obj_idx7_val = HEAP32[$obj + 12 >> 2];
    var $98 = __ZNK8JSObject5shapeEv($obj_idx7_val);
    var $pobj_idx6_val = HEAP32[$pobj + 12 >> 2];
    var $99 = __ZNK8JSObject5shapeEv($pobj_idx6_val);
    var $vshape_1 = $99;
    var $kshape_1 = $98;
    __label__ = 36;
    break;
   case 36:
    var $kshape_1;
    var $vshape_1;
    if (($obj | 0) == ($pobj | 0)) {
      __label__ = 39;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    if ($12 & ($protoIndex_0 | 0) == 1) {
      __label__ = 39;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    __ZN8JSObject11setDelegateEv($obj);
    __label__ = 39;
    break;
   case 39:
    var $106 = HEAP32[$pc >> 2];
    var $107 = __ZN2js13PropertyCache4hashEPhj($106, $kshape_1);
    var $108 = $this + ($107 << 4) | 0;
    var $110 = HEAP32[$vword >> 2];
    __ZN2js18PropertyCacheEntry6assignEPhjjjjNS_5PCValE($108, $106, $kshape_1, $vshape_1, $scopeIndex, $protoIndex_0, $110);
    HEAP32[$this + 65536 >> 2] = 0;
    var $_0 = $108;
    __label__ = 40;
    break;
   case 40:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13PropertyCache4fillEP9JSContextP8JSObjectjS4_PKNS_5ShapeEi["X"] = 1;

function __ZL12js_GetOpcodeP9JSContextP8JSScriptPh3033($script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU8[$pc];
    var $2 = $1 & 255;
    if ($1 << 24 >> 24 == 83) {
      __label__ = 2;
      break;
    } else {
      var $op_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $script;
    var $6 = _JS_GetTrapOpcode($5, $pc);
    var $op_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $op_0;
    return $op_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject3034($v_0_0_0_val$0, $v_0_0_0_val$1, $funobj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    HEAP32[$funobj >> 2] = $3;
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZNK8JSObject10isFunctionEv($_idx_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13PropertyCache8fullTestEP9JSContextPhPP8JSObjectS6_PNS_18PropertyCacheEntryE($cx, $pc, $objp, $pobjp, $entry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 60 | 0;
    var $2 = __ZNK2js12ContextStack13currentScriptEPPh($1, 0);
    var $3 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh3033($2, $pc);
    var $4 = _js_CodeSpec + ($3 << 3) | 0;
    var $5 = HEAP32[$objp >> 2];
    var $7 = HEAP32[$entry + 8 >> 2];
    if ((HEAP32[$entry >> 2] | 0) == ($pc | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = __ZL19GetAtomFromBytecodeP9JSContextPh4JSOpRK10JSCodeSpec($cx, $pc, $3, $4);
    var $_0 = $12;
    __label__ = 18;
    break;
   case 3:
    var $15 = HEAP32[$entry + 4 >> 2];
    var $_idx2_val = HEAP32[$5 + 12 >> 2];
    var $16 = __ZNK8JSObject5shapeEv($_idx2_val);
    if (($15 | 0) == ($16 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = __ZL19GetAtomFromBytecodeP9JSContextPh4JSOpRK10JSCodeSpec($cx, $pc, $3, $4);
    var $_0 = $19;
    __label__ = 18;
    break;
   case 5:
    if ((HEAP32[_js_CodeSpec + ($3 << 3) + 4 >> 2] & 224 | 0) == 32) {
      var $vcap_0 = $7;
      var $pobj_0 = $5;
      __label__ = 6;
      break;
    } else {
      var $vcap_1 = $7;
      var $pobj_1 = $5;
      __label__ = 11;
      break;
    }
   case 6:
    var $pobj_0;
    var $vcap_0;
    if (($vcap_0 & 240 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $pobj_0_idx_val = HEAP32[$pobj_0 + 20 >> 2];
    var $28 = __ZNK8JSObject9getParentEv($pobj_0_idx_val);
    if (($28 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx1_val = HEAP32[$28 >> 2];
    var $31 = __ZNK8JSObject8isNativeEv($_idx1_val);
    if ($31) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $vcap_0 = $vcap_0 - 16 | 0;
    var $pobj_0 = $28;
    __label__ = 6;
    break;
   case 10:
    HEAP32[$objp >> 2] = $pobj_0;
    var $vcap_1 = $vcap_0;
    var $pobj_1 = $pobj_0;
    __label__ = 11;
    break;
   case 11:
    var $pobj_1;
    var $vcap_1;
    if (($vcap_1 & 15 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $pobj_1_idx_val_idx_val = HEAP32[HEAP32[$pobj_1 + 36 >> 2] >> 2];
    var $38 = __ZNK8JSObject8getProtoEv($pobj_1_idx_val_idx_val);
    if (($38 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $_idx_val = HEAP32[$38 >> 2];
    var $41 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($41) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $vcap_1 = $vcap_1 - 1 | 0;
    var $pobj_1 = $38;
    __label__ = 11;
    break;
   case 15:
    var $pobj_1_idx3_val = HEAP32[$pobj_1 + 12 >> 2];
    var $46 = __ZN2js13PropertyCache10matchShapeEP9JSContextP8JSObjectj($pobj_1_idx3_val, $vcap_1 >>> 8);
    if ($46) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    HEAP32[$pobjp >> 2] = $pobj_1;
    var $_0 = 0;
    __label__ = 18;
    break;
   case 17:
    var $49 = __ZL19GetAtomFromBytecodeP9JSContextPh4JSOpRK10JSCodeSpec($cx, $pc, $3, $4);
    var $_0 = $49;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13PropertyCache8fullTestEP9JSContextPhPP8JSObjectS6_PNS_18PropertyCacheEntryE["X"] = 1;

function __ZL19GetAtomFromBytecodeP9JSContextPh4JSOpRK10JSCodeSpec($cx, $pc, $op, $cs) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($op | 0) == 220) {
      __label__ = 2;
      break;
    } else if (($op | 0) == 114) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    __label__ = 8;
    break;
   case 3:
    var $_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 210200 >> 2] | 0;
    __label__ = 8;
    break;
   case 4:
    var $14 = $cx + 60 | 0;
    var $15 = __ZNK2js12ContextStack13currentScriptEPPh($14, 0);
    var $20 = (HEAP32[$cs + 4 >> 2] & 31 | 0) == 8 ? 2 : 0;
    var $21 = _js_GetIndexFromBytecode($15, $pc, $20);
    var $23 = HEAPU32[$15 >> 2];
    if ($23 >>> 0 > $pc >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($23 + HEAP32[$15 + 8 >> 2] | 0) >>> 0 > $pc >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $33 = HEAP32[$cx + 52 >> 2] + 209948 | 0;
    var $34 = __ZN11JSAtomState16commonAtomsStartEv($33);
    var $_0 = HEAP32[$34 + ($21 << 2) >> 2];
    __label__ = 8;
    break;
   case 7:
    var $_idx_val = HEAP32[$15 + 56 >> 2];
    var $38 = __ZN8JSScript7getAtomEj($_idx_val, $21);
    var $_0 = $38;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13PropertyCache5purgeEP9JSContext($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 65536 | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZN2jsL12PodArrayZeroINS_18PropertyCacheEntryELj4096EEEvRAT0__T_($5);
    HEAP32[$1 >> 2] = 1;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL12PodArrayZeroINS_18PropertyCacheEntryELj4096EEEvRAT0__T_($t) {
  var $1 = $t;
  _memset($1, 0, 65536, 1);
  return;
}

function __ZN2js12PropertyTree8newShapeEP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z13js_NewGCShapeP9JSContext($cx);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $cx;
    _JS_ReportOutOfMemory($4);
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z13js_NewGCShapeP9JSContext($cx) {
  var $1 = __Z10NewGCThingIN2js5ShapeEEPT_P9JSContextNS0_2gc9AllocKindEj($cx);
  return $1;
}

function __ZN2js12PropertyTree11insertChildEP9JSContextPNS_5ShapeES4_($cx, $parent, $child) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $child;
    var $2 = $parent + 36 | 0;
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js11KidsPointer6isNullEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js5Shape9setParentEPS0_($child, $parent);
    __ZN2js11KidsPointer8setShapeEPNS_5ShapeE($2, $child);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 3:
    var $6 = __ZNK2js11KidsPointer7isShapeEv($_idx_val);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $8 = __ZNK2js11KidsPointer7toShapeEv($_idx_val);
    var $9 = __ZL12HashChildrenPN2js5ShapeES1_($8, $child);
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $12 = $cx;
    _JS_ReportOutOfMemory($12);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 6:
    __ZN2js11KidsPointer7setHashEPNS_7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEE($2, $9);
    __ZN2js5Shape9setParentEPS0_($child, $parent);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 7:
    var $15 = __ZNK2js11KidsPointer6toHashEv($_idx_val);
    var $16 = __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6putNewERKS2_($15, $1);
    if ($16) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $18 = $cx;
    _JS_ReportOutOfMemory($18);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 9:
    var $20 = HEAP32[$1 >> 2];
    __ZN2js5Shape9setParentEPS0_($20, $parent);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js11KidsPointer7isShapeEv($this_0_0_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_0_val & 1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2js11KidsPointer6isNullEv($this_0_0_val);
    var $7 = $4 ^ 1;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12HashChildrenPN2js5ShapeES1_($kid1, $kid2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $kid1;
    HEAP32[$2 >> 2] = $kid2;
    var $3 = __ZN2js11OffTheBooks4new_INS_7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEEEEPT_v();
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE4initEj($3);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js10Foreground7delete_INS_7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEEEEvPT_($3);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $9 = __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6putNewERKS2_($3, $1);
    var $10 = __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6putNewERKS2_($3, $2);
    var $_0 = $3;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6putNewERKS2_($this, $t) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $p = __stackBase__;
  var $1 = __stackBase__ + 8;
  var $2 = HEAP32[$t >> 2];
  HEAP32[$1 >> 2] = $2;
  __ZNK2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE12lookupForAddERKPKS1_($p, $this, $1);
  var $3 = __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS5_6SetOpsES4_E6AddPtrERS8_($this, $p, $t);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN2js5Shape11removeChildEPS0_($this, $child) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 36 | 0;
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js11KidsPointer7isShapeEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js11KidsPointer7setNullEv($2);
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZNK2js11KidsPointer6toHashEv($_idx_val);
    HEAP32[$1 >> 2] = $child;
    __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6removeERKPKS1_($6, $1);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6removeERKPKS1_($this, $l) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 4;
    __ZNK2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6lookupERKPKS1_($p, $this, $l);
    var $p_idx_val = HEAP32[$p >> 2];
    var $p_idx_val_idx_val = HEAP32[$p_idx_val >> 2];
    __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrcvMSB_FvvEEv($1, $p_idx_val_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS5_6SetOpsES4_E3PtrE($this, $p_idx_val);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12PropertyTree8getChildEP9JSContextPNS_5ShapeERKS3_($cx, $parent, $child) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $_idx_val = HEAP32[$parent + 36 >> 2];
    var $3 = __ZNK2js11KidsPointer7isShapeEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZNK2js11KidsPointer7toShapeEv($_idx_val);
    var $6 = __ZNK2js5Shape7matchesEPKS0_($5, $child);
    if ($6) {
      var $_0 = $5;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $8 = __ZNK2js11KidsPointer6isHashEv($_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = __ZNK2js11KidsPointer6toHashEv($_idx_val);
    HEAP32[$1 >> 2] = $child;
    __ZNK2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6lookupERKPKS1_($2, $10, $1);
    var $_idx5_val = HEAP32[$2 >> 2];
    var $11 = __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrdeEv($_idx5_val);
    var $12 = HEAPU32[$11 >> 2];
    if (($12 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $12;
      __label__ = 8;
      break;
    }
   case 5:
    var $15 = __ZN2js12PropertyTree8newShapeEP9JSContext($cx);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = HEAP32[$child + 12 >> 2];
    var $21 = HEAP32[$child + 16 >> 2];
    var $23 = HEAP32[$child + 20 >> 2];
    var $25 = HEAP32[$child + 24 >> 2];
    var $28 = HEAPU8[$child + 28 | 0] & 255;
    var $31 = HEAPU8[$child + 29 | 0] & 255;
    var $34 = HEAP16[$child + 30 >> 1] << 16 >> 16;
    var $_idx3_val = HEAP32[$cx + 52 >> 2];
    var $36 = __Z16js_GenerateShapeP9JSContext($_idx3_val);
    __ZN2js5ShapeC1EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj($15, $19, $21, $23, $25, $28, $31, $34, $36, 0);
    var $37 = __ZN2js12PropertyTree11insertChildEP9JSContextPNS_5ShapeES4_($cx, $parent, $15);
    if ($37) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $_0 = $15;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js12PropertyTree8getChildEP9JSContextPNS_5ShapeERKS3_["X"] = 1;

function __ZNK2js5Shape7matchesEPKS0_($this, $other) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 12 >> 2] | 0) == (HEAP32[$other + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      var $24 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = HEAP32[$other + 16 >> 2];
    var $10 = HEAP32[$other + 20 >> 2];
    var $12 = HEAP32[$other + 24 >> 2];
    var $15 = HEAPU8[$other + 28 | 0] & 255;
    var $18 = HEAPU8[$other + 29 | 0] & 255;
    var $21 = HEAP16[$other + 30 >> 1] << 16 >> 16;
    var $22 = __ZNK2js5Shape20matchesParamsAfterIdEPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjji($this, $8, $10, $12, $15, $18, $21);
    var $24 = $22;
    __label__ = 3;
    break;
   case 3:
    var $24;
    return $24;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6lookupERKPKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6lookupERKPKS2_($agg_result, $1, $l);
  return;
}

function __ZN2js5ShapeC1EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj($this, $propid, $getter, $setter, $slot, $attrs, $flags, $shortid, $shapeid, $slotSpan) {
  __ZN2js5ShapeC2EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj($this, $propid, $getter, $setter, $slot, $attrs, $flags, $shortid, $shapeid, $slotSpan);
  return;
}

function __ZN2js5Shape8finalizeEP9JSContext($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP8[$this + 29 | 0];
    var $2 = __ZNK2js5Shape12inDictionaryEv($_idx_val);
    if ($2) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $this + 32 | 0;
    var $5 = HEAP32[$4 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $5;
    var $9 = __ZNK2js2gc4Cell8isMarkedEj($8);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = HEAP32[$4 >> 2];
    __ZN2js5Shape11removeChildEPS0_($11, $this);
    __label__ = 5;
    break;
   case 5:
    var $_idx2_val = HEAP32[$this + 36 >> 2];
    var $13 = __ZNK2js11KidsPointer6isHashEv($_idx2_val);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $15 = __ZNK2js11KidsPointer6toHashEv($_idx2_val);
    __ZN9JSContext7delete_IN2js7HashSetIPNS1_5ShapeENS1_11ShapeHasherENS1_17SystemAllocPolicyEEEEEvPT_($15);
    __label__ = 7;
    break;
   case 7:
    __ZN2js5Shape9freeTableEP9JSContext($this);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext7delete_IN2js7HashSetIPNS1_5ShapeENS1_11ShapeHasherENS1_17SystemAllocPolicyEEEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEED1Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5Shape9freeTableEP9JSContext($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this + 8 >> 2];
    var $2 = __ZNK2js5Shape8hasTableEv($_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this;
    var $5 = __ZNK2js5Shape8getTableEv($4);
    var $6 = $5;
    __ZN9JSContext7delete_IN2js13PropertyTableEEEvPT_($6);
    __ZNK2js5Shape8setTableEPNS_13PropertyTableE($this, 0);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function _js_free3045($p) {
  _free($p);
  return;
}

function __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED1Ev($this_0_5_val) {
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED2Ev($this_0_5_val);
  return;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED2Ev($this_0_5_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_5_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12destroyTableERS7_PNS0_14HashTableEntryIS4_EEj($this_0_5_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12destroyTableERS7_PNS0_14HashTableEntryIS4_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv($0);
  return;
}

function __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6lookupERKPKS2_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11prepareHashERKPKS2_($l_val);
  var $2 = __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6lookupERKPKS2_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrC1ERNS0_14HashTableEntryIS4_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11prepareHashERKPKS2_($l_val) {
  var $1 = __ZN2js11ShapeHasher4hashEPKNS_5ShapeE($l_val);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrC1ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry);
  return;
}

function __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_($t) {
  return $t;
}

function __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_5ShapeEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefIPNS_5ShapeEEcvRS2_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js14JSProxyHandlerD2Ev($this) {
  return;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE12hasCollisionEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10overloadedEv($this_0_1_val, $this_0_2_val, $this_0_4_val) {
  return ($this_0_4_val + $this_0_2_val | 0) >>> 0 >= ($this_0_1_val * 192 | 0) >>> 8 >>> 0;
}

function _INT_TO_JSID3072($i) {
  return $i << 1 | 1;
}

function __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZNK2js5Shape4hashEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 16 >> 2];
    if (($2 | 0) == 0) {
      var $hash_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $hash_0 = $2;
    __label__ = 3;
    break;
   case 3:
    var $hash_0;
    var $8 = HEAPU32[$this + 20 >> 2];
    if (($8 | 0) == 0) {
      var $hash_1 = $hash_0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $hash_1 = ($hash_0 << 4 | $hash_0 >>> 28) ^ $8;
    __label__ = 5;
    break;
   case 5:
    var $hash_1;
    var $24 = HEAPU8[$this + 29 | 0] & 255 & 192 ^ ($hash_1 << 4 | $hash_1 >>> 28);
    var $31 = ($24 << 4 | $24 >>> 28) ^ HEAPU8[$this + 28 | 0] & 255;
    var $38 = ($31 << 4 | $31 >>> 28) ^ HEAP16[$this + 30 >> 1] << 16 >> 16;
    var $44 = ($38 << 4 | $38 >>> 28) ^ HEAP32[$this + 24 >> 2];
    return ($44 << 4 | $44 >>> 28) ^ HEAP32[$this + 12 >> 2];
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js5Shape4hashEv["X"] = 1;

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_5ShapeEEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefIPNS_5ShapeEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_5ShapeEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE10setRemovedEv($this) {
  HEAP32[$this >> 2] = 1;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE7setFreeEv($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZNK2js5Shape8setTableEPNS_13PropertyTableE($this, $t) {
  HEAP32[$this + 8 >> 2] = $t;
  return;
}

function __ZNK2js5Shape20matchesParamsAfterIdEPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjji($this, $agetter, $asetter, $aslot, $aattrs, $aflags, $ashortid) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 16 >> 2] | 0) == ($agetter | 0)) {
      __label__ = 2;
      break;
    } else {
      var $30 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    if ((HEAP32[$this + 20 >> 2] | 0) == ($asetter | 0)) {
      __label__ = 3;
      break;
    } else {
      var $30 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    if ((HEAP32[$this + 24 >> 2] | 0) == ($aslot | 0)) {
      __label__ = 4;
      break;
    } else {
      var $30 = 0;
      __label__ = 7;
      break;
    }
   case 4:
    if ((HEAPU8[$this + 28 | 0] & 255 | 0) == ($aattrs | 0)) {
      __label__ = 5;
      break;
    } else {
      var $30 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    if (((HEAPU8[$this + 29 | 0] & 255 ^ $aflags) & 192 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $30 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $30 = (HEAP16[$this + 30 >> 1] << 16 >> 16 | 0) == ($ashortid | 0);
    __label__ = 7;
    break;
   case 7:
    var $30;
    return $30;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC2ES7_($this) {
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  return;
}

function __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6lookupERKPKS2_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 3) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $l_val4 = HEAP32[$l >> 2];
    var $11 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5matchERNS0_14HashTableEntryIS4_EERKPKS2_($6, $l_val4);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + ($26 << 3) | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $l_val = HEAP32[$l >> 2];
    var $35 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5matchERNS0_14HashTableEntryIS4_EERKPKS2_($27, $l_val);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6lookupERKPKS2_jj["X"] = 1;

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5matchERNS0_14HashTableEntryIS4_EERKPKS2_($e, $l_val) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_($1);
  var $3 = HEAP32[$2 >> 2];
  var $4 = __ZN2js11ShapeHasher5matchEPNS_5ShapeEPKS1_($3, $l_val);
  return $4;
}

function __ZN2js11ShapeHasher5matchEPNS_5ShapeEPKS1_($k, $l) {
  var $1 = __ZNK2js5Shape7matchesEPKS0_($l, $k);
  return $1;
}

function __ZN2js11ShapeHasher4hashEPKNS_5ShapeE($l) {
  var $1 = __ZNK2js5Shape4hashEv($l);
  return $1;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE10isLiveHashEj($hash);
  return $1;
}

function __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrcvMSB_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 212,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS5_6SetOpsES4_E3PtrE($this, $p_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6removeENSA_3PtrE($1, $p_0);
  return;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6removeENSA_3PtrE($this, $p_0) {
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6removeERNS0_14HashTableEntryIS4_EE($this, $p_0);
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16checkUnderloadedEv($this);
  return;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6removeERNS0_14HashTableEntryIS4_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e_idx_val = HEAP32[$e >> 2];
    var $1 = __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE12hasCollisionEv($e_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11createTableERS7_j($10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + ($5 << 3) | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 5;
    break;
   case 5:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $22 = __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE6isLiveEv($src_01_idx_val);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE10getKeyHashEv($src_01_idx1_val);
    var $25 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryIKPNS_5ShapeEEEEENS_7MoveRefIT_EERS8_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryIKPNS_5ShapeEEaSENS_7MoveRefIS5_EE($25, $_02_val);
    __label__ = 7;
    break;
   case 7:
    var $27 = $src_01 + 8 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12destroyTableERS7_PNS0_14HashTableEntryIS4_EEj($3);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11createTableERS7_j($capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 3;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej($1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + ($capacity << 3) | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryIKPNS_5ShapeEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 8 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 3) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + ($15 << 3) | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryIKPNS_5ShapeEEaSENS_7MoveRefIS5_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_5ShapeEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $2 + 4 | 0;
  __ZN2js4MoveIPNS_5ShapeEEENS_7MoveRefIT_EERS4_($1, $6);
  var $_idx_val = HEAP32[$1 >> 2];
  var $7 = __ZNK2js7MoveRefIPNS_5ShapeEEcvRS2_Ev($_idx_val);
  var $8 = HEAP32[$7 >> 2];
  HEAP32[$this + 4 >> 2] = $8;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryIKPNS_5ShapeEEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_5ShapeEEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_5ShapeEEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_5ShapeEEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js4MoveIPNS_5ShapeEEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefIPNS_5ShapeEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIPNS_5ShapeEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIPNS_5ShapeEEC2ERS2_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_5ShapeEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryIKPNS_5ShapeEEC2Ev($this);
  return;
}

function _js_malloc3046() {
  var $1 = _malloc(24);
  return $1;
}

function __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZNK2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE12lookupForAddERKPKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12lookupForAddERKPKS2_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS5_6SetOpsES4_E6AddPtrERS8_($this, $p, $t) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrERS4_($1, $p, $t);
  return $2;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrERS4_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$t >> 2];
    var $6 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$6 >> 2] = $3;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 8 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 16 >> 2];
    var $12 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12lookupForAddERKPKS2_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11prepareHashERKPKS2_($l_val);
  var $2 = __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6lookupERKPKS2_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrC2ERNS0_14HashTableEntryIS4_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN9JSContext7delete_IN2js13PropertyTableEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $p_idx_val = HEAP32[$p + 16 >> 2];
    __ZN2js13PropertyTableD1Ev($p_idx_val);
    var $3 = $p;
    __ZN9JSContext5free_EPv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13PropertyTableD1Ev($this_0_4_val) {
  __ZN2js13PropertyTableD2Ev($this_0_4_val);
  return;
}

function __ZN2js13PropertyTableD2Ev($this_0_4_val) {
  var $1 = $this_0_4_val;
  __ZN2js10Foreground5free_EPv($1);
  return;
}

function __ZN2js5ShapeC2EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj($this, $propid, $getter, $setter, $slot, $attrs, $flags, $shortid, $shapeid, $slotSpan) {
  HEAP32[$this >> 2] = $shapeid;
  HEAP32[$this + 4 >> 2] = $slotSpan;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = $propid;
  HEAP32[$this + 16 >> 2] = $getter;
  HEAP32[$this + 20 >> 2] = $setter;
  HEAP32[$this + 24 >> 2] = $slot;
  HEAP8[$this + 28 | 0] = $attrs & 255;
  HEAP8[$this + 29 | 0] = $flags & 255;
  HEAP16[$this + 30 >> 1] = $shortid & 65535;
  HEAP32[$this + 32 >> 2] = 0;
  var $15 = $this + 36 | 0;
  __ZN2js11KidsPointer7setNullEv($15);
  return;
}

function __ZN2js11OffTheBooks4new_INS_7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEEEEPT_v() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_malloc3046();
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEC1ES4_($4);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4initEj($1);
  return $2;
}

function __ZN2js10Foreground7delete_INS_7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEED1Ev($p);
    var $3 = $p;
    _js_free3045($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $0 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11createTableERS7_j(16);
    HEAP32[$this + 20 >> 2] = $0;
    if (($0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16setTableSizeLog2Ej($this, 4);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEC1ES4_($this) {
  __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEC2ES4_($this);
  return;
}

function __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEC2ES4_($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC1ES7_($1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC1ES7_($this) {
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC2ES7_($this);
  return;
}

function __Z10NewGCThingIN2js5ShapeEEPT_P9JSContextNS0_2gc9AllocKindEj($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAP32[$cx + 56 >> 2] + 8 | 0;
    var $5 = __ZN2js2gc10ArenaLists20allocateFromFreeListENS0_9AllocKindEj($4, 14, 40);
    if (($5 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $11 = $5;
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $cx;
    var $9 = __ZN2js2gc10ArenaLists14refillFreeListEP9JSContextNS0_9AllocKindE($8, 14);
    var $11 = $9;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14JSProxyHandler3hasEP9JSContextP8JSObjectiPb($this, $cx, $proxy, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $desc = __stackBase__;
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($desc, $cx);
    var $4 = HEAP32[HEAP32[$this >> 2] + 8 >> 2];
    var $5 = $desc + 16 | 0;
    var $6 = FUNCTION_TABLE[$4]($this, $cx, $proxy, $id, 0, $5);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    HEAP8[$bp] = (HEAP32[$desc + 16 >> 2] | 0) != 0 & 1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14JSProxyHandler6hasOwnEP9JSContextP8JSObjectiPb($this, $cx, $proxy, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $desc = __stackBase__;
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($desc, $cx);
    var $4 = HEAP32[HEAP32[$this >> 2] + 12 >> 2];
    var $5 = $desc + 16 | 0;
    var $6 = FUNCTION_TABLE[$4]($this, $cx, $proxy, $id, 0, $5);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    HEAP8[$bp] = (HEAP32[$desc + 16 >> 2] | 0) != 0 & 1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14JSProxyHandler3getEP9JSContextP8JSObjectS4_iPN2JS5ValueE($this, $cx, $proxy, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $desc = __stackBase__;
    var $1 = __stackBase__ + 48;
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($desc, $cx);
    var $5 = HEAP32[HEAP32[$this >> 2] + 8 >> 2];
    var $6 = $desc + 16 | 0;
    var $7 = FUNCTION_TABLE[$5]($this, $cx, $proxy, $id, 0, $6);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 2:
    if ((HEAP32[$desc + 16 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 15;
    break;
   case 4:
    var $14 = $desc + 24 | 0;
    var $15 = HEAP32[$14 >> 2];
    if (($15 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = $desc + 20 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $21 = ($19 & 16 | 0) == 0;
    if ($21 & ($15 | 0) == 10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $24 = $desc + 32 | 0;
    var $st$1$0 = $24 | 0;
    var $25$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $24 + 4 | 0;
    var $25$1 = HEAP32[$st$1$1 >> 2];
    var $26 = $vp | 0;
    var $st$6$0 = $26 | 0;
    HEAP32[$st$6$0 >> 2] = $25$0;
    var $st$6$1 = $26 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $25$1;
    var $_0 = 1;
    __label__ = 15;
    break;
   case 7:
    if ($21) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2js17CastAsObjectJsvalEPFiP9JSContextP8JSObjectiPN2JS5ValueEE($1, $15);
    var $29 = __ZN2js20InvokeGetterOrSetterEP9JSContextP8JSObjectRKN2JS5ValueEjPS5_S8_($cx, $receiver, $1, 0, 0, $vp);
    var $_0 = $29;
    __label__ = 15;
    break;
   case 9:
    if (($19 & 64 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $34 = $desc + 32 | 0;
    var $st$1$0 = $34 | 0;
    var $35$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $34 + 4 | 0;
    var $35$1 = HEAP32[$st$1$1 >> 2];
    var $36 = $vp | 0;
    var $st$6$0 = $36 | 0;
    HEAP32[$st$6$0 >> 2] = $35$0;
    var $st$6$1 = $36 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $35$1;
    var $39 = $19;
    __label__ = 12;
    break;
   case 11:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $39 = HEAP32[$18 >> 2];
    __label__ = 12;
    break;
   case 12:
    var $39;
    if (($39 & 256 | 0) == 0) {
      var $_01 = $id;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $44 = HEAP32[$desc + 40 >> 2];
    var $45 = _INT_TO_JSID3072($44);
    var $_01 = $45;
    __label__ = 14;
    break;
   case 14:
    var $_01;
    var $47 = $cx;
    var $48 = HEAP32[$14 >> 2];
    var $49 = $receiver;
    var $50 = __ZN2js16CallJSPropertyOpEP9JSContextPFiS1_P8JSObjectiPN2JS5ValueEES3_iS6_($47, $48, $49, $_01, $vp);
    var $_0 = $50;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js14JSProxyHandler3getEP9JSContextP8JSObjectS4_iPN2JS5ValueE["X"] = 1;

function __ZN2js14JSProxyHandler8finalizeEP9JSContextP8JSObject($this, $cx, $proxy) {
  return;
}

function __ZN2js14JSProxyHandler5traceEP8JSTracerP8JSObject($this, $trc, $proxy) {
  return;
}

function __ZL24IndicatePropertyNotFoundP9JSContextP20JSPropertyDescriptor($desc) {
  HEAP32[$desc >> 2] = 0;
  return;
}

function __ZN2js14JSProxyHandler3setEP9JSContextP8JSObjectS4_ibPN2JS5ValueE($this, $cx, $proxy, $receiver, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $desc = __stackBase__;
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($desc, $cx);
    var $1 = $this;
    var $4 = HEAP32[HEAP32[$1 >> 2] + 12 >> 2];
    var $5 = $desc + 16 | 0;
    var $6 = FUNCTION_TABLE[$4]($this, $cx, $proxy, $id, 1, $5);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 2:
    var $8 = $5 | 0;
    if ((HEAP32[$8 >> 2] | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $desc + 20 | 0;
    var $13 = HEAPU32[$12 >> 2];
    if (($13 & 2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 4:
    var $17 = $desc + 28 | 0;
    var $18 = HEAPU32[$17 >> 2];
    if (($18 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    HEAP32[$17 >> 2] = 12;
    __label__ = 11;
    break;
   case 6:
    if (($13 & 32 | 0) == 0 & ($18 | 0) == 12) {
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $27 = HEAP32[$desc + 40 >> 2];
    var $28 = $strict & 1;
    var $29 = $cx;
    var $30 = $receiver;
    var $31 = $18;
    var $32 = __ZN2js10CallSetterEP9JSContextP8JSObjectiPFiS1_S3_iiPN2JS5ValueEEjjiS6_($29, $30, $id, $31, $13, $27, $28, $vp);
    if ($32) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 8:
    var $proxy_idx1_val = HEAP32[$proxy + 4 >> 2];
    var $34 = __ZNK8JSObject7isProxyEv($proxy_idx1_val);
    if ($34) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 9:
    var $36 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    if (($36 | 0) == ($this | 0)) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 10:
    if ((HEAP32[$12 >> 2] & 64 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 11:
    var $43 = $desc + 24 | 0;
    if ((HEAP32[$43 >> 2] | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    HEAP32[$43 >> 2] = 10;
    __label__ = 13;
    break;
   case 13:
    var $48 = $vp | 0;
    var $49$0 = HEAP32[$48 >> 2];
    var $49$1 = HEAP32[$48 + 4 >> 2];
    var $50 = $desc + 32 | 0;
    HEAP32[$50 >> 2] = $49$0;
    HEAP32[$50 + 4 >> 2] = $49$1;
    var $54 = HEAP32[HEAP32[$this >> 2] + 16 >> 2];
    var $55 = FUNCTION_TABLE[$54]($this, $cx, $receiver, $id, $5);
    var $_0 = $55;
    __label__ = 28;
    break;
   case 14:
    var $59 = HEAP32[HEAP32[$1 >> 2] + 8 >> 2];
    var $60 = FUNCTION_TABLE[$59]($this, $cx, $proxy, $id, 1, $5);
    if ($60) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 15:
    if ((HEAP32[$8 >> 2] | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $65 = $desc + 20 | 0;
    var $66 = HEAPU32[$65 >> 2];
    if (($66 & 2 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 17:
    var $70 = $desc + 28 | 0;
    var $71 = HEAPU32[$70 >> 2];
    if (($71 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    HEAP32[$70 >> 2] = 12;
    __label__ = 24;
    break;
   case 19:
    if (($66 & 32 | 0) == 0 & ($71 | 0) == 12) {
      __label__ = 24;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $80 = HEAP32[$desc + 40 >> 2];
    var $81 = $strict & 1;
    var $82 = $cx;
    var $83 = $receiver;
    var $84 = $71;
    var $85 = __ZN2js10CallSetterEP9JSContextP8JSObjectiPFiS1_S3_iiPN2JS5ValueEEjjiS6_($82, $83, $id, $84, $66, $80, $81, $vp);
    if ($85) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 21:
    var $proxy_idx_val = HEAP32[$proxy + 4 >> 2];
    var $87 = __ZNK8JSObject7isProxyEv($proxy_idx_val);
    if ($87) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 22:
    var $89 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    if (($89 | 0) == ($this | 0)) {
      __label__ = 23;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 23:
    if ((HEAP32[$65 >> 2] & 64 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 24:
    var $96 = $desc + 24 | 0;
    if ((HEAP32[$96 >> 2] | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    HEAP32[$96 >> 2] = 10;
    __label__ = 26;
    break;
   case 26:
    var $104 = HEAP32[HEAP32[$this >> 2] + 16 >> 2];
    var $105 = FUNCTION_TABLE[$104]($this, $cx, $receiver, $id, $5);
    var $_0 = $105;
    __label__ = 28;
    break;
   case 27:
    HEAP32[$8 >> 2] = $receiver;
    var $107 = $vp | 0;
    var $108$0 = HEAP32[$107 >> 2];
    var $108$1 = HEAP32[$107 + 4 >> 2];
    var $109 = $desc + 32 | 0;
    HEAP32[$109 >> 2] = $108$0;
    HEAP32[$109 + 4 >> 2] = $108$1;
    HEAP32[$desc + 20 >> 2] = 1;
    HEAP32[$desc + 40 >> 2] = 0;
    HEAP32[$desc + 24 >> 2] = 0;
    HEAP32[$desc + 28 >> 2] = 0;
    var $117 = HEAP32[HEAP32[$this >> 2] + 16 >> 2];
    var $118 = FUNCTION_TABLE[$117]($this, $cx, $receiver, $id, $5);
    var $_0 = $118;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js14JSProxyHandler3setEP9JSContextP8JSObjectS4_ibPN2JS5ValueE["X"] = 1;

function __ZNK8JSObject15getProxyHandlerEv($this) {
  var $1 = __ZNK8JSObject7getSlotEj($this, 0);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $2 = __ZNK2JS5Value9toPrivateEv($_idx_val$0, $_idx_val$1);
  return $2;
}

function __ZN2js14JSProxyHandler4keysEP9JSContextP8JSObjectRNS_12AutoIdVectorE($this, $cx, $proxy, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $desc = __stackBase__;
    var $4 = HEAP32[HEAP32[$this >> 2] + 20 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $proxy, $props);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($desc, $cx);
    var $7 = $props | 0;
    var $8 = __ZNK2js16AutoVectorRooterIiE6lengthEv($7);
    var $9 = $this;
    var $10 = $desc + 16 | 0;
    var $11 = $desc + 16 | 0;
    var $12 = $desc + 20 | 0;
    var $j_0 = 0;
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    var $j_0;
    if ($j_0 >>> 0 < $8 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    var $16 = __ZN2js16AutoVectorRooterIiEixEj($7, $j_0);
    var $17 = HEAP32[$16 >> 2];
    var $20 = HEAP32[HEAP32[$9 >> 2] + 12 >> 2];
    var $21 = FUNCTION_TABLE[$20]($this, $cx, $proxy, $17, 0, $10);
    if ($21) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 5:
    if ((HEAP32[$11 >> 2] | 0) == 0) {
      var $i_1 = $i_0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$12 >> 2] & 1 | 0) == 0) {
      var $i_1 = $i_0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $30 = $i_0 + 1 | 0;
    var $31 = __ZN2js16AutoVectorRooterIiEixEj($7, $i_0);
    HEAP32[$31 >> 2] = $17;
    var $i_1 = $30;
    __label__ = 8;
    break;
   case 8:
    var $i_1;
    var $j_0 = $j_0 + 1 | 0;
    var $i_0 = $i_1;
    __label__ = 3;
    break;
   case 9:
    var $35 = __ZN2js16AutoVectorRooterIiE6resizeEj($7, $i_0);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
    var $_1 = $_0;
    __label__ = 11;
    break;
   case 11:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16AutoVectorRooterIiE6resizeEj($this, $newLength) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    var $_idx = $this + 20 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $2 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE6lengthEv($_idx_val);
    if ($2 >>> 0 < $newLength >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 - $newLength | 0;
    __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE8shrinkByEj($1, $5);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $7 = $newLength - $2 | 0;
    var $8 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE19growByUninitializedEj($1, $7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx1_val = HEAP32[$this + 16 >> 2];
    var $10 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE5beginEv($_idx1_val);
    var $11 = $10 + ($2 << 2) | 0;
    var $_idx3_val = HEAP32[$_idx >> 2];
    var $12 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE3endEv($_idx1_val, $_idx3_val);
    __ZN2jsL15MakeRangeGCSafeEPiS0_($11, $12);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14JSProxyHandler7iterateEP9JSContextP8JSObjectjPN2JS5ValueE($this, $cx, $proxy, $flags, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $props = __stackBase__;
    __ZN2js12AutoIdVectorC1EP9JSContext($props, $cx);
    var $4 = HEAP32[$this >> 2];
    if (($flags & 8 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$4 + 52 >> 2];
    var $8 = FUNCTION_TABLE[$7]($this, $cx, $proxy, $props);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $11 = HEAP32[$4 + 28 >> 2];
    var $12 = FUNCTION_TABLE[$11]($this, $cx, $proxy, $props);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = $cx;
    var $15 = $proxy;
    var $16 = $props;
    var $17 = __ZN2js28EnumeratedIdVectorToIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE($14, $15, $flags, $16, $vp);
    var $_0 = $17;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    __ZN2js12AutoIdVectorD1Ev($props);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14JSProxyHandler12obj_toStringEP9JSContextP8JSObject($this, $cx, $proxy) {
  var $proxy_idx_val = HEAP32[$proxy + 4 >> 2];
  var $1 = __ZNK8JSObject15isFunctionProxyEv($proxy_idx_val);
  var $2 = $1 ? STRING_TABLE.__str3048 | 0 : STRING_TABLE.__str4127 | 0;
  var $3 = _JS_NewStringCopyZ($cx, $2);
  return $3;
}

function __ZN2js14JSProxyHandler12fun_toStringEP9JSContextP8JSObjectj($this, $cx, $proxy, $indent) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL7GetCallP8JSObject($proxy);
    var $2 = $1 | 0;
    var $3$0 = HEAP32[$2 >> 2];
    var $3$1 = HEAP32[$2 + 4 >> 2];
    var $proxy_idx_val = HEAP32[$proxy + 4 >> 2];
    var $4 = __ZNK8JSObject15isFunctionProxyEv($proxy_idx_val);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_pre = __ZNK2JS5Value8toObjectEv($3$0, $3$1);
    var $_pre_phi = $_pre;
    __label__ = 6;
    break;
   case 3:
    var $6 = __ZNK2JS5Value11isPrimitiveEv($3$0, $3$1);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toObjectEv($3$0, $3$1);
    var $_idx_val = HEAP32[$8 + 4 >> 2];
    var $9 = __ZNK8JSObject10isFunctionEv($_idx_val);
    if ($9) {
      var $_pre_phi = $8;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 4, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str73060 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE._js_toString_str | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str267560 | 0, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $_pre_phi;
    var $12 = __Z18fun_toStringHelperP9JSContextP8JSObjectj($cx, $_pre_phi, $indent);
    var $_0 = $12;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL7GetCallP8JSObject($proxy) {
  var $1 = __ZNK8JSObject7getSlotEj($proxy, 3);
  return $1;
}

function __ZN2js14JSProxyHandler12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE($this, $cx, $proxy, $hint, $vp) {
  var $1 = $cx;
  var $2 = $proxy;
  var $3 = __ZN2js12DefaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE($1, $2, $hint, $vp);
  return ($3 | 0) != 0;
}

function __ZN2js14JSProxyHandler4callEP9JSContextP8JSObjectjPN2JS5ValueE($this, $cx, $proxy, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $rval = __stackBase__;
    __ZN2js15AutoValueRooterC1EP9JSContext($rval, $cx);
    var $1 = $vp + 8 | 0;
    var $2 = __ZL7GetCallP8JSObject($proxy);
    var $3 = $vp + 16 | 0;
    var $4 = __ZN2js15AutoValueRooter4addrEv($rval);
    var $5 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $1, $2, $argc, $3, $4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZNK2js15AutoValueRooter5valueEv($rval);
    var $8 = $7 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $vp | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    __label__ = 3;
    break;
   case 3:
    __ZN2js15AutoValueRooterD1Ev($rval);
    STACKTOP = __stackBase__;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14JSProxyHandler9constructEP9JSContextP8JSObjectjPN2JS5ValueES7_($this, $cx, $proxy, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fval = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZL12GetConstructP8JSObject($fval, $proxy);
    var $fval_idx = $fval | 0;
    var $fval_idx_val$0 = HEAP32[$fval_idx >> 2];
    var $fval_idx_val$1 = HEAP32[$fval_idx + 4 >> 2];
    var $2 = __ZNK2JS5Value11isUndefinedEv($fval_idx_val$0, $fval_idx_val$1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZL7GetCallP8JSObject($proxy);
    var $5 = __ZN2js17InvokeConstructorEP9JSContextRKN2JS5ValueEjPS3_S6_($cx, $4, $argc, $argv, $rval);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv3073($1);
    var $7 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $1, $fval, $argc, $argv, $rval);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12GetConstructP8JSObject($agg_result, $proxy) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $proxy_idx_val = HEAP32[$proxy + 28 >> 2];
    var $1 = __ZNK8JSObject8numSlotsEv($proxy_idx_val);
    if ($1 >>> 0 < 5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JSL14UndefinedValueEv3073($agg_result);
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZNK8JSObject7getSlotEj($proxy, 4);
    var $6 = $5 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $agg_result | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL14UndefinedValueEv3073($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2js14JSProxyHandler11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb($this, $cx, $proxy, $vp, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL11ObjectValueER8JSObject3074($1, $proxy);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $2 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, 31, 1, $_idx_val$0, $_idx_val$1, 0, 0);
  STACKTOP = __stackBase__;
  return 0;
}

function __ZN2JSL11ObjectValueER8JSObject3074($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN2js14JSProxyHandler6typeOfEP9JSContextP8JSObject($this, $cx, $proxy) {
  var $proxy_idx_val = HEAP32[$proxy + 4 >> 2];
  var $1 = __ZNK8JSObject15isFunctionProxyEv($proxy_idx_val);
  var $2 = $1 ? 2 : 1;
  return $2;
}

function __ZN22JSScriptedProxyHandlerD0Ev($this) {
  var $1 = $this;
  __ZdlPv($1);
  return;
}

function __ZN22JSScriptedProxyHandler21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($this, $cx, $proxy, $id, $set, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $2 = $cx + 52 | 0;
    var $6 = HEAP32[HEAP32[$2 >> 2] + 210440 >> 2] | 0;
    var $7 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $8 = __ZL18GetFundamentalTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $1, $6, $7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $26 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $10 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = __ZL5Trap1P9JSContextP8JSObjectN2JS5ValueEiPS4_($cx, $1, $12$0, $12$1, $id, $7);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      var $26 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    var $_idx_val$0 = HEAP32[$11 >> 2];
    var $_idx_val$1 = HEAP32[$11 + 4 >> 2];
    var $15 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZL24IndicatePropertyNotFoundP9JSContextP20JSPropertyDescriptor($desc);
    var $26 = 1;
    __label__ = 7;
    break;
   case 5:
    var $21 = HEAP32[HEAP32[$2 >> 2] + 210440 >> 2] | 0;
    var $22 = __ZL31ReturnedValueMustNotBePrimitiveP9JSContextP8JSObjectP6JSAtomRKN2JS5ValueE($cx, $proxy, $21, $_idx_val$0, $_idx_val$1);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      var $26 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $24 = __ZL29ParsePropertyDescriptorObjectP9JSContextP8JSObjectiRKN2JS5ValueEP20JSPropertyDescriptor($cx, $proxy, $10, $desc);
    var $26 = $24;
    __label__ = 7;
    break;
   case 7:
    var $26;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $26;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy) {
  var $1 = __ZNK8JSObject15getProxyPrivateEv($proxy);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $2 = __ZNK2JS5Value14toObjectOrNullEv($_idx_val$0, $_idx_val$1);
  return $2;
}

function __ZL18GetFundamentalTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $handler, $atom, $fvalp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $bytes = __stackBase__;
    var $1 = __ZL7GetTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $handler, $atom, $fvalp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $fvalp_idx = $fvalp | 0;
    var $fvalp_idx_val$0 = HEAP32[$fvalp_idx >> 2];
    var $fvalp_idx_val$1 = HEAP32[$fvalp_idx + 4 >> 2];
    var $3 = __ZL13js_IsCallableRKN2JS5ValueE3075($fvalp_idx_val$0, $fvalp_idx_val$1);
    if ($3) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN16JSAutoByteStringC1Ev($bytes);
    var $5 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $atom, $bytes);
    var $bytes_idx_val_pre = HEAP32[$bytes >> 2];
    if (($5 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZNK16JSAutoByteString3ptrEv($bytes_idx_val_pre);
    _JS_ReportErrorNumber($cx, 4, 22, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $8, tempInt));
    __label__ = 5;
    break;
   case 5:
    __ZN16JSAutoByteStringD1Ev($bytes_idx_val_pre);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5Trap1P9JSContextP8JSObjectN2JS5ValueEiPS4_($cx, $handler, $_0_0_0_val$0, $_0_0_0_val$1, $id, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    __ZN2jsL9IdToValueEi3076($1, $id);
    var $2 = $cx;
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $3 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($2, $_idx_val$0, $_idx_val$1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setStringEP8JSString($rval, $3);
    var $6 = __ZL4TrapP9JSContextP8JSObjectN2JS5ValueEjPS4_S5_($cx, $handler, $_0_0_0_val$0, $_0_0_0_val$1, 1, $rval, $rval);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL31ReturnedValueMustNotBePrimitiveP9JSContextP8JSObjectP6JSAtomRKN2JS5ValueE($cx, $proxy, $atom, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $bytes = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __ZNK2JS5Value11isPrimitiveEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 2:
    __ZN16JSAutoByteStringC1Ev($bytes);
    var $4 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $atom, $bytes);
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $bytes_idx_val = HEAP32[$bytes >> 2];
    __label__ = 5;
    break;
   case 4:
    __ZN2JSL17ObjectOrNullValueEP8JSObject3078($1, $proxy);
    var $bytes_idx1_val = HEAP32[$bytes >> 2];
    var $7 = __ZNK16JSAutoByteString3ptrEv($bytes_idx1_val);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $8 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, 212, 1, $_idx_val$0, $_idx_val$1, 0, $7);
    var $bytes_idx_val = $bytes_idx1_val;
    __label__ = 5;
    break;
   case 5:
    var $bytes_idx_val;
    __ZN16JSAutoByteStringD1Ev($bytes_idx_val);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL29ParsePropertyDescriptorObjectP9JSContextP8JSObjectiRKN2JS5ValueEP20JSPropertyDescriptor($cx, $obj, $v, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 68;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $descs = __stackBase__;
    __ZN2js23AutoPropDescArrayRooterC1EP9JSContext($descs, $cx);
    var $1 = __ZN2js23AutoPropDescArrayRooter6appendEv($descs);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $5 = __ZN2js8PropDesc10initializeEP9JSContextRKN2JS5ValueEb($1, $4, $v_idx_val$0, $v_idx_val$1, 1);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[$desc >> 2] = $obj;
    var $8 = $1 + 8 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $desc + 16 | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    HEAP32[$desc + 4 >> 2] = HEAPU8[$1 + 32 | 0] & 255;
    var $15 = __ZNK2js8PropDesc6getterEv($1);
    HEAP32[$desc + 8 >> 2] = $15;
    var $18 = __ZNK2js8PropDesc6setterEv($1);
    HEAP32[$desc + 12 >> 2] = $18;
    HEAP32[$desc + 24 >> 2] = 0;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js23AutoPropDescArrayRooterD1Ev($descs);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN22JSScriptedProxyHandler24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($this, $cx, $proxy, $id, $set, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $2 = $cx + 52 | 0;
    var $6 = HEAP32[HEAP32[$2 >> 2] + 210436 >> 2] | 0;
    var $7 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $8 = __ZL18GetFundamentalTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $1, $6, $7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $26 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $10 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = __ZL5Trap1P9JSContextP8JSObjectN2JS5ValueEiPS4_($cx, $1, $12$0, $12$1, $id, $7);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      var $26 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    var $_idx_val$0 = HEAP32[$11 >> 2];
    var $_idx_val$1 = HEAP32[$11 + 4 >> 2];
    var $15 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZL24IndicatePropertyNotFoundP9JSContextP20JSPropertyDescriptor($desc);
    var $26 = 1;
    __label__ = 7;
    break;
   case 5:
    var $21 = HEAP32[HEAP32[$2 >> 2] + 210440 >> 2] | 0;
    var $22 = __ZL31ReturnedValueMustNotBePrimitiveP9JSContextP8JSObjectP6JSAtomRKN2JS5ValueE($cx, $proxy, $21, $_idx_val$0, $_idx_val$1);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      var $26 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $24 = __ZL29ParsePropertyDescriptorObjectP9JSContextP8JSObjectiRKN2JS5ValueEP20JSPropertyDescriptor($cx, $proxy, $10, $desc);
    var $26 = $24;
    __label__ = 7;
    break;
   case 7:
    var $26;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $26;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN22JSScriptedProxyHandler14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor($this, $cx, $proxy, $id, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $fval = __stackBase__ + 24;
    var $1 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    __ZN2js15AutoValueRooterC1EP9JSContext($fval, $cx);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210444 >> 2] | 0;
    var $7 = __ZN2js15AutoValueRooter4addrEv($fval);
    var $8 = __ZL18GetFundamentalTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $1, $6, $7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $23 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $10 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $11 = $cx;
    var $12 = $desc;
    var $13 = __ZN2js27NewPropertyDescriptorObjectEP9JSContextPK20JSPropertyDescriptorPN2JS5ValueE($11, $12, $10);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      var $23 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $15 = __ZNK2js15AutoValueRooter5valueEv($fval);
    var $16 = $15 | 0;
    var $17$0 = HEAP32[$16 >> 2];
    var $17$1 = HEAP32[$16 + 4 >> 2];
    var $18 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $19 = $18 | 0;
    var $20$0 = HEAP32[$19 >> 2];
    var $20$1 = HEAP32[$19 + 4 >> 2];
    var $21 = __ZL5Trap2P9JSContextP8JSObjectN2JS5ValueEiS4_PS4_($cx, $1, $17$0, $17$1, $id, $20$0, $20$1, $10);
    var $23 = $21;
    __label__ = 4;
    break;
   case 4:
    var $23;
    __ZN2js15AutoValueRooterD1Ev($fval);
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $23;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5Trap2P9JSContextP8JSObjectN2JS5ValueEiS4_PS4_($cx, $handler, $_0_0_0_val$0, $_0_0_0_val$1, $id, $_0_0_0_val1$0, $_0_0_0_val1$1, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $argv = __stackBase__ + 8;
    __ZN2jsL9IdToValueEi3076($1, $id);
    var $2 = $cx;
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $3 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($2, $_idx_val$0, $_idx_val$1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setStringEP8JSString($rval, $3);
    var $6 = $argv | 0;
    var $7 = $rval | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $argv | 0;
    HEAP32[$9 >> 2] = $8$0;
    HEAP32[$9 + 4 >> 2] = $8$1;
    var $_04 = $argv + 8 | 0;
    HEAP32[$_04 >> 2] = $_0_0_0_val1$0;
    HEAP32[$_04 + 4 >> 2] = $_0_0_0_val1$1;
    var $10 = __ZL4TrapP9JSContextP8JSObjectN2JS5ValueEjPS4_S5_($cx, $handler, $_0_0_0_val$0, $_0_0_0_val$1, 2, $6, $rval);
    var $_0 = $10;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN22JSScriptedProxyHandler19getOwnPropertyNamesEP9JSContextP8JSObjectRN2js12AutoIdVectorE($this, $cx, $proxy, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210452 >> 2] | 0;
    var $7 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $8 = __ZL18GetFundamentalTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $1, $6, $7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $17 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $10 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = __ZL4TrapP9JSContextP8JSObjectN2JS5ValueEjPS4_S5_($cx, $1, $12$0, $12$1, 0, 0, $7);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      var $17 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_idx1_val$0 = HEAP32[$11 >> 2];
    var $_idx1_val$1 = HEAP32[$11 + 4 >> 2];
    var $15 = __ZL15ArrayToIdVectorP9JSContextRKN2JS5ValueERN2js12AutoIdVectorE($cx, $_idx1_val$0, $_idx1_val$1, $props);
    var $17 = $15;
    __label__ = 4;
    break;
   case 4:
    var $17;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $17;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL4TrapP9JSContextP8JSObjectN2JS5ValueEjPS4_S5_($cx, $handler, $_0_0_0_val$0, $_0_0_0_val$1, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $fval = __stackBase__;
  var $1 = __stackBase__ + 8;
  var $2 = $fval | 0;
  HEAP32[$2 >> 2] = $_0_0_0_val$0;
  HEAP32[$2 + 4 >> 2] = $_0_0_0_val$1;
  __ZN2JSL11ObjectValueER8JSObject3074($1, $handler);
  var $3 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $1, $fval, $argc, $argv, $rval);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZL15ArrayToIdVectorP9JSContextRKN2JS5ValueERN2js12AutoIdVectorE($cx, $array_0_0_0_val$0, $array_0_0_0_val$1, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $length = __stackBase__;
    var $v = __stackBase__ + 4;
    var $id = __stackBase__ + 12;
    var $1 = __ZNK2JS5Value11isPrimitiveEv($array_0_0_0_val$0, $array_0_0_0_val$1);
    if ($1) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($array_0_0_0_val$0, $array_0_0_0_val$1);
    var $4 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $3, $length);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = HEAPU32[$length >> 2];
    var $7 = $cx + 52 | 0;
    var $8 = $props;
    var $n_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $n_0;
    if ($n_0 >>> 0 < $6 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 5:
    if ((HEAP32[HEAP32[$7 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($3, $cx, $n_0, $v);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($cx, $v, $id);
    if ($22) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 9:
    var $24 = HEAP32[$id >> 2];
    var $25 = __Z22js_CheckForStringIndexi($24);
    var $26 = __ZN2js16AutoVectorRooterIiE6appendERKi($8, $25);
    if ($26) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $n_0 = $n_0 + 1 | 0;
    __label__ = 4;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN22JSScriptedProxyHandler7delete_EP9JSContextP8JSObjectiPb($this, $cx, $proxy, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210448 >> 2] | 0;
    var $7 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $8 = __ZL18GetFundamentalTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $1, $6, $7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $16 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $10 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = __ZL5Trap1P9JSContextP8JSObjectN2JS5ValueEiPS4_($cx, $1, $12$0, $12$1, $id, $7);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      var $16 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZL11ValueToBoolP9JSContextRKN2JS5ValueEPb($10, $bp);
    var $16 = 1;
    __label__ = 4;
    break;
   case 4:
    var $16;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $16;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11ValueToBoolP9JSContextRKN2JS5ValueEPb($v, $bp) {
  var $1 = __Z17js_ValueToBooleanRKN2JS5ValueE($v);
  HEAP8[$bp] = ($1 | 0) != 0 & 1;
  return;
}

function __ZN22JSScriptedProxyHandler9enumerateEP9JSContextP8JSObjectRN2js12AutoIdVectorE($this, $cx, $proxy, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210456 >> 2] | 0;
    var $7 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $8 = __ZL18GetFundamentalTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $1, $6, $7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $17 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $10 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = __ZL4TrapP9JSContextP8JSObjectN2JS5ValueEjPS4_S5_($cx, $1, $12$0, $12$1, 0, 0, $7);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      var $17 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_idx1_val$0 = HEAP32[$11 >> 2];
    var $_idx1_val$1 = HEAP32[$11 + 4 >> 2];
    var $15 = __ZL15ArrayToIdVectorP9JSContextRKN2JS5ValueERN2js12AutoIdVectorE($cx, $_idx1_val$0, $_idx1_val$1, $props);
    var $17 = $15;
    __label__ = 4;
    break;
   case 4:
    var $17;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $17;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN22JSScriptedProxyHandler3fixEP9JSContextP8JSObjectPN2JS5ValueE($this, $cx, $proxy, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210460 >> 2] | 0;
    var $7 = __ZL18GetFundamentalTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $1, $6, $vp);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      var $13 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $vp | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = __ZL4TrapP9JSContextP8JSObjectN2JS5ValueEjPS4_S5_($cx, $1, $10$0, $10$1, 0, 0, $vp);
    var $13 = $11;
    __label__ = 3;
    break;
   case 3:
    var $13;
    return $13;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN22JSScriptedProxyHandler3hasEP9JSContextP8JSObjectiPb($this, $cx, $proxy, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210464 >> 2] | 0;
    var $7 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $8 = __ZL14GetDerivedTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $1, $6, $7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $10 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $_idx = $10 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $11 = __ZL13js_IsCallableRKN2JS5ValueE3075($_idx_val$0, $_idx_val$1);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = $this | 0;
    var $14 = __ZN2js14JSProxyHandler3hasEP9JSContextP8JSObjectiPb($13, $cx, $proxy, $id, $bp);
    var $_0 = $14;
    __label__ = 6;
    break;
   case 4:
    var $16 = __ZL5Trap1P9JSContextP8JSObjectN2JS5ValueEiPS4_($cx, $1, $_idx_val$0, $_idx_val$1, $id, $7);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    __ZL11ValueToBoolP9JSContextRKN2JS5ValueEPb($10, $bp);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14GetDerivedTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $handler, $atom, $fvalp) {
  var $1 = __ZL7GetTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $handler, $atom, $fvalp);
  return $1;
}

function __ZL13js_IsCallableRKN2JS5ValueE3075($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZN8JSObject10isCallableEv($_idx_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN22JSScriptedProxyHandler6hasOwnEP9JSContextP8JSObjectiPb($this, $cx, $proxy, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210468 >> 2] | 0;
    var $7 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $8 = __ZL14GetDerivedTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $1, $6, $7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $10 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $_idx = $10 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $11 = __ZL13js_IsCallableRKN2JS5ValueE3075($_idx_val$0, $_idx_val$1);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = $this | 0;
    var $14 = __ZN2js14JSProxyHandler6hasOwnEP9JSContextP8JSObjectiPb($13, $cx, $proxy, $id, $bp);
    var $_0 = $14;
    __label__ = 6;
    break;
   case 4:
    var $16 = __ZL5Trap1P9JSContextP8JSObjectN2JS5ValueEiPS4_($cx, $1, $_idx_val$0, $_idx_val$1, $id, $7);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    __ZL11ValueToBoolP9JSContextRKN2JS5ValueEPb($10, $bp);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN22JSScriptedProxyHandler3getEP9JSContextP8JSObjectS3_iPN2JS5ValueE($this, $cx, $proxy, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $tvr = __stackBase__ + 8;
    var $2 = __stackBase__ + 32;
    var $argv = __stackBase__ + 40;
    var $fval = __stackBase__ + 56;
    var $3 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2jsL9IdToValueEi3076($1, $id);
    var $4 = $cx;
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $5 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($4, $_idx_val$0, $_idx_val$1);
    if (($5 | 0) == 0) {
      var $_1 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL11StringValueEP8JSString3077($2, $5);
    __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr, $cx, $2);
    var $8 = $argv | 0;
    __ZN2JSL17ObjectOrNullValueEP8JSObject3078($8, $receiver);
    var $9 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $10 = $9 | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = $argv + 8 | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    __ZN2js15AutoValueRooterC1EP9JSContext($fval, $cx);
    var $17 = HEAP32[HEAP32[$cx + 52 >> 2] + 210220 >> 2] | 0;
    var $18 = __ZN2js15AutoValueRooter4addrEv($fval);
    var $19 = __ZL14GetDerivedTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $3, $17, $18);
    if ($19) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $21 = __ZNK2js15AutoValueRooter5valueEv($fval);
    var $_idx1 = $21 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $22 = __ZL13js_IsCallableRKN2JS5ValueE3075($_idx1_val$0, $_idx1_val$1);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $24 = $this | 0;
    var $25 = __ZN2js14JSProxyHandler3getEP9JSContextP8JSObjectS4_iPN2JS5ValueE($24, $cx, $proxy, $receiver, $id, $vp);
    var $_0 = $25;
    __label__ = 6;
    break;
   case 5:
    var $27 = __ZL4TrapP9JSContextP8JSObjectN2JS5ValueEjPS4_S5_($cx, $3, $_idx1_val$0, $_idx1_val$1, 2, $8, $vp);
    var $_0 = $27;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($fval);
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 7;
    break;
   case 7:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN22JSScriptedProxyHandler3getEP9JSContextP8JSObjectS3_iPN2JS5ValueE["X"] = 1;

function __ZN2jsL9IdToValueEi3076($agg_result, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_STRING3137($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_STRING3138($id);
    __ZN2JSL11StringValueEP8JSString3077($agg_result, $4);
    __label__ = 8;
    break;
   case 3:
    var $6 = _JSID_IS_INT3139($id);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _JSID_TO_INT3141($id);
    __ZN2JSL10Int32ValueEi3140($agg_result, $9);
    __label__ = 8;
    break;
   case 5:
    var $11 = _JSID_IS_OBJECT3142($id);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = _JSID_TO_OBJECT3143($id);
    __ZN2JSL11ObjectValueER8JSObject3074($agg_result, $14);
    __label__ = 8;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv3073($agg_result);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11StringValueEP8JSString3077($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2JSL17ObjectOrNullValueEP8JSObject3078($agg_result, $obj) {
  __ZN2JS5Value15setObjectOrNullEP8JSObject($agg_result, $obj);
  return;
}

function __ZN22JSScriptedProxyHandler3setEP9JSContextP8JSObjectS3_ibPN2JS5ValueE($this, $cx, $proxy, $receiver, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 88;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $tvr = __stackBase__ + 8;
    var $2 = __stackBase__ + 32;
    var $argv = __stackBase__ + 40;
    var $fval = __stackBase__ + 64;
    var $3 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2jsL9IdToValueEi3076($1, $id);
    var $4 = $cx;
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $5 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($4, $_idx_val$0, $_idx_val$1);
    if (($5 | 0) == 0) {
      var $_1 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL11StringValueEP8JSString3077($2, $5);
    __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr, $cx, $2);
    var $8 = $argv | 0;
    __ZN2JSL17ObjectOrNullValueEP8JSObject3078($8, $receiver);
    var $9 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $10 = $9 | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = $argv + 8 | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    var $13 = $vp | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $argv + 16 | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    __ZN2js15AutoValueRooterC1EP9JSContext($fval, $cx);
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210296 >> 2] | 0;
    var $21 = __ZN2js15AutoValueRooter4addrEv($fval);
    var $22 = __ZL14GetDerivedTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $3, $20, $21);
    if ($22) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $24 = __ZNK2js15AutoValueRooter5valueEv($fval);
    var $_idx1 = $24 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $25 = __ZL13js_IsCallableRKN2JS5ValueE3075($_idx1_val$0, $_idx1_val$1);
    if ($25) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $27 = $this | 0;
    var $28 = __ZN2js14JSProxyHandler3setEP9JSContextP8JSObjectS4_ibPN2JS5ValueE($27, $cx, $proxy, $receiver, $id, $strict, $vp);
    var $_0 = $28;
    __label__ = 6;
    break;
   case 5:
    var $30 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $31 = __ZL4TrapP9JSContextP8JSObjectN2JS5ValueEjPS4_S5_($cx, $3, $_idx1_val$0, $_idx1_val$1, 3, $8, $30);
    var $_0 = $31;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($fval);
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 7;
    break;
   case 7:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN22JSScriptedProxyHandler3setEP9JSContextP8JSObjectS3_ibPN2JS5ValueE["X"] = 1;

function __ZN22JSScriptedProxyHandler4keysEP9JSContextP8JSObjectRN2js12AutoIdVectorE($this, $cx, $proxy, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210472 >> 2] | 0;
    var $7 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $8 = __ZL14GetDerivedTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $1, $6, $7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $10 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $_idx = $10 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $11 = __ZL13js_IsCallableRKN2JS5ValueE3075($_idx_val$0, $_idx_val$1);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = $this | 0;
    var $14 = __ZN2js14JSProxyHandler4keysEP9JSContextP8JSObjectRNS_12AutoIdVectorE($13, $cx, $proxy, $props);
    var $_0 = $14;
    __label__ = 6;
    break;
   case 4:
    var $16 = __ZL4TrapP9JSContextP8JSObjectN2JS5ValueEjPS4_S5_($cx, $1, $_idx_val$0, $_idx_val$1, 0, 0, $7);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $_idx2_val$0 = HEAP32[$_idx >> 2];
    var $_idx2_val$1 = HEAP32[$_idx + 4 >> 2];
    var $18 = __ZL15ArrayToIdVectorP9JSContextRKN2JS5ValueERN2js12AutoIdVectorE($cx, $_idx2_val$0, $_idx2_val$1, $props);
    var $_0 = $18;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN22JSScriptedProxyHandler7iterateEP9JSContextP8JSObjectjPN2JS5ValueE($this, $cx, $proxy, $flags, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $2 = $cx + 52 | 0;
    var $6 = HEAP32[HEAP32[$2 >> 2] + 210476 >> 2] | 0;
    var $7 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $8 = __ZL14GetDerivedTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $1, $6, $7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $10 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $_idx = $10 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $11 = __ZL13js_IsCallableRKN2JS5ValueE3075($_idx_val$0, $_idx_val$1);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = $this | 0;
    var $14 = __ZN2js14JSProxyHandler7iterateEP9JSContextP8JSObjectjPN2JS5ValueE($13, $cx, $proxy, $flags, $vp);
    var $_0 = $14;
    __label__ = 6;
    break;
   case 4:
    var $16 = __ZL4TrapP9JSContextP8JSObjectN2JS5ValueEjPS4_S5_($cx, $1, $_idx_val$0, $_idx_val$1, 0, 0, $vp);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $21 = HEAP32[HEAP32[$2 >> 2] + 210476 >> 2] | 0;
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $22 = __ZL31ReturnedValueMustNotBePrimitiveP9JSContextP8JSObjectP6JSAtomRKN2JS5ValueE($cx, $proxy, $21, $vp_idx_val$0, $vp_idx_val$1);
    var $_0 = $22;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($cx, $proxy, $id, $set, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx_idx_val, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 8 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $id, $set, $desc);
    var $pending_idx_val = HEAP32[$pending >> 2];
    var $pending_idx1_val = HEAP32[$pending + 4 >> 2];
    __ZN25AutoPendingProxyOperationD1Ev($pending_idx_val, $pending_idx1_val);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($this, $cx_0_11_val, $proxy) {
  __ZN25AutoPendingProxyOperationC2EP9JSContextP8JSObject($this, $cx_0_11_val, $proxy);
  return;
}

function __ZN25AutoPendingProxyOperationD1Ev($this_0_0_val, $this_0_1_0_val) {
  __ZN25AutoPendingProxyOperationD2Ev($this_0_0_val, $this_0_1_0_val);
  return;
}

function __ZN2js7JSProxy24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($cx, $proxy, $id, $set, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx_idx_val, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 12 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $id, $set, $desc);
    var $pending_idx_val = HEAP32[$pending >> 2];
    var $pending_idx1_val = HEAP32[$pending + 4 >> 2];
    __ZN25AutoPendingProxyOperationD1Ev($pending_idx_val, $pending_idx1_val);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor($cx, $proxy, $id, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx_idx_val, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 16 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $id, $desc);
    var $pending_idx_val = HEAP32[$pending >> 2];
    var $pending_idx1_val = HEAP32[$pending + 4 >> 2];
    __ZN25AutoPendingProxyOperationD1Ev($pending_idx_val, $pending_idx1_val);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy14definePropertyEP9JSContextP8JSObjectiRKN2JS5ValueE($cx, $proxy, $id, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    var $desc = __stackBase__ + 16;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 3:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx_idx_val, $proxy);
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($desc, $cx);
    var $7 = $desc + 16 | 0;
    var $8 = __ZL29ParsePropertyDescriptorObjectP9JSContextP8JSObjectiRKN2JS5ValueEP20JSPropertyDescriptor($cx, $proxy, $v, $7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $12 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = __ZN2js7JSProxy14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor($cx, $proxy, $id, $7);
    var $12 = $10;
    __label__ = 5;
    break;
   case 5:
    var $12;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
    var $pending_idx_val = HEAP32[$pending >> 2];
    var $pending_idx1_val = HEAP32[$pending + 4 >> 2];
    __ZN25AutoPendingProxyOperationD1Ev($pending_idx_val, $pending_idx1_val);
    var $_0 = $12;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy19getOwnPropertyNamesEP9JSContextP8JSObjectRNS_12AutoIdVectorE($cx, $proxy, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx_idx_val, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 20 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $props);
    var $pending_idx_val = HEAP32[$pending >> 2];
    var $pending_idx1_val = HEAP32[$pending + 4 >> 2];
    __ZN25AutoPendingProxyOperationD1Ev($pending_idx_val, $pending_idx1_val);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy7delete_EP9JSContextP8JSObjectiPb($cx, $proxy, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx_idx_val, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 24 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $id, $bp);
    var $pending_idx_val = HEAP32[$pending >> 2];
    var $pending_idx1_val = HEAP32[$pending + 4 >> 2];
    __ZN25AutoPendingProxyOperationD1Ev($pending_idx_val, $pending_idx1_val);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy9enumerateEP9JSContextP8JSObjectRNS_12AutoIdVectorE($cx, $proxy, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx_idx_val, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 28 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $props);
    var $pending_idx_val = HEAP32[$pending >> 2];
    var $pending_idx1_val = HEAP32[$pending + 4 >> 2];
    __ZN25AutoPendingProxyOperationD1Ev($pending_idx_val, $pending_idx1_val);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy3fixEP9JSContextP8JSObjectPN2JS5ValueE($cx, $proxy, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx_idx_val, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 32 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $vp);
    var $pending_idx_val = HEAP32[$pending >> 2];
    var $pending_idx1_val = HEAP32[$pending + 4 >> 2];
    __ZN25AutoPendingProxyOperationD1Ev($pending_idx_val, $pending_idx1_val);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy3hasEP9JSContextP8JSObjectiPb($cx, $proxy, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx_idx_val, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 36 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $id, $bp);
    var $pending_idx_val = HEAP32[$pending >> 2];
    var $pending_idx1_val = HEAP32[$pending + 4 >> 2];
    __ZN25AutoPendingProxyOperationD1Ev($pending_idx_val, $pending_idx1_val);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy6hasOwnEP9JSContextP8JSObjectiPb($cx, $proxy, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx_idx_val, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 40 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $id, $bp);
    var $pending_idx_val = HEAP32[$pending >> 2];
    var $pending_idx1_val = HEAP32[$pending + 4 >> 2];
    __ZN25AutoPendingProxyOperationD1Ev($pending_idx_val, $pending_idx1_val);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy3getEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $proxy, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx_idx_val, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 44 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $receiver, $id, $vp);
    var $pending_idx_val = HEAP32[$pending >> 2];
    var $pending_idx1_val = HEAP32[$pending + 4 >> 2];
    __ZN25AutoPendingProxyOperationD1Ev($pending_idx_val, $pending_idx1_val);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy3setEP9JSContextP8JSObjectS4_ibPN2JS5ValueE($cx, $proxy, $receiver, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx_idx_val, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 48 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $receiver, $id, $strict, $vp);
    var $pending_idx_val = HEAP32[$pending >> 2];
    var $pending_idx1_val = HEAP32[$pending + 4 >> 2];
    __ZN25AutoPendingProxyOperationD1Ev($pending_idx_val, $pending_idx1_val);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy4keysEP9JSContextP8JSObjectRNS_12AutoIdVectorE($cx, $proxy, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx_idx_val, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 52 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $props);
    var $pending_idx_val = HEAP32[$pending >> 2];
    var $pending_idx1_val = HEAP32[$pending + 4 >> 2];
    __ZN25AutoPendingProxyOperationD1Ev($pending_idx_val, $pending_idx1_val);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy7iterateEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $proxy, $flags, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx_idx_val, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 56 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $flags, $vp);
    var $pending_idx_val = HEAP32[$pending >> 2];
    var $pending_idx1_val = HEAP32[$pending + 4 >> 2];
    __ZN25AutoPendingProxyOperationD1Ev($pending_idx_val, $pending_idx1_val);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy4callEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $proxy, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx_idx_val, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 60 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $argc, $vp);
    var $pending_idx_val = HEAP32[$pending >> 2];
    var $pending_idx1_val = HEAP32[$pending + 4 >> 2];
    __ZN25AutoPendingProxyOperationD1Ev($pending_idx_val, $pending_idx1_val);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy9constructEP9JSContextP8JSObjectjPN2JS5ValueES7_($cx, $proxy, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx_idx_val, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 64 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $argc, $argv, $rval);
    var $pending_idx_val = HEAP32[$pending >> 2];
    var $pending_idx1_val = HEAP32[$pending + 4 >> 2];
    __ZN25AutoPendingProxyOperationD1Ev($pending_idx_val, $pending_idx1_val);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb($cx, $proxy, $vp, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx_idx_val, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 68 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $vp, $bp);
    var $pending_idx_val = HEAP32[$pending >> 2];
    var $pending_idx1_val = HEAP32[$pending + 4 >> 2];
    __ZN25AutoPendingProxyOperationD1Ev($pending_idx_val, $pending_idx1_val);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy6typeOfEP9JSContextP8JSObject($cx, $proxy) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx_idx_val, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 72 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy);
    var $pending_idx_val = HEAP32[$pending >> 2];
    var $pending_idx1_val = HEAP32[$pending + 4 >> 2];
    __ZN25AutoPendingProxyOperationD1Ev($pending_idx_val, $pending_idx1_val);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy12obj_toStringEP9JSContextP8JSObject($cx, $proxy) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx_idx_val, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 76 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy);
    var $pending_idx_val = HEAP32[$pending >> 2];
    var $pending_idx1_val = HEAP32[$pending + 4 >> 2];
    __ZN25AutoPendingProxyOperationD1Ev($pending_idx_val, $pending_idx1_val);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy12fun_toStringEP9JSContextP8JSObjectj($cx, $proxy, $indent) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx_idx_val, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 80 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $indent);
    var $pending_idx_val = HEAP32[$pending >> 2];
    var $pending_idx1_val = HEAP32[$pending + 4 >> 2];
    __ZN25AutoPendingProxyOperationD1Ev($pending_idx_val, $pending_idx1_val);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE($cx, $proxy, $hint, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx_idx_val, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 84 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $hint, $vp);
    var $pending_idx_val = HEAP32[$pending >> 2];
    var $pending_idx1_val = HEAP32[$pending + 4 >> 2];
    __ZN25AutoPendingProxyOperationD1Ev($pending_idx_val, $pending_idx1_val);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13proxy_ConvertP9JSContextP8JSObject6JSTypePN2JS5ValueE($cx, $proxy, $hint, $vp) {
  var $1 = __ZN2js7JSProxy12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE($cx, $proxy, $hint, $vp);
  return $1 & 1;
}

function __ZL14proxy_FinalizeP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject7getSlotEj($obj, 0);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $2 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject15getProxyHandlerEv($obj);
    var $8 = HEAP32[HEAP32[$4 >> 2] + 88 >> 2];
    FUNCTION_TABLE[$8]($4, $cx, $obj);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17proxy_HasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi($cx, $proxy, $v, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__;
    var $b = __stackBase__ + 12;
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx_idx_val, $proxy);
    var $1 = __ZN2js7JSProxy11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb($cx, $proxy, $v, $b);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$bp >> 2] = HEAP8[$b] & 1 & 255;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    var $pending_idx_val = HEAP32[$pending >> 2];
    var $pending_idx1_val = HEAP32[$pending + 4 >> 2];
    __ZN25AutoPendingProxyOperationD1Ev($pending_idx_val, $pending_idx1_val);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17proxy_TraceObjectP8JSTracerP8JSObject($trc, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK8JSObject15getProxyHandlerEv($obj);
    var $6 = HEAP32[HEAP32[$2 >> 2] + 92 >> 2];
    FUNCTION_TABLE[$6]($2, $trc, $obj);
    var $7 = __ZNK8JSObject15getProxyPrivateEv($obj);
    var $_idx = $7 | 0;
    var $st$9$0 = $_idx | 0;
    var $_idx_val$0 = HEAP32[$st$9$0 >> 2];
    var $st$9$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAP32[$st$9$1 >> 2];
    __ZN2js2gc25MarkCrossCompartmentValueEP8JSTracerRKN2JS5ValueEPKc($trc, $_idx_val$0, $_idx_val$1);
    var $8 = __ZNK8JSObject13getProxyExtraEv($obj);
    var $_idx1 = $8 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN2js2gc25MarkCrossCompartmentValueEP8JSTracerRKN2JS5ValueEPKc($trc, $_idx1_val$0, $_idx1_val$1);
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $9 = __ZNK8JSObject15isFunctionProxyEv($obj_idx_val);
    if ($9) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = __ZL7GetCallP8JSObject($obj);
    var $_idx2 = $11 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN2js2gc25MarkCrossCompartmentValueEP8JSTracerRKN2JS5ValueEPKc($trc, $_idx2_val$0, $_idx2_val$1);
    __ZL12GetConstructP8JSObject($1, $obj);
    var $_idx3 = $1 | 0;
    var $st$9$0 = $_idx3 | 0;
    var $_idx3_val$0 = HEAP32[$st$9$0 >> 2];
    var $st$9$1 = $_idx3 + 4 | 0;
    var $_idx3_val$1 = HEAP32[$st$9$1 >> 2];
    __ZN2js2gc25MarkCrossCompartmentValueEP8JSTracerRKN2JS5ValueEPKc($trc, $_idx3_val$0, $_idx3_val$1);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20proxy_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $id, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $found = __stackBase__;
    var $1 = __Z22js_CheckForStringIndexi($id);
    var $2 = __ZN2js7JSProxy3hasEP9JSContextP8JSObjectiPb($cx, $obj, $1, $found);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    if ((HEAP8[$found] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$propp >> 2] = 1;
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 4:
    HEAP32[$objp >> 2] = 0;
    HEAP32[$propp >> 2] = 0;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19proxy_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty($cx, $obj, $index, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$id >> 2];
    var $4 = __ZL20proxy_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $3, $objp, $propp);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19proxy_LookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty($cx, $obj, $sid, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3133($sid_idx_val);
  var $2 = __ZL20proxy_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $1, $objp, $propp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL20proxy_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $id, $value, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var $desc = __stackBase__;
  var $1 = __Z22js_CheckForStringIndexi($id);
  __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($desc, $cx);
  var $2 = $desc + 16 | 0;
  HEAP32[$2 >> 2] = $obj;
  var $4 = $value | 0;
  var $5$0 = HEAP32[$4 >> 2];
  var $5$1 = HEAP32[$4 + 4 >> 2];
  var $6 = $desc + 32 | 0;
  HEAP32[$6 >> 2] = $5$0;
  HEAP32[$6 + 4 >> 2] = $5$1;
  HEAP32[$desc + 20 >> 2] = $attrs & -257;
  HEAP32[$desc + 24 >> 2] = $getter;
  HEAP32[$desc + 28 >> 2] = $setter;
  HEAP32[$desc + 40 >> 2] = 0;
  var $12 = __ZN2js7JSProxy14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor($cx, $obj, $1, $2);
  var $13 = $12 & 1;
  __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
  STACKTOP = __stackBase__;
  return $13;
}

function __ZL19proxy_DefineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $index, $value, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$id >> 2];
    var $4 = __ZL20proxy_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $3, $value, $getter, $setter, $attrs);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19proxy_DefineSpecialP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ej($cx, $obj, $sid, $value, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3133($sid_idx_val);
  var $2 = __ZL20proxy_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $1, $value, $getter, $setter, $attrs);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL16proxy_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var $1 = __Z22js_CheckForStringIndexi($id);
  var $2 = __ZN2js7JSProxy3getEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $1, $vp);
  return $2 & 1;
}

function __ZL17proxy_GetPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom3129($1);
  var $3 = __ZL16proxy_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $2, $vp);
  return $3;
}

function __ZL16proxy_GetElementP9JSContextP8JSObjectS2_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$id >> 2];
    var $4 = __ZL16proxy_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $3, $vp);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16proxy_GetSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3133($sid_idx_val);
  var $2 = __ZL16proxy_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL17proxy_SetPropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var $1 = __Z22js_CheckForStringIndexi($id);
  var $2 = ($strict | 0) != 0;
  var $3 = __ZN2js7JSProxy3setEP9JSContextP8JSObjectS4_ibPN2JS5ValueE($cx, $obj, $obj, $1, $2, $vp);
  return $3 & 1;
}

function __ZL16proxy_SetElementP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$id >> 2];
    var $4 = __ZL17proxy_SetPropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $3, $vp, $strict);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16proxy_SetSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3133($sid_idx_val);
  var $2 = __ZL17proxy_SetPropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, $strict);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL19proxy_GetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $desc = __stackBase__;
    var $1 = __Z22js_CheckForStringIndexi($id);
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($desc, $cx);
    var $2 = $desc + 16 | 0;
    var $3 = __ZN2js7JSProxy24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($cx, $obj, $1, 0, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = HEAP32[$desc + 20 >> 2];
    HEAP32[$attrsp >> 2] = $6;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26proxy_GetElementAttributesP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$id >> 2];
    var $4 = __ZL19proxy_GetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $3, $attrsp);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26proxy_GetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3133($sid_idx_val);
  var $2 = __ZL19proxy_GetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $1, $attrsp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL19proxy_SetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $desc = __stackBase__;
    var $1 = __Z22js_CheckForStringIndexi($id);
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($desc, $cx);
    var $2 = $desc + 16 | 0;
    var $3 = __ZN2js7JSProxy24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($cx, $obj, $1, 1, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = HEAP32[$attrsp >> 2] & -257;
    HEAP32[$desc + 20 >> 2] = $6;
    var $8 = __ZN2js7JSProxy14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor($cx, $obj, $1, $2);
    var $_0 = $8 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26proxy_SetElementAttributesP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$id >> 2];
    var $4 = __ZL19proxy_SetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $3, $attrsp);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26proxy_SetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3133($sid_idx_val);
  var $2 = __ZL19proxy_SetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $1, $attrsp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL20proxy_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $deleted = __stackBase__;
    var $1 = __Z22js_CheckForStringIndexi($id);
    var $2 = __ZN2js7JSProxy7delete_EP9JSContextP8JSObjectiPb($cx, $obj, $1, $deleted);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $obj;
    var $6 = __Z26js_SuppressDeletedPropertyP9JSContextP8JSObjecti($4, $5, $1);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = (HEAP8[$deleted] & 1) << 24 >> 24 != 0;
    __ZN2JS5Value10setBooleanEb($rval, $10);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19proxy_DeleteElementP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$id >> 2];
    var $4 = __ZL20proxy_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $3, $rval, $strict);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19proxy_DeleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3133($sid_idx_val);
  var $2 = __ZL20proxy_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, $strict);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL12proxy_TypeOfP9JSContextP8JSObject($cx, $proxy) {
  var $1 = __ZN2js7JSProxy6typeOfEP9JSContextP8JSObject($cx, $proxy);
  return $1;
}

function __ZL9proxy_FixP9JSContextP8JSObjectPbPN2js12AutoIdVectorE($cx, $obj, $fixed, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $isFixed = __stackBase__;
    var $1 = __ZN2js8FixProxyEP9JSContextP8JSObjectPi($cx, $obj, $isFixed);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP8[$fixed] = (HEAP32[$isFixed >> 2] | 0) != 0 & 1;
    var $7 = $cx;
    var $8 = $obj;
    var $9 = $props;
    var $10 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($7, $8, 24, $9);
    var $_0 = $10 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17proxy_innerObjectP9JSContextP8JSObject($cx, $obj) {
  var $1 = __ZNK8JSObject15getProxyPrivateEv($obj);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $2 = __ZNK2JS5Value14toObjectOrNullEv($_idx_val$0, $_idx_val$1);
  return $2;
}

function __ZL10proxy_CallP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $vp_idx = $vp | 0;
  var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
  var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
  var $1 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
  var $2 = __ZN2js7JSProxy4callEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $1, $argc, $vp);
  return $2 & 1;
}

function __ZL15proxy_ConstructP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $vp_idx = $vp | 0;
  var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
  var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
  var $1 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
  var $2 = $vp + 16 | 0;
  var $3 = __ZN2js7JSProxy9constructEP9JSContextP8JSObjectjPN2JS5ValueES7_($cx, $1, $argc, $2, $vp);
  return $3 & 1;
}

function __ZL19proxy_TraceFunctionP8JSTracerP8JSObject($trc, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL17proxy_TraceObjectP8JSTracerP8JSObject($trc, $obj);
  var $2 = __ZL7GetCallP8JSObject($obj);
  var $_idx = $2 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  __ZN2js2gc25MarkCrossCompartmentValueEP8JSTracerRKN2JS5ValueEPKc($trc, $_idx_val$0, $_idx_val$1);
  __ZL12GetConstructP8JSObject($1, $obj);
  var $_idx1 = $1 | 0;
  var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
  var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
  __ZN2js2gc25MarkCrossCompartmentValueEP8JSTracerRKN2JS5ValueEPKc($trc, $_idx1_val$0, $_idx1_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js14NewProxyObjectEP9JSContextPNS_14JSProxyHandlerERKN2JS5ValueEP8JSObjectS9_S9_S9_($cx, $handler, $priv, $proto, $parent, $call, $construct) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = ($call | 0) != 0;
    var $6 = $4 | ($construct | 0) != 0;
    if ($6) {
      var $clasp_0 = __ZN2js18FunctionProxyClassE;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = HEAP32[HEAP32[$handler >> 2] + 96 >> 2];
    var $12 = FUNCTION_TABLE[$11]($handler);
    var $13 = $12 ? __ZN2js21OuterWindowProxyClassE : __ZN2js16ObjectProxyClassE;
    var $clasp_0 = $13;
    __label__ = 3;
    break;
   case 3:
    var $clasp_0;
    if (($proto | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 1);
    __label__ = 5;
    break;
   case 5:
    var $19 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3103($cx, $clasp_0, $proto, $parent);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = $19;
    var $23 = $cx;
    var $24 = __ZN8JSObject27ensureInstanceReservedSlotsEP9JSContextj($22, $23, 0);
    if ($24) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 7:
    var $26 = $handler;
    __ZN2JSL12PrivateValueEPv3104($1, $26);
    var $_idx3 = $1 | 0;
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($19, 0, $_idx3_val$0, $_idx3_val$1);
    var $priv_idx = $priv | 0;
    var $priv_idx_val$0 = HEAP32[$priv_idx >> 2];
    var $priv_idx_val$1 = HEAP32[$priv_idx + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($19, 1, $priv_idx_val$0, $priv_idx_val$1);
    if ($6) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    if ($4) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    __ZN2JSL11ObjectValueER8JSObject3074($2, $call);
    __label__ = 11;
    break;
   case 10:
    __ZN2JSL14UndefinedValueEv3073($2);
    __label__ = 11;
    break;
   case 11:
    var $_idx2 = $2 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($19, 3, $_idx2_val$0, $_idx2_val$1);
    if (($construct | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN2JSL11ObjectValueER8JSObject3074($3, $construct);
    var $_idx1 = $3 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($19, 4, $_idx1_val$0, $_idx1_val$1);
    __label__ = 13;
    break;
   case 13:
    var $_idx_val = HEAP32[$19 + 36 >> 2];
    var $34 = __ZNK8JSObject4typeEv($_idx_val);
    __ZN2js5types31MarkTypeObjectUnknownPropertiesEP9JSContextPNS0_10TypeObjectEb($cx, $34, 0);
    var $_0 = $19;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js14NewProxyObjectEP9JSContextPNS_14JSProxyHandlerERKN2JS5ValueEP8JSObjectS9_S9_S9_["X"] = 1;

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3103($cx, $clasp, $proto, $parent) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb3110($4);
  var $6 = __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3122($cx, $clasp, $proto, $parent, $5);
  return $6;
}

function __ZN2JSL12PrivateValueEPv3104($agg_result, $ptr) {
  __ZN2JS5Value10setPrivateEPv($agg_result, $ptr);
  return;
}

function __ZL12proxy_createP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 4, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str53058 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str225518 | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str226519 | 0, tempInt));
    var $_0 = 0;
    __label__ = 10;
    break;
   case 3:
    var $5 = $cx;
    var $_idx4 = $vp + 16 | 0;
    var $st$2$0 = $_idx4 | 0;
    var $_idx4_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx4 + 4 | 0;
    var $_idx4_val$1 = HEAP32[$st$2$1 >> 2];
    var $6 = __ZN2js13NonNullObjectEP9JSContextRKN2JS5ValueE($5, $_idx4_val$0, $_idx4_val$1);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ($argc >>> 0 > 1) {
      __label__ = 5;
      break;
    } else {
      var $proto_02 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $_idx = $vp + 24 | 0;
    var $_idx_val$0 = HEAPU32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $12 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      var $proto_02 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $14 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $_idx3_val = HEAP32[$14 + 20 >> 2];
    var $15 = __ZNK8JSObject9getParentEv($_idx3_val);
    if (($15 | 0) == 0) {
      var $proto_02 = $14;
      __label__ = 7;
      break;
    } else {
      var $parent_1 = $15;
      var $proto_01 = $14;
      __label__ = 8;
      break;
    }
   case 7:
    var $proto_02;
    var $vp_idx = $vp | 0;
    var $st$2$0 = $vp_idx | 0;
    var $vp_idx_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $vp_idx + 4 | 0;
    var $vp_idx_val$1 = HEAP32[$st$2$1 >> 2];
    var $17 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
    var $_idx2_val = HEAP32[$17 + 20 >> 2];
    var $18 = __ZNK8JSObject9getParentEv($_idx2_val);
    var $parent_1 = $18;
    var $proto_01 = $proto_02;
    __label__ = 8;
    break;
   case 8:
    var $proto_01;
    var $parent_1;
    __ZN2JSL11ObjectValueER8JSObject3074($1, $7);
    var $20 = __ZN2js14NewProxyObjectEP9JSContextPNS_14JSProxyHandlerERKN2JS5ValueEP8JSObjectS9_S9_S9_($cx, __ZN22JSScriptedProxyHandler9singletonE | 0, $1, $proto_01, $parent_1, 0, 0);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2JS5Value9setObjectER8JSObject($vp, $20);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12proxy_createP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL20proxy_createFunctionP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $proto = __stackBase__;
    var $1 = __stackBase__ + 4;
    if ($argc >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 4, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str63059 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str163973 | 0, HEAP32[tempInt + 8 >> 2] = __str17668 | 0, tempInt));
    var $_0 = 0;
    __label__ = 10;
    break;
   case 3:
    var $5 = $cx;
    var $_idx2 = $vp + 16 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    var $6 = __ZN2js13NonNullObjectEP9JSContextRKN2JS5ValueE($5, $_idx2_val$0, $_idx2_val$1);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $10 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
    var $_idx1_val = HEAP32[$10 + 20 >> 2];
    var $11 = __ZNK8JSObject9getParentEv($_idx1_val);
    var $12 = $11;
    var $13 = $proto;
    var $14 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($5, $12, 2, $13, 0);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = HEAPU32[$proto >> 2];
    var $_idx_val = HEAP32[$17 + 20 >> 2];
    var $18 = __ZNK8JSObject9getParentEv($_idx_val);
    var $19 = $vp + 24 | 0;
    var $20 = __Z24js_ValueToCallableObjectP9JSContextPN2JS5ValueEj($cx, $19, 65536);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ($argc >>> 0 > 2) {
      __label__ = 7;
      break;
    } else {
      var $construct_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $25 = $vp + 32 | 0;
    var $26 = __Z24js_ValueToCallableObjectP9JSContextPN2JS5ValueEj($cx, $25, 65536);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      var $construct_0 = $26;
      __label__ = 8;
      break;
    }
   case 8:
    var $construct_0;
    __ZN2JSL11ObjectValueER8JSObject3074($1, $7);
    var $29 = __ZN2js14NewProxyObjectEP9JSContextPNS_14JSProxyHandlerERKN2JS5ValueEP8JSObjectS9_S9_S9_($cx, __ZN22JSScriptedProxyHandler9singletonE | 0, $1, $17, $18, $20, $construct_0);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2JS5Value9setObjectER8JSObject($vp, $29);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL20proxy_createFunctionP9JSContextjPN2JS5ValueE["X"] = 1;

function __Z18callable_ConstructP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fval = __stackBase__;
    var $protov = __stackBase__ + 8;
    var $proto = __stackBase__ + 16;
    var $rval = __stackBase__ + 20;
    var $1 = __stackBase__ + 28;
    var $2 = __stackBase__ + 36;
    var $vp_idx2 = $vp | 0;
    var $st$7$0 = $vp_idx2 | 0;
    var $vp_idx2_val$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $vp_idx2 + 4 | 0;
    var $vp_idx2_val$1 = HEAP32[$st$7$1 >> 2];
    var $3 = __ZNK2JS5Value8toObjectEv($vp_idx2_val$0, $vp_idx2_val$1);
    var $4 = $cx;
    var $5 = $3;
    var $6 = __Z13js_CreateThisP9JSContextP8JSObject($4, $5);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $st$0$0 = $vp_idx2 | 0;
    var $vp_idx_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $vp_idx2 + 4 | 0;
    var $vp_idx_val$1 = HEAP32[$st$0$1 >> 2];
    var $10 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
    var $11 = __ZNK8JSObject7getSlotEj($10, 1);
    var $12 = $11 | 0;
    var $st$7$0 = $12 | 0;
    var $13$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $12 + 4 | 0;
    var $13$1 = HEAP32[$st$7$1 >> 2];
    var $14 = $fval | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $15 = __ZNK2JS5Value11isUndefinedEv($13$0, $13$1);
    if ($15) {
      __label__ = 3;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 3:
    var $17 = __ZNK8JSObject7getSlotEj($10, 0);
    var $18 = $17 | 0;
    var $19$0 = HEAP32[$18 >> 2];
    var $19$1 = HEAP32[$18 + 4 >> 2];
    HEAP32[$14 >> 2] = $19$0;
    HEAP32[$14 + 4 >> 2] = $19$1;
    var $23 = HEAP32[HEAP32[$cx + 52 >> 2] + 210200 >> 2];
    var $24 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($10, $cx, $23, $protov);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $protov_idx = $protov | 0;
    var $st$1$0 = $protov_idx | 0;
    var $protov_idx_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $protov_idx + 4 | 0;
    var $protov_idx_val$1 = HEAP32[$st$1$1 >> 2];
    var $27 = __ZNK2JS5Value8isObjectEv($protov_idx_val$0, $protov_idx_val$1);
    if ($27) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $29 = __ZNK2JS5Value8toObjectEv($protov_idx_val$0, $protov_idx_val$1);
    HEAP32[$proto >> 2] = $29;
    var $35 = $29;
    __label__ = 8;
    break;
   case 6:
    var $31 = $proto;
    var $32 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($4, 0, 1, $31, 0);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $35 = HEAP32[$proto >> 2];
    __label__ = 8;
    break;
   case 8:
    var $35;
    var $_idx_val = HEAP32[$35 + 20 >> 2];
    var $36 = __ZNK8JSObject9getParentEv($_idx_val);
    var $37 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_3105($cx, $35, $36);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2JSL11ObjectValueER8JSObject3074($1, $37);
    var $40 = __ZNK8JSObject7getSlotEj($10, 0);
    var $41 = $vp + 16 | 0;
    var $42 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $1, $40, $argc, $41, $rval);
    if ($42) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 10:
    var $rval_idx = $rval | 0;
    var $st$1$0 = $rval_idx | 0;
    var $rval_idx_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $rval_idx + 4 | 0;
    var $rval_idx_val$1 = HEAP32[$st$1$1 >> 2];
    var $44 = __ZNK2JS5Value11isPrimitiveEv($rval_idx_val$0, $rval_idx_val$1);
    if ($44) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    __ZN2JS5Value9setObjectER8JSObject($vp, $37);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 12:
    var $st$0$0 = $vp_idx2 | 0;
    HEAP32[$st$0$0 >> 2] = $rval_idx_val$0;
    var $st$0$1 = $vp_idx2 + 4 | 0;
    HEAP32[$st$0$1 >> 2] = $rval_idx_val$1;
    var $_0 = 1;
    __label__ = 14;
    break;
   case 13:
    __ZN2JSL11ObjectValueER8JSObject3074($2, $7);
    var $48 = $vp + 16 | 0;
    var $49 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $2, $fval, $argc, $48, $vp);
    var $_0 = $49 & 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18callable_ConstructP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_3105($cx, $proto, $parent) {
  var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb3110($3);
  var $5 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE3127($cx, $proto, $parent, $4);
  return $5;
}

function __ZL13callable_CallP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $vp_idx = $vp | 0;
  var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
  var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
  var $1 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
  var $2 = __ZNK8JSObject7getSlotEj($1, 0);
  var $3 = $vp + 8 | 0;
  var $4 = $vp + 16 | 0;
  var $5 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $3, $2, $argc, $4, $vp);
  return $5 & 1;
}

function __ZN2js8FixProxyEP9JSContextP8JSObjectPi($cx, $proxy, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $tvr2 = __stackBase__ + 24;
    var $1 = __stackBase__ + 40;
    var $pending = __stackBase__ + 48;
    var $cx_idx7 = $cx + 52 | 0;
    var $cx_idx7_val = HEAP32[$cx_idx7 >> 2];
    var $2 = __ZL19OperationInProgressP9JSContextP8JSObject($cx_idx7_val, $proxy);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 4, 249, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_3 = 0;
    __label__ = 15;
    break;
   case 3:
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $5 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $6 = __ZN2js7JSProxy3fixEP9JSContextP8JSObjectPN2JS5ValueE($cx, $proxy, $5);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      var $_2 = 0;
      __label__ = 14;
      break;
    }
   case 4:
    var $8 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $_idx = $8 | 0;
    var $st$2$0 = $_idx | 0;
    var $_idx_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAP32[$st$2$1 >> 2];
    var $9 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    HEAP32[$bp >> 2] = 0;
    var $_2 = 1;
    __label__ = 14;
    break;
   case 6:
    var $12 = $cx;
    var $13 = __ZN2js13NonNullObjectEP9JSContextRKN2JS5ValueE($12, $_idx_val$0, $_idx_val$1);
    if (($13 | 0) == 0) {
      var $_2 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $proxy_idx1_val_idx_val = HEAP32[HEAP32[$proxy + 36 >> 2] >> 2];
    var $16 = __ZNK8JSObject8getProtoEv($proxy_idx1_val_idx_val);
    var $proxy_idx_val = HEAP32[$proxy + 20 >> 2];
    var $17 = __ZNK8JSObject9getParentEv($proxy_idx_val);
    var $proxy_idx4_val = HEAP32[$proxy + 4 >> 2];
    var $18 = __ZNK8JSObject15isFunctionProxyEv($proxy_idx4_val);
    var $19 = $18 ? __ZN2js19CallableObjectClassE : __ZN2js11ObjectClassE;
    var $20 = $proxy;
    var $21 = __ZNK2js2gc4Cell12getAllocKindEv($20);
    var $22 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE($cx, $19, $16, $17, $21);
    if (($22 | 0) == 0) {
      var $_2 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($tvr2, $cx, $22);
    if ($18 | (__ZN2js11ObjectClassE | 0) == (__ZN2js19CallableObjectClassE | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = __ZL7GetCallP8JSObject($proxy);
    var $_idx3 = $27 | 0;
    var $st$2$0 = $_idx3 | 0;
    var $_idx3_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx3 + 4 | 0;
    var $_idx3_val$1 = HEAP32[$st$2$1 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($22, 0, $_idx3_val$0, $_idx3_val$1);
    __ZL12GetConstructP8JSObject($1, $proxy);
    var $_idx2 = $1 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($22, 1, $_idx2_val$0, $_idx2_val$1);
    __label__ = 10;
    break;
   case 10:
    var $cx_idx_val = HEAP32[$cx_idx7 >> 2];
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx_idx_val, $proxy);
    var $29 = $22;
    var $30 = __Z17js_PopulateObjectP9JSContextP8JSObjectS2_($12, $29, $13);
    var $not_ = ($30 | 0) == 0;
    var $pending_idx_val = HEAP32[$pending >> 2];
    var $pending_idx5_val = HEAP32[$pending + 4 >> 2];
    __ZN25AutoPendingProxyOperationD1Ev($pending_idx_val, $pending_idx5_val);
    if ($not_) {
      var $_1 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $32 = $proxy;
    var $33 = __ZN8JSObject4swapEP9JSContextPS_($32, $12, $29);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $_1 = 0;
      __label__ = 13;
      break;
    }
   case 12:
    HEAP32[$bp >> 2] = 1;
    var $_1 = 1;
    __label__ = 13;
    break;
   case 13:
    var $_1;
    __ZN2js16AutoObjectRooterD1Ev($tvr2);
    var $_2 = $_1;
    __label__ = 14;
    break;
   case 14:
    var $_2;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_3 = $_2;
    __label__ = 15;
    break;
   case 15:
    var $_3;
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8FixProxyEP9JSContextP8JSObjectPi["X"] = 1;

function __ZN2js14JSProxyHandler13isOuterWindowEv($this) {
  return 0;
}

function __ZL14JSID_FROM_BITSj3130($bits) {
  return $bits;
}

function __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3133($sid_0_0_val) {
  return $sid_0_0_val;
}

function __ZN2jsL16GetClassProtoKeyEPNS_5ClassE3121() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[__ZN2js10ProxyClassE + 4 >> 2];
    var $2 = $1 >>> 24;
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $1 >>> 17 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSID_IS_STRING3137($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_TO_STRING3138($iden) {
  return $iden;
}

function _JSID_IS_INT3139($iden) {
  return $iden & 1;
}

function _JSID_TO_INT3141($iden) {
  return $iden >> 1;
}

function _JSID_IS_OBJECT3142($iden) {
  return ($iden & 7 | 0) == 4 & ($iden | 0) != 4 & 1;
}

function _JSID_TO_OBJECT3143($iden) {
  return $iden & -8;
}

function _INT_TO_JSID3398($i) {
  return $i << 1 | 1;
}

function __ZL19OperationInProgressP9JSContextP8JSObject($cx_0_11_val, $proxy) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $op_0_in = $cx_0_11_val + 209884 | 0;
    __label__ = 2;
    break;
   case 2:
    var $op_0_in;
    var $op_0 = HEAP32[$op_0_in >> 2];
    if (($op_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$op_0 + 4 >> 2] | 0) == ($proxy | 0)) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $op_0_in = $op_0 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL15GetGCObjectKindEjb3110($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE8shrinkByEj($this, $incr) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] - $incr | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZL13IMPL_TO_JSVAL12jsval_layout3125($agg_result, $l_0$0, $l_0$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $l_0$0;
  HEAP32[$1 + 4 >> 2] = $l_0$1;
  return;
}

function _OBJECT_TO_JSVAL_IMPL3126($agg_result, $obj) {
  HEAP32[$agg_result + 4 >> 2] = -121;
  HEAP32[$agg_result >> 2] = $obj;
  return;
}

function __ZN25AutoPendingProxyOperationD2Ev($this_0_0_val, $this_0_1_0_val) {
  HEAP32[$this_0_0_val + 65604 >> 2] = $this_0_1_0_val;
  return;
}

function __ZN25AutoPendingProxyOperationC2EP9JSContextP8JSObject($this, $cx_0_11_val, $proxy) {
  HEAP32[$this >> 2] = $cx_0_11_val + 144280 | 0;
  var $4 = HEAP32[$cx_0_11_val + 209884 >> 2];
  var $5 = $this + 4 | 0;
  HEAP32[$5 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = $proxy;
  HEAP32[$cx_0_11_val + 209884 >> 2] = $5;
  return;
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE($cx, $clasp, $proto, $parent, $kind) {
  var $1 = __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3122($cx, $clasp, $proto, $parent, $kind);
  return $1;
}

function _js_InitProxyClass($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3108($cx, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    var $6 = $cx;
    __ZN8JSObject16setSingletonTypeEP9JSContext($5, $6);
    _OBJECT_TO_JSVAL3109($1, $2);
    var $_idx1 = $1 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $$emscripten$temp$0 = STRING_TABLE.__str33051 | 0;
    var $7 = _JS_DefineProperty($cx, $obj, $$emscripten$temp$0, $_idx1_val$0, $_idx1_val$1, 10, 12, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = _JS_DefineFunctions($cx, $2, __ZL14static_methods | 0);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $obj;
    var $_idx_val = HEAP32[__ZN2js10ProxyClassE + 4 >> 2];
    __ZN2js35MarkStandardClassInitializedNoProtoEP8JSObjectPNS_5ClassE($13, $_idx_val);
    var $_0 = $2;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3108($cx, $parent) {
  var $3 = HEAPU32[__ZN2js10ProxyClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb3110($3);
  var $5 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3111($cx, $parent, $4);
  return $5;
}

function _OBJECT_TO_JSVAL3109($agg_result, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL_IMPL3126($1, $obj);
    var $_0 = $1 | 0;
    var $_0_val$0 = HEAP32[$_0 >> 2];
    var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
    __ZL13IMPL_TO_JSVAL12jsval_layout3125($agg_result, $_0_val$0, $_0_val$1);
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $6 = $agg_result | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3111($cx, $parent, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = 0;
    var $2 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_3112($cx, $parent, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    var $4 = HEAP32[$1 >> 2];
    var $5 = ($4 | 0) == 0;
    if ($5) {
      var $9 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($4, $cx, 0, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      var $9 = $7;
      __label__ = 4;
      break;
    }
   case 4:
    var $9;
    var $10 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_not = ($parent | 0) == 0 ^ 1;
    var $parent_mux = $_not ? $parent : 0;
    if ($_not | $5) {
      var $17 = $parent_mux;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx_val = HEAP32[$4 + 20 >> 2];
    var $15 = __ZNK8JSObject9getParentEv($_idx_val);
    var $17 = $15;
    __label__ = 7;
    break;
   case 7:
    var $17;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($10, __ZN2js10ProxyClassE, $9, $17, 0, (__ZN2js10ProxyClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $_ZN2js10ProxyClassE_idx_val = HEAP32[__ZN2js10ProxyClassE + 4 >> 2];
    var $18 = __ZNK2js5Class8isNativeEv($_ZN2js10ProxyClassE_idx_val);
    if ($18) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $20 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE3115($cx, $10, __ZN2js10ProxyClassE, $9, $kind);
    if ($20) {
      var $_0 = $10;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_0 = 0;
    __label__ = 11;
    break;
   case 10:
    __ZN8JSObject21setSharedNonNativeMapEv($10);
    var $_0 = $10;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_3112($cx, $parent, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL16GetClassProtoKeyEPNS_5ClassE3121();
    var $2 = $cx;
    var $3 = $parent;
    var $4 = $proto;
    var $5 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, $1, $4, __ZN2js10ProxyClassE);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$proto >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, 1, $4, 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE3115($cx, $obj, $clasp, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
    var $obj_idx_val = HEAP32[$obj + 28 >> 2];
    var $5 = __ZNK8JSObject8numSlotsEv($obj_idx_val);
    if ($4 >>> 0 > $5 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $obj;
    var $9 = $cx;
    var $10 = __ZN8JSObject10allocSlotsEP9JSContextj($8, $9, $4);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $12 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($type, $clasp);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($type, $cx, $clasp, $kind);
    var $empty_0 = $14;
    __label__ = 6;
    break;
   case 5:
    var $16 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, $clasp);
    var $empty_0 = $16;
    __label__ = 6;
    break;
   case 6:
    var $empty_0;
    if (($empty_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($obj, $empty_0 | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3122($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($proto | 0) != 0;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $5 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      var $5 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $5;
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($parent | 0) != 0 | $1 ^ 1) {
      var $12 = $parent;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $proto_idx_val = HEAP32[$proto + 20 >> 2];
    var $10 = __ZNK8JSObject9getParentEv($proto_idx_val);
    var $12 = $10;
    __label__ = 6;
    break;
   case 6:
    var $12;
    var $13 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, $clasp, $5, $12, 0, $13);
    var $clasp_idx_val = HEAP32[$clasp + 4 >> 2];
    var $14 = __ZNK2js5Class8isNativeEv($clasp_idx_val);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $16 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE3115($cx, $6, $clasp, $5, $kind);
    if ($16) {
      var $_0 = $6;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = 0;
    __label__ = 10;
    break;
   case 9:
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    var $_0 = $6;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE19growByUninitializedEj($this, $incr) {
  var $1 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr);
  return $1;
}

function __ZN2jsL15MakeRangeGCSafeEPiS0_($beg, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($beg | 0) == ($end | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $2 = _INT_TO_JSID3072(0);
    var $id_01 = $beg;
    __label__ = 3;
    break;
   case 3:
    var $id_01;
    HEAP32[$id_01 >> 2] = $2;
    var $4 = $id_01 + 4 | 0;
    if (($4 | 0) == ($end | 0)) {
      __label__ = 4;
      break;
    } else {
      var $id_01 = $4;
      __label__ = 3;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 8 | 0;
    var $4 = HEAPU32[$3 >> 2];
    if ((HEAP32[$this + 12 >> 2] - $4 | 0) >>> 0 < $incr >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $11 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = $this;
    var $9 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE13growStorageByEj($8, $incr);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $11 = HEAP32[$3 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $11;
    HEAP32[$3 >> 2] = $11 + $incr | 0;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE3127($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, __ZN2js11ObjectClassE, $1, $parent, 0, (__ZN2js11ObjectClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $7 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, __ZN2js11ObjectClassE, $kind);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $10);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12ATOM_TO_JSIDP6JSAtom3129($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj3130($1);
  return $2;
}

function __ZNK8JSObject13getProxyExtraEv($this) {
  var $1 = __ZNK8JSObject7getSlotEj($this, 2);
  return $1;
}

function __ZN2JSL10Int32ValueEi3140($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZL7GetTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $handler, $atom, $fvalp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $7 = __ZL12ATOM_TO_JSIDP6JSAtom3129($atom);
    var $8 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($handler, $cx, $7, $fvalp);
    var $_0 = ($8 | 0) != 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPP8JSObject($this, $type, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tv = __stackBase__;
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3397($2, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN2js11NodeBuilder10setNodeLocEP8JSObjectPNS_8TokenPosE($this, $3, $pos);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $9 = HEAP32[__ZN2js13nodeTypeNamesE + ($type << 2) >> 2];
    var $this_idx_val = HEAP32[$1 >> 2];
    var $10 = __ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE($this_idx_val, $9, $tv);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $12 = $tv | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    var $$emscripten$temp$0 = STRING_TABLE.__str1763328 | 0;
    var $14 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $3, $$emscripten$temp$0, $13$0, $13$1);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    HEAP32[$dst >> 2] = $3;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3397($cx, $parent) {
  var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb3408($3);
  var $5 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3409($cx, $parent, $4);
  return $5;
}

function __ZN2js11NodeBuilder10setNodeLocEP8JSObjectPNS_8TokenPosE($this, $node, $pos) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $loc = __stackBase__ + 8;
    if ((HEAP8[$this + 4 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JSL9NullValueEv3400($1);
    var $_idx1 = $1 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $$emscripten$temp$0 = STRING_TABLE.__str1823334 | 0;
    var $7 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $node, $$emscripten$temp$0, $_idx1_val$0, $_idx1_val$1);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $9 = __ZN2js11NodeBuilder10newNodeLocEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $loc);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = $loc | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $$emscripten$temp$1 = STRING_TABLE.__str1823334 | 0;
    var $13 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $node, $$emscripten$temp$1, $12$0, $12$1);
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE($this_0_0_val, $s, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _strlen($s);
    var $2 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($this_0_0_val, $s, $1, 0);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 | 0;
    __ZN2JS5Value9setStringEP8JSString($dst, $5);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $obj, $name, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $val = __stackBase__;
    var $1 = $val | 0;
    HEAP32[$1 >> 2] = $_0_0_0_val$0;
    HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
    var $2 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_0_0_0_val$0, $_0_0_0_val$1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value7setNullEv($val);
    __label__ = 3;
    break;
   case 3:
    var $5 = $this | 0;
    var $6 = HEAP32[$5 >> 2];
    var $7 = _strlen($name);
    var $8 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($6, $name, $7, 0);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = HEAP32[$5 >> 2];
    var $12 = __ZL12ATOM_TO_JSIDP6JSAtom3421($8);
    var $13 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj, $11, $12, $val, 10, 12, 1);
    var $_0 = ($13 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $elts, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $val = __stackBase__;
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $elts | 0;
    var $7 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($6);
    var $8 = $val | 0;
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    if ($i_0 >>> 0 < $7 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $12 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($6, $i_0);
    var $13 = $12 | 0;
    var $14$0 = HEAPU32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    HEAP32[$8 >> 2] = $14$0;
    HEAP32[$8 + 4 >> 2] = $14$1;
    var $15 = __ZNK2JS5Value7isMagicE10JSWhyMagic($14$0, $14$1);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = HEAP32[$1 >> 2];
    var $18 = _INT_TO_JSID3398($i_0);
    var $19 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($3, $17, $18, $val, 0);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 3;
    break;
   case 7:
    __ZN2JS5Value9setObjectER8JSObject($dst, $3);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder10newNodeLocEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $loc = __stackBase__;
    var $to = __stackBase__ + 4;
    var $tv = __stackBase__ + 8;
    var $1 = __stackBase__ + 16;
    var $2 = __stackBase__ + 24;
    if (($pos | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value7setNullEv($dst);
    var $_0 = 1;
    __label__ = 13;
    break;
   case 3:
    var $this_idx2 = $this | 0;
    var $this_idx2_val = HEAP32[$this_idx2 >> 2];
    var $6 = __ZN2js11NodeBuilder9newObjectEPP8JSObject($this_idx2_val, $loc);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 4:
    var $8 = HEAP32[$loc >> 2];
    __ZN2JS5Value9setObjectER8JSObject($dst, $8);
    var $this_idx1_val = HEAP32[$this_idx2 >> 2];
    var $9 = __ZN2js11NodeBuilder9newObjectEPP8JSObject($this_idx1_val, $to);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 5:
    var $11 = HEAP32[$to >> 2];
    __ZN2JSL11ObjectValueER8JSObject3399($1, $11);
    var $_idx8 = $1 | 0;
    var $st$3$0 = $_idx8 | 0;
    var $_idx8_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx8 + 4 | 0;
    var $_idx8_val$1 = HEAP32[$st$3$1 >> 2];
    var $$emscripten$temp$0 = STRING_TABLE.__str1773329 | 0;
    var $12 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $8, $$emscripten$temp$0, $_idx8_val$0, $_idx8_val$1);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 6:
    var $15 = HEAP32[$pos + 4 >> 2];
    var $16 = __ZN2JS5Value9setNumberEj($tv, $15);
    var $17 = $tv | 0;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    var $$emscripten$temp$1 = STRING_TABLE.__str1783330 | 0;
    var $19 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $11, $$emscripten$temp$1, $18$0, $18$1);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 7:
    var $22 = HEAP32[$pos >> 2];
    var $23 = __ZN2JS5Value9setNumberEj($tv, $22);
    var $st$3$0 = $17 | 0;
    var $24$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $17 + 4 | 0;
    var $24$1 = HEAP32[$st$3$1 >> 2];
    var $$emscripten$temp$2 = STRING_TABLE.__str1793331 | 0;
    var $25 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $11, $$emscripten$temp$2, $24$0, $24$1);
    if ($25) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 8:
    var $this_idx_val = HEAP32[$this_idx2 >> 2];
    var $27 = __ZN2js11NodeBuilder9newObjectEPP8JSObject($this_idx_val, $to);
    if ($27) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 9:
    var $29 = HEAP32[$to >> 2];
    __ZN2JSL11ObjectValueER8JSObject3399($2, $29);
    var $_idx5 = $2 | 0;
    var $st$3$0 = $_idx5 | 0;
    var $_idx5_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx5 + 4 | 0;
    var $_idx5_val$1 = HEAP32[$st$3$1 >> 2];
    var $$emscripten$temp$3 = STRING_TABLE.__str1803332 | 0;
    var $30 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $8, $$emscripten$temp$3, $_idx5_val$0, $_idx5_val$1);
    if ($30) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 10:
    var $33 = HEAP32[$pos + 12 >> 2];
    var $34 = __ZN2JS5Value9setNumberEj($tv, $33);
    var $st$3$0 = $17 | 0;
    var $35$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $17 + 4 | 0;
    var $35$1 = HEAP32[$st$3$1 >> 2];
    var $$emscripten$temp$4 = STRING_TABLE.__str1783330 | 0;
    var $36 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $29, $$emscripten$temp$4, $35$0, $35$1);
    if ($36) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 11:
    var $39 = HEAP32[$pos + 8 >> 2];
    var $40 = __ZN2JS5Value9setNumberEj($tv, $39);
    var $st$3$0 = $17 | 0;
    var $41$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $17 + 4 | 0;
    var $41$1 = HEAP32[$st$3$1 >> 2];
    var $$emscripten$temp$5 = STRING_TABLE.__str1793331 | 0;
    var $42 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $29, $$emscripten$temp$5, $41$0, $41$1);
    if ($42) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 12:
    var $44 = $this + 16 | 0;
    var $45$0 = HEAP32[$44 >> 2];
    var $45$1 = HEAP32[$44 + 4 >> 2];
    var $$emscripten$temp$6 = STRING_TABLE.__str263469 | 0;
    var $46 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $8, $$emscripten$temp$6, $45$0, $45$1);
    var $_0 = $46;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder10newNodeLocEPNS_8TokenPosEPN2JS5ValueE["X"] = 1;

function __ZN2js11NodeBuilder9newObjectEPP8JSObject($this_0_0_val, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3397($this_0_0_val, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$dst >> 2] = $1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11ObjectValueER8JSObject3399($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN2JSL9NullValueEv3400($agg_result) {
  __ZN2JS5Value7setNullEv($agg_result);
  return;
}

function __ZN2js11NodeBuilder7programERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 0, STRING_TABLE.__str1833335 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $type, $propName, $elts, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $1 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $elts, $array);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = $this + 24 + ($type << 3) | 0;
    var $4$0 = HEAP32[$3 >> 2];
    var $4$1 = HEAP32[$3 + 4 >> 2];
    var $5 = __ZNK2JS5Value6isNullEv($4$0, $4$1);
    var $6 = $array | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $4$0, $4$1, $7$0, $7$1, $pos, $dst);
    var $_0 = $9;
    __label__ = 5;
    break;
   case 4:
    var $11 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, $type, $pos, $propName, $7$0, $7$1, $dst);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder14blockStatementERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 28, STRING_TABLE.__str1833335 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder19expressionStatementEN2JS5ValueEPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 256 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZNK2JS5Value6isNullEv($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2$0, $2$1, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = STRING_TABLE.__str1843336 | 0;
    var $7 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 29, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fun = __stackBase__;
    var $loc = __stackBase__ + 8;
    var $argv = __stackBase__ + 16;
    var $argv1 = __stackBase__ + 32;
    var $1 = $fun | 0;
    HEAP32[$1 >> 2] = $_0_0_0_val$0;
    HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
    if ((HEAP8[$this + 4 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZN2js11NodeBuilder10newNodeLocEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $loc);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = $argv | 0;
    var $argv5_0 = $argv | 0;
    HEAP32[$argv5_0 >> 2] = $_0_0_0_val1$0;
    HEAP32[$argv5_0 + 4 >> 2] = $_0_0_0_val1$1;
    var $10 = $loc | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = $argv + 8 | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    var $14 = HEAP32[$this >> 2];
    var $15 = $this + 576 | 0;
    var $16 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($14, $15, $fun, 2, $9, $dst);
    var $_0 = $16;
    __label__ = 5;
    break;
   case 4:
    var $argv17_0 = $argv1 | 0;
    HEAP32[$argv17_0 >> 2] = $_0_0_0_val1$0;
    HEAP32[$argv17_0 + 4 >> 2] = $_0_0_0_val1$1;
    var $19 = HEAP32[$this >> 2];
    var $20 = $this + 576 | 0;
    var $21 = $argv1 | 0;
    var $22 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($19, $20, $fun, 1, $21, $dst);
    var $_0 = $22;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, $type, $pos, $childName, $_0_0_0_val$0, $_0_0_0_val$1, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $node = __stackBase__;
    var $1 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPP8JSObject($this, $type, $pos, $node);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = HEAP32[$node >> 2];
    var $4 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $3, $childName, $_0_0_0_val$0, $_0_0_0_val$1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $7 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js11NodeBuilder9setResultEP8JSObjectPN2JS5ValueE($3, $dst);
    var $7 = 1;
    __label__ = 4;
    break;
   case 4:
    var $7;
    STACKTOP = __stackBase__;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder14emptyStatementEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 240 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZNK2JS5Value6isNullEv($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11NodeBuilder8callbackEN2JS5ValueEPNS_8TokenPosEPS2_($this, $2$0, $2$1, $pos, $dst);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $7 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPN2JS5ValueE($this, 27, $pos, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder8callbackEN2JS5ValueEPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fun = __stackBase__;
    var $loc = __stackBase__ + 8;
    var $argv = __stackBase__ + 16;
    var $argv1 = __stackBase__ + 24;
    var $1 = $fun | 0;
    HEAP32[$1 >> 2] = $_0_0_0_val$0;
    HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
    if ((HEAP8[$this + 4 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZN2js11NodeBuilder10newNodeLocEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $loc);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = $argv | 0;
    var $10 = $loc | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = $argv | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    var $14 = HEAP32[$this >> 2];
    var $15 = $this + 576 | 0;
    var $16 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($14, $15, $fun, 1, $9, $dst);
    var $_0 = $16;
    __label__ = 5;
    break;
   case 4:
    var $18 = $argv1 | 0;
    __ZN2JSL9NullValueEv3400($18);
    var $20 = HEAP32[$this >> 2];
    var $21 = $this + 576 | 0;
    var $22 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($20, $21, $fun, 0, $18, $dst);
    var $_0 = $22;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPN2JS5ValueE($this, $type, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $node = __stackBase__;
    var $1 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPP8JSObject($this, $type, $pos, $node);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $5 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$node >> 2];
    __ZN2js11NodeBuilder9setResultEP8JSObjectPN2JS5ValueE($3, $dst);
    var $5 = 1;
    __label__ = 3;
    break;
   case 3:
    var $5;
    STACKTOP = __stackBase__;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder11ifStatementEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $_0_0_0_val2$0, $_0_0_0_val2$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 272 | 0;
    var $st$2$0 = $2 | 0;
    var $3$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $2 + 4 | 0;
    var $3$1 = HEAP32[$st$2$1 >> 2];
    var $4 = __ZNK2JS5Value6isNullEv($3$0, $3$1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js11NodeBuilder3optEN2JS5ValueE($1, $_0_0_0_val2$0, $_0_0_0_val2$1);
    var $_idx6 = $1 | 0;
    var $st$2$0 = $_idx6 | 0;
    var $_idx6_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx6 + 4 | 0;
    var $_idx6_val$1 = HEAP32[$st$2$1 >> 2];
    var $6 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $3$0, $3$1, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $_idx6_val$0, $_idx6_val$1, $pos, $dst);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$2 = STRING_TABLE.__str1873339 | 0;
    var $$emscripten$temp$1 = STRING_TABLE.__str1863338 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str253468 | 0;
    var $8 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 31, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $$emscripten$temp$2, $_0_0_0_val2$0, $_0_0_0_val2$1, $dst);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $_0_0_0_val2$0, $_0_0_0_val2$1, $_0_0_0_val3$0, $_0_0_0_val3$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fun = __stackBase__;
    var $loc = __stackBase__ + 8;
    var $argv = __stackBase__ + 16;
    var $argv1 = __stackBase__ + 48;
    var $1 = $fun | 0;
    HEAP32[$1 >> 2] = $_0_0_0_val$0;
    HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
    if ((HEAP8[$this + 4 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZN2js11NodeBuilder10newNodeLocEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $loc);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = $argv | 0;
    var $argv23_0 = $argv | 0;
    var $st$2$0 = $argv23_0 | 0;
    HEAP32[$st$2$0 >> 2] = $_0_0_0_val1$0;
    var $st$2$1 = $argv23_0 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $_0_0_0_val1$1;
    var $_014 = $argv + 8 | 0;
    var $st$7$0 = $_014 | 0;
    HEAP32[$st$7$0 >> 2] = $_0_0_0_val2$0;
    var $st$7$1 = $_014 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $_0_0_0_val2$1;
    var $_05 = $argv + 16 | 0;
    var $st$12$0 = $_05 | 0;
    HEAP32[$st$12$0 >> 2] = $_0_0_0_val3$0;
    var $st$12$1 = $_05 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $_0_0_0_val3$1;
    var $10 = $loc | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = $argv + 24 | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    var $14 = HEAP32[$this >> 2];
    var $15 = $this + 576 | 0;
    var $16 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($14, $15, $fun, 4, $9, $dst);
    var $_0 = $16;
    __label__ = 5;
    break;
   case 4:
    var $18 = $argv1 | 0;
    var $argv125_0 = $argv1 | 0;
    var $st$2$0 = $argv125_0 | 0;
    HEAP32[$st$2$0 >> 2] = $_0_0_0_val1$0;
    var $st$2$1 = $argv125_0 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $_0_0_0_val1$1;
    var $_016 = $argv1 + 8 | 0;
    var $st$7$0 = $_016 | 0;
    HEAP32[$st$7$0 >> 2] = $_0_0_0_val2$0;
    var $st$7$1 = $_016 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $_0_0_0_val2$1;
    var $_07 = $argv1 + 16 | 0;
    var $st$12$0 = $_07 | 0;
    HEAP32[$st$12$0 >> 2] = $_0_0_0_val3$0;
    var $st$12$1 = $_07 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $_0_0_0_val3$1;
    var $20 = HEAP32[$this >> 2];
    var $21 = $this + 576 | 0;
    var $22 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($20, $21, $fun, 3, $18, $dst);
    var $_0 = $22;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder3optEN2JS5ValueE($agg_result, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value7isMagicE10JSWhyMagic($_0_0_0_val$0, $_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JSL14UndefinedValueEv3403($agg_result);
    __label__ = 4;
    break;
   case 3:
    var $4 = $agg_result | 0;
    HEAP32[$4 >> 2] = $_0_0_0_val$0;
    HEAP32[$4 + 4 >> 2] = $_0_0_0_val$1;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, $type, $pos, $childName1, $_0_0_0_val$0, $_0_0_0_val$1, $childName2, $_0_0_0_val1$0, $_0_0_0_val1$1, $childName3, $_0_0_0_val2$0, $_0_0_0_val2$1, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $node = __stackBase__;
    var $1 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPP8JSObject($this, $type, $pos, $node);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $3 = HEAP32[$node >> 2];
    var $4 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $3, $childName1, $_0_0_0_val$0, $_0_0_0_val$1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $11 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $6 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $3, $childName2, $_0_0_0_val1$0, $_0_0_0_val1$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      var $11 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $8 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $3, $childName3, $_0_0_0_val2$0, $_0_0_0_val2$1);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      var $11 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js11NodeBuilder9setResultEP8JSObjectPN2JS5ValueE($3, $dst);
    var $11 = 1;
    __label__ = 6;
    break;
   case 6:
    var $11;
    STACKTOP = __stackBase__;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder14breakStatementEN2JS5ValueEPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 320 | 0;
    var $st$2$0 = $2 | 0;
    var $3$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $2 + 4 | 0;
    var $3$1 = HEAP32[$st$2$1 >> 2];
    var $4 = __ZNK2JS5Value6isNullEv($3$0, $3$1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js11NodeBuilder3optEN2JS5ValueE($1, $_0_0_0_val$0, $_0_0_0_val$1);
    var $_idx1 = $1 | 0;
    var $st$2$0 = $_idx1 | 0;
    var $_idx1_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx1 + 4 | 0;
    var $_idx1_val$1 = HEAP32[$st$2$1 >> 2];
    var $6 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $3$0, $3$1, $_idx1_val$0, $_idx1_val$1, $pos, $dst);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = STRING_TABLE.__str1883340 | 0;
    var $8 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 37, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $dst);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder17continueStatementEN2JS5ValueEPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 328 | 0;
    var $st$2$0 = $2 | 0;
    var $3$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $2 + 4 | 0;
    var $3$1 = HEAP32[$st$2$1 >> 2];
    var $4 = __ZNK2JS5Value6isNullEv($3$0, $3$1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js11NodeBuilder3optEN2JS5ValueE($1, $_0_0_0_val$0, $_0_0_0_val$1);
    var $_idx1 = $1 | 0;
    var $st$2$0 = $_idx1 | 0;
    var $_idx1_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx1 + 4 | 0;
    var $_idx1_val$1 = HEAP32[$st$2$1 >> 2];
    var $6 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $3$0, $3$1, $_idx1_val$0, $_idx1_val$1, $pos, $dst);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = STRING_TABLE.__str1883340 | 0;
    var $8 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 38, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $dst);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder16labeledStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 264 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZNK2JS5Value6isNullEv($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $2$0, $2$1, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$1 = STRING_TABLE.__str1833335 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str1883340 | 0;
    var $7 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 30, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $_0_0_0_val2$0, $_0_0_0_val2$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fun = __stackBase__;
    var $loc = __stackBase__ + 8;
    var $argv = __stackBase__ + 16;
    var $argv1 = __stackBase__ + 40;
    var $1 = $fun | 0;
    HEAP32[$1 >> 2] = $_0_0_0_val$0;
    HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
    if ((HEAP8[$this + 4 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZN2js11NodeBuilder10newNodeLocEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $loc);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = $argv | 0;
    var $argv14_0 = $argv | 0;
    var $st$2$0 = $argv14_0 | 0;
    HEAP32[$st$2$0 >> 2] = $_0_0_0_val1$0;
    var $st$2$1 = $argv14_0 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $_0_0_0_val1$1;
    var $_05 = $argv + 8 | 0;
    var $st$7$0 = $_05 | 0;
    HEAP32[$st$7$0 >> 2] = $_0_0_0_val2$0;
    var $st$7$1 = $_05 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $_0_0_0_val2$1;
    var $10 = $loc | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = $argv + 16 | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    var $14 = HEAP32[$this >> 2];
    var $15 = $this + 576 | 0;
    var $16 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($14, $15, $fun, 3, $9, $dst);
    var $_0 = $16;
    __label__ = 5;
    break;
   case 4:
    var $18 = $argv1 | 0;
    var $argv116_0 = $argv1 | 0;
    var $st$2$0 = $argv116_0 | 0;
    HEAP32[$st$2$0 >> 2] = $_0_0_0_val1$0;
    var $st$2$1 = $argv116_0 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $_0_0_0_val1$1;
    var $_07 = $argv1 + 8 | 0;
    var $st$7$0 = $_07 | 0;
    HEAP32[$st$7$0 >> 2] = $_0_0_0_val2$0;
    var $st$7$1 = $_07 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $_0_0_0_val2$1;
    var $20 = HEAP32[$this >> 2];
    var $21 = $this + 576 | 0;
    var $22 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($20, $21, $fun, 2, $18, $dst);
    var $_0 = $22;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, $type, $pos, $childName1, $_0_0_0_val$0, $_0_0_0_val$1, $childName2, $_0_0_0_val1$0, $_0_0_0_val1$1, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $node = __stackBase__;
    var $1 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPP8JSObject($this, $type, $pos, $node);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $9 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = HEAP32[$node >> 2];
    var $4 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $3, $childName1, $_0_0_0_val$0, $_0_0_0_val$1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $9 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $6 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $3, $childName2, $_0_0_0_val1$0, $_0_0_0_val1$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      var $9 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js11NodeBuilder9setResultEP8JSObjectPN2JS5ValueE($3, $dst);
    var $9 = 1;
    __label__ = 5;
    break;
   case 5:
    var $9;
    STACKTOP = __stackBase__;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder14throwStatementEN2JS5ValueEPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 360 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZNK2JS5Value6isNullEv($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2$0, $2$1, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = STRING_TABLE.__str1893341 | 0;
    var $7 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 42, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder15returnStatementEN2JS5ValueEPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 344 | 0;
    var $st$2$0 = $2 | 0;
    var $3$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $2 + 4 | 0;
    var $3$1 = HEAP32[$st$2$1 >> 2];
    var $4 = __ZNK2JS5Value6isNullEv($3$0, $3$1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js11NodeBuilder3optEN2JS5ValueE($1, $_0_0_0_val$0, $_0_0_0_val$1);
    var $_idx1 = $1 | 0;
    var $st$2$0 = $_idx1 | 0;
    var $_idx1_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx1 + 4 | 0;
    var $_idx1_val$1 = HEAP32[$st$2$1 >> 2];
    var $6 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $3$0, $3$1, $_idx1_val$0, $_idx1_val$1, $pos, $dst);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = STRING_TABLE.__str1893341 | 0;
    var $8 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 40, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $dst);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder12forStatementEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $_0_0_0_val2$0, $_0_0_0_val2$1, $_0_0_0_val3$0, $_0_0_0_val3$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = $this + 304 | 0;
    var $st$4$0 = $4 | 0;
    var $5$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $4 + 4 | 0;
    var $5$1 = HEAP32[$st$4$1 >> 2];
    var $6 = __ZNK2JS5Value6isNullEv($5$0, $5$1);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js11NodeBuilder3optEN2JS5ValueE($1, $_0_0_0_val$0, $_0_0_0_val$1);
    __ZN2js11NodeBuilder3optEN2JS5ValueE($2, $_0_0_0_val1$0, $_0_0_0_val1$1);
    __ZN2js11NodeBuilder3optEN2JS5ValueE($3, $_0_0_0_val2$0, $_0_0_0_val2$1);
    var $_idx4 = $1 | 0;
    var $st$4$0 = $_idx4 | 0;
    var $_idx4_val$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $_idx4 + 4 | 0;
    var $_idx4_val$1 = HEAP32[$st$4$1 >> 2];
    var $_idx5 = $2 | 0;
    var $_idx5_val$0 = HEAP32[$_idx5 >> 2];
    var $_idx5_val$1 = HEAP32[$_idx5 + 4 >> 2];
    var $_idx6 = $3 | 0;
    var $_idx6_val$0 = HEAP32[$_idx6 >> 2];
    var $_idx6_val$1 = HEAP32[$_idx6 + 4 >> 2];
    var $8 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_S2_PNS_8TokenPosEPS2_($this, $5$0, $5$1, $_idx4_val$0, $_idx4_val$1, $_idx5_val$0, $_idx5_val$1, $_idx6_val$0, $_idx6_val$1, $_0_0_0_val3$0, $_0_0_0_val3$1, $pos, $dst);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$3 = STRING_TABLE.__str1833335 | 0;
    var $$emscripten$temp$2 = STRING_TABLE.__str1913343 | 0;
    var $$emscripten$temp$1 = STRING_TABLE.__str253468 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str1903342 | 0;
    var $10 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_S5_S7_PS7_($this, 35, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $$emscripten$temp$2, $_0_0_0_val2$0, $_0_0_0_val2$1, $$emscripten$temp$3, $_0_0_0_val3$0, $_0_0_0_val3$1, $dst);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_S2_PNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $_0_0_0_val2$0, $_0_0_0_val2$1, $_0_0_0_val3$0, $_0_0_0_val3$1, $_0_0_0_val4$0, $_0_0_0_val4$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 88;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fun = __stackBase__;
    var $loc = __stackBase__ + 8;
    var $argv = __stackBase__ + 16;
    var $argv1 = __stackBase__ + 56;
    var $1 = $fun | 0;
    HEAP32[$1 >> 2] = $_0_0_0_val$0;
    HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
    if ((HEAP8[$this + 4 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZN2js11NodeBuilder10newNodeLocEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $loc);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = $argv | 0;
    var $argv32_0 = $argv | 0;
    var $st$2$0 = $argv32_0 | 0;
    HEAP32[$st$2$0 >> 2] = $_0_0_0_val1$0;
    var $st$2$1 = $argv32_0 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $_0_0_0_val1$1;
    var $_023 = $argv + 8 | 0;
    var $st$7$0 = $_023 | 0;
    HEAP32[$st$7$0 >> 2] = $_0_0_0_val2$0;
    var $st$7$1 = $_023 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $_0_0_0_val2$1;
    var $_014 = $argv + 16 | 0;
    var $st$12$0 = $_014 | 0;
    HEAP32[$st$12$0 >> 2] = $_0_0_0_val3$0;
    var $st$12$1 = $_014 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $_0_0_0_val3$1;
    var $_05 = $argv + 24 | 0;
    var $st$17$0 = $_05 | 0;
    HEAP32[$st$17$0 >> 2] = $_0_0_0_val4$0;
    var $st$17$1 = $_05 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $_0_0_0_val4$1;
    var $10 = $loc | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = $argv + 32 | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    var $14 = HEAP32[$this >> 2];
    var $15 = $this + 576 | 0;
    var $16 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($14, $15, $fun, 5, $9, $dst);
    var $_0 = $16;
    __label__ = 5;
    break;
   case 4:
    var $18 = $argv1 | 0;
    var $argv134_0 = $argv1 | 0;
    var $st$2$0 = $argv134_0 | 0;
    HEAP32[$st$2$0 >> 2] = $_0_0_0_val1$0;
    var $st$2$1 = $argv134_0 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $_0_0_0_val1$1;
    var $_025 = $argv1 + 8 | 0;
    var $st$7$0 = $_025 | 0;
    HEAP32[$st$7$0 >> 2] = $_0_0_0_val2$0;
    var $st$7$1 = $_025 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $_0_0_0_val2$1;
    var $_016 = $argv1 + 16 | 0;
    var $st$12$0 = $_016 | 0;
    HEAP32[$st$12$0 >> 2] = $_0_0_0_val3$0;
    var $st$12$1 = $_016 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $_0_0_0_val3$1;
    var $_07 = $argv1 + 24 | 0;
    var $st$17$0 = $_07 | 0;
    HEAP32[$st$17$0 >> 2] = $_0_0_0_val4$0;
    var $st$17$1 = $_07 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $_0_0_0_val4$1;
    var $20 = HEAP32[$this >> 2];
    var $21 = $this + 576 | 0;
    var $22 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($20, $21, $fun, 4, $18, $dst);
    var $_0 = $22;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_S2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_S5_S7_PS7_($this, $type, $pos, $childName1, $_0_0_0_val$0, $_0_0_0_val$1, $childName2, $_0_0_0_val1$0, $_0_0_0_val1$1, $childName3, $_0_0_0_val2$0, $_0_0_0_val2$1, $childName4, $_0_0_0_val3$0, $_0_0_0_val3$1, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $node = __stackBase__;
    var $1 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPP8JSObject($this, $type, $pos, $node);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $13 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $3 = HEAP32[$node >> 2];
    var $4 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $3, $childName1, $_0_0_0_val$0, $_0_0_0_val$1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $13 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    var $6 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $3, $childName2, $_0_0_0_val1$0, $_0_0_0_val1$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      var $13 = 0;
      __label__ = 7;
      break;
    }
   case 4:
    var $8 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $3, $childName3, $_0_0_0_val2$0, $_0_0_0_val2$1);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      var $13 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $10 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $3, $childName4, $_0_0_0_val3$0, $_0_0_0_val3$1);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      var $13 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js11NodeBuilder9setResultEP8JSObjectPN2JS5ValueE($3, $dst);
    var $13 = 1;
    __label__ = 7;
    break;
   case 7:
    var $13;
    STACKTOP = __stackBase__;
    return $13;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder14forInStatementEN2JS5ValueES2_S2_bPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $_0_0_0_val2$0, $_0_0_0_val2$1, $isForEach, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $this + 312 | 0;
    var $4$0 = HEAP32[$3 >> 2];
    var $4$1 = HEAP32[$3 + 4 >> 2];
    var $5 = __ZNK2JS5Value6isNullEv($4$0, $4$1);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL12BooleanValueEb3401($1, $isForEach);
    var $_idx4 = $1 | 0;
    var $st$2$0 = $_idx4 | 0;
    var $_idx4_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx4 + 4 | 0;
    var $_idx4_val$1 = HEAP32[$st$2$1 >> 2];
    var $7 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_S2_PNS_8TokenPosEPS2_($this, $4$0, $4$1, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $_0_0_0_val2$0, $_0_0_0_val2$1, $_idx4_val$0, $_idx4_val$1, $pos, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL12BooleanValueEb3401($2, $isForEach);
    var $_idx8 = $2 | 0;
    var $st$2$0 = $_idx8 | 0;
    var $_idx8_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx8 + 4 | 0;
    var $_idx8_val$1 = HEAP32[$st$2$1 >> 2];
    var $$emscripten$temp$3 = STRING_TABLE.__str1943346 | 0;
    var $$emscripten$temp$2 = STRING_TABLE.__str1833335 | 0;
    var $$emscripten$temp$1 = STRING_TABLE.__str1933345 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str1923344 | 0;
    var $9 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_S5_S7_PS7_($this, 36, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $$emscripten$temp$2, $_0_0_0_val2$0, $_0_0_0_val2$1, $$emscripten$temp$3, $_idx8_val$0, $_idx8_val$1, $dst);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL12BooleanValueEb3401($agg_result, $boo) {
  __ZN2JS5Value10setBooleanEb($agg_result, $boo);
  return;
}

function __ZN2js11NodeBuilder13withStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 336 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZNK2JS5Value6isNullEv($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $2$0, $2$1, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$1 = STRING_TABLE.__str1833335 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str267560 | 0;
    var $7 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 39, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder14whileStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 288 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZNK2JS5Value6isNullEv($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $2$0, $2$1, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$1 = STRING_TABLE.__str1833335 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str253468 | 0;
    var $7 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 33, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder16doWhileStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 296 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZNK2JS5Value6isNullEv($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $2$0, $2$1, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$1 = STRING_TABLE.__str253468 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str1833335 | 0;
    var $7 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 34, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder15switchStatementEN2JS5ValueERNS_15AutoValueVectorEbPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $elts, $lexical, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $elts, $array);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $5 = $this + 280 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = __ZNK2JS5Value6isNullEv($6$0, $6$1);
    var $8 = $array | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JSL12BooleanValueEb3401($1, $lexical);
    var $_idx6 = $1 | 0;
    var $st$2$0 = $_idx6 | 0;
    var $_idx6_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx6 + 4 | 0;
    var $_idx6_val$1 = HEAP32[$st$2$1 >> 2];
    var $11 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $6$0, $6$1, $_0_0_0_val$0, $_0_0_0_val$1, $9$0, $9$1, $_idx6_val$0, $_idx6_val$1, $pos, $dst);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 4:
    __ZN2JSL12BooleanValueEb3401($2, $lexical);
    var $_idx2 = $2 | 0;
    var $st$2$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$2$1 >> 2];
    var $$emscripten$temp$2 = STRING_TABLE.__str1983350 | 0;
    var $$emscripten$temp$1 = STRING_TABLE.__str1973349 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str1963348 | 0;
    var $13 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 32, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $9$0, $9$1, $$emscripten$temp$2, $_idx2_val$0, $_idx2_val$1, $dst);
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder12tryStatementEN2JS5ValueERNS_15AutoValueVectorES2_PNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $catches, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $handlers = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = $this + 352 | 0;
    var $3$0 = HEAP32[$2 >> 2];
    var $3$1 = HEAP32[$2 + 4 >> 2];
    var $4 = __ZNK2JS5Value6isNullEv($3$0, $3$1);
    var $5 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $catches, $handlers);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $8 = $handlers | 0;
    var $st$1$0 = $8 | 0;
    var $9$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $8 + 4 | 0;
    var $9$1 = HEAP32[$st$1$1 >> 2];
    __ZN2js11NodeBuilder3optEN2JS5ValueE($1, $_0_0_0_val1$0, $_0_0_0_val1$1);
    var $_idx6 = $1 | 0;
    var $_idx6_val$0 = HEAP32[$_idx6 >> 2];
    var $_idx6_val$1 = HEAP32[$_idx6 + 4 >> 2];
    var $10 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $3$0, $3$1, $_0_0_0_val$0, $_0_0_0_val$1, $9$0, $9$1, $_idx6_val$0, $_idx6_val$1, $pos, $dst);
    var $_0 = $10;
    __label__ = 6;
    break;
   case 4:
    if ($5) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $13 = $handlers | 0;
    var $st$1$0 = $13 | 0;
    var $14$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $13 + 4 | 0;
    var $14$1 = HEAP32[$st$1$1 >> 2];
    var $$emscripten$temp$2 = STRING_TABLE.__str2013353 | 0;
    var $$emscripten$temp$1 = STRING_TABLE.__str2003352 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str1993351 | 0;
    var $15 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 41, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $14$0, $14$1, $$emscripten$temp$2, $_0_0_0_val1$0, $_0_0_0_val1$1, $dst);
    var $_0 = $15;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder17debuggerStatementEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 368 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZNK2JS5Value6isNullEv($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11NodeBuilder8callbackEN2JS5ValueEPNS_8TokenPosEPS2_($this, $2$0, $2$1, $pos, $dst);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $7 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPN2JS5ValueE($this, 43, $pos, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder16binaryExpressionENS_14BinaryOperatorEN2JS5ValueES3_PNS_8TokenPosEPS3_($this, $op, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $opName = __stackBase__;
    var $2 = HEAP32[__ZN2js10binopNamesE + ($op << 2) >> 2];
    var $this_idx_val = HEAP32[$this >> 2];
    var $3 = __ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE($this_idx_val, $2, $opName);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $5 = $this + 104 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = __ZNK2JS5Value6isNullEv($6$0, $6$1);
    var $8 = $opName | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $6$0, $6$1, $9$0, $9$1, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 4:
    var $$emscripten$temp$2 = STRING_TABLE.__str1933345 | 0;
    var $$emscripten$temp$1 = STRING_TABLE.__str1923344 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str2023354 | 0;
    var $13 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 10, $pos, $$emscripten$temp$0, $9$0, $9$1, $$emscripten$temp$1, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$2, $_0_0_0_val1$0, $_0_0_0_val1$1, $dst);
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder15unaryExpressionENS_13UnaryOperatorEN2JS5ValueEPNS_8TokenPosEPS3_($this, $unop, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $opName = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $3 = HEAP32[__ZN2js9unopNamesE + ($unop << 2) >> 2];
    var $this_idx_val = HEAP32[$this >> 2];
    var $4 = __ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE($this_idx_val, $3, $opName);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $6 = $this + 96 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = __ZNK2JS5Value6isNullEv($7$0, $7$1);
    var $9 = $opName | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $7$0, $7$1, $10$0, $10$1, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst);
    var $_0 = $12;
    __label__ = 5;
    break;
   case 4:
    __ZN2JSL12BooleanValueEb3401($1, 1);
    var $_idx5 = $1 | 0;
    var $_idx5_val$0 = HEAP32[$_idx5 >> 2];
    var $_idx5_val$1 = HEAP32[$_idx5 + 4 >> 2];
    var $$emscripten$temp$2 = STRING_TABLE.__str2033355 | 0;
    var $$emscripten$temp$1 = STRING_TABLE.__str1893341 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str2023354 | 0;
    var $14 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 9, $pos, $$emscripten$temp$0, $10$0, $10$1, $$emscripten$temp$1, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$2, $_idx5_val$0, $_idx5_val$1, $dst);
    var $_0 = $14;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder20assignmentExpressionENS_18AssignmentOperatorEN2JS5ValueES3_PNS_8TokenPosEPS3_($this, $aop, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $opName = __stackBase__;
    var $2 = HEAP32[__ZN2js8aopNamesE + ($aop << 2) >> 2];
    var $this_idx_val = HEAP32[$this >> 2];
    var $3 = __ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE($this_idx_val, $2, $opName);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $5 = $this + 112 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = __ZNK2JS5Value6isNullEv($6$0, $6$1);
    var $8 = $opName | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $6$0, $6$1, $9$0, $9$1, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 4:
    var $$emscripten$temp$2 = STRING_TABLE.__str1933345 | 0;
    var $$emscripten$temp$1 = STRING_TABLE.__str1923344 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str2023354 | 0;
    var $13 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 11, $pos, $$emscripten$temp$0, $9$0, $9$1, $$emscripten$temp$1, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$2, $_0_0_0_val1$0, $_0_0_0_val1$1, $dst);
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder16updateExpressionEN2JS5ValueEbbPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $incr, $prefix, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $opName = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $_str2043356__str2053357 = $incr ? STRING_TABLE.__str2043356 : STRING_TABLE.__str2053357;
    var $3 = $_str2043356__str2053357 | 0;
    var $this_idx_val = HEAP32[$this >> 2];
    var $4 = __ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE($this_idx_val, $3, $opName);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $6 = $this + 128 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = __ZNK2JS5Value6isNullEv($7$0, $7$1);
    var $9 = $opName | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JSL12BooleanValueEb3401($1, $prefix);
    var $_idx6 = $1 | 0;
    var $st$2$0 = $_idx6 | 0;
    var $_idx6_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx6 + 4 | 0;
    var $_idx6_val$1 = HEAP32[$st$2$1 >> 2];
    var $12 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $7$0, $7$1, $_0_0_0_val$0, $_0_0_0_val$1, $10$0, $10$1, $_idx6_val$0, $_idx6_val$1, $pos, $dst);
    var $_0 = $12;
    __label__ = 5;
    break;
   case 4:
    __ZN2JSL12BooleanValueEb3401($2, $prefix);
    var $_idx2 = $2 | 0;
    var $st$2$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$2$1 >> 2];
    var $$emscripten$temp$2 = STRING_TABLE.__str2033355 | 0;
    var $$emscripten$temp$1 = STRING_TABLE.__str1893341 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str2023354 | 0;
    var $14 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 13, $pos, $$emscripten$temp$0, $10$0, $10$1, $$emscripten$temp$1, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$2, $_idx2_val$0, $_idx2_val$1, $dst);
    var $_0 = $14;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder17logicalExpressionEbN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $lor, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $opName = __stackBase__;
    var $_str2063358__str2073359 = $lor ? STRING_TABLE.__str2063358 : STRING_TABLE.__str2073359;
    var $1 = $_str2063358__str2073359 | 0;
    var $this_idx_val = HEAP32[$this >> 2];
    var $2 = __ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE($this_idx_val, $1, $opName);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = $this + 120 | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = __ZNK2JS5Value6isNullEv($5$0, $5$1);
    var $7 = $opName | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $5$0, $5$1, $8$0, $8$1, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst);
    var $_0 = $10;
    __label__ = 5;
    break;
   case 4:
    var $$emscripten$temp$2 = STRING_TABLE.__str1933345 | 0;
    var $$emscripten$temp$1 = STRING_TABLE.__str1923344 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str2023354 | 0;
    var $12 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 12, $pos, $$emscripten$temp$0, $8$0, $8$1, $$emscripten$temp$1, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$2, $_0_0_0_val1$0, $_0_0_0_val1$1, $dst);
    var $_0 = $12;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder21conditionalExpressionEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $_0_0_0_val2$0, $_0_0_0_val2$1, $pos, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 88 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZNK2JS5Value6isNullEv($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $2$0, $2$1, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $_0_0_0_val2$0, $_0_0_0_val2$1, $pos, $dst);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$2 = STRING_TABLE.__str1873339 | 0;
    var $$emscripten$temp$1 = STRING_TABLE.__str1863338 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str253468 | 0;
    var $7 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 8, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $$emscripten$temp$2, $_0_0_0_val2$0, $_0_0_0_val2$1, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder18sequenceExpressionERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 7, STRING_TABLE.__str2083360 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder14callExpressionEN2JS5ValueERNS_15AutoValueVectorEPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $args, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $1 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $args, $array);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = $this + 144 | 0;
    var $4$0 = HEAP32[$3 >> 2];
    var $4$1 = HEAP32[$3 + 4 >> 2];
    var $5 = __ZNK2JS5Value6isNullEv($4$0, $4$1);
    var $6 = $array | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $4$0, $4$1, $_0_0_0_val$0, $_0_0_0_val$1, $7$0, $7$1, $pos, $dst);
    var $_0 = $9;
    __label__ = 5;
    break;
   case 4:
    var $$emscripten$temp$1 = STRING_TABLE.__str142435 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str2093361 | 0;
    var $11 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 15, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $7$0, $7$1, $dst);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder13newExpressionEN2JS5ValueERNS_15AutoValueVectorEPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $args, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $1 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $args, $array);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = $this + 136 | 0;
    var $4$0 = HEAP32[$3 >> 2];
    var $4$1 = HEAP32[$3 + 4 >> 2];
    var $5 = __ZNK2JS5Value6isNullEv($4$0, $4$1);
    var $6 = $array | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $4$0, $4$1, $_0_0_0_val$0, $_0_0_0_val$1, $7$0, $7$1, $pos, $dst);
    var $_0 = $9;
    __label__ = 5;
    break;
   case 4:
    var $$emscripten$temp$1 = STRING_TABLE.__str142435 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str2093361 | 0;
    var $11 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 14, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $7$0, $7$1, $dst);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder16memberExpressionEbN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $computed, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $this + 152 | 0;
    var $4$0 = HEAP32[$3 >> 2];
    var $4$1 = HEAP32[$3 + 4 >> 2];
    var $5 = __ZNK2JS5Value6isNullEv($4$0, $4$1);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL12BooleanValueEb3401($1, $computed);
    var $_idx4 = $1 | 0;
    var $st$2$0 = $_idx4 | 0;
    var $_idx4_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx4 + 4 | 0;
    var $_idx4_val$1 = HEAP32[$st$2$1 >> 2];
    var $7 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $4$0, $4$1, $_idx4_val$0, $_idx4_val$1, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL12BooleanValueEb3401($2, $computed);
    var $_idx2 = $2 | 0;
    var $st$2$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$2$1 >> 2];
    var $$emscripten$temp$2 = STRING_TABLE.__str2113363 | 0;
    var $$emscripten$temp$1 = STRING_TABLE.__str1103262 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str267560 | 0;
    var $9 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 16, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $$emscripten$temp$2, $_idx2_val$0, $_idx2_val$1, $dst);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder15arrayExpressionERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 18, STRING_TABLE.__str174263 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder15propertyPatternEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $kindName = __stackBase__;
    var $this_idx_val = HEAP32[$this >> 2];
    var $1 = __ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE($this_idx_val, STRING_TABLE.__str1903342 | 0, $kindName);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = $this + 424 | 0;
    var $st$1$0 = $3 | 0;
    var $4$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $3 + 4 | 0;
    var $4$1 = HEAP32[$st$1$1 >> 2];
    var $5 = __ZNK2JS5Value6isNullEv($4$0, $4$1);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $4$0, $4$1, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 4:
    var $9 = $kindName | 0;
    var $st$1$0 = $9 | 0;
    var $10$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $9 + 4 | 0;
    var $10$1 = HEAP32[$st$1$1 >> 2];
    var $$emscripten$temp$2 = STRING_TABLE.__str2153367 | 0;
    var $$emscripten$temp$1 = STRING_TABLE.__str247540 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str2133365 | 0;
    var $11 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 50, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $$emscripten$temp$2, $10$0, $10$1, $dst);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder19propertyInitializerEN2JS5ValueES2_NS_8PropKindEPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $kind, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $kindName = __stackBase__;
    if (($kind | 0) == 0) {
      var $6 = STRING_TABLE.__str1903342 | 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_str2163368__str2173369 = ($kind | 0) == 1 ? STRING_TABLE.__str24079 : STRING_TABLE.__str44081;
    var $6 = $_str2163368__str2173369 | 0;
    __label__ = 3;
    break;
   case 3:
    var $6;
    var $this_idx_val = HEAP32[$this >> 2];
    var $7 = __ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE($this_idx_val, $6, $kindName);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 4:
    var $9 = $this + 48 | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = __ZNK2JS5Value6isNullEv($10$0, $10$1);
    var $12 = $kindName | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $10$0, $10$1, $13$0, $13$1, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst);
    var $_0 = $15;
    __label__ = 7;
    break;
   case 6:
    var $$emscripten$temp$2 = STRING_TABLE.__str2153367 | 0;
    var $$emscripten$temp$1 = STRING_TABLE.__str247540 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str2133365 | 0;
    var $17 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 3, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $$emscripten$temp$2, $13$0, $13$1, $dst);
    var $_0 = $17;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder16objectExpressionERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 19, STRING_TABLE.__str2183370 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder14thisExpressionEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 184 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZNK2JS5Value6isNullEv($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11NodeBuilder8callbackEN2JS5ValueEPNS_8TokenPosEPS2_($this, $2$0, $2$1, $pos, $dst);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $7 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPN2JS5ValueE($this, 20, $pos, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder15yieldExpressionEN2JS5ValueEPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 224 | 0;
    var $st$2$0 = $2 | 0;
    var $3$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $2 + 4 | 0;
    var $3$1 = HEAP32[$st$2$1 >> 2];
    var $4 = __ZNK2JS5Value6isNullEv($3$0, $3$1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js11NodeBuilder3optEN2JS5ValueE($1, $_0_0_0_val$0, $_0_0_0_val$1);
    var $_idx1 = $1 | 0;
    var $st$2$0 = $_idx1 | 0;
    var $_idx1_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx1 + 4 | 0;
    var $_idx1_val$1 = HEAP32[$st$2$1 >> 2];
    var $6 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $3$0, $3$1, $_idx1_val$0, $_idx1_val$1, $pos, $dst);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = STRING_TABLE.__str1893341 | 0;
    var $8 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 25, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $dst);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder18comprehensionBlockEN2JS5ValueES2_bPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $isForEach, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $this + 400 | 0;
    var $4$0 = HEAP32[$3 >> 2];
    var $4$1 = HEAP32[$3 + 4 >> 2];
    var $5 = __ZNK2JS5Value6isNullEv($4$0, $4$1);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL12BooleanValueEb3401($1, $isForEach);
    var $_idx6 = $1 | 0;
    var $st$2$0 = $_idx6 | 0;
    var $_idx6_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx6 + 4 | 0;
    var $_idx6_val$1 = HEAP32[$st$2$1 >> 2];
    var $7 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $4$0, $4$1, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $_idx6_val$0, $_idx6_val$1, $pos, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL12BooleanValueEb3401($2, $isForEach);
    var $_idx2 = $2 | 0;
    var $st$2$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$2$1 >> 2];
    var $$emscripten$temp$2 = STRING_TABLE.__str1943346 | 0;
    var $$emscripten$temp$1 = STRING_TABLE.__str1933345 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str1923344 | 0;
    var $9 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 47, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $$emscripten$temp$2, $_idx2_val$0, $_idx2_val$1, $dst);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder23comprehensionExpressionEN2JS5ValueERNS_15AutoValueVectorES2_PNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $blocks, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $blocks, $array);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = $this + 208 | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = __ZNK2JS5Value6isNullEv($5$0, $5$1);
    var $7 = $array | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js11NodeBuilder3optEN2JS5ValueE($1, $_0_0_0_val1$0, $_0_0_0_val1$1);
    var $_idx6 = $1 | 0;
    var $_idx6_val$0 = HEAP32[$_idx6 >> 2];
    var $_idx6_val$1 = HEAP32[$_idx6 + 4 >> 2];
    var $10 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $5$0, $5$1, $_0_0_0_val$0, $_0_0_0_val$1, $8$0, $8$1, $_idx6_val$0, $_idx6_val$1, $pos, $dst);
    var $_0 = $10;
    __label__ = 5;
    break;
   case 4:
    var $$emscripten$temp$2 = STRING_TABLE.__str2203372 | 0;
    var $$emscripten$temp$1 = STRING_TABLE.__str2193371 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str1833335 | 0;
    var $12 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 23, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $8$0, $8$1, $$emscripten$temp$2, $_0_0_0_val1$0, $_0_0_0_val1$1, $dst);
    var $_0 = $12;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer3aopE4JSOp($op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($op | 0) == 27) {
      __label__ = 2;
      break;
    } else if (($op | 0) == 28) {
      __label__ = 3;
      break;
    } else if (($op | 0) == 29) {
      __label__ = 4;
      break;
    } else if (($op | 0) == 30) {
      __label__ = 5;
      break;
    } else if (($op | 0) == 31) {
      __label__ = 6;
      break;
    } else if (($op | 0) == 24) {
      __label__ = 7;
      break;
    } else if (($op | 0) == 25) {
      __label__ = 8;
      break;
    } else if (($op | 0) == 26) {
      __label__ = 9;
      break;
    } else if (($op | 0) == 15) {
      __label__ = 10;
      break;
    } else if (($op | 0) == 16) {
      __label__ = 11;
      break;
    } else if (($op | 0) == 17) {
      __label__ = 12;
      break;
    } else if (($op | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 2:
    var $_0 = 1;
    __label__ = 14;
    break;
   case 3:
    var $_0 = 2;
    __label__ = 14;
    break;
   case 4:
    var $_0 = 3;
    __label__ = 14;
    break;
   case 5:
    var $_0 = 4;
    __label__ = 14;
    break;
   case 6:
    var $_0 = 5;
    __label__ = 14;
    break;
   case 7:
    var $_0 = 6;
    __label__ = 14;
    break;
   case 8:
    var $_0 = 7;
    __label__ = 14;
    break;
   case 9:
    var $_0 = 8;
    __label__ = 14;
    break;
   case 10:
    var $_0 = 9;
    __label__ = 14;
    break;
   case 11:
    var $_0 = 10;
    __label__ = 14;
    break;
   case 12:
    var $_0 = 11;
    __label__ = 14;
    break;
   case 13:
    var $_0 = -1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer4unopENS_9TokenKindE4JSOp($tk, $op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($tk | 0) == 50) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($op | 0) == 35) {
      __label__ = 3;
      break;
    } else if (($op | 0) == 32) {
      __label__ = 4;
      break;
    } else if (($op | 0) == 33) {
      __label__ = 5;
      break;
    } else if (($op | 0) == 39 || ($op | 0) == 200) {
      __label__ = 6;
      break;
    } else if (($op | 0) == 40) {
      __label__ = 7;
      break;
    } else if (($op | 0) == 34) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    var $_0 = 2;
    __label__ = 9;
    break;
   case 4:
    var $_0 = 3;
    __label__ = 9;
    break;
   case 5:
    var $_0 = 4;
    __label__ = 9;
    break;
   case 6:
    var $_0 = 5;
    __label__ = 9;
    break;
   case 7:
    var $_0 = 6;
    __label__ = 9;
    break;
   case 8:
    var $_0 = -1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer5binopENS_9TokenKindE4JSOp($tk, $op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($tk | 0) == 12) {
      __label__ = 2;
      break;
    } else if (($tk | 0) == 13) {
      __label__ = 7;
      break;
    } else if (($tk | 0) == 14) {
      __label__ = 12;
      break;
    } else if (($tk | 0) == 16) {
      __label__ = 16;
      break;
    } else if (($tk | 0) == 17) {
      __label__ = 17;
      break;
    } else if (($tk | 0) == 18) {
      __label__ = 18;
      break;
    } else if (($tk | 0) == 9) {
      __label__ = 19;
      break;
    } else if (($tk | 0) == 10) {
      __label__ = 20;
      break;
    } else if (($tk | 0) == 11) {
      __label__ = 21;
      break;
    } else if (($tk | 0) == 45) {
      __label__ = 22;
      break;
    } else if (($tk | 0) == 57) {
      __label__ = 23;
      break;
    } else if (($tk | 0) == 73) {
      __label__ = 24;
      break;
    } else if (($tk | 0) == 15) {
      var $_0 = 11;
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 2:
    if (($op | 0) == 19) {
      __label__ = 3;
      break;
    } else if (($op | 0) == 72) {
      __label__ = 4;
      break;
    } else if (($op | 0) == 73) {
      __label__ = 5;
      break;
    } else if (($op | 0) == 18) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $_0 = 1;
    __label__ = 26;
    break;
   case 4:
    var $_0 = 2;
    __label__ = 26;
    break;
   case 5:
    var $_0 = 3;
    __label__ = 26;
    break;
   case 6:
    var $_0 = -1;
    __label__ = 26;
    break;
   case 7:
    if (($op | 0) == 21) {
      __label__ = 8;
      break;
    } else if (($op | 0) == 22) {
      __label__ = 9;
      break;
    } else if (($op | 0) == 23) {
      __label__ = 10;
      break;
    } else if (($op | 0) == 20) {
      var $_0 = 4;
      __label__ = 26;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $_0 = 5;
    __label__ = 26;
    break;
   case 9:
    var $_0 = 6;
    __label__ = 26;
    break;
   case 10:
    var $_0 = 7;
    __label__ = 26;
    break;
   case 11:
    var $_0 = -1;
    __label__ = 26;
    break;
   case 12:
    if (($op | 0) == 25) {
      __label__ = 13;
      break;
    } else if (($op | 0) == 26) {
      __label__ = 14;
      break;
    } else if (($op | 0) == 24) {
      var $_0 = 8;
      __label__ = 26;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $_0 = 9;
    __label__ = 26;
    break;
   case 14:
    var $_0 = 10;
    __label__ = 26;
    break;
   case 15:
    var $_0 = -1;
    __label__ = 26;
    break;
   case 16:
    var $_0 = 12;
    __label__ = 26;
    break;
   case 17:
    var $_0 = 13;
    __label__ = 26;
    break;
   case 18:
    var $19 = ($op | 0) == 31 ? 15 : 14;
    var $_0 = $19;
    __label__ = 26;
    break;
   case 19:
    var $_0 = 16;
    __label__ = 26;
    break;
   case 20:
    var $_0 = 17;
    __label__ = 26;
    break;
   case 21:
    var $_0 = 18;
    __label__ = 26;
    break;
   case 22:
    var $_0 = 19;
    __label__ = 26;
    break;
   case 23:
    var $_0 = 20;
    __label__ = 26;
    break;
   case 24:
    var $_0 = 21;
    __label__ = 26;
    break;
   case 25:
    var $_0 = -1;
    __label__ = 26;
    break;
   case 26:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder19generatorExpressionEN2JS5ValueERNS_15AutoValueVectorES2_PNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $blocks, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $blocks, $array);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = $this + 216 | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = __ZNK2JS5Value6isNullEv($5$0, $5$1);
    var $7 = $array | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js11NodeBuilder3optEN2JS5ValueE($1, $_0_0_0_val1$0, $_0_0_0_val1$1);
    var $_idx6 = $1 | 0;
    var $_idx6_val$0 = HEAP32[$_idx6 >> 2];
    var $_idx6_val$1 = HEAP32[$_idx6 + 4 >> 2];
    var $10 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $5$0, $5$1, $_0_0_0_val$0, $_0_0_0_val$1, $8$0, $8$1, $_idx6_val$0, $_idx6_val$1, $pos, $dst);
    var $_0 = $10;
    __label__ = 5;
    break;
   case 4:
    var $$emscripten$temp$2 = STRING_TABLE.__str2203372 | 0;
    var $$emscripten$temp$1 = STRING_TABLE.__str2193371 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str1833335 | 0;
    var $12 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 24, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $8$0, $8$1, $$emscripten$temp$2, $_0_0_0_val1$0, $_0_0_0_val1$1, $dst);
    var $_0 = $12;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder15graphExpressionEiN2JS5ValueEPNS_8TokenPosEPS2_($this, $idx, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $this + 192 | 0;
    var $4$0 = HEAP32[$3 >> 2];
    var $4$1 = HEAP32[$3 + 4 >> 2];
    var $5 = __ZNK2JS5Value6isNullEv($4$0, $4$1);
    var $6 = $idx | 0;
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL11NumberValueEd3402($1, $6);
    var $_idx1 = $1 | 0;
    var $st$2$0 = $_idx1 | 0;
    var $_idx1_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx1 + 4 | 0;
    var $_idx1_val$1 = HEAP32[$st$2$1 >> 2];
    var $8 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $4$0, $4$1, $_idx1_val$0, $_idx1_val$1, $pos, $dst);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL11NumberValueEd3402($2, $6);
    var $_idx2 = $2 | 0;
    var $st$2$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$2$1 >> 2];
    var $$emscripten$temp$1 = STRING_TABLE.__str1843336 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str2213373 | 0;
    var $10 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 21, $pos, $$emscripten$temp$0, $_idx2_val$0, $_idx2_val$1, $$emscripten$temp$1, $_0_0_0_val$0, $_0_0_0_val$1, $dst);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11NumberValueEd3402($agg_result, $dbl) {
  var $1 = __ZN2JS5Value9setNumberEd($agg_result, $dbl);
  return;
}

function __ZN2js11NodeBuilder20graphIndexExpressionEiPNS_8TokenPosEPN2JS5ValueE($this, $idx, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $this + 200 | 0;
    var $4$0 = HEAP32[$3 >> 2];
    var $4$1 = HEAP32[$3 + 4 >> 2];
    var $5 = __ZNK2JS5Value6isNullEv($4$0, $4$1);
    var $6 = $idx | 0;
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL11NumberValueEd3402($1, $6);
    var $_idx1 = $1 | 0;
    var $st$2$0 = $_idx1 | 0;
    var $_idx1_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx1 + 4 | 0;
    var $_idx1_val$1 = HEAP32[$st$2$1 >> 2];
    var $8 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $4$0, $4$1, $_idx1_val$0, $_idx1_val$1, $pos, $dst);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL11NumberValueEd3402($2, $6);
    var $_idx2 = $2 | 0;
    var $st$2$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$2$1 >> 2];
    var $$emscripten$temp$0 = STRING_TABLE.__str2213373 | 0;
    var $10 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 22, $pos, $$emscripten$temp$0, $_idx2_val$0, $_idx2_val$1, $dst);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder13letExpressionERNS_15AutoValueVectorEN2JS5ValueEPNS_8TokenPosEPS4_($this, $head, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $1 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $head, $array);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = $this + 232 | 0;
    var $4$0 = HEAP32[$3 >> 2];
    var $4$1 = HEAP32[$3 + 4 >> 2];
    var $5 = __ZNK2JS5Value6isNullEv($4$0, $4$1);
    var $6 = $array | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $4$0, $4$1, $7$0, $7$1, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst);
    var $_0 = $9;
    __label__ = 5;
    break;
   case 4:
    var $$emscripten$temp$1 = STRING_TABLE.__str1833335 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str2223374 | 0;
    var $11 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 26, $pos, $$emscripten$temp$0, $7$0, $7$1, $$emscripten$temp$1, $_0_0_0_val$0, $_0_0_0_val$1, $dst);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder12letStatementERNS_15AutoValueVectorEN2JS5ValueEPNS_8TokenPosEPS4_($this, $head, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $1 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $head, $array);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = $this + 376 | 0;
    var $4$0 = HEAP32[$3 >> 2];
    var $4$1 = HEAP32[$3 + 4 >> 2];
    var $5 = __ZNK2JS5Value6isNullEv($4$0, $4$1);
    var $6 = $array | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $4$0, $4$1, $7$0, $7$1, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst);
    var $_0 = $9;
    __label__ = 5;
    break;
   case 4:
    var $$emscripten$temp$1 = STRING_TABLE.__str1833335 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str2223374 | 0;
    var $11 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 44, $pos, $$emscripten$temp$0, $7$0, $7$1, $$emscripten$temp$1, $_0_0_0_val$0, $_0_0_0_val$1, $dst);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder19variableDeclarationERNS_15AutoValueVectorENS_11VarDeclKindEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $kind, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $kindName = __stackBase__ + 8;
    var $1 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $elts, $array);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    if (($kind | 0) == 1) {
      var $8 = STRING_TABLE.__str2233375 | 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_str2243376__str2253377 = ($kind | 0) == 2 ? STRING_TABLE.__str2243376 : STRING_TABLE.__str2253377;
    var $8 = $_str2243376__str2253377 | 0;
    __label__ = 4;
    break;
   case 4:
    var $8;
    var $this_idx_val = HEAP32[$this >> 2];
    var $9 = __ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE($this_idx_val, $8, $kindName);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $11 = $this + 64 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = __ZNK2JS5Value6isNullEv($12$0, $12$1);
    var $14 = $kindName | 0;
    var $15$0 = HEAP32[$14 >> 2];
    var $15$1 = HEAP32[$14 + 4 >> 2];
    var $16 = $array | 0;
    var $17$0 = HEAP32[$16 >> 2];
    var $17$1 = HEAP32[$16 + 4 >> 2];
    if ($13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $12$0, $12$1, $15$0, $15$1, $17$0, $17$1, $pos, $dst);
    var $_0 = $19;
    __label__ = 8;
    break;
   case 7:
    var $$emscripten$temp$1 = STRING_TABLE.__str2263378 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str2153367 | 0;
    var $21 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 5, $pos, $$emscripten$temp$0, $15$0, $15$1, $$emscripten$temp$1, $17$0, $17$1, $dst);
    var $_0 = $21;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder18variableDeclaratorEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 72 | 0;
    var $st$2$0 = $2 | 0;
    var $3$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $2 + 4 | 0;
    var $3$1 = HEAP32[$st$2$1 >> 2];
    var $4 = __ZNK2JS5Value6isNullEv($3$0, $3$1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js11NodeBuilder3optEN2JS5ValueE($1, $_0_0_0_val1$0, $_0_0_0_val1$1);
    var $_idx2 = $1 | 0;
    var $st$2$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$2$1 >> 2];
    var $6 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $3$0, $3$1, $_0_0_0_val$0, $_0_0_0_val$1, $_idx2_val$0, $_idx2_val$1, $pos, $dst);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$1 = STRING_TABLE.__str1903342 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str246539 | 0;
    var $8 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 6, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $dst);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder10switchCaseEN2JS5ValueERNS_15AutoValueVectorEPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $elts, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $elts, $array);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = $this + 384 | 0;
    var $st$1$0 = $4 | 0;
    var $5$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $4 + 4 | 0;
    var $5$1 = HEAP32[$st$1$1 >> 2];
    var $6 = __ZNK2JS5Value6isNullEv($5$0, $5$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js11NodeBuilder3optEN2JS5ValueE($1, $_0_0_0_val$0, $_0_0_0_val$1);
    var $8 = $array | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $_idx1 = $1 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $10 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $5$0, $5$1, $_idx1_val$0, $_idx1_val$1, $9$0, $9$1, $pos, $dst);
    var $_0 = $10;
    __label__ = 5;
    break;
   case 4:
    var $12 = $array | 0;
    var $st$1$0 = $12 | 0;
    var $13$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $12 + 4 | 0;
    var $13$1 = HEAP32[$st$1$1 >> 2];
    var $$emscripten$temp$1 = STRING_TABLE.__str1863338 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str253468 | 0;
    var $14 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 45, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $13$0, $13$1, $dst);
    var $_0 = $14;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder11catchClauseEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $_0_0_0_val2$0, $_0_0_0_val2$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 392 | 0;
    var $st$2$0 = $2 | 0;
    var $3$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $2 + 4 | 0;
    var $3$1 = HEAP32[$st$2$1 >> 2];
    var $4 = __ZNK2JS5Value6isNullEv($3$0, $3$1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js11NodeBuilder3optEN2JS5ValueE($1, $_0_0_0_val1$0, $_0_0_0_val1$1);
    var $_idx5 = $1 | 0;
    var $st$2$0 = $_idx5 | 0;
    var $_idx5_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx5 + 4 | 0;
    var $_idx5_val$1 = HEAP32[$st$2$1 >> 2];
    var $6 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $3$0, $3$1, $_0_0_0_val$0, $_0_0_0_val$1, $_idx5_val$0, $_idx5_val$1, $_0_0_0_val2$0, $_0_0_0_val2$1, $pos, $dst);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$2 = STRING_TABLE.__str1833335 | 0;
    var $$emscripten$temp$1 = STRING_TABLE.__str2293381 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str2283380 | 0;
    var $8 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 46, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $$emscripten$temp$2, $_0_0_0_val2$0, $_0_0_0_val2$1, $dst);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder7literalEN2JS5ValueEPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 40 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZNK2JS5Value6isNullEv($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2$0, $2$1, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = STRING_TABLE.__str247540 | 0;
    var $7 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 2, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder10identifierEN2JS5ValueEPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 32 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZNK2JS5Value6isNullEv($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2$0, $2$1, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = STRING_TABLE.__str404286 | 0;
    var $7 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 1, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder13objectPatternERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 49, STRING_TABLE.__str2183370 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder12arrayPatternERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 48, STRING_TABLE.__str174263 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder8functionENS_7ASTTypeEPNS_8TokenPosEN2JS5ValueERNS_15AutoValueVectorES5_bbPS5_($this, $type, $pos, $_0_0_0_val$0, $_0_0_0_val$1, $args, $_0_0_0_val1$0, $_0_0_0_val1$1, $isGenerator, $isExpression, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 24;
    var $4 = __stackBase__ + 32;
    var $5 = __stackBase__ + 40;
    var $6 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $args, $array);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $8 = $this + 24 + ($type << 3) | 0;
    var $st$1$0 = $8 | 0;
    var $9$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $8 + 4 | 0;
    var $9$1 = HEAP32[$st$1$1 >> 2];
    var $10 = __ZNK2JS5Value6isNullEv($9$0, $9$1);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js11NodeBuilder3optEN2JS5ValueE($1, $_0_0_0_val$0, $_0_0_0_val$1);
    var $12 = $array | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    __ZN2JSL12BooleanValueEb3401($2, $isGenerator);
    __ZN2JSL12BooleanValueEb3401($3, $isExpression);
    var $_idx2 = $1 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    var $_idx5 = $2 | 0;
    var $_idx5_val$0 = HEAP32[$_idx5 >> 2];
    var $_idx5_val$1 = HEAP32[$_idx5 + 4 >> 2];
    var $_idx6 = $3 | 0;
    var $_idx6_val$0 = HEAP32[$_idx6 >> 2];
    var $_idx6_val$1 = HEAP32[$_idx6 + 4 >> 2];
    var $14 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_S2_S2_PNS_8TokenPosEPS2_($this, $9$0, $9$1, $_idx2_val$0, $_idx2_val$1, $13$0, $13$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $_idx5_val$0, $_idx5_val$1, $_idx6_val$0, $_idx6_val$1, $pos, $dst);
    var $_0 = $14;
    __label__ = 5;
    break;
   case 4:
    var $16 = $array | 0;
    var $st$1$0 = $16 | 0;
    var $17$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $16 + 4 | 0;
    var $17$1 = HEAP32[$st$1$1 >> 2];
    __ZN2JSL12BooleanValueEb3401($4, $isGenerator);
    __ZN2JSL12BooleanValueEb3401($5, $isExpression);
    var $_idx10 = $4 | 0;
    var $_idx10_val$0 = HEAP32[$_idx10 >> 2];
    var $_idx10_val$1 = HEAP32[$_idx10 + 4 >> 2];
    var $_idx11 = $5 | 0;
    var $_idx11_val$0 = HEAP32[$_idx11 >> 2];
    var $_idx11_val$1 = HEAP32[$_idx11 + 4 >> 2];
    var $18 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_S5_S7_S5_S7_PS7_($this, $type, $pos, $_0_0_0_val$0, $_0_0_0_val$1, $17$0, $17$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $_idx10_val$0, $_idx10_val$1, $_idx11_val$0, $_idx11_val$1, $dst);
    var $_0 = $18;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder8functionENS_7ASTTypeEPNS_8TokenPosEN2JS5ValueERNS_15AutoValueVectorES5_bbPS5_["X"] = 1;

function __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_S2_S2_PNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $_0_0_0_val2$0, $_0_0_0_val2$1, $_0_0_0_val3$0, $_0_0_0_val3$1, $_0_0_0_val4$0, $_0_0_0_val4$1, $_0_0_0_val5$0, $_0_0_0_val5$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 104;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fun = __stackBase__;
    var $loc = __stackBase__ + 8;
    var $argv = __stackBase__ + 16;
    var $argv1 = __stackBase__ + 64;
    var $1 = $fun | 0;
    HEAP32[$1 >> 2] = $_0_0_0_val$0;
    HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
    if ((HEAP8[$this + 4 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZN2js11NodeBuilder10newNodeLocEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $loc);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = $argv | 0;
    var $argv41_0 = $argv | 0;
    var $st$2$0 = $argv41_0 | 0;
    HEAP32[$st$2$0 >> 2] = $_0_0_0_val1$0;
    var $st$2$1 = $argv41_0 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $_0_0_0_val1$1;
    var $_032 = $argv + 8 | 0;
    var $st$7$0 = $_032 | 0;
    HEAP32[$st$7$0 >> 2] = $_0_0_0_val2$0;
    var $st$7$1 = $_032 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $_0_0_0_val2$1;
    var $_023 = $argv + 16 | 0;
    var $st$12$0 = $_023 | 0;
    HEAP32[$st$12$0 >> 2] = $_0_0_0_val3$0;
    var $st$12$1 = $_023 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $_0_0_0_val3$1;
    var $_014 = $argv + 24 | 0;
    var $st$17$0 = $_014 | 0;
    HEAP32[$st$17$0 >> 2] = $_0_0_0_val4$0;
    var $st$17$1 = $_014 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $_0_0_0_val4$1;
    var $_05 = $argv + 32 | 0;
    var $st$22$0 = $_05 | 0;
    HEAP32[$st$22$0 >> 2] = $_0_0_0_val5$0;
    var $st$22$1 = $_05 + 4 | 0;
    HEAP32[$st$22$1 >> 2] = $_0_0_0_val5$1;
    var $10 = $loc | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = $argv + 40 | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    var $14 = HEAP32[$this >> 2];
    var $15 = $this + 576 | 0;
    var $16 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($14, $15, $fun, 6, $9, $dst);
    var $_0 = $16;
    __label__ = 5;
    break;
   case 4:
    var $18 = $argv1 | 0;
    var $argv143_0 = $argv1 | 0;
    var $st$2$0 = $argv143_0 | 0;
    HEAP32[$st$2$0 >> 2] = $_0_0_0_val1$0;
    var $st$2$1 = $argv143_0 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $_0_0_0_val1$1;
    var $_034 = $argv1 + 8 | 0;
    var $st$7$0 = $_034 | 0;
    HEAP32[$st$7$0 >> 2] = $_0_0_0_val2$0;
    var $st$7$1 = $_034 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $_0_0_0_val2$1;
    var $_025 = $argv1 + 16 | 0;
    var $st$12$0 = $_025 | 0;
    HEAP32[$st$12$0 >> 2] = $_0_0_0_val3$0;
    var $st$12$1 = $_025 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $_0_0_0_val3$1;
    var $_016 = $argv1 + 24 | 0;
    var $st$17$0 = $_016 | 0;
    HEAP32[$st$17$0 >> 2] = $_0_0_0_val4$0;
    var $st$17$1 = $_016 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $_0_0_0_val4$1;
    var $_07 = $argv1 + 32 | 0;
    var $st$22$0 = $_07 | 0;
    HEAP32[$st$22$0 >> 2] = $_0_0_0_val5$0;
    var $st$22$1 = $_07 + 4 | 0;
    HEAP32[$st$22$1 >> 2] = $_0_0_0_val5$1;
    var $20 = HEAP32[$this >> 2];
    var $21 = $this + 576 | 0;
    var $22 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($20, $21, $fun, 5, $18, $dst);
    var $_0 = $22;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_S2_S2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_S5_S7_S5_S7_PS7_($this, $type, $pos, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $_0_0_0_val2$0, $_0_0_0_val2$1, $_0_0_0_val3$0, $_0_0_0_val3$1, $_0_0_0_val4$0, $_0_0_0_val4$1, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $node = __stackBase__;
    var $1 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPP8JSObject($this, $type, $pos, $node);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $15 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    var $3 = HEAP32[$node >> 2];
    var $$emscripten$temp$0 = STRING_TABLE.__str246539 | 0;
    var $4 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $3, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $15 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $$emscripten$temp$1 = STRING_TABLE.__str2313383 | 0;
    var $6 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $3, $$emscripten$temp$1, $_0_0_0_val1$0, $_0_0_0_val1$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      var $15 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $$emscripten$temp$2 = STRING_TABLE.__str1833335 | 0;
    var $8 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $3, $$emscripten$temp$2, $_0_0_0_val2$0, $_0_0_0_val2$1);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      var $15 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $$emscripten$temp$3 = STRING_TABLE.__str2323384 | 0;
    var $10 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $3, $$emscripten$temp$3, $_0_0_0_val3$0, $_0_0_0_val3$1);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      var $15 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $$emscripten$temp$4 = STRING_TABLE.__str1843336 | 0;
    var $12 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $3, $$emscripten$temp$4, $_0_0_0_val4$0, $_0_0_0_val4$1);
    if ($12) {
      __label__ = 7;
      break;
    } else {
      var $15 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2js11NodeBuilder9setResultEP8JSObjectPN2JS5ValueE($3, $dst);
    var $15 = 1;
    __label__ = 8;
    break;
   case 8:
    var $15;
    STACKTOP = __stackBase__;
    return $15;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder10xmlAnyNameEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 432 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZNK2JS5Value6isNullEv($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11NodeBuilder8callbackEN2JS5ValueEPNS_8TokenPosEPS2_($this, $2$0, $2$1, $pos, $dst);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $7 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPN2JS5ValueE($this, 51, $pos, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder19xmlEscapeExpressionEN2JS5ValueEPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 448 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZNK2JS5Value6isNullEv($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2$0, $2$1, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = STRING_TABLE.__str1843336 | 0;
    var $7 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 53, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder19xmlFilterExpressionEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 456 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZNK2JS5Value6isNullEv($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $2$0, $2$1, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$1 = STRING_TABLE.__str1933345 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str1923344 | 0;
    var $7 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 54, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder19xmlDefaultNamespaceEN2JS5ValueEPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 464 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZNK2JS5Value6isNullEv($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2$0, $2$1, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = STRING_TABLE.__str2333385 | 0;
    var $7 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 55, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder20xmlAttributeSelectorEN2JS5ValueEbPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $computed, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $this + 440 | 0;
    var $4$0 = HEAP32[$3 >> 2];
    var $4$1 = HEAP32[$3 + 4 >> 2];
    var $5 = __ZNK2JS5Value6isNullEv($4$0, $4$1);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL12BooleanValueEb3401($1, $computed);
    var $_idx2 = $1 | 0;
    var $st$2$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$2$1 >> 2];
    var $7 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $4$0, $4$1, $_0_0_0_val$0, $_0_0_0_val$1, $_idx2_val$0, $_idx2_val$1, $pos, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL12BooleanValueEb3401($2, $computed);
    var $_idx4 = $2 | 0;
    var $st$2$0 = $_idx4 | 0;
    var $_idx4_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx4 + 4 | 0;
    var $_idx4_val$1 = HEAP32[$st$2$1 >> 2];
    var $$emscripten$temp$1 = STRING_TABLE.__str2113363 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str2343386 | 0;
    var $9 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 52, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $_idx4_val$0, $_idx4_val$1, $dst);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder30xmlFunctionQualifiedIdentifierEN2JS5ValueEbPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $computed, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $this + 480 | 0;
    var $4$0 = HEAP32[$3 >> 2];
    var $4$1 = HEAP32[$3 + 4 >> 2];
    var $5 = __ZNK2JS5Value6isNullEv($4$0, $4$1);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL12BooleanValueEb3401($1, $computed);
    var $_idx2 = $1 | 0;
    var $st$2$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$2$1 >> 2];
    var $7 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $4$0, $4$1, $_0_0_0_val$0, $_0_0_0_val$1, $_idx2_val$0, $_idx2_val$1, $pos, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL12BooleanValueEb3401($2, $computed);
    var $_idx4 = $2 | 0;
    var $st$2$0 = $_idx4 | 0;
    var $_idx4_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx4 + 4 | 0;
    var $_idx4_val$1 = HEAP32[$st$2$1 >> 2];
    var $$emscripten$temp$1 = STRING_TABLE.__str2113363 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str1933345 | 0;
    var $9 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 57, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $_idx4_val$0, $_idx4_val$1, $dst);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder22xmlQualifiedIdentifierEN2JS5ValueES2_bPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $computed, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $this + 472 | 0;
    var $4$0 = HEAP32[$3 >> 2];
    var $4$1 = HEAP32[$3 + 4 >> 2];
    var $5 = __ZNK2JS5Value6isNullEv($4$0, $4$1);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL12BooleanValueEb3401($1, $computed);
    var $_idx6 = $1 | 0;
    var $st$2$0 = $_idx6 | 0;
    var $_idx6_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx6 + 4 | 0;
    var $_idx6_val$1 = HEAP32[$st$2$1 >> 2];
    var $7 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $4$0, $4$1, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $_idx6_val$0, $_idx6_val$1, $pos, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL12BooleanValueEb3401($2, $computed);
    var $_idx2 = $2 | 0;
    var $st$2$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$2$1 >> 2];
    var $$emscripten$temp$2 = STRING_TABLE.__str2113363 | 0;
    var $$emscripten$temp$1 = STRING_TABLE.__str1933345 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str1923344 | 0;
    var $9 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 56, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $$emscripten$temp$2, $_idx2_val$0, $_idx2_val$1, $dst);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder10xmlElementERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 58, STRING_TABLE.__str2353387 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder7xmlTextEN2JS5ValueEPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 496 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZNK2JS5Value6isNullEv($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2$0, $2$1, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = STRING_TABLE.__str2363388 | 0;
    var $7 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 59, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder7xmlListERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 60, STRING_TABLE.__str2353387 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder11xmlStartTagERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 61, STRING_TABLE.__str2353387 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder9xmlEndTagERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 62, STRING_TABLE.__str2353387 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder11xmlPointTagERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 63, STRING_TABLE.__str2353387 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder7xmlNameEN2JS5ValueEPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 536 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZNK2JS5Value6isNullEv($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2$0, $2$1, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = STRING_TABLE.__str2353387 | 0;
    var $7 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 64, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder7xmlNameERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 64, STRING_TABLE.__str2353387 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder12xmlAttributeEN2JS5ValueEPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 544 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZNK2JS5Value6isNullEv($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2$0, $2$1, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = STRING_TABLE.__str247540 | 0;
    var $7 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 65, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder8xmlCdataEN2JS5ValueEPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 552 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZNK2JS5Value6isNullEv($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2$0, $2$1, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = STRING_TABLE.__str2353387 | 0;
    var $7 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 66, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder10xmlCommentEN2JS5ValueEPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 560 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZNK2JS5Value6isNullEv($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2$0, $2$1, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = STRING_TABLE.__str2353387 | 0;
    var $7 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 67, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder5xmlPIEN2JS5ValueEPNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL9NullValueEv3400($1);
  var $_idx1 = $1 | 0;
  var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
  var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
  var $2 = __ZN2js11NodeBuilder5xmlPIEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $_idx1_val$0, $_idx1_val$1, $pos, $dst);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js11NodeBuilder5xmlPIEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 568 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZNK2JS5Value6isNullEv($2$0, $2$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $2$0, $2$1, $_0_0_0_val$0, $_0_0_0_val$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $pos, $dst);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$1 = STRING_TABLE.__str2353387 | 0;
    var $$emscripten$temp$0 = STRING_TABLE.__str2373389 | 0;
    var $7 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 68, $pos, $$emscripten$temp$0, $_0_0_0_val$0, $_0_0_0_val$1, $$emscripten$temp$1, $_0_0_0_val1$0, $_0_0_0_val1$1, $dst);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer10statementsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $elts) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $elt = __stackBase__;
    var $1 = $elts | 0;
    var $3 = HEAP32[$pn + 40 >> 2];
    var $4 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($1, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $elt_idx = $elt | 0;
    var $next_0_in = $pn + 32 | 0;
    __label__ = 3;
    break;
   case 3:
    var $next_0_in;
    var $next_0 = HEAP32[$next_0_in >> 2];
    if (($next_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZN2js13ASTSerializer13sourceElementEP11JSParseNodePN2JS5ValueE($this, $next_0, $elt);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $elt_idx_val$0 = HEAP32[$elt_idx >> 2];
    var $elt_idx_val$1 = HEAP32[$elt_idx + 4 >> 2];
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($1, $elt_idx_val$0, $elt_idx_val$1);
    var $next_0_in = $next_0 + 24 | 0;
    __label__ = 3;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer13sourceElementEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var $1 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
  return $1;
}

function __ZN2js13ASTSerializer11expressionsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $elts) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $elt = __stackBase__;
    var $1 = $elts | 0;
    var $3 = HEAP32[$pn + 40 >> 2];
    var $4 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($1, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $elt_idx = $elt | 0;
    var $next_0_in = $pn + 32 | 0;
    __label__ = 3;
    break;
   case 3:
    var $next_0_in;
    var $next_0 = HEAP32[$next_0_in >> 2];
    if (($next_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $next_0, $elt);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $elt_idx_val$0 = HEAP32[$elt_idx >> 2];
    var $elt_idx_val$1 = HEAP32[$elt_idx + 4 >> 2];
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($1, $elt_idx_val$0, $elt_idx_val$1);
    var $next_0_in = $next_0 + 24 | 0;
    __label__ = 3;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 688;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $exprs = __stackBase__ + 4;
    var $test = __stackBase__ + 96;
    var $cons = __stackBase__ + 104;
    var $alt = __stackBase__ + 112;
    var $left = __stackBase__ + 120;
    var $right = __stackBase__ + 128;
    var $expr = __stackBase__ + 136;
    var $lhs = __stackBase__ + 144;
    var $rhs = __stackBase__ + 152;
    var $left2 = __stackBase__ + 160;
    var $right3 = __stackBase__ + 168;
    var $expr5 = __stackBase__ + 176;
    var $callee = __stackBase__ + 184;
    var $args = __stackBase__ + 192;
    var $arg = __stackBase__ + 284;
    var $expr6 = __stackBase__ + 292;
    var $id = __stackBase__ + 300;
    var $left7 = __stackBase__ + 308;
    var $right8 = __stackBase__ + 316;
    var $elts = __stackBase__ + 324;
    var $1 = __stackBase__ + 416;
    var $expr10 = __stackBase__ + 424;
    var $elts11 = __stackBase__ + 432;
    var $prop = __stackBase__ + 524;
    var $arg13 = __stackBase__ + 532;
    var $expr14 = __stackBase__ + 540;
    var $dtors = __stackBase__ + 548;
    var $expr15 = __stackBase__ + 640;
    var $right16 = __stackBase__ + 648;
    var $left18 = __stackBase__ + 656;
    var $expr19 = __stackBase__ + 664;
    var $left21 = __stackBase__ + 672;
    var $right22 = __stackBase__ + 680;
    var $3 = $this | 0;
    var $4 = HEAPU32[$3 >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$4 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($4);
    var $_3 = 0;
    __label__ = 116;
    break;
   case 3:
    var $10 = __ZNK11JSParseNode7getKindEv($pn);
    if (($10 | 0) == 34) {
      __label__ = 4;
      break;
    } else if (($10 | 0) == 3) {
      __label__ = 5;
      break;
    } else if (($10 | 0) == 5) {
      __label__ = 8;
      break;
    } else if (($10 | 0) == 7 || ($10 | 0) == 8) {
      __label__ = 12;
      break;
    } else if (($10 | 0) == 20 || ($10 | 0) == 21) {
      __label__ = 17;
      break;
    } else if (($10 | 0) == 4) {
      __label__ = 19;
      break;
    } else if (($10 | 0) == 12 || ($10 | 0) == 13 || ($10 | 0) == 14 || ($10 | 0) == 15 || ($10 | 0) == 16 || ($10 | 0) == 17 || ($10 | 0) == 18 || ($10 | 0) == 9 || ($10 | 0) == 10 || ($10 | 0) == 11 || ($10 | 0) == 45 || ($10 | 0) == 57 || ($10 | 0) == 73) {
      __label__ = 24;
      break;
    } else if (($10 | 0) == 50 || ($10 | 0) == 19) {
      __label__ = 31;
      break;
    } else if (($10 | 0) == 49 || ($10 | 0) == 27) {
      __label__ = 39;
      break;
    } else if (($10 | 0) == 22) {
      __label__ = 51;
      break;
    } else if (($10 | 0) == 23) {
      __label__ = 54;
      break;
    } else if (($10 | 0) == 24) {
      __label__ = 60;
      break;
    } else if (($10 | 0) == 26) {
      __label__ = 70;
      break;
    } else if (($10 | 0) == 29) {
      __label__ = 77;
      break;
    } else if (($10 | 0) == 31 || ($10 | 0) == 32 || ($10 | 0) == 30 || ($10 | 0) == 33) {
      __label__ = 78;
      break;
    } else if (($10 | 0) == 77) {
      __label__ = 81;
      break;
    } else if (($10 | 0) == 51) {
      __label__ = 83;
      break;
    } else if (($10 | 0) == 52) {
      __label__ = 85;
      break;
    } else if (($10 | 0) == 78) {
      __label__ = 86;
      break;
    } else if (($10 | 0) == 80) {
      __label__ = 91;
      break;
    } else if (($10 | 0) == 72) {
      __label__ = 95;
      break;
    } else if (($10 | 0) == 71) {
      __label__ = 96;
      break;
    } else if (($10 | 0) == 70) {
      __label__ = 106;
      break;
    } else if (($10 | 0) == 74) {
      __label__ = 112;
      break;
    } else {
      __label__ = 115;
      break;
    }
   case 4:
    var $12 = __ZN2js13ASTSerializer8functionEP11JSParseNodeNS_7ASTTypeEPN2JS5ValueE($this, $pn, 17, $dst);
    var $_3 = $12;
    __label__ = 116;
    break;
   case 5:
    __ZN2js15AutoValueVectorC1EP9JSContext($exprs, $4);
    var $14 = __ZN2js13ASTSerializer11expressionsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $exprs);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      var $20 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $16 = $this + 8 | 0;
    var $17 = $pn + 4 | 0;
    var $18 = __ZN2js11NodeBuilder18sequenceExpressionERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($16, $exprs, $17, $dst);
    var $20 = $18;
    __label__ = 7;
    break;
   case 7:
    var $20;
    __ZN2js15AutoValueVectorD1Ev($exprs);
    var $_3 = $20;
    __label__ = 116;
    break;
   case 8:
    var $23 = HEAP32[$pn + 32 >> 2];
    var $24 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $23, $test);
    if ($24) {
      __label__ = 9;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 9:
    var $28 = HEAP32[$pn + 36 >> 2];
    var $29 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $28, $cons);
    if ($29) {
      __label__ = 10;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 10:
    var $33 = HEAP32[$pn + 40 >> 2];
    var $34 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $33, $alt);
    if ($34) {
      __label__ = 11;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 11:
    var $36 = $this + 8 | 0;
    var $37 = $test | 0;
    var $st$2$0 = $37 | 0;
    var $38$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $37 + 4 | 0;
    var $38$1 = HEAP32[$st$2$1 >> 2];
    var $39 = $cons | 0;
    var $st$7$0 = $39 | 0;
    var $40$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $39 + 4 | 0;
    var $40$1 = HEAP32[$st$7$1 >> 2];
    var $41 = $alt | 0;
    var $42$0 = HEAP32[$41 >> 2];
    var $42$1 = HEAP32[$41 + 4 >> 2];
    var $43 = $pn + 4 | 0;
    var $44 = __ZN2js11NodeBuilder21conditionalExpressionEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($36, $38$0, $38$1, $40$0, $40$1, $42$0, $42$1, $43, $dst);
    var $_3 = $44;
    __label__ = 116;
    break;
   case 12:
    var $46 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 2);
    if ($46) {
      __label__ = 13;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 13:
    var $49 = HEAP32[$pn + 32 >> 2];
    var $50 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $49, $left);
    if ($50) {
      __label__ = 14;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 14:
    var $54 = HEAP32[$pn + 36 >> 2];
    var $55 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $54, $right);
    if ($55) {
      __label__ = 15;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 15:
    var $57 = $this + 8 | 0;
    var $58 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 7);
    var $59 = $left | 0;
    var $st$3$0 = $59 | 0;
    var $60$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $59 + 4 | 0;
    var $60$1 = HEAP32[$st$3$1 >> 2];
    var $61 = $right | 0;
    var $62$0 = HEAP32[$61 >> 2];
    var $62$1 = HEAP32[$61 + 4 >> 2];
    var $63 = $pn + 4 | 0;
    var $64 = __ZN2js11NodeBuilder17logicalExpressionEbN2JS5ValueES2_PNS_8TokenPosEPS2_($57, $58, $60$0, $60$1, $62$0, $62$1, $63, $dst);
    var $_3 = $64;
    __label__ = 116;
    break;
   case 16:
    var $66 = __ZN2js13ASTSerializer13leftAssociateEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_3 = $66;
    __label__ = 116;
    break;
   case 17:
    var $68 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 20);
    var $69 = __ZNK11JSParseNode5getOpEv($pn);
    var $71 = HEAP32[$pn + 32 >> 2];
    var $72 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $71, $expr);
    if ($72) {
      __label__ = 18;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 18:
    var $74 = ($69 - 41 | 0) >>> 0 < 6;
    var $75 = $this + 8 | 0;
    var $76 = $expr | 0;
    var $77$0 = HEAP32[$76 >> 2];
    var $77$1 = HEAP32[$76 + 4 >> 2];
    var $78 = $pn + 4 | 0;
    var $79 = __ZN2js11NodeBuilder16updateExpressionEN2JS5ValueEbbPNS_8TokenPosEPS2_($75, $77$0, $77$1, $68, $74, $78, $dst);
    var $_3 = $79;
    __label__ = 116;
    break;
   case 19:
    var $81 = __ZNK11JSParseNode5getOpEv($pn);
    var $82 = __ZN2js13ASTSerializer3aopE4JSOp($81);
    if ($82 >>> 0 < 12) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($4, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_3 = 0;
    __label__ = 116;
    break;
   case 21:
    var $87 = HEAP32[$pn + 32 >> 2];
    var $88 = __ZN2js13ASTSerializer7patternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $87, 0, $lhs);
    if ($88) {
      __label__ = 22;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 22:
    var $92 = HEAP32[$pn + 36 >> 2];
    var $93 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $92, $rhs);
    if ($93) {
      __label__ = 23;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 23:
    var $95 = $this + 8 | 0;
    var $96 = $lhs | 0;
    var $st$2$0 = $96 | 0;
    var $97$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $96 + 4 | 0;
    var $97$1 = HEAP32[$st$2$1 >> 2];
    var $98 = $rhs | 0;
    var $st$7$0 = $98 | 0;
    var $99$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $98 + 4 | 0;
    var $99$1 = HEAP32[$st$7$1 >> 2];
    var $100 = $pn + 4 | 0;
    var $101 = __ZN2js11NodeBuilder20assignmentExpressionENS_18AssignmentOperatorEN2JS5ValueES3_PNS_8TokenPosEPS3_($95, $82, $97$0, $97$1, $99$0, $99$1, $100, $dst);
    var $_3 = $101;
    __label__ = 116;
    break;
   case 24:
    var $103 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 2);
    if ($103) {
      __label__ = 25;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 25:
    var $105 = __ZNK11JSParseNode5getOpEv($pn);
    var $106 = __ZN2js13ASTSerializer5binopENS_9TokenKindE4JSOp($10, $105);
    if ($106 >>> 0 < 22) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    _JS_ReportErrorNumber($4, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_3 = 0;
    __label__ = 116;
    break;
   case 27:
    var $111 = HEAP32[$pn + 32 >> 2];
    var $112 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $111, $left2);
    if ($112) {
      __label__ = 28;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 28:
    var $116 = HEAP32[$pn + 36 >> 2];
    var $117 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $116, $right3);
    if ($117) {
      __label__ = 29;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 29:
    var $119 = $this + 8 | 0;
    var $120 = $left2 | 0;
    var $st$2$0 = $120 | 0;
    var $121$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $120 + 4 | 0;
    var $121$1 = HEAP32[$st$2$1 >> 2];
    var $122 = $right3 | 0;
    var $st$7$0 = $122 | 0;
    var $123$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $122 + 4 | 0;
    var $123$1 = HEAP32[$st$7$1 >> 2];
    var $124 = $pn + 4 | 0;
    var $125 = __ZN2js11NodeBuilder16binaryExpressionENS_14BinaryOperatorEN2JS5ValueES3_PNS_8TokenPosEPS3_($119, $106, $121$0, $121$1, $123$0, $123$1, $124, $dst);
    var $_3 = $125;
    __label__ = 116;
    break;
   case 30:
    var $127 = __ZN2js13ASTSerializer13leftAssociateEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_3 = $127;
    __label__ = 116;
    break;
   case 31:
    var $129 = __ZNK11JSParseNode4isOpE4JSOp($pn, 174);
    if ($129) {
      __label__ = 34;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $131 = __ZNK11JSParseNode4isOpE4JSOp($pn, 173);
    if ($131) {
      __label__ = 34;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $133 = __ZNK11JSParseNode4isOpE4JSOp($pn, 172);
    if ($133) {
      __label__ = 34;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 34:
    var $136 = HEAP32[$pn + 32 >> 2];
    var $137 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $136, $dst);
    var $_3 = $137;
    __label__ = 116;
    break;
   case 35:
    var $139 = __ZNK11JSParseNode5getOpEv($pn);
    var $140 = __ZN2js13ASTSerializer4unopENS_9TokenKindE4JSOp($10, $139);
    if ($140 >>> 0 < 7) {
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    _JS_ReportErrorNumber($4, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_3 = 0;
    __label__ = 116;
    break;
   case 37:
    var $145 = HEAP32[$pn + 32 >> 2];
    var $146 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $145, $expr5);
    if ($146) {
      __label__ = 38;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 38:
    var $148 = $this + 8 | 0;
    var $149 = $expr5 | 0;
    var $st$2$0 = $149 | 0;
    var $150$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $149 + 4 | 0;
    var $150$1 = HEAP32[$st$2$1 >> 2];
    var $151 = $pn + 4 | 0;
    var $152 = __ZN2js11NodeBuilder15unaryExpressionENS_13UnaryOperatorEN2JS5ValueEPNS_8TokenPosEPS3_($148, $140, $150$0, $150$1, $151, $dst);
    var $_3 = $152;
    __label__ = 116;
    break;
   case 39:
    var $154 = __ZNK11JSParseNode15isGeneratorExprEv($pn);
    var $pn_idx_val = HEAP32[$pn + 32 >> 2];
    if ($154) {
      __label__ = 40;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 40:
    var $pn_idx_val_idx_val = HEAP32[$pn_idx_val + 36 >> 2];
    var $156 = __ZNK11JSParseNode13generatorExprEv($pn_idx_val_idx_val);
    var $157 = __ZN2js13ASTSerializer19generatorExpressionEP11JSParseNodePN2JS5ValueE($this, $156, $dst);
    var $_3 = $157;
    __label__ = 116;
    break;
   case 41:
    var $159 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $pn_idx_val, $callee);
    if ($159) {
      __label__ = 42;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 42:
    var $161 = HEAP32[$3 >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($args, $161);
    var $162 = $args | 0;
    var $165 = HEAP32[$pn + 40 >> 2] - 1 | 0;
    var $166 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($162, $165);
    if ($166) {
      __label__ = 43;
      break;
    } else {
      var $_0 = 0;
      __label__ = 50;
      break;
    }
   case 43:
    var $arg_idx = $arg | 0;
    var $_pn = $pn_idx_val;
    __label__ = 44;
    break;
   case 44:
    var $_pn;
    var $next_0 = HEAP32[$_pn + 24 >> 2];
    if (($next_0 | 0) == 0) {
      __label__ = 47;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $169 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $next_0, $arg);
    if ($169) {
      __label__ = 46;
      break;
    } else {
      var $_0 = 0;
      __label__ = 50;
      break;
    }
   case 46:
    var $st$0$0 = $arg_idx | 0;
    var $arg_idx_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $arg_idx + 4 | 0;
    var $arg_idx_val$1 = HEAP32[$st$0$1 >> 2];
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($162, $arg_idx_val$0, $arg_idx_val$1);
    var $_pn = $next_0;
    __label__ = 44;
    break;
   case 47:
    var $172 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 49);
    var $173 = $this + 8 | 0;
    var $174 = $callee | 0;
    var $st$3$0 = $174 | 0;
    var $175$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $174 + 4 | 0;
    var $175$1 = HEAP32[$st$3$1 >> 2];
    var $176 = $pn + 4 | 0;
    if ($172) {
      __label__ = 48;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 48:
    var $178 = __ZN2js11NodeBuilder13newExpressionEN2JS5ValueERNS_15AutoValueVectorEPNS_8TokenPosEPS2_($173, $175$0, $175$1, $args, $176, $dst);
    var $_0 = $178;
    __label__ = 50;
    break;
   case 49:
    var $180 = __ZN2js11NodeBuilder14callExpressionEN2JS5ValueERNS_15AutoValueVectorEPNS_8TokenPosEPS2_($173, $175$0, $175$1, $args, $176, $dst);
    var $_0 = $180;
    __label__ = 50;
    break;
   case 50:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($args);
    var $_3 = $_0;
    __label__ = 116;
    break;
   case 51:
    var $184 = HEAP32[$pn + 36 >> 2];
    var $185 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $184, $expr6);
    if ($185) {
      __label__ = 52;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 52:
    var $189 = HEAP32[$pn + 32 >> 2];
    var $190 = __ZN2js13ASTSerializer10identifierEP6JSAtomPNS_8TokenPosEPN2JS5ValueE($this, $189, 0, $id);
    if ($190) {
      __label__ = 53;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 53:
    var $192 = $this + 8 | 0;
    var $193 = $expr6 | 0;
    var $st$2$0 = $193 | 0;
    var $194$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $193 + 4 | 0;
    var $194$1 = HEAP32[$st$2$1 >> 2];
    var $195 = $id | 0;
    var $st$7$0 = $195 | 0;
    var $196$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $195 + 4 | 0;
    var $196$1 = HEAP32[$st$7$1 >> 2];
    var $197 = $pn + 4 | 0;
    var $198 = __ZN2js11NodeBuilder16memberExpressionEbN2JS5ValueES2_PNS_8TokenPosEPS2_($192, 0, $194$0, $194$1, $196$0, $196$1, $197, $dst);
    var $_3 = $198;
    __label__ = 116;
    break;
   case 54:
    var $200 = $pn + 36 | 0;
    var $202 = HEAP32[$200 >> 2];
    var $203 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($202, 71);
    if ($203) {
      var $210 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    var $205 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($202, 72);
    if ($205) {
      var $210 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    var $207 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($202, 70);
    var $210 = $207 ^ 1;
    __label__ = 57;
    break;
   case 57:
    var $210;
    var $212 = HEAP32[$pn + 32 >> 2];
    var $213 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $212, $left7);
    if ($213) {
      __label__ = 58;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 58:
    var $216 = HEAP32[$200 >> 2];
    var $217 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $216, $right8);
    if ($217) {
      __label__ = 59;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 59:
    var $219 = $this + 8 | 0;
    var $220 = $left7 | 0;
    var $st$2$0 = $220 | 0;
    var $221$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $220 + 4 | 0;
    var $221$1 = HEAP32[$st$2$1 >> 2];
    var $222 = $right8 | 0;
    var $st$7$0 = $222 | 0;
    var $223$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $222 + 4 | 0;
    var $223$1 = HEAP32[$st$7$1 >> 2];
    var $224 = $pn + 4 | 0;
    var $225 = __ZN2js11NodeBuilder16memberExpressionEbN2JS5ValueES2_PNS_8TokenPosEPS2_($219, $210, $221$0, $221$1, $223$0, $223$1, $224, $dst);
    var $_3 = $225;
    __label__ = 116;
    break;
   case 60:
    __ZN2js15AutoValueVectorC1EP9JSContext($elts, $4);
    var $227 = $elts | 0;
    var $229 = HEAP32[$pn + 40 >> 2];
    var $230 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($227, $229);
    if ($230) {
      __label__ = 61;
      break;
    } else {
      var $_1 = 0;
      __label__ = 69;
      break;
    }
   case 61:
    var $_idx = $1 | 0;
    var $expr10_idx = $expr10 | 0;
    var $next9_0_in = $pn + 32 | 0;
    __label__ = 62;
    break;
   case 62:
    var $next9_0_in;
    var $next9_0 = HEAP32[$next9_0_in >> 2];
    if (($next9_0 | 0) == 0) {
      __label__ = 68;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $236 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($next9_0, 3);
    if ($236) {
      __label__ = 64;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 64:
    __ZN2JSL10MagicValueE10JSWhyMagic3404($1);
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($227, $_idx_val$0, $_idx_val$1);
    __label__ = 67;
    break;
   case 65:
    var $239 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $next9_0, $expr10);
    if ($239) {
      __label__ = 66;
      break;
    } else {
      var $_1 = 0;
      __label__ = 69;
      break;
    }
   case 66:
    var $st$0$0 = $expr10_idx | 0;
    var $expr10_idx_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $expr10_idx + 4 | 0;
    var $expr10_idx_val$1 = HEAP32[$st$0$1 >> 2];
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($227, $expr10_idx_val$0, $expr10_idx_val$1);
    __label__ = 67;
    break;
   case 67:
    var $next9_0_in = $next9_0 + 24 | 0;
    __label__ = 62;
    break;
   case 68:
    var $244 = $this + 8 | 0;
    var $245 = $pn + 4 | 0;
    var $246 = __ZN2js11NodeBuilder15arrayExpressionERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($244, $elts, $245, $dst);
    var $_1 = $246;
    __label__ = 69;
    break;
   case 69:
    var $_1;
    __ZN2js15AutoValueVectorD1Ev($elts);
    var $_3 = $_1;
    __label__ = 116;
    break;
   case 70:
    __ZN2js15AutoValueVectorC1EP9JSContext($elts11, $4);
    var $248 = $elts11 | 0;
    var $250 = HEAP32[$pn + 40 >> 2];
    var $251 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($248, $250);
    if ($251) {
      __label__ = 71;
      break;
    } else {
      var $_2 = 0;
      __label__ = 76;
      break;
    }
   case 71:
    var $prop_idx = $prop | 0;
    var $next12_0_in = $pn + 32 | 0;
    __label__ = 72;
    break;
   case 72:
    var $next12_0_in;
    var $next12_0 = HEAP32[$next12_0_in >> 2];
    if (($next12_0 | 0) == 0) {
      __label__ = 75;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    var $257 = __ZN2js13ASTSerializer8propertyEP11JSParseNodePN2JS5ValueE($this, $next12_0, $prop);
    if ($257) {
      __label__ = 74;
      break;
    } else {
      var $_2 = 0;
      __label__ = 76;
      break;
    }
   case 74:
    var $st$0$0 = $prop_idx | 0;
    var $prop_idx_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $prop_idx + 4 | 0;
    var $prop_idx_val$1 = HEAP32[$st$0$1 >> 2];
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($248, $prop_idx_val$0, $prop_idx_val$1);
    var $next12_0_in = $next12_0 + 24 | 0;
    __label__ = 72;
    break;
   case 75:
    var $261 = $this + 8 | 0;
    var $262 = $pn + 4 | 0;
    var $263 = __ZN2js11NodeBuilder16objectExpressionERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($261, $elts11, $262, $dst);
    var $_2 = $263;
    __label__ = 76;
    break;
   case 76:
    var $_2;
    __ZN2js15AutoValueVectorD1Ev($elts11);
    var $_3 = $_2;
    __label__ = 116;
    break;
   case 77:
    var $265 = __ZN2js13ASTSerializer10identifierEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_3 = $265;
    __label__ = 116;
    break;
   case 78:
    var $267 = __ZNK11JSParseNode4isOpE4JSOp($pn, 65);
    if ($267) {
      __label__ = 79;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 79:
    var $269 = $this + 8 | 0;
    var $270 = $pn + 4 | 0;
    var $271 = __ZN2js11NodeBuilder14thisExpressionEPNS_8TokenPosEPN2JS5ValueE($269, $270, $dst);
    var $_3 = $271;
    __label__ = 116;
    break;
   case 80:
    var $273 = __ZN2js13ASTSerializer7literalEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_3 = $273;
    __label__ = 116;
    break;
   case 81:
    var $276 = HEAP32[$pn + 32 >> 2];
    var $277 = __ZN2js13ASTSerializer13optExpressionEP11JSParseNodePN2JS5ValueE($this, $276, $arg13);
    if ($277) {
      __label__ = 82;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 82:
    var $279 = $this + 8 | 0;
    var $280 = $arg13 | 0;
    var $st$2$0 = $280 | 0;
    var $281$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $280 + 4 | 0;
    var $281$1 = HEAP32[$st$2$1 >> 2];
    var $282 = $pn + 4 | 0;
    var $283 = __ZN2js11NodeBuilder15yieldExpressionEN2JS5ValueEPNS_8TokenPosEPS2_($279, $281$0, $281$1, $282, $dst);
    var $_3 = $283;
    __label__ = 116;
    break;
   case 83:
    var $286 = HEAP32[$pn + 32 >> 2];
    var $287 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $286, $expr14);
    if ($287) {
      __label__ = 84;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 84:
    var $289 = $this + 8 | 0;
    var $292 = HEAP32[$pn + 36 >> 2];
    var $293 = $expr14 | 0;
    var $294$0 = HEAP32[$293 >> 2];
    var $294$1 = HEAP32[$293 + 4 >> 2];
    var $295 = $pn + 4 | 0;
    var $296 = __ZN2js11NodeBuilder15graphExpressionEiN2JS5ValueEPNS_8TokenPosEPS2_($289, $292, $294$0, $294$1, $295, $dst);
    var $_3 = $296;
    __label__ = 116;
    break;
   case 85:
    var $298 = $this + 8 | 0;
    var $301 = HEAP32[$pn + 36 >> 2];
    var $302 = $pn + 4 | 0;
    var $303 = __ZN2js11NodeBuilder20graphIndexExpressionEiPNS_8TokenPosEPN2JS5ValueE($298, $301, $302, $dst);
    var $_3 = $303;
    __label__ = 116;
    break;
   case 86:
    if ((HEAP32[$pn + 40 >> 2] | 0) == 1) {
      __label__ = 88;
      break;
    } else {
      __label__ = 87;
      break;
    }
   case 87:
    _JS_ReportErrorNumber($4, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_3 = 0;
    __label__ = 116;
    break;
   case 88:
    var $311 = HEAP32[$pn + 32 >> 2];
    var $312 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($311, 80);
    if ($312) {
      __label__ = 90;
      break;
    } else {
      __label__ = 89;
      break;
    }
   case 89:
    _JS_ReportErrorNumber($4, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_3 = 0;
    __label__ = 116;
    break;
   case 90:
    var $317 = HEAP32[$311 + 36 >> 2];
    var $318 = __ZN2js13ASTSerializer13comprehensionEP11JSParseNodePN2JS5ValueE($this, $317, $dst);
    var $_3 = $318;
    __label__ = 116;
    break;
   case 91:
    var $321 = HEAP32[$pn + 36 >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($dtors, $4);
    var $323 = HEAP32[$321 + 32 >> 2];
    var $324 = __ZN2js13ASTSerializer7letHeadEP11JSParseNodeRNS_15AutoValueVectorE($this, $323, $dtors);
    if ($324) {
      __label__ = 92;
      break;
    } else {
      var $337 = 0;
      __label__ = 94;
      break;
    }
   case 92:
    var $327 = HEAP32[$321 + 36 >> 2];
    var $328 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $327, $expr15);
    if ($328) {
      __label__ = 93;
      break;
    } else {
      var $337 = 0;
      __label__ = 94;
      break;
    }
   case 93:
    var $330 = $this + 8 | 0;
    var $331 = $expr15 | 0;
    var $st$2$0 = $331 | 0;
    var $332$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $331 + 4 | 0;
    var $332$1 = HEAP32[$st$2$1 >> 2];
    var $334 = $321 + 4 | 0;
    var $335 = __ZN2js11NodeBuilder13letExpressionERNS_15AutoValueVectorEN2JS5ValueEPNS_8TokenPosEPS4_($330, $dtors, $332$0, $332$1, $334, $dst);
    var $337 = $335;
    __label__ = 94;
    break;
   case 94:
    var $337;
    __ZN2js15AutoValueVectorD1Ev($dtors);
    var $_3 = $337;
    __label__ = 116;
    break;
   case 95:
    var $339 = $this + 8 | 0;
    var $340 = $pn + 4 | 0;
    var $341 = __ZN2js11NodeBuilder10xmlAnyNameEPNS_8TokenPosEPN2JS5ValueE($339, $340, $dst);
    var $_3 = $341;
    __label__ = 116;
    break;
   case 96:
    var $343 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 6);
    if ($343) {
      __label__ = 99;
      break;
    } else {
      __label__ = 97;
      break;
    }
   case 97:
    var $345 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 2);
    if ($345) {
      __label__ = 99;
      break;
    } else {
      __label__ = 98;
      break;
    }
   case 98:
    _JS_ReportErrorNumber($4, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_3 = 0;
    __label__ = 116;
    break;
   case 99:
    var $348 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 2);
    if ($348) {
      __label__ = 100;
      break;
    } else {
      __label__ = 101;
      break;
    }
   case 100:
    var $351 = HEAP32[$pn + 32 >> 2];
    var $354 = HEAP32[$pn + 36 >> 2];
    var $355 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $354, $right16);
    if ($355) {
      var $computed17_0 = 1;
      var $pnleft_0 = $351;
      __label__ = 102;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 101:
    var $360 = HEAP32[$pn + 36 >> 2];
    var $362 = HEAP32[$pn + 32 >> 2];
    var $363 = __ZN2js13ASTSerializer10identifierEP6JSAtomPNS_8TokenPosEPN2JS5ValueE($this, $362, 0, $right16);
    if ($363) {
      var $computed17_0 = 0;
      var $pnleft_0 = $360;
      __label__ = 102;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 102:
    var $pnleft_0;
    var $computed17_0;
    var $365 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pnleft_0, 34);
    if ($365) {
      __label__ = 103;
      break;
    } else {
      __label__ = 104;
      break;
    }
   case 103:
    var $367 = $this + 8 | 0;
    var $368 = $right16 | 0;
    var $st$2$0 = $368 | 0;
    var $369$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $368 + 4 | 0;
    var $369$1 = HEAP32[$st$2$1 >> 2];
    var $370 = $pn + 4 | 0;
    var $371 = __ZN2js11NodeBuilder30xmlFunctionQualifiedIdentifierEN2JS5ValueEbPNS_8TokenPosEPS2_($367, $369$0, $369$1, $computed17_0, $370, $dst);
    var $_3 = $371;
    __label__ = 116;
    break;
   case 104:
    var $373 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $pnleft_0, $left18);
    if ($373) {
      __label__ = 105;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 105:
    var $375 = $this + 8 | 0;
    var $376 = $left18 | 0;
    var $st$2$0 = $376 | 0;
    var $377$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $376 + 4 | 0;
    var $377$1 = HEAP32[$st$2$1 >> 2];
    var $378 = $right16 | 0;
    var $st$7$0 = $378 | 0;
    var $379$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $378 + 4 | 0;
    var $379$1 = HEAP32[$st$7$1 >> 2];
    var $380 = $pn + 4 | 0;
    var $381 = __ZN2js11NodeBuilder22xmlQualifiedIdentifierEN2JS5ValueES2_bPNS_8TokenPosEPS2_($375, $377$0, $377$1, $379$0, $379$1, $computed17_0, $380, $dst);
    var $_3 = $381;
    __label__ = 116;
    break;
   case 106:
    var $384 = HEAP32[$pn + 32 >> 2];
    var $385 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($384, 29);
    if ($385) {
      __label__ = 107;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 107:
    var $387 = __ZNK11JSParseNode4isOpE4JSOp($384, 165);
    if ($387) {
      var $394 = 0;
      __label__ = 110;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 108:
    var $389 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($384, 71);
    if ($389) {
      var $394 = 0;
      __label__ = 110;
      break;
    } else {
      __label__ = 109;
      break;
    }
   case 109:
    var $391 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($384, 72);
    var $394 = $391 ^ 1;
    __label__ = 110;
    break;
   case 110:
    var $394;
    var $395 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $384, $expr19);
    if ($395) {
      __label__ = 111;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 111:
    var $397 = $this + 8 | 0;
    var $398 = $expr19 | 0;
    var $st$2$0 = $398 | 0;
    var $399$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $398 + 4 | 0;
    var $399$1 = HEAP32[$st$2$1 >> 2];
    var $400 = $pn + 4 | 0;
    var $401 = __ZN2js11NodeBuilder20xmlAttributeSelectorEN2JS5ValueEbPNS_8TokenPosEPS2_($397, $399$0, $399$1, $394, $400, $dst);
    var $_3 = $401;
    __label__ = 116;
    break;
   case 112:
    var $404 = HEAP32[$pn + 32 >> 2];
    var $405 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $404, $left21);
    if ($405) {
      __label__ = 113;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 113:
    var $409 = HEAP32[$pn + 36 >> 2];
    var $410 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $409, $right22);
    if ($410) {
      __label__ = 114;
      break;
    } else {
      var $_3 = 0;
      __label__ = 116;
      break;
    }
   case 114:
    var $412 = $this + 8 | 0;
    var $413 = $left21 | 0;
    var $st$2$0 = $413 | 0;
    var $414$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $413 + 4 | 0;
    var $414$1 = HEAP32[$st$2$1 >> 2];
    var $415 = $right22 | 0;
    var $st$7$0 = $415 | 0;
    var $416$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $415 + 4 | 0;
    var $416$1 = HEAP32[$st$7$1 >> 2];
    var $417 = $pn + 4 | 0;
    var $418 = __ZN2js11NodeBuilder19xmlFilterExpressionEN2JS5ValueES2_PNS_8TokenPosEPS2_($412, $414$0, $414$1, $416$0, $416$1, $417, $dst);
    var $_3 = $418;
    __label__ = 116;
    break;
   case 115:
    var $420 = __ZN2js13ASTSerializer3xmlEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_3 = $420;
    __label__ = 116;
    break;
   case 116:
    var $_3;
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer4xmlsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $elts) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $elt = __stackBase__;
    var $1 = $elts | 0;
    var $3 = HEAP32[$pn + 40 >> 2];
    var $4 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($1, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $elt_idx = $elt | 0;
    var $next_0_in = $pn + 32 | 0;
    __label__ = 3;
    break;
   case 3:
    var $next_0_in;
    var $next_0 = HEAP32[$next_0_in >> 2];
    if (($next_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZN2js13ASTSerializer3xmlEP11JSParseNodePN2JS5ValueE($this, $next_0, $elt);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $elt_idx_val$0 = HEAP32[$elt_idx >> 2];
    var $elt_idx_val$1 = HEAP32[$elt_idx + 4 >> 2];
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($1, $elt_idx_val$0, $elt_idx_val$1);
    var $next_0_in = $next_0 + 24 | 0;
    __label__ = 3;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer3xmlEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 628;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $expr = __stackBase__ + 4;
    var $elts = __stackBase__ + 12;
    var $elts1 = __stackBase__ + 104;
    var $elts2 = __stackBase__ + 196;
    var $elts3 = __stackBase__ + 288;
    var $elts4 = __stackBase__ + 380;
    var $1 = __stackBase__ + 472;
    var $2 = __stackBase__ + 480;
    var $elts5 = __stackBase__ + 488;
    var $3 = __stackBase__ + 580;
    var $4 = __stackBase__ + 588;
    var $5 = __stackBase__ + 596;
    var $6 = __stackBase__ + 604;
    var $7 = __stackBase__ + 612;
    var $8 = __stackBase__ + 620;
    var $11 = HEAPU32[$this >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$11 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($11);
    var $_5 = 0;
    __label__ = 36;
    break;
   case 3:
    var $17 = __ZNK11JSParseNode7getKindEv($pn);
    if (($17 | 0) == 25) {
      __label__ = 4;
      break;
    } else if (($17 | 0) == 75) {
      __label__ = 6;
      break;
    } else if (($17 | 0) == 76) {
      __label__ = 9;
      break;
    } else if (($17 | 0) == 59) {
      __label__ = 12;
      break;
    } else if (($17 | 0) == 60) {
      __label__ = 15;
      break;
    } else if (($17 | 0) == 61) {
      __label__ = 18;
      break;
    } else if (($17 | 0) == 66 || ($17 | 0) == 65) {
      __label__ = 21;
      break;
    } else if (($17 | 0) == 63) {
      __label__ = 22;
      break;
    } else if (($17 | 0) == 64) {
      __label__ = 29;
      break;
    } else if (($17 | 0) == 68) {
      __label__ = 30;
      break;
    } else if (($17 | 0) == 67) {
      __label__ = 31;
      break;
    } else if (($17 | 0) == 69) {
      __label__ = 32;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 4:
    var $20 = HEAP32[$pn + 32 >> 2];
    var $21 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $20, $expr);
    if ($21) {
      __label__ = 5;
      break;
    } else {
      var $_5 = 0;
      __label__ = 36;
      break;
    }
   case 5:
    var $23 = $this + 8 | 0;
    var $24 = $expr | 0;
    var $25$0 = HEAP32[$24 >> 2];
    var $25$1 = HEAP32[$24 + 4 >> 2];
    var $26 = $pn + 4 | 0;
    var $27 = __ZN2js11NodeBuilder19xmlEscapeExpressionEN2JS5ValueEPNS_8TokenPosEPS2_($23, $25$0, $25$1, $26, $dst);
    var $_5 = $27;
    __label__ = 36;
    break;
   case 6:
    __ZN2js15AutoValueVectorC1EP9JSContext($elts, $11);
    var $29 = __ZN2js13ASTSerializer4xmlsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $elts);
    if ($29) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $31 = $this + 8 | 0;
    var $32 = $pn + 4 | 0;
    var $33 = __ZN2js11NodeBuilder10xmlElementERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($31, $elts, $32, $dst);
    var $_0 = $33;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($elts);
    var $_5 = $_0;
    __label__ = 36;
    break;
   case 9:
    __ZN2js15AutoValueVectorC1EP9JSContext($elts1, $11);
    var $36 = __ZN2js13ASTSerializer4xmlsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $elts1);
    if ($36) {
      __label__ = 10;
      break;
    } else {
      var $_1 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $38 = $this + 8 | 0;
    var $39 = $pn + 4 | 0;
    var $40 = __ZN2js11NodeBuilder7xmlListERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($38, $elts1, $39, $dst);
    var $_1 = $40;
    __label__ = 11;
    break;
   case 11:
    var $_1;
    __ZN2js15AutoValueVectorD1Ev($elts1);
    var $_5 = $_1;
    __label__ = 36;
    break;
   case 12:
    __ZN2js15AutoValueVectorC1EP9JSContext($elts2, $11);
    var $43 = __ZN2js13ASTSerializer4xmlsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $elts2);
    if ($43) {
      __label__ = 13;
      break;
    } else {
      var $_2 = 0;
      __label__ = 14;
      break;
    }
   case 13:
    var $45 = $this + 8 | 0;
    var $46 = $pn + 4 | 0;
    var $47 = __ZN2js11NodeBuilder11xmlStartTagERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($45, $elts2, $46, $dst);
    var $_2 = $47;
    __label__ = 14;
    break;
   case 14:
    var $_2;
    __ZN2js15AutoValueVectorD1Ev($elts2);
    var $_5 = $_2;
    __label__ = 36;
    break;
   case 15:
    __ZN2js15AutoValueVectorC1EP9JSContext($elts3, $11);
    var $50 = __ZN2js13ASTSerializer4xmlsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $elts3);
    if ($50) {
      __label__ = 16;
      break;
    } else {
      var $_3 = 0;
      __label__ = 17;
      break;
    }
   case 16:
    var $52 = $this + 8 | 0;
    var $53 = $pn + 4 | 0;
    var $54 = __ZN2js11NodeBuilder9xmlEndTagERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($52, $elts3, $53, $dst);
    var $_3 = $54;
    __label__ = 17;
    break;
   case 17:
    var $_3;
    __ZN2js15AutoValueVectorD1Ev($elts3);
    var $_5 = $_3;
    __label__ = 36;
    break;
   case 18:
    __ZN2js15AutoValueVectorC1EP9JSContext($elts4, $11);
    var $57 = __ZN2js13ASTSerializer4xmlsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $elts4);
    if ($57) {
      __label__ = 19;
      break;
    } else {
      var $_4 = 0;
      __label__ = 20;
      break;
    }
   case 19:
    var $59 = $this + 8 | 0;
    var $60 = $pn + 4 | 0;
    var $61 = __ZN2js11NodeBuilder11xmlPointTagERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($59, $elts4, $60, $dst);
    var $_4 = $61;
    __label__ = 20;
    break;
   case 20:
    var $_4;
    __ZN2js15AutoValueVectorD1Ev($elts4);
    var $_5 = $_4;
    __label__ = 36;
    break;
   case 21:
    var $64 = $this + 8 | 0;
    var $67 = HEAP32[$pn + 32 >> 2];
    __ZN2js13ASTSerializer12atomContentsEP6JSAtom($1, $this, $67);
    var $68 = $pn + 4 | 0;
    var $_idx1 = $1 | 0;
    var $st$7$0 = $_idx1 | 0;
    var $_idx1_val$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $_idx1 + 4 | 0;
    var $_idx1_val$1 = HEAP32[$st$7$1 >> 2];
    var $69 = __ZN2js11NodeBuilder7xmlTextEN2JS5ValueEPNS_8TokenPosEPS2_($64, $_idx1_val$0, $_idx1_val$1, $68, $dst);
    var $_5 = $69;
    __label__ = 36;
    break;
   case 22:
    var $71 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 0);
    if ($71) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $73 = $this + 8 | 0;
    var $76 = HEAP32[$pn + 32 >> 2];
    __ZN2js13ASTSerializer12atomContentsEP6JSAtom($2, $this, $76);
    var $77 = $pn + 4 | 0;
    var $_idx2 = $2 | 0;
    var $st$7$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$7$1 >> 2];
    var $78 = __ZN2js11NodeBuilder7xmlNameEN2JS5ValueEPNS_8TokenPosEPS2_($73, $_idx2_val$0, $_idx2_val$1, $77, $dst);
    var $_5 = $78;
    __label__ = 36;
    break;
   case 24:
    var $80 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 5);
    if ($80) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    _JS_ReportErrorNumber($11, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_5 = 0;
    __label__ = 36;
    break;
   case 26:
    __ZN2js15AutoValueVectorC1EP9JSContext($elts5, $11);
    var $83 = __ZN2js13ASTSerializer4xmlsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $elts5);
    if ($83) {
      __label__ = 27;
      break;
    } else {
      var $89 = 0;
      __label__ = 28;
      break;
    }
   case 27:
    var $85 = $this + 8 | 0;
    var $86 = $pn + 4 | 0;
    var $87 = __ZN2js11NodeBuilder7xmlNameERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($85, $elts5, $86, $dst);
    var $89 = $87;
    __label__ = 28;
    break;
   case 28:
    var $89;
    __ZN2js15AutoValueVectorD1Ev($elts5);
    var $_5 = $89;
    __label__ = 36;
    break;
   case 29:
    var $91 = $this + 8 | 0;
    var $94 = HEAP32[$pn + 32 >> 2];
    __ZN2js13ASTSerializer12atomContentsEP6JSAtom($3, $this, $94);
    var $95 = $pn + 4 | 0;
    var $_idx3 = $3 | 0;
    var $st$7$0 = $_idx3 | 0;
    var $_idx3_val$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $_idx3 + 4 | 0;
    var $_idx3_val$1 = HEAP32[$st$7$1 >> 2];
    var $96 = __ZN2js11NodeBuilder12xmlAttributeEN2JS5ValueEPNS_8TokenPosEPS2_($91, $_idx3_val$0, $_idx3_val$1, $95, $dst);
    var $_5 = $96;
    __label__ = 36;
    break;
   case 30:
    var $98 = $this + 8 | 0;
    var $101 = HEAP32[$pn + 32 >> 2];
    __ZN2js13ASTSerializer12atomContentsEP6JSAtom($4, $this, $101);
    var $102 = $pn + 4 | 0;
    var $_idx4 = $4 | 0;
    var $st$7$0 = $_idx4 | 0;
    var $_idx4_val$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $_idx4 + 4 | 0;
    var $_idx4_val$1 = HEAP32[$st$7$1 >> 2];
    var $103 = __ZN2js11NodeBuilder8xmlCdataEN2JS5ValueEPNS_8TokenPosEPS2_($98, $_idx4_val$0, $_idx4_val$1, $102, $dst);
    var $_5 = $103;
    __label__ = 36;
    break;
   case 31:
    var $105 = $this + 8 | 0;
    var $108 = HEAP32[$pn + 32 >> 2];
    __ZN2js13ASTSerializer12atomContentsEP6JSAtom($5, $this, $108);
    var $109 = $pn + 4 | 0;
    var $_idx5 = $5 | 0;
    var $st$7$0 = $_idx5 | 0;
    var $_idx5_val$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $_idx5 + 4 | 0;
    var $_idx5_val$1 = HEAP32[$st$7$1 >> 2];
    var $110 = __ZN2js11NodeBuilder10xmlCommentEN2JS5ValueEPNS_8TokenPosEPS2_($105, $_idx5_val$0, $_idx5_val$1, $109, $dst);
    var $_5 = $110;
    __label__ = 36;
    break;
   case 32:
    var $113 = $pn + 36 | 0;
    var $116 = $this + 8 | 0;
    var $118 = HEAP32[$pn + 32 >> 2];
    if ((HEAP32[$113 >> 2] | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 33:
    __ZN2js13ASTSerializer12atomContentsEP6JSAtom($6, $this, $118);
    var $120 = $pn + 4 | 0;
    var $_idx8 = $6 | 0;
    var $_idx8_val$0 = HEAP32[$_idx8 >> 2];
    var $_idx8_val$1 = HEAP32[$_idx8 + 4 >> 2];
    var $121 = __ZN2js11NodeBuilder5xmlPIEN2JS5ValueEPNS_8TokenPosEPS2_($116, $_idx8_val$0, $_idx8_val$1, $120, $dst);
    var $_5 = $121;
    __label__ = 36;
    break;
   case 34:
    __ZN2js13ASTSerializer12atomContentsEP6JSAtom($7, $this, $118);
    var $124 = HEAP32[$113 >> 2];
    __ZN2js13ASTSerializer12atomContentsEP6JSAtom($8, $this, $124);
    var $125 = $pn + 4 | 0;
    var $_idx6 = $7 | 0;
    var $_idx6_val$0 = HEAP32[$_idx6 >> 2];
    var $_idx6_val$1 = HEAP32[$_idx6 + 4 >> 2];
    var $_idx7 = $8 | 0;
    var $_idx7_val$0 = HEAP32[$_idx7 >> 2];
    var $_idx7_val$1 = HEAP32[$_idx7 + 4 >> 2];
    var $126 = __ZN2js11NodeBuilder5xmlPIEN2JS5ValueES2_PNS_8TokenPosEPS2_($116, $_idx6_val$0, $_idx6_val$1, $_idx7_val$0, $_idx7_val$1, $125, $dst);
    var $_5 = $126;
    __label__ = 36;
    break;
   case 35:
    _JS_ReportErrorNumber($11, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_5 = 0;
    __label__ = 36;
    break;
   case 36:
    var $_5;
    STACKTOP = __stackBase__;
    return $_5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer3xmlEP11JSParseNodePN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer14blockStatementEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 92;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmts = __stackBase__;
    var $2 = HEAP32[$this >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($stmts, $2);
    var $3 = __ZN2js13ASTSerializer10statementsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $stmts);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $9 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 8 | 0;
    var $6 = $pn + 4 | 0;
    var $7 = __ZN2js11NodeBuilder14blockStatementERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($5, $stmts, $6, $dst);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    __ZN2js15AutoValueVectorD1Ev($stmts);
    STACKTOP = __stackBase__;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer7programEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 92;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmts = __stackBase__;
    var $2 = HEAP32[$this >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($stmts, $2);
    var $3 = __ZN2js13ASTSerializer10statementsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $stmts);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $9 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 8 | 0;
    var $6 = $pn + 4 | 0;
    var $7 = __ZN2js11NodeBuilder7programERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($5, $stmts, $6, $dst);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    __ZN2js15AutoValueVectorD1Ev($stmts);
    STACKTOP = __stackBase__;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 280;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $expr = __stackBase__ + 4;
    var $dtors = __stackBase__ + 12;
    var $stmt = __stackBase__ + 104;
    var $test = __stackBase__ + 112;
    var $cons = __stackBase__ + 120;
    var $alt = __stackBase__ + 128;
    var $expr1 = __stackBase__ + 136;
    var $stmt2 = __stackBase__ + 144;
    var $stmt3 = __stackBase__ + 152;
    var $test4 = __stackBase__ + 160;
    var $stmt5 = __stackBase__ + 168;
    var $var = __stackBase__ + 176;
    var $expr6 = __stackBase__ + 184;
    var $init = __stackBase__ + 192;
    var $test7 = __stackBase__ + 200;
    var $update = __stackBase__ + 208;
    var $var8 = __stackBase__ + 216;
    var $expr11 = __stackBase__ + 224;
    var $stmt12 = __stackBase__ + 232;
    var $label = __stackBase__ + 240;
    var $label13 = __stackBase__ + 248;
    var $stmt14 = __stackBase__ + 256;
    var $arg = __stackBase__ + 264;
    var $ns = __stackBase__ + 272;
    var $3 = HEAPU32[$this >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$3 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($3);
    var $_0 = 0;
    __label__ = 71;
    break;
   case 3:
    var $9 = __ZNK11JSParseNode7getKindEv($pn);
    if (($9 | 0) == 34 || ($9 | 0) == 46 || ($9 | 0) == 81) {
      __label__ = 4;
      break;
    } else if (($9 | 0) == 29) {
      __label__ = 5;
      break;
    } else if (($9 | 0) == 2) {
      __label__ = 8;
      break;
    } else if (($9 | 0) == 80) {
      __label__ = 12;
      break;
    } else if (($9 | 0) == 25) {
      var $_01 = $pn;
      __label__ = 19;
      break;
    } else if (($9 | 0) == 35) {
      __label__ = 20;
      break;
    } else if (($9 | 0) == 37) {
      __label__ = 24;
      break;
    } else if (($9 | 0) == 53) {
      __label__ = 25;
      break;
    } else if (($9 | 0) == 47 || ($9 | 0) == 40) {
      __label__ = 26;
      break;
    } else if (($9 | 0) == 41) {
      __label__ = 31;
      break;
    } else if (($9 | 0) == 42) {
      __label__ = 34;
      break;
    } else if (($9 | 0) == 82) {
      __label__ = 45;
      break;
    } else if (($9 | 0) == 43 || ($9 | 0) == 44) {
      __label__ = 54;
      break;
    } else if (($9 | 0) == 6) {
      __label__ = 58;
      break;
    } else if (($9 | 0) == 56 || ($9 | 0) == 48) {
      __label__ = 61;
      break;
    } else if (($9 | 0) == 58) {
      __label__ = 65;
      break;
    } else if (($9 | 0) == 39) {
      __label__ = 66;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 4:
    var $11 = __ZN2js13ASTSerializer11declarationEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_0 = $11;
    __label__ = 71;
    break;
   case 5:
    var $13 = __ZNK11JSParseNode6isUsedEv($pn);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($3, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 71;
    break;
   case 7:
    var $18 = HEAP32[$pn + 36 >> 2];
    var $19 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $18, $dst);
    var $_0 = $19;
    __label__ = 71;
    break;
   case 8:
    var $22 = HEAP32[$pn + 32 >> 2];
    if (($22 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $25 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $22, $expr);
    if ($25) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 10:
    var $27 = $this + 8 | 0;
    var $28 = $expr | 0;
    var $st$2$0 = $28 | 0;
    var $29$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $28 + 4 | 0;
    var $29$1 = HEAP32[$st$2$1 >> 2];
    var $30 = $pn + 4 | 0;
    var $31 = __ZN2js11NodeBuilder19expressionStatementEN2JS5ValueEPNS_8TokenPosEPS2_($27, $29$0, $29$1, $30, $dst);
    var $_0 = $31;
    __label__ = 71;
    break;
   case 11:
    var $33 = $this + 8 | 0;
    var $34 = $pn + 4 | 0;
    var $35 = __ZN2js11NodeBuilder14emptyStatementEPNS_8TokenPosEPN2JS5ValueE($33, $34, $dst);
    var $_0 = $35;
    __label__ = 71;
    break;
   case 12:
    var $38 = HEAP32[$pn + 36 >> 2];
    var $39 = $38;
    var $40 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($39, 81);
    if ($40) {
      __label__ = 13;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 13:
    __ZN2js15AutoValueVectorC1EP9JSContext($dtors, $3);
    var $43 = HEAP32[$38 + 32 >> 2];
    var $44 = __ZN2js13ASTSerializer7letHeadEP11JSParseNodeRNS_15AutoValueVectorE($this, $43, $dtors);
    if ($44) {
      __label__ = 14;
      break;
    } else {
      var $57 = 0;
      __label__ = 16;
      break;
    }
   case 14:
    var $47 = HEAP32[$38 + 36 >> 2];
    var $48 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $47, $stmt);
    if ($48) {
      __label__ = 15;
      break;
    } else {
      var $57 = 0;
      __label__ = 16;
      break;
    }
   case 15:
    var $50 = $this + 8 | 0;
    var $51 = $stmt | 0;
    var $st$2$0 = $51 | 0;
    var $52$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $51 + 4 | 0;
    var $52$1 = HEAP32[$st$2$1 >> 2];
    var $54 = $38 + 4 | 0;
    var $55 = __ZN2js11NodeBuilder12letStatementERNS_15AutoValueVectorEN2JS5ValueEPNS_8TokenPosEPS4_($50, $dtors, $52$0, $52$1, $54, $dst);
    var $57 = $55;
    __label__ = 16;
    break;
   case 16:
    var $57;
    __ZN2js15AutoValueVectorD1Ev($dtors);
    var $_0 = $57;
    __label__ = 71;
    break;
   case 17:
    var $59 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($39, 25);
    if ($59) {
      var $_01 = $39;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $61 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $39, $dst);
    var $_0 = $61;
    __label__ = 71;
    break;
   case 19:
    var $_01;
    var $63 = __ZN2js13ASTSerializer14blockStatementEP11JSParseNodePN2JS5ValueE($this, $_01, $dst);
    var $_0 = $63;
    __label__ = 71;
    break;
   case 20:
    var $66 = HEAP32[$pn + 32 >> 2];
    var $67 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $66, $test);
    if ($67) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 21:
    var $71 = HEAP32[$pn + 36 >> 2];
    var $72 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $71, $cons);
    if ($72) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 22:
    var $76 = HEAP32[$pn + 40 >> 2];
    var $77 = __ZN2js13ASTSerializer12optStatementEP11JSParseNodePN2JS5ValueE($this, $76, $alt);
    if ($77) {
      __label__ = 23;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 23:
    var $79 = $this + 8 | 0;
    var $80 = $test | 0;
    var $st$2$0 = $80 | 0;
    var $81$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $80 + 4 | 0;
    var $81$1 = HEAP32[$st$2$1 >> 2];
    var $82 = $cons | 0;
    var $st$7$0 = $82 | 0;
    var $83$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $82 + 4 | 0;
    var $83$1 = HEAP32[$st$7$1 >> 2];
    var $84 = $alt | 0;
    var $st$12$0 = $84 | 0;
    var $85$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $84 + 4 | 0;
    var $85$1 = HEAP32[$st$12$1 >> 2];
    var $86 = $pn + 4 | 0;
    var $87 = __ZN2js11NodeBuilder11ifStatementEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($79, $81$0, $81$1, $83$0, $83$1, $85$0, $85$1, $86, $dst);
    var $_0 = $87;
    __label__ = 71;
    break;
   case 24:
    var $89 = __ZN2js13ASTSerializer15switchStatementEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_0 = $89;
    __label__ = 71;
    break;
   case 25:
    var $91 = __ZN2js13ASTSerializer12tryStatementEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_0 = $91;
    __label__ = 71;
    break;
   case 26:
    var $94 = HEAP32[$pn + 32 >> 2];
    var $95 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $94, $expr1);
    if ($95) {
      __label__ = 27;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 27:
    var $99 = HEAP32[$pn + 36 >> 2];
    var $100 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $99, $stmt2);
    if ($100) {
      __label__ = 28;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 28:
    var $102 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 47);
    if ($102) {
      __label__ = 29;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 29:
    var $104 = $this + 8 | 0;
    var $105 = $expr1 | 0;
    var $st$2$0 = $105 | 0;
    var $106$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $105 + 4 | 0;
    var $106$1 = HEAP32[$st$2$1 >> 2];
    var $107 = $stmt2 | 0;
    var $st$7$0 = $107 | 0;
    var $108$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $107 + 4 | 0;
    var $108$1 = HEAP32[$st$7$1 >> 2];
    var $109 = $pn + 4 | 0;
    var $110 = __ZN2js11NodeBuilder13withStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_($104, $106$0, $106$1, $108$0, $108$1, $109, $dst);
    var $_0 = $110;
    __label__ = 71;
    break;
   case 30:
    var $112 = $this + 8 | 0;
    var $113 = $expr1 | 0;
    var $st$2$0 = $113 | 0;
    var $114$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $113 + 4 | 0;
    var $114$1 = HEAP32[$st$2$1 >> 2];
    var $115 = $stmt2 | 0;
    var $st$7$0 = $115 | 0;
    var $116$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $115 + 4 | 0;
    var $116$1 = HEAP32[$st$7$1 >> 2];
    var $117 = $pn + 4 | 0;
    var $118 = __ZN2js11NodeBuilder14whileStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_($112, $114$0, $114$1, $116$0, $116$1, $117, $dst);
    var $_0 = $118;
    __label__ = 71;
    break;
   case 31:
    var $121 = HEAP32[$pn + 32 >> 2];
    var $122 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $121, $stmt3);
    if ($122) {
      __label__ = 32;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 32:
    var $126 = HEAP32[$pn + 36 >> 2];
    var $127 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $126, $test4);
    if ($127) {
      __label__ = 33;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 33:
    var $129 = $this + 8 | 0;
    var $130 = $stmt3 | 0;
    var $st$2$0 = $130 | 0;
    var $131$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $130 + 4 | 0;
    var $131$1 = HEAP32[$st$2$1 >> 2];
    var $132 = $test4 | 0;
    var $st$7$0 = $132 | 0;
    var $133$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $132 + 4 | 0;
    var $133$1 = HEAP32[$st$7$1 >> 2];
    var $134 = $pn + 4 | 0;
    var $135 = __ZN2js11NodeBuilder16doWhileStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_($129, $131$0, $131$1, $133$0, $133$1, $134, $dst);
    var $_0 = $135;
    __label__ = 71;
    break;
   case 34:
    var $138 = HEAP32[$pn + 32 >> 2];
    var $141 = HEAP32[$pn + 36 >> 2];
    var $142 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $141, $stmt5);
    if ($142) {
      __label__ = 35;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 35:
    var $148 = (HEAP32[$pn + 44 >> 2] & 2 | 0) != 0;
    var $149 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($138, 45);
    var $151 = HEAP32[$138 + 32 >> 2];
    if ($149) {
      __label__ = 36;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 36:
    if (($151 | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 37:
    var $157 = HEAP32[$138 + 36 >> 2];
    var $158 = __ZN2js13ASTSerializer7patternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $157, 0, $var);
    if ($158) {
      __label__ = 39;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 38:
    var $160 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($151, 81);
    var $161 = __ZN2js13ASTSerializer19variableDeclarationEP11JSParseNodebPN2JS5ValueE($this, $151, $160, $var);
    if ($161) {
      __label__ = 39;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 39:
    var $165 = HEAP32[$138 + 40 >> 2];
    var $166 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $165, $expr6);
    if ($166) {
      __label__ = 40;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 40:
    var $168 = $this + 8 | 0;
    var $169 = $var | 0;
    var $st$2$0 = $169 | 0;
    var $170$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $169 + 4 | 0;
    var $170$1 = HEAP32[$st$2$1 >> 2];
    var $171 = $expr6 | 0;
    var $st$7$0 = $171 | 0;
    var $172$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $171 + 4 | 0;
    var $172$1 = HEAP32[$st$7$1 >> 2];
    var $173 = $stmt5 | 0;
    var $st$12$0 = $173 | 0;
    var $174$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $173 + 4 | 0;
    var $174$1 = HEAP32[$st$12$1 >> 2];
    var $175 = $pn + 4 | 0;
    var $176 = __ZN2js11NodeBuilder14forInStatementEN2JS5ValueES2_S2_bPNS_8TokenPosEPS2_($168, $170$0, $170$1, $172$0, $172$1, $174$0, $174$1, $148, $175, $dst);
    var $_0 = $176;
    __label__ = 71;
    break;
   case 41:
    var $178 = __ZN2js13ASTSerializer7forInitEP11JSParseNodePN2JS5ValueE($this, $151, $init);
    if ($178) {
      __label__ = 42;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 42:
    var $182 = HEAP32[$138 + 36 >> 2];
    var $183 = __ZN2js13ASTSerializer13optExpressionEP11JSParseNodePN2JS5ValueE($this, $182, $test7);
    if ($183) {
      __label__ = 43;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 43:
    var $187 = HEAP32[$138 + 40 >> 2];
    var $188 = __ZN2js13ASTSerializer13optExpressionEP11JSParseNodePN2JS5ValueE($this, $187, $update);
    if ($188) {
      __label__ = 44;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 44:
    var $190 = $this + 8 | 0;
    var $191 = $init | 0;
    var $st$2$0 = $191 | 0;
    var $192$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $191 + 4 | 0;
    var $192$1 = HEAP32[$st$2$1 >> 2];
    var $193 = $test7 | 0;
    var $st$7$0 = $193 | 0;
    var $194$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $193 + 4 | 0;
    var $194$1 = HEAP32[$st$7$1 >> 2];
    var $195 = $update | 0;
    var $st$12$0 = $195 | 0;
    var $196$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $195 + 4 | 0;
    var $196$1 = HEAP32[$st$12$1 >> 2];
    var $197 = $stmt5 | 0;
    var $198$0 = HEAP32[$197 >> 2];
    var $198$1 = HEAP32[$197 + 4 >> 2];
    var $199 = $pn + 4 | 0;
    var $200 = __ZN2js11NodeBuilder12forStatementEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($190, $192$0, $192$1, $194$0, $194$1, $196$0, $196$1, $198$0, $198$1, $199, $dst);
    var $_0 = $200;
    __label__ = 71;
    break;
   case 45:
    if ((HEAP32[$pn + 40 >> 2] | 0) == 2) {
      __label__ = 47;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    _JS_ReportErrorNumber($3, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 71;
    break;
   case 47:
    var $208 = HEAP32[$pn + 32 >> 2];
    var $210 = HEAP32[$208 + 24 >> 2];
    var $211 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($208, 46);
    if ($211) {
      __label__ = 48;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 48:
    var $213 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($210, 42);
    if ($213) {
      __label__ = 50;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    _JS_ReportErrorNumber($3, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 71;
    break;
   case 50:
    var $216 = __ZN2js13ASTSerializer19variableDeclarationEP11JSParseNodebPN2JS5ValueE($this, $208, 0, $var8);
    if ($216) {
      __label__ = 51;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 51:
    var $224 = (HEAP32[$210 + 44 >> 2] & 2 | 0) != 0;
    var $227 = HEAP32[HEAP32[$210 + 32 >> 2] + 40 >> 2];
    var $228 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $227, $expr11);
    if ($228) {
      __label__ = 52;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 52:
    var $232 = HEAP32[$210 + 36 >> 2];
    var $233 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $232, $stmt12);
    if ($233) {
      __label__ = 53;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 53:
    var $235 = $this + 8 | 0;
    var $236 = $var8 | 0;
    var $st$2$0 = $236 | 0;
    var $237$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $236 + 4 | 0;
    var $237$1 = HEAP32[$st$2$1 >> 2];
    var $238 = $expr11 | 0;
    var $st$7$0 = $238 | 0;
    var $239$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $238 + 4 | 0;
    var $239$1 = HEAP32[$st$7$1 >> 2];
    var $240 = $stmt12 | 0;
    var $st$12$0 = $240 | 0;
    var $241$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $240 + 4 | 0;
    var $241$1 = HEAP32[$st$12$1 >> 2];
    var $242 = $pn + 4 | 0;
    var $243 = __ZN2js11NodeBuilder14forInStatementEN2JS5ValueES2_S2_bPNS_8TokenPosEPS2_($235, $237$0, $237$1, $239$0, $239$1, $241$0, $241$1, $224, $242, $dst);
    var $_0 = $243;
    __label__ = 71;
    break;
   case 54:
    var $247 = HEAP32[$pn + 32 >> 2];
    var $248 = __ZN2js13ASTSerializer13optIdentifierEP6JSAtomPNS_8TokenPosEPN2JS5ValueE($this, $247, $label);
    if ($248) {
      __label__ = 55;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 55:
    var $250 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 43);
    var $251 = $this + 8 | 0;
    var $252 = $label | 0;
    var $st$3$0 = $252 | 0;
    var $253$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $252 + 4 | 0;
    var $253$1 = HEAP32[$st$3$1 >> 2];
    var $254 = $pn + 4 | 0;
    if ($250) {
      __label__ = 56;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 56:
    var $256 = __ZN2js11NodeBuilder14breakStatementEN2JS5ValueEPNS_8TokenPosEPS2_($251, $253$0, $253$1, $254, $dst);
    var $_0 = $256;
    __label__ = 71;
    break;
   case 57:
    var $258 = __ZN2js11NodeBuilder17continueStatementEN2JS5ValueEPNS_8TokenPosEPS2_($251, $253$0, $253$1, $254, $dst);
    var $_0 = $258;
    __label__ = 71;
    break;
   case 58:
    var $262 = HEAP32[$pn + 32 >> 2];
    var $263 = __ZN2js13ASTSerializer10identifierEP6JSAtomPNS_8TokenPosEPN2JS5ValueE($this, $262, 0, $label13);
    if ($263) {
      __label__ = 59;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 59:
    var $267 = HEAP32[$pn + 36 >> 2];
    var $268 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $267, $stmt14);
    if ($268) {
      __label__ = 60;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 60:
    var $270 = $this + 8 | 0;
    var $271 = $label13 | 0;
    var $st$2$0 = $271 | 0;
    var $272$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $271 + 4 | 0;
    var $272$1 = HEAP32[$st$2$1 >> 2];
    var $273 = $stmt14 | 0;
    var $st$7$0 = $273 | 0;
    var $274$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $273 + 4 | 0;
    var $274$1 = HEAP32[$st$7$1 >> 2];
    var $275 = $pn + 4 | 0;
    var $276 = __ZN2js11NodeBuilder16labeledStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_($270, $272$0, $272$1, $274$0, $274$1, $275, $dst);
    var $_0 = $276;
    __label__ = 71;
    break;
   case 61:
    var $279 = HEAP32[$pn + 32 >> 2];
    var $280 = __ZN2js13ASTSerializer13optExpressionEP11JSParseNodePN2JS5ValueE($this, $279, $arg);
    if ($280) {
      __label__ = 62;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 62:
    var $282 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 56);
    var $283 = $this + 8 | 0;
    var $284 = $arg | 0;
    var $st$3$0 = $284 | 0;
    var $285$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $284 + 4 | 0;
    var $285$1 = HEAP32[$st$3$1 >> 2];
    var $286 = $pn + 4 | 0;
    if ($282) {
      __label__ = 63;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 63:
    var $288 = __ZN2js11NodeBuilder14throwStatementEN2JS5ValueEPNS_8TokenPosEPS2_($283, $285$0, $285$1, $286, $dst);
    var $_0 = $288;
    __label__ = 71;
    break;
   case 64:
    var $290 = __ZN2js11NodeBuilder15returnStatementEN2JS5ValueEPNS_8TokenPosEPS2_($283, $285$0, $285$1, $286, $dst);
    var $_0 = $290;
    __label__ = 71;
    break;
   case 65:
    var $292 = $this + 8 | 0;
    var $293 = $pn + 4 | 0;
    var $294 = __ZN2js11NodeBuilder17debuggerStatementEPNS_8TokenPosEPN2JS5ValueE($292, $293, $dst);
    var $_0 = $294;
    __label__ = 71;
    break;
   case 66:
    var $296 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 1);
    if ($296) {
      __label__ = 68;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 67:
    _JS_ReportErrorNumber($3, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 71;
    break;
   case 68:
    var $300 = HEAP32[$pn + 32 >> 2];
    var $301 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $300, $ns);
    if ($301) {
      __label__ = 69;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 69:
    var $303 = $this + 8 | 0;
    var $304 = $ns | 0;
    var $st$2$0 = $304 | 0;
    var $305$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $304 + 4 | 0;
    var $305$1 = HEAP32[$st$2$1 >> 2];
    var $306 = $pn + 4 | 0;
    var $307 = __ZN2js11NodeBuilder19xmlDefaultNamespaceEN2JS5ValueEPNS_8TokenPosEPS2_($303, $305$0, $305$1, $306, $dst);
    var $_0 = $307;
    __label__ = 71;
    break;
   case 70:
    _JS_ReportErrorNumber($3, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 71;
    break;
   case 71:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer11declarationEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode7getKindEv($pn);
    if (($1 | 0) == 34) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 46) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZN2js13ASTSerializer8functionEP11JSParseNodeNS_7ASTTypeEPN2JS5ValueE($this, $pn, 4, $dst);
    var $_0 = $3;
    __label__ = 5;
    break;
   case 3:
    var $5 = __ZN2js13ASTSerializer19variableDeclarationEP11JSParseNodebPN2JS5ValueE($this, $pn, 0, $dst);
    var $_0 = $5;
    __label__ = 5;
    break;
   case 4:
    var $7 = __ZN2js13ASTSerializer19variableDeclarationEP11JSParseNodebPN2JS5ValueE($this, $pn, 1, $dst);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer8functionEP11JSParseNodeNS_7ASTTypeEPN2JS5ValueE($this, $pn, $type, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 108;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $args = __stackBase__ + 8;
    var $body = __stackBase__ + 100;
    var $3 = HEAP32[$pn + 32 >> 2];
    var $5 = HEAP32[$3 + 8 >> 2];
    var $10 = (HEAP32[$3 + 60 >> 2] & 512 | 0) != 0;
    var $14 = (HEAP16[$5 + 58 >> 1] & 4096) << 16 >> 16 != 0;
    var $17 = HEAP32[$5 + 72 >> 2];
    var $18 = __ZN2js13ASTSerializer13optIdentifierEP6JSAtomPNS_8TokenPosEPN2JS5ValueE($this, $17, $id);
    if ($18) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $21 = HEAP32[$this >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($args, $21);
    var $23 = HEAP32[$pn + 36 >> 2];
    var $24 = $23;
    var $25 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($24, 85);
    if ($25) {
      __label__ = 3;
      break;
    } else {
      var $30 = $24;
      __label__ = 4;
      break;
    }
   case 3:
    var $30 = HEAP32[$23 + 36 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $30;
    var $31 = __ZN2js13ASTSerializer19functionArgsAndBodyEP11JSParseNodeRNS_15AutoValueVectorEPN2JS5ValueE($this, $30, $args, $body);
    if ($31) {
      __label__ = 5;
      break;
    } else {
      var $41 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $33 = $this + 8 | 0;
    var $34 = $pn + 4 | 0;
    var $35 = $id | 0;
    var $36$0 = HEAP32[$35 >> 2];
    var $36$1 = HEAP32[$35 + 4 >> 2];
    var $37 = $body | 0;
    var $38$0 = HEAP32[$37 >> 2];
    var $38$1 = HEAP32[$37 + 4 >> 2];
    var $39 = __ZN2js11NodeBuilder8functionENS_7ASTTypeEPNS_8TokenPosEN2JS5ValueERNS_15AutoValueVectorES5_bbPS5_($33, $type, $34, $36$0, $36$1, $args, $38$0, $38$1, $10, $14, $dst);
    var $41 = $39;
    __label__ = 6;
    break;
   case 6:
    var $41;
    __ZN2js15AutoValueVectorD1Ev($args);
    var $_0 = $41;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer8functionEP11JSParseNodeNS_7ASTTypeEPN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer19variableDeclarationEP11JSParseNodebPN2JS5ValueE($this, $pn, $let, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 128;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $kind = __stackBase__;
    var $dtors = __stackBase__ + 4;
    var $patt = __stackBase__ + 96;
    var $child = __stackBase__ + 104;
    var $1 = __stackBase__ + 112;
    var $child1 = __stackBase__ + 120;
    var $2 = $let ? 2 : 0;
    HEAP32[$kind >> 2] = $2;
    var $4 = HEAP32[$this >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($dtors, $4);
    var $5 = $pn + 32 | 0;
    if ((HEAP32[$pn + 44 >> 2] & 8 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = $5 | 0;
    var $13 = HEAP32[$12 >> 2];
    var $14 = __ZN2js13ASTSerializer7patternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $13, $kind, $patt);
    if ($14) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 3:
    var $16 = $this + 8 | 0;
    var $17 = $patt | 0;
    var $st$2$0 = $17 | 0;
    var $18$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $17 + 4 | 0;
    var $18$1 = HEAP32[$st$2$1 >> 2];
    __ZN2JSL9NullValueEv3400($1);
    var $20 = HEAP32[$12 >> 2] + 4 | 0;
    var $_idx1 = $1 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $21 = __ZN2js11NodeBuilder18variableDeclaratorEN2JS5ValueES2_PNS_8TokenPosEPS2_($16, $18$0, $18$1, $_idx1_val$0, $_idx1_val$1, $20, $child);
    if ($21) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 4:
    var $23 = $dtors | 0;
    var $child_idx = $child | 0;
    var $st$2$0 = $child_idx | 0;
    var $child_idx_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $child_idx + 4 | 0;
    var $child_idx_val$1 = HEAP32[$st$2$1 >> 2];
    var $24 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($23, $child_idx_val$0, $child_idx_val$1);
    if ($24) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 5:
    var $26 = HEAP32[$kind >> 2];
    var $27 = $pn + 4 | 0;
    var $28 = __ZN2js11NodeBuilder19variableDeclarationERNS_15AutoValueVectorENS_11VarDeclKindEPNS_8TokenPosEPN2JS5ValueE($16, $dtors, $26, $27, $dst);
    var $_0 = $28;
    __label__ = 12;
    break;
   case 6:
    var $30 = $dtors | 0;
    var $32 = HEAP32[$pn + 40 >> 2];
    var $33 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($30, $32);
    if ($33) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 7:
    var $child1_idx = $child1 | 0;
    var $next_0_in = $5 | 0;
    __label__ = 8;
    break;
   case 8:
    var $next_0_in;
    var $next_0 = HEAP32[$next_0_in >> 2];
    if (($next_0 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $39 = __ZN2js13ASTSerializer18variableDeclaratorEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $next_0, $kind, $child1);
    if ($39) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 10:
    var $child1_idx_val$0 = HEAP32[$child1_idx >> 2];
    var $child1_idx_val$1 = HEAP32[$child1_idx + 4 >> 2];
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($30, $child1_idx_val$0, $child1_idx_val$1);
    var $next_0_in = $next_0 + 24 | 0;
    __label__ = 8;
    break;
   case 11:
    var $43 = $this + 8 | 0;
    var $44 = HEAP32[$kind >> 2];
    var $45 = $pn + 4 | 0;
    var $46 = __ZN2js11NodeBuilder19variableDeclarationERNS_15AutoValueVectorENS_11VarDeclKindEPNS_8TokenPosEPN2JS5ValueE($43, $dtors, $44, $45, $dst);
    var $_0 = $46;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($dtors);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer19variableDeclarationEP11JSParseNodebPN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer7patternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $pn, $pkind, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAPU32[$this >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$3 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($3);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 3:
    var $9 = __ZNK11JSParseNode7getKindEv($pn);
    if (($9 | 0) == 26) {
      __label__ = 4;
      break;
    } else if (($9 | 0) == 24) {
      __label__ = 5;
      break;
    } else if (($9 | 0) == 29) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    var $11 = __ZN2js13ASTSerializer13objectPatternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $pn, $pkind, $dst);
    var $_0 = $11;
    __label__ = 10;
    break;
   case 5:
    var $13 = __ZN2js13ASTSerializer12arrayPatternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $pn, $pkind, $dst);
    var $_0 = $13;
    __label__ = 10;
    break;
   case 6:
    if (($pkind | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ((HEAP32[$pn + 44 >> 2] & 2 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP32[$pkind >> 2] = 1;
    __label__ = 9;
    break;
   case 9:
    var $24 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_0 = $24;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer18variableDeclaratorEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $pn, $pkind, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $left = __stackBase__;
    var $right = __stackBase__ + 8;
    var $1 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 29);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZNK11JSParseNode6isUsedEv($pn);
    if ($3) {
      var $pnright_0 = 0;
      var $pnleft_0 = $pn;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $pnright_0 = HEAP32[$pn + 36 >> 2];
    var $pnleft_0 = $pn;
    __label__ = 5;
    break;
   case 4:
    var $pnright_0 = HEAP32[$pn + 36 >> 2];
    var $pnleft_0 = HEAP32[$pn + 32 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $pnleft_0;
    var $pnright_0;
    var $15 = __ZN2js13ASTSerializer7patternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $pnleft_0, $pkind, $left);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      var $27 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $17 = __ZN2js13ASTSerializer13optExpressionEP11JSParseNodePN2JS5ValueE($this, $pnright_0, $right);
    if ($17) {
      __label__ = 7;
      break;
    } else {
      var $27 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $19 = $this + 8 | 0;
    var $20 = $left | 0;
    var $21$0 = HEAP32[$20 >> 2];
    var $21$1 = HEAP32[$20 + 4 >> 2];
    var $22 = $right | 0;
    var $23$0 = HEAP32[$22 >> 2];
    var $23$1 = HEAP32[$22 + 4 >> 2];
    var $24 = $pn + 4 | 0;
    var $25 = __ZN2js11NodeBuilder18variableDeclaratorEN2JS5ValueES2_PNS_8TokenPosEPS2_($19, $21$0, $21$1, $23$0, $23$1, $24, $dst);
    var $27 = $25;
    __label__ = 8;
    break;
   case 8:
    var $27;
    STACKTOP = __stackBase__;
    return $27;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer13optExpressionEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($pn | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value8setMagicE10JSWhyMagic($dst, 8);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $4 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_0 = $4;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer7letHeadEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $dtors) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $kind = __stackBase__;
    var $child = __stackBase__ + 4;
    var $1 = $dtors | 0;
    var $3 = HEAP32[$pn + 40 >> 2];
    var $4 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($1, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    HEAP32[$kind >> 2] = 3;
    var $child_idx = $child | 0;
    var $next_0_in = $pn + 32 | 0;
    __label__ = 3;
    break;
   case 3:
    var $next_0_in;
    var $next_0 = HEAP32[$next_0_in >> 2];
    if (($next_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZN2js13ASTSerializer18variableDeclaratorEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $next_0, $kind, $child);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $child_idx_val$0 = HEAP32[$child_idx >> 2];
    var $child_idx_val$1 = HEAP32[$child_idx + 4 >> 2];
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($1, $child_idx_val$0, $child_idx_val$1);
    var $next_0_in = $next_0 + 24 | 0;
    __label__ = 3;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer10switchCaseEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 100;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmts = __stackBase__;
    var $expr = __stackBase__ + 92;
    var $2 = HEAP32[$this >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($stmts, $2);
    var $4 = HEAP32[$pn + 32 >> 2];
    var $5 = __ZN2js13ASTSerializer13optExpressionEP11JSParseNodePN2JS5ValueE($this, $4, $expr);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $18 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $9 = HEAP32[$pn + 36 >> 2];
    var $10 = __ZN2js13ASTSerializer10statementsEP11JSParseNodeRNS_15AutoValueVectorE($this, $9, $stmts);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $18 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = $this + 8 | 0;
    var $13 = $expr | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $pn + 4 | 0;
    var $16 = __ZN2js11NodeBuilder10switchCaseEN2JS5ValueERNS_15AutoValueVectorEPNS_8TokenPosEPS2_($12, $14$0, $14$1, $stmts, $15, $dst);
    var $18 = $16;
    __label__ = 4;
    break;
   case 4:
    var $18;
    __ZN2js15AutoValueVectorD1Ev($stmts);
    STACKTOP = __stackBase__;
    return $18;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer15switchStatementEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 108;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $disc = __stackBase__;
    var $cases = __stackBase__ + 8;
    var $child = __stackBase__ + 100;
    var $2 = HEAP32[$pn + 32 >> 2];
    var $3 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $2, $disc);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    var $6 = HEAP32[$pn + 36 >> 2];
    var $7 = $6;
    var $8 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($7, 80);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $lexical_0 = 0;
      var $listNode_0 = $7;
      __label__ = 4;
      break;
    }
   case 3:
    var $lexical_0 = 1;
    var $listNode_0 = HEAP32[$6 + 36 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $listNode_0;
    var $lexical_0;
    var $14 = HEAP32[$this >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($cases, $14);
    var $15 = $cases | 0;
    var $17 = HEAP32[$listNode_0 + 40 >> 2];
    var $18 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($15, $17);
    if ($18) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 5:
    var $child_idx = $child | 0;
    var $next_0_in = $listNode_0 + 32 | 0;
    __label__ = 6;
    break;
   case 6:
    var $next_0_in;
    var $next_0 = HEAP32[$next_0_in >> 2];
    if (($next_0 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JSL14UndefinedValueEv3403($child);
    var $24 = __ZN2js13ASTSerializer10switchCaseEP11JSParseNodePN2JS5ValueE($this, $next_0, $child);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $child_idx_val$0 = HEAP32[$child_idx >> 2];
    var $child_idx_val$1 = HEAP32[$child_idx + 4 >> 2];
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($15, $child_idx_val$0, $child_idx_val$1);
    var $next_0_in = $next_0 + 24 | 0;
    __label__ = 6;
    break;
   case 9:
    var $28 = $this + 8 | 0;
    var $29 = $disc | 0;
    var $30$0 = HEAP32[$29 >> 2];
    var $30$1 = HEAP32[$29 + 4 >> 2];
    var $31 = $pn + 4 | 0;
    var $32 = __ZN2js11NodeBuilder15switchStatementEN2JS5ValueERNS_15AutoValueVectorEbPNS_8TokenPosEPS2_($28, $30$0, $30$1, $cases, $lexical_0, $31, $dst);
    var $_0 = $32;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($cases);
    var $_1 = $_0;
    __label__ = 11;
    break;
   case 11:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer15switchStatementEP11JSParseNodePN2JS5ValueE["X"] = 1;

function __ZN2JSL14UndefinedValueEv3403($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2js13ASTSerializer11catchClauseEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $var = __stackBase__;
    var $guard = __stackBase__ + 8;
    var $body = __stackBase__ + 16;
    var $2 = HEAP32[$pn + 32 >> 2];
    var $3 = __ZN2js13ASTSerializer7patternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $2, 0, $var);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $25 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $7 = HEAP32[$pn + 36 >> 2];
    var $8 = __ZN2js13ASTSerializer13optExpressionEP11JSParseNodePN2JS5ValueE($this, $7, $guard);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $25 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $12 = HEAP32[$pn + 40 >> 2];
    var $13 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $12, $body);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      var $25 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = $this + 8 | 0;
    var $16 = $var | 0;
    var $17$0 = HEAP32[$16 >> 2];
    var $17$1 = HEAP32[$16 + 4 >> 2];
    var $18 = $guard | 0;
    var $19$0 = HEAP32[$18 >> 2];
    var $19$1 = HEAP32[$18 + 4 >> 2];
    var $20 = $body | 0;
    var $21$0 = HEAP32[$20 >> 2];
    var $21$1 = HEAP32[$20 + 4 >> 2];
    var $22 = $pn + 4 | 0;
    var $23 = __ZN2js11NodeBuilder11catchClauseEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($15, $17$0, $17$1, $19$0, $19$1, $21$0, $21$1, $22, $dst);
    var $25 = $23;
    __label__ = 5;
    break;
   case 5:
    var $25;
    STACKTOP = __stackBase__;
    return $25;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer12tryStatementEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 116;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $body = __stackBase__;
    var $clauses = __stackBase__ + 8;
    var $clause = __stackBase__ + 100;
    var $finally = __stackBase__ + 108;
    var $2 = HEAP32[$pn + 32 >> 2];
    var $3 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $2, $body);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    var $6 = HEAP32[$this >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($clauses, $6);
    var $7 = $pn + 36 | 0;
    var $8 = HEAP32[$7 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = $clauses | 0;
    var $14 = HEAP32[$8 + 40 >> 2];
    var $15 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($11, $14);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 4:
    var $clause_idx = $clause | 0;
    var $next_0_in = HEAP32[$7 >> 2] + 32 | 0;
    __label__ = 5;
    break;
   case 5:
    var $next_0_in;
    var $next_0 = HEAP32[$next_0_in >> 2];
    if (($next_0 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $24 = HEAP32[$next_0 + 36 >> 2];
    var $25 = __ZN2js13ASTSerializer11catchClauseEP11JSParseNodePN2JS5ValueE($this, $24, $clause);
    if ($25) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    var $clause_idx_val$0 = HEAP32[$clause_idx >> 2];
    var $clause_idx_val$1 = HEAP32[$clause_idx + 4 >> 2];
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($11, $clause_idx_val$0, $clause_idx_val$1);
    var $next_0_in = $next_0 + 24 | 0;
    __label__ = 5;
    break;
   case 8:
    var $30 = HEAP32[$pn + 40 >> 2];
    var $31 = __ZN2js13ASTSerializer12optStatementEP11JSParseNodePN2JS5ValueE($this, $30, $finally);
    if ($31) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    var $33 = $this + 8 | 0;
    var $34 = $body | 0;
    var $35$0 = HEAP32[$34 >> 2];
    var $35$1 = HEAP32[$34 + 4 >> 2];
    var $36 = $finally | 0;
    var $37$0 = HEAP32[$36 >> 2];
    var $37$1 = HEAP32[$36 + 4 >> 2];
    var $38 = $pn + 4 | 0;
    var $39 = __ZN2js11NodeBuilder12tryStatementEN2JS5ValueERNS_15AutoValueVectorES2_PNS_8TokenPosEPS2_($33, $35$0, $35$1, $clauses, $37$0, $37$1, $38, $dst);
    var $_0 = $39;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($clauses);
    var $_1 = $_0;
    __label__ = 11;
    break;
   case 11:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer12tryStatementEP11JSParseNodePN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer12optStatementEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($pn | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value8setMagicE10JSWhyMagic($dst, 8);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $4 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_0 = $4;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer7forInitEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($pn | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value8setMagicE10JSWhyMagic($dst, 8);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 3:
    var $4 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 46);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $6 = __ZN2js13ASTSerializer19variableDeclarationEP11JSParseNodebPN2JS5ValueE($this, $pn, 0, $dst);
    var $_0 = $6;
    __label__ = 8;
    break;
   case 5:
    var $8 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 81);
    if ($8) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $10 = __ZN2js13ASTSerializer19variableDeclarationEP11JSParseNodebPN2JS5ValueE($this, $pn, 1, $dst);
    var $_0 = $10;
    __label__ = 8;
    break;
   case 7:
    var $12 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_0 = $12;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer13optIdentifierEP6JSAtomPNS_8TokenPosEPN2JS5ValueE($this, $atom, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($atom | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value8setMagicE10JSWhyMagic($dst, 8);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $4 = __ZN2js13ASTSerializer10identifierEP6JSAtomPNS_8TokenPosEPN2JS5ValueE($this, $atom, 0, $dst);
    var $_0 = $4;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer10identifierEP6JSAtomPNS_8TokenPosEPN2JS5ValueE($this, $atom, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this + 8 | 0;
  __ZN2js13ASTSerializer12atomContentsEP6JSAtom($1, $this, $atom);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $3 = __ZN2js11NodeBuilder10identifierEN2JS5ValueEPNS_8TokenPosEPS2_($2, $_idx_val$0, $_idx_val$1, $pos, $dst);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN2js13ASTSerializer13leftAssociateEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $left = __stackBase__;
    var $right = __stackBase__ + 8;
    var $subpos = __stackBase__ + 16;
    var $1 = __ZNK11JSParseNode7getKindEv($pn);
    var $2 = ($1 | 0) == 7;
    var $3 = ($1 - 7 | 0) >>> 0 < 2;
    var $5 = HEAPU32[$pn + 32 >> 2];
    var $6 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $5, $left);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    var $8 = $pn + 4 | 0;
    var $9 = $subpos;
    var $11 = $subpos + 8 | 0;
    var $12 = $this + 8 | 0;
    var $13 = $left | 0;
    var $14 = $right | 0;
    var $_pn = $5;
    __label__ = 3;
    break;
   case 3:
    var $_pn;
    var $next_0 = HEAP32[$_pn + 24 >> 2];
    if (($next_0 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $next_0, $right);
    if ($17) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $st$0$0 = $8 | 0;
    var $19$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $8 + 4 | 0;
    var $19$1 = HEAP32[$st$0$1 >> 2];
    var $st$4$0 = $9 | 0;
    HEAP32[$st$4$0 >> 2] = $19$0;
    var $st$4$1 = $9 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $19$1;
    var $21 = $next_0 + 12 | 0;
    var $22$0 = HEAP32[$21 >> 2];
    var $22$1 = HEAP32[$21 + 4 >> 2];
    HEAP32[$11 >> 2] = $22$0;
    HEAP32[$11 + 4 >> 2] = $22$1;
    if ($3) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $st$0$0 = $13 | 0;
    var $24$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $13 + 4 | 0;
    var $24$1 = HEAP32[$st$0$1 >> 2];
    var $st$4$0 = $14 | 0;
    var $25$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $14 + 4 | 0;
    var $25$1 = HEAP32[$st$4$1 >> 2];
    var $26 = __ZN2js11NodeBuilder17logicalExpressionEbN2JS5ValueES2_PNS_8TokenPosEPS2_($12, $2, $24$0, $24$1, $25$0, $25$1, $subpos, $left);
    if ($26) {
      var $_pn = $next_0;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $28 = __ZNK11JSParseNode7getKindEv($pn);
    var $29 = __ZNK11JSParseNode5getOpEv($pn);
    var $30 = __ZN2js13ASTSerializer5binopENS_9TokenKindE4JSOp($28, $29);
    if ($30 >>> 0 < 22) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $34 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($34, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 11;
    break;
   case 9:
    var $st$0$0 = $13 | 0;
    var $36$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $13 + 4 | 0;
    var $36$1 = HEAP32[$st$0$1 >> 2];
    var $st$4$0 = $14 | 0;
    var $37$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $14 + 4 | 0;
    var $37$1 = HEAP32[$st$4$1 >> 2];
    var $38 = __ZN2js11NodeBuilder16binaryExpressionENS_14BinaryOperatorEN2JS5ValueES3_PNS_8TokenPosEPS3_($12, $30, $36$0, $36$1, $37$0, $37$1, $subpos, $left);
    if ($38) {
      var $_pn = $next_0;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $st$0$0 = $13 | 0;
    var $40$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $13 + 4 | 0;
    var $40$1 = HEAP32[$st$0$1 >> 2];
    var $41 = $dst | 0;
    HEAP32[$41 >> 2] = $40$0;
    HEAP32[$41 + 4 >> 2] = $40$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer13leftAssociateEP11JSParseNodePN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer18comprehensionBlockEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $patt = __stackBase__;
    var $src = __stackBase__ + 8;
    var $1 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 2);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($4, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 3:
    var $7 = HEAP32[$pn + 32 >> 2];
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($7, 45);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($13, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 6:
    var $19 = (HEAP32[$pn + 44 >> 2] & 2 | 0) != 0;
    var $22 = HEAP32[$7 + 36 >> 2];
    var $23 = __ZN2js13ASTSerializer7patternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $22, 0, $patt);
    if ($23) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $27 = HEAP32[$7 + 40 >> 2];
    var $28 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $27, $src);
    if ($28) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $30 = $this + 8 | 0;
    var $31 = $patt | 0;
    var $32$0 = HEAP32[$31 >> 2];
    var $32$1 = HEAP32[$31 + 4 >> 2];
    var $33 = $src | 0;
    var $34$0 = HEAP32[$33 >> 2];
    var $34$1 = HEAP32[$33 + 4 >> 2];
    var $35 = $7 + 4 | 0;
    var $36 = __ZN2js11NodeBuilder18comprehensionBlockEN2JS5ValueES2_bPNS_8TokenPosEPS2_($30, $32$0, $32$1, $34$0, $34$1, $19, $35, $dst);
    var $_0 = $36;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer18comprehensionBlockEP11JSParseNodePN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer13comprehensionEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 208;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $blocks = __stackBase__;
    var $block = __stackBase__ + 92;
    var $filter = __stackBase__ + 100;
    var $empty = __stackBase__ + 108;
    var $body = __stackBase__ + 200;
    var $1 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 42);
    var $2 = $this | 0;
    var $3 = HEAP32[$2 >> 2];
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($3, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 19;
    break;
   case 3:
    __ZN2js15AutoValueVectorC1EP9JSContext($blocks, $3);
    var $6 = $blocks | 0;
    var $block_idx = $block | 0;
    var $next_0 = $pn;
    __label__ = 4;
    break;
   case 4:
    var $next_0;
    var $8 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($next_0, 42);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $10 = __ZN2js13ASTSerializer18comprehensionBlockEP11JSParseNodePN2JS5ValueE($this, $next_0, $block);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 6:
    var $block_idx_val$0 = HEAP32[$block_idx >> 2];
    var $block_idx_val$1 = HEAP32[$block_idx + 4 >> 2];
    var $12 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($6, $block_idx_val$0, $block_idx_val$1);
    if ($12) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 7:
    var $next_0 = HEAP32[$next_0 + 36 >> 2];
    __label__ = 4;
    break;
   case 8:
    __ZN2JSL10MagicValueE10JSWhyMagic3404($filter);
    var $18 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($next_0, 35);
    if ($18) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $21 = HEAP32[$next_0 + 32 >> 2];
    var $22 = __ZN2js13ASTSerializer13optExpressionEP11JSParseNodePN2JS5ValueE($this, $21, $filter);
    if ($22) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 10:
    var $next_1 = HEAP32[$next_0 + 36 >> 2];
    __label__ = 14;
    break;
   case 11:
    var $28 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($next_0, 25);
    if ($28) {
      __label__ = 12;
      break;
    } else {
      var $next_1 = $next_0;
      __label__ = 14;
      break;
    }
   case 12:
    if ((HEAP32[$next_0 + 40 >> 2] | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $next_1 = $next_0;
      __label__ = 14;
      break;
    }
   case 13:
    var $34 = HEAP32[$2 >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($empty, $34);
    var $35 = $this + 8 | 0;
    var $36 = $pn + 4 | 0;
    var $37 = __ZN2js11NodeBuilder15arrayExpressionERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($35, $empty, $36, $dst);
    __ZN2js15AutoValueVectorD1Ev($empty);
    var $_0 = $37;
    __label__ = 18;
    break;
   case 14:
    var $next_1;
    var $39 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($next_1, 79);
    if ($39) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $41 = HEAP32[$2 >> 2];
    _JS_ReportErrorNumber($41, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 16:
    var $44 = HEAP32[$next_1 + 32 >> 2];
    var $45 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $44, $body);
    if ($45) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 17:
    var $47 = $this + 8 | 0;
    var $48 = $body | 0;
    var $49$0 = HEAP32[$48 >> 2];
    var $49$1 = HEAP32[$48 + 4 >> 2];
    var $50 = $filter | 0;
    var $51$0 = HEAP32[$50 >> 2];
    var $51$1 = HEAP32[$50 + 4 >> 2];
    var $52 = $pn + 4 | 0;
    var $53 = __ZN2js11NodeBuilder23comprehensionExpressionEN2JS5ValueERNS_15AutoValueVectorES2_PNS_8TokenPosEPS2_($47, $49$0, $49$1, $blocks, $51$0, $51$1, $52, $dst);
    var $_0 = $53;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($blocks);
    var $_1 = $_0;
    __label__ = 19;
    break;
   case 19:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer13comprehensionEP11JSParseNodePN2JS5ValueE["X"] = 1;

function __ZN2JSL10MagicValueE10JSWhyMagic3404($agg_result) {
  __ZN2JS5Value8setMagicE10JSWhyMagic($agg_result, 8);
  return;
}

function __ZN2js13ASTSerializer19generatorExpressionEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 116;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $blocks = __stackBase__;
    var $block = __stackBase__ + 92;
    var $filter = __stackBase__ + 100;
    var $body = __stackBase__ + 108;
    var $1 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 42);
    var $2 = $this | 0;
    var $3 = HEAP32[$2 >> 2];
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($3, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 18;
    break;
   case 3:
    __ZN2js15AutoValueVectorC1EP9JSContext($blocks, $3);
    var $6 = $blocks | 0;
    var $block_idx = $block | 0;
    var $next_0 = $pn;
    __label__ = 4;
    break;
   case 4:
    var $next_0;
    var $8 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($next_0, 42);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $10 = __ZN2js13ASTSerializer18comprehensionBlockEP11JSParseNodePN2JS5ValueE($this, $next_0, $block);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 6:
    var $block_idx_val$0 = HEAP32[$block_idx >> 2];
    var $block_idx_val$1 = HEAP32[$block_idx + 4 >> 2];
    var $12 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($6, $block_idx_val$0, $block_idx_val$1);
    if ($12) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 7:
    var $next_0 = HEAP32[$next_0 + 36 >> 2];
    __label__ = 4;
    break;
   case 8:
    __ZN2JSL10MagicValueE10JSWhyMagic3404($filter);
    var $18 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($next_0, 35);
    if ($18) {
      __label__ = 9;
      break;
    } else {
      var $next_1 = $next_0;
      __label__ = 11;
      break;
    }
   case 9:
    var $21 = HEAP32[$next_0 + 32 >> 2];
    var $22 = __ZN2js13ASTSerializer13optExpressionEP11JSParseNodePN2JS5ValueE($this, $21, $filter);
    if ($22) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 10:
    var $next_1 = HEAP32[$next_0 + 36 >> 2];
    __label__ = 11;
    break;
   case 11:
    var $next_1;
    var $28 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($next_1, 2);
    if ($28) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $31 = HEAP32[$next_1 + 32 >> 2];
    var $32 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($31, 77);
    if ($32) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $35 = HEAP32[$31 + 32 >> 2];
    if (($35 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $38 = HEAP32[$2 >> 2];
    _JS_ReportErrorNumber($38, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 17;
    break;
   case 15:
    var $40 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $35, $body);
    if ($40) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 16:
    var $42 = $this + 8 | 0;
    var $43 = $body | 0;
    var $44$0 = HEAP32[$43 >> 2];
    var $44$1 = HEAP32[$43 + 4 >> 2];
    var $45 = $filter | 0;
    var $46$0 = HEAP32[$45 >> 2];
    var $46$1 = HEAP32[$45 + 4 >> 2];
    var $47 = $pn + 4 | 0;
    var $48 = __ZN2js11NodeBuilder19generatorExpressionEN2JS5ValueERNS_15AutoValueVectorES2_PNS_8TokenPosEPS2_($42, $44$0, $44$1, $blocks, $46$0, $46$1, $47, $dst);
    var $_0 = $48;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($blocks);
    var $_1 = $_0;
    __label__ = 18;
    break;
   case 18:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer19generatorExpressionEP11JSParseNodePN2JS5ValueE["X"] = 1;

function __ZNK11JSParseNode15isGeneratorExprEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode7getKindEv($this);
    if (($1 | 0) == 27) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $5 = HEAP32[$this + 32 >> 2];
    var $6 = __ZNK11JSParseNode7getKindEv($5);
    if (($6 | 0) == 34) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $10 = HEAP32[$5 + 36 >> 2];
    var $11 = $10;
    var $12 = __ZNK11JSParseNode7getKindEv($11);
    if (($12 | 0) == 85) {
      __label__ = 4;
      break;
    } else {
      var $18 = $11;
      __label__ = 5;
      break;
    }
   case 4:
    var $18 = HEAP32[$10 + 36 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = __ZNK11JSParseNode7getKindEv($18);
    if (($19 | 0) == 80) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK11JSParseNode13generatorExprEv($this_0_7_0_0_val_0_7_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this_0_7_0_0_val_0_7_0_1_val;
    var $2 = __ZNK11JSParseNode7getKindEv($1);
    if (($2 | 0) == 85) {
      __label__ = 2;
      break;
    } else {
      var $8 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = HEAP32[$this_0_7_0_0_val_0_7_0_1_val + 36 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $8;
    return HEAP32[$8 + 36 >> 2];
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer8propertyEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $key = __stackBase__;
    var $val = __stackBase__ + 8;
    var $1 = __ZNK11JSParseNode5getOpEv($pn);
    if (($1 | 0) == 125) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 126) {
      __label__ = 3;
      break;
    } else if (($1 | 0) == 93) {
      var $kind_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $kind_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $kind_0 = 2;
    __label__ = 5;
    break;
   case 4:
    var $6 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($6, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 8;
    break;
   case 5:
    var $kind_0;
    var $9 = HEAP32[$pn + 32 >> 2];
    var $10 = __ZN2js13ASTSerializer12propertyNameEP11JSParseNodePN2JS5ValueE($this, $9, $key);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $14 = HEAP32[$pn + 36 >> 2];
    var $15 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $14, $val);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $17 = $this + 8 | 0;
    var $18 = $key | 0;
    var $19$0 = HEAP32[$18 >> 2];
    var $19$1 = HEAP32[$18 + 4 >> 2];
    var $20 = $val | 0;
    var $21$0 = HEAP32[$20 >> 2];
    var $21$1 = HEAP32[$20 + 4 >> 2];
    var $22 = $pn + 4 | 0;
    var $23 = __ZN2js11NodeBuilder19propertyInitializerEN2JS5ValueES2_NS_8PropKindEPNS_8TokenPosEPS2_($17, $19$0, $19$1, $21$0, $21$1, $kind_0, $22, $dst);
    var $_0 = $23;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer10identifierEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 6);
    if ($1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 0);
    if ($3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($6, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 4:
    var $10 = HEAP32[$pn + 32 >> 2];
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $14 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($14, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $16 = $pn + 4 | 0;
    var $17 = __ZN2js13ASTSerializer10identifierEP6JSAtomPNS_8TokenPosEPN2JS5ValueE($this, $10, $16, $dst);
    var $_0 = $17;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16GetClassProtoKeyEPNS_5ClassE3418() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2];
    var $2 = $1 >>> 24;
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $1 >>> 17 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL15GetGCObjectKindEjb3408($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13IMPL_TO_JSVAL12jsval_layout3419($agg_result, $l_0$0, $l_0$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $l_0$0;
  HEAP32[$1 + 4 >> 2] = $l_0$1;
  return;
}

function __ZN2js13ASTSerializer7literalEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $val = __stackBase__;
    var $proto = __stackBase__ + 8;
    var $1 = __ZNK11JSParseNode7getKindEv($pn);
    if (($1 | 0) == 31) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 32) {
      __label__ = 3;
      break;
    } else if (($1 | 0) == 30) {
      __label__ = 10;
      break;
    } else if (($1 | 0) == 33) {
      __label__ = 11;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 2:
    var $6 = HEAP32[$pn + 32 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($val, $6);
    __label__ = 15;
    break;
   case 3:
    var $10 = HEAP32[$pn + 32 >> 2];
    if (($10 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = HEAP32[$10 + 8 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx_val = HEAP32[$14 + 4 >> 2];
    var $17 = __ZNK8JSObject8isRegExpEv($_idx_val);
    if ($17) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($19, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 16;
    break;
   case 7:
    var $21 = $this | 0;
    var $22 = HEAP32[$21 >> 2];
    var $23 = __ZNK9JSContext2fpEv($22);
    var $24 = __ZNK2js10StackFrame10scopeChainEv($23);
    var $25 = $22;
    var $26 = $24;
    var $27 = $proto;
    var $28 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($25, $26, 10, $27, 0);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $33 = HEAP32[$21 >> 2];
    var $34 = $14;
    var $35 = HEAP32[$proto >> 2];
    var $36 = __Z20js_CloneRegExpObjectP9JSContextP8JSObjectS2_($33, $34, $35);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $39 = $36;
    __ZN2JS5Value9setObjectER8JSObject($val, $39);
    __label__ = 15;
    break;
   case 10:
    var $42 = $pn + 32 | 0;
    var $43 = (tempDoubleI32[0] = HEAP32[$42 >> 2], tempDoubleI32[1] = HEAP32[$42 + 4 >> 2], tempDoubleF64[0]);
    var $44 = __ZN2JS5Value9setNumberEd($val, $43);
    __label__ = 15;
    break;
   case 11:
    var $46 = __ZNK11JSParseNode4isOpE4JSOp($pn, 64);
    if ($46) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    __ZN2JS5Value7setNullEv($val);
    __label__ = 15;
    break;
   case 13:
    var $49 = __ZNK11JSParseNode4isOpE4JSOp($pn, 67);
    __ZN2JS5Value10setBooleanEb($val, $49);
    __label__ = 15;
    break;
   case 14:
    var $52 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($52, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 16;
    break;
   case 15:
    var $54 = $this + 8 | 0;
    var $55 = $val | 0;
    var $56$0 = HEAP32[$55 >> 2];
    var $56$1 = HEAP32[$55 + 4 >> 2];
    var $57 = $pn + 4 | 0;
    var $58 = __ZN2js11NodeBuilder7literalEN2JS5ValueEPNS_8TokenPosEPS2_($54, $56$0, $56$1, $57, $dst);
    var $_0 = $58;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer7literalEP11JSParseNodePN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer12atomContentsEP6JSAtom($agg_result, $this, $atom) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($atom | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $11 = $atom;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAP32[HEAP32[HEAP32[$this >> 2] + 52 >> 2] + 209972 >> 2] | 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    __ZN2JSL11StringValueEP8JSString3435($agg_result, $11 | 0);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer12propertyNameEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 29);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js13ASTSerializer10identifierEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_0 = $3;
    __label__ = 7;
    break;
   case 3:
    var $5 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 31);
    if ($5) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 30);
    if ($7) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($10, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $12 = __ZN2js13ASTSerializer7literalEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_0 = $12;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer12arrayPatternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $pn, $pkind, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 108;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $elts = __stackBase__;
    var $1 = __stackBase__ + 92;
    var $patt = __stackBase__ + 100;
    var $3 = HEAP32[$this >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($elts, $3);
    var $4 = $elts | 0;
    var $6 = HEAP32[$pn + 40 >> 2];
    var $7 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($4, $6);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 2:
    var $_idx = $1 | 0;
    var $patt_idx = $patt | 0;
    var $next_0_in = $pn + 32 | 0;
    __label__ = 3;
    break;
   case 3:
    var $next_0_in;
    var $next_0 = HEAP32[$next_0_in >> 2];
    if (($next_0 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($next_0, 3);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2JSL10MagicValueE10JSWhyMagic3404($1);
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($4, $_idx_val$0, $_idx_val$1);
    __label__ = 8;
    break;
   case 6:
    var $16 = __ZN2js13ASTSerializer7patternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $next_0, $pkind, $patt);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    var $patt_idx_val$0 = HEAP32[$patt_idx >> 2];
    var $patt_idx_val$1 = HEAP32[$patt_idx + 4 >> 2];
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($4, $patt_idx_val$0, $patt_idx_val$1);
    __label__ = 8;
    break;
   case 8:
    var $next_0_in = $next_0 + 24 | 0;
    __label__ = 3;
    break;
   case 9:
    var $21 = $this + 8 | 0;
    var $22 = $pn + 4 | 0;
    var $23 = __ZN2js11NodeBuilder12arrayPatternERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($21, $elts, $22, $dst);
    var $_0 = $23;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($elts);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer13objectPatternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $pn, $pkind, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 116;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $elts = __stackBase__;
    var $key = __stackBase__ + 92;
    var $patt = __stackBase__ + 100;
    var $prop = __stackBase__ + 108;
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($elts, $2);
    var $3 = $elts | 0;
    var $5 = HEAP32[$pn + 40 >> 2];
    var $6 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($3, $5);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    var $9 = $this + 8 | 0;
    var $10 = $key | 0;
    var $11 = $patt | 0;
    var $prop_idx = $prop | 0;
    var $next_0_in = $pn + 32 | 0;
    __label__ = 3;
    break;
   case 3:
    var $next_0_in;
    var $next_0 = HEAP32[$next_0_in >> 2];
    if (($next_0 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = __ZNK11JSParseNode4isOpE4JSOp($next_0, 93);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = HEAP32[$1 >> 2];
    _JS_ReportErrorNumber($17, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 11;
    break;
   case 6:
    var $20 = HEAP32[$next_0 + 32 >> 2];
    var $21 = __ZN2js13ASTSerializer12propertyNameEP11JSParseNodePN2JS5ValueE($this, $20, $key);
    if ($21) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $25 = HEAP32[$next_0 + 36 >> 2];
    var $26 = __ZN2js13ASTSerializer7patternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $25, $pkind, $patt);
    if ($26) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 8:
    var $st$0$0 = $10 | 0;
    var $28$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $10 + 4 | 0;
    var $28$1 = HEAP32[$st$0$1 >> 2];
    var $29$0 = HEAP32[$11 >> 2];
    var $29$1 = HEAP32[$11 + 4 >> 2];
    var $30 = $next_0 + 4 | 0;
    var $31 = __ZN2js11NodeBuilder15propertyPatternEN2JS5ValueES2_PNS_8TokenPosEPS2_($9, $28$0, $28$1, $29$0, $29$1, $30, $prop);
    if ($31) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 9:
    var $st$0$0 = $prop_idx | 0;
    var $prop_idx_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $prop_idx + 4 | 0;
    var $prop_idx_val$1 = HEAP32[$st$0$1 >> 2];
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($3, $prop_idx_val$0, $prop_idx_val$1);
    var $next_0_in = $next_0 + 24 | 0;
    __label__ = 3;
    break;
   case 10:
    var $35 = $pn + 4 | 0;
    var $36 = __ZN2js11NodeBuilder13objectPatternERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($9, $elts, $35, $dst);
    var $_0 = $36;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($elts);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer13objectPatternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer19functionArgsAndBodyEP11JSParseNodeRNS_15AutoValueVectorEPN2JS5ValueE($this, $pn, $args, $body) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 84);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $pnbody_0 = $pn;
      var $pnargs_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $pn_idx_val = HEAP32[$pn + 36 >> 2];
    var $3 = __ZNK11JSParseNode4lastEv($pn_idx_val);
    var $pnbody_0 = $3;
    var $pnargs_0 = $pn;
    __label__ = 3;
    break;
   case 3:
    var $pnargs_0;
    var $pnbody_0;
    var $5 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pnbody_0, 5);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $pndestruct_0 = 0;
      __label__ = 11;
      break;
    }
   case 4:
    if ((HEAP32[$pnbody_0 + 44 >> 2] & 512 | 0) == 0) {
      var $pndestruct_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = HEAP32[$pnbody_0 + 32 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($14, 2);
    if ($17) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($20, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 8:
    var $23 = HEAP32[$14 + 32 >> 2];
    if (($23 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $26 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($23, 46);
    if ($26) {
      var $pndestruct_0 = $23;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $29 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($29, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 11:
    var $pndestruct_0;
    var $31 = __ZNK11JSParseNode7getKindEv($pnbody_0);
    if (($31 | 0) == 48) {
      __label__ = 12;
      break;
    } else if (($31 | 0) == 82) {
      __label__ = 14;
      break;
    } else if (($31 | 0) == 25) {
      __label__ = 19;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 12:
    var $33 = __ZN2js13ASTSerializer12functionArgsEP11JSParseNodeS2_S2_S2_RNS_15AutoValueVectorE($this, $pnargs_0, 0, $pnbody_0, $args);
    if ($33) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 13:
    var $36 = HEAP32[$pnbody_0 + 32 >> 2];
    var $37 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $36, $body);
    var $_0 = $37;
    __label__ = 24;
    break;
   case 14:
    var $42 = HEAP32[HEAP32[$pnbody_0 + 32 >> 2] + 24 >> 2];
    if (($42 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $45 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($42, 48);
    if ($45) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $48 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($48, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 17:
    var $50 = __ZN2js13ASTSerializer12functionArgsEP11JSParseNodeS2_S2_S2_RNS_15AutoValueVectorE($this, $pnargs_0, $pndestruct_0, $pnbody_0, $args);
    if ($50) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 18:
    var $53 = HEAP32[$42 + 32 >> 2];
    var $54 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $53, $body);
    var $_0 = $54;
    __label__ = 24;
    break;
   case 19:
    var $62 = HEAP32[$pnbody_0 + 32 >> 2];
    if ((HEAP32[$pnbody_0 + 44 >> 2] & 512 | 0) == 0) {
      var $67 = $62;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $67 = HEAP32[$62 + 24 >> 2];
    __label__ = 21;
    break;
   case 21:
    var $67;
    var $68 = __ZN2js13ASTSerializer12functionArgsEP11JSParseNodeS2_S2_S2_RNS_15AutoValueVectorE($this, $pnargs_0, $pndestruct_0, $pnbody_0, $args);
    if ($68) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 22:
    var $71 = __ZN2js13ASTSerializer12functionBodyEP11JSParseNodePNS_8TokenPosEPN2JS5ValueE($this, $67, $pnbody_0 + 4 | 0, $body);
    var $_0 = $71;
    __label__ = 24;
    break;
   case 23:
    var $74 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($74, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 24:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer19functionArgsAndBodyEP11JSParseNodeRNS_15AutoValueVectorEPN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer12functionArgsEP11JSParseNodeS2_S2_S2_RNS_15AutoValueVectorE($this, $pnargs, $pndestruct, $pnbody, $args) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $node = __stackBase__;
    if (($pnargs | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$pnargs + 32 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $6;
    if (($pndestruct | 0) == 0) {
      var $destruct_0_ph = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $destruct_0_ph = HEAP32[$pndestruct + 32 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $destruct_0_ph;
    var $11 = $args | 0;
    var $node_idx = $node | 0;
    var $destruct_0 = $destruct_0_ph;
    var $arg_0 = $6;
    var $i_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $i_0;
    var $arg_0;
    var $destruct_0;
    var $or_cond = ($arg_0 | 0) == 0 | ($arg_0 | 0) == ($pnbody | 0);
    var $14 = ($destruct_0 | 0) == 0;
    if ($or_cond & $14) {
      var $_0 = 1;
      __label__ = 18;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ($14) {
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $18 = HEAP32[$destruct_0 + 36 >> 2];
    var $19 = __ZNK11JSParseNode9frameSlotEv($18);
    if (($19 | 0) == ($i_0 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 9:
    var $23 = HEAP32[$destruct_0 + 32 >> 2];
    var $24 = __ZN2js13ASTSerializer7patternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $23, 0, $node);
    if ($24) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 10:
    var $st$0$0 = $node_idx | 0;
    var $node_idx1_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $node_idx + 4 | 0;
    var $node_idx1_val$1 = HEAP32[$st$0$1 >> 2];
    var $26 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($11, $node_idx1_val$0, $node_idx1_val$1);
    if ($26) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 11:
    var $destruct_1 = HEAP32[$destruct_0 + 24 >> 2];
    var $arg_1 = $arg_0;
    __label__ = 17;
    break;
   case 12:
    if ($or_cond) {
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $32 = __ZN2js13ASTSerializer10identifierEP11JSParseNodePN2JS5ValueE($this, $arg_0, $node);
    if ($32) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 14:
    var $st$0$0 = $node_idx | 0;
    var $node_idx_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $node_idx + 4 | 0;
    var $node_idx_val$1 = HEAP32[$st$0$1 >> 2];
    var $34 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($11, $node_idx_val$0, $node_idx_val$1);
    if ($34) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 15:
    var $destruct_1 = $destruct_0;
    var $arg_1 = HEAP32[$arg_0 + 24 >> 2];
    __label__ = 17;
    break;
   case 16:
    var $40 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($40, 4, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 17:
    var $arg_1;
    var $destruct_1;
    var $destruct_0 = $destruct_1;
    var $arg_0 = $arg_1;
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 6;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer12functionArgsEP11JSParseNodeS2_S2_S2_RNS_15AutoValueVectorE["X"] = 1;

function __ZN2js13ASTSerializer12functionBodyEP11JSParseNodePNS_8TokenPosEPN2JS5ValueE($this, $pn, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 100;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $elts = __stackBase__;
    var $child = __stackBase__ + 92;
    var $2 = HEAP32[$this >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($elts, $2);
    var $3 = $elts | 0;
    var $child_idx = $child | 0;
    var $next_0 = $pn;
    __label__ = 2;
    break;
   case 2:
    var $next_0;
    if (($next_0 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZN2js13ASTSerializer13sourceElementEP11JSParseNodePN2JS5ValueE($this, $next_0, $child);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 4:
    var $child_idx_val$0 = HEAP32[$child_idx >> 2];
    var $child_idx_val$1 = HEAP32[$child_idx + 4 >> 2];
    var $9 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($3, $child_idx_val$0, $child_idx_val$1);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $next_0 = HEAP32[$next_0 + 24 >> 2];
    __label__ = 2;
    break;
   case 6:
    var $14 = $this + 8 | 0;
    var $15 = __ZN2js11NodeBuilder14blockStatementERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($14, $elts, $pos, $dst);
    var $_0 = $15;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($elts);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13reflect_parseP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 1660;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $filenamep = __stackBase__;
    var $lineno = __stackBase__ + 8;
    var $arg = __stackBase__ + 12;
    var $prop = __stackBase__ + 20;
    var $1 = __stackBase__ + 28;
    var $2 = __stackBase__ + 36;
    var $3 = __stackBase__ + 44;
    var $4 = __stackBase__ + 52;
    var $serialize = __stackBase__ + 60;
    var $parser = __stackBase__ + 660;
    var $val = __stackBase__ + 1652;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 4, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str2403393 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str225518 | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str226519 | 0, tempInt));
    var $_2 = 0;
    __label__ = 34;
    break;
   case 3:
    var $8 = $cx;
    var $_idx8 = $vp + 16 | 0;
    var $st$2$0 = $_idx8 | 0;
    var $_idx8_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx8 + 4 | 0;
    var $_idx8_val$1 = HEAP32[$st$2$1 >> 2];
    var $9 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($8, $_idx8_val$0, $_idx8_val$1);
    if (($9 | 0) == 0) {
      var $_2 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js22AutoReleaseNullablePtrC1EP9JSContextPv($filenamep, $cx);
    HEAP32[$lineno >> 2] = 1;
    if ($argc >>> 0 > 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $14 = $vp + 24 | 0;
    var $st$1$0 = $14 | 0;
    var $15$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $14 + 4 | 0;
    var $15$1 = HEAPU32[$st$1$1 >> 2];
    var $16 = $arg | 0;
    var $st$6$0 = $16 | 0;
    HEAP32[$st$6$0 >> 2] = $15$0;
    var $st$6$1 = $16 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $15$1;
    var $arg_idx9_val$1 = $15$1;
    var $arg_idx9_val$0 = $15$0;
    __label__ = 7;
    break;
   case 6:
    __ZN2JSL14UndefinedValueEv3403($arg);
    var $arg_idx6_phi_trans_insert = $arg | 0;
    var $st$2$0 = $arg_idx6_phi_trans_insert | 0;
    var $st$2$1 = $arg_idx6_phi_trans_insert + 4 | 0;
    var $arg_idx9_val$1 = HEAP32[$st$2$1 >> 2];
    var $arg_idx9_val$0 = HEAP32[$st$2$0 >> 2];
    __label__ = 7;
    break;
   case 7:
    var $arg_idx9_val$0;
    var $arg_idx9_val$1;
    var $19 = __ZNK2JS5Value17isNullOrUndefinedEv($arg_idx9_val$0, $arg_idx9_val$1);
    if ($19) {
      var $builder_0 = 0;
      var $loc_0 = 1;
      var $filename_2 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = __ZNK2JS5Value8isObjectEv($arg_idx9_val$0, $arg_idx9_val$1);
    if ($21) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $$emscripten$temp$0 = STRING_TABLE.__str2433396 | 0;
    var $23 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, 222, 1, $arg_idx9_val$0, $arg_idx9_val$1, 0, $$emscripten$temp$0);
    var $_1 = 0;
    __label__ = 33;
    break;
   case 10:
    var $25 = __ZNK2JS5Value8toObjectEv($arg_idx9_val$0, $arg_idx9_val$1);
    var $26 = $cx + 52 | 0;
    var $30 = HEAP32[HEAP32[$26 >> 2] + 210368 >> 2] | 0;
    var $31 = __ZL12ATOM_TO_JSIDP6JSAtom3421($30);
    __ZN2JSL12BooleanValueEb3401($1, 1);
    var $32 = $cx;
    var $33 = $25;
    var $34 = __ZN2js18GetPropertyDefaultEP9JSContextP8JSObjectiRKN2JS5ValueEPS5_($32, $33, $31, $1, $prop);
    if (($34 | 0) == 0) {
      var $_1 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $37 = __Z17js_ValueToBooleanRKN2JS5ValueE($prop);
    var $38 = ($37 | 0) != 0;
    var $39 = $38 & 1;
    if ($38) {
      __label__ = 12;
      break;
    } else {
      var $filename_1 = 0;
      __label__ = 20;
      break;
    }
   case 12:
    var $44 = HEAP32[HEAP32[$26 >> 2] + 210300 >> 2] | 0;
    var $45 = __ZL12ATOM_TO_JSIDP6JSAtom3421($44);
    __ZN2JSL9NullValueEv3400($2);
    var $46 = __ZN2js18GetPropertyDefaultEP9JSContextP8JSObjectiRKN2JS5ValueEPS5_($32, $33, $45, $2, $prop);
    if (($46 | 0) == 0) {
      var $_1 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $prop_idx5 = $prop | 0;
    var $st$1$0 = $prop_idx5 | 0;
    var $prop_idx5_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $prop_idx5 + 4 | 0;
    var $prop_idx5_val$1 = HEAP32[$st$1$1 >> 2];
    var $49 = __ZNK2JS5Value17isNullOrUndefinedEv($prop_idx5_val$0, $prop_idx5_val$1);
    if ($49) {
      var $filename_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $51 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($8, $prop_idx5_val$0, $prop_idx5_val$1);
    if (($51 | 0) == 0) {
      var $_1 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $_idx3_val = HEAP32[$51 >> 2];
    var $54 = __ZN8JSString8getCharsEP9JSContext($51, $cx);
    if (($54 | 0) == 0) {
      var $_1 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $57 = __ZNK8JSString6lengthEv($_idx3_val);
    var $58 = __ZN2js13DeflateStringEP9JSContextPKtj($8, $54, $57);
    if (($58 | 0) == 0) {
      var $_1 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    __ZN2js22AutoReleaseNullablePtr5resetEPv($filenamep, $58);
    var $filename_0 = $58;
    __label__ = 18;
    break;
   case 18:
    var $filename_0;
    var $65 = HEAP32[HEAP32[$26 >> 2] + 210372 >> 2] | 0;
    var $66 = __ZL12ATOM_TO_JSIDP6JSAtom3421($65);
    __ZN2JSL10Int32ValueEi3422($3);
    var $67 = __ZN2js18GetPropertyDefaultEP9JSContextP8JSObjectiRKN2JS5ValueEPS5_($32, $33, $66, $3, $prop);
    if (($67 | 0) == 0) {
      var $_1 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $70 = __ZN2js17ValueToECMAUint32EP9JSContextRKN2JS5ValueEPj($cx, $prop, $lineno);
    if ($70) {
      var $filename_1 = $filename_0;
      __label__ = 20;
      break;
    } else {
      var $_1 = 0;
      __label__ = 33;
      break;
    }
   case 20:
    var $filename_1;
    var $75 = HEAP32[HEAP32[$26 >> 2] + 210384 >> 2] | 0;
    var $76 = __ZL12ATOM_TO_JSIDP6JSAtom3421($75);
    __ZN2JSL9NullValueEv3400($4);
    var $77 = __ZN2js18GetPropertyDefaultEP9JSContextP8JSObjectiRKN2JS5ValueEPS5_($32, $33, $76, $4, $prop);
    if (($77 | 0) == 0) {
      var $_1 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $prop_idx4 = $prop | 0;
    var $st$1$0 = $prop_idx4 | 0;
    var $prop_idx4_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $prop_idx4 + 4 | 0;
    var $prop_idx4_val$1 = HEAP32[$st$1$1 >> 2];
    var $80 = __ZNK2JS5Value17isNullOrUndefinedEv($prop_idx4_val$0, $prop_idx4_val$1);
    if ($80) {
      var $builder_0 = 0;
      var $loc_0 = $39;
      var $filename_2 = $filename_1;
      __label__ = 25;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $82 = __ZNK2JS5Value8isObjectEv($prop_idx4_val$0, $prop_idx4_val$1);
    if ($82) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $$emscripten$temp$1 = STRING_TABLE.__str2433396 | 0;
    var $84 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, 222, 1, $prop_idx4_val$0, $prop_idx4_val$1, 0, $$emscripten$temp$1);
    var $_1 = 0;
    __label__ = 33;
    break;
   case 24:
    var $86 = __ZNK2JS5Value8toObjectEv($prop_idx4_val$0, $prop_idx4_val$1);
    var $builder_0 = $86;
    var $loc_0 = $39;
    var $filename_2 = $filename_1;
    __label__ = 25;
    break;
   case 25:
    var $filename_2;
    var $loc_0;
    var $builder_0;
    var $88 = HEAP32[$lineno >> 2];
    __ZN2js13ASTSerializerC1EP9JSContextbPKcj($serialize, $cx, $loc_0 << 24 >> 24 != 0, $filename_2, $88);
    var $89 = __ZN2js13ASTSerializer4initEP8JSObject($serialize, $builder_0);
    if ($89) {
      __label__ = 26;
      break;
    } else {
      var $_1 = 0;
      __label__ = 33;
      break;
    }
   case 26:
    var $_idx_val = HEAP32[$9 >> 2];
    var $91 = __ZN8JSString8getCharsEP9JSContext($9, $cx);
    if (($91 | 0) == 0) {
      var $_1 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $94 = __ZNK8JSString6lengthEv($_idx_val);
    __ZN2js6ParserC2EP9JSContextP12JSPrincipalsPNS_10StackFrameEb($parser, $cx, 0, 0, 0);
    var $95 = __ZNK9JSContext11findVersionEv($cx);
    var $96 = __ZN2js6Parser4initEPKtjPKcj9JSVersion($parser, $91, $94, $filename_2, $88, $95);
    if ($96) {
      __label__ = 28;
      break;
    } else {
      var $_0 = 0;
      __label__ = 32;
      break;
    }
   case 28:
    var $98 = __ZN2js6Parser5parseEP8JSObject($parser, 0);
    if (($98 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $101 = __ZN2js13ASTSerializer7programEP11JSParseNodePN2JS5ValueE($serialize, $98, $val);
    if ($101) {
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $$emscripten$temp$2 = _JSVAL_NULL | 0;
    var $st$1$0 = $$emscripten$temp$2 | 0;
    var $103$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$2 + 4 | 0;
    var $103$1 = HEAP32[$st$1$1 >> 2];
    var $104 = $vp | 0;
    var $st$6$0 = $104 | 0;
    HEAP32[$st$6$0 >> 2] = $103$0;
    var $st$6$1 = $104 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $103$1;
    var $_0 = 0;
    __label__ = 32;
    break;
   case 31:
    var $106 = $val | 0;
    var $st$1$0 = $106 | 0;
    var $107$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $106 + 4 | 0;
    var $107$1 = HEAP32[$st$1$1 >> 2];
    var $108 = $vp | 0;
    var $st$6$0 = $108 | 0;
    HEAP32[$st$6$0 >> 2] = $107$0;
    var $st$6$1 = $108 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $107$1;
    var $_0 = 1;
    __label__ = 32;
    break;
   case 32:
    var $_0;
    __ZN2js6ParserD2Ev($parser);
    var $_1 = $_0;
    __label__ = 33;
    break;
   case 33:
    var $_1;
    var $filenamep_idx_val = HEAP32[$filenamep + 4 >> 2];
    __ZN2js22AutoReleaseNullablePtrD1Ev($filenamep_idx_val);
    var $_2 = $_1;
    __label__ = 34;
    break;
   case 34:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13reflect_parseP9JSContextjPN2JS5ValueE["X"] = 1;

function _JS_InitReflect($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3397($cx, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    var $6 = $cx;
    __ZN8JSObject16setSingletonTypeEP9JSContext($5, $6);
    _OBJECT_TO_JSVAL3405($1, $2);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $$emscripten$temp$0 = STRING_TABLE.__str2393392 | 0;
    var $7 = _JS_DefineProperty($cx, $obj, $$emscripten$temp$0, $_idx_val$0, $_idx_val$1, 10, 12, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = _JS_DefineFunctions($cx, $2, __ZL14static_methods3391 | 0);
    var $_ = ($10 | 0) == 0 ? 0 : $2;
    var $_0 = $_;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _OBJECT_TO_JSVAL3405($agg_result, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL_IMPL3420($1, $obj);
    var $_0 = $1 | 0;
    var $_0_val$0 = HEAP32[$_0 >> 2];
    var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
    __ZL13IMPL_TO_JSVAL12jsval_layout3419($agg_result, $_0_val$0, $_0_val$1);
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $6 = $agg_result | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3409($cx, $parent, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = 0;
    var $2 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_3410($cx, $parent, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    var $4 = HEAP32[$1 >> 2];
    var $5 = ($4 | 0) == 0;
    if ($5) {
      var $9 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($4, $cx, 0, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      var $9 = $7;
      __label__ = 4;
      break;
    }
   case 4:
    var $9;
    var $10 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_not = ($parent | 0) == 0 ^ 1;
    var $parent_mux = $_not ? $parent : 0;
    if ($_not | $5) {
      var $17 = $parent_mux;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx_val = HEAP32[$4 + 20 >> 2];
    var $15 = __ZNK8JSObject9getParentEv($_idx_val);
    var $17 = $15;
    __label__ = 7;
    break;
   case 7:
    var $17;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($10, __ZN2js11ObjectClassE, $9, $17, 0, (__ZN2js11ObjectClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $_idx1_val = HEAP32[__ZN2js11ObjectClassE + 4 >> 2];
    var $18 = __ZNK2js5Class8isNativeEv($_idx1_val);
    if ($18) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $20 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE3413($cx, $10, $9, $kind);
    if ($20) {
      var $_0 = $10;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_0 = 0;
    __label__ = 11;
    break;
   case 10:
    __ZN8JSObject21setSharedNonNativeMapEv($10);
    var $_0 = $10;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_3410($cx, $parent, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL16GetClassProtoKeyEPNS_5ClassE3418();
    var $2 = $cx;
    var $3 = $parent;
    var $4 = $proto;
    var $5 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, $1, $4, __ZN2js11ObjectClassE);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$proto >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, 1, $4, 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE3413($cx, $obj, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 8 & 255;
    var $obj_idx_val = HEAP32[$obj + 28 >> 2];
    var $4 = __ZNK8JSObject8numSlotsEv($obj_idx_val);
    if ($3 >>> 0 > $4 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $obj;
    var $8 = $cx;
    var $9 = __ZN8JSObject10allocSlotsEP9JSContextj($7, $8, $3);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $11 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($type, __ZN2js11ObjectClassE);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($type, $cx, __ZN2js11ObjectClassE, $kind);
    var $empty_0 = $13;
    __label__ = 6;
    break;
   case 5:
    var $15 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, __ZN2js11ObjectClassE);
    var $empty_0 = $15;
    __label__ = 6;
    break;
   case 6:
    var $empty_0;
    if (($empty_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($obj, $empty_0 | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14JSID_FROM_BITSj3426($bits) {
  return $bits;
}

function _OBJECT_TO_JSVAL_IMPL3420($agg_result, $obj) {
  HEAP32[$agg_result + 4 >> 2] = -121;
  HEAP32[$agg_result >> 2] = $obj;
  return;
}

function __ZN2js11NodeBuilderC2EP9JSContextbPKc($this, $c, $l, $s) {
  HEAP32[$this >> 2] = $c;
  HEAP8[$this + 4 | 0] = $l & 1;
  HEAP32[$this + 8 >> 2] = $s;
  return;
}

function __ZN2js22AutoReleaseNullablePtrC2EP9JSContextPv($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6RegExp6increfEP9JSContext($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] + 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js22AutoReleaseNullablePtrC1EP9JSContextPv($this, $cx) {
  __ZN2js22AutoReleaseNullablePtrC2EP9JSContextPv($this, $cx);
  return;
}

function __ZL12ATOM_TO_JSIDP6JSAtom3421($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj3426($1);
  return $2;
}

function __ZN2js22AutoReleaseNullablePtr5resetEPv($this, $ptr2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN9JSContext5free_EPv($2);
    __label__ = 3;
    break;
   case 3:
    HEAP32[$1 >> 2] = $ptr2;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL10Int32ValueEi3422($agg_result) {
  __ZN2JS5Value8setInt32Ei($agg_result, 1);
  return;
}

function __ZN2js13ASTSerializerC1EP9JSContextbPKcj($this, $c, $l, $src, $ln) {
  __ZN2js13ASTSerializerC2EP9JSContextbPKcj($this, $c, $l, $src, $ln);
  return;
}

function __ZN2js13ASTSerializer4initEP8JSObject($this, $userobj) {
  var $1 = $this + 8 | 0;
  var $2 = __ZN2js11NodeBuilder4initEP8JSObject($1, $userobj);
  return $2;
}

function __ZN2js22AutoReleaseNullablePtrD1Ev($this_0_1_val) {
  __ZN2js22AutoReleaseNullablePtrD2Ev($this_0_1_val);
  return;
}

function __ZN2js22AutoReleaseNullablePtrD2Ev($this_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_1_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN9JSContext5free_EPv($this_0_1_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder4initEP8JSObject($this, $userobj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $funv = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $3 = HEAP32[$this + 8 >> 2];
    var $5 = $this + 16 | 0;
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this >> 2];
    var $7 = __ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE($this_idx_val, $3, $5);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 3:
    __ZN2JS5Value7setNullEv($5);
    __label__ = 4;
    break;
   case 4:
    var $11 = $this + 576 | 0;
    if (($userobj | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    __ZN2JS5Value7setNullEv($11);
    var $i_02 = 0;
    __label__ = 6;
    break;
   case 6:
    var $i_02;
    var $14 = $this + 24 + ($i_02 << 3) | 0;
    __ZN2JS5Value7setNullEv($14);
    var $15 = $i_02 + 1 | 0;
    if (($15 | 0) == 69) {
      var $_0 = 1;
      __label__ = 18;
      break;
    } else {
      var $i_02 = $15;
      __label__ = 6;
      break;
    }
   case 7:
    __ZN2JS5Value9setObjectER8JSObject($11, $userobj);
    var $17 = $this | 0;
    var $18 = $userobj;
    var $19 = $funv | 0;
    var $i1_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $i1_0;
    if ($i1_0 >>> 0 < 69) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 1;
      __label__ = 18;
      break;
    }
   case 9:
    var $24 = HEAPU32[__ZN2js13callbackNamesE + ($i1_0 << 2) >> 2];
    var $25 = HEAP32[$17 >> 2];
    var $26 = _strlen($24);
    var $27 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($25, $24, $26, 0);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $30 = HEAP32[$17 >> 2];
    var $31 = __ZL12ATOM_TO_JSIDP6JSAtom3421($27);
    __ZN2JSL9NullValueEv3400($1);
    var $32 = $30;
    var $33 = __ZN2js18GetPropertyDefaultEP9JSContextP8JSObjectiRKN2JS5ValueEPS5_($32, $18, $31, $1, $funv);
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $funv_idx2_val$0 = HEAPU32[$19 >> 2];
    var $funv_idx2_val$1 = HEAPU32[$19 + 4 >> 2];
    var $36 = __ZNK2JS5Value17isNullOrUndefinedEv($funv_idx2_val$0, $funv_idx2_val$1);
    if ($36) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $38 = $this + 24 + ($i1_0 << 3) | 0;
    __ZN2JS5Value7setNullEv($38);
    __label__ = 17;
    break;
   case 13:
    var $40 = __ZNK2JS5Value8isObjectEv($funv_idx2_val$0, $funv_idx2_val$1);
    if ($40) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $42 = __ZNK2JS5Value8toObjectEv($funv_idx2_val$0, $funv_idx2_val$1);
    var $_idx_val = HEAP32[$42 + 4 >> 2];
    var $43 = __ZNK8JSObject10isFunctionEv($_idx_val);
    if ($43) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $45 = HEAP32[$17 >> 2];
    var $46 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($45, 0, 22, 1, $funv_idx2_val$0, $funv_idx2_val$1, 0, 0);
    var $_0 = 0;
    __label__ = 18;
    break;
   case 16:
    var $48 = $this + 24 + ($i1_0 << 3) | 0;
    HEAP32[$48 >> 2] = $funv_idx2_val$0;
    HEAP32[$48 + 4 >> 2] = $funv_idx2_val$1;
    __label__ = 17;
    break;
   case 17:
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 8;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder4initEP8JSObject["X"] = 1;

function __ZN2js13ASTSerializerC2EP9JSContextbPKcj($this, $c, $l, $src, $ln) {
  HEAP32[$this >> 2] = $c;
  var $2 = $this + 8 | 0;
  __ZN2js11NodeBuilderC1EP9JSContextbPKc($2, $c, $l, $src);
  HEAP32[$this + 592 >> 2] = $ln;
  return;
}

function __ZN2js11NodeBuilderC1EP9JSContextbPKc($this, $c, $l, $s) {
  __ZN2js11NodeBuilderC2EP9JSContextbPKc($this, $c, $l, $s);
  return;
}

function __ZN2JSL11StringValueEP8JSString3435($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2js11NodeBuilder9setResultEP8JSObjectPN2JS5ValueE($obj, $dst) {
  __ZN2JS5Value9setObjectER8JSObject($dst, $obj);
  return;
}

function __ZL13resc_finalizeP9JSContextP8JSObject($cx, $obj) {
  var $_idx_val = HEAP32[$obj + 24 >> 2];
  var $2 = __ZNK8JSObject10getPrivateEv($_idx_val);
  var $3 = $2;
  __ZN9JSContext7delete_IN2js13RegExpStaticsEEEvPT_($3);
  return;
}

function __ZL10resc_traceP8JSTracerP8JSObject($trc, $obj) {
  var $_idx_val = HEAP32[$obj + 24 >> 2];
  var $2 = __ZNK8JSObject10getPrivateEv($_idx_val);
  var $3 = $2;
  __ZNK2js13RegExpStatics4markEP8JSTracer($3, $trc);
  return;
}

function __Z20js_CloneRegExpObjectP9JSContextP8JSObjectS2_($cx, $obj, $proto) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $clone1 = __stackBase__;
    var $_idx_val = HEAP32[$proto + 20 >> 2];
    var $2 = __ZNK8JSObject9getParentEv($_idx_val);
    var $3 = $2;
    var $4 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_3476($cx, $proto, $3);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $cx;
    var $8 = $4;
    var $9 = __ZN9JSContext13regExpStaticsEv($7);
    var $_idx1_val = HEAP32[$obj + 24 >> 2];
    var $11 = __ZN2js6RegExp11extractFromEP8JSObject($_idx1_val);
    var $12 = __ZNK2js6RegExp8getFlagsEv($11);
    var $13 = HEAP32[$12 >> 2];
    var $_idx4_val = HEAP32[$9 + 100 >> 2];
    var $14 = __ZNK2js13RegExpStatics8getFlagsEv($_idx4_val);
    if (($14 & $13 | 0) == ($14 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx2_val = HEAP32[$11 + 4 >> 2];
    var $18 = __ZNK2js6RegExp9getSourceEv($_idx2_val);
    var $19 = $18 | 0;
    var $20 = $14 | $13;
    __ZN2js6RegExp6createEP9JSContextP8JSStringjPNS_11TokenStreamE($clone1, $7, $19, $20);
    var $clone1_idx_val = HEAP32[$clone1 >> 2];
    var $21 = __ZNK2js15AlreadyIncRefedINS_6RegExpEEcvPPPPPS1_Ev($clone1_idx_val);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $24 = __ZNK2js15AlreadyIncRefedINS_6RegExpEE3getEv($clone1_idx_val);
    var $re_0 = $24;
    __label__ = 6;
    break;
   case 5:
    __ZN2js6RegExp6increfEP9JSContext($11);
    var $re_0 = $11;
    __label__ = 6;
    break;
   case 6:
    var $re_0;
    var $27 = __ZN8JSObject10initRegExpEP9JSContextPN2js6RegExpE($8, $7, $re_0);
    var $_ = $27 ? $4 : 0;
    var $_0 = $_;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_3476($cx, $proto, $parent) {
  var $3 = HEAPU32[__ZN2js11RegExpClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb3527($3);
  var $5 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE3529($cx, $proto, $parent, $4);
  return $5;
}

function __ZN2js6RegExp15reportPCREErrorEP9JSContexti($cx, $error) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($error | 0) == -2) {
      __label__ = 2;
      break;
    } else if (($error | 0) == 0 || ($error | 0) == 1) {
      __label__ = 3;
      break;
    } else if (($error | 0) == 2) {
      __label__ = 4;
      break;
    } else if (($error | 0) == 3) {
      __label__ = 5;
      break;
    } else if (($error | 0) == 4) {
      __label__ = 6;
      break;
    } else if (($error | 0) == 5) {
      __label__ = 7;
      break;
    } else if (($error | 0) == 6) {
      __label__ = 8;
      break;
    } else if (($error | 0) == 7) {
      __label__ = 9;
      break;
    } else if (($error | 0) == 8) {
      __label__ = 10;
      break;
    } else if (($error | 0) == 9) {
      __label__ = 11;
      break;
    } else if (($error | 0) == 10) {
      __label__ = 12;
      break;
    } else if (($error | 0) == 11) {
      __label__ = 13;
      break;
    } else if (($error | 0) == 12) {
      __label__ = 14;
      break;
    } else if (($error | 0) == 13) {
      __label__ = 15;
      break;
    } else if (($error | 0) == 14) {
      __label__ = 16;
      break;
    } else if (($error | 0) == 15) {
      __label__ = 17;
      break;
    } else if (($error | 0) == 16) {
      __label__ = 18;
      break;
    } else if (($error | 0) == 17) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 2:
    var $2 = $cx;
    _JS_ReportErrorFlagsAndNumberUC($2, 201, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 3:
    var $4 = $cx;
    _JS_ReportErrorFlagsAndNumberUC($4, 56, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 4:
    var $6 = $cx;
    _JS_ReportErrorFlagsAndNumberUC($6, 56, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 5:
    var $8 = $cx;
    _JS_ReportErrorFlagsAndNumberUC($8, 201, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 6:
    var $10 = $cx;
    _JS_ReportErrorFlagsAndNumberUC($10, 46, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 7:
    var $12 = $cx;
    _JS_ReportErrorFlagsAndNumberUC($12, 46, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 8:
    var $14 = $cx;
    _JS_ReportErrorFlagsAndNumberUC($14, 57, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 9:
    var $16 = $cx;
    _JS_ReportErrorFlagsAndNumberUC($16, 201, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 10:
    var $18 = $cx;
    _JS_ReportErrorFlagsAndNumberUC($18, 57, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 11:
    var $20 = $cx;
    _JS_ReportErrorFlagsAndNumberUC($20, 46, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 12:
    var $22 = $cx;
    _JS_ReportErrorFlagsAndNumberUC($22, 62, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 13:
    var $24 = $cx;
    _JS_ReportErrorFlagsAndNumberUC($24, 201, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 14:
    var $26 = $cx;
    _JS_ReportErrorFlagsAndNumberUC($26, 62, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 15:
    var $28 = $cx;
    _JS_ReportErrorFlagsAndNumberUC($28, 201, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 16:
    var $30 = $cx;
    _JS_ReportErrorFlagsAndNumberUC($30, 54, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 17:
    var $32 = $cx;
    _JS_ReportErrorFlagsAndNumberUC($32, 149, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 18:
    var $34 = $cx;
    _JS_ReportErrorFlagsAndNumberUC($34, 201, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 19:
    var $36 = $cx;
    _JS_ReportErrorFlagsAndNumberUC($36, 201, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 20:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6RegExp15reportPCREErrorEP9JSContexti["X"] = 1;

function __ZN2js6RegExp10parseFlagsEP9JSContextP8JSStringPj($cx, $flagStr, $flagsOut) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $charBuf = __stackBase__;
    var $flagStr_idx_val = HEAP32[$flagStr >> 2];
    var $1 = __ZNK8JSString6lengthEv($flagStr_idx_val);
    var $2 = $cx;
    var $3 = __ZN8JSString8getCharsEP9JSContext($flagStr, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$flagsOut >> 2] = 0;
    var $i_0 = 0;
    var $7 = 0;
    __label__ = 3;
    break;
   case 3:
    var $7;
    var $i_0;
    if ($i_0 >>> 0 < $1 >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 15;
      break;
    }
   case 4:
    var $11 = HEAPU16[$3 + ($i_0 << 1) >> 1];
    var $12 = $11 & 65535;
    if (($12 | 0) == 105) {
      __label__ = 5;
      break;
    } else if (($12 | 0) == 103) {
      __label__ = 7;
      break;
    } else if (($12 | 0) == 109) {
      __label__ = 9;
      break;
    } else if (($12 | 0) == 121) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 5:
    if (($7 & 1 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 6:
    var $17 = $7 | 1;
    HEAP32[$flagsOut >> 2] = $17;
    var $39 = $17;
    __label__ = 14;
    break;
   case 7:
    if (($7 & 2 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $22 = $7 | 2;
    HEAP32[$flagsOut >> 2] = $22;
    var $39 = $22;
    __label__ = 14;
    break;
   case 9:
    if (($7 & 4 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 10:
    var $27 = $7 | 4;
    HEAP32[$flagsOut >> 2] = $27;
    var $39 = $27;
    __label__ = 14;
    break;
   case 11:
    if (($7 & 8 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $32 = $7 | 8;
    HEAP32[$flagsOut >> 2] = $32;
    var $39 = $32;
    __label__ = 14;
    break;
   case 13:
    var $35 = $charBuf | 0;
    HEAP8[$35] = $11 & 255;
    HEAP8[$charBuf + 1 | 0] = 0;
    var $37 = _JS_ReportErrorFlagsAndNumber($2, 0, 58, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $35, tempInt));
    var $_0 = 0;
    __label__ = 15;
    break;
   case 14:
    var $39;
    var $i_0 = $i_0 + 1 | 0;
    var $7 = $39;
    __label__ = 3;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6RegExp10parseFlagsEP9JSContextP8JSStringPj["X"] = 1;

function __ZN2js6RegExp13createFlaggedEP9JSContextP8JSStringS4_PNS_11TokenStreamE($agg_result, $cx, $str, $opt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $flags = __stackBase__;
    if (($opt | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $cx;
    __ZN2js6RegExp6createEP9JSContextP8JSStringjPNS_11TokenStreamE($agg_result, $3, $str, 0);
    __label__ = 6;
    break;
   case 3:
    HEAP32[$flags >> 2] = 0;
    var $5 = __ZN2js6RegExp10parseFlagsEP9JSContextP8JSStringPj($cx, $opt, $flags);
    if ($5) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js15AlreadyIncRefedINS_6RegExpEEC1EPS1_($agg_result, 0);
    __label__ = 6;
    break;
   case 5:
    var $8 = HEAP32[$flags >> 2];
    var $9 = $cx;
    __ZN2js6RegExp6createEP9JSContextP8JSStringjPNS_11TokenStreamE($agg_result, $9, $str, $8);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject24assignInitialRegExpShapeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 52 | 0;
    var $5 = HEAP32[HEAP32[$1 >> 2] + 210252 >> 2] | 0;
    var $6 = __ZL12ATOM_TO_JSIDP6JSAtom3481($5);
    var $7 = $this;
    var $8 = $cx;
    var $9 = __ZN8JSObject15addDataPropertyEP9JSContextijj($7, $8, $6, 0, 4);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $15 = HEAP32[HEAP32[$1 >> 2] + 210300 >> 2] | 0;
    var $16 = __ZL12ATOM_TO_JSIDP6JSAtom3481($15);
    var $17 = __ZN8JSObject15addDataPropertyEP9JSContextijj($7, $8, $16, 1, 6);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $23 = HEAP32[HEAP32[$1 >> 2] + 210224 >> 2] | 0;
    var $24 = __ZL12ATOM_TO_JSIDP6JSAtom3481($23);
    var $25 = __ZN8JSObject15addDataPropertyEP9JSContextijj($7, $8, $24, 2, 6);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $31 = HEAP32[HEAP32[$1 >> 2] + 210228 >> 2] | 0;
    var $32 = __ZL12ATOM_TO_JSIDP6JSAtom3481($31);
    var $33 = __ZN8JSObject15addDataPropertyEP9JSContextijj($7, $8, $32, 3, 6);
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $39 = HEAP32[HEAP32[$1 >> 2] + 210268 >> 2] | 0;
    var $40 = __ZL12ATOM_TO_JSIDP6JSAtom3481($39);
    var $41 = __ZN8JSObject15addDataPropertyEP9JSContextijj($7, $8, $40, 4, 6);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $47 = HEAP32[HEAP32[$1 >> 2] + 210308 >> 2] | 0;
    var $48 = __ZL12ATOM_TO_JSIDP6JSAtom3481($47);
    var $49 = __ZN8JSObject15addDataPropertyEP9JSContextijj($7, $8, $48, 5, 6);
    var $_0 = $49;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject24assignInitialRegExpShapeEP9JSContext["X"] = 1;

function __ZL12ATOM_TO_JSIDP6JSAtom3481($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj3545($1);
  return $2;
}

function __ZL19static_input_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $_idx_val = HEAP32[$2 + 96 >> 2];
  __ZNK2js13RegExpStatics18createPendingInputEP9JSContextPN2JS5ValueE($_idx_val, $cx, $vp);
  return 1;
}

function __ZL19static_input_setterP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __ZN9JSContext13regExpStaticsEv($1);
    var $3 = $vp | 0;
    var $4$0 = HEAP32[$3 >> 2];
    var $4$1 = HEAP32[$3 + 4 >> 2];
    var $5 = _JSVAL_IS_STRING3541($4$0, $4$1);
    if (($5 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $st$0$0 = $3 | 0;
    var $8$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $3 + 4 | 0;
    var $8$1 = HEAP32[$st$0$1 >> 2];
    var $9 = _JS_ConvertValue($1, $8$0, $8$1, 3, $vp);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $st$0$0 = $3 | 0;
    var $12$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $3 + 4 | 0;
    var $12$1 = HEAP32[$st$0$1 >> 2];
    var $13 = _JSVAL_TO_STRING3542($12$0, $12$1);
    __ZN2js13RegExpStatics15setPendingInputEP8JSString($2, $13);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23static_multiline_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $cx;
  var $3 = __ZN9JSContext13regExpStaticsEv($2);
  var $_idx_val = HEAP32[$3 + 100 >> 2];
  var $4 = __ZNK2js13RegExpStatics9multilineEv($_idx_val);
  var $5 = $4 & 1;
  _BOOLEAN_TO_JSVAL3539($1, $5);
  var $6 = $1 | 0;
  var $7$0 = HEAP32[$6 >> 2];
  var $7$1 = HEAP32[$6 + 4 >> 2];
  var $8 = $vp | 0;
  HEAP32[$8 >> 2] = $7$0;
  HEAP32[$8 + 4 >> 2] = $7$1;
  STACKTOP = __stackBase__;
  return 1;
}

function __ZL23static_multiline_setterP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __ZN9JSContext13regExpStaticsEv($1);
    var $3 = $vp | 0;
    var $4$0 = HEAP32[$3 >> 2];
    var $4$1 = HEAP32[$3 + 4 >> 2];
    var $5 = _JSVAL_IS_BOOLEAN($4$0, $4$1);
    if (($5 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $st$0$0 = $3 | 0;
    var $8$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $3 + 4 | 0;
    var $8$1 = HEAP32[$st$0$1 >> 2];
    var $9 = _JS_ConvertValue($1, $8$0, $8$1, 5, $vp);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $st$0$0 = $3 | 0;
    var $12$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $3 + 4 | 0;
    var $12$1 = HEAP32[$st$0$1 >> 2];
    var $13 = _JSVAL_TO_BOOLEAN($12$0, $12$1);
    var $14 = ($13 | 0) != 0;
    __ZN2js13RegExpStatics12setMultilineEb($2, $14);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23static_lastMatch_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics15createLastMatchEP9JSContextPN2JS5ValueE($2, $cx, $vp);
  return $3 & 1;
}

function __ZL23static_lastParen_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics15createLastParenEP9JSContextPN2JS5ValueE($2, $cx, $vp);
  return $3 & 1;
}

function __ZL25static_leftContext_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics17createLeftContextEP9JSContextPN2JS5ValueE($2, $cx, $vp);
  return $3 & 1;
}

function __ZL26static_rightContext_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics18createRightContextEP9JSContextPN2JS5ValueE($2, $cx, $vp);
  return $3 & 1;
}

function __ZL20static_paren1_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE($2, $cx, 1, $vp);
  return $3 & 1;
}

function __ZL20static_paren2_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE($2, $cx, 2, $vp);
  return $3 & 1;
}

function __ZL20static_paren3_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE($2, $cx, 3, $vp);
  return $3 & 1;
}

function __ZL20static_paren4_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE($2, $cx, 4, $vp);
  return $3 & 1;
}

function __ZL20static_paren5_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE($2, $cx, 5, $vp);
  return $3 & 1;
}

function __ZL20static_paren6_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE($2, $cx, 6, $vp);
  return $3 & 1;
}

function __ZL20static_paren7_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE($2, $cx, 7, $vp);
  return $3 & 1;
}

function __ZL20static_paren8_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE($2, $cx, 8, $vp);
  return $3 & 1;
}

function __ZL20static_paren9_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE($2, $cx, 9, $vp);
  return $3 & 1;
}

function __Z18js_XDRRegExpObjectP10JSXDRStatePP8JSObject($xdr, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $source = __stackBase__;
    var $flagsword = __stackBase__ + 4;
    var $anchor = __stackBase__ + 8;
    var $re1 = __stackBase__ + 12;
    HEAP32[$source >> 2] = 0;
    HEAP32[$flagsword >> 2] = 0;
    var $1 = $xdr | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[HEAP32[$objp >> 2] + 24 >> 2];
    var $7 = __ZN2js6RegExp11extractFromEP8JSObject($_idx_val);
    if (($7 | 0) == 0) {
      var $_1 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx1_val = HEAP32[$7 + 4 >> 2];
    var $10 = __ZNK2js6RegExp9getSourceEv($_idx1_val);
    var $11 = $10 | 0;
    HEAP32[$source >> 2] = $11;
    var $12 = __ZNK2js6RegExp8getFlagsEv($7);
    var $13 = HEAP32[$12 >> 2];
    HEAP32[$flagsword >> 2] = $13;
    __label__ = 4;
    break;
   case 4:
    var $15 = $xdr;
    var $16 = _JS_XDRString($15, $source);
    if (($16 | 0) == 0) {
      var $_1 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = _JS_XDRUint32($15, $flagsword);
    if (($19 | 0) == 0) {
      var $_1 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$1 >> 2] | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      var $_1 = 1;
      __label__ = 11;
      break;
    }
   case 7:
    var $25 = $xdr + 8 | 0;
    var $26 = HEAP32[$25 >> 2];
    var $27 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3482($26);
    if (($27 | 0) == 0) {
      var $_1 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $30 = $27;
    __ZN8JSObject11clearParentEv($30);
    __ZN8JSObject9clearTypeEv($30);
    var $31 = HEAP32[$source >> 2];
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $31);
    var $33 = HEAP32[$flagsword >> 2];
    var $34 = HEAP32[$25 >> 2];
    __ZN2js6RegExp6createEP9JSContextP8JSStringjPNS_11TokenStreamE($re1, $34, $31, $33);
    var $re1_idx_val = HEAP32[$re1 >> 2];
    var $35 = __ZNK2js15AlreadyIncRefedINS_6RegExpEEcvPPPPPS1_Ev($re1_idx_val);
    if (($35 | 0) == 0) {
      var $_1 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $38 = HEAP32[$25 >> 2];
    var $39 = __ZNK2js15AlreadyIncRefedINS_6RegExpEE3getEv($re1_idx_val);
    var $40 = $38;
    var $41 = __ZN8JSObject10initRegExpEP9JSContextPN2js6RegExpE($30, $40, $39);
    if ($41) {
      __label__ = 10;
      break;
    } else {
      var $_1 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    HEAP32[$objp >> 2] = $27;
    var $_1 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18js_XDRRegExpObjectP10JSXDRStatePP8JSObject["X"] = 1;

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3482($cx) {
  var $3 = HEAPU32[__ZN2js11RegExpClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb3527($3);
  var $5 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE3528($cx, $4);
  return $5;
}

function __ZL15regexp_finalizeP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $2 = __ZN2js6RegExp11extractFromEP8JSObject($_idx_val);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6RegExp6decrefEP9JSContext($2);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE6lengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE5emptyEv($this_0_2_val) {
  return ($this_0_2_val | 0) == 0;
}

function __ZNK7mozilla14AlignedStorageILj256EE4addrEv($this) {
  return $this;
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 1) | 0;
}

function __Z18js_regexp_toStringP9JSContextP8JSObjectPN2JS5ValueE($cx, $obj, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 96;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $sb = __stackBase__ + 8;
    var $2 = __stackBase__ + 88;
    var $_idx8_val = HEAP32[$obj + 4 >> 2];
    var $4 = __ZNK8JSObject8isRegExpEv($_idx8_val);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx;
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($6, $vp, __ZN2js11RegExpClassE);
    var $_1 = 0;
    __label__ = 23;
    break;
   case 3:
    var $_idx2_val = HEAP32[$obj + 24 >> 2];
    var $9 = __ZN2js6RegExp11extractFromEP8JSObject($_idx2_val);
    if (($9 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN2JSL11StringValueEP8JSString3485($1, $16);
    var $17 = $1 | 0;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    var $19 = $vp | 0;
    HEAP32[$19 >> 2] = $18$0;
    HEAP32[$19 + 4 >> 2] = $18$1;
    var $_1 = 1;
    __label__ = 23;
    break;
   case 5:
    var $_idx3_val = HEAP32[$9 + 4 >> 2];
    var $21 = __ZNK2js6RegExp9getSourceEv($_idx3_val);
    var $22 = $sb;
    var $23 = $cx;
    __ZN2js12StringBufferC1EP9JSContext($22, $23);
    var $_idx_val = HEAP32[$21 >> 2];
    var $24 = __ZNK8JSString6lengthEv($_idx_val);
    if (($24 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $27 = $24 + 2 | 0;
    var $28 = __ZN2js12StringBuffer7reserveEj($22, $27);
    if ($28) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 7:
    __ZN2js12StringBuffer16infallibleAppendEt($sb);
    var $_idx1_val = HEAP32[$21 + 4 >> 2];
    var $30 = __ZNK14JSLinearString5charsEv($_idx1_val);
    __ZN2js12StringBuffer16infallibleAppendEPKtj($22, $30, $24);
    __ZN2js12StringBuffer16infallibleAppendEt($sb);
    __label__ = 9;
    break;
   case 8:
    var $32 = __ZN2js12StringBuffer6appendILj7EEEbRAT__Kc($sb, STRING_TABLE.__str223465);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 9:
    var $_idx7 = $9 + 16 | 0;
    var $_idx7_val = HEAP32[$_idx7 >> 2];
    var $34 = __ZNK2js6RegExp6globalEv($_idx7_val);
    if ($34) {
      __label__ = 10;
      break;
    } else {
      var $_idx5_val = $_idx7_val;
      __label__ = 12;
      break;
    }
   case 10:
    var $36 = __ZN2js12StringBuffer6appendEt($22, 103);
    if ($36) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 11:
    var $_idx5_val = HEAP32[$_idx7 >> 2];
    __label__ = 12;
    break;
   case 12:
    var $_idx5_val;
    var $38 = __ZNK2js6RegExp10ignoreCaseEv($_idx5_val);
    if ($38) {
      __label__ = 13;
      break;
    } else {
      var $_idx6_val = $_idx5_val;
      __label__ = 15;
      break;
    }
   case 13:
    var $40 = __ZN2js12StringBuffer6appendEt($22, 105);
    if ($40) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 14:
    var $_idx6_val = HEAP32[$_idx7 >> 2];
    __label__ = 15;
    break;
   case 15:
    var $_idx6_val;
    var $42 = __ZNK2js6RegExp9multilineEv($_idx6_val);
    if ($42) {
      __label__ = 16;
      break;
    } else {
      var $_idx4_val = $_idx6_val;
      __label__ = 18;
      break;
    }
   case 16:
    var $44 = __ZN2js12StringBuffer6appendEt($22, 109);
    if ($44) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 17:
    var $_idx4_val = HEAP32[$_idx7 >> 2];
    __label__ = 18;
    break;
   case 18:
    var $_idx4_val;
    var $46 = __ZNK2js6RegExp6stickyEv($_idx4_val);
    if ($46) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $48 = __ZN2js12StringBuffer6appendEt($22, 121);
    if ($48) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 20:
    var $50 = $sb;
    var $51 = __ZN2js12StringBuffer12finishStringEv($50);
    if (($51 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $54 = $51 | 0;
    __ZN2JSL11StringValueEP8JSString3485($2, $54);
    var $55 = $2 | 0;
    var $56$0 = HEAP32[$55 >> 2];
    var $56$1 = HEAP32[$55 + 4 >> 2];
    var $57 = $vp | 0;
    HEAP32[$57 >> 2] = $56$0;
    HEAP32[$57 + 4 >> 2] = $56$1;
    var $_0 = 1;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    __ZN2js12StringBufferD1Ev($22);
    var $_1 = $_0;
    __label__ = 23;
    break;
   case 23:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18js_regexp_toStringP9JSContextP8JSObjectPN2JS5ValueE["X"] = 1;

function __ZN2JSL11StringValueEP8JSString3485($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2js12StringBuffer16infallibleAppendEt($this) {
  var $1 = $this | 0;
  __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16infallibleAppendERKt($1, 47);
  return;
}

function __ZN2js12StringBuffer6appendILj7EEEbRAT__Kc($this, $array) {
  var $1 = $array | 0;
  var $2 = $array + 6 | 0;
  var $3 = $this;
  var $4 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendIcEEbPKT_S6_($3, $1, $2);
  return $4;
}

function __Z14js_regexp_execP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13ExecuteRegExpP9JSContext8ExecTypejPN2JS5ValueE($cx, 0, $argc, $vp);
  return $1;
}

function __ZL13ExecuteRegExpP9JSContext8ExecTypejPN2JS5ValueE($cx, $execType, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $arc = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 12;
    var $i = __stackBase__ + 20;
    var $3 = __stackBase__ + 28;
    var $lastIndexInt = __stackBase__ + 36;
    var $4 = $vp + 8 | 0;
    var $5 = $cx;
    var $6 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($5, $4);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_1 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx7_val = HEAP32[$6 + 4 >> 2];
    var $10 = __ZNK8JSObject8isRegExpEv($_idx7_val);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($5, $vp, __ZN2js11RegExpClassE);
    var $_1 = 0;
    __label__ = 24;
    break;
   case 4:
    var $_idx2_val = HEAP32[$6 + 24 >> 2];
    var $13 = __ZN2js6RegExp11extractFromEP8JSObject($_idx2_val);
    if (($13 | 0) == 0) {
      var $_1 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js11NeedsIncRefINS_6RegExpEEC1EPS1_($1, $13);
    var $_09_val = HEAP32[$1 >> 2];
    __ZN2js12AutoRefCountINS_6RegExpEEC1EP9JSContextNS_11NeedsIncRefIS1_EE($arc, $cx, $_09_val);
    var $16 = __ZN9JSContext13regExpStaticsEv($5);
    if (($argc | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = $vp + 16 | 0;
    var $20$0 = HEAP32[$19 >> 2];
    var $20$1 = HEAP32[$19 + 4 >> 2];
    var $21 = $2 | 0;
    HEAP32[$21 >> 2] = $20$0;
    HEAP32[$21 + 4 >> 2] = $20$1;
    var $_idx8_val$1 = $20$1;
    var $_idx8_val$0 = $20$0;
    __label__ = 8;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv3491($2);
    var $_idx8_phi_trans_insert = $2 | 0;
    var $_idx8_val$1 = HEAP32[$_idx8_phi_trans_insert + 4 >> 2];
    var $_idx8_val$0 = HEAP32[$_idx8_phi_trans_insert >> 2];
    __label__ = 8;
    break;
   case 8:
    var $_idx8_val$0;
    var $_idx8_val$1;
    var $24 = $cx;
    var $25 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($24, $_idx8_val$0, $_idx8_val$1);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_idx_val = HEAP32[$25 >> 2];
    var $28 = __ZNK8JSString6lengthEv($_idx_val);
    var $29 = __ZNK8JSObject18getRegExpLastIndexEv($7);
    var $30 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd3509($cx, $29, $i);
    if ($30) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 10:
    var $_idx6 = $13 + 16 | 0;
    var $_idx6_val = HEAP32[$_idx6 >> 2];
    var $32 = __ZNK2js6RegExp6globalEv($_idx6_val);
    if ($32) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $34 = __ZNK2js6RegExp6stickyEv($_idx6_val);
    if ($34) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    tempDoubleF64[0] = 0, HEAP32[$i >> 2] = tempDoubleI32[0], HEAP32[$i + 4 >> 2] = tempDoubleI32[1];
    var $38 = 0;
    __label__ = 14;
    break;
   case 13:
    var $_pr = (tempDoubleI32[0] = HEAP32[$i >> 2], tempDoubleI32[1] = HEAP32[$i + 4 >> 2], tempDoubleF64[0]);
    if ($_pr < 0) {
      __label__ = 15;
      break;
    } else {
      var $38 = $_pr;
      __label__ = 14;
      break;
    }
   case 14:
    var $38;
    if ($38 > $28 >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    __ZN8JSObject19zeroRegExpLastIndexEv($6);
    __ZN2JSL9NullValueEv3510($3);
    var $42 = $3 | 0;
    var $st$3$0 = $42 | 0;
    var $43$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $42 + 4 | 0;
    var $43$1 = HEAP32[$st$3$1 >> 2];
    var $44 = $vp | 0;
    HEAP32[$44 >> 2] = $43$0;
    HEAP32[$44 + 4 >> 2] = $43$1;
    var $_0 = 1;
    __label__ = 23;
    break;
   case 16:
    var $46 = $38 >= 0 ? Math.floor($38) : Math.ceil($38);
    HEAP32[$lastIndexInt >> 2] = $46;
    var $47 = ($execType | 0) == 1;
    var $48 = __ZN2js6RegExp7executeEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE($13, $5, $16, $25, $lastIndexInt, $47, $vp);
    if ($48) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 17:
    var $_idx5_val = HEAP32[$_idx6 >> 2];
    var $50 = __ZNK2js6RegExp6globalEv($_idx5_val);
    var $vp_idx_phi_trans_insert = $vp | 0;
    var $st$3$0 = $vp_idx_phi_trans_insert | 0;
    var $vp_idx_val_pre$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $vp_idx_phi_trans_insert + 4 | 0;
    var $vp_idx_val_pre$1 = HEAP32[$st$3$1 >> 2];
    if ($50) {
      var $vp_idx_val$1 = $vp_idx_val_pre$1;
      var $vp_idx_val$0 = $vp_idx_val_pre$0;
      __label__ = 20;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $52 = __ZNK2JS5Value6isNullEv($vp_idx_val_pre$0, $vp_idx_val_pre$1);
    if ($52) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $54 = __ZNK2js6RegExp6stickyEv($_idx5_val);
    if ($54) {
      var $vp_idx_val$1 = $vp_idx_val_pre$1;
      var $vp_idx_val$0 = $vp_idx_val_pre$0;
      __label__ = 20;
      break;
    } else {
      var $_0 = 1;
      __label__ = 23;
      break;
    }
   case 20:
    var $vp_idx_val$0;
    var $vp_idx_val$1;
    var $55 = __ZNK2JS5Value6isNullEv($vp_idx_val$0, $vp_idx_val$1);
    if ($55) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    __ZN8JSObject19zeroRegExpLastIndexEv($6);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 22:
    var $59 = HEAPU32[$lastIndexInt >> 2] >>> 0;
    __ZN8JSObject18setRegExpLastIndexEd($7, $59);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    var $arc_idx_val = HEAP32[$arc + 4 >> 2];
    __ZN2js12AutoRefCountINS_6RegExpEED1Ev($arc_idx_val);
    var $_1 = $_0;
    __label__ = 24;
    break;
   case 24:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13ExecuteRegExpP9JSContext8ExecTypejPN2JS5ValueE["X"] = 1;

function __Z14js_regexp_testP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL13ExecuteRegExpP9JSContext8ExecTypejPN2JS5ValueE($cx, 1, $argc, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $4 = __ZNK2JS5Value6isTrueEv($vp_idx_val$0, $vp_idx_val$1);
    if ($4) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value10setBooleanEb($vp, 0);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15regexp_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __Z18js_regexp_toStringP9JSContextP8JSObjectPN2JS5ValueE($cx, $6, $vp);
    var $_0 = $7;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14regexp_compileP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $7 = __ZNK8JSObject8isRegExpEv($_idx_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($2, $vp, __ZN2js11RegExpClassE);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $10 = $vp + 16 | 0;
    var $11 = __ZL20CompileRegExpAndSwapP9JSContextP8JSObjectjPN2JS5ValueES5_($cx, $4, $argc, $10, $vp);
    var $_0 = $11 & 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18js_InitRegExpClassP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $re = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 12;
    var $4 = __stackBase__ + 16;
    var $5 = __stackBase__ + 20;
    var $6 = __stackBase__ + 24;
    var $7 = $obj;
    var $8 = __ZN8JSObject8asGlobalEv($7);
    var $9 = $cx;
    var $10 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($8, $9, __ZN2js11RegExpClassE);
    var $11 = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = $cx + 52 | 0;
    var $18 = HEAP32[HEAP32[$14 >> 2] + 144136 >> 2] | 0;
    var $19 = $cx;
    __ZN2js6RegExp6createEP9JSContextP8JSStringjPNS_11TokenStreamE($re, $19, $18, 0);
    var $re_idx_val = HEAP32[$re >> 2];
    var $20 = __ZNK2js15AlreadyIncRefedINS_6RegExpEEcvPPPPPS1_Ev($re_idx_val);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $23 = __ZNK2js15AlreadyIncRefedINS_6RegExpEE3getEv($re_idx_val);
    var $24 = $10;
    var $25 = __ZN8JSObject10initRegExpEP9JSContextPN2js6RegExpE($24, $19, $23);
    if ($25) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 4:
    var $27 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($9, $10, 0, __ZL14regexp_methods);
    if ($27) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 5:
    var $32 = HEAP32[HEAP32[$14 >> 2] + 210060 >> 2];
    var $33 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($8, $9, 214, __ZN2js11RegExpClassE, $32, 2);
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $36 = $33 | 0;
    var $37 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($9, $36, $10);
    if ($37) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    var $39 = $33;
    var $40 = _JS_DefineProperties($19, $39, __ZL19regexp_static_props);
    if (($40 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $43 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($24, $19, 0, 0);
    var $44 = $43;
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2js5types4Type10StringTypeEv($1);
    var $_07_val = HEAP32[$1 >> 2];
    __ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcNS0_4TypeE($cx, $44, STRING_TABLE.__str263469 | 0, $_07_val);
    __ZN2js5types4Type11BooleanTypeEv($2);
    var $_06_val = HEAP32[$2 >> 2];
    __ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcNS0_4TypeE($cx, $44, STRING_TABLE.__str86379 | 0, $_06_val);
    __ZN2js5types4Type11BooleanTypeEv($3);
    var $_05_val = HEAP32[$3 >> 2];
    __ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcNS0_4TypeE($cx, $44, STRING_TABLE.__str283471 | 0, $_05_val);
    __ZN2js5types4Type11BooleanTypeEv($4);
    var $_04_val = HEAP32[$4 >> 2];
    __ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcNS0_4TypeE($cx, $44, STRING_TABLE.__str23443 | 0, $_04_val);
    __ZN2js5types4Type11BooleanTypeEv($5);
    var $_03_val = HEAP32[$5 >> 2];
    __ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcNS0_4TypeE($cx, $44, STRING_TABLE.__str293472 | 0, $_03_val);
    __ZN2js5types4Type9Int32TypeEv($6);
    var $_02_val = HEAP32[$6 >> 2];
    __ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcNS0_4TypeE($cx, $44, STRING_TABLE.__str303473 | 0, $_02_val);
    var $47 = $8;
    var $48 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($19, $47, 10, $39, $24);
    var $_ = $48 ? $11 : 0;
    var $_0 = $_;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18js_InitRegExpClassP9JSContextP8JSObject["X"] = 1;

function __ZL16regexp_constructP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 16 | 0;
    var $2 = __ZN2jsL14IsConstructingEPKN2JS5ValueE3500($vp);
    if ($2 | ($argc | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx = $1 | 0;
    var $st$1$0 = $_idx | 0;
    var $_idx_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAP32[$st$1$1 >> 2];
    var $5 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    var $7 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $_idx3_val = HEAP32[$7 + 4 >> 2];
    var $8 = __ZNK8JSObject8isRegExpEv($_idx3_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    if (($argc | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx2 = $vp + 24 | 0;
    var $st$1$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$1$1 >> 2];
    var $12 = __ZNK2JS5Value11isUndefinedEv($_idx2_val$0, $_idx2_val$1);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $14 = $vp | 0;
    var $st$1$0 = $14 | 0;
    HEAP32[$st$1$0 >> 2] = $_idx_val$0;
    var $st$1$1 = $14 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $_idx_val$1;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 7:
    var $16 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3482($cx);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $19 = __ZL20CompileRegExpAndSwapP9JSContextP8JSObjectjPN2JS5ValueES5_($cx, $16, $argc, $1, $vp);
    var $_0 = $19 & 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcNS0_4TypeE($cx, $obj, $name, $type_0) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $_idx_val = HEAP8[$cx + 232 | 0];
    var $3 = __ZN9JSContext20typeInferenceEnabledEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$obj + 12 >> 2];
    var $6 = __ZN2js5types10TypeObject17unknownPropertiesEv($_idx1_val);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $obj;
    __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextPKcNS0_4TypeE($8, $1, $name, $type_0);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11ObjectValueER8JSObject3490($agg_result, $obj) {
  var $1 = $obj;
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $1);
  return;
}

function __ZN2JSL14UndefinedValueEv3491($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2jsL14IsConstructingEPKN2JS5ValueE3500($vp) {
  var $_idx = $vp + 8 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $1 = __ZNK2JS5Value7isMagicEv($_idx_val$0, $_idx_val$1);
  return $1;
}

function __ZL20CompileRegExpAndSwapP9JSContextP8JSObjectjPN2JS5ValueES5_($cx, $obj, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $flags = __stackBase__ + 12;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    var $10 = __ZL19SwapRegExpInternalsP9JSContextP8JSObjectPN2JS5ValueEP8JSStringj($cx, $obj, $rval, $9, 0);
    var $_0 = $10;
    __label__ = 19;
    break;
   case 3:
    var $12 = $argv | 0;
    var $st$1$0 = $12 | 0;
    var $13$0 = HEAPU32[$st$1$0 >> 2];
    var $st$1$1 = $12 + 4 | 0;
    var $13$1 = HEAPU32[$st$1$1 >> 2];
    var $14 = __ZNK2JS5Value8isObjectEv($13$0, $13$1);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 4:
    var $16 = __ZNK2JS5Value8toObjectEv($13$0, $13$1);
    var $_idx5_val = HEAP32[$16 + 4 >> 2];
    var $17 = __ZNK8JSObject8isRegExpEv($_idx5_val);
    if ($17) {
      __label__ = 5;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 5:
    if ($argc >>> 0 > 1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $_idx3 = $argv + 8 | 0;
    var $st$1$0 = $_idx3 | 0;
    var $_idx3_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx3 + 4 | 0;
    var $_idx3_val$1 = HEAP32[$st$1$1 >> 2];
    var $21 = __ZNK2JS5Value11isUndefinedEv($_idx3_val$0, $_idx3_val$1);
    if ($21) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = $cx;
    _JS_ReportErrorNumber($23, 4, 165, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 19;
    break;
   case 8:
    var $_idx4_val = HEAP32[$16 + 24 >> 2];
    var $25 = __ZN2js6RegExp11extractFromEP8JSObject($_idx4_val);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2js6RegExp6increfEP9JSContext($25);
    __ZN2js15AlreadyIncRefedINS_6RegExpEEC1EPS1_($1, $25);
    var $_08_val = HEAP32[$1 >> 2];
    __ZL16SwapObjectRegExpP9JSContextP8JSObjectN2js15AlreadyIncRefedINS3_6RegExpEEE($cx, $obj, $_08_val);
    __ZN2JSL11ObjectValueER8JSObject3490($2, $obj);
    var $28 = $2 | 0;
    var $29$0 = HEAP32[$28 >> 2];
    var $29$1 = HEAP32[$28 + 4 >> 2];
    var $30 = $rval | 0;
    HEAP32[$30 >> 2] = $29$0;
    HEAP32[$30 + 4 >> 2] = $29$1;
    var $_0 = 1;
    __label__ = 19;
    break;
   case 10:
    var $32 = __ZNK2JS5Value11isUndefinedEv($13$0, $13$1);
    if ($32) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $sourceStr_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 13;
    break;
   case 12:
    var $40 = $cx;
    var $41 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($40, $13$0, $13$1);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      var $sourceStr_0 = $41;
      __label__ = 13;
      break;
    }
   case 13:
    var $sourceStr_0;
    HEAP32[$flags >> 2] = 0;
    if ($argc >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 14:
    var $46 = $argv + 8 | 0;
    var $_idx = $46 | 0;
    var $_idx_val$0 = HEAPU32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $47 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($47) {
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $49 = $cx;
    var $50 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($49, $_idx_val$0, $_idx_val$1);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN2JS5Value9setStringEP8JSString($46, $50);
    var $53 = __ZN2js6RegExp10parseFlagsEP9JSContextP8JSStringPj($cx, $50, $flags);
    if ($53) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 17:
    var $55 = __ZL25EscapeNakedForwardSlashesP9JSContextP8JSString($cx, $sourceStr_0);
    if (($55 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $58 = HEAP32[$flags >> 2];
    var $59 = __ZL19SwapRegExpInternalsP9JSContextP8JSObjectPN2JS5ValueEP8JSStringj($cx, $obj, $rval, $55, $58);
    var $_0 = $59;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL20CompileRegExpAndSwapP9JSContextP8JSObjectjPN2JS5ValueES5_["X"] = 1;

function __ZL19SwapRegExpInternalsP9JSContextP8JSObjectPN2JS5ValueEP8JSStringj($cx, $obj, $rval, $str, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $re = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = $cx;
    var $3 = __ZN9JSContext13regExpStaticsEv($2);
    var $_idx_val = HEAP32[$3 + 100 >> 2];
    var $4 = __ZNK2js13RegExpStatics8getFlagsEv($_idx_val);
    var $5 = $4 | $flags;
    __ZN2js6RegExp6createEP9JSContextP8JSStringjPNS_11TokenStreamE($re, $2, $str, $5);
    var $re_idx_val = HEAP32[$re >> 2];
    var $6 = __ZNK2js15AlreadyIncRefedINS_6RegExpEEcvPPPPPS1_Ev($re_idx_val);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZL16SwapObjectRegExpP9JSContextP8JSObjectN2js15AlreadyIncRefedINS3_6RegExpEEE($cx, $obj, $re_idx_val);
    __ZN2JSL11ObjectValueER8JSObject3490($1, $obj);
    var $9 = $1 | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $rval | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16SwapObjectRegExpP9JSContextP8JSObjectN2js15AlreadyIncRefedINS3_6RegExpEEE($cx, $obj, $newRegExp_0) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $3 = __ZN2js6RegExp11extractFromEP8JSObject($_idx_val);
    var $4 = __ZNK2js15AlreadyIncRefedINS_6RegExpEE3getEv($newRegExp_0);
    var $5 = $cx;
    var $6 = __ZN8JSObject10initRegExpEP9JSContextPN2js6RegExpE($1, $5, $4);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6RegExp6decrefEP9JSContext($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL25EscapeNakedForwardSlashesP9JSContextP8JSString($cx, $unescaped) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 280;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $anchor = __stackBase__;
    var $newChars = __stackBase__ + 4;
    var $1 = __stackBase__ + 276;
    var $unescaped_idx_val = HEAP32[$unescaped >> 2];
    var $2 = __ZNK8JSString6lengthEv($unescaped_idx_val);
    var $3 = $cx;
    var $4 = __ZN8JSString8getCharsEP9JSContext($unescaped, $3);
    if (($4 | 0) == 0) {
      var $_1 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $unescaped);
    var $7 = $1;
    __ZN2js15TempAllocPolicyC1EP9JSContext($7, $3);
    var $_01_val = HEAP32[$1 >> 2];
    __ZN2js6VectorItLj128ENS_15TempAllocPolicyEEC1ES1_($newChars, $_01_val);
    var $8 = $4 + ($2 << 1) | 0;
    var $9 = $2 + 1 | 0;
    var $10 = $4;
    var $newChars_idx2 = $newChars + 8 | 0;
    var $it_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $it_0;
    if ($it_0 >>> 0 < $8 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 4:
    if (HEAP16[$it_0 >> 1] << 16 >> 16 == 47) {
      __label__ = 5;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 5:
    if (($it_0 | 0) == ($4 | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (HEAP16[$it_0 - 2 >> 1] << 16 >> 16 == 92) {
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $newChars_idx2_val = HEAP32[$newChars_idx2 >> 2];
    var $22 = __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE6lengthEv($newChars_idx2_val);
    if (($22 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $25 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE7reserveEj($newChars, $9);
    if ($25) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 9:
    var $29 = $it_0 - $10 >> 1;
    __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE16infallibleAppendItEEvPKT_j($newChars, $4, $29);
    __label__ = 10;
    break;
   case 10:
    var $31 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE6appendIcEEbT_($newChars, 92);
    if ($31) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 11:
    var $newChars_idx4_val = HEAP32[$newChars_idx2 >> 2];
    var $32 = __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE5emptyEv($newChars_idx4_val);
    if ($32) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $34 = HEAP16[$it_0 >> 1];
    var $35 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE6appendItEEbT_($newChars, $34);
    if ($35) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 13:
    var $it_0 = $it_0 + 2 | 0;
    __label__ = 3;
    break;
   case 14:
    var $newChars_idx3_val = HEAP32[$newChars_idx2 >> 2];
    var $39 = __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE5emptyEv($newChars_idx3_val);
    if ($39) {
      var $_0 = $unescaped;
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $41 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE6appendIcEEbT_($newChars, 0);
    if ($41) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 16:
    var $43 = __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE6lengthEv($newChars_idx3_val);
    var $44 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE16extractRawBufferEv($newChars);
    var $45 = $cx;
    var $46 = __Z12js_NewStringP9JSContextPtj($45, $44, $43);
    var $47 = $46 | 0;
    if (($46 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $_0 = $47;
      __label__ = 18;
      break;
    }
   case 17:
    var $50 = $44;
    __ZN9JSContext5free_EPv($50);
    var $_0 = $47;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    __ZN2js6VectorItLj128ENS_15TempAllocPolicyEED1Ev($newChars);
    var $_1 = $_0;
    __label__ = 19;
    break;
   case 19:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL25EscapeNakedForwardSlashesP9JSContextP8JSString["X"] = 1;

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEEC1ES1_($this, $ap_01) {
  __ZN2js6VectorItLj128ENS_15TempAllocPolicyEEC2ES1_($this, $ap_01);
  return;
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE7reserveEj($this, $request) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$this + 12 >> 2] >>> 0 < $request >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $request - HEAP32[$this + 8 >> 2] | 0;
    var $8 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE13growStorageByEj($this, $7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE16infallibleAppendItEEvPKT_j($this, $begin, $length) {
  __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE14internalAppendItEEvPKT_j($this, $begin, $length);
  return;
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE6appendIcEEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE14internalAppendIcEEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE6appendItEEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE14internalAppendItEEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE16extractRawBufferEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $this + 8 | 0;
    var $5 = HEAP32[$3 >> 2] << 1;
    var $6 = $this;
    var $7 = __ZN2js15TempAllocPolicy7malloc_Ej($6, $5);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $11 = __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$3 >> 2];
    var $12 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplItLj128ENS_15TempAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_($8, $11, $12);
    HEAP32[$3 >> 2] = 0;
    var $_0 = $8;
    __label__ = 5;
    break;
   case 4:
    var $14 = $this + 4 | 0;
    var $15 = HEAP32[$14 >> 2];
    var $16 = $this + 16 | 0;
    var $17 = __ZN7mozilla14AlignedStorageILj256EE4addrEv($16);
    HEAP32[$14 >> 2] = $17;
    HEAP32[$this + 8 >> 2] = 0;
    HEAP32[$this + 12 >> 2] = 128;
    var $_0 = $15;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorItLj128ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj256EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZNK2js11NeedsIncRefINS_6RegExpEE3getEv($this_0_0_val) {
  return $this_0_0_val;
}

function _JSVAL_TO_BOOLEAN_IMPL3536($l_0$0, $l_0$1) {
  return $l_0$0;
}

function __ZL14JSID_FROM_BITSj3545($bits) {
  return $bits;
}

function _JSVAL_IS_BOOLEAN_IMPL3538($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -125) & 1;
}

function __ZNK2js13RegExpStatics9multilineEv($this_0_3_val) {
  return ($this_0_3_val & 4 | 0) != 0;
}

function _JSVAL_TO_STRING_IMPL3543($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_IS_STRING_IMPL3544($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -123) & 1;
}

function __ZN7mozilla14AlignedStorageILj256EE4addrEv($this) {
  return $this;
}

function __ZL18JSDOUBLE_IS_FINITEd3520($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function __ZL15JSDOUBLE_IS_NaNd3521($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZN2js10VectorImplItLj128ENS_15TempAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP16[$p_01 >> 1];
    HEAP16[$_02 >> 1] = $2;
    var $3 = $p_01 + 2 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 2 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _BOOLEAN_TO_JSVAL_IMPL3507($agg_result, $b) {
  HEAP32[$agg_result + 4 >> 2] = -125;
  HEAP32[$agg_result >> 2] = $b;
  return;
}

function __ZN2js11NeedsIncRefINS_6RegExpEEC2EPS1_($this, $obj) {
  HEAP32[$this >> 2] = $obj;
  return;
}

function __ZN2js2gcL15GetGCObjectKindEjb3527($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13JSVAL_TO_IMPLN2JS5ValueE3537($agg_result, $_0_0_0_val$0, $_0_0_0_val$1) {
  var $agg_result_0 = $agg_result | 0;
  HEAP32[$agg_result_0 >> 2] = $_0_0_0_val$0;
  HEAP32[$agg_result_0 + 4 >> 2] = $_0_0_0_val$1;
  return;
}

function __ZL13IMPL_TO_JSVAL12jsval_layout3540($agg_result, $l_0$0, $l_0$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $l_0$0;
  HEAP32[$1 + 4 >> 2] = $l_0$1;
  return;
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE14internalAppendItEEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $5 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP16[$1 >> 1] = $t;
    var $5 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    HEAP32[$this_idx1 >> 2] = $5 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 1;
    var $7 = $this;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($7, $6);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplItLj128ENS_15TempAllocPolicyELb1EE13moveConstructItEEvPtPKT_S7_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplItLj128ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorItLj128ES1_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 1073741823) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 1073741823) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplItLj128ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorItLj128ES1_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 1;
    var $2 = $v + 4 | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = $v;
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($5, $4, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $v + 12 | 0;
    var $10 = $6;
    HEAP32[$2 >> 2] = $10;
    HEAP32[$9 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplItLj128ENS_15TempAllocPolicyELb1EE13moveConstructItEEvPtPKT_S7_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplItLj128ENS_15TempAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE14internalAppendIcEEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $6 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP16[$1 >> 1] = $t << 24 >> 24;
    var $6 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $6;
    HEAP32[$this_idx1 >> 2] = $6 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE14internalAppendItEEvPKT_j($this, $insBegin, $length) {
  var $this_idx_val = HEAP32[$this + 4 >> 2];
  var $this_idx1 = $this + 8 | 0;
  var $this_idx1_val = HEAP32[$this_idx1 >> 2];
  var $1 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
  var $2 = $insBegin + ($length << 1) | 0;
  __ZN2js10VectorImplItLj128ENS_15TempAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_($1, $insBegin, $2);
  var $4 = HEAP32[$this_idx1 >> 2] + $length | 0;
  HEAP32[$this_idx1 >> 2] = $4;
  return;
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEEC2ES1_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj256EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 128;
  return;
}

function __ZN2js12AutoRefCountINS_6RegExpEEC1EP9JSContextNS_11NeedsIncRefIS1_EE($this, $cx, $aobj_01) {
  __ZN2js12AutoRefCountINS_6RegExpEEC2EP9JSContextNS_11NeedsIncRefIS1_EE($this, $cx, $aobj_01);
  return;
}

function __ZN2js11NeedsIncRefINS_6RegExpEEC1EPS1_($this, $obj) {
  __ZN2js11NeedsIncRefINS_6RegExpEEC2EPS1_($this, $obj);
  return;
}

function __ZNK8JSObject18getRegExpLastIndexEv($this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject7getSlotEj($1, 0);
  return $2;
}

function __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd3509($cx, $v, $dp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx2 = $v | 0;
    var $v_idx2_val$0 = HEAP32[$v_idx2 >> 2];
    var $v_idx2_val$1 = HEAP32[$v_idx2 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx2_val$0, $v_idx2_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx2_val$0, $v_idx2_val$1);
    tempDoubleF64[0] = $3 | 0, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 8;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($v_idx2_val$0, $v_idx2_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($v);
    tempDoubleF64[0] = $8, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $13 = $8;
    __label__ = 7;
    break;
   case 5:
    var $10 = $cx;
    var $11 = __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($10, $v_idx2_val$0, $v_idx2_val$1, $dp);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $_pre = (tempDoubleI32[0] = HEAP32[$dp >> 2], tempDoubleI32[1] = HEAP32[$dp + 4 >> 2], tempDoubleF64[0]);
    var $13 = $_pre;
    __label__ = 7;
    break;
   case 7:
    var $13;
    var $14 = __ZL18js_DoubleToIntegerd3519($13);
    tempDoubleF64[0] = $14, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL9NullValueEv3510($agg_result) {
  __ZN2JS5Value7setNullEv($agg_result);
  return;
}

function __ZN8JSObject18setRegExpLastIndexEd($this, $d) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL11NumberValueEd3511($1, $d);
  var $2 = $this;
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, 0, $_idx_val$0, $_idx_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12AutoRefCountINS_6RegExpEED1Ev($this_0_1_val) {
  __ZN2js12AutoRefCountINS_6RegExpEED2Ev($this_0_1_val);
  return;
}

function __ZN2js12AutoRefCountINS_6RegExpEED2Ev($this_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_1_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6RegExp6decrefEP9JSContext($this_0_1_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11NumberValueEd3511($agg_result, $dbl) {
  var $1 = __ZN2JS5Value9setNumberEd($agg_result, $dbl);
  return;
}

function __ZL18js_DoubleToIntegerd3519($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d == 0) {
      var $_0 = $d;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL18JSDOUBLE_IS_FINITEd3520($d);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZL15JSDOUBLE_IS_NaNd3521($d);
    var $d_ = ($6 | 0) == 0 ? $d : 0;
    var $_0 = $d_;
    __label__ = 7;
    break;
   case 4:
    if ($d < 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = _floor($d);
    var $_0 = $10;
    __label__ = 7;
    break;
   case 6:
    var $12 = -$d;
    var $13 = _floor($12);
    var $_0 = -$13;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12AutoRefCountINS_6RegExpEEC2EP9JSContextNS_11NeedsIncRefIS1_EE($this, $cx, $aobj_0) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this >> 2] = $cx;
    var $2 = $this + 4 | 0;
    var $3 = __ZNK2js11NeedsIncRefINS_6RegExpEE3getEv($aobj_0);
    HEAP32[$2 >> 2] = $3;
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6RegExp6increfEP9JSContext($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16infallibleAppendERKt($this, $t_val) {
  var $1 = $this;
  __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendItEEvT_($1, $t_val);
  return;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE3528($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js11RegExpClassE + 4 >> 2] >>> 24;
    var $4 = $cx;
    var $5 = __ZNK9JSContext5hasfpEv($4);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $8;
    var $9 = $cx;
    var $10 = $global;
    var $11 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($9, $10);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $19 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $13 = __ZNK9JSContext2fpEv($4);
    var $14 = __ZNK2js10StackFrame10scopeChainEv($13);
    var $15 = $14;
    var $16 = __ZNK8JSObject9getGlobalEv($15);
    var $17 = $16;
    HEAP32[$global >> 2] = $17;
    var $19 = $17;
    __label__ = 5;
    break;
   case 5:
    var $19;
    var $20 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $19, $20);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $22 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $24 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $25 = $24;
    HEAP32[$proto >> 2] = $25;
    var $32 = $25;
    __label__ = 9;
    break;
   case 7:
    var $27 = $cx;
    var $29 = $proto;
    var $30 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($27, $19, $3, $29, __ZN2js11RegExpClassE);
    if ($30) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $32 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $32;
    var $33 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE3529($cx, $32, $19, $kind);
    var $_0 = $33;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE3528["X"] = 1;

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE3529($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $proto;
    var $2 = $cx;
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($1, $2, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($2, $kind);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_0 = $7;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $parent;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, __ZN2js11RegExpClassE, $3, $10, 0, (__ZN2js11RegExpClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $11 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($3, $2, __ZN2js11RegExpClassE, $kind);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $11 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($6, $14);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE($this, $cx, $pairNum, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js13RegExpStatics9pairCountEv($this);
    if ($1 >>> 0 > $pairNum >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($out, $8);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $10 = $pairNum << 1;
    var $11 = __ZNK2js13RegExpStatics9makeMatchEP9JSContextjjPN2JS5ValueE($this, $cx, $10, $pairNum, $out);
    var $_0 = $11;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics9pairCountEv($this) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $1 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE6lengthEv($_idx_val);
  return $1 >>> 1;
}

function __ZNK2js13RegExpStatics9makeMatchEP9JSContextjjPN2JS5ValueE($this, $cx, $checkValidIndex, $pairNum, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $checkValidIndex >>> 1;
    var $2 = __ZNK2js13RegExpStatics9pairCountEv($this);
    if ($1 >>> 0 < $2 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this >> 2];
    var $5 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEEixEj($_idx_val, $checkValidIndex);
    if ((HEAP32[$5 >> 2] | 0) < 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $13 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($out, $13);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 4:
    var $15 = __ZNK2js13RegExpStatics3getEjb($this, $pairNum, 0);
    var $16 = __ZNK2js13RegExpStatics3getEjb($this, $pairNum, 1);
    var $this_idx_val = HEAP32[$this + 92 >> 2];
    var $17 = __ZNK2js13RegExpStatics15createDependentEP9JSContextjjPN2JS5ValueE($this_idx_val, $cx, $15, $16, $out);
    var $_0 = $17;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEEixEj($this_0_0_val, $i) {
  var $1 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE5beginEv($this_0_0_val);
  return $1 + ($i << 2) | 0;
}

function __ZNK2js13RegExpStatics15createDependentEP9JSContextjjPN2JS5ValueE($this_0_1_val, $cx, $start, $end, $out) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this_0_1_val | 0;
    var $3 = $end - $start | 0;
    var $4 = $cx;
    var $5 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($4, $2, $start, $3);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5 | 0;
    __ZN2JSL11StringValueEP8JSString3485($1, $8);
    var $9 = $1 | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $out | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics3getEjb($this, $pairNum, $which) {
  var $3 = $which & 1 | $pairNum << 1;
  var $_idx_val = HEAP32[$this >> 2];
  var $4 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEEixEj($_idx_val, $3);
  return HEAP32[$4 >> 2];
}

function __ZNK2js13RegExpStatics18createRightContextEP9JSContextPN2JS5ValueE($this, $cx, $out) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2js13RegExpStatics9pairCountEv($this);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($out, $9);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $_idx1_val = HEAP32[$this >> 2];
    var $11 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEEixEj($_idx1_val, 1);
    var $12 = HEAP32[$11 >> 2];
    if (($12 | 0) < 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JSL14UndefinedValueEv3491($1);
    var $15 = $1 | 0;
    var $16$0 = HEAP32[$15 >> 2];
    var $16$1 = HEAP32[$15 + 4 >> 2];
    var $17 = $out | 0;
    HEAP32[$17 >> 2] = $16$0;
    HEAP32[$17 + 4 >> 2] = $16$1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $20 = HEAP32[$this + 92 >> 2];
    var $_idx_val = HEAP32[$20 >> 2];
    var $21 = __ZNK8JSString6lengthEv($_idx_val);
    var $22 = __ZNK2js13RegExpStatics15createDependentEP9JSContextjjPN2JS5ValueE($20, $cx, $12, $21, $out);
    var $_0 = $22;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics17createLeftContextEP9JSContextPN2JS5ValueE($this, $cx, $out) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2js13RegExpStatics9pairCountEv($this);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($out, $9);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $_idx_val = HEAP32[$this >> 2];
    var $11 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEEixEj($_idx_val, 0);
    var $12 = HEAP32[$11 >> 2];
    if (($12 | 0) < 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JSL14UndefinedValueEv3491($1);
    var $15 = $1 | 0;
    var $16$0 = HEAP32[$15 >> 2];
    var $16$1 = HEAP32[$15 + 4 >> 2];
    var $17 = $out | 0;
    HEAP32[$17 >> 2] = $16$0;
    HEAP32[$17 + 4 >> 2] = $16$1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $this_idx_val = HEAP32[$this + 92 >> 2];
    var $19 = __ZNK2js13RegExpStatics15createDependentEP9JSContextjjPN2JS5ValueE($this_idx_val, $cx, 0, $12, $out);
    var $_0 = $19;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics15createLastParenEP9JSContextPN2JS5ValueE($this, $cx, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js13RegExpStatics9pairCountEv($this);
    if ($1 >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($out, $8);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $10 = $1 - 1 | 0;
    var $11 = __ZNK2js13RegExpStatics3getEjb($this, $10, 0);
    if (($11 | 0) == -1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $18 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($out, $18);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $20 = __ZNK2js13RegExpStatics3getEjb($this, $10, 1);
    var $this_idx_val = HEAP32[$this + 92 >> 2];
    var $21 = __ZNK2js13RegExpStatics15createDependentEP9JSContextjjPN2JS5ValueE($this_idx_val, $cx, $11, $20, $out);
    var $_0 = $21;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics15createLastMatchEP9JSContextPN2JS5ValueE($this, $cx, $out) {
  var $1 = __ZNK2js13RegExpStatics9makeMatchEP9JSContextjjPN2JS5ValueE($this, $cx, 0, 0, $out);
  return $1;
}

function _JSVAL_IS_BOOLEAN($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE3537($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_BOOLEAN_IMPL3538($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_BOOLEAN($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE3537($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_BOOLEAN_IMPL3536($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _BOOLEAN_TO_JSVAL3539($agg_result, $b) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BOOLEAN_TO_JSVAL_IMPL3507($1, $b);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout3540($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function _JSVAL_IS_STRING3541($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE3537($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_STRING_IMPL3544($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js13RegExpStatics15setPendingInputEP8JSString($this, $newInput) {
  var $1 = $this;
  __ZN2js13RegExpStatics12aboutToWriteEv($1);
  HEAP32[$this + 96 >> 2] = $newInput;
  return;
}

function _JSVAL_TO_STRING3542($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE3537($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_STRING_IMPL3543($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZNK2js13RegExpStatics18createPendingInputEP9JSContextPN2JS5ValueE($this_0_2_val, $cx, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_2_val | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $9 = $this_0_2_val;
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    __ZN2JS5Value9setStringEP8JSString($out, $9);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics4markEP8JSTracer($this, $trc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 96 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    var $6 = $trc;
    _JS_CallTracer($6, $5, 1);
    __label__ = 3;
    break;
   case 3:
    var $9 = HEAP32[$this + 92 >> 2];
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $9;
    var $13 = $trc;
    _JS_CallTracer($13, $12, 1);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext7delete_IN2js13RegExpStaticsEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js13RegExpStaticsD1Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13RegExpStaticsD1Ev($this) {
  __ZN2js13RegExpStaticsD2Ev($this);
  return;
}

function __ZN2js13RegExpStaticsD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEED1Ev($1);
  return;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this >> 2];
    var $3 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js17SystemAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL13VersionHasXMLE9JSVersion3598($version) {
  return ($version & 4096 | 0) != 0;
}

function __ZNK2js11TokenStream8TokenBuf11hasRawCharsEv($this_0_1_val, $this_0_2_val) {
  return $this_0_2_val >>> 0 < $this_0_1_val >>> 0;
}

function __ZN2js11FindKeywordEPKtj($s, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($length | 0) == 2) {
      __label__ = 2;
      break;
    } else if (($length | 0) == 3) {
      __label__ = 6;
      break;
    } else if (($length | 0) == 4) {
      __label__ = 16;
      break;
    } else if (($length | 0) == 5) {
      __label__ = 38;
      break;
    } else if (($length | 0) == 6) {
      __label__ = 71;
      break;
    } else if (($length | 0) == 7) {
      __label__ = 86;
      break;
    } else if (($length | 0) == 8) {
      __label__ = 91;
      break;
    } else if (($length | 0) == 9) {
      __label__ = 94;
      break;
    } else if (($length | 0) == 10) {
      __label__ = 96;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 2:
    var $2 = HEAP16[$s >> 1];
    if ($2 << 16 >> 16 == 100) {
      __label__ = 3;
      break;
    } else if ($2 << 16 >> 16 == 105) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 3:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 111) {
      var $i_0 = 10;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 4:
    var $9 = HEAP16[$s + 2 >> 1];
    if ($9 << 16 >> 16 == 110) {
      __label__ = 5;
      break;
    } else if ($9 << 16 >> 16 == 102) {
      var $i_0 = 15;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 5:
    var $i_0 = 16;
    __label__ = 98;
    break;
   case 6:
    var $14 = HEAPU16[$s + 4 >> 1] & 65535;
    if (($14 | 0) == 114) {
      __label__ = 7;
      break;
    } else if (($14 | 0) == 116) {
      __label__ = 10;
      break;
    } else if (($14 | 0) == 119) {
      __label__ = 12;
      break;
    } else if (($14 | 0) == 121) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 7:
    var $16 = HEAP16[$s >> 1];
    if ($16 << 16 >> 16 == 102) {
      __label__ = 8;
      break;
    } else if ($16 << 16 >> 16 == 118) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 8:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 111) {
      var $i_0 = 13;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 9:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 97) {
      var $i_0 = 25;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 10:
    if (HEAP16[$s >> 1] << 16 >> 16 == 108) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 11:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 101) {
      var $i_0 = 36;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 12:
    if (HEAP16[$s >> 1] << 16 >> 16 == 110) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 13:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 101) {
      var $i_0 = 18;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 14:
    if (HEAP16[$s >> 1] << 16 >> 16 == 116) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 15:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 114) {
      var $i_0 = 23;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 16:
    var $49 = HEAPU16[$s + 4 >> 1] & 65535;
    if (($49 | 0) == 105) {
      __label__ = 17;
      break;
    } else if (($49 | 0) == 108) {
      __label__ = 22;
      break;
    } else if (($49 | 0) == 115) {
      __label__ = 25;
      break;
    } else if (($49 | 0) == 116) {
      __label__ = 30;
      break;
    } else if (($49 | 0) == 117) {
      __label__ = 33;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 17:
    var $51 = HEAP16[$s >> 1];
    if ($51 << 16 >> 16 == 116) {
      __label__ = 18;
      break;
    } else if ($51 << 16 >> 16 == 118) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 18:
    if (HEAP16[$s + 6 >> 1] << 16 >> 16 == 115) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 19:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 104) {
      var $i_0 = 21;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 20:
    if (HEAP16[$s + 6 >> 1] << 16 >> 16 == 100) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 21:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 111) {
      var $i_0 = 26;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 22:
    if (HEAP16[$s >> 1] << 16 >> 16 == 110) {
      __label__ = 23;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 23:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 117) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 24:
    if (HEAP16[$s + 6 >> 1] << 16 >> 16 == 108) {
      var $i_0 = 2;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 25:
    var $81 = HEAP16[$s + 2 >> 1];
    if ($81 << 16 >> 16 == 97) {
      __label__ = 26;
      break;
    } else if ($81 << 16 >> 16 == 108) {
      __label__ = 28;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 26:
    if (HEAP16[$s >> 1] << 16 >> 16 == 99) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 27:
    if (HEAP16[$s + 6 >> 1] << 16 >> 16 == 101) {
      var $i_0 = 4;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 28:
    if (HEAP16[$s >> 1] << 16 >> 16 == 101) {
      __label__ = 29;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 29:
    if (HEAP16[$s + 6 >> 1] << 16 >> 16 == 101) {
      var $i_0 = 11;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 30:
    if (HEAP16[$s >> 1] << 16 >> 16 == 119) {
      __label__ = 31;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 31:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 105) {
      __label__ = 32;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 32:
    if (HEAP16[$s + 6 >> 1] << 16 >> 16 == 104) {
      var $i_0 = 28;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 33:
    var $108 = HEAP16[$s >> 1];
    if ($108 << 16 >> 16 == 101) {
      __label__ = 34;
      break;
    } else if ($108 << 16 >> 16 == 116) {
      __label__ = 36;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 34:
    if (HEAP16[$s + 6 >> 1] << 16 >> 16 == 109) {
      __label__ = 35;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 35:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 110) {
      var $i_0 = 30;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 36:
    if (HEAP16[$s + 6 >> 1] << 16 >> 16 == 101) {
      __label__ = 37;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 37:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 114) {
      var $i_0 = 1;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 38:
    var $128 = HEAPU16[$s + 6 >> 1] & 65535;
    if (($128 | 0) == 97) {
      __label__ = 39;
      break;
    } else if (($128 | 0) == 99) {
      __label__ = 43;
      break;
    } else if (($128 | 0) == 101) {
      __label__ = 47;
      break;
    } else if (($128 | 0) == 108) {
      __label__ = 51;
      break;
    } else if (($128 | 0) == 111) {
      __label__ = 58;
      break;
    } else if (($128 | 0) == 115) {
      __label__ = 62;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 39:
    if (HEAP16[$s >> 1] << 16 >> 16 == 98) {
      __label__ = 40;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 40:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 114) {
      __label__ = 41;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 41:
    if (HEAP16[$s + 4 >> 1] << 16 >> 16 == 101) {
      __label__ = 42;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 42:
    if (HEAP16[$s + 8 >> 1] << 16 >> 16 == 107) {
      var $i_0 = 3;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 43:
    if (HEAP16[$s >> 1] << 16 >> 16 == 99) {
      __label__ = 44;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 44:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 97) {
      __label__ = 45;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 45:
    if (HEAP16[$s + 4 >> 1] << 16 >> 16 == 116) {
      __label__ = 46;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 46:
    if (HEAP16[$s + 8 >> 1] << 16 >> 16 == 104) {
      var $i_0 = 5;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 47:
    if (HEAP16[$s >> 1] << 16 >> 16 == 115) {
      __label__ = 48;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 48:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 117) {
      __label__ = 49;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 49:
    if (HEAP16[$s + 4 >> 1] << 16 >> 16 == 112) {
      __label__ = 50;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 50:
    if (HEAP16[$s + 8 >> 1] << 16 >> 16 == 114) {
      var $i_0 = 34;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 51:
    var $175 = HEAP16[$s >> 1];
    if ($175 << 16 >> 16 == 119) {
      __label__ = 52;
      break;
    } else if ($175 << 16 >> 16 == 121) {
      __label__ = 55;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 52:
    if (HEAP16[$s + 8 >> 1] << 16 >> 16 == 101) {
      __label__ = 53;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 53:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 104) {
      __label__ = 54;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 54:
    if (HEAP16[$s + 4 >> 1] << 16 >> 16 == 105) {
      var $i_0 = 27;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 55:
    if (HEAP16[$s + 8 >> 1] << 16 >> 16 == 100) {
      __label__ = 56;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 56:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 105) {
      __label__ = 57;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 57:
    if (HEAP16[$s + 4 >> 1] << 16 >> 16 == 101) {
      var $i_0 = 37;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 58:
    if (HEAP16[$s >> 1] << 16 >> 16 == 116) {
      __label__ = 59;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 59:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 104) {
      __label__ = 60;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 60:
    if (HEAP16[$s + 4 >> 1] << 16 >> 16 == 114) {
      __label__ = 61;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 61:
    if (HEAP16[$s + 8 >> 1] << 16 >> 16 == 119) {
      var $i_0 = 22;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 62:
    var $216 = HEAP16[$s >> 1];
    if ($216 << 16 >> 16 == 99) {
      __label__ = 63;
      break;
    } else if ($216 << 16 >> 16 == 102) {
      __label__ = 68;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 63:
    var $219 = HEAP16[$s + 8 >> 1];
    if ($219 << 16 >> 16 == 115) {
      __label__ = 64;
      break;
    } else if ($219 << 16 >> 16 == 116) {
      __label__ = 66;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 64:
    if (HEAP16[$s + 4 >> 1] << 16 >> 16 == 97) {
      __label__ = 65;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 65:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 108) {
      var $i_0 = 29;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 66:
    if (HEAP16[$s + 4 >> 1] << 16 >> 16 == 110) {
      __label__ = 67;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 67:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 111) {
      var $i_0 = 35;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 68:
    if (HEAP16[$s + 8 >> 1] << 16 >> 16 == 101) {
      __label__ = 69;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 69:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 97) {
      __label__ = 70;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 70:
    if (HEAP16[$s + 4 >> 1] << 16 >> 16 == 108) {
      var $i_0 = 0;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 71:
    var $250 = HEAPU16[$s >> 1] & 65535;
    if (($250 | 0) == 101) {
      __label__ = 72;
      break;
    } else if (($250 | 0) == 105) {
      __label__ = 73;
      break;
    } else if (($250 | 0) == 112) {
      __label__ = 74;
      break;
    } else if (($250 | 0) == 114) {
      __label__ = 75;
      break;
    } else if (($250 | 0) == 115) {
      __label__ = 76;
      break;
    } else if (($250 | 0) == 116) {
      __label__ = 85;
      break;
    } else if (($250 | 0) == 100) {
      var $i_1 = 9;
      __label__ = 99;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 72:
    var $i_1 = 31;
    __label__ = 99;
    break;
   case 73:
    var $i_1 = 33;
    __label__ = 99;
    break;
   case 74:
    var $i_1 = 43;
    __label__ = 99;
    break;
   case 75:
    var $i_1 = 19;
    __label__ = 99;
    break;
   case 76:
    var $257 = HEAP16[$s + 2 >> 1];
    if ($257 << 16 >> 16 == 116) {
      __label__ = 77;
      break;
    } else if ($257 << 16 >> 16 == 119) {
      __label__ = 81;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 77:
    if (HEAP16[$s + 10 >> 1] << 16 >> 16 == 99) {
      __label__ = 78;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 78:
    if (HEAP16[$s + 8 >> 1] << 16 >> 16 == 105) {
      __label__ = 79;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 79:
    if (HEAP16[$s + 4 >> 1] << 16 >> 16 == 97) {
      __label__ = 80;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 80:
    if (HEAP16[$s + 6 >> 1] << 16 >> 16 == 116) {
      var $i_0 = 44;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 81:
    if (HEAP16[$s + 10 >> 1] << 16 >> 16 == 104) {
      __label__ = 82;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 82:
    if (HEAP16[$s + 8 >> 1] << 16 >> 16 == 99) {
      __label__ = 83;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 83:
    if (HEAP16[$s + 4 >> 1] << 16 >> 16 == 105) {
      __label__ = 84;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 84:
    if (HEAP16[$s + 6 >> 1] << 16 >> 16 == 116) {
      var $i_0 = 20;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 85:
    var $i_1 = 24;
    __label__ = 99;
    break;
   case 86:
    var $293 = HEAPU16[$s >> 1] & 65535;
    if (($293 | 0) == 101) {
      __label__ = 87;
      break;
    } else if (($293 | 0) == 102) {
      __label__ = 88;
      break;
    } else if (($293 | 0) == 112) {
      __label__ = 89;
      break;
    } else if (($293 | 0) == 100) {
      var $i_1 = 8;
      __label__ = 99;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 87:
    var $i_1 = 32;
    __label__ = 99;
    break;
   case 88:
    var $i_1 = 12;
    __label__ = 99;
    break;
   case 89:
    var $298 = HEAP16[$s + 2 >> 1];
    if ($298 << 16 >> 16 == 114) {
      __label__ = 90;
      break;
    } else if ($298 << 16 >> 16 == 97) {
      var $i_1 = 40;
      __label__ = 99;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 90:
    var $i_1 = 41;
    __label__ = 99;
    break;
   case 91:
    var $302 = HEAP16[$s + 4 >> 1];
    if ($302 << 16 >> 16 == 110) {
      __label__ = 92;
      break;
    } else if ($302 << 16 >> 16 == 98) {
      var $i_1 = 7;
      __label__ = 99;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 92:
    var $304 = HEAP16[$s >> 1];
    if ($304 << 16 >> 16 == 102) {
      __label__ = 93;
      break;
    } else if ($304 << 16 >> 16 == 99) {
      var $i_1 = 6;
      __label__ = 99;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 93:
    var $i_1 = 14;
    __label__ = 99;
    break;
   case 94:
    var $307 = HEAP16[$s >> 1];
    if ($307 << 16 >> 16 == 112) {
      __label__ = 95;
      break;
    } else if ($307 << 16 >> 16 == 105) {
      var $i_1 = 39;
      __label__ = 99;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 95:
    var $i_1 = 42;
    __label__ = 99;
    break;
   case 96:
    var $311 = HEAP16[$s + 2 >> 1];
    if ($311 << 16 >> 16 == 109) {
      __label__ = 97;
      break;
    } else if ($311 << 16 >> 16 == 110) {
      var $i_1 = 17;
      __label__ = 99;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 97:
    var $i_1 = 38;
    __label__ = 99;
    break;
   case 98:
    var $i_0;
    var $_0 = __ZL8keywords + ($i_0 << 4) | 0;
    __label__ = 103;
    break;
   case 99:
    var $i_1;
    var $316 = __ZL8keywords + ($i_1 << 4) | 0;
    var $_01 = $s;
    var $_02 = $length;
    var $chars_0 = HEAP32[$316 >> 2];
    __label__ = 100;
    break;
   case 100:
    var $chars_0;
    var $_02;
    var $_01;
    if ((HEAPU16[$_01 >> 1] & 65535 | 0) == (HEAPU8[$chars_0] & 255 | 0)) {
      __label__ = 101;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 101:
    var $326 = $_02 - 1 | 0;
    if (($326 | 0) == 0) {
      var $_0 = $316;
      __label__ = 103;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 102:
    var $_01 = $_01 + 2 | 0;
    var $_02 = $326;
    var $chars_0 = $chars_0 + 1 | 0;
    __label__ = 100;
    break;
   case 103:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11FindKeywordEPKtj["X"] = 1;

function __ZN2js11TokenStream8TokenBuf4initEPKtj($this, $buf, $length) {
  HEAP32[$this + 8 >> 2] = $buf;
  HEAP32[$this >> 2] = $buf;
  HEAP32[$this + 4 >> 2] = $buf + ($length << 1) | 0;
  return;
}

function __ZN2js11TokenStream8TokenBuf10getRawCharEv($this) {
  var $1 = $this + 8 | 0;
  var $2 = HEAP32[$1 >> 2];
  var $3 = $2 + 2 | 0;
  HEAP32[$1 >> 2] = $3;
  return HEAP16[$2 >> 1];
}

function __Z15js_IsIdentifierP14JSLinearString($str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str_idx_val = HEAP32[$str + 4 >> 2];
    var $1 = __ZNK14JSLinearString5charsEv($str_idx_val);
    var $_idx_val = HEAP32[$str >> 2];
    var $2 = __ZNK8JSString6lengthEv($_idx_val);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP16[$1 >> 1];
    var $6 = __ZN2js7unicode17IsIdentifierStartEt($5);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $8 = $1 + ($2 << 1) | 0;
    var $chars_0 = $1;
    __label__ = 4;
    break;
   case 4:
    var $chars_0;
    var $10 = $chars_0 + 2 | 0;
    if (($10 | 0) == ($8 | 0)) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = HEAP16[$10 >> 1];
    var $14 = __ZN2js7unicode16IsIdentifierPartEt($13);
    if ($14) {
      var $chars_0 = $10;
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7unicode17IsIdentifierStartEt($ch) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($ch & 65535) < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = STRING_TABLE._js_isidstart + ($ch & 65535) | 0;
    var $_0 = (HEAP8[$4] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $9 = __ZN2js7unicode8CharInfoEt($ch);
    var $_idx_val = HEAP8[$9 + 4 | 0];
    var $10 = __ZNK2js7unicode13CharacterInfo8isLetterEv($_idx_val);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7unicode16IsIdentifierPartEt($ch) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($ch & 65535) < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = STRING_TABLE._js_isident + ($ch & 65535) | 0;
    var $_0 = (HEAP8[$4] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $9 = __ZN2js7unicode8CharInfoEt($ch);
    var $_idx_val = HEAP8[$9 + 4 | 0];
    var $10 = __ZNK2js7unicode13CharacterInfo16isIdentifierPartEv($_idx_val);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStreamC2EP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = $cx;
  var $3 = $this + 4 | 0;
  HEAP32[$this + 144 >> 2] = 0;
  var $5 = $this + 156 | 0;
  var $6 = $3;
  for (var $$dest = $6 >> 2, $$stop = $$dest + 34; $$dest < $$stop; $$dest++) {
    HEAP32[$$dest] = 0;
  }
  __ZN2js11TokenStream8TokenBufC1Ev($5);
  HEAP32[$this + 180 >> 2] = 0;
  var $8 = $this + 184 | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js6VectorItLj32ENS_15TempAllocPolicyEEC1ES1_($8, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js11TokenStream8TokenBufC1Ev($this) {
  __ZN2js11TokenStream8TokenBufC2Ev($this);
  return;
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEEC1ES1_($this, $ap_01) {
  __ZN2js6VectorItLj32ENS_15TempAllocPolicyEEC2ES1_($this, $ap_01);
  return;
}

function __ZN2js11TokenStream4initEPKtjPKcj9JSVersion($this, $base, $length, $fn, $ln, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this + 172 >> 2] = $fn;
    HEAP32[$this + 140 >> 2] = $ln;
    HEAP32[$this + 904 >> 2] = $v;
    var $4 = __ZN2jsL13VersionHasXMLE9JSVersion3598($v);
    HEAP8[$this + 908 | 0] = $4 & 1;
    var $7 = $this + 156 | 0;
    __ZN2js11TokenStream8TokenBuf4initEPKtj($7, $base, $length);
    HEAP32[$this + 148 >> 2] = $base;
    HEAP32[$this + 152 >> 2] = 0;
    HEAP32[$this + 176 >> 2] = 0;
    var $14 = HEAP32[HEAP32[$this >> 2] + 200 >> 2];
    var $16 = HEAP32[$14 + 32 >> 2];
    if (($16 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $20 = HEAP32[$14 + 36 >> 2];
    var $21 = $this + 180 | 0;
    FUNCTION_TABLE[$16]($fn, $ln, $base, $length, $21, $20);
    __label__ = 3;
    break;
   case 3:
    var $23 = $this + 264 | 0;
    _memset($23, 0, 128, 1);
    HEAP8[$this + 323 | 0] = 2;
    HEAP8[$this + 308 | 0] = 3;
    HEAP8[$this + 327 | 0] = 5;
    HEAP8[$this + 355 | 0] = 23;
    HEAP8[$this + 357 | 0] = 24;
    HEAP8[$this + 387 | 0] = 25;
    HEAP8[$this + 389 | 0] = 26;
    HEAP8[$this + 304 | 0] = 27;
    HEAP8[$this + 305 | 0] = 28;
    var $33 = $this + 392 | 0;
    _memset($33, 0, 256, 1);
    HEAP8[$this + 402 | 0] = 1;
    HEAP8[$this + 405 | 0] = 1;
    HEAP8[$this + 432 | 0] = 1;
    HEAP8[$this + 433 | 0] = 1;
    var $38 = $this + 648 | 0;
    _memset($38, 0, 256, 1);
    HEAP8[$this + 682 | 0] = 1;
    HEAP8[$this + 687 | 0] = 1;
    HEAP8[$this + 740 | 0] = 1;
    HEAP8[$this + 658 | 0] = 1;
    HEAP8[$this + 661 | 0] = 1;
    HEAP8[$this + 688 | 0] = 1;
    HEAP8[$this + 689 | 0] = 1;
    HEAP8[$this + 903 | 0] = 1;
    HEAP32[$this + 20 >> 2] = $ln;
    HEAP32[$this + 12 >> 2] = $ln;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11TokenStream4initEPKtjPKcj9JSVersion["X"] = 1;

function __ZN2js11TokenStreamD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 144 >> 2] & 256 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 172 >> 2];
    __ZN9JSContext5free_EPv($7);
    __label__ = 3;
    break;
   case 3:
    var $10 = HEAP32[$this + 176 >> 2];
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $10;
    __ZN9JSContext5free_EPv($13);
    __label__ = 5;
    break;
   case 5:
    var $15 = $this + 184 | 0;
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEED1Ev($15);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorItLj32ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __Z8js_fgetsPciP7__sFILE($buf, $size, $file) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $size - 1 | 0;
    if (($1 | 0) < 0) {
      var $_0 = -1;
      __label__ = 10;
      break;
    } else {
      var $crflag_0 = 0;
      var $i_0 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $i_0;
    var $crflag_0;
    if (($i_0 | 0) < ($1 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $i_1 = $i_0;
      __label__ = 9;
      break;
    }
   case 3:
    var $5 = _getc_unlocked($file);
    if (($5 | 0) == -1) {
      var $i_1 = $i_0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP8[$buf + $i_0 | 0] = $5 & 255;
    if (($5 | 0) == 10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $i_1 = $i_0 + 1 | 0;
    __label__ = 9;
    break;
   case 6:
    if (($crflag_0 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $16 = _ungetc($5, $file);
    var $i_1 = $i_0;
    __label__ = 9;
    break;
   case 8:
    var $crflag_0 = ($5 | 0) == 13 & 1;
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 9:
    var $i_1;
    HEAP8[$buf + $i_1 | 0] = 0;
    var $_0 = $i_1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream7getCharEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 156 | 0;
    var $_idx2 = $this + 160 | 0;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $_idx3 = $this + 164 | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $2 = __ZNK2js11TokenStream8TokenBuf11hasRawCharsEv($_idx2_val, $_idx3_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $4 = __ZN2js11TokenStream8TokenBuf10getRawCharEv($1);
    var $5 = $4 & 65535;
    if (HEAP8[$this + 392 + ($5 & 255) | 0] << 24 >> 24 == 0) {
      var $_0 = $5;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($4 << 16 >> 16 == 13) {
      __label__ = 4;
      break;
    } else if ($4 << 16 >> 16 == 10) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$_idx2 >> 2];
    var $_idx1_val = HEAP32[$_idx3 >> 2];
    var $12 = __ZNK2js11TokenStream8TokenBuf11hasRawCharsEv($_idx_val, $_idx1_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    __ZN2js11TokenStream8TokenBuf12matchRawCharEt($1);
    __label__ = 8;
    break;
   case 6:
    if (($4 - 8232 & 65535 & 65535) < 2) {
      __label__ = 8;
      break;
    } else {
      var $_0 = $5;
      __label__ = 9;
      break;
    }
   case 7:
    var $17 = $this + 144 | 0;
    var $19 = HEAP32[$17 >> 2] | 2;
    HEAP32[$17 >> 2] = $19;
    var $_0 = -1;
    __label__ = 9;
    break;
   case 8:
    __ZN2js11TokenStream20updateLineInfoForEOLEv($this);
    var $_0 = 10;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream8TokenBuf12isRawEOLCharEi($c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($c | 0) == 8232 || ($c | 0) == 13 || ($c | 0) == 10 || ($c | 0) == 8233) {
      var $2 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $2 = 0;
    __label__ = 3;
    break;
   case 3:
    var $2;
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js11TokenStream8TokenBuf7atStartEv($this_0_0_val, $this_0_2_val) {
  return ($this_0_2_val | 0) == ($this_0_0_val | 0);
}

function __ZN2js11TokenStream12isStrictModeEv($this_0_5_val) {
  return ($this_0_5_val & 64 | 0) != 0;
}

function __ZN2js11TokenStream8TokenBuf12matchRawCharEt($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (HEAP16[$2 >> 1] << 16 >> 16 == 10) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = $2 + 2 | 0;
    HEAP32[$1 >> 2] = $6;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream8TokenBuf12ungetRawCharEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] - 2 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js11TokenStream8TokenBuf21matchRawCharBackwardsEt($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 8 | 0;
    var $3 = HEAP32[$1 >> 2] - 2 | 0;
    if (HEAP16[$3 >> 1] << 16 >> 16 == 13) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $3;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE8shrinkByEj($this, $incr) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] - $incr | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 1) | 0;
}

function __ZN2js11TokenStream20updateLineInfoForEOLEv($this) {
  var $1 = $this + 148 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$this + 152 >> 2] = $2;
  var $_idx_val = HEAP32[$this + 164 >> 2];
  var $4 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($_idx_val);
  HEAP32[$1 >> 2] = $4;
  var $5 = $this + 140 | 0;
  var $7 = HEAP32[$5 >> 2] + 1 | 0;
  HEAP32[$5 >> 2] = $7;
  return;
}

function __ZN2js11TokenStream16getCharIgnoreEOLEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this + 160 >> 2];
    var $_idx1_val = HEAP32[$this + 164 >> 2];
    var $1 = __ZNK2js11TokenStream8TokenBuf11hasRawCharsEv($_idx_val, $_idx1_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this + 156 | 0;
    var $4 = __ZN2js11TokenStream8TokenBuf10getRawCharEv($3);
    var $_0 = $4 & 65535;
    __label__ = 4;
    break;
   case 3:
    var $7 = $this + 144 | 0;
    var $9 = HEAP32[$7 >> 2] | 2;
    HEAP32[$7 >> 2] = $9;
    var $_0 = -1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream9ungetCharEi($this, $c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($c | 0) == -1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $this + 156 | 0;
    __ZN2js11TokenStream8TokenBuf12ungetRawCharEv($3);
    if (($c | 0) == 10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$3 >> 2];
    var $_idx1_val = HEAP32[$this + 164 >> 2];
    var $6 = __ZNK2js11TokenStream8TokenBuf7atStartEv($_idx_val, $_idx1_val);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js11TokenStream8TokenBuf21matchRawCharBackwardsEt($3);
    __label__ = 5;
    break;
   case 5:
    var $9 = $this + 152 | 0;
    var $10 = HEAP32[$9 >> 2];
    HEAP32[$this + 148 >> 2] = $10;
    HEAP32[$9 >> 2] = 0;
    var $12 = $this + 140 | 0;
    var $14 = HEAP32[$12 >> 2] - 1 | 0;
    HEAP32[$12 >> 2] = $14;
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, $c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($c | 0) == -1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $this + 156 | 0;
    __ZN2js11TokenStream8TokenBuf12ungetRawCharEv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream9peekCharsEiPt($this, $n, $cp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if (($i_0 | 0) < ($n | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($i_0 | 0) > 0) {
      var $j_02_in = $i_0;
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $5 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    if (($5 | 0) == -1) {
      __label__ = 3;
      break;
    } else if (($5 | 0) == 10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, 10);
    __label__ = 3;
    break;
   case 6:
    HEAP16[$cp + ($i_0 << 1) >> 1] = $5 & 65535;
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 7:
    var $j_02_in;
    var $j_02 = $j_02_in - 1 | 0;
    var $13 = HEAPU16[$cp + ($j_02 << 1) >> 1] & 65535;
    __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, $13);
    if (($j_02 | 0) > 0) {
      var $j_02_in = $j_02;
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    return ($i_0 | 0) == ($n | 0);
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream8TokenBuf7findEOLEv($this_0_1_val, $this_0_2_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp_0 = $this_0_2_val;
    __label__ = 2;
    break;
   case 2:
    var $tmp_0;
    if ($tmp_0 >>> 0 < $this_0_1_val >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $tmp_1 = $tmp_0;
      __label__ = 4;
      break;
    }
   case 3:
    var $4 = $tmp_0 + 2 | 0;
    var $6 = HEAPU16[$tmp_0 >> 1] & 65535;
    var $7 = __ZN2js11TokenStream8TokenBuf12isRawEOLCharEi($6);
    if ($7) {
      var $tmp_1 = $4;
      __label__ = 4;
      break;
    } else {
      var $tmp_0 = $4;
      __label__ = 2;
      break;
    }
   case 4:
    var $tmp_1;
    return $tmp_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream26reportCompileErrorNumberVAEP11JSParseNodejjPc($this, $pn, $flags, $errorNumber, $ap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $report = __stackBase__;
    var $message = __stackBase__ + 40;
    if (($flags & 4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[HEAP32[$this >> 2] + 32 >> 2];
    var $6 = __ZNK9JSContext15hasStrictOptionEv($_idx_val);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 34;
      break;
    }
   case 3:
    var $8 = $flags & 255 & 1;
    var $_pre = HEAP32[$this >> 2];
    if (($flags & 1 | 0) == 0) {
      var $_01 = $flags;
      var $warning_0 = $8;
      var $15 = $_pre;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $flags & -2;
    var $_idx1_val = HEAP32[$_pre + 32 >> 2];
    var $13 = __ZNK9JSContext15hasWErrorOptionEv($_idx1_val);
    var $_flags = $13 ? $12 : $flags;
    if ($13) {
      __label__ = 5;
      break;
    } else {
      var $_01 = $_flags;
      var $warning_0 = $8;
      var $15 = $_pre;
      __label__ = 6;
      break;
    }
   case 5:
    var $_01 = $_flags;
    var $warning_0 = 0;
    var $15 = $_pre;
    __label__ = 6;
    break;
   case 6:
    var $15;
    var $warning_0;
    var $_01;
    __ZN2jsL7PodZeroI13JSErrorReportEEvPT_3601($report);
    HEAP32[$report + 24 >> 2] = $_01;
    HEAP32[$report + 28 >> 2] = $errorNumber;
    HEAP32[$message >> 2] = 0;
    var $18 = $this | 0;
    var $20 = ($_01 & 256 | 0) != 0;
    var $22 = __Z23js_ExpandErrorArgumentsP9JSContextPFPK19JSErrorFormatStringPvPKcjES4_jPPcP13JSErrorReportbS9_($15, 4, $errorNumber, $message, $report, $20 ^ 1, $ap);
    if (($22 | 0) == 0) {
      var $warning_134 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $26 = HEAP32[$this + 172 >> 2];
    HEAP32[$report >> 2] = $26;
    if (($pn | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $35 = $pn + 4 | 0;
    __label__ = 10;
    break;
   case 9:
    var $32 = __ZNK2js11TokenStream12currentTokenEv($this);
    var $35 = $32 + 4 | 0;
    __label__ = 10;
    break;
   case 10:
    var $35;
    var $37 = HEAP32[$35 + 4 >> 2];
    HEAP32[$report + 4 >> 2] = $37;
    if (($37 | 0) == (HEAP32[$this + 140 >> 2] | 0)) {
      __label__ = 11;
      break;
    } else {
      var $linebytes_0 = 0;
      var $linechars_0 = 0;
      __label__ = 14;
      break;
    }
   case 11:
    var $_idx2_val = HEAP32[$this + 160 >> 2];
    var $_idx3_val = HEAP32[$this + 164 >> 2];
    var $43 = __ZN2js11TokenStream8TokenBuf7findEOLEv($_idx2_val, $_idx3_val);
    var $44 = $this + 148 | 0;
    var $48 = $43 - HEAP32[$44 >> 2] | 0;
    var $49 = $48 >> 1;
    var $50 = HEAP32[$18 >> 2];
    var $51 = $48 + 2 | 0;
    var $52 = __ZN9JSContext7malloc_Ej($50, $51);
    var $53 = $52;
    if (($52 | 0) == 0) {
      var $linechars_12 = $53;
      var $warning_13 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $57 = HEAP32[$44 >> 2];
    _memcpy($52, $57, $48, 1);
    HEAP16[$53 + ($49 << 1) >> 1] = 0;
    var $60 = HEAP32[$18 >> 2];
    var $61 = __ZN2js13DeflateStringEP9JSContextPKtj($60, $53, $49);
    if (($61 | 0) == 0) {
      var $linechars_12 = $53;
      var $warning_13 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    HEAP32[$report + 8 >> 2] = $61;
    HEAP32[$report + 16 >> 2] = $53;
    var $66 = $35 | 0;
    var $68 = $61 + HEAP32[$66 >> 2] | 0;
    HEAP32[$report + 12 >> 2] = $68;
    var $71 = $53 + (HEAP32[$66 >> 2] << 1) | 0;
    HEAP32[$report + 20 >> 2] = $71;
    var $linebytes_0 = $61;
    var $linechars_0 = $53;
    __label__ = 14;
    break;
   case 14:
    var $linechars_0;
    var $linebytes_0;
    var $75 = HEAP32[$message >> 2];
    var $76 = HEAP32[$18 >> 2];
    var $77 = $report;
    var $78 = __Z19js_ErrorToExceptionP9JSContextPKcP13JSErrorReportPFPK19JSErrorFormatStringPvS2_jES8_($76, $75, $77, 0);
    if (($78 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 15:
    var $81 = HEAP32[$18 >> 2];
    var $83 = HEAP32[$81 + 200 >> 2];
    var $85 = HEAP32[$83 + 64 >> 2];
    if (($85 | 0) == 0) {
      var $92 = $81;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $89 = HEAP32[$83 + 68 >> 2];
    var $90 = FUNCTION_TABLE[$85]($81, $75, $report, $89);
    if (($90 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $92 = HEAP32[$18 >> 2];
    __label__ = 18;
    break;
   case 18:
    var $92;
    var $94 = HEAP32[$92 + 180 >> 2];
    if (($94 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    FUNCTION_TABLE[$94]($92, $75, $report);
    __label__ = 20;
    break;
   case 20:
    if (($linebytes_0 | 0) == 0) {
      var $linechars_12 = $linechars_0;
      var $warning_13 = $warning_0;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    __ZN9JSContext5free_EPv($linebytes_0);
    var $linechars_12 = $linechars_0;
    var $warning_13 = $warning_0;
    __label__ = 22;
    break;
   case 22:
    var $warning_13;
    var $linechars_12;
    if (($linechars_12 | 0) == 0) {
      var $warning_134 = $warning_13;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    __ZN9JSContext5free_EPv($linechars_12);
    var $warning_134 = $warning_13;
    __label__ = 24;
    break;
   case 24:
    var $warning_134;
    var $103 = HEAP32[$message >> 2];
    if (($103 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    __ZN9JSContext5free_EPv($103);
    __label__ = 26;
    break;
   case 26:
    var $108 = HEAP32[$report + 32 >> 2];
    if (($108 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $111 = $108;
    __ZN9JSContext5free_EPv($111);
    __label__ = 28;
    break;
   case 28:
    var $113 = $report + 36 | 0;
    var $114 = HEAP32[$113 >> 2];
    if (($114 | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    if ($20) {
      var $126 = $114;
      __label__ = 32;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $117 = HEAP32[$114 >> 2];
    if (($117 | 0) == 0) {
      var $126 = $114;
      __label__ = 32;
      break;
    } else {
      var $i_05 = 0;
      var $119 = $117;
      __label__ = 31;
      break;
    }
   case 31:
    var $119;
    var $i_05;
    var $120 = $i_05 + 1 | 0;
    __ZN9JSContext5free_EPv($119);
    var $122 = HEAP32[$113 >> 2];
    var $124 = HEAP32[$122 + ($120 << 2) >> 2];
    if (($124 | 0) == 0) {
      var $126 = $122;
      __label__ = 32;
      break;
    } else {
      var $i_05 = $120;
      var $119 = $124;
      __label__ = 31;
      break;
    }
   case 32:
    var $126;
    __ZN9JSContext5free_EPv($126);
    __label__ = 33;
    break;
   case 33:
    var $_0 = ($warning_134 & 1) << 24 >> 24 != 0;
    __label__ = 34;
    break;
   case 34:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11TokenStream26reportCompileErrorNumberVAEP11JSParseNodejjPc["X"] = 1;

function __ZN2jsL7PodZeroI13JSErrorReportEEvPT_3601($t) {
  var $1 = $t;
  _memset($1, 0, 40, 1);
  return;
}

function __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($cx, $ts, $tc, $pn, $errorNumber) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ap = __stackBase__;
    if (($ts | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $ts_idx_val = HEAP32[$ts + 144 >> 2];
    var $3 = __ZN2js11TokenStream12isStrictModeEv($ts_idx_val);
    if ($3) {
      var $flags_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($tc | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP32[$tc >> 2] & 262144 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $flags_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $cx_idx_val = HEAP32[$cx + 32 >> 2];
    var $12 = __ZNK9JSContext15hasStrictOptionEv($cx_idx_val);
    if ($12) {
      var $flags_0 = 1;
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 6:
    var $flags_0;
    HEAP32[$ap >> 2] = arguments[__ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz.length];
    var $15 = HEAP32[$ap >> 2];
    var $16 = __ZN2js11TokenStream26reportCompileErrorNumberVAEP11JSParseNodejjPc($ts, $pn, $flags_0, $errorNumber, $15);
    var $_0 = $16;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($ts, $pn, $flags, $errorNumber) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $ap = __stackBase__;
  HEAP32[$ap >> 2] = arguments[__ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz.length];
  var $2 = HEAP32[$ap >> 2];
  var $3 = __ZN2js11TokenStream26reportCompileErrorNumberVAEP11JSParseNodejjPc($ts, $pn, $flags, $errorNumber, $2);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN2js11TokenStream12getXMLEntityEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 184 | 0;
    var $_idx1 = $this + 192 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $2 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv($_idx1_val);
    var $3 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIcEEbT_($1);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 39;
      break;
    }
   case 2:
    var $4 = __ZN2js11TokenStream7getCharEv($this);
    if (($4 | 0) == -1 || ($4 | 0) == 10) {
      __label__ = 3;
      break;
    } else if (($4 | 0) == 59) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($this, 0, 0, 191, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 39;
    break;
   case 4:
    var $8 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($1, $4);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 39;
      break;
    }
   case 5:
    var $_idx_val = HEAP32[$_idx1 >> 2];
    var $10 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv($_idx_val);
    var $11 = $10 - $2 | 0;
    var $_idx2 = $this + 188 | 0;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $12 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5beginEv($_idx2_val);
    var $13 = $12 + ($2 << 1) | 0;
    if (($11 | 0) > 2) {
      __label__ = 6;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 6:
    var $16 = $12 + ($2 + 1 << 1) | 0;
    if (HEAP16[$16 >> 1] << 16 >> 16 == 35) {
      __label__ = 7;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 7:
    if (($11 | 0) > 3) {
      __label__ = 8;
      break;
    } else {
      var $i_1 = 2;
      var $c_1 = 0;
      __label__ = 16;
      break;
    }
   case 8:
    var $23 = HEAP16[$12 + ($2 + 2 << 1) >> 1];
    if ($23 << 16 >> 16 == 120 || $23 << 16 >> 16 == 88) {
      __label__ = 9;
      break;
    } else {
      var $i_1 = 2;
      var $c_1 = 0;
      __label__ = 16;
      break;
    }
   case 9:
    if (($11 | 0) > 9) {
      var $msg_0 = 196;
      __label__ = 37;
      break;
    } else {
      var $i_0 = 3;
      var $c_0 = 0;
      __label__ = 10;
      break;
    }
   case 10:
    var $c_0;
    var $i_0;
    if (($i_0 | 0) < ($11 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $c_2 = $c_0;
      __label__ = 19;
      break;
    }
   case 11:
    var $29 = HEAPU16[$12 + ($i_0 + $2 << 1) >> 1];
    var $30 = $29 & 65535;
    if (($29 & 65535) < 128) {
      __label__ = 12;
      break;
    } else {
      var $msg_0 = 196;
      __label__ = 37;
      break;
    }
   case 12:
    var $33 = _isxdigit($30);
    if (($33 | 0) == 0) {
      var $msg_0 = 196;
      __label__ = 37;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $36 = $c_0 << 4;
    var $37 = $30 - 48 | 0;
    if ($37 >>> 0 < 10) {
      var $43 = $37;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $40 = _tolower($30);
    var $43 = $40 - 87 | 0;
    __label__ = 15;
    break;
   case 15:
    var $43;
    var $i_0 = $i_0 + 1 | 0;
    var $c_0 = $43 + $36 | 0;
    __label__ = 10;
    break;
   case 16:
    var $c_1;
    var $i_1;
    if (($i_1 | 0) < ($11 | 0)) {
      __label__ = 17;
      break;
    } else {
      var $c_2 = $c_1;
      __label__ = 19;
      break;
    }
   case 17:
    var $49 = HEAPU16[$12 + ($i_1 + $2 << 1) >> 1] & 65535;
    if (($49 - 48 | 0) >>> 0 < 10) {
      __label__ = 18;
      break;
    } else {
      var $msg_0 = 196;
      __label__ = 37;
      break;
    }
   case 18:
    var $56 = $c_1 * 10 - 48 + $49 | 0;
    if (($56 | 0) < 0) {
      var $msg_0 = 196;
      __label__ = 37;
      break;
    } else {
      var $i_1 = $i_1 + 1 | 0;
      var $c_1 = $56;
      __label__ = 16;
      break;
    }
   case 19:
    var $c_2;
    if (($c_2 - 65536 | 0) >>> 0 < 1048576) {
      __label__ = 35;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    if (($c_2 | 0) == 13 | ($c_2 - 9 | 0) >>> 0 < 2 | ($c_2 - 32 | 0) >>> 0 < 55264 | ($c_2 - 57344 | 0) >>> 0 < 8190) {
      var $c_4_ph = $c_2;
      __label__ = 34;
      break;
    } else {
      var $msg_0 = 196;
      __label__ = 37;
      break;
    }
   case 21:
    if (($11 | 0) == 3) {
      __label__ = 22;
      break;
    } else if (($11 | 0) == 4) {
      __label__ = 25;
      break;
    } else if (($11 | 0) == 5) {
      __label__ = 28;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 22:
    if (HEAP16[$12 + ($2 + 2 << 1) >> 1] << 16 >> 16 == 116) {
      __label__ = 23;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 23:
    var $69 = HEAP16[$12 + ($2 + 1 << 1) >> 1];
    if ($69 << 16 >> 16 == 108) {
      var $c_4_ph = 60;
      __label__ = 34;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    if ($69 << 16 >> 16 == 103) {
      var $c_4_ph = 62;
      __label__ = 34;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 25:
    if (HEAP16[$12 + ($2 + 1 << 1) >> 1] << 16 >> 16 == 97) {
      __label__ = 26;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 26:
    if (HEAP16[$12 + ($2 + 2 << 1) >> 1] << 16 >> 16 == 109) {
      __label__ = 27;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 27:
    if (HEAP16[$12 + ($2 + 3 << 1) >> 1] << 16 >> 16 == 112) {
      var $c_4_ph = 38;
      __label__ = 34;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 28:
    if (HEAP16[$12 + ($2 + 3 << 1) >> 1] << 16 >> 16 == 111) {
      __label__ = 29;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 29:
    var $91 = HEAP16[$12 + ($2 + 1 << 1) >> 1];
    if ($91 << 16 >> 16 == 97) {
      __label__ = 30;
      break;
    } else if ($91 << 16 >> 16 == 113) {
      __label__ = 32;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 30:
    if (HEAP16[$12 + ($2 + 2 << 1) >> 1] << 16 >> 16 == 112) {
      __label__ = 31;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 31:
    if (HEAP16[$12 + ($2 + 4 << 1) >> 1] << 16 >> 16 == 115) {
      var $c_4_ph = 39;
      __label__ = 34;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 32:
    if (HEAP16[$12 + ($2 + 2 << 1) >> 1] << 16 >> 16 == 117) {
      __label__ = 33;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 33:
    if (HEAP16[$12 + ($2 + 4 << 1) >> 1] << 16 >> 16 == 116) {
      var $c_4_ph = 34;
      __label__ = 34;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 34:
    var $c_4_ph;
    var $_sum1240 = $2 + 1 | 0;
    HEAP16[$13 >> 1] = $c_4_ph & 65535;
    var $_sum13_pn = $_sum1240;
    __label__ = 36;
    break;
   case 35:
    HEAP16[$13 >> 1] = ($c_2 >>> 10) + 55232 & 65535;
    var $_sum13 = $2 + 2 | 0;
    HEAP16[$16 >> 1] = ($c_2 & 1023 | 56320) & 65535;
    var $_sum13_pn = $_sum13;
    __label__ = 36;
    break;
   case 36:
    var $_sum13_pn;
    var $bp_0 = $12 + ($_sum13_pn << 1) | 0;
    var $_idx5_val = HEAP32[$_idx2 >> 2];
    var $_idx6_val = HEAP32[$_idx1 >> 2];
    var $116 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE3endEv($_idx5_val, $_idx6_val);
    var $120 = $116 - $bp_0 >> 1;
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE8shrinkByEj($1, $120);
    var $_0 = 1;
    __label__ = 39;
    break;
   case 37:
    var $msg_0;
    var $122 = HEAP32[$this >> 2];
    var $123 = $12 + ($2 + 1 << 1) | 0;
    var $_idx3_val = HEAP32[$_idx2 >> 2];
    var $_idx4_val = HEAP32[$_idx1 >> 2];
    var $124 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE3endEv($_idx3_val, $_idx4_val);
    var $129 = ($124 - $13 >> 1) - 1 | 0;
    var $130 = $122;
    var $131 = __ZN2js13DeflateStringEP9JSContextPKtj($130, $123, $129);
    if (($131 | 0) == 0) {
      var $_0 = 0;
      __label__ = 39;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $134 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($this, 0, 0, $msg_0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $131, tempInt));
    __ZN9JSContext5free_EPv($131);
    var $_0 = 0;
    __label__ = 39;
    break;
   case 39:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11TokenStream12getXMLEntityEv["X"] = 1;

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIcEEbT_($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendIcEEvT_($this);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendIiEEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7unicode10IsXMLSpaceEt($ch) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($ch << 16 >> 16 == 32 || $ch << 16 >> 16 == 9 || $ch << 16 >> 16 == 13 || $ch << 16 >> 16 == 10) {
      var $2 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $2 = 0;
    __label__ = 3;
    break;
   case 3:
    var $2;
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5emptyEv($this_0_2_val) {
  return ($this_0_2_val | 0) == 0;
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE5clearEv($this) {
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN2js11TokenStream15getXMLTextOrTagEPNS_9TokenKindEPPNS_5TokenE($this, $ttp, $tpp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 144 | 0;
    var $4 = (HEAP32[$1 >> 2] & 1024 | 0) == 0;
    var $5 = __ZN2js11TokenStream8newTokenEi($this, 0);
    if ($4) {
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this + 184 | 0;
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE5clearEv($7);
    var $10 = (HEAP32[$1 >> 2] & 2048 | 0) != 0;
    var $11 = $10 ? 60 : 123;
    var $tt_0 = 65;
    __label__ = 3;
    break;
   case 3:
    var $tt_0;
    var $12 = __ZN2js11TokenStream7getCharEv($this);
    if (($12 | 0) == ($11 | 0) | ($12 | 0) == 60) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($12 | 0) == 38) {
      __label__ = 5;
      break;
    } else if (($12 | 0) == -1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $18 = __ZN2js11TokenStream12getXMLEntityEv($this);
    if ($18) {
      var $tt_0 = 66;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      var $storemerge1 = -1;
      __label__ = 43;
      break;
    }
   case 7:
    var $20 = $12 & 65535;
    var $21 = __ZN2js7unicode10IsXMLSpaceEt($20);
    var $tt_1 = $21 ? $tt_0 : 66;
    var $22 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($7, $12);
    if ($22) {
      var $tt_0 = $tt_1;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      var $storemerge1 = -1;
      __label__ = 43;
      break;
    }
   case 8:
    __ZN2js11TokenStream9ungetCharEi($this, $12);
    var $_idx_val = HEAP32[$this + 192 >> 2];
    var $23 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5emptyEv($_idx_val);
    if ($23) {
      var $atom_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $26 = HEAP32[$this >> 2];
    var $_idx5_val = HEAP32[$this + 188 >> 2];
    var $27 = __ZN2js11TokenStream7atomizeEP9JSContextRNS_6VectorItLj32ENS_15TempAllocPolicyEEE($26, $_idx5_val, $_idx_val);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      var $storemerge1 = -1;
      __label__ = 43;
      break;
    } else {
      var $atom_0 = $27;
      __label__ = 10;
      break;
    }
   case 10:
    var $atom_0;
    var $31 = HEAP32[$this + 140 >> 2];
    HEAP32[$5 + 16 >> 2] = $31;
    HEAP32[$5 + 24 >> 2] = 61;
    HEAP32[$5 + 28 >> 2] = $atom_0;
    var $_0 = 1;
    var $storemerge1 = $tt_0;
    __label__ = 43;
    break;
   case 11:
    var $36 = __ZN2js11TokenStream7getCharEv($this);
    if (($36 | 0) == -1) {
      var $_0 = 1;
      var $storemerge1 = 0;
      __label__ = 43;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $38 = $36 & 65535;
    var $39 = __ZN2js7unicode10IsXMLSpaceEt($38);
    if ($39) {
      __label__ = 13;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 13:
    var $40 = __ZN2js11TokenStream7getCharEv($this);
    if (($40 | 0) == -1) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $43 = $40 & 65535;
    var $44 = __ZN2js7unicode10IsXMLSpaceEt($43);
    if ($44) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    __ZN2js11TokenStream9ungetCharEi($this, $40);
    var $47 = HEAP32[$this + 140 >> 2];
    HEAP32[$5 + 16 >> 2] = $47;
    var $_0 = 1;
    var $storemerge1 = 65;
    __label__ = 43;
    break;
   case 16:
    var $50 = $this + 184 | 0;
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE5clearEv($50);
    var $51 = __ZN2js7unicode19IsXMLNamespaceStartEt($38);
    if ($51) {
      __label__ = 17;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 17:
    var $53 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($50, $36);
    if ($53) {
      var $sawColon_0 = 0;
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      var $storemerge1 = -1;
      __label__ = 43;
      break;
    }
   case 18:
    var $sawColon_0;
    var $54 = __ZN2js11TokenStream7getCharEv($this);
    if (($54 | 0) == -1) {
      __label__ = 26;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $57 = $54 & 65535;
    var $58 = __ZN2js7unicode13IsXMLNamePartEt($57);
    if ($58) {
      __label__ = 20;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 20:
    if (($54 | 0) == 58) {
      __label__ = 21;
      break;
    } else {
      var $sawColon_1 = $sawColon_0;
      __label__ = 25;
      break;
    }
   case 21:
    if (($sawColon_0 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 22:
    var $64 = __ZN2js11TokenStream8peekCharEv($this);
    if ((HEAP32[$1 >> 2] & 2048 | 0) == 0 & ($64 | 0) == 123) {
      var $sawColon_1 = 1;
      __label__ = 25;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $70 = $64 & 65535;
    var $71 = __ZN2js7unicode13IsXMLNamePartEt($70);
    if ($71) {
      var $sawColon_1 = 1;
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $73 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($this, 0, 0, 192, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    var $storemerge1 = -1;
    __label__ = 43;
    break;
   case 25:
    var $sawColon_1;
    var $74 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($50, $54);
    if ($74) {
      var $sawColon_0 = $sawColon_1;
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      var $storemerge1 = -1;
      __label__ = 43;
      break;
    }
   case 26:
    __ZN2js11TokenStream9ungetCharEi($this, $54);
    var $76 = HEAP32[$this >> 2];
    var $_idx3_val = HEAP32[$this + 188 >> 2];
    var $_idx4_val = HEAP32[$this + 192 >> 2];
    var $77 = __ZN2js11TokenStream7atomizeEP9JSContextRNS_6VectorItLj32ENS_15TempAllocPolicyEEE($76, $_idx3_val, $_idx4_val);
    if (($77 | 0) == 0) {
      var $_0 = 0;
      var $storemerge1 = -1;
      __label__ = 43;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    HEAP32[$5 + 24 >> 2] = 61;
    HEAP32[$5 + 28 >> 2] = $77;
    var $_0 = 1;
    var $storemerge1 = 63;
    __label__ = 43;
    break;
   case 28:
    if (($36 | 0) == 123) {
      __label__ = 29;
      break;
    } else if (($36 | 0) == 34 || ($36 | 0) == 39) {
      __label__ = 30;
      break;
    } else if (($36 | 0) == 62) {
      __label__ = 40;
      break;
    } else if (($36 | 0) == 47) {
      __label__ = 41;
      break;
    } else if (($36 | 0) == 61) {
      var $_0 = 1;
      var $storemerge1 = 4;
      __label__ = 43;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 29:
    if ((HEAP32[$1 >> 2] & 2048 | 0) == 0) {
      var $_0 = 1;
      var $storemerge1 = 25;
      __label__ = 43;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 30:
    var $87 = __ZN2js11TokenStream7getCharEv($this);
    if (($87 | 0) == ($36 | 0)) {
      __label__ = 38;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    if (($87 | 0) == -1) {
      __label__ = 32;
      break;
    } else if (($87 | 0) == 34) {
      __label__ = 33;
      break;
    } else if (($87 | 0) == 38) {
      __label__ = 35;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 32:
    var $91 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($this, 0, 0, 138, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    var $storemerge1 = -1;
    __label__ = 43;
    break;
   case 33:
    if ((HEAP32[$1 >> 2] & 2048 | 0) == 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 34:
    var $97 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIcEEbPKT_j($50);
    if ($97) {
      __label__ = 30;
      break;
    } else {
      var $_0 = 0;
      var $storemerge1 = -1;
      __label__ = 43;
      break;
    }
   case 35:
    if ((HEAP32[$1 >> 2] & 2048 | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $103 = __ZN2js11TokenStream12getXMLEntityEv($this);
    if ($103) {
      __label__ = 30;
      break;
    } else {
      var $_0 = 0;
      var $storemerge1 = -1;
      __label__ = 43;
      break;
    }
   case 37:
    var $105 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($50, $87);
    if ($105) {
      __label__ = 30;
      break;
    } else {
      var $_0 = 0;
      var $storemerge1 = -1;
      __label__ = 43;
      break;
    }
   case 38:
    var $108 = HEAP32[$this >> 2];
    var $_idx1_val = HEAP32[$this + 188 >> 2];
    var $_idx2_val = HEAP32[$this + 192 >> 2];
    var $109 = __ZN2js11TokenStream7atomizeEP9JSContextRNS_6VectorItLj32ENS_15TempAllocPolicyEEE($108, $_idx1_val, $_idx2_val);
    if (($109 | 0) == 0) {
      var $_0 = 0;
      var $storemerge1 = -1;
      __label__ = 43;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $113 = HEAP32[$this + 140 >> 2];
    HEAP32[$5 + 16 >> 2] = $113;
    HEAP32[$5 + 24 >> 2] = 61;
    HEAP32[$5 + 28 >> 2] = $109;
    var $_0 = 1;
    var $storemerge1 = 64;
    __label__ = 43;
    break;
   case 40:
    var $_0 = 1;
    var $storemerge1 = 62;
    __label__ = 43;
    break;
   case 41:
    var $119 = __ZN2js11TokenStream9matchCharEi($this, 62);
    if ($119) {
      var $_0 = 1;
      var $storemerge1 = 61;
      __label__ = 43;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $121 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($this, 0, 0, 171, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    var $storemerge1 = -1;
    __label__ = 43;
    break;
   case 43:
    var $storemerge1;
    var $_0;
    HEAP32[$ttp >> 2] = $storemerge1;
    HEAP32[$tpp >> 2] = $5;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11TokenStream15getXMLTextOrTagEPNS_9TokenKindEPPNS_5TokenE["X"] = 1;

function __ZN2js11TokenStream8newTokenEi($this, $adjust) {
  var $1 = $this + 132 | 0;
  var $4 = HEAP32[$1 >> 2] + 1 & 3;
  HEAP32[$1 >> 2] = $4;
  var $5 = $this + 4 + ($4 << 5) | 0;
  var $_idx_val = HEAP32[$this + 164 >> 2];
  var $6 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($_idx_val);
  var $7 = $6 + ($adjust << 1) | 0;
  var $8 = $this + 4 + ($4 << 5) + 20 | 0;
  HEAP32[$8 >> 2] = $7;
  var $14 = $7 - HEAP32[$this + 148 >> 2] >> 1;
  var $15 = $this + 4 + ($4 << 5) + 4 | 0;
  HEAP32[$15 >> 2] = $14;
  var $17 = HEAP32[$this + 140 >> 2];
  var $18 = $this + 4 + ($4 << 5) + 16 | 0;
  HEAP32[$18 >> 2] = $17;
  var $19 = $this + 4 + ($4 << 5) + 8 | 0;
  HEAP32[$19 >> 2] = $17;
  return $5;
}

function __ZN2js11TokenStream7atomizeEP9JSContextRNS_6VectorItLj32ENS_15TempAllocPolicyEEE($cx, $cb_0_1_val, $cb_0_2_val) {
  var $1 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5beginEv($cb_0_1_val);
  var $2 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv($cb_0_2_val);
  var $3 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($cx, $1, $2, 0);
  return $3;
}

function __ZN2js7unicode19IsXMLNamespaceStartEt($ch) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($ch << 16 >> 16 == 95) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2js7unicode8CharInfoEt($ch);
    var $_idx_val = HEAP8[$3 + 4 | 0];
    var $4 = __ZNK2js7unicode13CharacterInfo22isCombiningSpacingMarkEv($_idx_val);
    if ($4) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZN2js7unicode17IsIdentifierStartEt($ch);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7unicode13IsXMLNamePartEt($ch) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($ch << 16 >> 16 == 46 || $ch << 16 >> 16 == 45 || $ch << 16 >> 16 == 95 || $ch << 16 >> 16 == 58) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $2 = __ZN2js7unicode8CharInfoEt($ch);
    var $_idx_val = HEAP8[$2 + 4 | 0];
    var $3 = __ZNK2js7unicode13CharacterInfo15isEnclosingMarkEv($_idx_val);
    if ($3) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js7unicode16IsIdentifierPartEt($ch);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream8peekCharEv($this) {
  var $1 = __ZN2js11TokenStream7getCharEv($this);
  __ZN2js11TokenStream9ungetCharEi($this, $1);
  return $1;
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIcEEbPKT_j($this) {
  var $1 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIcEEbPKT_S6_($this);
  return $1;
}

function __ZN2js11TokenStream9matchCharEi($this, $expect) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11TokenStream7getCharEv($this);
    if (($1 | 0) == ($expect | 0)) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js11TokenStream9ungetCharEi($this, $1);
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream12getXMLMarkupEPNS_9TokenKindEPPNS_5TokenE($this, $ttp, $tpp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cp = __stackBase__;
    var $1 = HEAP32[$tpp >> 2];
    var $2 = __ZN2js11TokenStream9matchCharEi($this, 33);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 2:
    var $4 = $this + 184 | 0;
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE5clearEv($4);
    var $5 = __ZN2js11TokenStream9matchCharEi($this, 45);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    var $7 = __ZN2js11TokenStream9matchCharEi($this, 45);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 4:
    var $8 = __ZN2js11TokenStream7getCharEv($this);
    if (($8 | 0) == 45) {
      __label__ = 5;
      break;
    } else if (($8 | 0) == -1) {
      __label__ = 45;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $10 = __ZN2js11TokenStream9matchCharEi($this, 45);
    if ($10) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $11 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($4, $8);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      var $storemerge = -1;
      __label__ = 46;
      break;
    }
   case 7:
    var $13 = $1 + 24 | 0;
    HEAP32[$13 >> 2] = 184;
    var $tt_0 = 67;
    __label__ = 41;
    break;
   case 8:
    var $15 = __ZN2js11TokenStream9matchCharEi($this, 91);
    if ($15) {
      __label__ = 9;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 9:
    var $17 = $cp | 0;
    var $18 = __ZN2js11TokenStream9peekCharsEiPt($this, 6, $17);
    if ($18 & HEAP16[$17 >> 1] << 16 >> 16 == 67) {
      __label__ = 10;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 10:
    var $22 = $cp + 2 | 0;
    if (HEAP16[$22 >> 1] << 16 >> 16 == 68) {
      __label__ = 11;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 11:
    if (HEAP16[$cp + 4 >> 1] << 16 >> 16 == 65) {
      __label__ = 12;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 12:
    if (HEAP16[$cp + 6 >> 1] << 16 >> 16 == 84) {
      __label__ = 13;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 13:
    if (HEAP16[$cp + 8 >> 1] << 16 >> 16 == 65) {
      __label__ = 14;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 14:
    if (HEAP16[$cp + 10 >> 1] << 16 >> 16 == 91) {
      __label__ = 15;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 15:
    __ZN2js11TokenStream9skipCharsEi($this, 6);
    __label__ = 16;
    break;
   case 16:
    var $43 = __ZN2js11TokenStream7getCharEv($this);
    if (($43 | 0) == 93) {
      __label__ = 17;
      break;
    } else if (($43 | 0) == -1) {
      __label__ = 45;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 17:
    var $45 = __ZN2js11TokenStream9peekCharsEiPt($this, 2, $17);
    if ($45 & HEAP16[$17 >> 1] << 16 >> 16 == 93) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    if (HEAP16[$22 >> 1] << 16 >> 16 == 62) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $51 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($4, $43);
    if ($51) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      var $storemerge = -1;
      __label__ = 46;
      break;
    }
   case 20:
    var $53 = __ZN2js11TokenStream7getCharEv($this);
    var $54 = $1 + 24 | 0;
    HEAP32[$54 >> 2] = 183;
    var $tt_0 = 68;
    __label__ = 41;
    break;
   case 21:
    var $56 = __ZN2js11TokenStream9matchCharEi($this, 63);
    if ($56) {
      __label__ = 22;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 22:
    var $58 = $this + 184 | 0;
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE5clearEv($58);
    var $_idx2 = $this + 192 | 0;
    var $contentIndex_0 = -1;
    var $targetLength_0 = 0;
    var $inTarget_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $inTarget_0;
    var $targetLength_0;
    var $contentIndex_0;
    var $60 = __ZN2js11TokenStream7getCharEv($this);
    if (($60 | 0) == 63) {
      __label__ = 24;
      break;
    } else if (($60 | 0) == -1) {
      __label__ = 45;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $62 = __ZN2js11TokenStream8peekCharEv($this);
    if (($62 | 0) == 62) {
      __label__ = 36;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    if (($inTarget_0 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $66 = $60 & 65535;
    var $67 = __ZN2js7unicode10IsXMLSpaceEt($66);
    var $_idx4_val = HEAP32[$_idx2 >> 2];
    var $68 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5emptyEv($_idx4_val);
    if ($67) {
      __label__ = 27;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 27:
    if ($68) {
      __label__ = 45;
      break;
    } else {
      var $contentIndex_1 = $contentIndex_0;
      var $targetLength_1 = $targetLength_0;
      var $inTarget_1 = 0;
      __label__ = 35;
      break;
    }
   case 28:
    if ($68) {
      __label__ = 29;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 29:
    var $72 = __ZN2js7unicode19IsXMLNamespaceStartEt($66);
    if ($72) {
      __label__ = 31;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 30:
    var $74 = __ZN2js7unicode18IsXMLNamespacePartEt($66);
    if ($74) {
      __label__ = 31;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 31:
    var $contentIndex_1 = $contentIndex_0;
    var $targetLength_1 = $targetLength_0 + 1 | 0;
    var $inTarget_1 = $inTarget_0;
    __label__ = 35;
    break;
   case 32:
    if (($contentIndex_0 | 0) < 0) {
      __label__ = 33;
      break;
    } else {
      var $contentIndex_1 = $contentIndex_0;
      var $targetLength_1 = $targetLength_0;
      var $inTarget_1 = 0;
      __label__ = 35;
      break;
    }
   case 33:
    var $80 = $60 & 65535;
    var $81 = __ZN2js7unicode10IsXMLSpaceEt($80);
    if ($81) {
      var $contentIndex_1 = $contentIndex_0;
      var $targetLength_1 = $targetLength_0;
      var $inTarget_1 = 0;
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $83 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv($_idx2_val);
    var $contentIndex_1 = $83;
    var $targetLength_1 = $targetLength_0;
    var $inTarget_1 = $inTarget_0;
    __label__ = 35;
    break;
   case 35:
    var $inTarget_1;
    var $targetLength_1;
    var $contentIndex_1;
    var $85 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($58, $60);
    if ($85) {
      var $contentIndex_0 = $contentIndex_1;
      var $targetLength_0 = $targetLength_1;
      var $inTarget_0 = $inTarget_1;
      __label__ = 23;
      break;
    } else {
      var $_0 = 0;
      var $storemerge = -1;
      __label__ = 46;
      break;
    }
   case 36:
    if (($targetLength_0 | 0) == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $91 = HEAP32[$this >> 2];
    if (($contentIndex_0 | 0) < 0) {
      __label__ = 38;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 38:
    var $atom_0 = HEAP32[HEAP32[$91 + 52 >> 2] + 209972 >> 2] | 0;
    __label__ = 40;
    break;
   case 39:
    var $_idx3_val = HEAP32[$this + 188 >> 2];
    var $99 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5beginEv($_idx3_val);
    var $100 = $99 + ($contentIndex_0 << 1) | 0;
    var $_idx1_val = HEAP32[$_idx2 >> 2];
    var $101 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv($_idx1_val);
    var $102 = $101 - $contentIndex_0 | 0;
    var $103 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($91, $100, $102, 0);
    if (($103 | 0) == 0) {
      var $_0 = 0;
      var $storemerge = -1;
      __label__ = 46;
      break;
    } else {
      var $atom_0 = $103;
      __label__ = 40;
      break;
    }
   case 40:
    var $atom_0;
    var $_idx_val = HEAP32[$_idx2 >> 2];
    var $106 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv($_idx_val);
    var $107 = $106 - $targetLength_0 | 0;
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE8shrinkByEj($58, $107);
    var $108 = $1 + 24 | 0;
    HEAP32[$108 >> 2] = $atom_0;
    var $tt_0 = 69;
    __label__ = 41;
    break;
   case 41:
    var $tt_0;
    var $110 = __ZN2js11TokenStream9matchCharEi($this, 62);
    if ($110) {
      __label__ = 42;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 42:
    var $113 = HEAP32[$this >> 2];
    var $_idx5_val = HEAP32[$this + 188 >> 2];
    var $_idx6_val = HEAP32[$this + 192 >> 2];
    var $114 = __ZN2js11TokenStream7atomizeEP9JSContextRNS_6VectorItLj32ENS_15TempAllocPolicyEEE($113, $_idx5_val, $_idx6_val);
    if (($114 | 0) == 0) {
      var $_0 = 0;
      var $storemerge = -1;
      __label__ = 46;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    var $117 = $1 + 28 | 0;
    HEAP32[$117 >> 2] = $114;
    var $119 = HEAP32[$this + 140 >> 2];
    var $120 = $1 + 16 | 0;
    HEAP32[$120 >> 2] = $119;
    var $_0 = 1;
    var $storemerge = $tt_0;
    __label__ = 46;
    break;
   case 44:
    var $122 = __ZN2js11TokenStream9matchCharEi($this, 47);
    var $123 = $122 ? 60 : 59;
    var $_0 = 1;
    var $storemerge = $123;
    __label__ = 46;
    break;
   case 45:
    var $124 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($this, 0, 0, 170, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    var $storemerge = -1;
    __label__ = 46;
    break;
   case 46:
    var $storemerge;
    var $_0;
    HEAP32[$ttp >> 2] = $storemerge;
    HEAP32[$tpp >> 2] = $1;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11TokenStream12getXMLMarkupEPNS_9TokenKindEPPNS_5TokenE["X"] = 1;

function __ZN2js11TokenStream9skipCharsEi($this, $n) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($n | 0) > 0) {
      var $_01 = $n;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_01;
    var $2 = $_01 - 1 | 0;
    var $3 = __ZN2js11TokenStream7getCharEv($this);
    if (($2 | 0) > 0) {
      var $_01 = $2;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7unicode18IsXMLNamespacePartEt($ch) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($ch << 16 >> 16 == 46 || $ch << 16 >> 16 == 45 || $ch << 16 >> 16 == 95) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $2 = __ZN2js7unicode8CharInfoEt($ch);
    var $_idx_val = HEAP8[$2 + 4 | 0];
    var $3 = __ZNK2js7unicode13CharacterInfo15isEnclosingMarkEv($_idx_val);
    if ($3) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js7unicode16IsIdentifierPartEt($ch);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream17peekUnicodeEscapeEPi($this, $result) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cp = __stackBase__;
    var $1 = $cp | 0;
    var $2 = __ZN2js11TokenStream9peekCharsEiPt($this, 5, $1);
    if ($2 & HEAP16[$1 >> 1] << 16 >> 16 == 117) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 2:
    var $7 = HEAPU16[$cp + 2 >> 1];
    if (($7 & 65535) < 128) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 3:
    var $10 = $7 & 65535;
    var $11 = _isxdigit($10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = HEAPU16[$cp + 4 >> 1];
    if (($15 & 65535) < 128) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 5:
    var $18 = $15 & 65535;
    var $19 = _isxdigit($18);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = HEAPU16[$cp + 6 >> 1];
    if (($23 & 65535) < 128) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 7:
    var $26 = $23 & 65535;
    var $27 = _isxdigit($26);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAPU16[$cp + 8 >> 1];
    if (($31 & 65535) < 128) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 9:
    var $34 = $31 & 65535;
    var $35 = _isxdigit($34);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = $10 - 48 | 0;
    if ($38 >>> 0 < 10) {
      var $44 = $38;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $41 = _tolower($10);
    var $44 = $41 - 87 | 0;
    __label__ = 12;
    break;
   case 12:
    var $44;
    var $45 = $44 << 4;
    var $46 = $18 - 48 | 0;
    if ($46 >>> 0 < 10) {
      var $52 = $46;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $49 = _tolower($18);
    var $52 = $49 - 87 | 0;
    __label__ = 14;
    break;
   case 14:
    var $52;
    var $54 = $52 + $45 << 4;
    var $55 = $26 - 48 | 0;
    if ($55 >>> 0 < 10) {
      var $61 = $55;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $58 = _tolower($26);
    var $61 = $58 - 87 | 0;
    __label__ = 16;
    break;
   case 16:
    var $61;
    var $63 = $61 + $54 << 4;
    var $64 = $34 - 48 | 0;
    if ($64 >>> 0 < 10) {
      var $70 = $64;
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $67 = _tolower($34);
    var $70 = $67 - 87 | 0;
    __label__ = 18;
    break;
   case 18:
    var $70;
    HEAP32[$result >> 2] = $70 + $63 | 0;
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11TokenStream17peekUnicodeEscapeEPi["X"] = 1;

function __ZN2js11TokenStream25matchUnicodeEscapeIdStartEPi($this, $cp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11TokenStream17peekUnicodeEscapeEPi($this, $cp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = HEAP32[$cp >> 2] & 65535;
    var $5 = __ZN2js7unicode17IsIdentifierStartEt($4);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js11TokenStream9skipCharsEi($this, 5);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream23matchUnicodeEscapeIdentEPi($this, $cp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11TokenStream17peekUnicodeEscapeEPi($this, $cp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = HEAP32[$cp >> 2] & 65535;
    var $5 = __ZN2js7unicode16IsIdentifierPartEt($4);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js11TokenStream9skipCharsEi($this, 5);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZL10CharsMatchPKtPKc($p, $q) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $p;
    var $_02 = $q;
    __label__ = 2;
    break;
   case 2:
    var $_02;
    var $_01;
    var $2 = HEAPU8[$_02];
    if ($2 << 24 >> 24 == 0) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAPU16[$_01 >> 1] & 65535 | 0) == ($2 << 24 >> 24 | 0)) {
      var $_01 = $_01 + 2 | 0;
      var $_02 = $_02 + 1 | 0;
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream8TokenBuf23setAddressOfNextRawCharEPKt($this, $a) {
  HEAP32[$this + 8 >> 2] = $a;
  return;
}

function __ZN2js11TokenStream9getAtLineEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 1036;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $filenameBuf = __stackBase__ + 12;
    var $1 = __stackBase__ | 0;
    var $2 = __ZN2js11TokenStream9peekCharsEiPt($this, 5, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 2:
    var $4 = __ZL10CharsMatchPKtPKc($1, STRING_TABLE.__str3585 | 0);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 3:
    __ZN2js11TokenStream9skipCharsEi($this, 5);
    __label__ = 4;
    break;
   case 4:
    var $7 = __ZN2js11TokenStream7getCharEv($this);
    if (($7 | 0) == 10 || ($7 | 0) == -1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = $7 & 65535;
    var $10 = __ZN2js7unicode13IsSpaceOrBOM2Et($9);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $11 = $7 - 48 | 0;
    if ($11 >>> 0 < 10) {
      var $line_0 = $11;
      __label__ = 7;
      break;
    } else {
      var $c_2 = $7;
      __label__ = 27;
      break;
    }
   case 7:
    var $line_0;
    var $14 = __ZN2js11TokenStream7getCharEv($this);
    if (($14 | 0) != -1 & ($14 - 48 | 0) >>> 0 < 10) {
      __label__ = 8;
      break;
    } else {
      var $c_0 = $14;
      __label__ = 9;
      break;
    }
   case 8:
    var $21 = $line_0 * 10 - 48 + $14 | 0;
    if ($21 >>> 0 < $line_0 >>> 0) {
      var $_0 = 1;
      __label__ = 28;
      break;
    } else {
      var $line_0 = $21;
      __label__ = 7;
      break;
    }
   case 9:
    var $c_0;
    if (($c_0 | 0) == 10 || ($c_0 | 0) == -1) {
      var $c_1 = $c_0;
      var $i_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $25 = __ZN2js7unicode13IsSpaceOrBOM2Et($c_0 & 65535);
    if ($25) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $27 = __ZN2js11TokenStream7getCharEv($this);
    var $c_0 = $27;
    __label__ = 9;
    break;
   case 12:
    if (($c_0 | 0) == 34) {
      var $i_0 = 0;
      __label__ = 13;
      break;
    } else {
      var $c_1 = $c_0;
      var $i_1 = 0;
      __label__ = 20;
      break;
    }
   case 13:
    var $i_0;
    var $29 = __ZN2js11TokenStream7getCharEv($this);
    if (($29 | 0) == -1) {
      __label__ = 14;
      break;
    } else if (($29 | 0) == 10) {
      __label__ = 15;
      break;
    } else if (($29 | 0) == 34) {
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    HEAP8[$filenameBuf + $i_0 | 0] = 0;
    var $i_139 = $i_0;
    var $c_140 = -1;
    __label__ = 21;
    break;
   case 15:
    __ZN2js11TokenStream9ungetCharEi($this, 10);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 16:
    if ($29 >>> 0 > 255 | $i_0 >>> 0 > 1022) {
      var $_0 = 1;
      __label__ = 28;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    HEAP8[$filenameBuf + $i_0 | 0] = $29 & 255;
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 13;
    break;
   case 18:
    var $39 = __ZN2js11TokenStream7getCharEv($this);
    if (($39 | 0) == 10 || ($39 | 0) == -1) {
      var $c_1 = $39;
      var $i_1 = $i_0;
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $41 = $39 & 65535;
    var $42 = __ZN2js7unicode13IsSpaceOrBOM2Et($41);
    if ($42) {
      __label__ = 18;
      break;
    } else {
      var $c_1 = $39;
      var $i_1 = $i_0;
      __label__ = 20;
      break;
    }
   case 20:
    var $i_1;
    var $c_1;
    HEAP8[$filenameBuf + $i_1 | 0] = 0;
    if (($c_1 | 0) == -1 || ($c_1 | 0) == 10) {
      var $i_139 = $i_1;
      var $c_140 = $c_1;
      __label__ = 21;
      break;
    } else {
      var $c_2 = $c_1;
      __label__ = 27;
      break;
    }
   case 21:
    var $c_140;
    var $i_139;
    if (($i_139 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $47 = $this + 144 | 0;
    var $_pre = $this + 172 | 0;
    if ((HEAP32[$47 >> 2] & 256 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $52 = HEAP32[$_pre >> 2];
    __ZN9JSContext5free_EPv($52);
    __label__ = 24;
    break;
   case 24:
    var $54 = HEAP32[$this >> 2];
    var $55 = $filenameBuf | 0;
    var $56 = _JS_strdup($54, $55);
    HEAP32[$_pre >> 2] = $56;
    if (($56 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $60 = HEAP32[$47 >> 2] | 256;
    HEAP32[$47 >> 2] = $60;
    __label__ = 26;
    break;
   case 26:
    HEAP32[$this + 140 >> 2] = $line_0;
    var $c_2 = $c_140;
    __label__ = 27;
    break;
   case 27:
    var $c_2;
    __ZN2js11TokenStream9ungetCharEi($this, $c_2);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11TokenStream9getAtLineEv["X"] = 1;

function __ZN2js7unicode13IsSpaceOrBOM2Et($ch) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($ch & 65535) < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = STRING_TABLE._js_isspace + ($ch & 65535) | 0;
    var $_0 = (HEAP8[$4] & 1) << 24 >> 24 != 0;
    __label__ = 5;
    break;
   case 3:
    if ($ch << 16 >> 16 == 160 || $ch << 16 >> 16 == -2) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZN2js7unicode8CharInfoEt($ch);
    var $_idx_val = HEAP8[$10 + 4 | 0];
    var $11 = __ZNK2js7unicode13CharacterInfo7isSpaceEv($_idx_val);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream21getAtSourceMappingURLEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__ | 0;
    var $2 = __ZN2js11TokenStream9peekCharsEiPt($this, 18, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 15;
      break;
    }
   case 2:
    var $4 = __ZL10CharsMatchPKtPKc($1, STRING_TABLE.__str13586 | 0);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 15;
      break;
    }
   case 3:
    __ZN2js11TokenStream9skipCharsEi($this, 18);
    var $6 = $this + 184 | 0;
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE5clearEv($6);
    __label__ = 4;
    break;
   case 4:
    var $8 = __ZN2js11TokenStream7getCharEv($this);
    var $9 = $8 & 65535;
    var $10 = __ZN2js7unicode13IsSpaceOrBOM2Et($9);
    if ($10) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $8 << 24 >> 24;
    if (($12 | 0) == 0 || ($12 | 0) == -1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendItEEbT_($6, $9);
    __label__ = 4;
    break;
   case 7:
    var $_idx1_val = HEAP32[$this + 192 >> 2];
    var $14 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5emptyEv($_idx1_val);
    if ($14) {
      var $_0 = 1;
      __label__ = 15;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $16 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv($_idx1_val);
    var $17 = $this + 176 | 0;
    var $18 = HEAP32[$17 >> 2];
    if (($18 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $21 = $18;
    __ZN9JSContext5free_EPv($21);
    __label__ = 10;
    break;
   case 10:
    var $24 = HEAP32[$this >> 2];
    var $26 = ($16 << 1) + 2 | 0;
    var $27 = __ZN9JSContext7malloc_Ej($24, $26);
    var $28 = $27;
    HEAP32[$17 >> 2] = $28;
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    if (($16 | 0) > 0) {
      __label__ = 12;
      break;
    } else {
      var $36 = $28;
      __label__ = 14;
      break;
    }
   case 12:
    var $_idx2 = $this + 188 | 0;
    var $i_02 = 0;
    var $31 = $28;
    __label__ = 13;
    break;
   case 13:
    var $31;
    var $i_02;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $32 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEEixEj($_idx2_val, $i_02);
    var $33 = HEAP16[$32 >> 1];
    HEAP16[$31 + ($i_02 << 1) >> 1] = $33;
    var $35 = $i_02 + 1 | 0;
    var $_pre = HEAP32[$17 >> 2];
    if (($35 | 0) == ($16 | 0)) {
      var $36 = $_pre;
      __label__ = 14;
      break;
    } else {
      var $i_02 = $35;
      var $31 = $_pre;
      __label__ = 13;
      break;
    }
   case 14:
    var $36;
    HEAP16[$36 + ($16 << 1) >> 1] = 0;
    var $_0 = 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11TokenStream21getAtSourceMappingURLEv["X"] = 1;

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendItEEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendItEEvT_($this, $t);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEEixEj($this_0_1_val, $i) {
  var $1 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5beginEv($this_0_1_val);
  return $1 + ($i << 1) | 0;
}

function __ZN2js11TokenStream18putIdentInTokenbufEPKt($this, $identStart) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $qc = __stackBase__;
    var $1 = $this + 156 | 0;
    var $_idx_val = HEAP32[$this + 164 >> 2];
    var $2 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($_idx_val);
    __ZN2js11TokenStream8TokenBuf23setAddressOfNextRawCharEPKt($1, $identStart);
    var $3 = $this + 184 | 0;
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE5clearEv($3);
    __label__ = 2;
    break;
   case 2:
    var $5 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    var $6 = $5 & 65535;
    var $7 = __ZN2js7unicode16IsIdentifierPartEt($6);
    if ($7) {
      var $c_0 = $5;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($5 | 0) == 92) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $11 = __ZN2js11TokenStream23matchUnicodeEscapeIdentEPi($this, $qc);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $c_0 = HEAP32[$qc >> 2];
    __label__ = 6;
    break;
   case 6:
    var $c_0;
    var $15 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($3, $c_0);
    if ($15) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2js11TokenStream8TokenBuf23setAddressOfNextRawCharEPKt($1, $2);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 8:
    __ZN2js11TokenStream8TokenBuf23setAddressOfNextRawCharEPKt($1, $2);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream16getTokenInternalEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tt = __stackBase__;
    var $qc = __stackBase__ + 4;
    var $tp = __stackBase__ + 8;
    var $cp = __stackBase__ + 12;
    var $cp1 = __stackBase__ + 20;
    var $dval = __stackBase__ + 24;
    var $dummy = __stackBase__ + 32;
    var $dval3 = __stackBase__ + 36;
    var $dummy4 = __stackBase__ + 44;
    var $buf = __stackBase__ + 48;
    var $buf5 = __stackBase__ + 52;
    var $1 = $this + 144 | 0;
    if ((HEAP32[$1 >> 2] & 1536 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 156 | 0;
    var $6 = $this + 132 | 0;
    var $7 = $this | 0;
    var $8 = $this + 140 | 0;
    var $_idx15 = $this + 160 | 0;
    var $_idx16 = $this + 164 | 0;
    __label__ = 5;
    break;
   case 3:
    var $10 = __ZN2js11TokenStream15getXMLTextOrTagEPNS_9TokenKindEPPNS_5TokenE($this, $tt, $tp);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 4:
    var $_idx1_pre_phi = $this + 164 | 0;
    __label__ = 263;
    break;
   case 5:
    var $_idx15_val = HEAP32[$_idx15 >> 2];
    var $_idx16_val = HEAP32[$_idx16 >> 2];
    var $11 = __ZNK2js11TokenStream8TokenBuf11hasRawCharsEv($_idx15_val, $_idx16_val);
    if ($11) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $13 = __ZN2js11TokenStream8newTokenEi($this, 0);
    HEAP32[$tp >> 2] = $13;
    HEAP32[$tt >> 2] = 0;
    var $15 = HEAP32[$1 >> 2] | 2;
    HEAP32[$1 >> 2] = $15;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 7:
    var $17 = __ZN2js11TokenStream8TokenBuf10getRawCharEv($5);
    var $18 = $17 & 65535;
    if (($17 & 65535) > 127) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $21 = __ZN2js7unicode13IsSpaceOrBOM2Et($17);
    if ($21) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    if (($17 - 8232 & 65535 & 65535) < 2) {
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 10:
    __ZN2js11TokenStream20updateLineInfoForEOLEv($this);
    __ZN2js11TokenStream17updateFlagsForEOLEv($this);
    __label__ = 5;
    break;
   case 11:
    var $26 = __ZN2js11TokenStream8newTokenEi($this, -1);
    HEAP32[$tp >> 2] = $26;
    var $27 = __ZN2js7unicode8IsLetterEt($17);
    if ($27) {
      __label__ = 12;
      break;
    } else {
      __label__ = 262;
      break;
    }
   case 12:
    var $_idx12_val = HEAP32[$_idx16 >> 2];
    var $29 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($_idx12_val);
    var $identStart_0_ph = $29 - 2 | 0;
    var $hadUnicodeEscape_0_ph = 0;
    __label__ = 21;
    break;
   case 13:
    var $32 = STRING_TABLE.__ZL14firstCharKinds + $18 | 0;
    var $33 = HEAPU8[$32];
    if (($33 & 255) > 9) {
      __label__ = 14;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 14:
    if ($17 << 16 >> 16 == 13) {
      __label__ = 15;
      break;
    } else if ($17 << 16 >> 16 == 10) {
      __label__ = 17;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 15:
    var $_idx13_val = HEAP32[$_idx15 >> 2];
    var $_idx14_val = HEAP32[$_idx16 >> 2];
    var $37 = __ZNK2js11TokenStream8TokenBuf11hasRawCharsEv($_idx13_val, $_idx14_val);
    if ($37) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    __ZN2js11TokenStream8TokenBuf12matchRawCharEt($5);
    __label__ = 17;
    break;
   case 17:
    __ZN2js11TokenStream20updateLineInfoForEOLEv($this);
    __ZN2js11TokenStream17updateFlagsForEOLEv($this);
    __label__ = 5;
    break;
   case 18:
    var $41 = __ZN2js11TokenStream8newTokenEi($this, -1);
    HEAP32[$tp >> 2] = $41;
    if ($33 << 24 >> 24 == 1) {
      __label__ = 19;
      break;
    } else if ($33 << 24 >> 24 == 2) {
      __label__ = 20;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 19:
    HEAP32[$tt >> 2] = HEAP8[$this + ($18 + 264) | 0] << 24 >> 24;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 20:
    var $_idx11_val = HEAP32[$_idx16 >> 2];
    var $47 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($_idx11_val);
    var $identStart_0_ph = $47 - 2 | 0;
    var $hadUnicodeEscape_0_ph = 0;
    __label__ = 21;
    break;
   case 21:
    var $hadUnicodeEscape_0_ph;
    var $identStart_0_ph;
    var $hadUnicodeEscape_0_ph56 = $hadUnicodeEscape_0_ph;
    __label__ = 22;
    break;
   case 22:
    var $hadUnicodeEscape_0_ph56;
    __label__ = 23;
    break;
   case 23:
    var $50 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    if (($50 | 0) == -1) {
      __label__ = 27;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $53 = $50 & 65535;
    var $54 = __ZN2js7unicode16IsIdentifierPartEt($53);
    if ($54) {
      __label__ = 23;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    if (($50 | 0) == 92) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $58 = __ZN2js11TokenStream23matchUnicodeEscapeIdentEPi($this, $qc);
    if ($58) {
      var $hadUnicodeEscape_0_ph56 = 1;
      __label__ = 22;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, $50);
    if ($hadUnicodeEscape_0_ph56 << 24 >> 24 == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 28:
    var $61 = HEAP32[$1 >> 2];
    if (($61 & 32 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $_pre_phi = $identStart_0_ph;
    __label__ = 40;
    break;
   case 30:
    var $_idx10_val = HEAP32[$_idx16 >> 2];
    var $65 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($_idx10_val);
    var $67 = $identStart_0_ph;
    var $69 = $65 - $67 >> 1;
    var $70 = __ZN2js11FindKeywordEPKtj($identStart_0_ph, $69);
    if (($70 | 0) == 0) {
      var $_pre_phi = $67;
      __label__ = 40;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $74 = HEAP32[$70 + 4 >> 2];
    if (($74 | 0) == 86) {
      __label__ = 32;
      break;
    } else if (($74 | 0) == 87) {
      __label__ = 33;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 32:
    var $77 = HEAP32[$70 >> 2];
    var $78 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($this, 0, 0, 132, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $77, tempInt));
    if ($78) {
      var $_pre_phi = $67;
      __label__ = 40;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 33:
    var $80 = __ZN2js11TokenStream12isStrictModeEv($61);
    var $82 = HEAP32[$70 >> 2];
    if ($80) {
      __label__ = 34;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 34:
    var $84 = HEAP32[$7 >> 2];
    var $85 = __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($84, $this, 0, 0, 132, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $82, tempInt));
    if ($85) {
      var $_pre_phi = $67;
      __label__ = 40;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 35:
    var $87 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($this, 0, 5, 132, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $82, tempInt));
    if ($87) {
      var $_pre_phi = $67;
      __label__ = 40;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 36:
    var $90 = HEAP32[$70 + 12 >> 2];
    var $this_idx18_val = HEAP32[$this + 904 >> 2];
    var $91 = __ZNK2js11TokenStream13versionNumberEv($this_idx18_val);
    if (($90 | 0) > ($91 | 0)) {
      __label__ = 38;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    HEAP32[$tt >> 2] = $74;
    var $95 = HEAP32[$70 + 8 >> 2];
    var $97 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$97 >> 2] = $95;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 38:
    if (($74 | 0) == 81 || ($74 | 0) == 77) {
      __label__ = 39;
      break;
    } else {
      var $_pre_phi = $67;
      __label__ = 40;
      break;
    }
   case 39:
    var $100 = HEAP32[$7 >> 2];
    var $102 = HEAP32[$70 >> 2];
    var $103 = __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($100, $this, 0, 0, 132, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $102, tempInt));
    if ($103) {
      var $_pre_phi = $67;
      __label__ = 40;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 40:
    var $_pre_phi;
    var $104 = HEAP32[$7 >> 2];
    var $_idx9_val = HEAP32[$_idx16 >> 2];
    var $105 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($_idx9_val);
    var $108 = $105 - $_pre_phi >> 1;
    var $109 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($104, $identStart_0_ph, $108, 0);
    var $atom_0 = $109;
    __label__ = 43;
    break;
   case 41:
    var $110 = __ZN2js11TokenStream18putIdentInTokenbufEPKt($this, $identStart_0_ph);
    if ($110) {
      __label__ = 42;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 42:
    var $112 = HEAP32[$7 >> 2];
    var $_idx22_val = HEAP32[$this + 188 >> 2];
    var $_idx23_val = HEAP32[$this + 192 >> 2];
    var $113 = __ZN2js11TokenStream7atomizeEP9JSContextRNS_6VectorItLj32ENS_15TempAllocPolicyEEE($112, $_idx22_val, $_idx23_val);
    var $atom_0 = $113;
    __label__ = 43;
    break;
   case 43:
    var $atom_0;
    if (($atom_0 | 0) == 0) {
      __label__ = 264;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $118 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$118 >> 2] = 59;
    var $120 = HEAP32[$tp >> 2] + 28 | 0;
    HEAP32[$120 >> 2] = $atom_0;
    HEAP32[$tt >> 2] = 29;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 45:
    if ($17 << 16 >> 16 == 46) {
      __label__ = 46;
      break;
    } else if ($17 << 16 >> 16 == 61) {
      __label__ = 51;
      break;
    } else if ($17 << 16 >> 16 == 39 || $17 << 16 >> 16 == 34) {
      __label__ = 54;
      break;
    } else {
      __label__ = 109;
      break;
    }
   case 46:
    var $123 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    if (($123 - 48 | 0) >>> 0 < 10) {
      __label__ = 47;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 47:
    var $_idx8_val = HEAP32[$_idx16 >> 2];
    var $127 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($_idx8_val);
    var $numStart_1 = $127 - 4 | 0;
    __label__ = 114;
    break;
   case 48:
    if (($123 | 0) == 46) {
      __label__ = 49;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 49:
    HEAP32[$tt >> 2] = 73;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 50:
    __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, $123);
    HEAP32[$tt >> 2] = 22;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 51:
    var $134 = __ZN2js11TokenStream9matchCharEi($this, 61);
    if ($134) {
      __label__ = 52;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 52:
    var $136 = __ZN2js11TokenStream9matchCharEi($this, 61);
    var $137 = $136 ? 72 : 18;
    var $139 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$139 >> 2] = $137;
    HEAP32[$tt >> 2] = 12;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 53:
    var $142 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$142 >> 2] = 0;
    HEAP32[$tt >> 2] = 4;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 54:
    HEAP32[$qc >> 2] = $18;
    var $144 = $this + 184 | 0;
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE5clearEv($144);
    var $145 = $cp | 0;
    var $146 = $cp + 2 | 0;
    var $147 = $cp + 4 | 0;
    var $148 = $cp + 6 | 0;
    var $149 = $cp1 | 0;
    var $150 = $cp1 + 2 | 0;
    __label__ = 55;
    break;
   case 55:
    var $151 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    if (HEAP8[$this + 648 + ($151 & 255) | 0] << 24 >> 24 == 0) {
      var $c_0 = $151;
      __label__ = 106;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    if (($151 | 0) == ($18 | 0)) {
      __label__ = 107;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    if (($151 | 0) == 92) {
      __label__ = 58;
      break;
    } else {
      __label__ = 104;
      break;
    }
   case 58:
    var $161 = __ZN2js11TokenStream7getCharEv($this);
    if (($161 | 0) == 102) {
      __label__ = 59;
      break;
    } else if (($161 | 0) == 110) {
      __label__ = 60;
      break;
    } else if (($161 | 0) == 114) {
      __label__ = 61;
      break;
    } else if (($161 | 0) == 116) {
      __label__ = 62;
      break;
    } else if (($161 | 0) == 118) {
      __label__ = 63;
      break;
    } else if (($161 | 0) == 98) {
      var $c_0 = 8;
      __label__ = 106;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 59:
    var $c_0 = 12;
    __label__ = 106;
    break;
   case 60:
    var $c_0 = 10;
    __label__ = 106;
    break;
   case 61:
    var $c_0 = 13;
    __label__ = 106;
    break;
   case 62:
    var $c_0 = 9;
    __label__ = 106;
    break;
   case 63:
    var $c_0 = 11;
    __label__ = 106;
    break;
   case 64:
    var $_off = $161 - 48 | 0;
    if ($_off >>> 0 < 8) {
      __label__ = 65;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 65:
    var $170 = __ZN2js11TokenStream8peekCharEv($this);
    if (($_off | 0) == 0) {
      __label__ = 66;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 66:
    if (($170 - 48 | 0) >>> 0 < 10) {
      __label__ = 67;
      break;
    } else {
      var $val_0 = $_off;
      __label__ = 72;
      break;
    }
   case 67:
    var $176 = HEAP32[$7 >> 2];
    var $177 = __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($176, $this, 0, 0, 232, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    if ($177) {
      __label__ = 68;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 68:
    __ZN2js11TokenStream23setOctalCharacterEscapeEb($this, 1);
    if (($170 - 48 | 0) >>> 0 < 8) {
      __label__ = 69;
      break;
    } else {
      var $val_0 = $_off;
      __label__ = 72;
      break;
    }
   case 69:
    var $183 = ($_off << 3) - 48 + $170 | 0;
    var $184 = __ZN2js11TokenStream7getCharEv($this);
    var $185 = __ZN2js11TokenStream8peekCharEv($this);
    if (($185 - 48 | 0) >>> 0 < 8) {
      __label__ = 70;
      break;
    } else {
      var $val_0 = $183;
      __label__ = 72;
      break;
    }
   case 70:
    var $190 = ($183 << 3) - 48 + $185 | 0;
    if (($190 | 0) < 256) {
      __label__ = 71;
      break;
    } else {
      var $val_0 = $183;
      __label__ = 72;
      break;
    }
   case 71:
    var $193 = __ZN2js11TokenStream7getCharEv($this);
    var $val_0 = $190;
    __label__ = 72;
    break;
   case 72:
    var $val_0;
    var $c_0 = $val_0 & 65535;
    __label__ = 106;
    break;
   case 73:
    if (($161 | 0) == 10) {
      __label__ = 55;
      break;
    } else if (($161 | 0) == 117) {
      __label__ = 74;
      break;
    } else if (($161 | 0) == 120) {
      __label__ = 93;
      break;
    } else {
      var $c_0 = $161;
      __label__ = 106;
      break;
    }
   case 74:
    var $197 = __ZN2js11TokenStream9peekCharsEiPt($this, 4, $145);
    if ($197) {
      __label__ = 75;
      break;
    } else {
      __label__ = 92;
      break;
    }
   case 75:
    var $199 = HEAPU16[$145 >> 1];
    if (($199 & 65535) < 128) {
      __label__ = 76;
      break;
    } else {
      __label__ = 92;
      break;
    }
   case 76:
    var $202 = $199 & 65535;
    var $203 = _isxdigit($202);
    if (($203 | 0) == 0) {
      __label__ = 92;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 77:
    var $206 = HEAPU16[$146 >> 1];
    if (($206 & 65535) < 128) {
      __label__ = 78;
      break;
    } else {
      __label__ = 92;
      break;
    }
   case 78:
    var $209 = $206 & 65535;
    var $210 = _isxdigit($209);
    if (($210 | 0) == 0) {
      __label__ = 92;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 79:
    var $213 = HEAPU16[$147 >> 1];
    if (($213 & 65535) < 128) {
      __label__ = 80;
      break;
    } else {
      __label__ = 92;
      break;
    }
   case 80:
    var $216 = $213 & 65535;
    var $217 = _isxdigit($216);
    if (($217 | 0) == 0) {
      __label__ = 92;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 81:
    var $220 = HEAPU16[$148 >> 1];
    if (($220 & 65535) < 128) {
      __label__ = 82;
      break;
    } else {
      __label__ = 92;
      break;
    }
   case 82:
    var $223 = $220 & 65535;
    var $224 = _isxdigit($223);
    if (($224 | 0) == 0) {
      __label__ = 92;
      break;
    } else {
      __label__ = 83;
      break;
    }
   case 83:
    var $227 = $202 - 48 | 0;
    if ($227 >>> 0 < 10) {
      var $233 = $227;
      __label__ = 85;
      break;
    } else {
      __label__ = 84;
      break;
    }
   case 84:
    var $230 = _tolower($202);
    var $233 = $230 - 87 | 0;
    __label__ = 85;
    break;
   case 85:
    var $233;
    var $234 = $233 << 4;
    var $235 = $209 - 48 | 0;
    if ($235 >>> 0 < 10) {
      var $241 = $235;
      __label__ = 87;
      break;
    } else {
      __label__ = 86;
      break;
    }
   case 86:
    var $238 = _tolower($209);
    var $241 = $238 - 87 | 0;
    __label__ = 87;
    break;
   case 87:
    var $241;
    var $243 = $241 + $234 << 4;
    var $244 = $216 - 48 | 0;
    if ($244 >>> 0 < 10) {
      var $250 = $244;
      __label__ = 89;
      break;
    } else {
      __label__ = 88;
      break;
    }
   case 88:
    var $247 = _tolower($216);
    var $250 = $247 - 87 | 0;
    __label__ = 89;
    break;
   case 89:
    var $250;
    var $252 = $250 + $243 << 4;
    var $253 = $223 - 48 | 0;
    if ($253 >>> 0 < 10) {
      var $259 = $253;
      __label__ = 91;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 90:
    var $256 = _tolower($223);
    var $259 = $256 - 87 | 0;
    __label__ = 91;
    break;
   case 91:
    var $259;
    var $260 = $259 + $252 | 0;
    __ZN2js11TokenStream9skipCharsEi($this, 4);
    var $c_0 = $260;
    __label__ = 106;
    break;
   case 92:
    var $262 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($this, 0, 0, 270, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str23587 | 0, tempInt));
    __label__ = 264;
    break;
   case 93:
    var $264 = __ZN2js11TokenStream9peekCharsEiPt($this, 2, $149);
    if ($264) {
      __label__ = 94;
      break;
    } else {
      __label__ = 103;
      break;
    }
   case 94:
    var $266 = HEAPU16[$149 >> 1];
    if (($266 & 65535) < 128) {
      __label__ = 95;
      break;
    } else {
      __label__ = 103;
      break;
    }
   case 95:
    var $269 = $266 & 65535;
    var $270 = _isxdigit($269);
    if (($270 | 0) == 0) {
      __label__ = 103;
      break;
    } else {
      __label__ = 96;
      break;
    }
   case 96:
    var $273 = HEAPU16[$150 >> 1];
    if (($273 & 65535) < 128) {
      __label__ = 97;
      break;
    } else {
      __label__ = 103;
      break;
    }
   case 97:
    var $276 = $273 & 65535;
    var $277 = _isxdigit($276);
    if (($277 | 0) == 0) {
      __label__ = 103;
      break;
    } else {
      __label__ = 98;
      break;
    }
   case 98:
    var $280 = $269 - 48 | 0;
    if ($280 >>> 0 < 10) {
      var $286 = $280;
      __label__ = 100;
      break;
    } else {
      __label__ = 99;
      break;
    }
   case 99:
    var $283 = _tolower($269);
    var $286 = $283 - 87 | 0;
    __label__ = 100;
    break;
   case 100:
    var $286;
    var $287 = $286 << 4;
    var $288 = $276 - 48 | 0;
    if ($288 >>> 0 < 10) {
      var $294 = $288;
      __label__ = 102;
      break;
    } else {
      __label__ = 101;
      break;
    }
   case 101:
    var $291 = _tolower($276);
    var $294 = $291 - 87 | 0;
    __label__ = 102;
    break;
   case 102:
    var $294;
    var $295 = $294 + $287 | 0;
    __ZN2js11TokenStream9skipCharsEi($this, 2);
    var $c_0 = $295;
    __label__ = 106;
    break;
   case 103:
    var $297 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($this, 0, 0, 270, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str33588 | 0, tempInt));
    __label__ = 264;
    break;
   case 104:
    var $299 = __ZN2js11TokenStream8TokenBuf12isRawEOLCharEi($151);
    if ($299 | ($151 | 0) == -1) {
      __label__ = 105;
      break;
    } else {
      var $c_0 = $151;
      __label__ = 106;
      break;
    }
   case 105:
    __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, $151);
    var $302 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($this, 0, 0, 138, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 264;
    break;
   case 106:
    var $c_0;
    var $304 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($144, $c_0);
    if ($304) {
      __label__ = 55;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 107:
    var $306 = HEAP32[$7 >> 2];
    var $_idx20_val = HEAP32[$this + 188 >> 2];
    var $_idx21_val = HEAP32[$this + 192 >> 2];
    var $307 = __ZN2js11TokenStream7atomizeEP9JSContextRNS_6VectorItLj32ENS_15TempAllocPolicyEEE($306, $_idx20_val, $_idx21_val);
    if (($307 | 0) == 0) {
      __label__ = 264;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 108:
    var $310 = HEAP32[$8 >> 2];
    var $312 = HEAP32[$tp >> 2] + 16 | 0;
    HEAP32[$312 >> 2] = $310;
    var $314 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$314 >> 2] = 61;
    var $316 = HEAP32[$tp >> 2] + 28 | 0;
    HEAP32[$316 >> 2] = $307;
    HEAP32[$tt >> 2] = 31;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 109:
    if (($18 - 49 | 0) >>> 0 < 9) {
      __label__ = 110;
      break;
    } else {
      __label__ = 129;
      break;
    }
   case 110:
    var $_idx7_val = HEAP32[$_idx16 >> 2];
    var $321 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($_idx7_val);
    var $c_1 = $18;
    var $numStart_0 = $321 - 2 | 0;
    __label__ = 111;
    break;
   case 111:
    var $numStart_0;
    var $c_1;
    if (($c_1 - 48 | 0) >>> 0 < 10) {
      __label__ = 112;
      break;
    } else {
      var $c_2_lcssa = $c_1;
      __label__ = 113;
      break;
    }
   case 112:
    var $326 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    if (($326 - 48 | 0) >>> 0 < 10) {
      __label__ = 112;
      break;
    } else {
      var $c_2_lcssa = $326;
      __label__ = 113;
      break;
    }
   case 113:
    var $c_2_lcssa;
    if (($c_2_lcssa | 0) == 46) {
      var $numStart_1 = $numStart_0;
      __label__ = 114;
      break;
    } else {
      var $c_3 = $c_2_lcssa;
      var $numStart_2 = $numStart_0;
      var $hasFracOrExp_0 = 0;
      __label__ = 116;
      break;
    }
   case 114:
    var $numStart_1;
    __label__ = 115;
    break;
   case 115:
    var $332 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    if (($332 - 48 | 0) >>> 0 < 10) {
      __label__ = 115;
      break;
    } else {
      var $c_3 = $332;
      var $numStart_2 = $numStart_1;
      var $hasFracOrExp_0 = 1;
      __label__ = 116;
      break;
    }
   case 116:
    var $hasFracOrExp_0;
    var $numStart_2;
    var $c_3;
    if (($c_3 | 0) == 101 || ($c_3 | 0) == 69) {
      __label__ = 117;
      break;
    } else {
      var $c_5 = $c_3;
      var $hasFracOrExp_1 = $hasFracOrExp_0;
      __label__ = 122;
      break;
    }
   case 117:
    var $336 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    if (($336 | 0) == 45 || ($336 | 0) == 43) {
      __label__ = 118;
      break;
    } else {
      var $c_4 = $336;
      __label__ = 119;
      break;
    }
   case 118:
    var $338 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    var $c_4 = $338;
    __label__ = 119;
    break;
   case 119:
    var $c_4;
    if (($c_4 - 48 | 0) >>> 0 < 10) {
      __label__ = 121;
      break;
    } else {
      __label__ = 120;
      break;
    }
   case 120:
    __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, $c_4);
    var $343 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($this, 0, 0, 136, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 264;
    break;
   case 121:
    var $344 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    if (($344 - 48 | 0) >>> 0 < 10) {
      __label__ = 121;
      break;
    } else {
      var $c_5 = $344;
      var $hasFracOrExp_1 = 1;
      __label__ = 122;
      break;
    }
   case 122:
    var $hasFracOrExp_1;
    var $c_5;
    __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, $c_5);
    if (($c_5 | 0) == -1) {
      __label__ = 125;
      break;
    } else {
      __label__ = 123;
      break;
    }
   case 123:
    var $350 = __ZN2js7unicode17IsIdentifierStartEt($c_5 & 65535);
    if ($350) {
      __label__ = 124;
      break;
    } else {
      __label__ = 125;
      break;
    }
   case 124:
    var $352 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($this, 0, 0, 161, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 264;
    break;
   case 125:
    var $355 = ($hasFracOrExp_1 & 1) << 24 >> 24 == 0;
    var $356 = HEAP32[$7 >> 2];
    var $_idx6_val = HEAP32[$_idx16 >> 2];
    var $357 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($_idx6_val);
    if ($355) {
      __label__ = 126;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 126:
    var $359 = __ZN2js16GetPrefixIntegerEP9JSContextPKtS3_iPS3_Pd($356, $numStart_2, $357, 10, $dummy, $dval);
    if ($359) {
      __label__ = 128;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 127:
    var $361 = __Z9js_strtodP9JSContextPKtS2_PS2_Pd($356, $numStart_2, $357, $dummy, $dval);
    if (($361 | 0) == 0) {
      __label__ = 264;
      break;
    } else {
      __label__ = 128;
      break;
    }
   case 128:
    var $364 = (tempDoubleI32[0] = HEAP32[$dval >> 2], tempDoubleI32[1] = HEAP32[$dval + 4 >> 2], tempDoubleF64[0]);
    var $367 = HEAP32[$tp >> 2] + 24 | 0;
    tempDoubleF64[0] = $364, HEAP32[$367 >> 2] = tempDoubleI32[0], HEAP32[$367 + 4 >> 2] = tempDoubleI32[1];
    HEAP32[$tt >> 2] = 30;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 129:
    if ($17 << 16 >> 16 == 58) {
      __label__ = 130;
      break;
    } else if ($17 << 16 >> 16 == 43) {
      __label__ = 133;
      break;
    } else if ($17 << 16 >> 16 == 48) {
      __label__ = 138;
      break;
    } else {
      __label__ = 158;
      break;
    }
   case 130:
    var $370 = __ZN2js11TokenStream9matchCharEi($this, 58);
    if ($370) {
      __label__ = 131;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 131:
    HEAP32[$tt >> 2] = 71;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 132:
    var $374 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$374 >> 2] = 0;
    HEAP32[$tt >> 2] = 6;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 133:
    var $376 = __ZN2js11TokenStream9matchCharEi($this, 61);
    if ($376) {
      __label__ = 134;
      break;
    } else {
      __label__ = 135;
      break;
    }
   case 134:
    var $379 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$379 >> 2] = 27;
    HEAP32[$tt >> 2] = 4;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 135:
    var $381 = __ZN2js11TokenStream9matchCharEi($this, 43);
    if ($381) {
      __label__ = 136;
      break;
    } else {
      __label__ = 137;
      break;
    }
   case 136:
    HEAP32[$tt >> 2] = 20;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 137:
    var $385 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$385 >> 2] = 35;
    HEAP32[$tt >> 2] = 15;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 138:
    var $387 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    if (($387 | 0) == 120 || ($387 | 0) == 88) {
      __label__ = 139;
      break;
    } else {
      __label__ = 147;
      break;
    }
   case 139:
    var $389 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    if (($389 | 0) < 128) {
      __label__ = 140;
      break;
    } else {
      __label__ = 141;
      break;
    }
   case 140:
    var $392 = _isxdigit($389);
    if (($392 | 0) == 0) {
      __label__ = 141;
      break;
    } else {
      __label__ = 142;
      break;
    }
   case 141:
    __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, $389);
    var $395 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($this, 0, 0, 7, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 264;
    break;
   case 142:
    var $_idx5_val = HEAP32[$_idx16 >> 2];
    var $397 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($_idx5_val);
    var $398 = $397 - 2 | 0;
    var $c_6 = $389;
    __label__ = 143;
    break;
   case 143:
    var $c_6;
    if (($c_6 | 0) < 128) {
      __label__ = 145;
      break;
    } else {
      __label__ = 144;
      break;
    }
   case 144:
    __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, $c_6);
    var $radix_029 = 16;
    var $numStart_331 = $398;
    var $c_833 = $c_6;
    __label__ = 154;
    break;
   case 145:
    var $402 = _isxdigit($c_6);
    if (($402 | 0) == 0) {
      var $c_8 = $c_6;
      var $numStart_3 = $398;
      var $radix_0 = 16;
      __label__ = 153;
      break;
    } else {
      __label__ = 146;
      break;
    }
   case 146:
    var $405 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    var $c_6 = $405;
    __label__ = 143;
    break;
   case 147:
    var $408 = ($387 - 48 | 0) >>> 0 < 10;
    var $_idx4_val = HEAP32[$_idx16 >> 2];
    var $409 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($_idx4_val);
    var $410 = $409 - 2 | 0;
    if ($408) {
      var $c_7 = $387;
      __label__ = 148;
      break;
    } else {
      var $c_1 = $387;
      var $numStart_0 = $410;
      __label__ = 111;
      break;
    }
   case 148:
    var $c_7;
    if (($c_7 - 48 | 0) >>> 0 < 10) {
      __label__ = 149;
      break;
    } else {
      var $c_8 = $c_7;
      var $numStart_3 = $410;
      var $radix_0 = 8;
      __label__ = 153;
      break;
    }
   case 149:
    var $414 = HEAP32[$7 >> 2];
    var $415 = __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($414, $this, 0, 0, 232, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    if ($415) {
      __label__ = 150;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 150:
    if (($c_7 | 0) > 55) {
      __label__ = 151;
      break;
    } else {
      __label__ = 152;
      break;
    }
   case 151:
    var $_str43589__str53590 = ($c_7 | 0) == 56 ? STRING_TABLE.__str43589 : STRING_TABLE.__str53590;
    var $420 = $_str43589__str53590 | 0;
    var $421 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($this, 0, 1, 145, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $420, tempInt));
    if ($421) {
      var $c_1 = $c_7;
      var $numStart_0 = $410;
      __label__ = 111;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 152:
    var $423 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    var $c_7 = $423;
    __label__ = 148;
    break;
   case 153:
    var $radix_0;
    var $numStart_3;
    var $c_8;
    __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, $c_8);
    if (($c_8 | 0) == -1) {
      var $radix_030 = $radix_0;
      var $numStart_332 = $numStart_3;
      __label__ = 156;
      break;
    } else {
      var $radix_029 = $radix_0;
      var $numStart_331 = $numStart_3;
      var $c_833 = $c_8;
      __label__ = 154;
      break;
    }
   case 154:
    var $c_833;
    var $numStart_331;
    var $radix_029;
    var $427 = __ZN2js7unicode17IsIdentifierStartEt($c_833 & 65535);
    if ($427) {
      __label__ = 155;
      break;
    } else {
      var $radix_030 = $radix_029;
      var $numStart_332 = $numStart_331;
      __label__ = 156;
      break;
    }
   case 155:
    var $429 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($this, 0, 0, 161, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 264;
    break;
   case 156:
    var $numStart_332;
    var $radix_030;
    var $431 = HEAP32[$7 >> 2];
    var $_idx3_val = HEAP32[$_idx16 >> 2];
    var $432 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($_idx3_val);
    var $433 = __ZN2js16GetPrefixIntegerEP9JSContextPKtS3_iPS3_Pd($431, $numStart_332, $432, $radix_030, $dummy4, $dval3);
    if ($433) {
      __label__ = 157;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 157:
    var $435 = (tempDoubleI32[0] = HEAP32[$dval3 >> 2], tempDoubleI32[1] = HEAP32[$dval3 + 4 >> 2], tempDoubleF64[0]);
    var $438 = HEAP32[$tp >> 2] + 24 | 0;
    tempDoubleF64[0] = $435, HEAP32[$438 >> 2] = tempDoubleI32[0], HEAP32[$438 + 4 >> 2] = tempDoubleI32[1];
    HEAP32[$tt >> 2] = 30;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 158:
    if (($18 | 0) == 92) {
      __label__ = 159;
      break;
    } else if (($18 | 0) == 124) {
      __label__ = 161;
      break;
    } else if (($18 | 0) == 94) {
      __label__ = 166;
      break;
    } else if (($18 | 0) == 38) {
      __label__ = 169;
      break;
    } else if (($18 | 0) == 33) {
      __label__ = 174;
      break;
    } else if (($18 | 0) == 64) {
      __label__ = 177;
      break;
    } else if (($18 | 0) == 60) {
      __label__ = 178;
      break;
    } else if (($18 | 0) == 62) {
      __label__ = 191;
      break;
    } else if (($18 | 0) == 42) {
      __label__ = 194;
      break;
    } else if (($18 | 0) == 47) {
      __label__ = 195;
      break;
    } else if (($18 | 0) == 37) {
      __label__ = 241;
      break;
    } else if (($18 | 0) == 126) {
      __label__ = 242;
      break;
    } else if (($18 | 0) == 45) {
      __label__ = 243;
      break;
    } else if (($18 | 0) == 35) {
      __label__ = 251;
      break;
    } else {
      __label__ = 262;
      break;
    }
   case 159:
    var $441 = __ZN2js11TokenStream25matchUnicodeEscapeIdStartEPi($this, $qc);
    if ($441) {
      __label__ = 160;
      break;
    } else {
      __label__ = 262;
      break;
    }
   case 160:
    var $_idx2_val = HEAP32[$_idx16 >> 2];
    var $443 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($_idx2_val);
    var $identStart_0_ph = $443 - 12 | 0;
    var $hadUnicodeEscape_0_ph = 1;
    __label__ = 21;
    break;
   case 161:
    var $446 = __ZN2js11TokenStream9matchCharEi($this, 124);
    if ($446) {
      __label__ = 162;
      break;
    } else {
      __label__ = 163;
      break;
    }
   case 162:
    HEAP32[$tt >> 2] = 7;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 163:
    var $449 = __ZN2js11TokenStream9matchCharEi($this, 61);
    if ($449) {
      __label__ = 164;
      break;
    } else {
      __label__ = 165;
      break;
    }
   case 164:
    var $452 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$452 >> 2] = 15;
    HEAP32[$tt >> 2] = 4;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 165:
    HEAP32[$tt >> 2] = 9;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 166:
    var $455 = __ZN2js11TokenStream9matchCharEi($this, 61);
    if ($455) {
      __label__ = 167;
      break;
    } else {
      __label__ = 168;
      break;
    }
   case 167:
    var $458 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$458 >> 2] = 16;
    HEAP32[$tt >> 2] = 4;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 168:
    HEAP32[$tt >> 2] = 10;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 169:
    var $461 = __ZN2js11TokenStream9matchCharEi($this, 38);
    if ($461) {
      __label__ = 170;
      break;
    } else {
      __label__ = 171;
      break;
    }
   case 170:
    HEAP32[$tt >> 2] = 8;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 171:
    var $464 = __ZN2js11TokenStream9matchCharEi($this, 61);
    if ($464) {
      __label__ = 172;
      break;
    } else {
      __label__ = 173;
      break;
    }
   case 172:
    var $467 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$467 >> 2] = 17;
    HEAP32[$tt >> 2] = 4;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 173:
    HEAP32[$tt >> 2] = 11;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 174:
    var $470 = __ZN2js11TokenStream9matchCharEi($this, 61);
    if ($470) {
      __label__ = 175;
      break;
    } else {
      __label__ = 176;
      break;
    }
   case 175:
    var $472 = __ZN2js11TokenStream9matchCharEi($this, 61);
    var $473 = $472 ? 73 : 19;
    var $475 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$475 >> 2] = $473;
    HEAP32[$tt >> 2] = 12;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 176:
    var $478 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$478 >> 2] = 32;
    HEAP32[$tt >> 2] = 19;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 177:
    HEAP32[$tt >> 2] = 70;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 178:
    if ((HEAP32[$1 >> 2] & 8 | 0) == 0) {
      __label__ = 182;
      break;
    } else {
      __label__ = 179;
      break;
    }
   case 179:
    var $485 = __ZNK2js11TokenStream6hasXMLEv($this);
    if ($485) {
      __label__ = 181;
      break;
    } else {
      __label__ = 180;
      break;
    }
   case 180:
    var $487 = __ZN2js11TokenStream8peekCharEv($this);
    if (($487 | 0) == 33) {
      __label__ = 182;
      break;
    } else {
      __label__ = 181;
      break;
    }
   case 181:
    var $490 = __ZN2js11TokenStream12getXMLMarkupEPNS_9TokenKindEPPNS_5TokenE($this, $tt, $tp);
    if ($490) {
      var $_idx1_pre_phi = $_idx16;
      __label__ = 263;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 182:
    var $492 = __ZN2js11TokenStream9matchCharEi($this, 33);
    if ($492) {
      __label__ = 183;
      break;
    } else {
      __label__ = 188;
      break;
    }
   case 183:
    var $494 = __ZN2js11TokenStream9matchCharEi($this, 45);
    if ($494) {
      __label__ = 184;
      break;
    } else {
      __label__ = 187;
      break;
    }
   case 184:
    var $496 = __ZN2js11TokenStream9matchCharEi($this, 45);
    if ($496) {
      __label__ = 185;
      break;
    } else {
      __label__ = 186;
      break;
    }
   case 185:
    var $499 = HEAP32[$1 >> 2] | 8192;
    HEAP32[$1 >> 2] = $499;
    var $540 = $499;
    __label__ = 200;
    break;
   case 186:
    __ZN2js11TokenStream9ungetCharEi($this, 45);
    __label__ = 187;
    break;
   case 187:
    __ZN2js11TokenStream9ungetCharEi($this, 33);
    __label__ = 188;
    break;
   case 188:
    var $501 = __ZN2js11TokenStream9matchCharEi($this, 60);
    if ($501) {
      __label__ = 189;
      break;
    } else {
      __label__ = 190;
      break;
    }
   case 189:
    var $504 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$504 >> 2] = 24;
    var $505 = __ZN2js11TokenStream9matchCharEi($this, 61);
    var $506 = $505 ? 4 : 14;
    HEAP32[$tt >> 2] = $506;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 190:
    var $508 = __ZN2js11TokenStream9matchCharEi($this, 61);
    var $509 = $508 ? 21 : 20;
    var $511 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$511 >> 2] = $509;
    HEAP32[$tt >> 2] = 13;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 191:
    var $513 = __ZN2js11TokenStream9matchCharEi($this, 62);
    if ($513) {
      __label__ = 192;
      break;
    } else {
      __label__ = 193;
      break;
    }
   case 192:
    var $515 = __ZN2js11TokenStream9matchCharEi($this, 62);
    var $516 = $515 ? 26 : 25;
    var $518 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$518 >> 2] = $516;
    var $519 = __ZN2js11TokenStream9matchCharEi($this, 61);
    var $520 = $519 ? 4 : 14;
    HEAP32[$tt >> 2] = $520;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 193:
    var $522 = __ZN2js11TokenStream9matchCharEi($this, 61);
    var $523 = $522 ? 23 : 22;
    var $525 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$525 >> 2] = $523;
    HEAP32[$tt >> 2] = 13;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 194:
    HEAP32[$41 + 24 >> 2] = 29;
    var $528 = __ZN2js11TokenStream9matchCharEi($this, 61);
    var $529 = $528 ? 4 : 17;
    HEAP32[$tt >> 2] = $529;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 195:
    var $531 = __ZN2js11TokenStream9matchCharEi($this, 47);
    if ($531) {
      __label__ = 196;
      break;
    } else {
      __label__ = 207;
      break;
    }
   case 196:
    var $_idx19_val = HEAP32[HEAP32[$7 >> 2] + 32 >> 2];
    var $534 = __ZNK9JSContext15hasAtLineOptionEv($_idx19_val);
    if ($534) {
      __label__ = 197;
      break;
    } else {
      __label__ = 198;
      break;
    }
   case 197:
    var $536 = __ZN2js11TokenStream9getAtLineEv($this);
    if ($536) {
      __label__ = 198;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 198:
    var $538 = __ZN2js11TokenStream21getAtSourceMappingURLEv($this);
    if ($538) {
      __label__ = 199;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 199:
    var $540 = HEAP32[$1 >> 2];
    __label__ = 200;
    break;
   case 200:
    var $540;
    if (($540 & 8192 | 0) == 0) {
      __label__ = 205;
      break;
    } else {
      __label__ = 201;
      break;
    }
   case 201:
    var $543 = __ZN2js11TokenStream7getCharEv($this);
    if (($543 | 0) == 45) {
      __label__ = 202;
      break;
    } else if (($543 | 0) == -1 || ($543 | 0) == 10) {
      var $c_9 = $543;
      __label__ = 206;
      break;
    } else {
      __label__ = 201;
      break;
    }
   case 202:
    var $545 = __ZN2js11TokenStream9matchCharEi($this, 45);
    if ($545) {
      __label__ = 203;
      break;
    } else {
      __label__ = 201;
      break;
    }
   case 203:
    var $547 = __ZN2js11TokenStream9matchCharEi($this, 62);
    if ($547) {
      __label__ = 204;
      break;
    } else {
      __label__ = 201;
      break;
    }
   case 204:
    var $550 = HEAP32[$1 >> 2] & -8193;
    HEAP32[$1 >> 2] = $550;
    __label__ = 201;
    break;
   case 205:
    var $551 = __ZN2js11TokenStream7getCharEv($this);
    if (($551 | 0) == -1 || ($551 | 0) == 10) {
      var $c_9 = $551;
      __label__ = 206;
      break;
    } else {
      __label__ = 205;
      break;
    }
   case 206:
    var $c_9;
    __ZN2js11TokenStream9ungetCharEi($this, $c_9);
    var $554 = HEAP32[$6 >> 2] + 3 & 3;
    HEAP32[$6 >> 2] = $554;
    __label__ = 5;
    break;
   case 207:
    var $556 = __ZN2js11TokenStream9matchCharEi($this, 42);
    if ($556) {
      __label__ = 208;
      break;
    } else {
      __label__ = 215;
      break;
    }
   case 208:
    var $558 = HEAP32[$8 >> 2];
    __label__ = 209;
    break;
   case 209:
    var $559 = __ZN2js11TokenStream7getCharEv($this);
    if (($559 | 0) == 42) {
      __label__ = 210;
      break;
    } else if (($559 | 0) == -1) {
      __label__ = 211;
      break;
    } else {
      __label__ = 209;
      break;
    }
   case 210:
    var $561 = __ZN2js11TokenStream9matchCharEi($this, 47);
    if ($561) {
      __label__ = 212;
      break;
    } else {
      __label__ = 209;
      break;
    }
   case 211:
    var $563 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($this, 0, 0, 140, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 264;
    break;
   case 212:
    if (($558 | 0) == (HEAP32[$8 >> 2] | 0)) {
      __label__ = 214;
      break;
    } else {
      __label__ = 213;
      break;
    }
   case 213:
    __ZN2js11TokenStream17updateFlagsForEOLEv($this);
    __label__ = 214;
    break;
   case 214:
    var $571 = HEAP32[$6 >> 2] + 3 & 3;
    HEAP32[$6 >> 2] = $571;
    __label__ = 5;
    break;
   case 215:
    if ((HEAP32[$1 >> 2] & 8 | 0) == 0) {
      __label__ = 240;
      break;
    } else {
      __label__ = 216;
      break;
    }
   case 216:
    var $577 = $this + 184 | 0;
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE5clearEv($577);
    var $inCharClass_0 = 0;
    __label__ = 217;
    break;
   case 217:
    var $inCharClass_0;
    var $579 = __ZN2js11TokenStream7getCharEv($this);
    if (($579 | 0) == 92) {
      __label__ = 218;
      break;
    } else if (($579 | 0) == 93) {
      __label__ = 220;
      break;
    } else if (($579 | 0) == 91) {
      var $inCharClass_135 = 1;
      var $c_1036 = 91;
      __label__ = 224;
      break;
    } else {
      __label__ = 221;
      break;
    }
   case 218:
    var $581 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($577, 92);
    if ($581) {
      __label__ = 219;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 219:
    var $583 = __ZN2js11TokenStream7getCharEv($this);
    var $c_10 = $583;
    __label__ = 222;
    break;
   case 220:
    var $inCharClass_135 = 0;
    var $c_1036 = 93;
    __label__ = 224;
    break;
   case 221:
    if (($579 | 0) == 47 & ($inCharClass_0 | 0) == 0) {
      __label__ = 225;
      break;
    } else {
      var $c_10 = $579;
      __label__ = 222;
      break;
    }
   case 222:
    var $c_10;
    if (($c_10 | 0) == -1 || ($c_10 | 0) == 10) {
      __label__ = 223;
      break;
    } else {
      var $inCharClass_135 = $inCharClass_0;
      var $c_1036 = $c_10;
      __label__ = 224;
      break;
    }
   case 223:
    __ZN2js11TokenStream9ungetCharEi($this, $c_10);
    var $590 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($this, 0, 0, 141, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 264;
    break;
   case 224:
    var $c_1036;
    var $inCharClass_135;
    var $591 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($577, $c_1036);
    if ($591) {
      var $inCharClass_0 = $inCharClass_135;
      __label__ = 217;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 225:
    var $_idx17_val = HEAP32[$this + 192 >> 2];
    var $593 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv($_idx17_val);
    var $length_0_in = $593;
    var $reflags_0 = 0;
    __label__ = 226;
    break;
   case 226:
    var $reflags_0;
    var $length_0_in;
    var $length_0 = $length_0_in + 1 | 0;
    var $595 = __ZN2js11TokenStream8peekCharEv($this);
    if (($595 | 0) == 103) {
      __label__ = 227;
      break;
    } else if (($595 | 0) == 105) {
      __label__ = 229;
      break;
    } else if (($595 | 0) == 109) {
      __label__ = 231;
      break;
    } else if (($595 | 0) == 121) {
      __label__ = 233;
      break;
    } else {
      __label__ = 236;
      break;
    }
   case 227:
    if (($reflags_0 & 2 | 0) == 0) {
      __label__ = 228;
      break;
    } else {
      __label__ = 236;
      break;
    }
   case 228:
    var $reflags_1 = $reflags_0 | 2;
    __label__ = 235;
    break;
   case 229:
    if (($reflags_0 & 1 | 0) == 0) {
      __label__ = 230;
      break;
    } else {
      __label__ = 236;
      break;
    }
   case 230:
    var $reflags_1 = $reflags_0 | 1;
    __label__ = 235;
    break;
   case 231:
    if (($reflags_0 & 4 | 0) == 0) {
      __label__ = 232;
      break;
    } else {
      __label__ = 236;
      break;
    }
   case 232:
    var $reflags_1 = $reflags_0 | 4;
    __label__ = 235;
    break;
   case 233:
    if (($reflags_0 & 8 | 0) == 0) {
      __label__ = 234;
      break;
    } else {
      __label__ = 236;
      break;
    }
   case 234:
    var $reflags_1 = $reflags_0 | 8;
    __label__ = 235;
    break;
   case 235:
    var $reflags_1;
    var $617 = __ZN2js11TokenStream7getCharEv($this);
    var $length_0_in = $length_0;
    var $reflags_0 = $reflags_1;
    __label__ = 226;
    break;
   case 236:
    var $618 = __ZN2js11TokenStream8peekCharEv($this);
    if (($618 | 0) < 128) {
      __label__ = 237;
      break;
    } else {
      __label__ = 239;
      break;
    }
   case 237:
    var $621 = _isalpha($618);
    if (($621 | 0) == 0) {
      __label__ = 239;
      break;
    } else {
      __label__ = 238;
      break;
    }
   case 238:
    HEAP16[$buf >> 1] = 0;
    var $625 = HEAP32[$tp >> 2] + 4 | 0;
    var $628 = $length_0_in + 2 + HEAP32[$625 >> 2] | 0;
    HEAP32[$625 >> 2] = $628;
    HEAP8[$buf] = $618 & 255;
    var $631 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($this, 0, 0, 58, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $buf, tempInt));
    var $632 = __ZN2js11TokenStream7getCharEv($this);
    __label__ = 264;
    break;
   case 239:
    var $635 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$635 >> 2] = $reflags_0;
    HEAP32[$tt >> 2] = 32;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 240:
    var $638 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$638 >> 2] = 30;
    var $639 = __ZN2js11TokenStream9matchCharEi($this, 61);
    var $640 = $639 ? 4 : 18;
    HEAP32[$tt >> 2] = $640;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 241:
    HEAP32[$41 + 24 >> 2] = 31;
    var $643 = __ZN2js11TokenStream9matchCharEi($this, 61);
    var $644 = $643 ? 4 : 18;
    HEAP32[$tt >> 2] = $644;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 242:
    HEAP32[$41 + 24 >> 2] = 33;
    HEAP32[$tt >> 2] = 19;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 243:
    var $648 = __ZN2js11TokenStream9matchCharEi($this, 61);
    if ($648) {
      __label__ = 244;
      break;
    } else {
      __label__ = 245;
      break;
    }
   case 244:
    var $651 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$651 >> 2] = 28;
    HEAP32[$tt >> 2] = 4;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 245:
    var $653 = __ZN2js11TokenStream9matchCharEi($this, 45);
    if ($653) {
      __label__ = 246;
      break;
    } else {
      __label__ = 250;
      break;
    }
   case 246:
    var $655 = __ZN2js11TokenStream8peekCharEv($this);
    if (($655 | 0) == 62) {
      __label__ = 247;
      break;
    } else {
      __label__ = 249;
      break;
    }
   case 247:
    var $658 = HEAP32[$1 >> 2];
    if (($658 & 128 | 0) == 0) {
      __label__ = 248;
      break;
    } else {
      __label__ = 249;
      break;
    }
   case 248:
    var $662 = $658 & -8193;
    HEAP32[$1 >> 2] = $662;
    var $540 = $662;
    __label__ = 200;
    break;
   case 249:
    HEAP32[$tt >> 2] = 21;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 250:
    var $666 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$666 >> 2] = 34;
    HEAP32[$tt >> 2] = 16;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 251:
    var $668 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    var $669 = $668 - 48 | 0;
    if ($669 >>> 0 < 10) {
      var $n_0 = $669;
      __label__ = 253;
      break;
    } else {
      __label__ = 252;
      break;
    }
   case 252:
    __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, $668);
    __label__ = 262;
    break;
   case 253:
    var $n_0;
    var $673 = __ZN2js11TokenStream7getCharEv($this);
    if (($673 - 48 | 0) >>> 0 < 10) {
      __label__ = 254;
      break;
    } else {
      __label__ = 256;
      break;
    }
   case 254:
    var $679 = $n_0 * 10 - 48 + $673 | 0;
    if ($679 >>> 0 > 65535) {
      __label__ = 255;
      break;
    } else {
      var $n_0 = $679;
      __label__ = 253;
      break;
    }
   case 255:
    var $682 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($this, 0, 0, 143, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 264;
    break;
   case 256:
    var $687 = HEAP32[$tp >> 2] + 24 | 0;
    tempDoubleF64[0] = $n_0 >>> 0, HEAP32[$687 >> 2] = tempDoubleI32[0], HEAP32[$687 + 4 >> 2] = tempDoubleI32[1];
    var $_idx_val = HEAP32[HEAP32[$7 >> 2] + 32 >> 2];
    var $689 = __ZNK9JSContext15hasStrictOptionEv($_idx_val);
    if ($689) {
      __label__ = 257;
      break;
    } else {
      __label__ = 259;
      break;
    }
   case 257:
    if (($673 | 0) == 61 || ($673 | 0) == 35) {
      __label__ = 258;
      break;
    } else {
      __label__ = 262;
      break;
    }
   case 258:
    var $692 = $buf5 | 0;
    var $693 = _JS_snprintf($692, 20, STRING_TABLE.__str63591 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $n_0, HEAP32[tempInt + 4 >> 2] = $673, tempInt));
    var $694 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($this, 0, 5, 158, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $692, tempInt));
    if ($694) {
      __label__ = 259;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 259:
    if (($673 | 0) == 61) {
      __label__ = 260;
      break;
    } else if (($673 | 0) == 35) {
      __label__ = 261;
      break;
    } else {
      __label__ = 262;
      break;
    }
   case 260:
    HEAP32[$tt >> 2] = 51;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 261:
    HEAP32[$tt >> 2] = 52;
    var $_idx1_pre_phi = $_idx16;
    __label__ = 263;
    break;
   case 262:
    var $698 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($this, 0, 0, 144, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 264;
    break;
   case 263:
    var $_idx1_pre_phi;
    var $700 = HEAP32[$1 >> 2] | 128;
    HEAP32[$1 >> 2] = $700;
    var $_idx1_val = HEAP32[$_idx1_pre_phi >> 2];
    var $701 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($_idx1_val);
    var $707 = $701 - HEAP32[$this + 148 >> 2] >> 1;
    var $709 = HEAP32[$tp >> 2] + 12 | 0;
    HEAP32[$709 >> 2] = $707;
    var $710 = HEAP32[$tt >> 2];
    var $712 = HEAP32[$tp >> 2] | 0;
    HEAP32[$712 >> 2] = $710;
    var $_0 = HEAP32[$tt >> 2];
    __label__ = 265;
    break;
   case 264:
    var $715 = HEAP32[$1 >> 2] | 128;
    HEAP32[$1 >> 2] = $715;
    var $716 = HEAP32[$tp >> 2];
    var $719 = HEAP32[$716 + 4 >> 2] + 1 | 0;
    var $720 = $716 + 12 | 0;
    HEAP32[$720 >> 2] = $719;
    var $722 = HEAP32[$tp >> 2] | 0;
    HEAP32[$722 >> 2] = -1;
    var $_0 = -1;
    __label__ = 265;
    break;
   case 265:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11TokenStream16getTokenInternalEv["X"] = 1;

function __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js7unicode13CharacterInfo8isLetterEv($this_0_2_val) {
  return ($this_0_2_val & 2) << 24 >> 24 != 0;
}

function __ZNK2js7unicode13CharacterInfo15isEnclosingMarkEv($this_0_2_val) {
  return ($this_0_2_val & 16) << 24 >> 24 != 0;
}

function __ZNK2js7unicode13CharacterInfo22isCombiningSpacingMarkEv($this_0_2_val) {
  return ($this_0_2_val & 32) << 24 >> 24 != 0;
}

function __ZNK2js7unicode13CharacterInfo16isIdentifierPartEv($this_0_2_val) {
  return ($this_0_2_val & 6) << 24 >> 24 != 0;
}

function __ZN2js13PropertyTable13sizeOfEntriesEj($cap) {
  return $cap << 2;
}

function __ZN2jsL6HashIdEi($id) {
  return $id * -1640531527 | 0;
}

function __ZNK2js13PropertyTable8capacityEv($this_0_0_val) {
  return 1 << 32 - $this_0_0_val;
}

function __ZN2js11TokenStream17updateFlagsForEOLEv($this) {
  var $1 = $this + 144 | 0;
  var $4 = HEAP32[$1 >> 2] & -133 | 4;
  HEAP32[$1 >> 2] = $4;
  return;
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 1) | 0;
}

function __ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP16[$p_01 >> 1];
    HEAP16[$_02 >> 1] = $2;
    var $3 = $p_01 + 2 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 2 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE13copyConstructIcEEvPtPKT_S7_($dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p_01 = STRING_TABLE._js_quot_entity_str | 0;
    var $_02 = $dst;
    __label__ = 2;
    break;
   case 2:
    var $_02;
    var $p_01;
    HEAP16[$_02 >> 1] = HEAP8[$p_01] << 24 >> 24;
    var $3 = $p_01 + 1 | 0;
    var $5 = ($3 | 0) == (STRING_TABLE._js_quot_entity_str + 6 | 0);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 2 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream8TokenBufC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN2js7unicode8IsLetterEt($ch) {
  var $1 = __ZN2js7unicode8CharInfoEt($ch);
  var $_idx_val = HEAP8[$1 + 4 | 0];
  var $2 = __ZNK2js7unicode13CharacterInfo8isLetterEv($_idx_val);
  return $2;
}

function __ZNK9JSContext15hasAtLineOptionEv($this_0_6_val) {
  var $1 = __ZNK9JSContext12hasRunOptionEj($this_0_6_val, 32);
  return $1;
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendItEEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $5 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP16[$1 >> 1] = $t;
    var $5 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    HEAP32[$this_idx1 >> 2] = $5 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $4 = $this + 16 | 0;
  var $5 = __ZNK7mozilla14AlignedStorageILj64EE4addrEv($4);
  return ($2 | 0) == ($5 | 0);
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 1;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE13moveConstructItEEvPtPKT_S7_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorItLj32ES1_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 1073741823) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 1073741823) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorItLj32ES1_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 1;
    var $2 = $v | 0;
    var $3 = $v + 4 | 0;
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($2, $5, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    var $10 = $v + 12 | 0;
    HEAP32[$3 >> 2] = $9;
    HEAP32[$10 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE13moveConstructItEEvPtPKT_S7_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIcEEbPKT_S6_($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] + 6 | 0) >>> 0 > HEAPU32[$this + 12 >> 2] >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE13growStorageByEj($this, 6);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendIcEEvPKT_j($this);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendIcEEvPKT_j($this) {
  var $this_idx_val = HEAP32[$this + 4 >> 2];
  var $this_idx1 = $this + 8 | 0;
  var $this_idx1_val = HEAP32[$this_idx1 >> 2];
  var $1 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
  __ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE13copyConstructIcEEvPtPKT_S7_($1);
  var $3 = HEAP32[$this_idx1 >> 2] + 6 | 0;
  HEAP32[$this_idx1 >> 2] = $3;
  return;
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendIiEEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $6 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP16[$1 >> 1] = $t & 65535;
    var $6 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $6;
    HEAP32[$this_idx1 >> 2] = $6 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendIcEEvT_($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $5 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP16[$1 >> 1] = 38;
    var $5 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    HEAP32[$this_idx1 >> 2] = $5 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEEC2ES1_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $4 = $this + 16 | 0;
  var $5 = __ZN7mozilla14AlignedStorageILj64EE4addrEv($4);
  HEAP32[$2 >> 2] = $5;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 32;
  return;
}

function __Z16js_GenerateShapeP9JSRuntime($rt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $rt + 209944 | 0;
    var $3 = HEAP32[$1 >> 2] + 1 | 0;
    HEAP32[$1 >> 2] = $3;
    if ($3 >>> 0 > 16777215) {
      __label__ = 2;
      break;
    } else {
      var $shape_0 = $3;
      __label__ = 6;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = 16777216;
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[__ZN2js8gcReasonE >> 2] = 9;
    __label__ = 5;
    break;
   case 4:
    var $10 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $10;
    __label__ = 5;
    break;
   case 5:
    __ZN2js9TriggerGCEP9JSRuntime($rt);
    var $shape_0 = 16777216;
    __label__ = 6;
    break;
   case 6:
    var $shape_0;
    return $shape_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_GenerateShapeP9JSContext($cx_0_11_val) {
  var $1 = __Z16js_GenerateShapeP9JSRuntime($cx_0_11_val);
  return $1;
}

function __ZN8JSObject38ensureClassReservedSlotsForEmptyObjectEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx1_val = HEAP32[$this + 4 >> 2];
    var $1 = __ZNK8JSObject8getClassEv($this_idx1_val);
    var $5 = HEAPU32[$1 + 4 >> 2] >>> 8 & 255;
    var $this_idx_val = HEAP32[$this + 28 >> 2];
    var $6 = __ZNK8JSObject8numSlotsEv($this_idx_val);
    if ($5 >>> 0 > $6 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $this;
    var $10 = $cx;
    var $11 = __ZN8JSObject10allocSlotsEP9JSContextj($9, $10, $5);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13PropertyTable4initEP9JSRuntimePNS_5ShapeE($this, $rt, $lastProp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $3 = HEAP32[$this + 4 >> 2] << 1;
    var $4 = _JS_CeilingLog2($3);
    var $sizeLog2_0 = $4 >>> 0 < 4 ? 4 : $4;
    var $6 = 1 << $sizeLog2_0;
    var $7 = __ZN2js13PropertyTable13sizeOfEntriesEj($6);
    var $8 = __ZN9JSRuntime7calloc_EjP9JSContext($rt, $7, 0);
    var $9 = $8;
    HEAP32[$this + 16 >> 2] = $9;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = 32 - $sizeLog2_0 | 0;
    HEAP32[$this >> 2] = $13;
    var $15 = $r;
    var $16 = $lastProp;
    __ZNK2js5Shape3allEv($15, $16);
    var $_idx1 = $r;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $_idx1_val_idx_val = HEAP32[$_idx1_val + 32 >> 2];
    var $17 = __ZNK2js5Shape5Range5emptyEv($_idx1_val_idx_val);
    if ($17) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      var $r_idx_val_in = $_idx1_val;
      __label__ = 3;
      break;
    }
   case 3:
    var $r_idx_val_in;
    var $18 = __ZNK2js5Shape5Range5frontEv($r_idx_val_in);
    var $20 = HEAP32[$18 + 12 >> 2];
    var $21 = __ZN2js13PropertyTable6searchEib($this, $20, 1);
    var $22 = HEAPU32[$21 >> 2];
    if ($22 >>> 0 > 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $29 = $22 & 1 | $18;
    HEAP32[$21 >> 2] = $29;
    __label__ = 5;
    break;
   case 5:
    __ZN2js5Shape5Range8popFrontEv($r);
    var $_idx_val = HEAPU32[$_idx1 >> 2];
    var $_idx_val_idx_val = HEAP32[$_idx_val + 32 >> 2];
    var $31 = __ZNK2js5Shape5Range5emptyEv($_idx_val_idx_val);
    if ($31) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      var $r_idx_val_in = $_idx_val;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13PropertyTable4initEP9JSRuntimePNS_5ShapeE["X"] = 1;

function __ZN2js13PropertyTable6searchEib($this, $id, $adding) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL6HashIdEi($id);
    var $3 = HEAPU32[$this >> 2];
    var $4 = $1 >>> ($3 >>> 0);
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] + ($4 << 2) | 0;
    var $8 = HEAPU32[$7 >> 2];
    if (($8 | 0) == 0) {
      var $_0 = $7;
      __label__ = 18;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = $8;
    var $12 = $11 & -2;
    if (($12 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$12 + 12 >> 2] | 0) == ($id | 0)) {
      var $_0 = $7;
      __label__ = 18;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $20 = 32 - $3 | 0;
    var $23 = $1 << $20 >>> ($3 >>> 0) | 1;
    var $25 = (1 << $20) - 1 | 0;
    var $26 = ($8 | 0) == 1;
    var $_mux = $26 ? $7 : 0;
    if ($26 | $adding ^ 1) {
      var $firstRemoved_0_ph1 = $_mux;
      var $hash1_0_ph = $4;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($11 & 1 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $firstRemoved_0_ph1 = 0;
      var $hash1_0_ph = $4;
      __label__ = 7;
      break;
    }
   case 6:
    var $32 = $11 | 1;
    HEAP32[$7 >> 2] = $32;
    var $firstRemoved_0_ph1 = 0;
    var $hash1_0_ph = $4;
    __label__ = 7;
    break;
   case 7:
    var $hash1_0_ph;
    var $firstRemoved_0_ph1;
    var $33 = ($firstRemoved_0_ph1 | 0) == 0;
    var $hash1_0 = $hash1_0_ph;
    __label__ = 8;
    break;
   case 8:
    var $hash1_0;
    var $35 = $hash1_0 - $23 & $25;
    var $37 = HEAP32[$5 >> 2] + ($35 << 2) | 0;
    var $38 = HEAP32[$37 >> 2];
    if (($38 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    if ($adding) {
      __label__ = 10;
      break;
    } else {
      var $_0 = $37;
      __label__ = 18;
      break;
    }
   case 10:
    var $phitmp = ($firstRemoved_0_ph1 | 0) != 0 ? $firstRemoved_0_ph1 : $37;
    var $_0 = $phitmp;
    __label__ = 18;
    break;
   case 11:
    var $44 = $38;
    var $45 = $44 & -2;
    if (($45 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[$45 + 12 >> 2] | 0) == ($id | 0)) {
      var $_0 = $37;
      __label__ = 18;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if (($38 | 0) == 1) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    if ($33) {
      var $firstRemoved_0_ph1 = $37;
      var $hash1_0_ph = $35;
      __label__ = 7;
      break;
    } else {
      var $hash1_0 = $35;
      __label__ = 8;
      break;
    }
   case 15:
    if ($adding) {
      __label__ = 16;
      break;
    } else {
      var $hash1_0 = $35;
      __label__ = 8;
      break;
    }
   case 16:
    if (($44 & 1 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $hash1_0 = $35;
      __label__ = 8;
      break;
    }
   case 17:
    var $61 = $44 | 1;
    HEAP32[$37 >> 2] = $61;
    var $hash1_0 = $35;
    __label__ = 8;
    break;
   case 18:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13PropertyTable6searchEib["X"] = 1;

function __ZN2js5Shape7hashifyEP9JSContext($this, $cx_0_11_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js5Shape10entryCountEv($1);
    var $3 = __ZN9JSRuntime4new_IN2js13PropertyTableEjEEPT_T0_($cx_0_11_val, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN2js13PropertyTable4initEP9JSRuntimePNS_5ShapeE($3, $cx_0_11_val, $this);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $3;
    __ZN9JSRuntime5free_EPv($8);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $10 = $this;
    var $11 = $3;
    __ZNK2js5Shape8setTableEPNS_13PropertyTableE($10, $11);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime4new_IN2js13PropertyTableEjEEPT_T0_($this, $p1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSRuntime7malloc_EjP9JSContext($this, 20, 0);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js13PropertyTableC1Ej($4, $p1);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13PropertyTable6changeEiP9JSContext($this, $log2Delta, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $3 = 32 - HEAP32[$1 >> 2] | 0;
    var $4 = $3 + $log2Delta | 0;
    var $5 = 1 << $4;
    var $6 = __ZN2js13PropertyTable13sizeOfEntriesEj($5);
    var $7 = __ZN9JSContext7calloc_Ej($cx, $6);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $7;
    var $11 = 1 << $3;
    var $12 = 32 - $4 | 0;
    HEAP32[$1 >> 2] = $12;
    HEAP32[$this + 8 >> 2] = 0;
    var $14 = $this + 16 | 0;
    var $15 = HEAP32[$14 >> 2];
    HEAP32[$14 >> 2] = $10;
    var $oldsize_01 = $11;
    var $oldspp_02 = $15;
    __label__ = 3;
    break;
   case 3:
    var $oldspp_02;
    var $oldsize_01;
    var $19 = HEAP32[$oldspp_02 >> 2] & -2;
    var $20 = $19;
    if (($19 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $24 = HEAP32[$20 + 12 >> 2];
    var $25 = __ZN2js13PropertyTable6searchEib($this, $24, 1);
    HEAP32[$25 >> 2] = $20;
    __label__ = 5;
    break;
   case 5:
    var $27 = $oldsize_01 - 1 | 0;
    if (($27 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $oldsize_01 = $27;
      var $oldspp_02 = $oldspp_02 + 4 | 0;
      __label__ = 3;
      break;
    }
   case 6:
    var $31 = $15;
    __ZN9JSContext5free_EPv($31);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13PropertyTable4growEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK2js13PropertyTable8capacityEv($this_idx_val);
    var $2 = $this + 8 | 0;
    var $6 = HEAPU32[$2 >> 2] >>> 0 < $1 >>> 2 >>> 0 & 1;
    var $7 = __ZN2js13PropertyTable6changeEiP9JSContext($this, $6, $cx);
    if ($7) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$2 >> 2] + HEAP32[$this + 4 >> 2] | 0) == ($1 - 1 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportOutOfMemory($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5Shape8getChildEP9JSContextRKS0_PPS0_($this, $cx, $child, $listp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_tr = $this;
    __label__ = 2;
    break;
   case 2:
    var $this_tr;
    var $this_tr_idx_val = HEAP8[$this_tr + 29 | 0];
    var $1 = __ZNK2js5Shape12inDictionaryEv($this_tr_idx_val);
    var $2 = HEAPU32[$listp >> 2];
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 3:
    if (($2 | 0) == 0) {
      var $15 = 0;
      var $14 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx1_val = HEAP32[$2 + 8 >> 2];
    var $6 = __ZNK2js5Shape8hasTableEv($_idx1_val);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      var $15 = 0;
      var $14 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $8 = __ZNK2js5Shape8getTableEv($2);
    if (($8 | 0) == 0) {
      var $15 = 0;
      var $14 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx2_val = HEAP32[$8 >> 2];
    var $_idx3_val = HEAP32[$8 + 4 >> 2];
    var $_idx4_val = HEAP32[$8 + 8 >> 2];
    var $11 = __ZNK2js13PropertyTable11needsToGrowEv($_idx2_val, $_idx3_val, $_idx4_val);
    if ($11) {
      __label__ = 7;
      break;
    } else {
      var $15 = $8;
      var $14 = 1;
      __label__ = 8;
      break;
    }
   case 7:
    var $13 = __ZN2js13PropertyTable4growEP9JSContext($8, $cx);
    if ($13) {
      var $15 = $8;
      var $14 = 1;
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 8:
    var $14;
    var $15;
    var $16 = __ZN2js5Shape18newDictionaryShapeEP9JSContextRKS0_PPS0_($cx, $child, $listp);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $19 = HEAPU32[$listp >> 2];
    if ($14) {
      __label__ = 10;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 10:
    var $22 = HEAP32[$19 + 12 >> 2];
    var $23 = __ZN2js13PropertyTable6searchEib($15, $22, 1);
    var $24 = HEAPU32[$23 >> 2];
    if ($24 >>> 0 > 1) {
      var $31 = $24;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $27 = $15 + 4 | 0;
    var $29 = HEAP32[$27 >> 2] + 1 | 0;
    HEAP32[$27 >> 2] = $29;
    var $31 = HEAP32[$23 >> 2];
    __label__ = 12;
    break;
   case 12:
    var $31;
    HEAP32[$23 >> 2] = $31 & 1 | $19;
    var $37 = $2;
    __ZNK2js5Shape8setTableEPNS_13PropertyTableE($37, 0);
    var $38 = $19;
    __ZNK2js5Shape8setTableEPNS_13PropertyTableE($38, $15);
    var $_0 = $19;
    __label__ = 19;
    break;
   case 13:
    var $_idx_val = HEAP32[$19 + 8 >> 2];
    var $41 = __ZNK2js5Shape8hasTableEv($_idx_val);
    if ($41) {
      var $_0 = $19;
      __label__ = 19;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    var $43 = __ZN2js5Shape7hashifyEP9JSContext($19, $cx_idx_val);
    var $_0 = $19;
    __label__ = 19;
    break;
   case 15:
    var $45 = $2;
    var $46 = __ZNK2js5Shape10entryCountEv($45);
    if ($46 >>> 0 > 127) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $49 = __ZN2js5Shape17newDictionaryListEP9JSContextPPS0_($cx, $listp);
    if (($49 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      var $this_tr = $49;
      __label__ = 2;
      break;
    }
   case 17:
    var $52 = $cx;
    var $54 = $child;
    var $55 = __ZN2js12PropertyTree8getChildEP9JSContextPNS_5ShapeERKS3_($52, $this_tr, $54);
    var $56 = $55;
    if (($55 | 0) == 0) {
      var $_0 = $56;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    HEAP32[$listp >> 2] = $56;
    var $_0 = $56;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5Shape8getChildEP9JSContextRKS0_PPS0_["X"] = 1;

function __ZNK2js13PropertyTable11needsToGrowEv($this_0_0_val, $this_0_1_val, $this_0_2_val) {
  var $1 = __ZNK2js13PropertyTable8capacityEv($this_0_0_val);
  return ($this_0_2_val + $this_0_1_val | 0) >>> 0 >= ($1 - ($1 >>> 2) | 0) >>> 0;
}

function __ZN2js5Shape18newDictionaryShapeEP9JSContextRKS0_PPS0_($cx, $child, $listp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __ZN2js12PropertyTree8newShapeEP9JSContext($1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$child + 12 >> 2];
    var $9 = HEAP32[$child + 16 >> 2];
    var $11 = HEAP32[$child + 20 >> 2];
    var $13 = HEAP32[$child + 24 >> 2];
    var $16 = HEAPU8[$child + 28 | 0] & 255;
    var $21 = HEAPU8[$child + 29 | 0] & 255 & 249 | 2;
    var $24 = HEAP16[$child + 30 >> 1] << 16 >> 16;
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    var $25 = __Z16js_GenerateShapeP9JSContext($cx_idx_val);
    var $27 = HEAP32[$child + 4 >> 2];
    var $28 = $9;
    var $29 = $11;
    __ZN2js5ShapeC1EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj($2, $7, $28, $29, $13, $16, $21, $24, $25, $27);
    HEAP32[$2 + 36 >> 2] = 0;
    __ZN2js5Shape20insertIntoDictionaryEPPS0_($3, $listp);
    var $_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5Shape17newDictionaryListEP9JSContextPPS0_($cx, $listp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $root = __stackBase__;
    var $1 = HEAP32[$listp >> 2];
    HEAP32[$root >> 2] = 0;
    var $childp_0 = $root;
    var $shape_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $shape_0;
    var $childp_0;
    if (($shape_0 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js5Shape18newDictionaryShapeEP9JSContextRKS0_PPS0_($cx, $shape_0, $childp_0);
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$listp >> 2] = $1;
    var $_0 = 0;
    __label__ = 7;
    break;
   case 5:
    var $childp_0 = $5 + 32 | 0;
    var $shape_0 = HEAP32[$shape_0 + 32 >> 2];
    __label__ = 2;
    break;
   case 6:
    var $13 = HEAP32[$root >> 2];
    HEAP32[$listp >> 2] = $13;
    var $14 = $13 + 36 | 0;
    HEAP32[$14 >> 2] = $listp;
    var $15 = HEAP32[$root >> 2];
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    var $16 = __ZN2js5Shape7hashifyEP9JSContext($15, $cx_idx_val);
    var $_0 = HEAP32[$root >> 2];
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5Shape6frozenEv($this_0_8_val) {
  return ($this_0_8_val & 4) << 24 >> 24 != 0;
}

function __ZL24NormalizeGetterAndSetterP9JSContextP8JSObjectijjRPFiS0_S2_iPN2JS5ValueEERPFiS0_S2_iiS5_E($flags, $getter, $setter) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$setter >> 2] | 0) == 12) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$setter >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    if (($flags & 128 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    if ((HEAP32[$getter >> 2] | 0) == 10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    HEAP32[$getter >> 2] = 0;
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject13clearOwnShapeEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] & -129;
  HEAP32[$1 >> 2] = $3;
  var $7 = HEAP32[HEAP32[$this >> 2] >> 2];
  HEAP32[$this + 12 >> 2] = $7;
  return;
}

function __ZN8JSObject18removeLastPropertyEv($this) {
  var $1 = $this | 0;
  var $4 = HEAP32[HEAP32[$1 >> 2] + 32 >> 2];
  HEAP32[$1 >> 2] = $4;
  return;
}

function __ZN8JSObject16getChildPropertyEP9JSContextPN2js5ShapeERS3_($this, $cx, $parent, $child) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = $child + 24 | 0;
    if ((HEAP8[$child + 28 | 0] & 64) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$5 >> 2] = -1;
    __label__ = 5;
    break;
   case 3:
    if ((HEAP32[$5 >> 2] | 0) == -1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = $this;
    var $12 = $cx;
    var $13 = __ZN8JSObject9allocSlotEP9JSContextPj($11, $12, $5);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 5:
    var $this_idx = $this | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $15 = __ZNK8JSObject16inDictionaryModeEv($this_idx_val);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $parent_idx_val = HEAP8[$parent + 29 | 0];
    var $17 = __ZNK2js5Shape6frozenEv($parent_idx_val);
    if ($17) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $19 = __ZN2js5Shape17newDictionaryListEP9JSContextPPS0_($cx, $this_idx);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = __ZN2js5Shape18newDictionaryShapeEP9JSContextRKS0_PPS0_($cx, $child, $this_idx);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      var $shape_0 = $22;
      __label__ = 11;
      break;
    }
   case 9:
    var $25 = $cx;
    var $26 = $parent;
    var $27 = $child;
    var $28 = __ZN2js12PropertyTree8getChildEP9JSContextPNS_5ShapeERKS3_($25, $26, $27);
    var $29 = $28;
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN8JSObject15setLastPropertyEPKN2js5ShapeE($this, $29);
    var $shape_0 = $29;
    __label__ = 11;
    break;
   case 11:
    var $shape_0;
    __ZN8JSObject11updateFlagsEPKN2js5ShapeEb($this, $shape_0);
    __ZN8JSObject11updateShapeEP9JSContext($this, $cx);
    var $_0 = $shape_0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5Shape20insertIntoDictionaryEPPS0_($this, $dictp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $this;
    var $3 = HEAP32[$dictp >> 2];
    __ZN2js5Shape9setParentEPS0_($2, $3);
    var $4 = $this + 32 | 0;
    var $5 = HEAP32[$4 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5 + 36 | 0;
    HEAP32[$8 >> 2] = $4;
    __label__ = 3;
    break;
   case 3:
    HEAP32[$this + 36 >> 2] = $dictp;
    HEAP32[$dictp >> 2] = $this;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject16toDictionaryModeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZN2js5Shape17newDictionaryListEP9JSContextPPS0_($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN8JSObject13clearOwnShapeEv($this);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject11addPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji($this, $cx, $id, $getter, $setter, $slot, $attrs, $flags, $shortid) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $getter;
    HEAP32[$2 >> 2] = $setter;
    var $this_idx_val = HEAP32[$this + 8 >> 2];
    var $3 = __ZNK8JSObject12isExtensibleEv($this_idx_val);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $this;
    var $6 = $cx;
    var $7 = __ZN8JSObject19reportNotExtensibleEP9JSContextj($5, $6, 0);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZL24NormalizeGetterAndSetterP9JSContextP8JSObjectijjRPFiS0_S2_iPN2JS5ValueEERPFiS0_S2_iiS5_E($flags, $1, $2);
    var $9 = __ZN8JSObject12nativeSearchEP9JSContextib($this, $cx, $id, 1);
    var $10 = HEAP32[$1 >> 2];
    var $11 = HEAP32[$2 >> 2];
    var $12 = __ZN8JSObject19addPropertyInternalEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_EjjjiPPN2js5ShapeE($this, $cx, $id, $10, $11, $slot, $attrs, $flags, $shortid, $9);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject19addPropertyInternalEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_EjjjiPPN2js5ShapeE($this, $cx, $id, $getter, $setter, $slot, $attrs, $flags, $shortid, $spp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $child = __stackBase__;
    var $this_idx = $this | 0;
    var $this_idx_val = HEAPU32[$this_idx >> 2];
    var $1 = __ZNK8JSObject16inDictionaryModeEv($this_idx_val);
    if ($1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $this_idx_val;
    var $4 = __ZNK2js5Shape10entryCountEv($3);
    if ($4 >>> 0 > 127) {
      __label__ = 3;
      break;
    } else {
      var $table_0 = 0;
      var $_01 = $spp;
      __label__ = 9;
      break;
    }
   case 3:
    var $7 = __ZN8JSObject16toDictionaryModeEP9JSContext($this, $cx);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 4:
    var $9 = __ZN8JSObject12nativeSearchEP9JSContextib($this, $cx, $id, 1);
    var $10 = HEAP32[$this_idx >> 2];
    var $11 = __ZNK2js5Shape8getTableEv($10);
    var $table_0 = $11;
    var $_01 = $9;
    __label__ = 9;
    break;
   case 5:
    var $_idx_val = HEAP32[$this_idx_val + 8 >> 2];
    var $13 = __ZNK2js5Shape8hasTableEv($_idx_val);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      var $table_0 = 0;
      var $_01 = $spp;
      __label__ = 9;
      break;
    }
   case 6:
    var $15 = __ZNK2js5Shape8getTableEv($this_idx_val);
    var $_idx1_val = HEAP32[$15 >> 2];
    var $_idx2_val = HEAP32[$15 + 4 >> 2];
    var $_idx3_val = HEAP32[$15 + 8 >> 2];
    var $16 = __ZNK2js13PropertyTable11needsToGrowEv($_idx1_val, $_idx2_val, $_idx3_val);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $table_0 = $15;
      var $_01 = $spp;
      __label__ = 9;
      break;
    }
   case 7:
    var $18 = __ZN2js13PropertyTable4growEP9JSContext($15, $cx);
    if ($18) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 8:
    var $20 = __ZN2js13PropertyTable6searchEib($15, $id, 1);
    var $table_0 = $15;
    var $_01 = $20;
    __label__ = 9;
    break;
   case 9:
    var $_01;
    var $table_0;
    var $22 = $child;
    var $23 = $getter;
    var $24 = $setter;
    __ZN2js5ShapeC1EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj($22, $id, $23, $24, $slot, $attrs, $flags, $shortid, -1879048193, 0);
    var $25 = HEAP32[$this_idx >> 2];
    var $26 = __ZN8JSObject16getChildPropertyEP9JSContextPN2js5ShapeERS3_($this, $cx, $25, $child);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if (($table_0 | 0) == 0) {
      var $_0 = $26;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $36 = HEAP32[$_01 >> 2] & 1 | $26;
    HEAP32[$_01 >> 2] = $36;
    var $37 = $table_0 + 4 | 0;
    var $39 = HEAP32[$37 >> 2] + 1 | 0;
    HEAP32[$37 >> 2] = $39;
    var $42 = HEAP32[$26 + 32 >> 2];
    __ZNK2js5Shape8setTableEPNS_13PropertyTableE($42, 0);
    var $43 = $26;
    __ZNK2js5Shape8setTableEPNS_13PropertyTableE($43, $table_0);
    var $_0 = $26;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject19addPropertyInternalEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_EjjjiPPN2js5ShapeE["X"] = 1;

function __ZN8JSObject11putPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji($this, $cx, $id, $getter, $setter, $slot, $attrs, $flags, $shortid) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 12;
    var $child = __stackBase__ + 16;
    var $5 = __stackBase__ + 56;
    HEAP32[$1 >> 2] = $getter;
    HEAP32[$2 >> 2] = $setter;
    HEAP32[$3 >> 2] = $slot;
    HEAP32[$4 >> 2] = $attrs;
    var $6 = $this | 0;
    var $_idx3_val = HEAP8[HEAP32[$6 >> 2] + 29 | 0];
    var $8 = __ZNK2js5Shape6frozenEv($_idx3_val);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = __ZN2js5Shape17newDictionaryListEP9JSContextPPS0_($cx, $6);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZL24NormalizeGetterAndSetterP9JSContextP8JSObjectijjRPFiS0_S2_iPN2JS5ValueEERPFiS0_S2_iiS5_E($flags, $1, $2);
    var $13 = __ZN8JSObject12nativeSearchEP9JSContextib($this, $cx, $id, 1);
    var $16 = HEAP32[$13 >> 2] & -2;
    var $17 = $16;
    if (($16 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $this_idx4_val = HEAP32[$this + 8 >> 2];
    var $20 = __ZNK8JSObject12isExtensibleEv($this_idx4_val);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $22 = $this;
    var $23 = $cx;
    var $24 = __ZN8JSObject19reportNotExtensibleEP9JSContextj($22, $23, 0);
    var $_0 = 0;
    __label__ = 36;
    break;
   case 6:
    var $26 = HEAP32[$1 >> 2];
    var $27 = HEAP32[$2 >> 2];
    var $28 = __ZN8JSObject19addPropertyInternalEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_EjjjiPPN2js5ShapeE($this, $cx, $id, $26, $27, $slot, $attrs, $flags, $shortid, $13);
    var $_0 = $28;
    __label__ = 36;
    break;
   case 7:
    var $30 = __Z19CheckCanChangeAttrsP9JSContextP8JSObjectPKN2js5ShapeEPj($cx, $17, $4);
    if ($30) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 36;
      break;
    }
   case 8:
    var $_idx_val = HEAP8[$17 + 28 | 0];
    var $32 = __ZNK2js5Shape7hasSlotEv($_idx_val);
    var $34 = HEAPU32[$17 + 24 >> 2];
    var $35 = HEAPU32[$4 >> 2];
    var $37 = ($35 & 64 | 0) == 0;
    var $38 = HEAP32[$3 >> 2];
    if ($37) {
      __label__ = 9;
      break;
    } else {
      var $41 = $38;
      __label__ = 11;
      break;
    }
   case 9:
    if (($38 | 0) != -1 | $32 ^ 1) {
      var $41 = $38;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    HEAP32[$3 >> 2] = $34;
    var $41 = $34;
    __label__ = 11;
    break;
   case 11:
    var $41;
    var $44 = $16;
    var $45 = HEAP32[$1 >> 2];
    var $46 = HEAP32[$2 >> 2];
    var $47 = __ZNK2js5Shape20matchesParamsAfterIdEPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjji($44, $45, $46, $41, $35, $flags, $shortid);
    if ($47) {
      var $_0 = $17;
      __label__ = 36;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $49 = HEAP32[$6 >> 2];
    if (($17 | 0) == ($49 | 0)) {
      var $shape_0 = $17;
      var $this_idx_val = $49;
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $52 = __ZNK8JSObject16inDictionaryModeEv($49);
    if ($52) {
      var $shape_0 = $17;
      var $this_idx_val = $49;
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $54 = __ZN8JSObject16toDictionaryModeEP9JSContext($this, $cx);
    if ($54) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 36;
      break;
    }
   case 15:
    var $57 = HEAP32[$17 + 12 >> 2];
    var $58 = __ZN8JSObject12nativeSearchEP9JSContextib($this, $cx, $57, 0);
    var $shape_0 = HEAP32[$58 >> 2] & -2;
    var $this_idx_val = HEAP32[$6 >> 2];
    __label__ = 16;
    break;
   case 16:
    var $this_idx_val;
    var $shape_0;
    var $64 = __ZNK8JSObject16inDictionaryModeEv($this_idx_val);
    if ($64) {
      __label__ = 17;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 17:
    if (($41 | 0) == -1 ^ 1 | $37 ^ 1) {
      var $72 = $41;
      __label__ = 20;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $68 = $this;
    var $69 = $cx;
    var $70 = __ZN8JSObject9allocSlotEP9JSContextPj($68, $69, $3);
    if ($70) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 36;
      break;
    }
   case 19:
    var $72 = HEAP32[$3 >> 2];
    __label__ = 20;
    break;
   case 20:
    var $72;
    HEAP32[$shape_0 + 24 >> 2] = $72;
    var $74 = HEAPU32[$3 >> 2];
    if (($74 | 0) == -1) {
      __label__ = 27;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $77 = $shape_0 + 4 | 0;
    if ($74 >>> 0 < HEAPU32[$77 >> 2] >>> 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    HEAP32[$77 >> 2] = $74 + 1 | 0;
    var $temp_02 = HEAPU32[$6 >> 2];
    if (($temp_02 | 0) == ($shape_0 | 0)) {
      __label__ = 27;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $83 = HEAPU32[$3 >> 2];
    var $84 = $83 + 1 | 0;
    var $temp_03 = $temp_02;
    __label__ = 24;
    break;
   case 24:
    var $temp_03;
    var $86 = $temp_03 + 4 | 0;
    if (HEAPU32[$86 >> 2] >>> 0 > $83 >>> 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    HEAP32[$86 >> 2] = $84;
    __label__ = 26;
    break;
   case 26:
    var $temp_0 = HEAPU32[$temp_03 + 32 >> 2];
    if (($temp_0 | 0) == ($shape_0 | 0)) {
      __label__ = 27;
      break;
    } else {
      var $temp_03 = $temp_0;
      __label__ = 24;
      break;
    }
   case 27:
    var $93 = HEAP32[$1 >> 2];
    HEAP32[$shape_0 + 16 >> 2] = $93;
    var $95 = HEAP32[$2 >> 2];
    HEAP32[$shape_0 + 20 >> 2] = $95;
    HEAP8[$shape_0 + 28 | 0] = HEAP32[$4 >> 2] & 255;
    HEAP8[$shape_0 + 29 | 0] = ($flags | 2) & 255;
    HEAP16[$shape_0 + 30 >> 1] = $shortid & 65535;
    __ZN8JSObject11updateFlagsEPKN2js5ShapeEb($this, $shape_0);
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    var $105 = __Z16js_GenerateShapeP9JSContext($cx_idx_val);
    var $107 = HEAP32[$6 >> 2] | 0;
    HEAP32[$107 >> 2] = $105;
    __ZN8JSObject13clearOwnShapeEv($this);
    var $shape_1 = $shape_0;
    __label__ = 30;
    break;
   case 28:
    __ZN8JSObject18removeLastPropertyEv($this);
    var $109 = $child;
    __ZN2js5ShapeC1EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj($109, $id, $45, $46, $41, $35, $flags, $shortid, -1879048193, 0);
    var $110 = HEAP32[$6 >> 2];
    var $111 = __ZN8JSObject16getChildPropertyEP9JSContextPN2js5ShapeERS3_($this, $cx, $110, $child);
    if (($111 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      var $shape_1 = $111;
      __label__ = 30;
      break;
    }
   case 29:
    __ZN8JSObject15setLastPropertyEPKN2js5ShapeE($this, $shape_0);
    var $_0 = 0;
    __label__ = 36;
    break;
   case 30:
    var $shape_1;
    if ($32) {
      __label__ = 31;
      break;
    } else {
      var $_0 = $shape_1;
      __label__ = 36;
      break;
    }
   case 31:
    var $shape_1_idx_val = HEAP8[$shape_1 + 28 | 0];
    var $116 = __ZNK2js5Shape7hasSlotEv($shape_1_idx_val);
    if ($116) {
      var $_0 = $shape_1;
      __label__ = 36;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    if ($34 >>> 0 < HEAPU32[$shape_1 + 4 >> 2] >>> 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 33:
    var $122 = $this;
    var $123 = __ZN8JSObject8freeSlotEP9JSContextj($122, $34);
    __label__ = 35;
    break;
   case 34:
    __ZN2JSL14UndefinedValueEv3631($5);
    var $_idx2 = $5 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, $34, $_idx2_val$0, $_idx2_val$1);
    __label__ = 35;
    break;
   case 35:
    var $128 = HEAP32[$cx + 52 >> 2] + 144252 | 0;
    var $130 = HEAP32[$128 >> 2] + 1 | 0;
    HEAP32[$128 >> 2] = $130;
    var $_0 = $shape_1;
    __label__ = 36;
    break;
   case 36:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject11putPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji["X"] = 1;

function __Z19CheckCanChangeAttrsP9JSContextP8JSObjectPKN2js5ShapeEPj($cx, $shape, $attrsp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $shape + 28 | 0;
    var $_idx_val = HEAP8[$1];
    var $2 = __ZNK2js5Shape12configurableEv($_idx_val);
    if ($2) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$attrsp >> 2];
    var $5 = $4 | 4;
    HEAP32[$attrsp >> 2] = $5;
    var $shape_idx_val = HEAP8[$1];
    var $6 = __ZNK2js5Shape16isDataDescriptorEv($shape_idx_val);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 3:
    var $8 = __ZNK2js5Shape7hasSlotEv($shape_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 4:
    if (($4 & 112 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = HEAP32[$shape + 12 >> 2];
    var $15 = $cx;
    var $16 = __ZN8JSObject21reportNotConfigurableEP9JSContextij($15, $14);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL14UndefinedValueEv3631($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN8JSObject14changePropertyEP9JSContextPKN2js5ShapeEjjPFiS1_PS_iPN2JS5ValueEEPFiS1_S6_iiS9_E($this, $cx, $shape, $attrs, $mask, $getter, $setter) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 92;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $slot = __stackBase__ + 8;
    var $child = __stackBase__ + 12;
    var $child1 = __stackBase__ + 52;
    var $3 = $shape + 28 | 0;
    var $7 = HEAPU8[$3] & 255 & $mask | $attrs;
    HEAP32[$1 >> 2] = $7;
    var $8 = $shape + 12 | 0;
    var $9 = HEAP32[$8 >> 2];
    __ZN2js5types26MarkTypePropertyConfiguredEP9JSContextP8JSObjecti($cx, $this, $9);
    if (($7 & 48 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = HEAP32[$8 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($2);
    var $_03_val = HEAP32[$2 >> 2];
    __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiNS0_4TypeE($cx, $this, $13, $_03_val);
    __label__ = 3;
    break;
   case 3:
    var $_02 = ($getter | 0) == 10 ? 0 : $getter;
    var $_01 = ($setter | 0) == 12 ? 0 : $setter;
    var $17 = __Z19CheckCanChangeAttrsP9JSContextP8JSObjectPKN2js5ShapeEPj($cx, $shape, $1);
    if ($17) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 4:
    var $21 = HEAPU32[$1 >> 2];
    if ((HEAPU8[$3] & 255 | 0) == ($21 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $shape_idx_val = HEAP32[$shape + 16 >> 2];
    var $24 = __ZNK2js5Shape6getterEv($shape_idx_val);
    if (($24 | 0) == ($_02 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $shape_idx1_val = HEAP32[$shape + 20 >> 2];
    var $27 = __ZNK2js5Shape6setterEv($shape_idx1_val);
    if (($27 | 0) == ($_01 | 0)) {
      var $_0 = $shape;
      __label__ = 23;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $this_idx = $this | 0;
    var $this_idx_val = HEAPU32[$this_idx >> 2];
    var $30 = __ZNK8JSObject16inDictionaryModeEv($this_idx_val);
    if ($30) {
      __label__ = 8;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 8:
    var $32 = $shape + 24 | 0;
    var $33 = HEAPU32[$32 >> 2];
    HEAP32[$slot >> 2] = $33;
    if (($33 | 0) == -1) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    HEAP32[$32 >> 2] = $33;
    var $45 = $33;
    __label__ = 14;
    break;
   case 10:
    if (($21 & 64 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    HEAP32[$32 >> 2] = $33;
    __label__ = 19;
    break;
   case 12:
    var $39 = $this;
    var $40 = $cx;
    var $41 = __ZN8JSObject9allocSlotEP9JSContextPj($39, $40, $slot);
    if ($41) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 13:
    var $_pre = HEAP32[$slot >> 2];
    HEAP32[$32 >> 2] = $_pre;
    if (($_pre | 0) == -1) {
      __label__ = 19;
      break;
    } else {
      var $45 = $_pre;
      __label__ = 14;
      break;
    }
   case 14:
    var $45;
    var $46 = $shape + 4 | 0;
    if ($45 >>> 0 < HEAPU32[$46 >> 2] >>> 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $50 = $45 + 1 | 0;
    HEAP32[$46 >> 2] = $50;
    var $temp_03 = HEAP32[$this_idx >> 2];
    if (($temp_03 | 0) == ($shape | 0)) {
      __label__ = 19;
      break;
    } else {
      var $temp_04 = $temp_03;
      __label__ = 16;
      break;
    }
   case 16:
    var $temp_04;
    var $52 = $temp_04 + 4 | 0;
    if (HEAPU32[$52 >> 2] >>> 0 > $45 >>> 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    HEAP32[$52 >> 2] = $50;
    __label__ = 18;
    break;
   case 18:
    var $temp_0 = HEAPU32[$temp_04 + 32 >> 2];
    if (($temp_0 | 0) == ($shape | 0)) {
      __label__ = 19;
      break;
    } else {
      var $temp_04 = $temp_0;
      __label__ = 16;
      break;
    }
   case 19:
    HEAP32[$shape + 16 >> 2] = $_02;
    HEAP32[$shape + 20 >> 2] = $_01;
    HEAP8[$3] = $21 & 255;
    __ZN8JSObject11updateFlagsEPKN2js5ShapeEb($this, $shape);
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    var $62 = __Z16js_GenerateShapeP9JSContext($cx_idx_val);
    var $64 = HEAP32[$this_idx >> 2] | 0;
    HEAP32[$64 >> 2] = $62;
    __ZN8JSObject13clearOwnShapeEv($this);
    var $_0 = $shape;
    __label__ = 23;
    break;
   case 20:
    var $67 = HEAP32[$8 >> 2];
    var $69 = HEAP32[$shape + 24 >> 2];
    var $72 = HEAPU8[$shape + 29 | 0] & 255;
    var $75 = HEAP16[$shape + 30 >> 1] << 16 >> 16;
    if (($this_idx_val | 0) == ($shape | 0)) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    var $77 = $child;
    var $78 = $_02;
    var $79 = $_01;
    __ZN2js5ShapeC1EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj($77, $67, $78, $79, $69, $21, $72, $75, -1879048193, 0);
    var $81 = HEAP32[$shape + 32 >> 2];
    var $82 = __ZN8JSObject16getChildPropertyEP9JSContextPN2js5ShapeERS3_($this, $cx, $81, $child);
    var $_0 = $82;
    __label__ = 23;
    break;
   case 22:
    var $84 = $child1;
    var $85 = $_02;
    var $86 = $_01;
    __ZN2js5ShapeC1EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj($84, $67, $85, $86, $69, $21, $72, $75, -1879048193, 0);
    var $88 = HEAP32[$child1 + 12 >> 2];
    var $90 = HEAP32[$child1 + 16 >> 2];
    var $92 = HEAP32[$child1 + 20 >> 2];
    var $94 = HEAP32[$child1 + 24 >> 2];
    var $97 = HEAPU32[$child1 + 28 >> 2];
    var $98 = $97 & 255;
    var $100 = $97 >>> 8 & 255;
    var $101 = $97 >> 16;
    var $102 = __ZN8JSObject11putPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji($this, $cx, $88, $90, $92, $94, $98, $100, $101);
    var $_0 = $102;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject14changePropertyEP9JSContextPKN2js5ShapeEjjPFiS1_PS_iPN2JS5ValueEEPFiS1_S6_iiS9_E["X"] = 1;

function __ZN8JSObject14removePropertyEP9JSContexti($this, $cx, $id) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN8JSObject12nativeSearchEP9JSContextib($this, $cx, $id, 0);
    var $5 = HEAP32[$2 >> 2] & -2;
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx3_val = HEAP8[$6 + 28 | 0];
    var $9 = __ZNK2js5Shape7hasSlotEv($_idx3_val);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $addedToFreelist_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = HEAP32[$6 + 24 >> 2];
    var $13 = $this;
    var $14 = __ZN8JSObject8freeSlotEP9JSContextj($13, $12);
    var $17 = HEAP32[$cx + 52 >> 2] + 144252 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    var $addedToFreelist_0 = $14;
    __label__ = 4;
    break;
   case 4:
    var $addedToFreelist_0;
    var $21 = $this | 0;
    var $22 = HEAP32[$21 >> 2];
    if (($6 | 0) == ($22 | 0)) {
      var $shape_0 = $6;
      var $spp_0 = $2;
      var $37 = $22;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $25 = __ZNK8JSObject16inDictionaryModeEv($22);
    if ($25) {
      var $shape_0 = $6;
      var $spp_0 = $2;
      var $37 = $22;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $27 = __ZN8JSObject16toDictionaryModeEP9JSContext($this, $cx);
    if ($27) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 30;
      break;
    }
   case 7:
    var $30 = HEAP32[$6 + 12 >> 2];
    var $31 = __ZN8JSObject12nativeSearchEP9JSContextib($this, $cx, $30, 0);
    var $shape_0 = HEAP32[$31 >> 2] & -2;
    var $spp_0 = $31;
    var $37 = HEAP32[$21 >> 2];
    __label__ = 8;
    break;
   case 8:
    var $37;
    var $spp_0;
    var $shape_0;
    var $38 = __ZNK8JSObject16inDictionaryModeEv($37);
    if ($38) {
      __label__ = 9;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 9:
    var $_idx1_val = HEAP32[$37 + 8 >> 2];
    var $40 = __ZNK2js5Shape8hasTableEv($_idx1_val);
    if ($40) {
      __label__ = 10;
      break;
    } else {
      var $43 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $42 = __ZNK2js5Shape8getTableEv($37);
    var $43 = $42;
    __label__ = 11;
    break;
   case 11:
    var $43;
    if ((HEAP32[$spp_0 >> 2] & 1 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    HEAP32[$spp_0 >> 2] = 1;
    var $49 = $43 + 8 | 0;
    var $51 = HEAP32[$49 >> 2] + 1 | 0;
    HEAP32[$49 >> 2] = $51;
    var $52 = $43 + 4 | 0;
    var $54 = HEAP32[$52 >> 2] - 1 | 0;
    HEAP32[$52 >> 2] = $54;
    var $_pre_phi = ($43 | 0) == 0;
    __label__ = 15;
    break;
   case 13:
    var $56 = ($43 | 0) == 0;
    if ($56) {
      var $_pre_phi = $56;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    HEAP32[$spp_0 >> 2] = 0;
    var $58 = $43 + 4 | 0;
    var $60 = HEAP32[$58 >> 2] - 1 | 0;
    HEAP32[$58 >> 2] = $60;
    var $_pre_phi = 0;
    __label__ = 15;
    break;
   case 15:
    var $_pre_phi;
    var $62 = $this + 8 | 0;
    var $64 = HEAP32[$62 >> 2] | 128;
    HEAP32[$62 >> 2] = $64;
    var $65 = HEAPU32[$21 >> 2];
    __ZNK2js5Shape20removeFromDictionaryEP8JSObject($shape_0);
    if ($_pre_phi) {
      __label__ = 23;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if (($shape_0 | 0) == ($65 | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 17:
    var $69 = $43 + 12 | 0;
    if ((HEAP32[$69 >> 2] | 0) == -1) {
      __label__ = 21;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $74 = HEAP32[$shape_0 + 4 >> 2];
    var $76 = HEAP32[$21 >> 2] + 4 | 0;
    HEAP32[$76 >> 2] = $74;
    if ($addedToFreelist_0 | $9 ^ 1) {
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $84 = $shape_0 + 24 | 0;
    var $85 = HEAPU32[$84 >> 2];
    if ((HEAPU32[HEAP32[$this + 4 >> 2] + 4 >> 2] >>> 8 & 255) >>> 0 > $85 >>> 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $88 = HEAP32[$69 >> 2];
    __ZN2JSL18PrivateUint32ValueEj3636($1, $88);
    var $_idx6 = $1 | 0;
    var $_idx6_val$0 = HEAP32[$_idx6 >> 2];
    var $_idx6_val$1 = HEAP32[$_idx6 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, $85, $_idx6_val$0, $_idx6_val$1);
    var $89 = HEAP32[$84 >> 2];
    HEAP32[$69 >> 2] = $89;
    __label__ = 21;
    break;
   case 21:
    var $91 = $65;
    __ZNK2js5Shape8setTableEPNS_13PropertyTableE($91, 0);
    var $93 = HEAP32[$21 >> 2];
    __ZNK2js5Shape8setTableEPNS_13PropertyTableE($93, $43);
    __label__ = 23;
    break;
   case 22:
    __ZN8JSObject18removeLastPropertyEv($this);
    __label__ = 23;
    break;
   case 23:
    __ZN8JSObject11updateShapeEP9JSContext($this, $cx);
    var $97 = HEAP32[$21 >> 2];
    var $_idx_val = HEAP32[$97 + 8 >> 2];
    var $98 = __ZNK2js5Shape8hasTableEv($_idx_val);
    if ($98) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $100 = __ZNK2js5Shape8getTableEv($97);
    var $_idx7_val = HEAP32[$100 >> 2];
    var $101 = __ZNK2js13PropertyTable8capacityEv($_idx7_val);
    if ($101 >>> 0 > 16) {
      __label__ = 25;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 25:
    if (HEAPU32[$100 + 4 >> 2] >>> 0 > $101 >>> 2 >>> 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $109 = __ZN2js13PropertyTable6changeEiP9JSContext($100, -1, $cx);
    __label__ = 27;
    break;
   case 27:
    var $111 = __ZNK8JSObject13hasSlotsArrayEv($this);
    if ($111) {
      __label__ = 28;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 28:
    var $this_idx2_val_idx_val = HEAP32[HEAP32[$21 >> 2] + 4 >> 2];
    var $113 = __ZNK8JSObject8slotSpanEv($this_idx2_val_idx_val);
    var $115 = ($113 >>> 2) + $113 | 0;
    var $this_idx_val = HEAP32[$this + 28 >> 2];
    var $116 = __ZNK8JSObject8numSlotsEv($this_idx_val);
    if ($115 >>> 0 < $116 >>> 0) {
      __label__ = 29;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 29:
    var $119 = $this;
    var $120 = $cx;
    __ZN8JSObject11shrinkSlotsEP9JSContextj($119, $120, $113);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 30:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject14removePropertyEP9JSContexti["X"] = 1;

function __ZNK2js8Bindings9lastUpvarEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js5Shape8getFlagsEv($this_0_8_val) {
  return $this_0_8_val & 255 & 192;
}

function __ZNK8JSObject20getMethodThrashCountEv($this_0_2_val) {
  return $this_0_2_val >>> 8 & 3;
}

function _INT_TO_JSID3676($i) {
  return $i << 1 | 1;
}

function __ZNK2js5Shape20removeFromDictionaryEP8JSObject($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 32 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $_pre1 = $this + 36 | 0;
    var $_pre2 = $_pre1;
    if (($2 | 0) == 0) {
      var $7 = $2;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $2 + 36 | 0;
    var $_c = HEAP32[$_pre2 >> 2];
    HEAP32[$6 >> 2] = $_c;
    var $7 = HEAP32[$1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $7;
    var $8 = HEAP32[$_pre2 >> 2];
    HEAP32[$8 >> 2] = $7;
    HEAP32[$_pre1 >> 2] = 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject20setMethodThrashCountEj($this, $count) {
  var $1 = $this + 8 | 0;
  var $5 = HEAP32[$1 >> 2] & -769 | $count << 8;
  HEAP32[$1 >> 2] = $5;
  return;
}

function __ZN2js13PropertyTableC2Ej($this, $nentries) {
  HEAP32[$this >> 2] = 28;
  HEAP32[$this + 4 >> 2] = $nentries;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = -1;
  return;
}

function __ZN2js5Shape9setFrozenEv($this) {
  var $1 = $this + 29 | 0;
  var $3 = HEAP8[$1] | 4;
  HEAP8[$1] = $3;
  return;
}

function __ZN2JSL18PrivateUint32ValueEj3636($agg_result, $ui) {
  __ZN2JS5Value16setPrivateUint32Ej($agg_result, $ui);
  return;
}

function __ZN8JSObject5clearEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $shape_0 = $2;
    __label__ = 2;
    break;
   case 2:
    var $shape_0;
    var $5 = HEAP32[$shape_0 + 32 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $shape_0 = $5;
      __label__ = 2;
      break;
    }
   case 3:
    var $8 = __ZNK8JSObject16inDictionaryModeEv($2);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$shape_0 + 36 >> 2] = $this;
    __label__ = 5;
    break;
   case 5:
    __ZN8JSObject13clearOwnShapeEv($this);
    __ZN8JSObject6setMapEPN2js5ShapeE($this, $shape_0);
    var $14 = HEAP32[$cx + 52 >> 2] + 144252 | 0;
    var $16 = HEAP32[$14 >> 2] + 1 | 0;
    HEAP32[$14 >> 2] = $16;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject18rollbackPropertiesEP9JSContextj($this, $cx, $slotSpan) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx1 = $this | 0;
    var $this_idx1_val_idx_val = HEAP32[HEAP32[$this_idx1 >> 2] + 4 >> 2];
    var $1 = __ZNK8JSObject8slotSpanEv($this_idx1_val_idx_val);
    if (($1 | 0) == ($slotSpan | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN8JSObject18removeLastPropertyEv($this);
    var $this_idx_val_idx_val = HEAP32[HEAP32[$this_idx1 >> 2] + 4 >> 2];
    var $3 = __ZNK8JSObject8slotSpanEv($this_idx_val_idx_val);
    if (($3 | 0) == ($slotSpan | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 3:
    __ZN8JSObject11updateShapeEP9JSContext($this, $cx);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject16generateOwnShapeEP9JSContext($this, $cx_0_11_val) {
  var $1 = __Z16js_GenerateShapeP9JSContext($cx_0_11_val);
  __ZN8JSObject11setOwnShapeEj($this, $1);
  return;
}

function __ZN8JSObject17methodShapeChangeEP9JSContextRKN2js5ShapeE($this, $cx, $shape) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $shape_idx_val = HEAPU8[$shape + 29 | 0];
    var $1 = __ZNK2js5Shape8isMethodEv($shape_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $result_0 = $shape;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$shape + 12 >> 2];
    var $6 = HEAP32[$shape + 20 >> 2];
    var $8 = HEAP32[$shape + 24 >> 2];
    var $11 = HEAPU8[$shape + 28 | 0] & 255;
    var $12 = __ZNK2js5Shape8getFlagsEv($shape_idx_val);
    var $13 = $12 & -129;
    var $16 = HEAP16[$shape + 30 >> 1] << 16 >> 16;
    var $17 = __ZN8JSObject11putPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji($this, $cx, $4, 0, $6, $8, $11, $13, $16);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      var $result_0 = $17;
      __label__ = 3;
      break;
    }
   case 3:
    var $result_0;
    var $20 = $this;
    var $_idx_val = HEAP32[$this + 8 >> 2];
    var $22 = __ZN8JSObject7brandedEv($_idx_val);
    if ($22) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $24 = __ZNK8JSObject20getMethodThrashCountEv($_idx_val);
    if ($24 >>> 0 < 3) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $27 = $24 + 1 | 0;
    __ZN8JSObject20setMethodThrashCountEj($this, $27);
    if (($27 | 0) == 3) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $30 = $cx;
    __ZN8JSObject7unbrandEP9JSContext($20, $30);
    var $_0 = $result_0;
    __label__ = 8;
    break;
   case 7:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN8JSObject16generateOwnShapeEP9JSContext($this, $cx_idx_val);
    var $_0 = $result_0;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject17methodShapeChangeEP9JSContextj($this, $cx, $slot) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $this_idx_val = HEAP32[$this + 8 >> 2];
    var $1 = __ZN8JSObject16hasMethodBarrierEv($this_idx_val);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN8JSObject16generateOwnShapeEP9JSContext($this, $cx_idx_val);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 3:
    var $6 = $r;
    var $7 = HEAP32[$this >> 2];
    __ZNK2js5Shape3allEv($6, $7);
    var $_idx = $r;
    __label__ = 4;
    break;
   case 4:
    var $_idx_val = HEAP32[$_idx >> 2];
    var $_idx_val_idx_val = HEAP32[$_idx_val + 32 >> 2];
    var $9 = __ZNK2js5Shape5Range5emptyEv($_idx_val_idx_val);
    if ($9) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = $_idx_val;
    var $12 = __ZNK2js5Shape5Range5frontEv($11);
    if ((HEAP32[$12 + 24 >> 2] | 0) == ($slot | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $17 = __ZN8JSObject17methodShapeChangeEP9JSContextRKN2js5ShapeE($this, $cx, $12);
    var $_0 = ($17 | 0) != 0;
    __label__ = 8;
    break;
   case 7:
    __ZN2js5Shape5Range8popFrontEv($r);
    __label__ = 4;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject16protoShapeChangeEP9JSContext($this, $cx_0_11_val) {
  __ZN8JSObject16generateOwnShapeEP9JSContext($this, $cx_0_11_val);
  return;
}

function __ZN8JSObject20shadowingShapeChangeEP9JSContextRKN2js5ShapeE($this, $cx_0_11_val) {
  __ZN8JSObject16generateOwnShapeEP9JSContext($this, $cx_0_11_val);
  return;
}

function __ZN2js13PropertyTableC1Ej($this, $nentries) {
  __ZN2js13PropertyTableC2Ej($this, $nentries);
  return;
}

function __ZNK2js8Bindings6lookupEP9JSContextP6JSAtomPj($this, $cx, $name, $indexp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this >> 2] | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL12ATOM_TO_JSIDP6JSAtom3673($name);
    var $6 = $cx;
    var $7 = $this;
    var $8 = __ZN2js5Shape6searchEP9JSContextPPS0_ib($6, $7, $5, 0);
    var $11 = HEAP32[$8 >> 2] & -2;
    var $12 = $11;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($indexp | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = HEAP16[$12 + 30 >> 1] << 16 >> 16;
    HEAP32[$indexp >> 2] = $19;
    __label__ = 5;
    break;
   case 5:
    var $_idx_val = HEAP32[$11 + 16 >> 2];
    var $22 = __ZNK2js5Shape6getterEv($_idx_val);
    if (($22 | 0) == 92) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($22 | 0) == 218) {
      var $_0 = 4;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx1_val = HEAP8[$11 + 28 | 0];
    var $28 = __ZNK2js5Shape8writableEv($_idx1_val);
    var $29 = $28 ? 2 : 3;
    var $_0 = $29;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12ATOM_TO_JSIDP6JSAtom3673($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj3746($1);
  return $2;
}

function __ZN2js8Bindings3addEP9JSContextP6JSAtomNS_11BindingKindE($this, $cx, $name, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $child = __stackBase__;
    var $1 = __ZN2js8Bindings11ensureShapeEP9JSContext($this, $cx);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 2:
    var $3 = ($kind | 0) == 1;
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = $this + 4 | 0;
    var $6 = HEAPU16[$5 >> 1];
    var $slot_0 = ($6 & 65535) + 2 | 0;
    var $setter_0 = 216;
    var $getter_0 = 92;
    var $attrs_1 = 69;
    var $indexp_0 = $5;
    var $24 = $6;
    __label__ = 7;
    break;
   case 4:
    if (($kind | 0) == 4) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $12 = $this + 8 | 0;
    var $slot_0 = -1;
    var $setter_0 = 220;
    var $getter_0 = 218;
    var $attrs_1 = 69;
    var $indexp_0 = $12;
    var $24 = HEAP16[$12 >> 1];
    __label__ = 7;
    break;
   case 6:
    var $14 = $this + 6 | 0;
    var $attrs_0 = ($kind | 0) == 3 ? 71 : 69;
    var $19 = HEAPU16[$14 >> 1];
    var $slot_0 = (HEAPU16[$this + 4 >> 1] & 65535) + 2 + ($19 & 65535) | 0;
    var $setter_0 = 222;
    var $getter_0 = 94;
    var $attrs_1 = $attrs_0;
    var $indexp_0 = $14;
    var $24 = $19;
    __label__ = 7;
    break;
   case 7:
    var $24;
    var $indexp_0;
    var $attrs_1;
    var $getter_0;
    var $setter_0;
    var $slot_0;
    if ($24 << 16 >> 16 == -1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $27 = $3 ? 45 : 199;
    var $28 = $cx;
    _JS_ReportErrorNumber($28, 4, $27, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 9:
    if (($name | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $34 = HEAPU16[$this + 4 >> 1] & 65535;
    var $35 = _INT_TO_JSID3676($34);
    var $id_0 = $35;
    __label__ = 12;
    break;
   case 11:
    var $37 = __ZL12ATOM_TO_JSIDP6JSAtom3673($name);
    var $id_0 = $37;
    __label__ = 12;
    break;
   case 12:
    var $id_0;
    var $40 = $child;
    __ZN2js5ShapeC1EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj($40, $id_0, $getter_0, $setter_0, $slot_0, $attrs_1, 64, $24 & 65535, -1879048193, 0);
    var $45 = HEAP32[$this >> 2];
    var $46 = $cx;
    var $47 = $child;
    var $48 = $this;
    var $49 = __ZN2js5Shape8getChildEP9JSContextRKS0_PPS0_($45, $46, $47, $48);
    if (($49 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $53 = HEAP16[$indexp_0 >> 1] + 1 & 65535;
    HEAP16[$indexp_0 >> 1] = $53;
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Bindings3addEP9JSContextP6JSAtomNS_11BindingKindE["X"] = 1;

function __ZN2js8Bindings11ensureShapeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZN2js10EmptyShape17getEmptyCallShapeEP9JSContext($cx);
    HEAP32[$1 >> 2] = $5 | 0;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Bindings17getLocalNameArrayEP9JSContextPNS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEE($this, $namesp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $this + 4 | 0;
    var $_idx4_val = HEAP16[$1 >> 1];
    var $2 = $this + 6 | 0;
    var $_idx5_val = HEAP16[$2 >> 1];
    var $_idx6_val = HEAP16[$this + 8 >> 1];
    var $4 = __ZNK2js8Bindings15countLocalNamesEv($_idx4_val, $_idx5_val, $_idx6_val);
    var $5 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE19growByUninitializedEj($namesp, $4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 2:
    var $9 = $r;
    var $10 = HEAP32[$this >> 2];
    __ZN2js5Shape5RangeC1EPKS0_($9, $10);
    var $_idx1 = $r;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $_idx1_val_idx_val = HEAP32[$_idx1_val + 32 >> 2];
    var $11 = __ZNK2js5Shape5Range5emptyEv($_idx1_val_idx_val);
    if ($11) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $namesp + 4 | 0;
    var $_idx3_val_in = $_idx1_val;
    __label__ = 4;
    break;
   case 4:
    var $_idx3_val_in;
    var $14 = __ZNK2js5Shape5Range5frontEv($_idx3_val_in);
    var $17 = HEAPU16[$14 + 30 >> 1] & 65535;
    var $_idx2_val = HEAP32[$14 + 16 >> 2];
    var $18 = __ZNK2js5Shape6getterEv($_idx2_val);
    if (($18 | 0) == 92) {
      var $index_0 = $17;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = HEAPU16[$1 >> 1] & 65535;
    if (($18 | 0) == 218) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $index_0 = $23 + $17 + (HEAPU16[$2 >> 1] & 65535) | 0;
    __label__ = 8;
    break;
   case 7:
    var $index_0 = $23 + $17 | 0;
    __label__ = 8;
    break;
   case 8:
    var $index_0;
    var $33 = HEAP32[$14 + 12 >> 2];
    var $34 = __ZL12JSID_IS_ATOMi3679($33);
    if (($34 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $37 = __ZL12JSID_TO_ATOMi3680($33);
    var $_idx8_val = HEAP32[$12 >> 2];
    var $38 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEixEj($_idx8_val, $index_0);
    HEAP32[$38 >> 2] = $37;
    __label__ = 11;
    break;
   case 10:
    var $_idx7_val = HEAP32[$12 >> 2];
    var $40 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEixEj($_idx7_val, $index_0);
    HEAP32[$40 >> 2] = 0;
    __label__ = 11;
    break;
   case 11:
    __ZN2js5Shape5Range8popFrontEv($9);
    var $_idx_val = HEAPU32[$_idx1 >> 2];
    var $_idx_val_idx_val = HEAP32[$_idx_val + 32 >> 2];
    var $42 = __ZNK2js5Shape5Range5emptyEv($_idx_val_idx_val);
    if ($42) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      var $_idx3_val_in = $_idx_val;
      __label__ = 4;
      break;
    }
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Bindings17getLocalNameArrayEP9JSContextPNS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEE["X"] = 1;

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE19growByUninitializedEj($this, $incr) {
  var $1 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr);
  return $1;
}

function __ZL12JSID_IS_ATOMi3679($id) {
  var $1 = _JSID_IS_STRING3745($id);
  return $1;
}

function __ZL12JSID_TO_ATOMi3680($id) {
  var $1 = _JSID_TO_STRING3744($id);
  return $1;
}

function __ZNK2js8Bindings12lastVariableEv($this_0_0_val, $this_0_3_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js8Bindings9lastUpvarEv($this_0_0_val);
    if ($this_0_3_val << 16 >> 16 == 0) {
      var $shape_1 = $1;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$1 + 16 >> 2];
    var $4 = __ZNK2js5Shape6getterEv($_idx1_val);
    if (($4 | 0) == 218) {
      __label__ = 3;
      break;
    } else {
      var $shape_1 = $1;
      __label__ = 6;
      break;
    }
   case 3:
    var $7 = $1;
    __label__ = 4;
    break;
   case 4:
    var $7;
    var $_idx2_val = HEAP32[$7 + 32 >> 2];
    var $8 = __ZNK2js5Shape8previousEv($_idx2_val);
    var $_idx_val = HEAP32[$8 + 16 >> 2];
    var $9 = __ZNK2js5Shape6getterEv($_idx_val);
    if (($9 | 0) == 218) {
      var $7 = $8;
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $shape_1 = $8;
    __label__ = 6;
    break;
   case 6:
    var $shape_1;
    return $shape_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Bindings13sharpSlotBaseEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = $cx;
    var $2 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($1, STRING_TABLE.__str3667 | 0, 6, 0);
    if (($2 | 0) == 0) {
      var $_0 = -1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$index >> 2] = -1;
    var $5 = __ZNK2js8Bindings6lookupEP9JSContextP6JSAtomPj($this, $cx, $2, $index);
    var $_0 = HEAP32[$index >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Bindings13makeImmutableEv($this_0_0_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP8[$this_0_0_val + 29 | 0];
    var $2 = __ZNK2js5Shape12inDictionaryEv($_idx_val);
    if ($2) {
      var $shape_0 = $this_0_0_val;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $shape_0;
    __ZN2js5Shape9setFrozenEv($shape_0);
    var $4 = HEAP32[$shape_0 + 32 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $shape_0 = $4;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Bindings5traceEP8JSTracer($this_0_0_val, $trc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_0_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $trc;
    var $4 = $this_0_0_val;
    __ZN2js2gc9MarkShapeEP8JSTracerPKNS_5ShapeEPKc($3, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z12js_XDRScriptP10JSXDRStatePP8JSScript($xdr, $scriptp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 136;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $length = __stackBase__;
    var $lineno = __stackBase__ + 4;
    var $nslots = __stackBase__ + 8;
    var $natoms = __stackBase__ + 12;
    var $nsrcnotes = __stackBase__ + 16;
    var $ntrynotes = __stackBase__ + 20;
    var $nobjects = __stackBase__ + 24;
    var $nregexps = __stackBase__ + 28;
    var $nconsts = __stackBase__ + 32;
    var $prologLength = __stackBase__ + 36;
    var $version = __stackBase__ + 40;
    var $encodedClosedCount = __stackBase__ + 44;
    var $nTypeSets = __stackBase__ + 48;
    var $principals = __stackBase__ + 52;
    var $encodeable = __stackBase__ + 56;
    var $scriptBits = __stackBase__ + 60;
    var $argsVars = __stackBase__ + 64;
    var $paddingUpvars = __stackBase__ + 68;
    var $bindings = __stackBase__ + 72;
    var $automark = __stackBase__ + 84;
    var $names = __stackBase__ + 92;
    var $1 = __stackBase__ + 116;
    var $dummy = __stackBase__ + 120;
    var $name = __stackBase__ + 124;
    var $isBlock = __stackBase__ + 128;
    var $kindAndDepth = __stackBase__ + 132;
    HEAP32[$nTypeSets >> 2] = 0;
    HEAP32[$scriptBits >> 2] = 0;
    var $2 = $xdr + 8 | 0;
    var $3 = HEAPU32[$2 >> 2];
    var $4 = HEAPU32[$scriptp >> 2];
    HEAP32[$nconsts >> 2] = 0;
    HEAP32[$nregexps >> 2] = 0;
    HEAP32[$nobjects >> 2] = 0;
    HEAP32[$natoms >> 2] = 0;
    HEAP32[$ntrynotes >> 2] = 0;
    HEAP32[$nsrcnotes >> 2] = 0;
    var $6 = HEAP32[$xdr + 36 >> 2];
    var $7 = $xdr | 0;
    if ((HEAP32[$7 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $nupvars_0 = -1;
      var $nargs_0 = -1;
      var $nvars_0 = -1;
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx22_val = HEAP16[$4 + 68 >> 1];
    var $12 = __ZNK2js8Bindings9countArgsEv($_idx22_val);
    var $_idx23_val = HEAP16[$4 + 70 >> 1];
    var $14 = __ZNK2js8Bindings9countVarsEv($_idx23_val);
    var $_idx19_val = HEAP16[$4 + 72 >> 1];
    var $16 = __ZNK2js8Bindings11countUpvarsEv($_idx19_val);
    HEAP32[$argsVars >> 2] = ($12 & 65535) << 16 | $14 & 65535;
    HEAP32[$paddingUpvars >> 2] = $16 & 65535;
    var $nupvars_0 = $16;
    var $nargs_0 = $12;
    var $nvars_0 = $14;
    __label__ = 3;
    break;
   case 3:
    var $nvars_0;
    var $nargs_0;
    var $nupvars_0;
    var $23 = $xdr;
    var $24 = _JS_XDRUint32($23, $argsVars);
    if (($24 | 0) == 0) {
      var $_2 = 0;
      __label__ = 172;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $27 = _JS_XDRUint32($23, $paddingUpvars);
    if (($27 | 0) == 0) {
      var $_2 = 0;
      __label__ = 172;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $30 = HEAPU32[$7 >> 2];
    if (($30 | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      var $nupvars_1 = $nupvars_0;
      var $nargs_1 = $nargs_0;
      var $nvars_1 = $nvars_0;
      __label__ = 7;
      break;
    }
   case 6:
    var $33 = HEAPU32[$argsVars >> 2];
    var $nupvars_1 = HEAP32[$paddingUpvars >> 2] & 65535;
    var $nargs_1 = $33 >>> 16 & 65535;
    var $nvars_1 = $33 & 65535;
    __label__ = 7;
    break;
   case 7:
    var $nvars_1;
    var $nargs_1;
    var $nupvars_1;
    var $40 = $bindings;
    var $41 = $3;
    __ZN2js8BindingsC1EP9JSContext($40);
    var $42 = $nargs_1 & 65535;
    var $44 = $42 + ($nvars_1 & 65535) | 0;
    var $45 = $nupvars_1 & 65535;
    var $46 = $44 + $45 | 0;
    if (($46 | 0) == 0) {
      var $156 = $30;
      __label__ = 39;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $49 = $3 + 72 | 0;
    __ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkC2EP11JSArenaPool($automark, $49);
    var $50 = $46 + 31 | 0;
    var $51 = $50 >>> 5;
    var $53 = HEAPU32[$3 + 88 >> 2];
    var $57 = HEAP32[$3 + 96 >> 2];
    var $60 = $57 + ($50 >>> 3 & 536870908) & ($57 ^ -1);
    var $61 = $53 + 12 | 0;
    var $62 = HEAPU32[$61 >> 2];
    var $64 = HEAPU32[$53 + 8 >> 2];
    if ($60 >>> 0 > $64 >>> 0 | $62 >>> 0 > ($64 - $60 | 0) >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $69 = _JS_ArenaAllocate($49, $60);
    var $_p_0 = $69;
    __label__ = 11;
    break;
   case 10:
    var $72 = $60 + $62 | 0;
    HEAP32[$61 >> 2] = $72;
    var $_p_0 = $62;
    __label__ = 11;
    break;
   case 11:
    var $_p_0;
    var $74 = $_p_0;
    if (($_p_0 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    __Z20js_ReportOutOfMemoryP9JSContext($41);
    var $automark_idx35_val = HEAP32[$automark >> 2];
    var $automark_idx36_val = HEAP32[$automark + 4 >> 2];
    __ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkD2Ev($automark_idx35_val, $automark_idx36_val);
    var $_2 = 0;
    __label__ = 172;
    break;
   case 13:
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $41);
    var $77 = $names;
    var $_0_val = HEAP32[$1 >> 2];
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEC1ES3_($77, $_0_val);
    if ((HEAP32[$7 >> 2] | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      var $i2_0 = 0;
      __label__ = 20;
      break;
    }
   case 14:
    var $81 = $4 + 64 | 0;
    var $82 = __ZN2js8Bindings17getLocalNameArrayEP9JSContextPNS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEE($81, $names);
    if ($82) {
      __label__ = 15;
      break;
    } else {
      __label__ = 167;
      break;
    }
   case 15:
    __ZN2jsL7PodZeroIjEEvPT_j($74, $51);
    var $83 = $names + 4 | 0;
    var $i1_011 = 0;
    __label__ = 16;
    break;
   case 16:
    var $i1_011;
    if ($i1_011 >>> 0 < $42 >>> 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 17:
    var $_idx18_val = HEAP32[$83 >> 2];
    var $87 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEixEj($_idx18_val, $i1_011);
    if ((HEAP32[$87 >> 2] | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $94 = $74 + ($i1_011 >>> 5 << 2) | 0;
    var $96 = HEAP32[$94 >> 2] | 1 << ($i1_011 & 31);
    HEAP32[$94 >> 2] = $96;
    __label__ = 19;
    break;
   case 19:
    var $98 = $i1_011 + 1 | 0;
    if (($98 | 0) == ($46 | 0)) {
      var $i2_0 = 0;
      __label__ = 20;
      break;
    } else {
      var $i1_011 = $98;
      __label__ = 16;
      break;
    }
   case 20:
    var $i2_0;
    if ($i2_0 >>> 0 < $51 >>> 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $100 = $name;
    var $101 = $names + 4 | 0;
    var $i3_0 = 0;
    __label__ = 24;
    break;
   case 22:
    var $104 = _JS_XDRUint32($23, $74 + ($i2_0 << 2) | 0);
    if (($104 | 0) == 0) {
      __label__ = 168;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $i2_0 = $i2_0 + 1 | 0;
    __label__ = 20;
    break;
   case 24:
    var $i3_0;
    if ($i3_0 >>> 0 < $46 >>> 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 25:
    var $111 = $i3_0 >>> 0 < $42 >>> 0;
    if ($111) {
      __label__ = 26;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 26:
    if ((HEAP32[$74 + ($i3_0 >>> 5 << 2) >> 2] & 1 << ($i3_0 & 31) | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 27:
    if ((HEAP32[$7 >> 2] | 0) == 1) {
      __label__ = 28;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 28:
    var $124 = __ZN2js8Bindings16addDestructuringEP9JSContextPt($40, $41, $dummy);
    if ($124) {
      __label__ = 37;
      break;
    } else {
      __label__ = 169;
      break;
    }
   case 29:
    if ((HEAP32[$7 >> 2] | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    var $_idx17_val = HEAP32[$101 >> 2];
    var $128 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEixEj($_idx17_val, $i3_0);
    var $129 = HEAP32[$128 >> 2];
    HEAP32[$name >> 2] = $129;
    __label__ = 31;
    break;
   case 31:
    var $131 = _js_XDRAtom($23, $100);
    if (($131 | 0) == 0) {
      __label__ = 170;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    if ((HEAP32[$7 >> 2] | 0) == 1) {
      __label__ = 33;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 33:
    if ($111) {
      var $149 = 1;
      __label__ = 36;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    if ($i3_0 >>> 0 < $44 >>> 0) {
      __label__ = 35;
      break;
    } else {
      var $149 = 4;
      __label__ = 36;
      break;
    }
   case 35:
    var $147 = (HEAP32[$74 + ($i3_0 >>> 5 << 2) >> 2] & 1 << ($i3_0 & 31) | 0) != 0 ? 3 : 2;
    var $149 = $147;
    __label__ = 36;
    break;
   case 36:
    var $149;
    var $150 = HEAP32[$name >> 2];
    var $151 = __ZN2js8Bindings3addEP9JSContextP6JSAtomNS_11BindingKindE($bindings, $3, $150, $149);
    if ($151) {
      __label__ = 37;
      break;
    } else {
      __label__ = 171;
      break;
    }
   case 37:
    var $i3_0 = $i3_0 + 1 | 0;
    __label__ = 24;
    break;
   case 38:
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev($77);
    var $automark_idx33_val = HEAP32[$automark >> 2];
    var $automark_idx34_val = HEAP32[$automark + 4 >> 2];
    __ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkD2Ev($automark_idx33_val, $automark_idx34_val);
    var $156 = HEAP32[$7 >> 2];
    __label__ = 39;
    break;
   case 39:
    var $156;
    if (($156 | 0) == 1) {
      __label__ = 40;
      break;
    } else {
      var $162 = $156;
      __label__ = 42;
      break;
    }
   case 40:
    var $159 = __ZN2js8Bindings11ensureShapeEP9JSContext($bindings, $3);
    if ($159) {
      __label__ = 41;
      break;
    } else {
      var $_2 = 0;
      __label__ = 172;
      break;
    }
   case 41:
    var $bindings_idx_val = HEAP32[$bindings >> 2];
    __ZN2js8Bindings13makeImmutableEv($bindings_idx_val);
    var $162 = HEAP32[$7 >> 2];
    __label__ = 42;
    break;
   case 42:
    var $162;
    if (($162 | 0) == 0) {
      __label__ = 43;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 43:
    var $166 = HEAP32[$4 + 8 >> 2];
    HEAP32[$length >> 2] = $166;
    __label__ = 44;
    break;
   case 44:
    var $168 = _JS_XDRUint32($23, $length);
    if (($168 | 0) == 0) {
      var $_2 = 0;
      __label__ = 172;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    if ((HEAP32[$7 >> 2] | 0) == 0) {
      __label__ = 46;
      break;
    } else {
      var $nClosedArgs_0 = 0;
      var $nClosedVars_0 = 0;
      var $notes_0 = 0;
      __label__ = 66;
      break;
    }
   case 46:
    var $175 = HEAP32[$4 + 32 >> 2];
    HEAP32[$prologLength >> 2] = $175;
    var $_idx37_val = HEAP16[$4 + 12 >> 1];
    var $177 = __ZNK8JSScript10getVersionEv($_idx37_val);
    HEAP32[$version >> 2] = (HEAPU16[$4 + 14 >> 1] & 65535) << 16 | $177;
    var $184 = HEAP32[$4 + 28 >> 2];
    HEAP32[$lineno >> 2] = $184;
    var $185 = $4 + 44 | 0;
    HEAP32[$nslots >> 2] = HEAPU16[$185 >> 1] & 65535;
    HEAP32[$nslots >> 2] = (HEAPU16[$4 + 46 >> 1] & 65535) << 16 | HEAPU16[$185 >> 1] & 65535;
    var $196 = HEAP32[$4 + 40 >> 2];
    HEAP32[$natoms >> 2] = $196;
    var $_idx2_val = HEAP32[$4 >> 2];
    var $_idx3_val = HEAP32[$4 + 8 >> 2];
    var $198 = __ZN8JSScript5notesEv($_idx2_val, $_idx3_val);
    var $199 = __ZN8JSScript8numNotesEv($4);
    HEAP32[$nsrcnotes >> 2] = $199;
    var $201 = HEAP8[$4 + 16 | 0];
    var $202 = __ZN8JSScript13isValidOffsetEh($201);
    if ($202) {
      __label__ = 47;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 47:
    var $_idx6_val = HEAP32[$4 + 4 >> 2];
    var $205 = __ZN8JSScript7objectsEv($_idx6_val, $201);
    var $207 = HEAP32[$205 + 4 >> 2];
    HEAP32[$nobjects >> 2] = $207;
    __label__ = 48;
    break;
   case 48:
    var $210 = HEAP8[$4 + 18 | 0];
    var $211 = __ZN8JSScript13isValidOffsetEh($210);
    if ($211) {
      __label__ = 49;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 49:
    var $_idx11_val = HEAP32[$4 + 4 >> 2];
    var $214 = __ZN8JSScript7regexpsEv($_idx11_val, $210);
    var $216 = HEAP32[$214 + 4 >> 2];
    HEAP32[$nregexps >> 2] = $216;
    __label__ = 50;
    break;
   case 50:
    var $219 = HEAP8[$4 + 19 | 0];
    var $220 = __ZN8JSScript13isValidOffsetEh($219);
    if ($220) {
      __label__ = 51;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 51:
    var $_idx40_val = HEAP32[$4 + 4 >> 2];
    var $223 = __ZN8JSScript8trynotesEv($_idx40_val, $219);
    var $225 = HEAP32[$223 + 4 >> 2];
    HEAP32[$ntrynotes >> 2] = $225;
    __label__ = 52;
    break;
   case 52:
    var $228 = HEAP8[$4 + 21 | 0];
    var $229 = __ZN8JSScript13isValidOffsetEh($228);
    if ($229) {
      __label__ = 53;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 53:
    var $_idx15_val = HEAP32[$4 + 4 >> 2];
    var $232 = __ZN8JSScript6constsEv($_idx15_val, $228);
    var $234 = HEAP32[$232 + 4 >> 2];
    HEAP32[$nconsts >> 2] = $234;
    __label__ = 54;
    break;
   case 54:
    var $237 = HEAPU16[$4 + 48 >> 1];
    var $239 = HEAPU16[$4 + 50 >> 1];
    HEAP32[$encodedClosedCount >> 2] = ($237 & 65535) << 16 | $239 & 65535;
    HEAP32[$nTypeSets >> 2] = HEAPU16[$4 + 22 >> 1] & 65535;
    var $247 = $4 + 36 | 0;
    var $248 = HEAPU8[$247];
    if (($248 & 1) << 24 >> 24 == 0) {
      var $255 = $248;
      __label__ = 56;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    var $253 = HEAP32[$scriptBits >> 2] | 1;
    HEAP32[$scriptBits >> 2] = $253;
    var $255 = HEAP8[$247];
    __label__ = 56;
    break;
   case 56:
    var $255;
    if (($255 & 2) << 24 >> 24 == 0) {
      var $262 = $255;
      __label__ = 58;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    var $260 = HEAP32[$scriptBits >> 2] | 2;
    HEAP32[$scriptBits >> 2] = $260;
    var $262 = HEAP8[$247];
    __label__ = 58;
    break;
   case 58:
    var $262;
    if (($262 & 4) << 24 >> 24 == 0) {
      var $269 = $262;
      __label__ = 60;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 59:
    var $267 = HEAP32[$scriptBits >> 2] | 4;
    HEAP32[$scriptBits >> 2] = $267;
    var $269 = HEAP8[$247];
    __label__ = 60;
    break;
   case 60:
    var $269;
    if (($269 & 8) << 24 >> 24 == 0) {
      var $276 = $269;
      __label__ = 62;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    var $274 = HEAP32[$scriptBits >> 2] | 8;
    HEAP32[$scriptBits >> 2] = $274;
    var $276 = HEAP8[$247];
    __label__ = 62;
    break;
   case 62:
    var $276;
    if (($276 & 32) << 24 >> 24 == 0) {
      var $283 = $276;
      __label__ = 64;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $281 = HEAP32[$scriptBits >> 2] | 16;
    HEAP32[$scriptBits >> 2] = $281;
    var $283 = HEAP8[$247];
    __label__ = 64;
    break;
   case 64:
    var $283;
    if (($283 & 64) << 24 >> 24 == 0) {
      var $nClosedArgs_0 = $237;
      var $nClosedVars_0 = $239;
      var $notes_0 = $198;
      __label__ = 66;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 65:
    var $288 = HEAP32[$scriptBits >> 2] | 32;
    HEAP32[$scriptBits >> 2] = $288;
    var $nClosedArgs_0 = $237;
    var $nClosedVars_0 = $239;
    var $notes_0 = $198;
    __label__ = 66;
    break;
   case 66:
    var $notes_0;
    var $nClosedVars_0;
    var $nClosedArgs_0;
    var $290 = _JS_XDRUint32($23, $prologLength);
    if (($290 | 0) == 0) {
      var $_2 = 0;
      __label__ = 172;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 67:
    var $293 = _JS_XDRUint32($23, $version);
    if (($293 | 0) == 0) {
      var $_2 = 0;
      __label__ = 172;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 68:
    var $296 = _JS_XDRUint32($23, $natoms);
    if (($296 | 0) == 0) {
      var $_2 = 0;
      __label__ = 172;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 69:
    var $299 = _JS_XDRUint32($23, $nsrcnotes);
    if (($299 | 0) == 0) {
      var $_2 = 0;
      __label__ = 172;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    var $302 = _JS_XDRUint32($23, $ntrynotes);
    if (($302 | 0) == 0) {
      var $_2 = 0;
      __label__ = 172;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 71:
    var $305 = _JS_XDRUint32($23, $nobjects);
    if (($305 | 0) == 0) {
      var $_2 = 0;
      __label__ = 172;
      break;
    } else {
      __label__ = 72;
      break;
    }
   case 72:
    var $308 = _JS_XDRUint32($23, $nregexps);
    if (($308 | 0) == 0) {
      var $_2 = 0;
      __label__ = 172;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    var $311 = _JS_XDRUint32($23, $nconsts);
    if (($311 | 0) == 0) {
      var $_2 = 0;
      __label__ = 172;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 74:
    var $314 = _JS_XDRUint32($23, $encodedClosedCount);
    if (($314 | 0) == 0) {
      var $_2 = 0;
      __label__ = 172;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 75:
    var $317 = _JS_XDRUint32($23, $nTypeSets);
    if (($317 | 0) == 0) {
      var $_2 = 0;
      __label__ = 172;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 76:
    var $320 = _JS_XDRUint32($23, $scriptBits);
    if (($320 | 0) == 0) {
      var $_2 = 0;
      __label__ = 172;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 77:
    if ((HEAP32[$7 >> 2] | 0) == 1) {
      __label__ = 78;
      break;
    } else {
      var $nClosedArgs_1 = $nClosedArgs_0;
      var $nClosedVars_1 = $nClosedVars_0;
      var $script_0 = $4;
      var $notes_1 = $notes_0;
      __label__ = 91;
      break;
    }
   case 78:
    var $326 = HEAPU32[$encodedClosedCount >> 2];
    var $328 = $326 >>> 16 & 65535;
    var $329 = $326 & 65535;
    var $331 = HEAP32[$version >> 2] & 65535;
    var $332 = HEAP32[$length >> 2];
    var $333 = HEAP32[$nsrcnotes >> 2];
    var $334 = HEAP32[$natoms >> 2];
    var $335 = HEAP32[$nobjects >> 2];
    var $336 = HEAP32[$nregexps >> 2];
    var $337 = HEAP32[$ntrynotes >> 2];
    var $338 = HEAP32[$nconsts >> 2];
    var $339 = HEAP32[$nTypeSets >> 2];
    var $340 = __ZN8JSScript9NewScriptEP9JSContextjjjjjjjjjttj9JSVersion($3, $332, $333, $334, $335, $45, $336, $337, $338, 0, $328, $329, $339, $331);
    if (($340 | 0) == 0) {
      var $_2 = 0;
      __label__ = 172;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 79:
    var $344 = $340 + 64 | 0;
    __ZN2js8Bindings8transferEP9JSContextPS0_($344, $40);
    var $345 = HEAP32[$prologLength >> 2];
    var $346 = $340 + 32 | 0;
    HEAP32[$346 >> 2] = $345;
    HEAP16[$340 + 14 >> 1] = HEAPU32[$version >> 2] >>> 16 & 65535;
    var $_idx_val = HEAP32[$340 >> 2];
    var $_idx1_val = HEAP32[$340 + 8 >> 2];
    var $352 = __ZN8JSScript5notesEv($_idx_val, $_idx1_val);
    HEAP32[$scriptp >> 2] = $340;
    var $353 = HEAPU32[$scriptBits >> 2];
    if (($353 & 1 | 0) == 0) {
      var $361 = $353;
      __label__ = 81;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 80:
    var $357 = $340 + 36 | 0;
    var $359 = HEAP8[$357] | 1;
    HEAP8[$357] = $359;
    var $361 = HEAP32[$scriptBits >> 2];
    __label__ = 81;
    break;
   case 81:
    var $361;
    if (($361 & 2 | 0) == 0) {
      var $369 = $361;
      __label__ = 83;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 82:
    var $365 = $340 + 36 | 0;
    var $367 = HEAP8[$365] | 2;
    HEAP8[$365] = $367;
    var $369 = HEAP32[$scriptBits >> 2];
    __label__ = 83;
    break;
   case 83:
    var $369;
    if (($369 & 4 | 0) == 0) {
      var $377 = $369;
      __label__ = 85;
      break;
    } else {
      __label__ = 84;
      break;
    }
   case 84:
    var $373 = $340 + 36 | 0;
    var $375 = HEAP8[$373] | 4;
    HEAP8[$373] = $375;
    var $377 = HEAP32[$scriptBits >> 2];
    __label__ = 85;
    break;
   case 85:
    var $377;
    if (($377 & 8 | 0) == 0) {
      var $385 = $377;
      __label__ = 87;
      break;
    } else {
      __label__ = 86;
      break;
    }
   case 86:
    var $381 = $340 + 36 | 0;
    var $383 = HEAP8[$381] | 8;
    HEAP8[$381] = $383;
    var $385 = HEAP32[$scriptBits >> 2];
    __label__ = 87;
    break;
   case 87:
    var $385;
    if (($385 & 16 | 0) == 0) {
      var $393 = $385;
      __label__ = 89;
      break;
    } else {
      __label__ = 88;
      break;
    }
   case 88:
    var $389 = $340 + 36 | 0;
    var $391 = HEAP8[$389] | 32;
    HEAP8[$389] = $391;
    var $393 = HEAP32[$scriptBits >> 2];
    __label__ = 89;
    break;
   case 89:
    var $393;
    if (($393 & 32 | 0) == 0) {
      var $nClosedArgs_1 = $328;
      var $nClosedVars_1 = $329;
      var $script_0 = $340;
      var $notes_1 = $352;
      __label__ = 91;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 90:
    var $397 = $340 + 36 | 0;
    var $399 = HEAP8[$397] | 64;
    HEAP8[$397] = $399;
    var $nClosedArgs_1 = $328;
    var $nClosedVars_1 = $329;
    var $script_0 = $340;
    var $notes_1 = $352;
    __label__ = 91;
    break;
   case 91:
    var $notes_1;
    var $script_0;
    var $nClosedVars_1;
    var $nClosedArgs_1;
    var $400 = $xdr + 32 | 0;
    var $401 = HEAP32[$400 >> 2];
    var $402 = $script_0 | 0;
    var $403 = HEAP32[$402 >> 2];
    if ((HEAP32[$7 >> 2] | 0) == 0) {
      __label__ = 92;
      break;
    } else {
      var $code_0 = $403;
      __label__ = 93;
      break;
    }
   case 92:
    var $407 = $3;
    var $409 = _js_UntrapScriptCode($407, $script_0);
    if (($409 | 0) == 0) {
      __label__ = 164;
      break;
    } else {
      var $code_0 = $409;
      __label__ = 93;
      break;
    }
   case 93:
    var $code_0;
    HEAP32[$400 >> 2] = $script_0;
    var $412 = HEAP32[$length >> 2];
    var $413 = _JS_XDRBytes($23, $code_0, $412);
    if (($code_0 | 0) == (HEAP32[$402 >> 2] | 0)) {
      __label__ = 95;
      break;
    } else {
      __label__ = 94;
      break;
    }
   case 94:
    __ZN9JSContext5free_EPv($code_0);
    __label__ = 95;
    break;
   case 95:
    if (($413 | 0) == 0) {
      __label__ = 164;
      break;
    } else {
      __label__ = 96;
      break;
    }
   case 96:
    var $420 = HEAP32[$nsrcnotes >> 2];
    var $421 = _JS_XDRBytes($23, $notes_1, $420);
    if (($421 | 0) == 0) {
      __label__ = 164;
      break;
    } else {
      __label__ = 97;
      break;
    }
   case 97:
    var $424 = _JS_XDRUint32($23, $lineno);
    if (($424 | 0) == 0) {
      __label__ = 164;
      break;
    } else {
      __label__ = 98;
      break;
    }
   case 98:
    var $427 = _JS_XDRUint32($23, $nslots);
    if (($427 | 0) == 0) {
      __label__ = 164;
      break;
    } else {
      __label__ = 99;
      break;
    }
   case 99:
    var $430 = HEAP32[$7 >> 2];
    if (($430 | 0) == 1) {
      __label__ = 100;
      break;
    } else {
      var $450 = $430;
      __label__ = 105;
      break;
    }
   case 100:
    var $433 = $6 + 4 | 0;
    var $434 = HEAP32[$433 >> 2];
    if (($434 | 0) == 0) {
      __label__ = 101;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 101:
    var $436 = _JS_GetSecurityCallbacks($41);
    var $476 = $436;
    __label__ = 111;
    break;
   case 102:
    var $438 = $6 + 8 | 0;
    if ((HEAP8[$438] & 1) << 24 >> 24 == 0) {
      __label__ = 103;
      break;
    } else {
      var $448 = $434;
      __label__ = 104;
      break;
    }
   case 103:
    var $443 = HEAP32[$2 >> 2];
    var $444 = __ZL18SaveScriptFilenameP9JSContextPKc($443, $434);
    var $445 = HEAP32[$433 >> 2];
    __ZN9JSContext5free_EPv($445);
    HEAP32[$433 >> 2] = $444;
    HEAP8[$438] = 1;
    if (($444 | 0) == 0) {
      __label__ = 164;
      break;
    } else {
      var $448 = $444;
      __label__ = 104;
      break;
    }
   case 104:
    var $448;
    HEAP32[$script_0 + 52 >> 2] = $448;
    var $450 = HEAP32[$7 >> 2];
    __label__ = 105;
    break;
   case 105:
    var $450;
    var $451 = _JS_GetSecurityCallbacks($41);
    if (($450 | 0) == 0) {
      __label__ = 106;
      break;
    } else {
      var $476 = $451;
      __label__ = 111;
      break;
    }
   case 106:
    var $455 = HEAP32[$script_0 + 76 >> 2];
    HEAP32[$principals >> 2] = $455;
    if (($451 | 0) == 0) {
      var $462 = 0;
      __label__ = 108;
      break;
    } else {
      __label__ = 107;
      break;
    }
   case 107:
    var $462 = (HEAP32[$451 + 4 >> 2] | 0) != 0;
    __label__ = 108;
    break;
   case 108:
    var $462;
    HEAP32[$encodeable >> 2] = $462 & 1;
    var $464 = _JS_XDRUint32($23, $encodeable);
    if (($464 | 0) == 0) {
      __label__ = 164;
      break;
    } else {
      __label__ = 109;
      break;
    }
   case 109:
    if ((HEAP32[$encodeable >> 2] | 0) == 0) {
      __label__ = 118;
      break;
    } else {
      __label__ = 110;
      break;
    }
   case 110:
    var $472 = HEAP32[$451 + 4 >> 2];
    var $473 = FUNCTION_TABLE[$472]($xdr, $principals);
    if (($473 | 0) == 0) {
      __label__ = 164;
      break;
    } else {
      __label__ = 118;
      break;
    }
   case 111:
    var $476;
    var $477 = _JS_XDRUint32($23, $encodeable);
    if (($477 | 0) == 0) {
      __label__ = 164;
      break;
    } else {
      __label__ = 112;
      break;
    }
   case 112:
    if ((HEAP32[$encodeable >> 2] | 0) == 0) {
      __label__ = 118;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 113:
    if (($476 | 0) == 0) {
      __label__ = 115;
      break;
    } else {
      __label__ = 114;
      break;
    }
   case 114:
    var $486 = HEAP32[$476 + 4 >> 2];
    if (($486 | 0) == 0) {
      __label__ = 115;
      break;
    } else {
      __label__ = 116;
      break;
    }
   case 115:
    _JS_ReportErrorNumber($41, 4, 167, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 164;
    break;
   case 116:
    var $490 = $486;
    var $491 = FUNCTION_TABLE[$490]($xdr, $principals);
    if (($491 | 0) == 0) {
      __label__ = 164;
      break;
    } else {
      __label__ = 117;
      break;
    }
   case 117:
    var $494 = HEAP32[$principals >> 2];
    HEAP32[$script_0 + 76 >> 2] = $494;
    __label__ = 118;
    break;
   case 118:
    if ((HEAP32[$7 >> 2] | 0) == 1) {
      __label__ = 119;
      break;
    } else {
      __label__ = 120;
      break;
    }
   case 119:
    var $500 = HEAP32[$lineno >> 2];
    HEAP32[$script_0 + 28 >> 2] = $500;
    HEAP16[$script_0 + 44 >> 1] = HEAP32[$nslots >> 2] & 65535;
    HEAP16[$script_0 + 46 >> 1] = HEAPU32[$nslots >> 2] >>> 16 & 65535;
    __label__ = 120;
    break;
   case 120:
    var $509 = $script_0 + 56 | 0;
    var $i_0 = 0;
    __label__ = 121;
    break;
   case 121:
    var $i_0;
    if (($i_0 | 0) == (HEAP32[$natoms >> 2] | 0)) {
      __label__ = 122;
      break;
    } else {
      __label__ = 123;
      break;
    }
   case 122:
    var $513 = $xdr;
    var $514 = $script_0 + 4 | 0;
    var $515 = $script_0 + 16 | 0;
    var $i_1 = 0;
    __label__ = 125;
    break;
   case 123:
    var $519 = HEAP32[$509 >> 2] + ($i_0 << 2) | 0;
    var $520 = _js_XDRAtom($23, $519);
    if (($520 | 0) == 0) {
      __label__ = 164;
      break;
    } else {
      __label__ = 124;
      break;
    }
   case 124:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 121;
    break;
   case 125:
    var $i_1;
    if (($i_1 | 0) == (HEAP32[$nobjects >> 2] | 0)) {
      __label__ = 126;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 126:
    var $527 = $script_0 + 17 | 0;
    var $i_2 = 0;
    __label__ = 134;
    break;
   case 127:
    var $_idx4_val = HEAP32[$514 >> 2];
    var $_idx5_val = HEAP8[$515];
    var $529 = __ZN8JSScript7objectsEv($_idx4_val, $_idx5_val);
    var $532 = HEAP32[$529 >> 2] + ($i_1 << 2) | 0;
    if ((HEAP32[$7 >> 2] | 0) == 0) {
      __label__ = 128;
      break;
    } else {
      __label__ = 129;
      break;
    }
   case 128:
    var $_idx8_val = HEAP32[HEAP32[$532 >> 2] + 4 >> 2];
    var $538 = __ZNK8JSObject8getClassEv($_idx8_val);
    var $540 = ($538 | 0) == (__ZN2js10BlockClassE | 0) & 1;
    HEAP32[$isBlock >> 2] = $540;
    __label__ = 129;
    break;
   case 129:
    var $542 = _JS_XDRUint32($23, $isBlock);
    if (($542 | 0) == 0) {
      __label__ = 164;
      break;
    } else {
      __label__ = 130;
      break;
    }
   case 130:
    if ((HEAP32[$isBlock >> 2] | 0) == 0) {
      __label__ = 131;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 131:
    var $548 = $532;
    var $549 = __Z20js_XDRFunctionObjectP10JSXDRStatePP8JSObject($513, $548);
    if (($549 | 0) == 0) {
      __label__ = 164;
      break;
    } else {
      __label__ = 133;
      break;
    }
   case 132:
    var $552 = __Z17js_XDRBlockObjectP10JSXDRStatePP8JSObject($xdr, $532);
    if (($552 | 0) == 0) {
      __label__ = 164;
      break;
    } else {
      __label__ = 133;
      break;
    }
   case 133:
    var $i_1 = $i_1 + 1 | 0;
    __label__ = 125;
    break;
   case 134:
    var $i_2;
    if (($i_2 | 0) == ($45 | 0)) {
      __label__ = 135;
      break;
    } else {
      __label__ = 136;
      break;
    }
   case 135:
    var $557 = $xdr;
    var $558 = $script_0 + 18 | 0;
    var $i_3 = 0;
    __label__ = 138;
    break;
   case 136:
    var $_idx20_val = HEAP32[$514 >> 2];
    var $_idx21_val = HEAP8[$527];
    var $560 = __ZN8JSScript6upvarsEv($_idx20_val, $_idx21_val);
    var $563 = HEAP32[$560 >> 2] + ($i_2 << 2) | 0;
    var $564 = _JS_XDRUint32($23, $563);
    if (($564 | 0) == 0) {
      __label__ = 164;
      break;
    } else {
      __label__ = 137;
      break;
    }
   case 137:
    var $i_2 = $i_2 + 1 | 0;
    __label__ = 134;
    break;
   case 138:
    var $i_3;
    if (($i_3 | 0) == (HEAP32[$nregexps >> 2] | 0)) {
      __label__ = 139;
      break;
    } else {
      __label__ = 140;
      break;
    }
   case 139:
    var $571 = $nClosedArgs_1 & 65535;
    var $572 = $script_0 + 88 | 0;
    var $i_4 = 0;
    __label__ = 142;
    break;
   case 140:
    var $_idx9_val = HEAP32[$514 >> 2];
    var $_idx10_val = HEAP8[$558];
    var $574 = __ZN8JSScript7regexpsEv($_idx9_val, $_idx10_val);
    var $578 = HEAP32[$574 >> 2] + ($i_3 << 2) | 0;
    var $579 = __Z18js_XDRRegExpObjectP10JSXDRStatePP8JSObject($557, $578);
    if (($579 | 0) == 0) {
      __label__ = 164;
      break;
    } else {
      __label__ = 141;
      break;
    }
   case 141:
    var $i_3 = $i_3 + 1 | 0;
    __label__ = 138;
    break;
   case 142:
    var $i_4;
    if (($i_4 | 0) == ($571 | 0)) {
      __label__ = 143;
      break;
    } else {
      __label__ = 144;
      break;
    }
   case 143:
    var $585 = $nClosedVars_1 & 65535;
    var $i_5 = 0;
    __label__ = 146;
    break;
   case 144:
    var $588 = HEAP32[$572 >> 2] + ($i_4 << 2) | 0;
    var $589 = _JS_XDRUint32($23, $588);
    if (($589 | 0) == 0) {
      __label__ = 164;
      break;
    } else {
      __label__ = 145;
      break;
    }
   case 145:
    var $i_4 = $i_4 + 1 | 0;
    __label__ = 142;
    break;
   case 146:
    var $i_5;
    if (($i_5 | 0) == ($585 | 0)) {
      __label__ = 149;
      break;
    } else {
      __label__ = 147;
      break;
    }
   case 147:
    var $598 = HEAP32[$572 >> 2] + ($i_5 + $571 << 2) | 0;
    var $599 = _JS_XDRUint32($23, $598);
    if (($599 | 0) == 0) {
      __label__ = 164;
      break;
    } else {
      __label__ = 148;
      break;
    }
   case 148:
    var $i_5 = $i_5 + 1 | 0;
    __label__ = 146;
    break;
   case 149:
    var $604 = HEAP32[$ntrynotes >> 2];
    if (($604 | 0) == 0) {
      __label__ = 159;
      break;
    } else {
      __label__ = 150;
      break;
    }
   case 150:
    var $_idx38_val = HEAP32[$514 >> 2];
    var $_idx39_val = HEAP8[$script_0 + 19 | 0];
    var $608 = __ZN8JSScript8trynotesEv($_idx38_val, $_idx39_val);
    var $610 = HEAPU32[$608 >> 2];
    var $tn_0 = $610 + $604 * 12 | 0;
    __label__ = 151;
    break;
   case 151:
    var $tn_0;
    var $612 = $tn_0 - 12 | 0;
    if ((HEAP32[$7 >> 2] | 0) == 0) {
      __label__ = 152;
      break;
    } else {
      __label__ = 153;
      break;
    }
   case 152:
    HEAP32[$kindAndDepth >> 2] = (HEAPU8[$612 | 0] & 255) << 16 | HEAPU16[$tn_0 - 12 + 2 >> 1] & 65535;
    __label__ = 153;
    break;
   case 153:
    var $625 = _JS_XDRUint32($23, $kindAndDepth);
    if (($625 | 0) == 0) {
      __label__ = 164;
      break;
    } else {
      __label__ = 154;
      break;
    }
   case 154:
    var $629 = _JS_XDRUint32($23, $tn_0 - 12 + 4 | 0);
    if (($629 | 0) == 0) {
      __label__ = 164;
      break;
    } else {
      __label__ = 155;
      break;
    }
   case 155:
    var $633 = _JS_XDRUint32($23, $tn_0 - 12 + 8 | 0);
    if (($633 | 0) == 0) {
      __label__ = 164;
      break;
    } else {
      __label__ = 156;
      break;
    }
   case 156:
    if ((HEAP32[$7 >> 2] | 0) == 1) {
      __label__ = 157;
      break;
    } else {
      __label__ = 158;
      break;
    }
   case 157:
    HEAP8[$612 | 0] = HEAPU32[$kindAndDepth >> 2] >>> 16 & 255;
    HEAP16[$tn_0 - 12 + 2 >> 1] = HEAP32[$kindAndDepth >> 2] & 65535;
    __label__ = 158;
    break;
   case 158:
    if (($612 | 0) == ($610 | 0)) {
      __label__ = 159;
      break;
    } else {
      var $tn_0 = $612;
      __label__ = 151;
      break;
    }
   case 159:
    var $648 = $script_0 + 21 | 0;
    var $i_6 = 0;
    __label__ = 160;
    break;
   case 160:
    var $i_6;
    if (($i_6 | 0) == (HEAP32[$nconsts >> 2] | 0)) {
      __label__ = 163;
      break;
    } else {
      __label__ = 161;
      break;
    }
   case 161:
    var $_idx13_val = HEAP32[$514 >> 2];
    var $_idx14_val = HEAP8[$648];
    var $652 = __ZN8JSScript6constsEv($_idx13_val, $_idx14_val);
    var $655 = HEAP32[$652 >> 2] + ($i_6 << 3) | 0;
    var $656 = _JS_XDRValue($23, $655);
    if (($656 | 0) == 0) {
      __label__ = 164;
      break;
    } else {
      __label__ = 162;
      break;
    }
   case 162:
    var $i_6 = $i_6 + 1 | 0;
    __label__ = 160;
    break;
   case 163:
    HEAP32[$400 >> 2] = $401;
    var $_2 = 1;
    __label__ = 172;
    break;
   case 164:
    if ((HEAP32[$7 >> 2] | 0) == 1) {
      __label__ = 165;
      break;
    } else {
      __label__ = 166;
      break;
    }
   case 165:
    HEAP32[$scriptp >> 2] = 0;
    __label__ = 166;
    break;
   case 166:
    HEAP32[$400 >> 2] = $401;
    var $_2 = 0;
    __label__ = 172;
    break;
   case 167:
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev($77);
    var $automark_idx31_val = HEAP32[$automark >> 2];
    var $automark_idx32_val = HEAP32[$automark + 4 >> 2];
    __ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkD2Ev($automark_idx31_val, $automark_idx32_val);
    var $_2 = 0;
    __label__ = 172;
    break;
   case 168:
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev($77);
    var $automark_idx29_val = HEAP32[$automark >> 2];
    var $automark_idx30_val = HEAP32[$automark + 4 >> 2];
    __ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkD2Ev($automark_idx29_val, $automark_idx30_val);
    var $_2 = 0;
    __label__ = 172;
    break;
   case 169:
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev($77);
    var $automark_idx27_val = HEAP32[$automark >> 2];
    var $automark_idx28_val = HEAP32[$automark + 4 >> 2];
    __ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkD2Ev($automark_idx27_val, $automark_idx28_val);
    var $_2 = 0;
    __label__ = 172;
    break;
   case 170:
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev($77);
    var $automark_idx25_val = HEAP32[$automark >> 2];
    var $automark_idx26_val = HEAP32[$automark + 4 >> 2];
    __ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkD2Ev($automark_idx25_val, $automark_idx26_val);
    var $_2 = 0;
    __label__ = 172;
    break;
   case 171:
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev($77);
    var $automark_idx_val = HEAP32[$automark >> 2];
    var $automark_idx24_val = HEAP32[$automark + 4 >> 2];
    __ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkD2Ev($automark_idx_val, $automark_idx24_val);
    var $_2 = 0;
    __label__ = 172;
    break;
   case 172:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z12js_XDRScriptP10JSXDRStatePP8JSScript["X"] = 1;

function __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5Range5emptyEv($this_0_0_val, $this_0_1_val) {
  return ($this_0_0_val | 0) == ($this_0_1_val | 0);
}

function __Z21js_MarkScriptFilenamePKc($filename) {
  HEAP8[$filename - 1 | 0] = 1;
  return;
}

function __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5Range5frontEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN2jsL7PodZeroIjEEvPT_j($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem << 2;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN8JSScript8numNotesEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this >> 2];
    var $_idx1_val = HEAP32[$this + 8 >> 2];
    var $2 = __ZN8JSScript5notesEv($_idx_val, $_idx1_val);
    var $3 = HEAP8[$2];
    if ($3 << 24 >> 24 == 0) {
      var $sn_0_lcssa = $2;
      __label__ = 7;
      break;
    } else {
      var $sn_01 = $2;
      var $5 = $3;
      __label__ = 2;
      break;
    }
   case 2:
    var $5;
    var $sn_01;
    if (($5 & 255) > 191) {
      var $11 = 24;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = ($5 & 255) >>> 3;
    __label__ = 4;
    break;
   case 4:
    var $11;
    if (HEAP8[_js_SrcNoteSpec + ($11 << 3) + 4 | 0] << 24 >> 24 == 0) {
      var $18 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = _js_SrcNoteLength($sn_01);
    var $18 = $16;
    __label__ = 6;
    break;
   case 6:
    var $18;
    var $19 = $sn_01 + $18 | 0;
    var $20 = HEAPU8[$19];
    if ($20 << 24 >> 24 == 0) {
      var $sn_0_lcssa = $19;
      __label__ = 7;
      break;
    } else {
      var $sn_01 = $19;
      var $5 = $20;
      __label__ = 2;
      break;
    }
   case 7:
    var $sn_0_lcssa;
    return 1 - $2 + $sn_0_lcssa | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSScript9NewScriptEP9JSContextjjjjjjjjjttj9JSVersion($cx, $length, $nsrcnotes, $natoms, $nobjects, $nupvars, $nregexps, $ntrynotes, $nconsts, $nglobals, $nClosedArgs, $nClosedVars, $nTypeSets, $version) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $natoms << 2;
    var $2 = ($nobjects | 0) != 0;
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $size_0 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    var $size_0 = $1 + 8 + ($nobjects << 2) | 0;
    __label__ = 3;
    break;
   case 3:
    var $size_0;
    var $8 = ($nupvars | 0) != 0;
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $size_1 = $size_0;
      __label__ = 5;
      break;
    }
   case 4:
    var $size_1 = ($nupvars << 2) + 8 + $size_0 | 0;
    __label__ = 5;
    break;
   case 5:
    var $size_1;
    var $14 = ($nregexps | 0) != 0;
    if ($14) {
      __label__ = 6;
      break;
    } else {
      var $size_2 = $size_1;
      __label__ = 7;
      break;
    }
   case 6:
    var $size_2 = ($nregexps << 2) + 8 + $size_1 | 0;
    __label__ = 7;
    break;
   case 7:
    var $size_2;
    var $20 = ($ntrynotes | 0) != 0;
    if ($20) {
      __label__ = 8;
      break;
    } else {
      var $size_3 = $size_2;
      __label__ = 9;
      break;
    }
   case 8:
    var $size_3 = $ntrynotes * 12 + 8 + $size_2 | 0;
    __label__ = 9;
    break;
   case 9:
    var $size_3;
    var $26 = ($nglobals | 0) != 0;
    if ($26) {
      __label__ = 10;
      break;
    } else {
      var $size_4 = $size_3;
      __label__ = 11;
      break;
    }
   case 10:
    var $size_4 = ($nglobals << 3) + 8 + $size_3 | 0;
    __label__ = 11;
    break;
   case 11:
    var $size_4;
    var $34 = ($nClosedVars & 65535) + ($nClosedArgs & 65535) | 0;
    var $35 = ($34 | 0) != 0;
    if ($35) {
      __label__ = 12;
      break;
    } else {
      var $size_5 = $size_4;
      __label__ = 13;
      break;
    }
   case 12:
    var $size_5 = $size_4 + ($34 << 2) | 0;
    __label__ = 13;
    break;
   case 13:
    var $size_5;
    var $40 = ($nconsts | 0) != 0;
    if ($40) {
      __label__ = 14;
      break;
    } else {
      var $size_6 = $size_5;
      __label__ = 15;
      break;
    }
   case 14:
    var $size_6 = ($nconsts << 3) + 8 + $size_5 | 0;
    __label__ = 15;
    break;
   case 15:
    var $size_6;
    var $49 = $size_6 + ($nsrcnotes + ($length + 7)) & -8;
    var $50 = $cx;
    var $51 = __ZN9JSContext7calloc_Ej($50, $49);
    if (($51 | 0) == 0) {
      var $_0 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $54 = __Z14js_NewGCScriptP9JSContext($cx);
    if (($54 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    __ZN2js10Foreground5free_EPv($51);
    var $_0 = 0;
    __label__ = 55;
    break;
   case 18:
    __ZN2jsL7PodZeroI8JSScriptEEvPT_($54);
    var $58 = $54 + 4 | 0;
    HEAP32[$58 >> 2] = $51;
    HEAP32[$54 + 8 >> 2] = $length;
    HEAP16[$54 + 12 >> 1] = $version & 65535;
    var $62 = $54 + 64 | 0;
    if (($62 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $65 = $62;
    __ZN2js8BindingsC1EP9JSContext($65);
    __label__ = 20;
    break;
   case 20:
    var $_idx4_val = HEAP32[$cx + 32 >> 2];
    var $68 = __ZNK9JSContext12hasRunOptionEj($_idx4_val, 131072);
    if ($68) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    var $70 = $54 + 92 | 0;
    __ZN12JSPCCounters4initEP9JSContextj($70, $cx, $length);
    __label__ = 22;
    break;
   case 22:
    var $72 = $54 + 16 | 0;
    if ($2) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    HEAP8[$72] = 0;
    var $cursor_0 = $51 + 8 | 0;
    __label__ = 25;
    break;
   case 24:
    HEAP8[$72] = -1;
    var $cursor_0 = $51;
    __label__ = 25;
    break;
   case 25:
    var $cursor_0;
    if ($8) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    HEAP8[$54 + 17 | 0] = $cursor_0 - $51 & 255;
    var $cursor_1 = $cursor_0 + 8 | 0;
    __label__ = 28;
    break;
   case 27:
    HEAP8[$54 + 17 | 0] = -1;
    var $cursor_1 = $cursor_0;
    __label__ = 28;
    break;
   case 28:
    var $cursor_1;
    if ($14) {
      __label__ = 29;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 29:
    HEAP8[$54 + 18 | 0] = $cursor_1 - $51 & 255;
    var $cursor_2 = $cursor_1 + 8 | 0;
    __label__ = 31;
    break;
   case 30:
    HEAP8[$54 + 18 | 0] = -1;
    var $cursor_2 = $cursor_1;
    __label__ = 31;
    break;
   case 31:
    var $cursor_2;
    if ($20) {
      __label__ = 32;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 32:
    HEAP8[$54 + 19 | 0] = $cursor_2 - $51 & 255;
    var $cursor_3 = $cursor_2 + 8 | 0;
    __label__ = 34;
    break;
   case 33:
    HEAP8[$54 + 19 | 0] = -1;
    var $cursor_3 = $cursor_2;
    __label__ = 34;
    break;
   case 34:
    var $cursor_3;
    if ($26) {
      __label__ = 35;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 35:
    HEAP8[$54 + 20 | 0] = $cursor_3 - $51 & 255;
    var $cursor_4 = $cursor_3 + 8 | 0;
    __label__ = 37;
    break;
   case 36:
    HEAP8[$54 + 20 | 0] = -1;
    var $cursor_4 = $cursor_3;
    __label__ = 37;
    break;
   case 37:
    var $cursor_4;
    if ($40) {
      __label__ = 39;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    HEAP8[$54 + 21 | 0] = -1;
    var $cursor_6 = $cursor_4;
    __label__ = 40;
    break;
   case 39:
    var $123 = $cursor_4 - $51 & 255;
    var $124 = $54 + 21 | 0;
    HEAP8[$124] = $123;
    var $125 = $cursor_4 + 8 | 0;
    var $_idx11_val = HEAP32[$58 >> 2];
    var $126 = __ZN8JSScript6constsEv($_idx11_val, $123);
    var $127 = $126 + 4 | 0;
    HEAP32[$127 >> 2] = $nconsts;
    var $128 = $125;
    var $_idx9_val = HEAP32[$58 >> 2];
    var $_idx10_val = HEAP8[$124];
    var $129 = __ZN8JSScript6constsEv($_idx9_val, $_idx10_val);
    var $130 = $129 | 0;
    HEAP32[$130 >> 2] = $128;
    var $cursor_6 = $cursor_4 + (($nconsts << 3) + 8) | 0;
    __label__ = 40;
    break;
   case 40:
    var $cursor_6;
    if (($natoms | 0) == 0) {
      var $cursor_7 = $cursor_6;
      __label__ = 42;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    HEAP32[$54 + 40 >> 2] = $natoms;
    HEAP32[$54 + 56 >> 2] = $cursor_6;
    var $cursor_7 = $cursor_6 + $1 | 0;
    __label__ = 42;
    break;
   case 42:
    var $cursor_7;
    if ($2) {
      __label__ = 43;
      break;
    } else {
      var $cursor_8 = $cursor_7;
      __label__ = 44;
      break;
    }
   case 43:
    var $_idx2_val = HEAP32[$58 >> 2];
    var $_idx3_val = HEAP8[$72];
    var $142 = __ZN8JSScript7objectsEv($_idx2_val, $_idx3_val);
    var $143 = $142 + 4 | 0;
    HEAP32[$143 >> 2] = $nobjects;
    var $_idx_val = HEAP32[$58 >> 2];
    var $_idx1_val = HEAP8[$72];
    var $144 = __ZN8JSScript7objectsEv($_idx_val, $_idx1_val);
    var $145 = $144 | 0;
    HEAP32[$145 >> 2] = $cursor_7;
    var $cursor_8 = $cursor_7 + ($nobjects << 2) | 0;
    __label__ = 44;
    break;
   case 44:
    var $cursor_8;
    if ($14) {
      __label__ = 45;
      break;
    } else {
      var $cursor_9 = $cursor_8;
      __label__ = 46;
      break;
    }
   case 45:
    var $_idx7_val = HEAP32[$58 >> 2];
    var $150 = $54 + 18 | 0;
    var $_idx8_val = HEAP8[$150];
    var $151 = __ZN8JSScript7regexpsEv($_idx7_val, $_idx8_val);
    var $152 = $151 + 4 | 0;
    HEAP32[$152 >> 2] = $nregexps;
    var $_idx5_val = HEAP32[$58 >> 2];
    var $_idx6_val = HEAP8[$150];
    var $153 = __ZN8JSScript7regexpsEv($_idx5_val, $_idx6_val);
    var $154 = $153 | 0;
    HEAP32[$154 >> 2] = $cursor_8;
    var $cursor_9 = $cursor_8 + ($nregexps << 2) | 0;
    __label__ = 46;
    break;
   case 46:
    var $cursor_9;
    if ($20) {
      __label__ = 47;
      break;
    } else {
      var $cursor_10 = $cursor_9;
      __label__ = 48;
      break;
    }
   case 47:
    var $_idx19_val = HEAP32[$58 >> 2];
    var $159 = $54 + 19 | 0;
    var $_idx20_val = HEAP8[$159];
    var $160 = __ZN8JSScript8trynotesEv($_idx19_val, $_idx20_val);
    var $161 = $160 + 4 | 0;
    HEAP32[$161 >> 2] = $ntrynotes;
    var $_idx17_val = HEAP32[$58 >> 2];
    var $_idx18_val = HEAP8[$159];
    var $162 = __ZN8JSScript8trynotesEv($_idx17_val, $_idx18_val);
    var $163 = $162 | 0;
    HEAP32[$163 >> 2] = $cursor_9;
    var $cursor_10 = $cursor_9 + $ntrynotes * 12 | 0;
    __label__ = 48;
    break;
   case 48:
    var $cursor_10;
    if ($26) {
      __label__ = 49;
      break;
    } else {
      var $cursor_11 = $cursor_10;
      __label__ = 50;
      break;
    }
   case 49:
    var $_idx23_val = HEAP32[$58 >> 2];
    var $168 = $54 + 20 | 0;
    var $_idx24_val = HEAP8[$168];
    var $169 = __ZN8JSScript7globalsEv($_idx23_val, $_idx24_val);
    var $170 = $169 + 4 | 0;
    HEAP32[$170 >> 2] = $nglobals;
    var $_idx21_val = HEAP32[$58 >> 2];
    var $_idx22_val = HEAP8[$168];
    var $171 = __ZN8JSScript7globalsEv($_idx21_val, $_idx22_val);
    var $172 = $171 | 0;
    HEAP32[$172 >> 2] = $cursor_10;
    var $cursor_11 = $cursor_10 + ($nglobals << 3) | 0;
    __label__ = 50;
    break;
   case 50:
    var $cursor_11;
    if ($35) {
      __label__ = 51;
      break;
    } else {
      var $cursor_12 = $cursor_11;
      __label__ = 52;
      break;
    }
   case 51:
    HEAP16[$54 + 48 >> 1] = $nClosedArgs;
    HEAP16[$54 + 50 >> 1] = $nClosedVars;
    HEAP32[$54 + 88 >> 2] = $cursor_11;
    var $cursor_12 = $cursor_11 + ($34 << 2) | 0;
    __label__ = 52;
    break;
   case 52:
    var $cursor_12;
    HEAP16[$54 + 22 >> 1] = $nTypeSets & 65535;
    if ($8) {
      __label__ = 53;
      break;
    } else {
      var $cursor_13 = $cursor_12;
      __label__ = 54;
      break;
    }
   case 53:
    var $_idx15_val = HEAP32[$58 >> 2];
    var $187 = $54 + 17 | 0;
    var $_idx16_val = HEAP8[$187];
    var $188 = __ZN8JSScript6upvarsEv($_idx15_val, $_idx16_val);
    var $189 = $188 + 4 | 0;
    HEAP32[$189 >> 2] = $nupvars;
    var $190 = $cursor_12;
    var $_idx13_val = HEAP32[$58 >> 2];
    var $_idx14_val = HEAP8[$187];
    var $191 = __ZN8JSScript6upvarsEv($_idx13_val, $_idx14_val);
    var $192 = $191 | 0;
    HEAP32[$192 >> 2] = $190;
    var $cursor_13 = $cursor_12 + ($nupvars << 2) | 0;
    __label__ = 54;
    break;
   case 54:
    var $cursor_13;
    HEAP32[$54 >> 2] = $cursor_13;
    var $_0 = $54;
    __label__ = 55;
    break;
   case 55:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSScript9NewScriptEP9JSContextjjjjjjjjjttj9JSVersion["X"] = 1;

function __ZL18SaveScriptFilenameP9JSContextPKc($cx, $filename) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $entry = __stackBase__ + 20;
    HEAP32[$1 >> 2] = $filename;
    var $5 = HEAP32[$cx + 56 >> 2] + 1864 | 0;
    __ZNK2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE12lookupForAddERKPKc($p, $5, $1);
    var $_idx = $p | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $_idx_val_idx_val = HEAP32[$_idx_val >> 2];
    __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrcvMSB_FvvEEv($2, $_idx_val_idx_val);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_idx1_val = $_idx_val;
      __label__ = 6;
      break;
    }
   case 2:
    var $10 = HEAP32[$1 >> 2];
    var $11 = _strlen($10);
    var $12 = $11 + 2 | 0;
    var $13 = $cx;
    var $14 = __ZN9JSContext7malloc_Ej($13, $12);
    var $15 = $14;
    HEAP32[$entry >> 2] = $15;
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP8[$14] = 0;
    var $18 = $14 + 1 | 0;
    var $19 = _strcpy($18, $10);
    var $20 = __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS5_6SetOpsES4_E6AddPtrERS8_($5, $p, $entry);
    if ($20) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx1_val = HEAP32[$_idx >> 2];
    __label__ = 6;
    break;
   case 5:
    var $23 = HEAP32[$entry >> 2] | 0;
    __ZN2js10Foreground5free_EPv($23);
    _JS_ReportOutOfMemory($13);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $_idx1_val;
    var $25 = __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrdeEv($_idx1_val);
    var $_0 = HEAP32[$25 >> 2] + 1 | 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN12JSPCCounters4initEP9JSContextj($this, $cx, $numBytecodes) {
  HEAP32[$this >> 2] = $numBytecodes;
  var $2 = $numBytecodes * 48 | 0;
  var $3 = $cx;
  var $4 = __ZN9JSContext7calloc_Ej($3, $2);
  HEAP32[$this + 4 >> 2] = $4;
  return;
}

function __ZN12JSPCCounters7destroyEP9JSContext($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN9JSContext5free_EPv($5);
    HEAP32[$1 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12script_traceP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $2 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    var $6 = $trc;
    __ZN2js2gc10MarkScriptEP8JSTracerP8JSScriptPKc($6, $5);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z23js_SweepScriptFilenamesP13JSCompartment($comp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e = __stackBase__;
    var $1 = $comp + 1864 | 0;
    __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumC1IS8_EERT_($e, $1);
    var $2 = $e | 0;
    var $_idx2 = $e | 0;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $_idx3 = $e + 4 | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $3 = __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5Range5emptyEv($_idx2_val, $_idx3_val);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $comp | 0;
    var $_idx4_val = $_idx2_val;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumD1Ev($e);
    STACKTOP = __stackBase__;
    return;
   case 4:
    var $_idx4_val;
    var $6 = __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5Range5frontEv($_idx4_val);
    var $8 = HEAP32[$6 >> 2] | 0;
    if ((HEAP8[$8] & 1) << 24 >> 24 == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP8[$8] = 0;
    __label__ = 8;
    break;
   case 6:
    if ((HEAP32[HEAP32[$4 >> 2] + 136 >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2js10Foreground5free_EPv($8);
    __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4Enum11removeFrontEv($e);
    __label__ = 8;
    break;
   case 8:
    __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5Range8popFrontEv($2);
    var $_idx_val = HEAP32[$_idx2 >> 2];
    var $_idx1_val = HEAP32[$_idx3 >> 2];
    var $20 = __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5Range5emptyEv($_idx_val, $_idx1_val);
    if ($20) {
      __label__ = 3;
      break;
    } else {
      var $_idx4_val = $_idx_val;
      __label__ = 4;
      break;
    }
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumC1IS8_EERT_($this, $map) {
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumC2IS8_EERT_($this, $map);
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6removeERNS0_14HashTableEntryIS4_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 8 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$5 >> 2];
    var $8 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isLiveEv($_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumD2Ev($this);
  return;
}

function __Z14js_NewGCScriptP9JSContext($cx) {
  var $1 = __Z10NewGCThingI8JSScriptEPT_P9JSContextN2js2gc9AllocKindEj($cx);
  return $1;
}

function __ZN2jsL7PodZeroI8JSScriptEEvPT_($t) {
  var $1 = $t;
  _memset($1, 0, 104, 1);
  return;
}

function __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE6getMapEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE6hasMapEv($this_0_0_val) {
  return ($this_0_0_val | 0) != 0;
}

function __ZN2js11TokenStream16releaseSourceMapEv($this) {
  var $1 = $this + 176 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$1 >> 2] = 0;
  return $2;
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE5clearEv($this) {
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN8JSScript15NewScriptFromCGEP9JSContextP15JSCodeGenerator($cx, $cg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg + 172 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $9 = HEAP32[$2 + 8 >> 2] - HEAP32[$2 >> 2] | 0;
    var $10 = $cg + 116 | 0;
    var $12 = $cg + 108 | 0;
    var $16 = HEAP32[$10 >> 2] - HEAP32[$12 >> 2] | 0;
    var $17 = $cg + 92 | 0;
    var $18 = __ZN2js8Bindings11ensureShapeEP9JSContext($17, $cx);
    if ($18) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 78;
      break;
    }
   case 2:
    var $27 = HEAP32[$10 >> 2] - HEAP32[$12 >> 2] - HEAP32[$cg + 132 >> 2] | 0;
    var $29 = HEAP32[$cg + 124 >> 2];
    var $31 = HEAPU32[$cg + 156 >> 2];
    var $33 = $31 + ($29 + 1) | 0;
    if (($29 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $39 = HEAPU32[$cg + 188 >> 2];
    if ((HEAP32[$cg + 136 >> 2] | 0) == ($39 | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($27 | 0) > 7) {
      __label__ = 5;
      break;
    } else {
      var $nsrcnotes_0 = $33;
      __label__ = 6;
      break;
    }
   case 5:
    var $nsrcnotes_0 = (($27 + 55 | 0) / 63 & -1) + $33 | 0;
    __label__ = 6;
    break;
   case 6:
    var $nsrcnotes_0;
    var $nsrcnotes_1 = $nsrcnotes_0 + 2 + (($39 >>> 0 > 127 & 1) << 1) | 0;
    __label__ = 15;
    break;
   case 7:
    if (($27 | 0) > 0) {
      __label__ = 8;
      break;
    } else {
      var $nsrcnotes_1 = $33;
      __label__ = 15;
      break;
    }
   case 8:
    if (($31 | 0) == 0) {
      var $diff__0 = $27;
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $60 = HEAPU8[HEAP32[$cg + 152 >> 2]];
    var $61 = $60 & 255;
    if (($60 & 255) > 191) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $68 = $61 & 63 ^ 63;
    __label__ = 12;
    break;
   case 11:
    var $68 = $61 & 7 ^ 7;
    __label__ = 12;
    break;
   case 12:
    var $68;
    var $diff__0 = $27 - $68 | 0;
    __label__ = 13;
    break;
   case 13:
    var $diff__0;
    if (($diff__0 | 0) > 0) {
      __label__ = 14;
      break;
    } else {
      var $nsrcnotes_1 = $33;
      __label__ = 15;
      break;
    }
   case 14:
    var $nsrcnotes_1 = (($diff__0 + 62 | 0) / 63 & -1) + $33 | 0;
    __label__ = 15;
    break;
   case 15:
    var $nsrcnotes_1;
    var $77 = $cg + 516 | 0;
    var $_idx21_val = HEAP32[$cg + 524 >> 2];
    var $79 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE6lengthEv($_idx21_val);
    var $80 = $79 & 65535;
    var $81 = $cg + 564 | 0;
    var $_idx20_val = HEAP32[$cg + 572 >> 2];
    var $83 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE6lengthEv($_idx20_val);
    var $84 = $83 & 65535;
    var $85 = $cg + 308 | 0;
    var $_idx32_val = HEAP32[$85 >> 2];
    var $86 = __ZNK2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE6hasMapEv($_idx32_val);
    if ($86) {
      __label__ = 16;
      break;
    } else {
      var $92 = 0;
      __label__ = 17;
      break;
    }
   case 16:
    var $88 = $_idx32_val;
    var $89 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($88);
    var $90 = __ZN2js9InlineMapIP6JSAtomjLj24EE5countEv($89);
    var $92 = $90;
    __label__ = 17;
    break;
   case 17:
    var $92;
    var $93 = $16 + $9 | 0;
    var $94 = $cg + 176 | 0;
    var $_idx24_val = HEAP32[$94 >> 2];
    var $95 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($_idx24_val);
    var $96 = __ZN2js9InlineMapIP6JSAtomjLj24EE5countEv($95);
    var $97 = $cg + 292 | 0;
    var $98 = HEAP32[$97 >> 2];
    var $99 = $cg + 300 | 0;
    var $100 = HEAP32[$99 >> 2];
    var $101 = $cg + 200 | 0;
    var $102 = HEAP32[$101 >> 2];
    var $104 = $cg + 268 | 0;
    var $105 = __ZNK13JSGCConstList6lengthEv($104);
    var $106 = $cg + 372 | 0;
    var $_idx34_val = HEAP32[$106 >> 2];
    var $107 = __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE6lengthEv($_idx34_val);
    var $110 = HEAPU16[$cg + 614 >> 1] & 65535;
    var $cg_idx = $cg + 48 | 0;
    var $cg_idx_val = HEAP32[$cg_idx >> 2];
    var $111 = __ZNK15JSCodeGenerator7versionEv($cg_idx_val);
    var $112 = __ZN8JSScript9NewScriptEP9JSContextjjjjjjjjjttj9JSVersion($cx, $93, $nsrcnotes_1, $96, $98, $92, $100, $102, $105, $107, $80, $84, $110, $111);
    if (($112 | 0) == 0) {
      var $_0 = 0;
      __label__ = 78;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $_idx15_val = HEAP32[$17 >> 2];
    __ZN2js8Bindings13makeImmutableEv($_idx15_val);
    var $115 = $112 + 32 | 0;
    HEAP32[$115 >> 2] = $16;
    var $116 = $112 | 0;
    var $117 = HEAP32[$116 >> 2];
    var $118 = HEAP32[$12 >> 2];
    _memcpy($117, $118, $16, 1);
    var $119 = $112;
    var $_idx10_val = HEAP32[$116 >> 2];
    var $_idx11_val = HEAP32[$115 >> 2];
    var $120 = __ZN8JSScript4mainEv($_idx10_val, $_idx11_val);
    var $123 = HEAP32[HEAP32[$1 >> 2] >> 2];
    _memcpy($120, $123, $9, 1);
    var $124 = $cg;
    var $_idx27 = $cg | 0;
    var $_idx27_val = HEAP32[$_idx27 >> 2];
    var $125 = __ZNK13JSTreeContext10inFunctionEv($_idx27_val);
    if ($125) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $_idx14_val = HEAP16[$cg + 98 >> 1];
    var $128 = __ZNK2js8Bindings9countVarsEv($_idx14_val);
    var $134 = $128 & 65535;
    __label__ = 21;
    break;
   case 20:
    var $131 = $cg;
    var $132 = __ZNK15JSCodeGenerator10sharpSlotsEv($131);
    var $134 = $132;
    __label__ = 21;
    break;
   case 21:
    var $134;
    var $136 = $112 + 14 | 0;
    HEAP16[$136 >> 1] = $134 & 65535;
    var $_idx36_val = HEAP32[$94 >> 2];
    var $137 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE6getMapEv($_idx36_val);
    var $139 = HEAP32[$112 + 56 >> 2];
    var $140 = $cx;
    var $141 = $137;
    __Z14js_InitAtomMapP9JSContextPN2js9InlineMapIP6JSAtomjLj24EEEPS4_($141, $139);
    var $_idx31_val = HEAP32[HEAP32[$cg_idx >> 2] + 212 >> 2];
    var $144 = __ZNK2js11TokenStream11getFilenameEv($_idx31_val);
    if (($144 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $147 = __ZL18SaveScriptFilenameP9JSContextPKc($cx, $144);
    var $148 = $112 + 52 | 0;
    HEAP32[$148 >> 2] = $147;
    if (($147 | 0) == 0) {
      var $_0 = 0;
      __label__ = 78;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $152 = HEAP32[$cg + 188 >> 2];
    var $153 = $112 + 28 | 0;
    HEAP32[$153 >> 2] = $152;
    var $158 = (HEAPU16[$136 >> 1] & 65535) + HEAP32[$cg + 196 >> 2] | 0;
    if ($158 >>> 0 > 65535) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $163 = HEAP32[$cg_idx >> 2] + 40 | 0;
    var $164 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($163, 0, 0, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str120413 | 0, tempInt));
    var $_0 = 0;
    __label__ = 78;
    break;
   case 25:
    HEAP16[$112 + 44 >> 1] = $158 & 65535;
    HEAP16[$112 + 46 >> 1] = HEAP32[$cg + 76 >> 2] & 65535;
    var $174 = HEAP32[HEAP32[$cg_idx >> 2] + 956 >> 2];
    var $175 = $112 + 76 | 0;
    HEAP32[$175 >> 2] = $174;
    if (($174 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $178 = $174 + 12 | 0;
    var $180 = HEAP32[$178 >> 2] + 1 | 0;
    HEAP32[$178 >> 2] = $180;
    __label__ = 27;
    break;
   case 27:
    var $183 = HEAP32[$cg_idx >> 2] + 40 | 0;
    var $184 = __ZN2js11TokenStream16releaseSourceMapEv($183);
    var $185 = $112 + 80 | 0;
    HEAP32[$185 >> 2] = $184;
    var $_idx1_val = HEAP32[$116 >> 2];
    var $_idx2_val = HEAP32[$112 + 8 >> 2];
    var $187 = __ZN8JSScript5notesEv($_idx1_val, $_idx2_val);
    var $188 = $cg;
    var $189 = _js_FinishTakingSrcNotes($140, $188, $187);
    if (($189 | 0) == 0) {
      var $_0 = 0;
      __label__ = 78;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    if ((HEAP32[$101 >> 2] | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $_idx16_val = HEAP32[$112 + 4 >> 2];
    var $_idx17_val = HEAP8[$112 + 19 | 0];
    var $197 = __ZN8JSScript8trynotesEv($_idx16_val, $_idx17_val);
    var $_idx37_val = HEAP32[$cg + 204 >> 2];
    var $_idx38_val = HEAP32[$197 >> 2];
    var $_idx39_val = HEAP32[$197 + 4 >> 2];
    _js_FinishTakingTryNotes($_idx37_val, $_idx38_val, $_idx39_val);
    __label__ = 30;
    break;
   case 30:
    if ((HEAP32[$97 >> 2] | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $_idx3_val = HEAP32[$112 + 4 >> 2];
    var $_idx4_val = HEAP8[$112 + 16 | 0];
    var $206 = __ZN8JSScript7objectsEv($_idx3_val, $_idx4_val);
    var $_idx43_val = HEAP32[$cg + 296 >> 2];
    var $_idx44_val = HEAP32[$206 >> 2];
    var $_idx45_val = HEAP32[$206 + 4 >> 2];
    __ZN14JSCGObjectList6finishEP13JSObjectArray($_idx43_val, $_idx44_val, $_idx45_val);
    __label__ = 32;
    break;
   case 32:
    if ((HEAP32[$99 >> 2] | 0) == 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $_idx5_val = HEAP32[$112 + 4 >> 2];
    var $_idx6_val = HEAP8[$112 + 18 | 0];
    var $215 = __ZN8JSScript7regexpsEv($_idx5_val, $_idx6_val);
    var $_idx40_val = HEAP32[$cg + 304 >> 2];
    var $_idx41_val = HEAP32[$215 >> 2];
    var $_idx42_val = HEAP32[$215 + 4 >> 2];
    __ZN14JSCGObjectList6finishEP13JSObjectArray($_idx40_val, $_idx41_val, $_idx42_val);
    __label__ = 34;
    break;
   case 34:
    var $219 = __ZNK13JSGCConstList6lengthEv($104);
    if (($219 | 0) == 0) {
      __label__ = 36;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $_idx7_val = HEAP32[$112 + 4 >> 2];
    var $_idx8_val = HEAP8[$112 + 21 | 0];
    var $224 = __ZN8JSScript6constsEv($_idx7_val, $_idx8_val);
    var $225 = $224;
    __ZN13JSGCConstList6finishEP12JSConstArray($104, $225);
    __label__ = 36;
    break;
   case 36:
    var $227 = HEAP32[$_idx27 >> 2];
    if (($227 & 16384 | 0) == 0) {
      var $_idx35_val = $227;
      __label__ = 38;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $231 = $112 + 36 | 0;
    var $233 = HEAP8[$231] | 1;
    HEAP8[$231] = $233;
    var $_idx35_val = HEAP32[$_idx27 >> 2];
    __label__ = 38;
    break;
   case 38:
    var $_idx35_val;
    var $235 = __ZNK15JSCodeGenerator9hasSharpsEv($_idx35_val);
    if ($235) {
      __label__ = 39;
      break;
    } else {
      var $241 = $_idx35_val;
      __label__ = 40;
      break;
    }
   case 39:
    var $237 = $112 + 36 | 0;
    var $239 = HEAP8[$237] | 4;
    HEAP8[$237] = $239;
    var $241 = HEAP32[$_idx27 >> 2];
    __label__ = 40;
    break;
   case 40:
    var $241;
    if (($241 & 262144 | 0) == 0) {
      var $249 = $241;
      __label__ = 42;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    var $245 = $112 + 36 | 0;
    var $247 = HEAP8[$245] | 8;
    HEAP8[$245] = $247;
    var $249 = HEAP32[$_idx27 >> 2];
    __label__ = 42;
    break;
   case 42:
    var $249;
    if (($249 & 8192 | 0) == 0) {
      __label__ = 46;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    var $253 = $112 + 36 | 0;
    var $254 = HEAP8[$253];
    var $255 = $254 | 16;
    HEAP8[$253] = $255;
    var $258 = HEAP32[HEAP32[$cg_idx >> 2] + 960 >> 2];
    if (($258 | 0) == 0) {
      __label__ = 46;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $_idx_val = HEAP32[$258 >> 2];
    var $261 = __ZNK2js10StackFrame15isFunctionFrameEv($_idx_val);
    if ($261) {
      __label__ = 45;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 45:
    var $263 = $254 | 18;
    HEAP8[$253] = $263;
    __label__ = 46;
    break;
   case 46:
    var $_idx29_val = HEAP32[$_idx27 >> 2];
    var $264 = __ZNK13JSTreeContext9callsEvalEv($_idx29_val);
    if ($264) {
      __label__ = 47;
      break;
    } else {
      var $270 = $_idx29_val;
      __label__ = 48;
      break;
    }
   case 47:
    var $266 = $112 + 36 | 0;
    var $268 = HEAP8[$266] | 32;
    HEAP8[$266] = $268;
    var $270 = HEAP32[$_idx27 >> 2];
    __label__ = 48;
    break;
   case 48:
    var $270;
    if (($270 & 128 | 0) == 0) {
      var $278 = $270;
      __label__ = 50;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $274 = $112 + 36 | 0;
    var $276 = HEAP8[$274] | 64;
    HEAP8[$274] = $276;
    var $278 = HEAP32[$_idx27 >> 2];
    __label__ = 50;
    break;
   case 50:
    var $278;
    if (($278 & 134217728 | 0) == 0) {
      __label__ = 52;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $282 = $112 + 37 | 0;
    var $284 = HEAP8[$282] | 2;
    HEAP8[$282] = $284;
    __label__ = 52;
    break;
   case 52:
    var $286 = __ZNK15JSCodeGenerator15hasUpvarIndicesEv($cg);
    if ($286) {
      __label__ = 53;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 53:
    var $_idx12_val = HEAP32[$112 + 4 >> 2];
    var $_idx13_val = HEAP8[$112 + 17 | 0];
    var $290 = __ZN8JSScript6upvarsEv($_idx12_val, $_idx13_val);
    var $293 = HEAP32[$290 >> 2];
    var $294 = $cg + 316 | 0;
    var $_idx46_val = HEAP32[$cg + 320 >> 2];
    var $296 = __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE5beginEv($_idx46_val);
    var $297 = $296;
    var $_idx23 = $85;
    var $_idx23_val = HEAP32[$_idx23 >> 2];
    var $298 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($_idx23_val);
    var $299 = __ZN2js9InlineMapIP6JSAtomjLj24EE5countEv($298);
    var $300 = $299 << 2;
    _memcpy($293, $297, $300, 1);
    var $_idx22_val = HEAP32[$_idx23 >> 2];
    var $301 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($_idx22_val);
    __ZN2js9InlineMapIP6JSAtomjLj24EE5clearEv($301);
    __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE5clearEv($294);
    __label__ = 54;
    break;
   case 54:
    var $_idx33_val = HEAP32[$106 >> 2];
    var $303 = __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE6lengthEv($_idx33_val);
    if (($303 | 0) == 0) {
      __label__ = 56;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    var $_idx18_val = HEAP32[$112 + 4 >> 2];
    var $_idx19_val = HEAP8[$112 + 20 | 0];
    var $308 = __ZN8JSScript7globalsEv($_idx18_val, $_idx19_val);
    var $311 = HEAP32[$308 >> 2];
    var $_idx47_val = HEAP32[$cg + 368 >> 2];
    var $313 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEEixEj($_idx47_val, 0);
    var $314 = $313;
    var $315 = $303 << 3;
    _memcpy($311, $314, $315, 1);
    __label__ = 56;
    break;
   case 56:
    var $317 = $112 + 48 | 0;
    var $318 = HEAPU16[$317 >> 1];
    if ($318 << 16 >> 16 == 0) {
      __label__ = 58;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    var $323 = HEAP32[$112 + 88 >> 2];
    var $324 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEixEj($77);
    var $325 = $324;
    var $327 = ($318 & 65535) << 2;
    _memcpy($323, $325, $327, 1);
    __label__ = 58;
    break;
   case 58:
    var $330 = HEAPU16[$112 + 50 >> 1];
    if ($330 << 16 >> 16 == 0) {
      __label__ = 60;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 59:
    var $338 = HEAP32[$112 + 88 >> 2] + ((HEAPU16[$317 >> 1] & 65535) << 2) | 0;
    var $339 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEixEj($81);
    var $340 = $339;
    var $342 = ($330 & 65535) << 2;
    _memcpy($338, $340, $342, 1);
    __label__ = 60;
    break;
   case 60:
    var $345 = $112 + 64 | 0;
    var $346 = $17;
    __ZN2js8Bindings8transferEP9JSContextPS0_($345, $346);
    var $_idx26_val = HEAPU32[$_idx27 >> 2];
    var $347 = __ZNK13JSTreeContext10inFunctionEv($_idx26_val);
    if ($347) {
      __label__ = 61;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 61:
    var $_idx28_val = HEAP32[$cg + 60 >> 2];
    var $350 = __ZNK13JSTreeContext3funEv($_idx28_val);
    var $351 = $350;
    if (($_idx26_val & 256 | 0) == 0) {
      __label__ = 63;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 62:
    var $355 = $350 + 58 | 0;
    var $357 = HEAP16[$355 >> 1] | 128;
    HEAP16[$355 >> 1] = $357;
    __label__ = 63;
    break;
   case 63:
    var $_idx9_val = HEAP8[$cx + 232 | 0];
    var $360 = __ZN9JSContext20typeInferenceEnabledEv($_idx9_val);
    if ($360) {
      __label__ = 64;
      break;
    } else {
      var $372 = 0;
      __label__ = 67;
      break;
    }
   case 64:
    var $363 = HEAP32[$cg + 72 >> 2];
    if (($363 | 0) == 0) {
      var $372 = 0;
      __label__ = 67;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 65:
    var $_idx30_val = HEAP32[$363 >> 2];
    var $366 = __ZNK13JSTreeContext9compilingEv($_idx30_val);
    if ($366) {
      __label__ = 66;
      break;
    } else {
      var $372 = 0;
      __label__ = 67;
      break;
    }
   case 66:
    var $368 = $363;
    var $369 = __ZN13JSTreeContext15asCodeGeneratorEv($368);
    var $370 = __ZN15JSCodeGenerator21checkSingletonContextEv($369);
    var $372 = $370;
    __label__ = 67;
    break;
   case 67:
    var $372;
    var $373 = __ZN8JSScript15typeSetFunctionEP9JSContextP10JSFunctionb($119, $140, $350, $372);
    if ($373) {
      __label__ = 68;
      break;
    } else {
      var $_0 = 0;
      __label__ = 78;
      break;
    }
   case 68:
    var $375 = $350 + 60 | 0;
    var $_c = $112;
    HEAP32[$375 >> 2] = $_c;
    var $fun_0 = $351;
    __label__ = 71;
    break;
   case 69:
    if (($_idx26_val & 1073741824 | 0) == 0) {
      var $fun_0 = 0;
      __label__ = 71;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    var $380 = __Z18js_NewScriptObjectP9JSContextP8JSScript($cx, $112);
    if (($380 | 0) == 0) {
      var $_0 = 0;
      __label__ = 78;
      break;
    } else {
      var $fun_0 = 0;
      __label__ = 71;
      break;
    }
   case 71:
    var $fun_0;
    __Z20js_CallNewScriptHookP9JSContextP8JSScriptP10JSFunction($cx, $112, $fun_0);
    if ((HEAP32[$cg + 72 >> 2] | 0) == 0) {
      __label__ = 72;
      break;
    } else {
      var $_0 = $112;
      __label__ = 78;
      break;
    }
   case 72:
    if (($fun_0 | 0) == 0) {
      __label__ = 73;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 73:
    var $390 = HEAP32[$112 + 84 >> 2];
    if (($390 | 0) == 0) {
      __label__ = 74;
      break;
    } else {
      var $_ph = $390;
      __label__ = 76;
      break;
    }
   case 74:
    var $393 = __ZNK13JSTreeContext10scopeChainEv($124);
    var $_ph = $393;
    __label__ = 76;
    break;
   case 75:
    var $401 = 1;
    var $400 = $fun_0 | 0;
    __label__ = 77;
    break;
   case 76:
    var $_ph;
    var $401 = ($390 | 0) != 0;
    var $400 = $_ph;
    __label__ = 77;
    break;
   case 77:
    var $400;
    var $401;
    __ZN2js8Debugger11onNewScriptEP9JSContextP8JSScriptP8JSObjectNS0_13NewScriptKindE($140, $119, $400, $401 & 1);
    var $_0 = $112;
    __label__ = 78;
    break;
   case 78:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSScript15NewScriptFromCGEP9JSContextP15JSCodeGenerator["X"] = 1;

function __ZNK15JSCodeGenerator7versionEv($this_0_0_11_val) {
  var $1 = __ZNK2js6Parser16versionWithFlagsEv($this_0_0_11_val);
  return $1;
}

function __ZNK15JSCodeGenerator15hasUpvarIndicesEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this + 308 >> 2];
    var $1 = __ZNK2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE6hasMapEv($_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($_idx_val);
    var $4 = __ZNK2js9InlineMapIP6JSAtomjLj24EE5emptyEv($3);
    var $7 = $4 ^ 1;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEixEj($this) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $2 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE5beginEv($_idx_val);
  return $2;
}

function __Z18js_NewScriptObjectP9JSContextP8JSScript($cx, $script) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3707($cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $script;
    var $5 = $1;
    __ZN8JSObject10setPrivateEPv($5, $4);
    HEAP32[$script + 84 >> 2] = $1;
    __ZN8JSObject9clearTypeEv($5);
    var $_0 = $1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z20js_CallNewScriptHookP9JSContextP8JSScriptP10JSFunction($cx, $script, $fun) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $keep = __stackBase__;
    var $1 = $cx + 200 | 0;
    var $4 = HEAP32[HEAP32[$1 >> 2] + 8 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$cx + 52 >> 2];
    __ZN2js13AutoKeepAtomsC1EP9JSRuntime($keep, $9);
    var $11 = HEAP32[$script + 52 >> 2];
    var $13 = HEAP32[$script + 28 >> 2];
    var $16 = HEAP32[HEAP32[$1 >> 2] + 12 >> 2];
    FUNCTION_TABLE[$4]($cx, $11, $13, $script, $fun, $16);
    var $keep_idx_val = HEAP32[$keep >> 2];
    __ZN2js13AutoKeepAtomsD1Ev($keep_idx_val);
    __label__ = 3;
    break;
   case 3:
    var $18 = $script + 38 | 0;
    var $20 = HEAP8[$18] | 32;
    HEAP8[$18] = $20;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z24js_CallDestroyScriptHookP9JSContextP8JSScript($cx, $script) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $script + 38 | 0;
    var $2 = HEAP8[$1];
    if (($2 & 32) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 200 >> 2];
    var $9 = HEAP32[$7 + 16 >> 2];
    if (($9 | 0) == 0) {
      var $15 = $2;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = HEAP32[$7 + 20 >> 2];
    FUNCTION_TABLE[$9]($cx, $script, $13);
    var $15 = HEAP8[$1];
    __label__ = 4;
    break;
   case 4:
    var $15;
    HEAP8[$1] = $15 & -33;
    __ZN2js8Debugger15onDestroyScriptEP8JSScript($script);
    var $17 = $cx;
    var $18 = $script;
    _JS_ClearScriptTraps($17, $18);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger15onDestroyScriptEP8JSScript($script) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $script;
    var $2 = __ZNK2js2gc4Cell11compartmentEv($1);
    var $3 = __ZN13JSCompartment12getDebuggeesEv($2);
    var $4 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5emptyEv($3);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $script;
    __ZN2js8Debugger23slowPathOnDestroyScriptEP8JSScript($6);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSScript8finalizeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __Z24js_CallDestroyScriptHookP9JSContextP8JSScript($cx, $this);
    var $1 = $this + 76 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 12 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $9 = HEAP32[$1 >> 2];
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = HEAP32[$9 + 16 >> 2];
    FUNCTION_TABLE[$12]($cx, $9);
    __label__ = 4;
    break;
   case 4:
    var $15 = HEAP32[$this + 100 >> 2];
    if (($15 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = $15;
    __ZN2js5types10TypeScript7destroyEv($18);
    __label__ = 6;
    break;
   case 6:
    var $20 = $this + 92 | 0;
    __ZN12JSPCCounters7destroyEP9JSContext($20);
    var $22 = HEAP32[$this + 80 >> 2];
    if (($22 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = $22;
    __ZN9JSContext5free_EPv($25);
    __label__ = 8;
    break;
   case 8:
    var $28 = HEAP32[$this + 4 >> 2];
    __ZN9JSContext5free_EPv($28);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3707($cx) {
  var $3 = HEAPU32[__ZN2js11ScriptClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb3731($3);
  var $5 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3732($cx, $4);
  return $5;
}

function __ZN2js8GSNCache5purgeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this >> 2] = 0;
    var $2 = $this + 4 | 0;
    var $3 = __ZNK2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE11initializedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE6finishEv($2);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE11initializedEv($this) {
  var $_idx_val = HEAP32[$this + 20 >> 2];
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11initializedEv($_idx_val);
  return $1;
}

function __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE6finishEv($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6finishEv($1);
  return;
}

function __ZNK14AutoJSXDRStatecvP10JSXDRStateEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10overloadedEv($this_0_1_val, $this_0_2_val, $this_0_4_val) {
  return ($this_0_4_val + $this_0_2_val | 0) >>> 0 >= ($this_0_1_val * 192 | 0) >>> 8 >>> 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($cx, $script, $pc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 8;
    var $sn2 = __stackBase__ + 16;
    HEAP32[$1 >> 2] = $pc;
    var $3 = $script | 0;
    var $4 = HEAPU32[$3 >> 2];
    var $7 = $pc - $4 | 0;
    var $8 = $script + 8 | 0;
    var $9 = HEAPU32[$8 >> 2];
    if ($7 >>> 0 < $9 >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 33;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$cx + 52 >> 2];
    var $13 = __ZN2js11GetGSNCacheEP9JSContext($_idx_val);
    var $14 = $13 | 0;
    var $15 = HEAPU32[$14 >> 2];
    if (($15 | 0) == ($4 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $19 = $13 + 4 | 0;
    __ZNK2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE6lookupERKS1_($p, $19, $1);
    var $p_idx_val = HEAP32[$p >> 2];
    var $p_idx_val_idx_val = HEAP32[$p_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($2, $p_idx_val_idx_val);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $24 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($p_idx_val);
    var $_0 = HEAP32[$24 + 4 >> 2];
    __label__ = 33;
    break;
   case 5:
    var $28 = __ZN8JSScript5notesEv($4, $9);
    var $sn_0 = $28;
    var $offset_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $offset_0;
    var $sn_0;
    var $30 = HEAPU8[$sn_0];
    if ($30 << 24 >> 24 == 0) {
      var $result_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $33 = $30 & 255;
    var $34 = ($30 & 255) > 191;
    var $_v = $34 ? 63 : 7;
    var $36 = ($_v & $33) + $offset_0 | 0;
    if (($36 | 0) == ($7 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    if (($30 & 255) < 176 & ($34 ^ 1)) {
      var $result_0 = $sn_0;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_ = $34 ? 24 : $33 >>> 3;
    if (HEAP8[_js_SrcNoteSpec + ($_ << 3) + 4 | 0] << 24 >> 24 == 0) {
      var $48 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $46 = _js_SrcNoteLength($sn_0);
    var $48 = $46;
    __label__ = 11;
    break;
   case 11:
    var $48;
    var $sn_0 = $sn_0 + $48 | 0;
    var $offset_0 = $36;
    __label__ = 6;
    break;
   case 12:
    var $result_0;
    if ($9 >>> 0 > 99) {
      __label__ = 13;
      break;
    } else {
      var $_0 = $result_0;
      __label__ = 33;
      break;
    }
   case 13:
    var $53 = HEAPU8[$28];
    if ($53 << 24 >> 24 == 0) {
      var $nsrcnotes_0_lcssa = 0;
      __label__ = 19;
      break;
    } else {
      var $nsrcnotes_06 = 0;
      var $sn1_07 = $28;
      var $55 = $53;
      __label__ = 14;
      break;
    }
   case 14:
    var $55;
    var $sn1_07;
    var $nsrcnotes_06;
    var $56 = ($55 & 255) > 191;
    var $_nsrcnotes_0 = (($55 & 255) < 176 & ($56 ^ 1) & 1) + $nsrcnotes_06 | 0;
    if ($56) {
      var $63 = 24;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $63 = ($55 & 255) >>> 3;
    __label__ = 16;
    break;
   case 16:
    var $63;
    if (HEAP8[_js_SrcNoteSpec + ($63 << 3) + 4 | 0] << 24 >> 24 == 0) {
      var $70 = 1;
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $68 = _js_SrcNoteLength($sn1_07);
    var $70 = $68;
    __label__ = 18;
    break;
   case 18:
    var $70;
    var $71 = $sn1_07 + $70 | 0;
    var $72 = HEAPU8[$71];
    if ($72 << 24 >> 24 == 0) {
      var $nsrcnotes_0_lcssa = $_nsrcnotes_0;
      __label__ = 19;
      break;
    } else {
      var $nsrcnotes_06 = $_nsrcnotes_0;
      var $sn1_07 = $71;
      var $55 = $72;
      __label__ = 14;
      break;
    }
   case 19:
    var $nsrcnotes_0_lcssa;
    var $_pre11 = $13 + 4 | 0;
    if (($15 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE6finishEv($_pre11);
    HEAP32[$14 >> 2] = 0;
    __label__ = 21;
    break;
   case 21:
    var $76 = __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE4initEj($_pre11, $nsrcnotes_0_lcssa);
    if ($76) {
      __label__ = 22;
      break;
    } else {
      var $_0 = $result_0;
      __label__ = 33;
      break;
    }
   case 22:
    var $78 = HEAPU32[$3 >> 2];
    HEAP32[$1 >> 2] = $78;
    var $_idx3_val = HEAP32[$8 >> 2];
    var $79 = __ZN8JSScript5notesEv($78, $_idx3_val);
    HEAP32[$sn2 >> 2] = $79;
    var $80 = HEAP8[$79];
    if ($80 << 24 >> 24 == 0) {
      var $109 = $78;
      __label__ = 32;
      break;
    } else {
      var $84 = $80;
      var $83 = $79;
      var $82 = $78;
      __label__ = 23;
      break;
    }
   case 23:
    var $82;
    var $83;
    var $84;
    var $_v1 = ($84 & 255) > 191 ? 63 : 7;
    HEAP32[$1 >> 2] = $82 + ($_v1 & ($84 & 255)) | 0;
    if (($84 & 255) < 176) {
      __label__ = 24;
      break;
    } else {
      var $91 = $83;
      __label__ = 25;
      break;
    }
   case 24:
    __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE3putERKS1_S7_($_pre11, $1, $sn2);
    var $91 = HEAP32[$sn2 >> 2];
    __label__ = 25;
    break;
   case 25:
    var $91;
    var $92 = HEAPU8[$91];
    if (($92 & 255) > 191) {
      var $98 = 24;
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $98 = ($92 & 255) >>> 3;
    __label__ = 27;
    break;
   case 27:
    var $98;
    if (HEAP8[_js_SrcNoteSpec + ($98 << 3) + 4 | 0] << 24 >> 24 == 0) {
      var $105 = 1;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $103 = _js_SrcNoteLength($91);
    var $105 = $103;
    __label__ = 29;
    break;
   case 29:
    var $105;
    var $106 = $91 + $105 | 0;
    HEAP32[$sn2 >> 2] = $106;
    var $107 = HEAPU8[$106];
    if ($107 << 24 >> 24 == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $84 = $107;
    var $83 = $106;
    var $82 = HEAP32[$1 >> 2];
    __label__ = 23;
    break;
   case 31:
    var $109 = HEAP32[$3 >> 2];
    __label__ = 32;
    break;
   case 32:
    var $109;
    HEAP32[$14 >> 2] = $109;
    var $_0 = $result_0;
    __label__ = 33;
    break;
   case 33:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh["X"] = 1;

function __ZNK2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE6lookupERKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS3_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 224,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj($1, $len);
  return $2;
}

function __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE3putERKS1_S7_($this, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZNK2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE12lookupForAddERKS1_($p, $this, $k);
    var $_idx_val = HEAP32[$p >> 2];
    var $_idx_val_idx_val = HEAP32[$_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($1, $_idx_val_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$v >> 2];
    var $7 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($_idx_val);
    var $8 = $7 + 4 | 0;
    HEAP32[$8 >> 2] = $6;
    __label__ = 4;
    break;
   case 3:
    var $10 = __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S1_EENS5_13MapHashPolicyES4_E6AddPtrERKS1_SF_($this, $p, $k, $v);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z22js_FramePCToLineNumberP9JSContextPN2js10StackFrameEPh($cx, $fp, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $fp;
    var $2 = __ZNK2js10StackFrame6scriptEv($1);
    var $3 = $2;
    var $_idx_val = HEAP32[$fp >> 2];
    var $4 = __ZNK2js10StackFrame11hasImacropcEv($_idx_val);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $9 = $pc;
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$fp + 40 >> 2];
    var $7 = __ZNK2js10StackFrame8imacropcEv($_idx1_val);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    var $10 = __Z17js_PCToLineNumberP9JSContextP8JSScriptPh($cx, $3, $9);
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_PCToLineNumberP9JSContextP8JSScriptPh($cx, $script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($pc | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh3716($script, $pc);
    if ((HEAP32[_js_CodeSpec + ($3 << 3) + 4 >> 2] & 262144 | 0) == 0) {
      var $_01 = $pc;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_01 = $pc + (HEAP8[_js_CodeSpec + ($3 << 3) | 0] << 24 >> 24) | 0;
    __label__ = 4;
    break;
   case 4:
    var $_01;
    if (HEAP8[$_01] << 24 >> 24 == 127) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $17 = $script;
    var $18 = _js_GetIndexFromBytecode($17, $_01, 0);
    var $_idx2_val = HEAP32[$script + 4 >> 2];
    var $_idx3_val = HEAP8[$script + 16 | 0];
    var $21 = __ZN8JSScript11getFunctionEj($_idx2_val, $_idx3_val, $18);
    var $22 = __ZNK10JSFunction6scriptEv($21);
    var $_0 = HEAP32[$22 + 28 >> 2];
    __label__ = 16;
    break;
   case 6:
    var $27 = HEAP32[$script + 28 >> 2];
    var $29 = HEAP32[$script >> 2];
    var $32 = $_01 - $29 | 0;
    var $_idx1_val = HEAP32[$script + 8 >> 2];
    var $34 = __ZN8JSScript5notesEv($29, $_idx1_val);
    var $sn_0 = $34;
    var $offset_0 = 0;
    var $lineno_0 = $27;
    __label__ = 7;
    break;
   case 7:
    var $lineno_0;
    var $offset_0;
    var $sn_0;
    var $36 = HEAPU8[$sn_0];
    var $37 = $36 & 255;
    if ($36 << 24 >> 24 == 0) {
      var $_0 = $lineno_0;
      __label__ = 16;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $40 = ($36 & 255) > 191;
    var $_v = $40 ? 63 : 7;
    var $42 = ($_v & $37) + $offset_0 | 0;
    var $43 = $37 >>> 3;
    var $_ = $40 ? 24 : $43;
    if (($_ | 0) == 23) {
      __label__ = 9;
      break;
    } else if (($_ | 0) == 22) {
      __label__ = 11;
      break;
    } else {
      var $lineno_1 = $lineno_0;
      __label__ = 12;
      break;
    }
   case 9:
    if (($42 | 0) > ($32 | 0)) {
      var $lineno_1 = $lineno_0;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $47 = _js_GetSrcNoteOffset($sn_0, 0);
    var $lineno_1 = $47;
    __label__ = 12;
    break;
   case 11:
    var $lineno_1 = (($42 | 0) <= ($32 | 0) & 1) + $lineno_0 | 0;
    __label__ = 12;
    break;
   case 12:
    var $lineno_1;
    if (($42 | 0) > ($32 | 0)) {
      var $_0 = $lineno_1;
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $53 = $40 ? 24 : $43;
    if (HEAP8[_js_SrcNoteSpec + ($53 << 3) + 4 | 0] << 24 >> 24 == 0) {
      var $60 = 1;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $58 = _js_SrcNoteLength($sn_0);
    var $60 = $58;
    __label__ = 15;
    break;
   case 15:
    var $60;
    var $sn_0 = $sn_0 + $60 | 0;
    var $offset_0 = $42;
    var $lineno_0 = $lineno_1;
    __label__ = 7;
    break;
   case 16:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z17js_PCToLineNumberP9JSContextP8JSScriptPh["X"] = 1;

function __ZL12js_GetOpcodeP9JSContextP8JSScriptPh3716($script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU8[$pc];
    var $2 = $1 & 255;
    if ($1 << 24 >> 24 == 83) {
      __label__ = 2;
      break;
    } else {
      var $op_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $script;
    var $6 = _JS_GetTrapOpcode($5, $pc);
    var $op_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $op_0;
    return $op_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_LineNumberToPCP8JSScriptj($script, $target) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$script + 28 >> 2];
    var $_idx_val = HEAPU32[$script >> 2];
    var $_idx1_val = HEAP32[$script + 8 >> 2];
    var $4 = __ZN8JSScript5notesEv($_idx_val, $_idx1_val);
    var $5 = $script + 32 | 0;
    var $sn_0 = $4;
    var $bestdiff_0 = 8388608;
    var $offset_0 = 0;
    var $best_0 = -1;
    var $lineno_0 = $2;
    __label__ = 2;
    break;
   case 2:
    var $lineno_0;
    var $best_0;
    var $offset_0;
    var $bestdiff_0;
    var $sn_0;
    var $7 = HEAPU8[$sn_0];
    if ($7 << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($lineno_0 | 0) == ($target | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    if (($offset_0 | 0) < (HEAP32[$5 >> 2] | 0)) {
      __label__ = 5;
      break;
    } else {
      var $offset_1 = $offset_0;
      __label__ = 16;
      break;
    }
   case 5:
    if ($lineno_0 >>> 0 < $target >>> 0) {
      var $bestdiff_1 = $bestdiff_0;
      var $best_1 = $best_0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = $lineno_0 - $target | 0;
    if ($17 >>> 0 < $bestdiff_0 >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $bestdiff_1 = $bestdiff_0;
      var $best_1 = $best_0;
      __label__ = 8;
      break;
    }
   case 7:
    var $bestdiff_1 = $17;
    var $best_1 = $offset_0;
    __label__ = 8;
    break;
   case 8:
    var $best_1;
    var $bestdiff_1;
    var $21 = $7 & 255;
    var $22 = ($7 & 255) > 191;
    var $_v = $22 ? 63 : 7;
    var $24 = ($_v & $21) + $offset_0 | 0;
    var $25 = $21 >>> 3;
    var $_ = $22 ? 24 : $25;
    if (($_ | 0) == 23) {
      __label__ = 9;
      break;
    } else if (($_ | 0) == 22) {
      __label__ = 10;
      break;
    } else {
      var $lineno_1 = $lineno_0;
      __label__ = 11;
      break;
    }
   case 9:
    var $27 = _js_GetSrcNoteOffset($sn_0, 0);
    var $lineno_1 = $27;
    __label__ = 11;
    break;
   case 10:
    var $lineno_1 = $lineno_0 + 1 | 0;
    __label__ = 11;
    break;
   case 11:
    var $lineno_1;
    var $31 = $22 ? 24 : $25;
    if (HEAP8[_js_SrcNoteSpec + ($31 << 3) + 4 | 0] << 24 >> 24 == 0) {
      var $38 = 1;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $36 = _js_SrcNoteLength($sn_0);
    var $38 = $36;
    __label__ = 13;
    break;
   case 13:
    var $38;
    var $sn_0 = $sn_0 + $38 | 0;
    var $bestdiff_0 = $bestdiff_1;
    var $offset_0 = $24;
    var $best_0 = $best_1;
    var $lineno_0 = $lineno_1;
    __label__ = 2;
    break;
   case 14:
    if (($best_0 | 0) > -1) {
      __label__ = 15;
      break;
    } else {
      var $offset_1 = $offset_0;
      __label__ = 16;
      break;
    }
   case 15:
    var $offset_1 = $best_0;
    __label__ = 16;
    break;
   case 16:
    var $offset_1;
    return $_idx_val + $offset_1 | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z17js_LineNumberToPCP8JSScriptj["X"] = 1;

function __Z22js_GetScriptLineExtentP8JSScript($script) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$script + 28 >> 2];
    var $_idx_val = HEAP32[$script >> 2];
    var $_idx1_val = HEAP32[$script + 8 >> 2];
    var $4 = __ZN8JSScript5notesEv($_idx_val, $_idx1_val);
    var $5 = HEAP8[$4];
    if ($5 << 24 >> 24 == 0) {
      var $maxLineNo_0_lcssa = 0;
      var $lineno_0_lcssa = $2;
      __label__ = 10;
      break;
    } else {
      var $maxLineNo_01 = 0;
      var $lineno_02 = $2;
      var $counting_03 = 1;
      var $sn_04 = $4;
      var $7 = $5;
      __label__ = 2;
      break;
    }
   case 2:
    var $7;
    var $sn_04;
    var $counting_03;
    var $lineno_02;
    var $maxLineNo_01;
    if (($7 & 255) > 191) {
      var $20 = 24;
      var $maxLineNo_23 = $maxLineNo_01;
      var $lineno_15 = $lineno_02;
      var $counting_17 = $counting_03;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = ($7 & 255) >>> 3;
    if (($11 | 0) == 22) {
      __label__ = 4;
      break;
    } else if (($11 | 0) == 23) {
      __label__ = 5;
      break;
    } else {
      var $maxLineNo_22 = $maxLineNo_01;
      var $lineno_14 = $lineno_02;
      var $counting_16 = $counting_03;
      __label__ = 6;
      break;
    }
   case 4:
    var $maxLineNo_22 = $maxLineNo_01;
    var $lineno_14 = ($counting_03 & 1 & 255) + $lineno_02 | 0;
    var $counting_16 = $counting_03;
    __label__ = 6;
    break;
   case 5:
    var $maxLineNo_1 = $maxLineNo_01 >>> 0 < $lineno_02 >>> 0 ? $lineno_02 : $maxLineNo_01;
    var $16 = _js_GetSrcNoteOffset($sn_04, 0);
    var $17 = $maxLineNo_1 >>> 0 < $16 >>> 0;
    var $_maxLineNo_1 = $17 ? $16 : $maxLineNo_1;
    var $maxLineNo_22 = $_maxLineNo_1;
    var $lineno_14 = $16;
    var $counting_16 = $17 & 1;
    __label__ = 6;
    break;
   case 6:
    var $counting_16;
    var $lineno_14;
    var $maxLineNo_22;
    var $20 = ($7 & 255) >>> 3;
    var $maxLineNo_23 = $maxLineNo_22;
    var $lineno_15 = $lineno_14;
    var $counting_17 = $counting_16;
    __label__ = 7;
    break;
   case 7:
    var $counting_17;
    var $lineno_15;
    var $maxLineNo_23;
    var $20;
    if (HEAP8[_js_SrcNoteSpec + ($20 << 3) + 4 | 0] << 24 >> 24 == 0) {
      var $27 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $25 = _js_SrcNoteLength($sn_04);
    var $27 = $25;
    __label__ = 9;
    break;
   case 9:
    var $27;
    var $28 = $sn_04 + $27 | 0;
    var $29 = HEAPU8[$28];
    if ($29 << 24 >> 24 == 0) {
      var $maxLineNo_0_lcssa = $maxLineNo_23;
      var $lineno_0_lcssa = $lineno_15;
      __label__ = 10;
      break;
    } else {
      var $maxLineNo_01 = $maxLineNo_23;
      var $lineno_02 = $lineno_15;
      var $counting_03 = $counting_17;
      var $sn_04 = $28;
      var $7 = $29;
      __label__ = 2;
      break;
    }
   case 10:
    var $lineno_0_lcssa;
    var $maxLineNo_0_lcssa;
    var $lineno_2 = $maxLineNo_0_lcssa >>> 0 > $lineno_0_lcssa >>> 0 ? $maxLineNo_0_lcssa : $lineno_0_lcssa;
    return $lineno_2 + 1 - $2 | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z22js_GetScriptLineExtentP8JSScript["X"] = 1;

function __ZN2js28CurrentScriptFileAndLineSlowEP9JSContextPj($cx, $linenop) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $iter = __stackBase__;
    var $1 = $cx;
    __ZN2js13FrameRegsIterC1EP9JSContextNS_9StackIter11SavedOptionE($iter, $1);
    __label__ = 2;
    break;
   case 2:
    var $3 = __ZNK2js13FrameRegsIter4doneEv($iter);
    if ($3) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK2js13FrameRegsIter2fpEv($iter);
    var $_idx_val = HEAP32[$5 >> 2];
    var $6 = __ZNK2js10StackFrame13isScriptFrameEv($_idx_val);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js13FrameRegsIterppEv($iter);
    __label__ = 2;
    break;
   case 5:
    var $8 = __ZNK2js13FrameRegsIter4doneEv($iter);
    if ($8) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$linenop >> 2] = 0;
    var $_0 = 0;
    __label__ = 8;
    break;
   case 7:
    var $11 = __ZNK2js13FrameRegsIter2fpEv($iter);
    var $12 = $11;
    var $13 = __ZNK2js13FrameRegsIter2pcEv($iter);
    var $14 = __Z22js_FramePCToLineNumberP9JSContextPN2js10StackFrameEPh($cx, $12, $13);
    HEAP32[$linenop >> 2] = $14;
    var $15 = __ZNK2js13FrameRegsIter2fpEv($iter);
    var $16 = __ZNK2js10StackFrame6scriptEv($15);
    var $_0 = HEAP32[$16 + 52 >> 2];
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z14js_CloneScriptP9JSContextP8JSScript($cx, $script) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $w = __stackBase__ + 4;
    var $disable = __stackBase__ + 8;
    var $wstate = __stackBase__ + 16;
    var $nbytes = __stackBase__ + 28;
    var $r = __stackBase__ + 32;
    var $rstate = __stackBase__ + 36;
    HEAP32[$1 >> 2] = $script;
    var $2 = $cx;
    var $3 = _JS_XDRNewMem($2, 0);
    var $4 = $3;
    __ZN14AutoJSXDRStateC1EP10JSXDRState($w, $4);
    var $w_idx6_val = HEAP32[$w >> 2];
    var $5 = __ZNK14AutoJSXDRStatecvP10JSXDRStateEv($w_idx6_val);
    if (($5 | 0) == 0) {
      var $_3 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN28DisablePrincipalsTranscodingC1EP9JSContext($disable, $cx_idx_val);
    var $8 = $5;
    __ZN2js14XDRScriptStateC2EP10JSXDRState($wstate, $8);
    var $9 = __Z12js_XDRScriptP10JSXDRStatePP8JSScript($5, $1);
    if (($9 | 0) == 0) {
      var $_2 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = _JS_XDRMemGetData($8, $nbytes);
    if (($12 | 0) == 0) {
      var $_2 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = _JS_XDRNewMem($2, 1);
    var $16 = $15;
    __ZN14AutoJSXDRStateC1EP10JSXDRState($r, $16);
    var $r_idx2_val = HEAP32[$r >> 2];
    var $17 = __ZNK14AutoJSXDRStatecvP10JSXDRStateEv($r_idx2_val);
    if (($17 | 0) == 0) {
      var $_1 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = HEAP32[$nbytes >> 2];
    var $21 = $17;
    _JS_XDRMemSetData($21, $12, $20);
    _JS_XDRMemSetData($8, 0, 0);
    var $22 = $rstate;
    __ZN2js14XDRScriptStateC2EP10JSXDRState($22, $21);
    var $25 = HEAP32[HEAP32[$1 >> 2] + 52 >> 2];
    HEAP32[$rstate + 4 >> 2] = $25;
    HEAP8[$rstate + 8 | 0] = 1;
    var $28 = __Z12js_XDRScriptP10JSXDRStatePP8JSScript($17, $1);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $31 = HEAP32[$1 >> 2];
    var $32 = $31;
    var $33 = __ZNK2js2gc4Cell11compartmentEv($32);
    var $35 = HEAP32[$33 + 4 >> 2];
    var $36 = $35;
    var $37 = $31 + 76 | 0;
    HEAP32[$37 >> 2] = $36;
    if (($35 | 0) == 0) {
      var $_0 = $31;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $40 = $35 + 12 | 0;
    var $42 = HEAP32[$40 >> 2] + 1 | 0;
    HEAP32[$40 >> 2] = $42;
    var $_0 = $31;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    __ZN2js14XDRScriptStateD2Ev($22);
    var $_1 = $_0;
    __label__ = 9;
    break;
   case 9:
    var $_1;
    __ZN14AutoJSXDRStateD1Ev($r_idx2_val);
    var $_2 = $_1;
    __label__ = 10;
    break;
   case 10:
    var $_2;
    __ZN2js14XDRScriptStateD2Ev($wstate);
    __ZN28DisablePrincipalsTranscodingD1Ev($disable);
    var $_3 = $_2;
    __label__ = 11;
    break;
   case 11:
    var $_3;
    __ZN14AutoJSXDRStateD1Ev($w_idx6_val);
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z14js_CloneScriptP9JSContextP8JSScript["X"] = 1;

function __ZN14AutoJSXDRStateC1EP10JSXDRState($this, $x) {
  __ZN14AutoJSXDRStateC2EP10JSXDRState($this, $x);
  return;
}

function __ZN28DisablePrincipalsTranscodingC1EP9JSContext($this, $cx_0_11_val) {
  __ZN28DisablePrincipalsTranscodingC2EP9JSContext($this, $cx_0_11_val);
  return;
}

function __ZN14AutoJSXDRStateD1Ev($this_0_0_val) {
  __ZN14AutoJSXDRStateD2Ev($this_0_0_val);
  return;
}

function __ZN28DisablePrincipalsTranscodingD1Ev($this) {
  __ZN28DisablePrincipalsTranscodingD2Ev($this);
  return;
}

function __ZN8JSScript14tryNewStepModeEP9JSContextj($this, $cx, $newValue) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 24 | 0;
    var $2 = HEAP32[$1 >> 2];
    HEAP32[$1 >> 2] = $newValue;
    var $5 = ($newValue | 0) != 0;
    if ((($2 | 0) == 0 & 1 | 0) == ($5 & 1 ^ 1 | 0) | $5 ^ 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $frames_01 = HEAP32[HEAP32[$cx + 52 >> 2] + 209936 >> 2];
    if (($frames_01 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $frames_02 = $frames_01;
      __label__ = 3;
      break;
    }
   case 3:
    var $frames_02;
    __ZN2js17InterpreterFrames25enableInterruptsIfRunningEP8JSScript($frames_02, $this);
    var $frames_0 = HEAP32[$frames_02 >> 2];
    if (($frames_0 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $frames_02 = $frames_0;
      __label__ = 3;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17InterpreterFrames25enableInterruptsIfRunningEP8JSScript($this, $script) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[HEAP32[$this + 8 >> 2] + 12 >> 2];
    var $4 = __ZNK2js9FrameRegs2fpEv($_idx_val);
    var $5 = __ZNK2js10StackFrame6scriptEv($4);
    if (($5 | 0) == ($script | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = HEAP32[$this + 12 >> 2];
    var $13 = HEAP32[HEAP32[$10 >> 2] >> 2];
    FUNCTION_TABLE[$13]($10);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSScript19changeStepModeCountEP9JSContexti($this, $cx, $delta) {
  var $2 = HEAP32[$this + 24 >> 2];
  var $6 = $2 + $delta & 2147483647 | $2 & -2147483648;
  __ZN8JSScript14tryNewStepModeEP9JSContextj($this, $cx, $6);
  return;
}

function __ZNK2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE12lookupForAddERKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12lookupForAddERKS3_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S1_EENS5_13MapHashPolicyES4_E6AddPtrERKS1_SF_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrEPPS4_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $7 = HEAP32[$v >> 2];
    var $8 = $5 + 4 | 0;
    HEAP32[$8 >> 2] = $7;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrEPPS4_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 8 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 16 >> 2];
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIPhS2_EEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr7nonNullEv($this) {
  return;
}

function __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefIPNS_19ScriptFilenameEntryEEcvRS2_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZN2js13PointerHasherIPhLj0EE5matchERKS1_S4_($k_val, $l_val) {
  return ($k_val | 0) == ($l_val | 0);
}

function __ZN2js13PointerHasherIPhLj0EE4hashERKS1_($l_val) {
  return $l_val;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11initializedEv($this_0_5_val) {
  return ($this_0_5_val | 0) != 0;
}

function __ZN2jsL16GetClassProtoKeyEPNS_5ClassE3741() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[__ZN2js11ScriptClassE + 4 >> 2];
    var $2 = $1 >>> 24;
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $1 >>> 17 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE12hasCollisionEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIPhS2_EEEC2ERS3_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js12HashMapEntryIPhS1_EC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S1_EE($e) {
  return $e | 0;
}

function __ZN2js2gcL15GetGCObjectKindEjb3731($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE10setRemovedEv($this) {
  HEAP32[$this >> 2] = 1;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE7setFreeEv($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefIPNS_19ScriptFilenameEntryEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j($10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 5;
    break;
   case 5:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $22 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE6isLiveEv($src_01_idx_val);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE10getKeyHashEv($src_01_idx1_val);
    var $25 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEENS_7MoveRefIT_EERS8_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEEaSENS_7MoveRefIS5_EE($25, $_02_val);
    __label__ = 7;
    break;
   case 7:
    var $27 = $src_01 + 12 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 5;
      break;
    }
   case 8:
    var $29 = $3;
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($29);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j($capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej($1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEEaSENS_7MoveRefIS5_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = $2 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIPhS2_EEEENS_7MoveRefIT_EERS5_($1, $7);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js12HashMapEntryIPhS1_EaSENS_7MoveRefIS2_EE($6, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIPhS1_EaSENS_7MoveRefIS2_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIPhS2_EEEptEv($rhs_0);
  var $4 = $3 | 0;
  __ZN2js4MoveIPhEENS_7MoveRefIT_EERKS3_($1, $4);
  var $_idx2_val = HEAP32[$1 >> 2];
  var $5 = __ZNK2js7MoveRefIPhEcvRS1_Ev($_idx2_val);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = $3 + 4 | 0;
  __ZN2js4MoveIPhEENS_7MoveRefIT_EERS3_($2, $8);
  var $_idx_val = HEAP32[$2 >> 2];
  var $9 = __ZNK2js7MoveRefIPhEcvRS1_Ev($_idx_val);
  var $10 = HEAP32[$9 >> 2];
  HEAP32[$this + 4 >> 2] = $10;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIPhS2_EEEENS_7MoveRefIT_EERS5_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIPhS2_EEEC1ERS3_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIPhS2_EEEC1ERS3_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIPhS2_EEEC2ERS3_($this, $t);
  return;
}

function __ZN2js4MoveIPhEENS_7MoveRefIT_EERS3_($agg_result, $t) {
  __ZN2js7MoveRefIPhEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPhS1_EC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIPhS1_EC1Ev($this) {
  __ZN2js12HashMapEntryIPhS1_EC2Ev($this);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12lookupForAddERKS3_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKS3_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS3_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKS3_($l_val1) {
  var $1 = __ZN2js13PointerHasherIPhLj0EE4hashERKS1_($l_val1);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS3_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $l_val4 = HEAP32[$l >> 2];
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS4_EERKS3_($6, $l_val4);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $l_val = HEAP32[$l >> 2];
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS4_EERKS3_($27, $l_val);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS3_jj["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS4_EERKS3_($e, $l_val1) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S1_EE($1);
  var $_val = HEAP32[$2 >> 2];
  var $3 = __ZN2js13PointerHasherIPhLj0EE5matchERKS1_S4_($_val, $l_val1);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $length * 171 | 0;
    var $capacity_0 = $3 >>> 0 < 2048 ? 16 : $3 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 4;
      break;
    }
   case 3:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $7 = $roundUp_01 << 1;
    var $8 = $roundUpLog2_02 + 1 | 0;
    if ($7 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $7;
      var $roundUpLog2_02 = $8;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = $7;
      var $roundUpLog2_0_lcssa = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j($roundUp_0_lcssa);
    HEAP32[$this + 20 >> 2] = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS3_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKS3_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS3_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6finishEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 20 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($5);
    HEAP32[$1 >> 2] = 0;
    var $6 = $this + 12 | 0;
    var $8 = HEAP32[$6 >> 2] + 1 | 0;
    HEAP32[$6 >> 2] = $8;
    HEAP32[$this + 8 >> 2] = 0;
    HEAP32[$this + 16 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3732($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = 0;
    var $2 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_3733($cx, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 2:
    var $4 = HEAP32[$1 >> 2];
    var $5 = ($4 | 0) == 0;
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = __ZN2js5types15emptyTypeObjectE;
    var $_pre_phi = $cx;
    __label__ = 5;
    break;
   case 4:
    var $7 = $4;
    var $8 = $cx;
    var $9 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($7, $8, 0, 0);
    var $10 = $9;
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      var $12 = $10;
      var $_pre_phi = $8;
      __label__ = 5;
      break;
    }
   case 5:
    var $_pre_phi;
    var $12;
    var $13 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($_pre_phi, $kind);
    var $14 = $13;
    if (($13 | 0) == 0) {
      var $_0 = $14;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ($5) {
      var $21 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx_val = HEAP32[$4 + 20 >> 2];
    var $19 = __ZNK8JSObject9getParentEv($_idx_val);
    var $21 = $19;
    __label__ = 8;
    break;
   case 8:
    var $21;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($13, __ZN2js11ScriptClassE, $12, $21, 0, (__ZN2js11ScriptClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $_idx1_val = HEAP32[__ZN2js11ScriptClassE + 4 >> 2];
    var $23 = __ZNK2js5Class8isNativeEv($_idx1_val);
    if ($23) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $25 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE3736($cx, $14, $12, $kind);
    if ($25) {
      var $_0 = $14;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 0;
    __label__ = 12;
    break;
   case 11:
    __ZN8JSObject21setSharedNonNativeMapEv($13);
    var $_0 = $14;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_3733($cx, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL16GetClassProtoKeyEPNS_5ClassE3741();
    var $2 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($cx, 0, $1, $proto, __ZN2js11ScriptClassE);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$proto >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($cx, 0, 1, $proto, 0);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE3736($cx, $obj, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAPU32[__ZN2js11ScriptClassE + 4 >> 2] >>> 8 & 255;
    var $4 = $obj;
    var $_idx_val = HEAP32[$obj + 28 >> 2];
    var $6 = __ZNK8JSObject8numSlotsEv($_idx_val);
    if ($3 >>> 0 > $6 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = __ZN8JSObject10allocSlotsEP9JSContextj($obj, $cx, $3);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $11 = $type;
    var $12 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($11, __ZN2js11ScriptClassE);
    var $13 = $cx;
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($11, $13, __ZN2js11ScriptClassE, $kind);
    var $empty_0_in = $15;
    __label__ = 6;
    break;
   case 5:
    var $17 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($13, __ZN2js11ScriptClassE);
    var $empty_0_in = $17;
    __label__ = 6;
    break;
   case 6:
    var $empty_0_in;
    if (($empty_0_in | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $empty_0_in | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6removeERNS0_14HashTableEntryIS4_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e_idx_val = HEAP32[$e >> 2];
    var $1 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE12hasCollisionEv($e_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11createTableERS7_j($10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = $13;
    var $17 = $this;
    __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16setTableSizeLog2Ej($17, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $19 = $this + 12 | 0;
    var $21 = HEAP32[$19 >> 2] + 1 | 0;
    HEAP32[$19 >> 2] = $21;
    HEAP32[$2 >> 2] = $16;
    var $22 = $3 + ($5 << 3) | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 5;
    break;
   case 5:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isLiveEv($src_01_idx_val);
    if ($24) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $26 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE10getKeyHashEv($src_01_idx1_val);
    var $27 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E13findFreeEntryEj($this, $26);
    __ZN2js4MoveINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEENS_7MoveRefIT_EERS8_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEaSENS_7MoveRefIS5_EE($27, $_02_val);
    __label__ = 7;
    break;
   case 7:
    var $29 = $src_01 + 8 | 0;
    if (($29 | 0) == ($22 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $29;
      __label__ = 5;
      break;
    }
   case 8:
    var $31 = $3;
    __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12destroyTableERS7_PNS0_14HashTableEntryIS4_EEj($31);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E15changeTableSizeEi["X"] = 1;

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 3) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + ($15 << 3) | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEaSENS_7MoveRefIS5_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $2 + 4 | 0;
  __ZN2js4MoveIPNS_19ScriptFilenameEntryEEENS_7MoveRefIT_EERS4_($1, $6);
  var $_idx_val = HEAP32[$1 >> 2];
  var $7 = __ZNK2js7MoveRefIPNS_19ScriptFilenameEntryEEcvRS2_Ev($_idx_val);
  var $8 = HEAP32[$7 >> 2];
  HEAP32[$this + 4 >> 2] = $8;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js4MoveIPNS_19ScriptFilenameEntryEEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefIPNS_19ScriptFilenameEntryEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIPNS_19ScriptFilenameEntryEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIPNS_19ScriptFilenameEntryEEC2ERS2_($this, $t);
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumC2IS8_EERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZNK2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE3allEv($1, $map);
  var $2 = $1;
  var $3 = $this;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  HEAP32[$this + 8 >> 2] = $map | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE3allEv($agg_result, $this) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $_idx1_val = HEAP32[$this + 20 >> 2];
  __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3allEv($agg_result, $_idx_val, $_idx1_val);
  return;
}

function __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3allEv($agg_result, $this_0_1_val, $this_0_5_val) {
  var $1 = $this_0_5_val + ($this_0_1_val << 3) | 0;
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5RangeC1EPNS0_14HashTableEntryIS4_EESE_($agg_result, $this_0_5_val, $1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5RangeC1EPNS0_14HashTableEntryIS4_EESE_($this, $c, $e) {
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5RangeC2EPNS0_14HashTableEntryIS4_EESE_($this, $c, $e);
  return;
}

function __ZNK2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js11TokenStream16versionWithFlagsEv($this_0_16_val) {
  return $this_0_16_val;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_($t) {
  return $t;
}

function __ZL14JSID_FROM_BITSj3746($bits) {
  return $bits;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5emptyEv($this_0_3_val) {
  return ($this_0_3_val | 0) == 0;
}

function __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10overloadedEv($this_0_1_val, $this_0_2_val, $this_0_4_val) {
  return ($this_0_4_val + $this_0_2_val | 0) >>> 0 >= ($this_0_1_val * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function _JSID_TO_STRING3744($iden) {
  return $iden;
}

function _JSID_IS_STRING3745($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function __ZN2js10VectorImplIP6JSAtomLj0ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN28DisablePrincipalsTranscodingD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$this + 4 >> 2];
    var $7 = $2 + 4 | 0;
    HEAP32[$7 >> 2] = $6;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN14AutoJSXDRStateC2EP10JSXDRState($this, $x) {
  HEAP32[$this >> 2] = $x;
  return;
}

function __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrdeEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE12setCollisionEj($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkC2EP11JSArenaPool($this, $pool) {
  HEAP32[$this >> 2] = $pool;
  var $7 = HEAP32[HEAP32[$pool + 16 >> 2] + 12 >> 2];
  HEAP32[$this + 4 >> 2] = $7;
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5RangeC2EPNS0_14HashTableEntryIS4_EESE_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$4 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isLiveEv($_idx_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 8 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 8 | 0;
    var $4 = HEAPU32[$3 >> 2];
    if ((HEAP32[$this + 12 >> 2] - $4 | 0) >>> 0 < $incr >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $10 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = HEAP32[$3 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $10;
    HEAP32[$3 >> 2] = $10 + $incr | 0;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $8 = $4;
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $8 = $6;
    __label__ = 4;
    break;
   case 4:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 2;
    var $7 = $this;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($7, $6);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $this + 4 | 0;
    var $_idx_val = HEAP32[$12 >> 2];
    var $13 = __ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($_idx_val);
    var $_idx2_val = HEAP32[$1 >> 2];
    var $14 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE10endNoCheckEv($_idx_val, $_idx2_val);
    __ZN2js10VectorImplIP6JSAtomLj0ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $13, $14);
    HEAP32[$12 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIP6JSAtomLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP6JSAtomLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v + 4 | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = $v;
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($5, $4, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $v + 12 | 0;
    var $10 = $6;
    HEAP32[$2 >> 2] = $10;
    HEAP32[$9 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP6JSAtomLj0ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIP6JSAtomLj0ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend);
  return;
}

function __ZN14AutoJSXDRStateD2Ev($this_0_0_val) {
  var $1 = $this_0_0_val;
  _JS_XDRDestroy($1);
  return;
}

function __ZN28DisablePrincipalsTranscodingC2EP9JSContext($this, $cx_0_11_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_idx_val = HEAP32[$cx_0_11_val + 144244 >> 2];
    var $3 = _JS_GetRuntimeSecurityCallbacks($_idx_val);
    var $4 = $3;
    HEAP32[$1 >> 2] = $4;
    var $5 = $this + 4 | 0;
    HEAP32[$5 >> 2] = 0;
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $3 + 4 | 0;
    var $10 = HEAP32[$8 >> 2];
    HEAP32[$5 >> 2] = $10;
    HEAP32[$8 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js9InlineMapIP6JSAtomjLj24EE5emptyEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK2js9InlineMapIP6JSAtomjLj24EE8usingMapEv($_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this + 200 | 0;
    var $4 = __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5emptyEv($3);
    var $10 = $4;
    __label__ = 4;
    break;
   case 3:
    var $10 = (HEAP32[$this + 4 >> 2] | 0) == 0;
    __label__ = 4;
    break;
   case 4:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5emptyEv($this) {
  var $_idx_val = HEAP32[$this + 12 >> 2];
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5emptyEv($_idx_val);
  return $1;
}

function __ZNK2js6Parser16versionWithFlagsEv($this) {
  var $_idx_val = HEAP32[$this + 944 >> 2];
  var $1 = __ZNK2js11TokenStream16versionWithFlagsEv($_idx_val);
  return $1;
}

function __Z10NewGCThingI8JSScriptEPT_P9JSContextN2js2gc9AllocKindEj($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAP32[$cx + 56 >> 2] + 8 | 0;
    var $5 = __ZN2js2gc10ArenaLists20allocateFromFreeListENS0_9AllocKindEj($4, 13, 104);
    if (($5 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $11 = $5;
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $cx;
    var $9 = __ZN2js2gc10ArenaLists14refillFreeListEP9JSContextNS0_9AllocKindE($8, 13);
    var $11 = $9;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE12lookupForAddERKPKc($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12lookupForAddERKPKc($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrcvMSB_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 226,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS5_6SetOpsES4_E6AddPtrERS8_($this, $p, $t) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrERS4_($1, $p, $t);
  return $2;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrERS4_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$t >> 2];
    var $6 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$6 >> 2] = $3;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 8 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 16 >> 2];
    var $12 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12lookupForAddERKPKc($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11prepareHashERKPKc($l_val);
  var $2 = __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6lookupERKPKcjj($this, $l, $1);
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11prepareHashERKPKc($l_val) {
  var $1 = __ZN2js20ScriptFilenameHasher4hashEPKc($l_val);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6lookupERKPKcjj($this, $l, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 3) | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $l_val4 = HEAP32[$l >> 2];
    var $11 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5matchERNS0_14HashTableEntryIS4_EERKPKc($6, $l_val4);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE12setCollisionEj($entry_0);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + ($26 << 3) | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $l_val = HEAP32[$l >> 2];
    var $35 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5matchERNS0_14HashTableEntryIS4_EERKPKc($27, $l_val);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6lookupERKPKcjj["X"] = 1;

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrC2ERNS0_14HashTableEntryIS4_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5matchERNS0_14HashTableEntryIS4_EERKPKc($e, $l_val) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_($1);
  var $3 = HEAP32[$2 >> 2];
  var $4 = __ZN2js20ScriptFilenameHasher5matchEPKNS_19ScriptFilenameEntryEPKc($3, $l_val);
  return $4;
}

function __ZN2js20ScriptFilenameHasher5matchEPKNS_19ScriptFilenameEntryEPKc($e, $l) {
  var $1 = $e + 1 | 0;
  var $2 = _strcmp($1, $l);
  return ($2 | 0) == 0;
}

function __ZN2js20ScriptFilenameHasher4hashEPKc($l) {
  var $1 = _JS_HashString($l);
  return $1;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE10isLiveHashEj($hash);
  return $1;
}

function __ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkD2Ev($this_0_0_val, $this_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this_0_0_val + 16 >> 2];
    if (($2 | 0) == ($this_0_0_val | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $this_0_1_val;
    var $8 = HEAP32[$2 + 4 >> 2];
    var $10 = $2 + 12 | 0;
    if (($6 - $8 | 0) >>> 0 > (HEAP32[$10 >> 2] - $8 | 0) >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = HEAP32[$this_0_0_val + 24 >> 2];
    var $19 = $16 + $6 & ($16 ^ -1);
    HEAP32[$10 >> 2] = $19;
    __label__ = 5;
    break;
   case 4:
    _JS_ArenaRelease($this_0_0_val, $this_0_1_val);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10EmptyShape17getEmptyCallShapeEP9JSContext($cx) {
  var $4 = $cx;
  var $5 = HEAP32[$cx + 56 >> 2] + 756 | 0;
  var $6 = __ZN2js10EmptyShape6ensureEP9JSContextPNS_5ClassEPPS0_($4, __ZN2js9CallClassE, $5);
  return $6;
}

function __ZL10str_escapeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($cx, $argc, $vp, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$1 >> 2];
    var $4 = __ZNK8JSString6lengthEv($_idx_val);
    var $_idx1_val = HEAP32[$1 + 4 >> 2];
    var $5 = __ZNK14JSLinearString5charsEv($_idx1_val);
    var $i_0 = 0;
    var $newlength_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $newlength_0;
    var $i_0;
    if ($i_0 >>> 0 < $4 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    var $10 = HEAPU16[$5 + ($i_0 << 1) >> 1];
    if (($10 & 65535) < 128) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $14 = STRING_TABLE.__ZZL10str_escapeP9JSContextjPN2JS5ValueEE17shouldPassThrough + ($10 & 65535) | 0;
    if (HEAP8[$14] << 24 >> 24 == 0) {
      __label__ = 6;
      break;
    } else {
      var $newlength_1 = $newlength_0;
      __label__ = 8;
      break;
    }
   case 6:
    var $19 = ($10 & 65535) < 256 ? 2 : 5;
    var $20 = $19 + $newlength_0 | 0;
    if ($20 >>> 0 < $4 >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $newlength_1 = $20;
      __label__ = 8;
      break;
    }
   case 7:
    var $23 = $cx;
    __Z27js_ReportAllocationOverflowP9JSContext($23);
    var $_0 = 0;
    __label__ = 24;
    break;
   case 8:
    var $newlength_1;
    var $i_0 = $i_0 + 1 | 0;
    var $newlength_0 = $newlength_1;
    __label__ = 3;
    break;
   case 9:
    if ($newlength_0 >>> 0 > 2147483646) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $29 = $cx;
    __Z27js_ReportAllocationOverflowP9JSContext($29);
    var $_0 = 0;
    __label__ = 24;
    break;
   case 11:
    var $33 = $cx;
    var $34 = __ZN9JSContext7malloc_Ej($33, ($newlength_0 << 1) + 2 | 0);
    var $35 = $34;
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (($4 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      var $i1_01 = 0;
      var $ni_02 = 0;
      __label__ = 13;
      break;
    }
   case 13:
    var $ni_02;
    var $i1_01;
    var $39 = HEAPU16[$5 + ($i1_01 << 1) >> 1];
    var $40 = $39 & 65535;
    if (($39 & 65535) < 128) {
      __label__ = 14;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 14:
    var $43 = STRING_TABLE.__ZZL10str_escapeP9JSContextjPN2JS5ValueEE17shouldPassThrough + $40 | 0;
    var $46 = $ni_02 + 1 | 0;
    var $47 = $35 + ($ni_02 << 1) | 0;
    if (HEAP8[$43] << 24 >> 24 == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    HEAP16[$47 >> 1] = 37;
    var $54 = $46;
    __label__ = 18;
    break;
   case 16:
    HEAP16[$47 >> 1] = $39;
    var $ni_1 = $46;
    __label__ = 20;
    break;
   case 17:
    var $50 = ($39 & 65535) < 256;
    var $51 = $ni_02 + 1 | 0;
    HEAP16[$35 + ($ni_02 << 1) >> 1] = 37;
    if ($50) {
      var $54 = $51;
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $54;
    var $56 = STRING_TABLE.__ZZL10str_escapeP9JSContextjPN2JS5ValueEE6digits + ($40 >>> 4) | 0;
    HEAP16[$35 + ($54 << 1) >> 1] = HEAP8[$56] << 24 >> 24;
    var $62 = STRING_TABLE.__ZZL10str_escapeP9JSContextjPN2JS5ValueEE6digits + ($40 & 15) | 0;
    HEAP16[$35 + ($ni_02 + 2 << 1) >> 1] = HEAP8[$62] << 24 >> 24;
    var $ni_1 = $ni_02 + 3 | 0;
    __label__ = 20;
    break;
   case 19:
    HEAP16[$35 + ($51 << 1) >> 1] = 117;
    var $71 = STRING_TABLE.__ZZL10str_escapeP9JSContextjPN2JS5ValueEE6digits + ($40 >>> 12) | 0;
    HEAP16[$35 + ($ni_02 + 2 << 1) >> 1] = HEAP8[$71] << 24 >> 24;
    var $78 = STRING_TABLE.__ZZL10str_escapeP9JSContextjPN2JS5ValueEE6digits + ($40 >>> 8 & 15) | 0;
    HEAP16[$35 + ($ni_02 + 3 << 1) >> 1] = HEAP8[$78] << 24 >> 24;
    var $85 = STRING_TABLE.__ZZL10str_escapeP9JSContextjPN2JS5ValueEE6digits + ($40 >>> 4 & 15) | 0;
    HEAP16[$35 + ($ni_02 + 4 << 1) >> 1] = HEAP8[$85] << 24 >> 24;
    var $91 = STRING_TABLE.__ZZL10str_escapeP9JSContextjPN2JS5ValueEE6digits + ($40 & 15) | 0;
    HEAP16[$35 + ($ni_02 + 5 << 1) >> 1] = HEAP8[$91] << 24 >> 24;
    var $ni_1 = $ni_02 + 6 | 0;
    __label__ = 20;
    break;
   case 20:
    var $ni_1;
    var $97 = $i1_01 + 1 | 0;
    if (($97 | 0) == ($4 | 0)) {
      __label__ = 21;
      break;
    } else {
      var $i1_01 = $97;
      var $ni_02 = $ni_1;
      __label__ = 13;
      break;
    }
   case 21:
    HEAP16[$35 + ($newlength_0 << 1) >> 1] = 0;
    var $99 = __Z12js_NewStringP9JSContextPtj($cx, $35, $newlength_0);
    if (($99 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    __ZN9JSContext5free_EPv($34);
    var $_0 = 0;
    __label__ = 24;
    break;
   case 23:
    var $103 = $99 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $103);
    var $_0 = 1;
    __label__ = 24;
    break;
   case 24:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10str_escapeP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL12str_unescapeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($cx, $argc, $vp, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$1 >> 2];
    var $4 = __ZNK8JSString6lengthEv($_idx_val);
    var $_idx1_val = HEAP32[$1 + 4 >> 2];
    var $5 = __ZNK14JSLinearString5charsEv($_idx1_val);
    var $7 = ($4 << 1) + 2 | 0;
    var $8 = $cx;
    var $9 = __ZN9JSContext7malloc_Ej($8, $7);
    var $10 = $9;
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($4 | 0) == 0) {
      var $ni_0_lcssa = 0;
      __label__ = 35;
      break;
    } else {
      var $ni_01 = 0;
      var $i_02 = 0;
      __label__ = 4;
      break;
    }
   case 4:
    var $i_02;
    var $ni_01;
    var $13 = $i_02 + 1 | 0;
    var $15 = HEAPU16[$5 + ($i_02 << 1) >> 1];
    if ($15 << 16 >> 16 == 37) {
      __label__ = 5;
      break;
    } else {
      var $ch_0 = $15;
      var $i_1 = $13;
      __label__ = 34;
      break;
    }
   case 5:
    var $18 = $i_02 + 2 | 0;
    if ($18 >>> 0 < $4 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 6:
    var $21 = $5 + ($13 << 1) | 0;
    var $22 = HEAPU16[$21 >> 1];
    if (($22 & 65535) < 128) {
      __label__ = 7;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 7:
    var $25 = $22 & 65535;
    var $26 = _isxdigit($25);
    if (($26 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $29 = $5 + ($18 << 1) | 0;
    var $30 = HEAPU16[$29 >> 1];
    if (($30 & 65535) < 128) {
      __label__ = 9;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 9:
    var $33 = $30 & 65535;
    var $34 = _isxdigit($33);
    if (($34 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = HEAPU16[$21 >> 1] & 65535;
    var $39 = $38 - 48 | 0;
    if ($39 >>> 0 < 10) {
      var $45 = $39;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $42 = _tolower($38);
    var $45 = $42 - 87 | 0;
    __label__ = 12;
    break;
   case 12:
    var $45;
    var $46 = $45 << 4;
    var $48 = HEAPU16[$29 >> 1] & 65535;
    var $49 = $48 - 48 | 0;
    if ($49 >>> 0 < 10) {
      var $55 = $49;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $52 = _tolower($48);
    var $55 = $52 - 87 | 0;
    __label__ = 14;
    break;
   case 14:
    var $55;
    var $ch_0 = $55 + $46 & 65535;
    var $i_1 = $i_02 + 3 | 0;
    __label__ = 34;
    break;
   case 15:
    var $60 = $i_02 + 5 | 0;
    if ($60 >>> 0 < $4 >>> 0) {
      __label__ = 16;
      break;
    } else {
      var $ch_0 = $15;
      var $i_1 = $13;
      __label__ = 34;
      break;
    }
   case 16:
    if (HEAP16[$5 + ($13 << 1) >> 1] << 16 >> 16 == 117) {
      __label__ = 17;
      break;
    } else {
      var $ch_0 = $15;
      var $i_1 = $13;
      __label__ = 34;
      break;
    }
   case 17:
    var $67 = $5 + ($18 << 1) | 0;
    var $68 = HEAPU16[$67 >> 1];
    if (($68 & 65535) < 128) {
      __label__ = 18;
      break;
    } else {
      var $ch_0 = $15;
      var $i_1 = $13;
      __label__ = 34;
      break;
    }
   case 18:
    var $71 = $68 & 65535;
    var $72 = _isxdigit($71);
    if (($72 | 0) == 0) {
      var $ch_0 = $15;
      var $i_1 = $13;
      __label__ = 34;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $76 = $5 + ($i_02 + 3 << 1) | 0;
    var $77 = HEAPU16[$76 >> 1];
    if (($77 & 65535) < 128) {
      __label__ = 20;
      break;
    } else {
      var $ch_0 = $15;
      var $i_1 = $13;
      __label__ = 34;
      break;
    }
   case 20:
    var $80 = $77 & 65535;
    var $81 = _isxdigit($80);
    if (($81 | 0) == 0) {
      var $ch_0 = $15;
      var $i_1 = $13;
      __label__ = 34;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $85 = $5 + ($i_02 + 4 << 1) | 0;
    var $86 = HEAPU16[$85 >> 1];
    if (($86 & 65535) < 128) {
      __label__ = 22;
      break;
    } else {
      var $ch_0 = $15;
      var $i_1 = $13;
      __label__ = 34;
      break;
    }
   case 22:
    var $89 = $86 & 65535;
    var $90 = _isxdigit($89);
    if (($90 | 0) == 0) {
      var $ch_0 = $15;
      var $i_1 = $13;
      __label__ = 34;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $93 = $5 + ($60 << 1) | 0;
    var $94 = HEAPU16[$93 >> 1];
    if (($94 & 65535) < 128) {
      __label__ = 24;
      break;
    } else {
      var $ch_0 = $15;
      var $i_1 = $13;
      __label__ = 34;
      break;
    }
   case 24:
    var $97 = $94 & 65535;
    var $98 = _isxdigit($97);
    if (($98 | 0) == 0) {
      var $ch_0 = $15;
      var $i_1 = $13;
      __label__ = 34;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $102 = HEAPU16[$67 >> 1] & 65535;
    var $103 = $102 - 48 | 0;
    if ($103 >>> 0 < 10) {
      var $109 = $103;
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $106 = _tolower($102);
    var $109 = $106 - 87 | 0;
    __label__ = 27;
    break;
   case 27:
    var $109;
    var $110 = $109 << 4;
    var $112 = HEAPU16[$76 >> 1] & 65535;
    var $113 = $112 - 48 | 0;
    if ($113 >>> 0 < 10) {
      var $119 = $113;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $116 = _tolower($112);
    var $119 = $116 - 87 | 0;
    __label__ = 29;
    break;
   case 29:
    var $119;
    var $121 = $119 + $110 << 4;
    var $123 = HEAPU16[$85 >> 1] & 65535;
    var $124 = $123 - 48 | 0;
    if ($124 >>> 0 < 10) {
      var $130 = $124;
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $127 = _tolower($123);
    var $130 = $127 - 87 | 0;
    __label__ = 31;
    break;
   case 31:
    var $130;
    var $132 = $130 + $121 << 4;
    var $134 = HEAPU16[$93 >> 1] & 65535;
    var $135 = $134 - 48 | 0;
    if ($135 >>> 0 < 10) {
      var $141 = $135;
      __label__ = 33;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $138 = _tolower($134);
    var $141 = $138 - 87 | 0;
    __label__ = 33;
    break;
   case 33:
    var $141;
    var $ch_0 = $141 + $132 & 65535;
    var $i_1 = $i_02 + 6 | 0;
    __label__ = 34;
    break;
   case 34:
    var $i_1;
    var $ch_0;
    var $146 = $ni_01 + 1 | 0;
    HEAP16[$10 + ($ni_01 << 1) >> 1] = $ch_0;
    if ($i_1 >>> 0 < $4 >>> 0) {
      var $ni_01 = $146;
      var $i_02 = $i_1;
      __label__ = 4;
      break;
    } else {
      var $ni_0_lcssa = $146;
      __label__ = 35;
      break;
    }
   case 35:
    var $ni_0_lcssa;
    HEAP16[$10 + ($ni_0_lcssa << 1) >> 1] = 0;
    var $150 = __Z12js_NewStringP9JSContextPtj($cx, $10, $ni_0_lcssa);
    if (($150 | 0) == 0) {
      __label__ = 36;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 36:
    __ZN9JSContext5free_EPv($9);
    var $_0 = 0;
    __label__ = 38;
    break;
   case 37:
    var $154 = $150 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $154);
    var $_0 = 1;
    __label__ = 38;
    break;
   case 38:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12str_unescapeP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL10str_unevalP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $vp + 16 | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = $1 | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv3828($1);
    __label__ = 4;
    break;
   case 4:
    var $9 = __Z16js_ValueToSourceP9JSContextRKN2JS5ValueE($cx, $1);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JS5Value9setStringEP8JSString($vp, $9);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13str_decodeURIP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($cx, $argc, $vp, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1 | 0;
    var $5 = __ZL6DecodeP9JSContextP8JSStringPKtPN2JS5ValueE($cx, $4, __ZL29js_uriReservedPlusPound_ucstr | 0, $vp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13str_encodeURIP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($cx, $argc, $vp, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1 | 0;
    var $5 = __ZL6EncodeP9JSContextP8JSStringPKtS4_PN2JS5ValueE($cx, $4, __ZL29js_uriReservedPlusPound_ucstr | 0, __ZL21js_uriUnescaped_ucstr | 0, $vp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23str_decodeURI_ComponentP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($cx, $argc, $vp, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1 | 0;
    var $5 = __ZL6DecodeP9JSContextP8JSStringPKtPN2JS5ValueE($cx, $4, _js_empty_ucstr | 0, $vp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23str_encodeURI_ComponentP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($cx, $argc, $vp, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1 | 0;
    var $5 = __ZL6EncodeP9JSContextP8JSStringPKtS4_PN2JS5ValueE($cx, $4, __ZL21js_uriUnescaped_ucstr | 0, 0, $vp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13str_enumerateP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $obj;
    var $3 = __ZNK8JSObject16getPrimitiveThisEv($2);
    var $_idx1 = $3 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $4 = __ZNK2JS5Value8toStringEv($_idx1_val$0, $_idx1_val$1);
    var $_idx_val = HEAP32[$4 >> 2];
    var $5 = __ZNK8JSString6lengthEv($_idx_val);
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if ($i_0 >>> 0 < $5 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 3:
    var $9 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $4, $i_0, 1);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $9 | 0;
    __ZN2JSL11StringValueEP8JSString3909($1, $12);
    var $13 = __ZN8JSObject13defineElementEP9JSContextjRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj, $cx, $i_0, $1, 10, 12, 7);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11str_resolveP9JSContextP8JSObjectijPS2_($cx, $obj, $id, $flags, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = _JSID_IS_INT3906($id);
    if (($2 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $obj;
    var $6 = __ZNK8JSObject16getPrimitiveThisEv($5);
    var $_idx1 = $6 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $7 = __ZNK2JS5Value8toStringEv($_idx1_val$0, $_idx1_val$1);
    var $8 = _JSID_TO_INT3948($id);
    var $_idx_val = HEAP32[$7 >> 2];
    var $9 = __ZNK8JSString6lengthEv($_idx_val);
    if ($8 >>> 0 < $9 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 3:
    var $14 = HEAP32[$cx + 52 >> 2] + 210584 | 0;
    var $15 = $cx;
    var $16 = __ZN2js13StaticStrings23getUnitStringForElementEP9JSContextP8JSStringj($14, $15, $7, $8);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = $16 | 0;
    __ZN2JSL11StringValueEP8JSString3909($1, $19);
    var $20 = __ZN8JSObject13defineElementEP9JSContextjRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj, $cx, $8, $1, 0, 0, 7);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z15js_str_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str = __stackBase__;
    var $1 = __ZN2js16GetPrimitiveThisIP8JSStringEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $str);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$str >> 2];
    __ZN2JS5Value9setStringEP8JSString($vp, $3);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16GetPrimitiveThisIP8JSStringEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx3 = $vp + 8 | 0;
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    var $1 = __ZN2js6detail17PrimitiveBehaviorIP8JSStringE6isTypeERKN2JS5ValueE($_idx3_val$0, $_idx3_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail17PrimitiveBehaviorIP8JSStringE7extractERKN2JS5ValueE($_idx3_val$0, $_idx3_val$1);
    HEAP32[$v >> 2] = $3;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 3:
    var $5 = __ZNK2JS5Value8isObjectEv($_idx3_val$0, $_idx3_val$1);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $7 = __ZNK2JS5Value8toObjectEv($_idx3_val$0, $_idx3_val$1);
    var $_idx2_val = HEAP32[$7 + 4 >> 2];
    var $8 = __ZNK8JSObject8getClassEv($_idx2_val);
    if (($8 | 0) == (__ZN2js11StringClassE | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = $7;
    var $12 = __ZNK8JSObject16getPrimitiveThisEv($11);
    var $_idx4 = $12 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    var $13 = __ZN2js6detail17PrimitiveBehaviorIP8JSStringE7extractERKN2JS5ValueE($_idx4_val$0, $_idx4_val$1);
    HEAP32[$v >> 2] = $13;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 6:
    var $15 = $cx;
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($15, $vp, __ZN2js11StringClassE);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z14js_toLowerCaseP9JSContextP8JSString($cx, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str_idx_val = HEAP32[$str >> 2];
    var $1 = __ZNK8JSString6lengthEv($str_idx_val);
    var $2 = $cx;
    var $3 = __ZN8JSString8getCharsEP9JSContext($str, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = ($1 << 1) + 2 | 0;
    var $8 = __ZN9JSContext7malloc_Ej($2, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($1 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 4;
      break;
    }
   case 4:
    var $i_01;
    var $13 = HEAP16[$3 + ($i_01 << 1) >> 1];
    var $14 = __ZN2js7unicode11ToLowerCaseEt($13);
    HEAP16[$9 + ($i_01 << 1) >> 1] = $14;
    var $16 = $i_01 + 1 | 0;
    if (($16 | 0) == ($1 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = $16;
      __label__ = 4;
      break;
    }
   case 5:
    HEAP16[$9 + ($1 << 1) >> 1] = 0;
    var $18 = __Z12js_NewStringP9JSContextPtj($cx, $9, $1);
    if (($18 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN9JSContext5free_EPv($8);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 7:
    var $_0 = $18 | 0;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z12js_NewStringP9JSContextPtj($cx, $chars, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL17CheckStringLengthEP9JSContextj3839($cx, $length);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN13JSFixedString4new_EP9JSContextPKtj($cx, $chars, $length);
    var $_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z14js_toUpperCaseP9JSContextP8JSString($cx, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str_idx_val = HEAP32[$str >> 2];
    var $1 = __ZNK8JSString6lengthEv($str_idx_val);
    var $2 = $cx;
    var $3 = __ZN8JSString8getCharsEP9JSContext($str, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = ($1 << 1) + 2 | 0;
    var $8 = __ZN9JSContext7malloc_Ej($2, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($1 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 4;
      break;
    }
   case 4:
    var $i_01;
    var $13 = HEAP16[$3 + ($i_01 << 1) >> 1];
    var $14 = __ZN2js7unicode11ToUpperCaseEt($13);
    HEAP16[$9 + ($i_01 << 1) >> 1] = $14;
    var $16 = $i_01 + 1 | 0;
    if (($16 | 0) == ($1 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = $16;
      __label__ = 4;
      break;
    }
   case 5:
    HEAP16[$9 + ($1 << 1) >> 1] = 0;
    var $18 = __Z12js_NewStringP9JSContextPtj($cx, $9, $1);
    if (($18 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN9JSContext5free_EPv($8);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 7:
    var $_0 = $18 | 0;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7unicode11ToUpperCaseEt($ch) {
  var $1 = __ZN2js7unicode8CharInfoEt($ch);
  var $8 = (HEAP8[$1 + 4 | 0] & 8) << 24 >> 24 == 0 ? $ch : 0;
  return $8 + HEAP16[$1 >> 1] & 65535;
}

function __Z13js_str_charAtP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $_idx4 = $vp + 8 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    var $1 = __ZNK2JS5Value8isStringEv($_idx4_val$0, $_idx4_val$1);
    var $2 = ($argc | 0) == 0;
    if ($2 | $1 ^ 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx5 = $vp + 16 | 0;
    var $_idx5_val$0 = HEAP32[$_idx5 >> 2];
    var $_idx5_val$1 = HEAP32[$_idx5 + 4 >> 2];
    var $4 = __ZNK2JS5Value7isInt32Ev($_idx5_val$0, $_idx5_val$1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZNK2JS5Value8toStringEv($_idx4_val$0, $_idx4_val$1);
    var $7 = __ZNK2JS5Value7toInt32Ev($_idx5_val$0, $_idx5_val$1);
    var $_idx2_val = HEAP32[$6 >> 2];
    var $8 = __ZNK8JSString6lengthEv($_idx2_val);
    if ($7 >>> 0 < $8 >>> 0) {
      var $i_0 = $7;
      var $str_0 = $6;
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 4:
    var $11 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    if ($2) {
      var $19 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $vp + 16 | 0;
    var $16 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd3824($cx, $15, $d);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 7:
    var $_pr = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    if ($_pr < 0) {
      __label__ = 12;
      break;
    } else {
      var $19 = $_pr;
      __label__ = 8;
      break;
    }
   case 8:
    var $19;
    var $_idx1_val = HEAP32[$11 >> 2];
    var $20 = __ZNK8JSString6lengthEv($_idx1_val);
    if ($20 >>> 0 > $19) {
      __label__ = 9;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 9:
    var $i_0 = $19 & -1;
    var $str_0 = $11;
    __label__ = 10;
    break;
   case 10:
    var $str_0;
    var $i_0;
    var $28 = HEAP32[$cx + 52 >> 2] + 210584 | 0;
    var $29 = $cx;
    var $30 = __ZN2js13StaticStrings23getUnitStringForElementEP9JSContextP8JSStringj($28, $29, $str_0, $i_0);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $33 = $30 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $33);
    var $_0 = 1;
    __label__ = 13;
    break;
   case 12:
    var $39 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $39);
    var $_0 = 1;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z13js_str_charAtP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx;
    __Z21js_ReportOverRecursedP9JSContext($6);
    var $_0 = 0;
    __label__ = 14;
    break;
   case 3:
    var $8 = $vp + 8 | 0;
    var $_idx4 = $8 | 0;
    var $_idx4_val$0 = HEAPU32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAPU32[$_idx4 + 4 >> 2];
    var $9 = __ZNK2JS5Value8isStringEv($_idx4_val$0, $_idx4_val$1);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = __ZNK2JS5Value8toStringEv($_idx4_val$0, $_idx4_val$1);
    var $_0 = $11;
    __label__ = 14;
    break;
   case 5:
    var $13 = __ZNK2JS5Value8isObjectEv($_idx4_val$0, $_idx4_val$1);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $15 = __ZNK2JS5Value8toObjectEv($_idx4_val$0, $_idx4_val$1);
    var $_idx7_val = HEAP32[$15 + 4 >> 2];
    var $16 = __ZNK8JSObject8isStringEv($_idx7_val);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_idx8_val$1 = $_idx4_val$1;
      var $_idx8_val$0 = $_idx4_val$0;
      __label__ = 12;
      break;
    }
   case 7:
    var $18 = $15;
    var $23 = HEAP32[HEAP32[$cx + 52 >> 2] + 210324 >> 2] | 0;
    var $24 = __ZL12ATOM_TO_JSIDP6JSAtom3836($23);
    var $25 = __ZN2jsL19ClassMethodIsNativeEP9JSContextP8JSObjectPNS_5ClassEiPFiS1_jPN2JS5ValueEE3938($cx, $18, $24);
    if ($25) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx8_val$1 = HEAP32[$_idx4 + 4 >> 2];
    var $_idx8_val$0 = HEAP32[$_idx4 >> 2];
    __label__ = 12;
    break;
   case 9:
    var $27 = $15;
    var $28 = __ZNK8JSObject16getPrimitiveThisEv($27);
    var $29 = $28 | 0;
    var $30$0 = HEAP32[$29 >> 2];
    var $30$1 = HEAP32[$29 + 4 >> 2];
    HEAP32[$_idx4 >> 2] = $30$0;
    HEAP32[$_idx4 + 4 >> 2] = $30$1;
    var $31 = __ZNK2JS5Value8toStringEv($30$0, $30$1);
    var $_0 = $31;
    __label__ = 14;
    break;
   case 10:
    var $33 = __ZNK2JS5Value17isNullOrUndefinedEv($_idx4_val$0, $_idx4_val$1);
    if ($33) {
      __label__ = 11;
      break;
    } else {
      var $_idx8_val$1 = $_idx4_val$1;
      var $_idx8_val$0 = $_idx4_val$0;
      __label__ = 12;
      break;
    }
   case 11:
    var $35 = __ZNK2JS5Value6isNullEv($_idx4_val$0, $_idx4_val$1);
    var $36 = $35 ? STRING_TABLE.__str483817 | 0 : STRING_TABLE.__str493818 | 0;
    var $37 = $cx;
    _JS_ReportErrorNumber($37, 4, 38, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $36, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str267560 | 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 12:
    var $_idx8_val$0;
    var $_idx8_val$1;
    var $39 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($cx, $_idx8_val$0, $_idx8_val$1);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    __ZN2JS5Value9setStringEP8JSString($8, $39);
    var $_0 = $39;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE["X"] = 1;

function __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd3824($cx, $v, $dp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx2 = $v | 0;
    var $v_idx2_val$0 = HEAP32[$v_idx2 >> 2];
    var $v_idx2_val$1 = HEAP32[$v_idx2 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx2_val$0, $v_idx2_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx2_val$0, $v_idx2_val$1);
    tempDoubleF64[0] = $3 | 0, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 8;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($v_idx2_val$0, $v_idx2_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($v);
    tempDoubleF64[0] = $8, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $13 = $8;
    __label__ = 7;
    break;
   case 5:
    var $10 = $cx;
    var $11 = __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($10, $v_idx2_val$0, $v_idx2_val$1, $dp);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $_pre = (tempDoubleI32[0] = HEAP32[$dp >> 2], tempDoubleI32[1] = HEAP32[$dp + 4 >> 2], tempDoubleF64[0]);
    var $13 = $_pre;
    __label__ = 7;
    break;
   case 7:
    var $13;
    var $14 = __ZL18js_DoubleToIntegerd3931($13);
    tempDoubleF64[0] = $14, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_str_charCodeAtP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $_idx4 = $vp + 8 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    var $1 = __ZNK2JS5Value8isStringEv($_idx4_val$0, $_idx4_val$1);
    var $2 = ($argc | 0) == 0;
    if ($2 | $1 ^ 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx5 = $vp + 16 | 0;
    var $_idx5_val$0 = HEAP32[$_idx5 >> 2];
    var $_idx5_val$1 = HEAP32[$_idx5 + 4 >> 2];
    var $4 = __ZNK2JS5Value7isInt32Ev($_idx5_val$0, $_idx5_val$1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZNK2JS5Value8toStringEv($_idx4_val$0, $_idx4_val$1);
    var $7 = __ZNK2JS5Value7toInt32Ev($_idx5_val$0, $_idx5_val$1);
    var $_idx2_val = HEAP32[$6 >> 2];
    var $8 = __ZNK8JSString6lengthEv($_idx2_val);
    if ($7 >>> 0 < $8 >>> 0) {
      var $i_0 = $7;
      var $str_0 = $6;
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 4:
    var $11 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    if ($2) {
      var $19 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $vp + 16 | 0;
    var $16 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd3824($cx, $15, $d);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 7:
    var $_pr = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    if ($_pr < 0) {
      __label__ = 12;
      break;
    } else {
      var $19 = $_pr;
      __label__ = 8;
      break;
    }
   case 8:
    var $19;
    var $_idx1_val = HEAP32[$11 >> 2];
    var $20 = __ZNK8JSString6lengthEv($_idx1_val);
    if ($20 >>> 0 > $19) {
      __label__ = 9;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 9:
    var $i_0 = $19 & -1;
    var $str_0 = $11;
    __label__ = 10;
    break;
   case 10:
    var $str_0;
    var $i_0;
    var $26 = $cx;
    var $27 = __ZN8JSString8getCharsEP9JSContext($str_0, $26);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $32 = HEAPU16[$27 + ($i_0 << 1) >> 1] & 65535;
    __ZN2JS5Value8setInt32Ei($vp, $32);
    var $_0 = 1;
    __label__ = 13;
    break;
   case 12:
    var $34 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $34);
    var $_0 = 1;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z17js_str_charCodeAtP9JSContextjPN2JS5ValueE["X"] = 1;

function __Z21js_BoyerMooreHorspoolPKtjS0_j($text, $textlen, $pat, $patlen) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 256;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $skip = __stackBase__;
    var $skip7 = $skip | 0;
    var $1 = $patlen & 255;
    _memset($skip7, $1, 256, 1);
    var $2 = $patlen - 1 | 0;
    var $i1_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i1_0;
    if ($i1_0 >>> 0 < $2 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $k_0 = $2;
      __label__ = 5;
      break;
    }
   case 3:
    var $7 = HEAPU16[$pat + ($i1_0 << 1) >> 1];
    if (($7 & 65535) > 255) {
      var $_0 = -2;
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP8[$skip + ($7 & 65535) | 0] = $2 - $i1_0 & 255;
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 2;
    break;
   case 5:
    var $k_0;
    if ($k_0 >>> 0 < $textlen >>> 0) {
      var $j_0 = $2;
      var $i3_0 = $k_0;
      __label__ = 6;
      break;
    } else {
      var $_0 = -1;
      __label__ = 12;
      break;
    }
   case 6:
    var $i3_0;
    var $j_0;
    if (HEAP16[$text + ($i3_0 << 1) >> 1] << 16 >> 16 == HEAP16[$pat + ($j_0 << 1) >> 1] << 16 >> 16) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    if (($j_0 | 0) == 0) {
      var $_0 = $i3_0;
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $j_0 = $j_0 - 1 | 0;
    var $i3_0 = $i3_0 - 1 | 0;
    __label__ = 6;
    break;
   case 9:
    var $28 = HEAPU16[$text + ($k_0 << 1) >> 1];
    if (($28 & 65535) > 255) {
      var $36 = $patlen;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $36 = HEAPU8[$skip + ($28 & 65535) | 0] & 255;
    __label__ = 11;
    break;
   case 11:
    var $36;
    var $k_0 = $36 + $k_0 | 0;
    __label__ = 5;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z21js_BoyerMooreHorspoolPKtjS0_j["X"] = 1;

function __ZNK9FlatMatch5matchEv($this_0_3_val) {
  return $this_0_3_val;
}

function __Z15js_strchr_limitPKttS0_($s, $c, $limit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $s;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    if ($_01 >>> 0 < $limit >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    if (HEAP16[$_01 >> 1] << 16 >> 16 == $c << 16 >> 16) {
      var $_0 = $_01;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_01 = $_01 + 2 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11str_replaceEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 184;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $rdata = __stackBase__;
    var $table = __stackBase__ + 176;
    __ZN11ReplaceDataC1EP9JSContext($rdata, $cx);
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    var $2 = $rdata | 0;
    HEAP32[$2 >> 2] = $1;
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $rdata + 4 | 0;
    var $6 = __ZN11RegExpGuard4initEjPN2JS5ValueEb($5, $argc, $vp, 0);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 32;
      break;
    }
   case 3:
    if ($argc >>> 0 > 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 4:
    var $_idx10 = $vp + 24 | 0;
    var $st$1$0 = $_idx10 | 0;
    var $_idx10_val$0 = HEAPU32[$st$1$0 >> 2];
    var $st$1$1 = $_idx10 + 4 | 0;
    var $_idx10_val$1 = HEAP32[$st$1$1 >> 2];
    var $10 = __ZL13js_IsCallableRKN2JS5ValueE3827($_idx10_val$0, $_idx10_val$1);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 5:
    var $12 = __ZNK2JS5Value8toObjectEv($_idx10_val$0, $_idx10_val$1);
    var $13 = $12;
    var $14 = $rdata + 36 | 0;
    HEAP32[$14 >> 2] = $13;
    var $15 = $rdata + 40 | 0;
    HEAP32[$15 >> 2] = 0;
    HEAP32[$rdata + 44 >> 2] = 0;
    HEAP32[$rdata + 52 >> 2] = 0;
    HEAP32[$rdata + 48 >> 2] = 0;
    var $19 = HEAP32[$12 + 4 >> 2];
    var $20 = __ZNK8JSObject10isFunctionEv($19);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 6:
    var $_idx3_val = HEAP32[$12 + 24 >> 2];
    var $23 = __ZNK8JSObject18getFunctionPrivateEv($_idx3_val);
    var $_idx4_val = HEAP16[$23 + 58 >> 1];
    var $24 = __ZNK10JSFunction13isInterpretedEv($_idx4_val);
    if ($24) {
      __label__ = 7;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 7:
    var $26 = __ZNK10JSFunction6scriptEv($23);
    var $28 = HEAPU32[$26 >> 2];
    __ZN2JSL14UndefinedValueEv3828($table);
    if (HEAP8[$28] << 24 >> 24 == -120) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $table_idx_phi_trans_insert = $table | 0;
    var $st$1$0 = $table_idx_phi_trans_insert | 0;
    var $st$1$1 = $table_idx_phi_trans_insert + 4 | 0;
    var $pc_0 = $28;
    var $table_idx_val$1 = HEAP32[$st$1$1 >> 2];
    var $table_idx_val$0 = HEAP32[$st$1$0 >> 2];
    __label__ = 10;
    break;
   case 9:
    var $40 = (HEAPU8[$28 + 1 | 0] & 255) << 8 | HEAPU8[$28 + 2 | 0] & 255;
    var $41 = HEAP32[$14 >> 2];
    var $42 = __ZN8JSObject19getFlatClosureUpvarEj($41, $40);
    var $43 = $42 | 0;
    var $44$0 = HEAPU32[$43 >> 2];
    var $44$1 = HEAPU32[$43 + 4 >> 2];
    var $45 = $table | 0;
    HEAP32[$45 >> 2] = $44$0;
    HEAP32[$45 + 4 >> 2] = $44$1;
    var $pc_0 = $28 + 3 | 0;
    var $table_idx_val$1 = $44$1;
    var $table_idx_val$0 = $44$0;
    __label__ = 10;
    break;
   case 10:
    var $table_idx_val$0;
    var $table_idx_val$1;
    var $pc_0;
    var $48 = __ZNK2JS5Value8isObjectEv($table_idx_val$0, $table_idx_val$1);
    if ($48) {
      __label__ = 11;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 11:
    if (HEAP8[$pc_0] << 24 >> 24 == 84) {
      __label__ = 12;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 12:
    if (((HEAPU8[$pc_0 + 1 | 0] & 255) << 8 | HEAPU8[$pc_0 + 2 | 0] & 255 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 13:
    if (HEAP8[$pc_0 + 3 | 0] << 24 >> 24 == 55) {
      __label__ = 14;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 14:
    if (HEAP8[$pc_0 + 4 | 0] << 24 >> 24 == 5) {
      __label__ = 15;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 15:
    var $71 = __ZNK2JS5Value8toObjectEv($table_idx_val$0, $table_idx_val$1);
    var $_idx5_val = HEAP32[$71 + 4 >> 2];
    var $72 = __ZNK8JSObject8getClassEv($_idx5_val);
    var $_idx11_val = HEAP32[$72 + 4 >> 2];
    var $73 = __ZNK2js5Class8isNativeEv($_idx11_val);
    if ($73) {
      __label__ = 16;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 16:
    if ((HEAP32[$72 + 96 >> 2] | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 17:
    if ((HEAP32[$72 + 128 >> 2] | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 18:
    HEAP32[$15 >> 2] = $71;
    __label__ = 22;
    break;
   case 19:
    HEAP32[$rdata + 36 >> 2] = 0;
    HEAP32[$rdata + 40 >> 2] = 0;
    var $87 = __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($cx, $argc, $vp, 1);
    HEAP32[$rdata + 44 >> 2] = $87;
    if (($87 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $91 = $87 | 0;
    var $92 = $cx;
    var $93 = __ZN8JSString11ensureFixedEP9JSContext($91, $92);
    if (($93 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $_idx8 = $93 + 4 | 0;
    var $_idx8_val = HEAP32[$_idx8 >> 2];
    var $96 = __ZNK14JSLinearString5charsEv($_idx8_val);
    var $_idx6_val = HEAP32[$93 >> 2];
    var $97 = __ZNK8JSString6lengthEv($_idx6_val);
    var $98 = $96 + ($97 << 1) | 0;
    HEAP32[$rdata + 52 >> 2] = $98;
    var $_idx7_val = HEAP32[$_idx8 >> 2];
    var $100 = __ZNK14JSLinearString5charsEv($_idx7_val);
    var $101 = __Z15js_strchr_limitPKttS0_($100, 36, $98);
    HEAP32[$rdata + 48 >> 2] = $101;
    __label__ = 22;
    break;
   case 22:
    var $104 = HEAP32[$2 >> 2];
    var $105 = __ZN11RegExpGuard12tryFlatMatchEP9JSContextP8JSStringjjb($5, $cx, $104, 2, $argc, 0);
    if (($105 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 23:
    var $_idx9_val = HEAP32[$cx + 20 >> 2];
    var $109 = __ZN9JSContext18isExceptionPendingEv($_idx9_val);
    if ($109) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $111 = __ZL18str_replace_regexpP9JSContextjPN2JS5ValueER11ReplaceData($cx, $argc, $vp, $rdata);
    var $_0 = $111 & 1;
    __label__ = 32;
    break;
   case 25:
    var $_idx12_val = HEAP32[$105 + 12 >> 2];
    var $114 = __ZNK9FlatMatch5matchEv($_idx12_val);
    if (($114 | 0) < 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $117 = HEAP32[$2 >> 2];
    __ZN2JS5Value9setStringEP8JSString($vp, $117);
    var $_0 = 1;
    __label__ = 32;
    break;
   case 27:
    if ((HEAP32[$rdata + 36 >> 2] | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $123 = __ZL23str_replace_flat_lambdaP9JSContextjPN2JS5ValueER11ReplaceDataRK9FlatMatch($cx, $vp, $rdata, $105);
    var $_0 = $123 & 1;
    __label__ = 32;
    break;
   case 29:
    var $127 = HEAPU32[$rdata + 48 >> 2];
    var $129 = HEAPU32[$2 >> 2];
    var $131 = HEAPU32[$rdata + 44 >> 2];
    if (($127 | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $133 = __ZL22BuildDollarReplacementP9JSContextP8JSStringP14JSLinearStringPKtRK9FlatMatchPN2JS5ValueE($cx, $129, $131, $127, $105, $vp);
    var $_0 = $133 & 1;
    __label__ = 32;
    break;
   case 31:
    var $136 = $131 | 0;
    var $137 = __ZL20BuildFlatReplacementP9JSContextP8JSStringS2_RK9FlatMatchPN2JS5ValueE($cx, $129, $136, $105, $vp);
    var $_0 = $137 & 1;
    __label__ = 32;
    break;
   case 32:
    var $_0;
    __ZN11ReplaceDataD1Ev($rdata);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11str_replaceEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN11ReplaceDataC1EP9JSContext($this, $cx) {
  __ZN11ReplaceDataC2EP9JSContext($this, $cx);
  return;
}

function __ZN11RegExpGuard4initEjPN2JS5ValueEb($this, $argc, $vp, $convertVoid) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($argc | 0) == 0;
    if ($1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $vp + 16 | 0;
    var $st$1$0 = $3 | 0;
    var $4$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $3 + 4 | 0;
    var $4$1 = HEAP32[$st$1$1 >> 2];
    var $5 = __ZL15VALUE_IS_REGEXPP9JSContextN2JS5ValueE($4$0, $4$1);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = $this + 4 | 0;
    var $8 = __ZNK2JS5Value8toObjectEv($4$0, $4$1);
    var $9 = $8;
    __ZN10RegExpPair5resetER8JSObject($7, $9);
    __label__ = 9;
    break;
   case 4:
    if ($convertVoid) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    if ($1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx1 = $vp + 16 | 0;
    var $st$1$0 = $_idx1 | 0;
    var $_idx1_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx1 + 4 | 0;
    var $_idx1_val$1 = HEAP32[$st$1$1 >> 2];
    var $13 = __ZNK2JS5Value11isUndefinedEv($_idx1_val$0, $_idx1_val$1);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $21 = HEAP32[HEAP32[HEAP32[$this >> 2] + 52 >> 2] + 144136 >> 2] | 0;
    HEAP32[$this + 16 >> 2] = $21;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 8:
    var $25 = HEAP32[$this >> 2];
    var $26 = __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($25, $argc, $vp, 0);
    HEAP32[$this + 16 >> 2] = $26;
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13js_IsCallableRKN2JS5ValueE3827($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZN8JSObject10isCallableEv($_idx_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL14UndefinedValueEv3828($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($cx, $argc, $vp, $arg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($arg >>> 0 < $argc >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 209984 >> 2] | 0;
    __label__ = 14;
    break;
   case 3:
    var $10 = $vp + ($arg + 2 << 3) | 0;
    var $11 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE3862($cx, $10);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 4:
    var $_idx2 = $10 | 0;
    var $_idx2_val$0 = HEAPU32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAPU32[$_idx2 + 4 >> 2];
    var $13 = __ZNK2JS5Value8isStringEv($_idx2_val$0, $_idx2_val$1);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $15 = __ZNK2JS5Value8toStringEv($_idx2_val$0, $_idx2_val$1);
    var $16 = $cx;
    var $17 = __ZN8JSString12ensureLinearEP9JSContext($15, $16);
    var $_0 = $17;
    __label__ = 14;
    break;
   case 6:
    var $19 = __ZNK2JS5Value9isBooleanEv($_idx2_val$0, $_idx2_val$1);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $21 = __ZNK2JS5Value9toBooleanEv($_idx2_val$0, $_idx2_val$1);
    var $_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 209976 + (($21 & 1) << 2) >> 2] | 0;
    __label__ = 14;
    break;
   case 8:
    var $29 = __ZNK2JS5Value6isNullEv($_idx2_val$0, $_idx2_val$1);
    if ($29) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 210016 >> 2] | 0;
    __label__ = 14;
    break;
   case 10:
    var $37 = __ZNK2JS5Value11isUndefinedEv($_idx2_val$0, $_idx2_val$1);
    if ($37) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 209984 >> 2] | 0;
    __label__ = 14;
    break;
   case 12:
    var $45 = __ZNK2JS5Value8toNumberEv($10);
    var $46 = $cx;
    var $47 = __ZN2js14NumberToStringEP9JSContextd($46, $45);
    if (($47 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $50 = $47 | 0;
    var $51 = $47 | 0;
    __ZN2JS5Value9setStringEP8JSString($10, $51);
    var $_0 = $50;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj["X"] = 1;

function __ZN11RegExpGuard12tryFlatMatchEP9JSContextP8JSStringjjb($this, $cx, $textstr, $optarg, $argc, $checkMetaChars) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = __ZNK10RegExpPair9hasRegExpEv($1);
    if ($2) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $this + 16 | 0;
    var $6 = HEAP32[$4 >> 2];
    var $_idx2_val = HEAP32[$6 + 4 >> 2];
    var $7 = __ZNK14JSLinearString5charsEv($_idx2_val);
    HEAP32[$this + 20 >> 2] = $7;
    var $_idx_val = HEAP32[$6 >> 2];
    var $9 = __ZNK8JSString6lengthEv($_idx_val);
    HEAP32[$this + 24 >> 2] = $9;
    if ($optarg >>> 0 < $argc >>> 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($checkMetaChars) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    if ($9 >>> 0 > 256) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = __ZN2js6RegExp12hasMetaCharsEPKtj($7, $9);
    if ($16) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $textstr_idx3_val = HEAPU32[$textstr >> 2];
    var $18 = __ZNK8JSString6isRopeEv($textstr_idx3_val);
    if ($18) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = $this + 28 | 0;
    var $21 = __ZL9RopeMatchP9JSContextP8JSStringPKtjPi($cx, $textstr, $7, $9, $20);
    if ($21) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $23 = __ZN8JSString8asLinearEv($textstr);
    var $_idx1_val = HEAP32[$23 + 4 >> 2];
    var $24 = __ZNK14JSLinearString5charsEv($_idx1_val);
    var $25 = __ZNK8JSString6lengthEv($textstr_idx3_val);
    var $26 = __ZL11StringMatchPKtjS0_j($24, $25, $7, $9);
    HEAP32[$this + 28 >> 2] = $26;
    __label__ = 9;
    break;
   case 9:
    var $_0 = $4;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18str_replace_regexpP9JSContextjPN2JS5ValueER11ReplaceData($cx, $argc, $vp, $rdata) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $sub = __stackBase__ + 8;
    var $1 = $rdata + 4 | 0;
    var $2 = __ZN11RegExpGuard15normalizeRegExpEbjjPN2JS5ValueE($1, 1, 2, $argc, $vp);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$rdata + 56 >> 2] = 0;
    var $6 = $rdata + 68 | 0;
    HEAP8[$6] = 0;
    var $7 = $cx;
    var $8 = __ZN9JSContext13regExpStaticsEv($7);
    var $9 = $rdata | 0;
    var $10 = HEAP32[$9 >> 2];
    var $11 = $rdata;
    var $12 = __ZL7DoMatchP9JSContextPN2js13RegExpStaticsEP8JSStringRK10RegExpPairPFbS0_S3_jPvES9_17MatchControlFlagsPN2JS5ValueE($cx, $8, $10, $2, 228, $11, 7, $tmp);
    if ($12) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    if ((HEAP8[$6] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $18 = HEAP32[$9 >> 2];
    __ZN2JS5Value9setStringEP8JSString($vp, $18);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 5:
    __ZNK2js13RegExpStatics15getRightContextEP11JSSubString($8, $sub);
    var $20 = $rdata + 96 | 0;
    var $22 = HEAP32[$sub + 4 >> 2];
    var $24 = HEAP32[$sub >> 2];
    var $25 = $20;
    var $26 = __ZN2js12StringBuffer6appendEPKtj($25, $22, $24);
    if ($26) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $28 = __ZN2js12StringBuffer12finishStringEv($20);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $31 = $28 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $31);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23str_replace_flat_lambdaP9JSContextjPN2JS5ValueER11ReplaceDataRK9FlatMatch($cx, $vp, $rdata, $fm) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $builder = __stackBase__;
    var $1 = $rdata | 0;
    var $2 = HEAP32[$1 >> 2];
    var $fm_idx8 = $fm + 12 | 0;
    var $fm_idx8_val = HEAP32[$fm_idx8 >> 2];
    var $3 = __ZNK9FlatMatch5matchEv($fm_idx8_val);
    var $fm_idx10 = $fm + 8 | 0;
    var $fm_idx10_val = HEAP32[$fm_idx10 >> 2];
    var $4 = __ZNK9FlatMatch13patternLengthEv($fm_idx10_val);
    var $5 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $2, $3, $4);
    var $6 = $5 | 0;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $rdata + 72 | 0;
    var $11 = $cx + 60 | 0;
    var $12 = $cx;
    var $13 = $10;
    var $14 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($11, $12, 3, $13);
    if ($14) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 3:
    var $_idx1 = $10 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $16 = __ZNK2js12CallReceiver7calleevEv($_idx1_val);
    var $19 = HEAP32[$rdata + 36 >> 2];
    __ZN2JS5Value9setObjectER8JSObject($16, $19);
    var $_idx2_val = HEAP32[$_idx1 >> 2];
    var $20 = __ZNK2js12CallReceiver5thisvEv($_idx2_val);
    __ZN2JS5Value12setUndefinedEv($20);
    var $_idx_val = HEAP32[$_idx1 >> 2];
    var $21 = __ZNK2js8CallArgs4argvEv($_idx_val);
    __ZN2JS5Value9setStringEP8JSString($21, $6);
    var $22 = $21 + 8 | 0;
    var $fm_idx7_val = HEAP32[$fm_idx8 >> 2];
    var $23 = __ZNK9FlatMatch5matchEv($fm_idx7_val);
    __ZN2JS5Value8setInt32Ei($22, $23);
    var $24 = $21 + 16 | 0;
    var $25 = HEAP32[$1 >> 2];
    __ZN2JS5Value9setStringEP8JSString($24, $25);
    var $26 = $cx;
    var $27 = $10;
    var $28 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($26, $27, 0);
    if ($28) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 4:
    var $_idx4_val = HEAP32[$_idx1 >> 2];
    var $30 = __ZNK2js12CallReceiver4rvalEv($_idx4_val);
    var $_idx5 = $30 | 0;
    var $_idx5_val$0 = HEAP32[$_idx5 >> 2];
    var $_idx5_val$1 = HEAP32[$_idx5 + 4 >> 2];
    var $31 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($cx, $_idx5_val$0, $_idx5_val$1);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $34 = HEAP32[$1 >> 2];
    var $fm_idx6_val = HEAP32[$fm_idx8 >> 2];
    var $35 = __ZNK9FlatMatch5matchEv($fm_idx6_val);
    var $36 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $34, 0, $35);
    var $37 = $36 | 0;
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $fm_idx_val = HEAP32[$fm_idx8 >> 2];
    var $40 = __ZNK9FlatMatch5matchEv($fm_idx_val);
    var $fm_idx9_val = HEAP32[$fm_idx10 >> 2];
    var $41 = __ZNK9FlatMatch13patternLengthEv($fm_idx9_val);
    var $42 = $41 + $40 | 0;
    var $43 = HEAP32[$1 >> 2];
    var $_idx3_val = HEAP32[$43 >> 2];
    var $44 = __ZNK8JSString6lengthEv($_idx3_val);
    var $45 = $44 - $42 | 0;
    var $46 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $43, $42, $45);
    var $47 = $46 | 0;
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2js11RopeBuilderC1EP9JSContext($builder, $cx);
    var $50 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $37);
    if ($50) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 8:
    var $52 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $31);
    if ($52) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 9:
    var $54 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $47);
    if ($54) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $builder_idx_val = HEAP32[$builder + 4 >> 2];
    var $56 = __ZN2js11RopeBuilder6resultEv($builder_idx_val);
    __ZN2JS5Value9setStringEP8JSString($vp, $56);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL23str_replace_flat_lambdaP9JSContextjPN2JS5ValueER11ReplaceDataRK9FlatMatch["X"] = 1;

function __ZL22BuildDollarReplacementP9JSContextP8JSStringP14JSLinearStringPKtRK9FlatMatchPN2JS5ValueE($cx, $textstrArg, $repstr, $firstDollar, $fm, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 88;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newReplaceChars = __stackBase__;
    var $builder = __stackBase__ + 80;
    var $1 = $cx;
    var $2 = __ZN8JSString12ensureLinearEP9JSContext($textstrArg, $1);
    if (($2 | 0) == 0) {
      var $_1 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $fm_idx_val = HEAP32[$fm + 12 >> 2];
    var $5 = __ZNK9FlatMatch5matchEv($fm_idx_val);
    var $fm_idx10 = $fm + 8 | 0;
    var $fm_idx10_val = HEAP32[$fm_idx10 >> 2];
    var $6 = __ZNK9FlatMatch13patternLengthEv($fm_idx10_val);
    var $7 = $6 + $5 | 0;
    var $8 = $newReplaceChars;
    __ZN2js12StringBufferC1EP9JSContext($8, $1);
    var $9 = $2 | 0;
    var $_idx4 = $2 | 0;
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $10 = __ZNK8JSString6lengthEv($_idx4_val);
    var $fm_idx9_val = HEAP32[$fm_idx10 >> 2];
    var $11 = __ZNK9FlatMatch13patternLengthEv($fm_idx9_val);
    var $_idx3 = $repstr | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $12 = __ZNK8JSString6lengthEv($_idx3_val);
    var $14 = $10 - $11 + $12 | 0;
    var $15 = __ZN2js12StringBuffer7reserveEj($8, $14);
    if ($15) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 3:
    var $repstr_idx8 = $repstr + 4 | 0;
    var $repstr_idx8_val = HEAP32[$repstr_idx8 >> 2];
    var $17 = __ZNK14JSLinearString5charsEv($repstr_idx8_val);
    __ZN2js12StringBuffer16infallibleAppendEPKtS2_($newReplaceChars, $17, $firstDollar);
    var $repstr_idx_val = HEAP32[$repstr_idx8 >> 2];
    var $18 = __ZNK14JSLinearString5charsEv($repstr_idx_val);
    var $_idx2_val = HEAP32[$_idx3 >> 2];
    var $19 = __ZNK8JSString6lengthEv($_idx2_val);
    var $20 = $18 + ($19 << 1) | 0;
    var $21 = $18 + ($19 - 1 << 1) | 0;
    var $22 = $newReplaceChars;
    var $_idx7 = $2 + 4 | 0;
    var $it_0 = $firstDollar;
    __label__ = 4;
    break;
   case 4:
    var $it_0;
    if ($it_0 >>> 0 < $20 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 5:
    var $26 = HEAPU16[$it_0 >> 1];
    if ($26 << 16 >> 16 != 36 | ($it_0 | 0) == ($21 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $30 = __ZN2js12StringBuffer6appendEt($8, $26);
    if ($30) {
      var $it_1 = $it_0;
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 7:
    var $32 = $it_0 + 2 | 0;
    var $34 = HEAPU16[$32 >> 1] & 65535;
    if (($34 | 0) == 36) {
      __label__ = 8;
      break;
    } else if (($34 | 0) == 38) {
      __label__ = 9;
      break;
    } else if (($34 | 0) == 96) {
      __label__ = 10;
      break;
    } else if (($34 | 0) == 39) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 8:
    var $36 = __ZN2js12StringBuffer6appendEt($8, 36);
    if ($36) {
      var $it_1 = $32;
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 9:
    var $_idx7_val = HEAP32[$_idx7 >> 2];
    var $38 = __ZNK14JSLinearString5charsEv($_idx7_val);
    var $39 = $38 + ($5 << 1) | 0;
    var $40 = $38 + ($7 << 1) | 0;
    var $41 = __ZN2js12StringBuffer6appendEPKtS2_($22, $39, $40);
    if ($41) {
      var $it_1 = $32;
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 10:
    var $_idx6_val = HEAP32[$_idx7 >> 2];
    var $43 = __ZNK14JSLinearString5charsEv($_idx6_val);
    var $44 = $43 + ($5 << 1) | 0;
    var $45 = __ZN2js12StringBuffer6appendEPKtS2_($22, $43, $44);
    if ($45) {
      var $it_1 = $32;
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 11:
    var $_idx5_val = HEAP32[$_idx7 >> 2];
    var $47 = __ZNK14JSLinearString5charsEv($_idx5_val);
    var $48 = $47 + ($7 << 1) | 0;
    var $_idx1_val = HEAP32[$_idx4 >> 2];
    var $49 = __ZNK8JSString6lengthEv($_idx1_val);
    var $50 = $47 + ($49 << 1) | 0;
    var $51 = __ZN2js12StringBuffer6appendEPKtS2_($22, $48, $50);
    if ($51) {
      var $it_1 = $32;
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 12:
    var $53 = __ZN2js12StringBuffer6appendEt($8, 36);
    if ($53) {
      var $it_1 = $it_0;
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 13:
    var $it_1;
    var $it_0 = $it_1 + 2 | 0;
    __label__ = 4;
    break;
   case 14:
    var $57 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $9, 0, $5);
    var $58 = $57 | 0;
    if (($57 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $61 = __ZN2js12StringBuffer12finishStringEv($newReplaceChars);
    var $62 = $61 | 0;
    if (($61 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $_idx_val = HEAP32[$_idx4 >> 2];
    var $65 = __ZNK8JSString6lengthEv($_idx_val);
    var $66 = $65 - $7 | 0;
    var $67 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $9, $7, $66);
    var $68 = $67 | 0;
    if (($67 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    __ZN2js11RopeBuilderC1EP9JSContext($builder, $cx);
    var $71 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $58);
    if ($71) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 18:
    var $73 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $62);
    if ($73) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 19:
    var $75 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $68);
    if ($75) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 20:
    var $builder_idx_val = HEAP32[$builder + 4 >> 2];
    var $77 = __ZN2js11RopeBuilder6resultEv($builder_idx_val);
    __ZN2JS5Value9setStringEP8JSString($vp, $77);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    __ZN2js12StringBufferD1Ev($8);
    var $_1 = $_0;
    __label__ = 22;
    break;
   case 22:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL22BuildDollarReplacementP9JSContextP8JSStringP14JSLinearStringPKtRK9FlatMatchPN2JS5ValueE["X"] = 1;

function __ZL20BuildFlatReplacementP9JSContextP8JSStringS2_RK9FlatMatchPN2JS5ValueE($cx, $textstr, $repstr, $fm, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 156;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $builder = __stackBase__;
    var $r = __stackBase__ + 8;
    __ZN2js11RopeBuilderC1EP9JSContext($builder, $cx);
    var $fm_idx_val = HEAP32[$fm + 12 >> 2];
    var $1 = __ZNK9FlatMatch5matchEv($fm_idx_val);
    var $fm_idx5 = $fm + 8 | 0;
    var $fm_idx5_val = HEAP32[$fm_idx5 >> 2];
    var $2 = __ZNK9FlatMatch13patternLengthEv($fm_idx5_val);
    var $3 = $2 + $1 | 0;
    var $textstr_idx2 = $textstr | 0;
    var $textstr_idx2_val = HEAP32[$textstr_idx2 >> 2];
    var $4 = __ZNK8JSString6isRopeEv($textstr_idx2_val);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 2:
    __ZN2js18StringSegmentRangeC1EP9JSContext($r, $cx);
    var $6 = __ZN2js18StringSegmentRange4initEP8JSString($r, $textstr);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 3:
    var $r_idx = $r + 144 | 0;
    var $pos_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $pos_0;
    var $r_idx_val = HEAP32[$r_idx >> 2];
    var $7 = __ZNK2js18StringSegmentRange5emptyEv($r_idx_val);
    if ($7) {
      __label__ = 15;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZNK2js18StringSegmentRange5frontEv($r_idx_val);
    var $10 = $9 | 0;
    var $_idx1 = $9 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $11 = __ZNK8JSString6lengthEv($_idx1_val);
    var $12 = $11 + $pos_0 | 0;
    if ($pos_0 >>> 0 < $3 >>> 0 & $12 >>> 0 > $1 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 6:
    if ($1 >>> 0 < $pos_0 >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = $1 - $pos_0 | 0;
    var $19 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $10, 0, $18);
    if (($19 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = $19 | 0;
    var $23 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $22);
    if ($23) {
      __label__ = 9;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 9:
    var $25 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $repstr);
    if ($25) {
      __label__ = 10;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 10:
    if ($12 >>> 0 > $3 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 11:
    var $29 = $3 - $pos_0 | 0;
    var $30 = $12 - $3 | 0;
    var $31 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $10, $29, $30);
    if (($31 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $34 = $31 | 0;
    var $35 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $34);
    if ($35) {
      __label__ = 14;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 13:
    var $37 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $10);
    if ($37) {
      __label__ = 14;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 14:
    var $_idx_val = HEAP32[$_idx1 >> 2];
    var $38 = __ZNK8JSString6lengthEv($_idx_val);
    var $39 = $38 + $pos_0 | 0;
    var $40 = __ZN2js18StringSegmentRange8popFrontEv($r);
    if ($40) {
      var $pos_0 = $39;
      __label__ = 4;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 15:
    __ZN2js18StringSegmentRangeD1Ev($r);
    __label__ = 21;
    break;
   case 16:
    var $43 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $textstr, 0, $1);
    var $44 = $43 | 0;
    if (($43 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $fm_idx4_val = HEAP32[$fm_idx5 >> 2];
    var $47 = __ZNK9FlatMatch13patternLengthEv($fm_idx4_val);
    var $48 = $47 + $1 | 0;
    var $textstr_idx_val = HEAP32[$textstr_idx2 >> 2];
    var $49 = __ZNK8JSString6lengthEv($textstr_idx_val);
    var $50 = $49 - $48 | 0;
    var $51 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $textstr, $48, $50);
    var $52 = $51 | 0;
    if (($51 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $55 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $44);
    if ($55) {
      __label__ = 19;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 19:
    var $57 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $repstr);
    if ($57) {
      __label__ = 20;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 20:
    var $59 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $52);
    if ($59) {
      __label__ = 21;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 21:
    var $builder_idx_val = HEAP32[$builder + 4 >> 2];
    var $61 = __ZN2js11RopeBuilder6resultEv($builder_idx_val);
    __ZN2JS5Value9setStringEP8JSString($vp, $61);
    var $_1 = 1;
    __label__ = 30;
    break;
   case 22:
    __ZN2js18StringSegmentRangeD1Ev($r);
    var $_1 = 0;
    __label__ = 30;
    break;
   case 23:
    __ZN2js18StringSegmentRangeD1Ev($r);
    var $_1 = 0;
    __label__ = 30;
    break;
   case 24:
    __ZN2js18StringSegmentRangeD1Ev($r);
    var $_1 = 0;
    __label__ = 30;
    break;
   case 25:
    __ZN2js18StringSegmentRangeD1Ev($r);
    var $_1 = 0;
    __label__ = 30;
    break;
   case 26:
    __ZN2js18StringSegmentRangeD1Ev($r);
    var $_1 = 0;
    __label__ = 30;
    break;
   case 27:
    __ZN2js18StringSegmentRangeD1Ev($r);
    var $_1 = 0;
    __label__ = 30;
    break;
   case 28:
    __ZN2js18StringSegmentRangeD1Ev($r);
    var $_1 = 0;
    __label__ = 30;
    break;
   case 29:
    __ZN2js18StringSegmentRangeD1Ev($r);
    var $_1 = 0;
    __label__ = 30;
    break;
   case 30:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL20BuildFlatReplacementP9JSContextP8JSStringS2_RK9FlatMatchPN2JS5ValueE["X"] = 1;

function __ZN11ReplaceDataD1Ev($this) {
  __ZN11ReplaceDataD2Ev($this);
  return;
}

function __ZL9str_quoteP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = _js_QuoteString($4, $1, 34);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value9setStringEP8JSString($vp, $5);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12str_toSourceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str = __stackBase__;
    var $buf = __stackBase__ + 4;
    var $anchor = __stackBase__ + 20;
    var $1 = __ZN2js16GetPrimitiveThisIP8JSStringEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $str);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 13;
      break;
    }
   case 2:
    var $3 = HEAP32[$str >> 2];
    var $4 = $cx;
    var $5 = _js_QuoteString($4, $3, 34);
    HEAP32[$str >> 2] = $5;
    if (($5 | 0) == 0) {
      var $_1 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $buf | 0;
    var $9 = _JS_snprintf($8, 16, STRING_TABLE.__str473816 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $5);
    var $_idx_val = HEAP32[$5 >> 2];
    var $10 = __ZNK8JSString6lengthEv($_idx_val);
    var $11 = __ZN8JSString8getCharsEP9JSContext($5, $4);
    if (($11 | 0) == 0) {
      var $_1 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $10 + $9 | 0;
    var $15 = $14 + 2 | 0;
    var $17 = ($14 << 1) + 6 | 0;
    var $18 = __ZN9JSContext7malloc_Ej($4, $17);
    var $19 = $18;
    if (($18 | 0) == 0) {
      var $_1 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($9 | 0) == 0) {
      var $i_0_lcssa = 0;
      __label__ = 6;
      break;
    } else {
      var $i_04 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $i_0_lcssa;
    if (($10 | 0) == 0) {
      var $i_1_lcssa = $i_0_lcssa;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = $10 + $i_0_lcssa | 0;
    var $j_01 = 0;
    var $i_12 = $i_0_lcssa;
    __label__ = 9;
    break;
   case 8:
    var $i_04;
    HEAP16[$19 + ($i_04 << 1) >> 1] = HEAP8[$buf + $i_04 | 0] << 24 >> 24;
    var $28 = $i_04 + 1 | 0;
    if (($28 | 0) == ($9 | 0)) {
      var $i_0_lcssa = $9;
      __label__ = 6;
      break;
    } else {
      var $i_04 = $28;
      __label__ = 8;
      break;
    }
   case 9:
    var $i_12;
    var $j_01;
    var $31 = HEAP16[$11 + ($j_01 << 1) >> 1];
    HEAP16[$19 + ($i_12 << 1) >> 1] = $31;
    var $33 = $i_12 + 1 | 0;
    if (($33 | 0) == ($23 | 0)) {
      var $i_1_lcssa = $23;
      __label__ = 10;
      break;
    } else {
      var $j_01 = $j_01 + 1 | 0;
      var $i_12 = $33;
      __label__ = 9;
      break;
    }
   case 10:
    var $i_1_lcssa;
    HEAP16[$19 + ($i_1_lcssa << 1) >> 1] = 41;
    HEAP16[$19 + ($i_1_lcssa + 1 << 1) >> 1] = 41;
    HEAP16[$19 + ($i_1_lcssa + 2 << 1) >> 1] = 0;
    var $40 = __Z12js_NewStringP9JSContextPtj($cx, $19, $15);
    var $41 = $40 | 0;
    HEAP32[$str >> 2] = $41;
    if (($40 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    __ZN9JSContext5free_EPv($18);
    var $_1 = 0;
    __label__ = 13;
    break;
   case 12:
    __ZN2JS5Value9setStringEP8JSString($vp, $41);
    var $_1 = 1;
    __label__ = 13;
    break;
   case 13:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12str_toSourceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL13str_substringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $begin = __stackBase__;
    var $end = __stackBase__ + 4;
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($argc | 0) == 0) {
      var $str_0 = $1;
      __label__ = 18;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx1_val = HEAP32[$1 >> 2];
    var $6 = __ZNK8JSString6lengthEv($_idx1_val);
    HEAP32[$end >> 2] = $6;
    var $7 = $vp + 16 | 0;
    var $8 = __Z19ValueToIntegerRangeP9JSContextRKN2JS5ValueEPi($cx, $7, $begin);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 4:
    var $10 = HEAP32[$begin >> 2];
    if (($10 | 0) < 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    HEAP32[$begin >> 2] = 0;
    var $17 = 0;
    __label__ = 8;
    break;
   case 6:
    if (($10 | 0) > ($6 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $17 = $10;
      __label__ = 8;
      break;
    }
   case 7:
    HEAP32[$begin >> 2] = $6;
    var $17 = $6;
    __label__ = 8;
    break;
   case 8:
    var $17;
    if ($argc >>> 0 > 1) {
      __label__ = 9;
      break;
    } else {
      var $37 = $17;
      var $36 = $6;
      __label__ = 17;
      break;
    }
   case 9:
    var $20 = $vp + 24 | 0;
    var $_idx = $20 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $21 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($21) {
      var $37 = $17;
      var $36 = $6;
      __label__ = 17;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $23 = __Z19ValueToIntegerRangeP9JSContextRKN2JS5ValueEPi($cx, $20, $end);
    if ($23) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 11:
    var $25 = HEAP32[$end >> 2];
    if (($25 | 0) > ($6 | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    HEAP32[$end >> 2] = $6;
    var $37 = $17;
    var $36 = $6;
    __label__ = 17;
    break;
   case 13:
    if (($25 | 0) < 0) {
      __label__ = 14;
      break;
    } else {
      var $32 = $25;
      __label__ = 15;
      break;
    }
   case 14:
    HEAP32[$end >> 2] = 0;
    var $32 = 0;
    __label__ = 15;
    break;
   case 15:
    var $32;
    if (($32 | 0) < ($17 | 0)) {
      __label__ = 16;
      break;
    } else {
      var $37 = $17;
      var $36 = $32;
      __label__ = 17;
      break;
    }
   case 16:
    HEAP32[$begin >> 2] = $32;
    HEAP32[$end >> 2] = $17;
    var $37 = $32;
    var $36 = $17;
    __label__ = 17;
    break;
   case 17:
    var $36;
    var $37;
    var $39 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $1, $37, $36 - $37 | 0);
    var $40 = $39 | 0;
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      var $str_0 = $40;
      __label__ = 18;
      break;
    }
   case 18:
    var $str_0;
    __ZN2JS5Value9setStringEP8JSString($vp, $str_0);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13str_substringP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL15str_toLowerCaseP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_toLowerCaseP9JSContextP8JSString($cx, $1);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value9setStringEP8JSString($vp, $4);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15str_toUpperCaseP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_toUpperCaseP9JSContextP8JSString($cx, $1);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value9setStringEP8JSString($vp, $4);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11str_indexOfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($cx, $argc, $vp, 0);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx2_val = HEAP32[$1 >> 2];
    var $7 = __ZNK8JSString6lengthEv($_idx2_val);
    var $8 = $cx;
    var $9 = __ZN8JSString8getCharsEP9JSContext($1, $8);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx1_val = HEAP32[$4 >> 2];
    var $12 = __ZNK8JSString6lengthEv($_idx1_val);
    var $_idx3_val = HEAP32[$4 + 4 >> 2];
    var $13 = __ZNK14JSLinearString5charsEv($_idx3_val);
    if ($argc >>> 0 > 1) {
      __label__ = 5;
      break;
    } else {
      var $start_0 = 0;
      var $text_0 = $9;
      var $textlen_0 = $7;
      __label__ = 13;
      break;
    }
   case 5:
    var $16 = $vp + 24 | 0;
    var $_idx4 = $16 | 0;
    var $_idx4_val$0 = HEAPU32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    var $17 = __ZNK2JS5Value7isInt32Ev($_idx4_val$0, $_idx4_val$1);
    if ($17) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $19 = __ZNK2JS5Value7toInt32Ev($_idx4_val$0, $_idx4_val$1);
    if (($19 | 0) < 1) {
      var $start_0 = 0;
      var $text_0 = $9;
      var $textlen_0 = $7;
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ($19 >>> 0 > $7 >>> 0) {
      var $start_0 = $7;
      var $text_0 = $9;
      var $textlen_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $start_0 = $19;
    var $text_0 = $9 + ($19 << 1) | 0;
    var $textlen_0 = $7 - $19 | 0;
    __label__ = 13;
    break;
   case 9:
    var $27 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd3824($cx, $16, $d);
    if ($27) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 10:
    var $29 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    if ($29 > 0) {
      __label__ = 11;
      break;
    } else {
      var $start_0 = 0;
      var $text_0 = $9;
      var $textlen_0 = $7;
      __label__ = 13;
      break;
    }
   case 11:
    if ($29 > $7 >>> 0) {
      var $start_0 = $7;
      var $text_0 = $9;
      var $textlen_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $35 = $29 & -1;
    var $start_0 = $35;
    var $text_0 = $9 + ($35 << 1) | 0;
    var $textlen_0 = $7 - $35 | 0;
    __label__ = 13;
    break;
   case 13:
    var $textlen_0;
    var $text_0;
    var $start_0;
    var $39 = __ZL11StringMatchPKtjS0_j($text_0, $textlen_0, $13, $12);
    var $42 = ($39 | 0) == -1 ? -1 : $39 + $start_0 | 0;
    __ZN2JS5Value8setInt32Ei($vp, $42);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11str_indexOfP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL15str_lastIndexOfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx2_val = HEAP32[$1 >> 2];
    var $4 = __ZNK8JSString6lengthEv($_idx2_val);
    var $5 = $cx;
    var $6 = __ZN8JSString8getCharsEP9JSContext($1, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($cx, $argc, $vp, 0);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx1_val = HEAP32[$9 >> 2];
    var $12 = __ZNK8JSString6lengthEv($_idx1_val);
    var $_idx3_val = HEAP32[$9 + 4 >> 2];
    var $13 = __ZNK14JSLinearString5charsEv($_idx3_val);
    var $14 = $4 - $12 | 0;
    if (($14 | 0) < 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2JS5Value8setInt32Ei($vp, -1);
    var $_0 = 1;
    __label__ = 26;
    break;
   case 6:
    if ($argc >>> 0 > 1) {
      __label__ = 7;
      break;
    } else {
      var $i_0 = $14;
      __label__ = 16;
      break;
    }
   case 7:
    var $20 = $vp + 24 | 0;
    var $_idx4 = $20 | 0;
    var $_idx4_val$0 = HEAPU32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    var $21 = __ZNK2JS5Value7isInt32Ev($_idx4_val$0, $_idx4_val$1);
    if ($21) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $23 = __ZNK2JS5Value7toInt32Ev($_idx4_val$0, $_idx4_val$1);
    if (($23 | 0) < 1) {
      var $i_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (($23 | 0) < ($14 | 0)) {
      __label__ = 10;
      break;
    } else {
      var $i_0 = $14;
      __label__ = 16;
      break;
    }
   case 10:
    var $i_0 = $23;
    __label__ = 16;
    break;
   case 11:
    var $29 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($5, $20, $d);
    if ($29) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 26;
      break;
    }
   case 12:
    var $31 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $32 = __ZL15JSDOUBLE_IS_NaNd3930($31);
    if (($32 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $i_0 = $14;
      __label__ = 16;
      break;
    }
   case 13:
    var $35 = __ZL18js_DoubleToIntegerd3931($31);
    tempDoubleF64[0] = $35, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    if ($35 > 0) {
      __label__ = 14;
      break;
    } else {
      var $i_0 = 0;
      __label__ = 16;
      break;
    }
   case 14:
    if ($35 < ($14 | 0)) {
      __label__ = 15;
      break;
    } else {
      var $i_0 = $14;
      __label__ = 16;
      break;
    }
   case 15:
    var $i_0 = $35 & -1;
    __label__ = 16;
    break;
   case 16:
    var $i_0;
    if (($12 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    __ZN2JS5Value8setInt32Ei($vp, $i_0);
    var $_0 = 1;
    __label__ = 26;
    break;
   case 18:
    var $47 = $6 - 2 | 0;
    var $48 = HEAP16[$13 >> 1];
    var $49 = $13 + ($12 << 1) | 0;
    var $t_0 = $6 + ($i_0 << 1) | 0;
    __label__ = 19;
    break;
   case 19:
    var $t_0;
    if (($t_0 | 0) == ($47 | 0)) {
      __label__ = 25;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    if (HEAP16[$t_0 >> 1] << 16 >> 16 == $48 << 16 >> 16) {
      var $_pn = $13;
      var $t_0_pn = $t_0;
      __label__ = 21;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 21:
    var $t_0_pn;
    var $_pn;
    var $p1_0 = $_pn + 2 | 0;
    var $t1_0 = $t_0_pn + 2 | 0;
    if (($p1_0 | 0) == ($49 | 0)) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    if (HEAP16[$t1_0 >> 1] << 16 >> 16 == HEAP16[$p1_0 >> 1] << 16 >> 16) {
      var $_pn = $p1_0;
      var $t_0_pn = $t1_0;
      __label__ = 21;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $64 = $t_0 - $6 >> 1;
    __ZN2JS5Value8setInt32Ei($vp, $64);
    var $_0 = 1;
    __label__ = 26;
    break;
   case 24:
    var $t_0 = $t_0 - 2 | 0;
    __label__ = 19;
    break;
   case 25:
    __ZN2JS5Value8setInt32Ei($vp, -1);
    var $_0 = 1;
    __label__ = 26;
    break;
   case 26:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15str_lastIndexOfP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL8str_trimP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13js_TrimStringP9JSContextPN2JS5ValueEii($cx, $vp, 1, 1);
  return $1;
}

function __ZL12str_trimLeftP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13js_TrimStringP9JSContextPN2JS5ValueEii($cx, $vp, 1, 0);
  return $1;
}

function __ZL13str_trimRightP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13js_TrimStringP9JSContextPN2JS5ValueEii($cx, $vp, 0, 1);
  return $1;
}

function __ZL21str_toLocaleLowerCaseP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 36 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$2 + 4 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = HEAP32[HEAP32[$1 >> 2] + 4 >> 2];
    var $15 = FUNCTION_TABLE[$14]($cx, $9, $vp);
    var $_0 = $15;
    __label__ = 6;
    break;
   case 5:
    var $17 = __ZL15str_toLowerCaseP9JSContextjPN2JS5ValueE($cx, 0, $vp);
    var $_0 = $17;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21str_toLocaleUpperCaseP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 36 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = HEAP32[HEAP32[$1 >> 2] >> 2];
    var $15 = FUNCTION_TABLE[$14]($cx, $9, $vp);
    var $_0 = $15;
    __label__ = 6;
    break;
   case 5:
    var $17 = __ZL15str_toUpperCaseP9JSContextjPN2JS5ValueE($cx, 0, $vp);
    var $_0 = $17;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17str_localeCompareP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2JS5Value8setInt32Ei($vp, 0);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 4:
    var $7 = $vp + 16 | 0;
    var $_idx = $7 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $8 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($cx, $_idx_val$0, $_idx_val$1);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = $cx + 36 | 0;
    var $12 = HEAP32[$11 >> 2];
    if (($12 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$12 + 8 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JS5Value9setStringEP8JSString($7, $8);
    var $21 = HEAP32[HEAP32[$11 >> 2] + 8 >> 2];
    var $22 = FUNCTION_TABLE[$21]($cx, $1, $8, $vp);
    var $_0 = $22;
    __label__ = 10;
    break;
   case 8:
    var $24 = __ZN2js14CompareStringsEP9JSContextP8JSStringS3_Pi($cx, $1, $8, $result);
    if ($24) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    var $26 = HEAP32[$result >> 2];
    __ZN2JS5Value8setInt32Ei($vp, $26);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9str_matchP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $g = __stackBase__;
    var $array = __stackBase__ + 32;
    var $rval = __stackBase__ + 48;
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_2 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN11RegExpGuardC1EP9JSContext($g, $cx);
    var $4 = __ZN11RegExpGuard4initEjPN2JS5ValueEb($g, $argc, $vp, 1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 0;
      __label__ = 12;
      break;
    }
   case 3:
    var $6 = __ZN11RegExpGuard12tryFlatMatchEP9JSContextP8JSStringjjb($g, $cx, $1, 1, $argc, 1);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZL19BuildFlatMatchArrayP9JSContextP8JSStringRK9FlatMatchPN2JS5ValueE($cx, $1, $6, $vp);
    var $_1 = $9 & 1;
    __label__ = 12;
    break;
   case 5:
    var $12 = $cx;
    var $_idx_val = HEAP32[$cx + 20 >> 2];
    var $14 = __ZN9JSContext18isExceptionPendingEv($_idx_val);
    if ($14) {
      var $_1 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = __ZN11RegExpGuard15normalizeRegExpEbjjPN2JS5ValueE($g, 0, 1, $argc, $vp);
    if (($16 | 0) == 0) {
      var $_1 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = $array;
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($19, $12, 0);
    var $20 = $array;
    var $21 = __ZN2js16AutoObjectRooter4addrEv($20);
    var $22 = __ZN9JSContext13regExpStaticsEv($12);
    var $23 = $21;
    var $24 = __ZL7DoMatchP9JSContextPN2js13RegExpStaticsEP8JSStringRK10RegExpPairPFbS0_S3_jPvES9_17MatchControlFlagsPN2JS5ValueE($cx, $22, $1, $16, 230, $23, 1, $rval);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 8:
    var $26 = __ZNK10RegExpPair2reEv($16);
    var $_idx2_val = HEAP32[$26 + 16 >> 2];
    var $27 = __ZNK2js6RegExp6globalEv($_idx2_val);
    if ($27) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $_idx1_val = HEAP32[$array + 12 >> 2];
    var $30 = __ZNK2js16AutoObjectRooter6objectEv($_idx1_val);
    var $31 = $30;
    __ZN2JS5Value15setObjectOrNullEP8JSObject($vp, $31);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 10:
    var $33 = $rval | 0;
    var $34$0 = HEAP32[$33 >> 2];
    var $34$1 = HEAP32[$33 + 4 >> 2];
    var $35 = $vp | 0;
    HEAP32[$35 >> 2] = $34$0;
    HEAP32[$35 + 4 >> 2] = $34$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    __ZN2js16AutoObjectRooterD1Ev($19);
    var $_1 = $_0;
    __label__ = 12;
    break;
   case 12:
    var $_1;
    __ZN11RegExpGuardD1Ev($g);
    var $_2 = $_1;
    __label__ = 13;
    break;
   case 13:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9str_matchP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL10str_searchP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $g = __stackBase__;
    var $i = __stackBase__ + 32;
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_1 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN11RegExpGuardC1EP9JSContext($g, $cx);
    var $4 = __ZN11RegExpGuard4initEjPN2JS5ValueEb($g, $argc, $vp, 1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 3:
    var $6 = __ZN11RegExpGuard12tryFlatMatchEP9JSContextP8JSStringjjb($g, $cx, $1, 1, $argc, 1);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx1_val = HEAP32[$6 + 12 >> 2];
    var $9 = __ZNK9FlatMatch5matchEv($_idx1_val);
    __ZN2JS5Value8setInt32Ei($vp, $9);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 5:
    var $11 = $cx;
    var $_idx_val = HEAP32[$cx + 20 >> 2];
    var $13 = __ZN9JSContext18isExceptionPendingEv($_idx_val);
    if ($13) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = __ZN11RegExpGuard15normalizeRegExpEbjjPN2JS5ValueE($g, 0, 1, $argc, $vp);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = __ZN9JSContext13regExpStaticsEv($11);
    HEAP32[$i >> 2] = 0;
    var $19 = __ZNK10RegExpPair2reEv($15);
    var $20 = __ZN2js6RegExp7executeEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE($19, $11, $18, $1, $i, 1, $vp);
    if ($20) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 8:
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $22 = __ZNK2JS5Value6isTrueEv($vp_idx_val$0, $vp_idx_val$1);
    if ($22) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $24 = __ZNK2js13RegExpStatics10matchStartEv($18);
    __ZN2JS5Value8setInt32Ei($vp, $24);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 10:
    __ZN2JS5Value8setInt32Ei($vp, -1);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    __ZN11RegExpGuardD1Ev($g);
    var $_1 = $_0;
    __label__ = 12;
    break;
   case 12:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9str_splitP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $d = __stackBase__ + 4;
    var $v = __stackBase__ + 12;
    var $2 = __stackBase__ + 20;
    var $3 = __stackBase__ + 28;
    var $4 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $cx;
    var $8 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($7, 3);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js5types4Type10StringTypeEv($1);
    var $12 = $cx;
    var $13 = $8;
    var $_05_val = HEAP32[$1 >> 2];
    __ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcNS0_4TypeE($12, $13, 0, $_05_val);
    if ($argc >>> 0 > 1) {
      __label__ = 4;
      break;
    } else {
      var $limit_0 = -1;
      __label__ = 7;
      break;
    }
   case 4:
    var $16 = $vp + 24 | 0;
    var $_idx3 = $16 | 0;
    var $st$2$0 = $_idx3 | 0;
    var $_idx3_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx3 + 4 | 0;
    var $_idx3_val$1 = HEAP32[$st$2$1 >> 2];
    var $17 = __ZNK2JS5Value11isUndefinedEv($_idx3_val$0, $_idx3_val$1);
    if ($17) {
      var $limit_01 = -1;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($7, $16, $d);
    if ($19) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 25;
      break;
    }
   case 6:
    var $21 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $22 = __Z21js_DoubleToECMAUint32d($21);
    var $limit_0 = $22;
    __label__ = 7;
    break;
   case 7:
    var $limit_0;
    if (($argc | 0) == 0) {
      var $sepstr_0 = 0;
      var $re_0 = 0;
      var $limit_024 = $limit_0;
      var $39 = 1;
      __label__ = 13;
      break;
    } else {
      var $limit_01 = $limit_0;
      __label__ = 8;
      break;
    }
   case 8:
    var $limit_01;
    var $_idx2 = $vp + 16 | 0;
    var $st$2$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$2$1 >> 2];
    var $25 = __ZNK2JS5Value11isUndefinedEv($_idx2_val$0, $_idx2_val$1);
    if ($25) {
      var $sepstr_0 = 0;
      var $re_0 = 0;
      var $limit_024 = $limit_01;
      var $39 = 1;
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $27 = $vp + 16 | 0;
    var $28 = __ZL15VALUE_IS_REGEXPP9JSContextN2JS5ValueE($_idx2_val$0, $_idx2_val$1);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $30 = __ZNK2JS5Value8toObjectEv($_idx2_val$0, $_idx2_val$1);
    var $_idx_val = HEAP32[$30 + 24 >> 2];
    var $31 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $sepstr_0 = 0;
    var $re_0 = $31;
    var $limit_024 = $limit_01;
    var $39 = 0;
    __label__ = 13;
    break;
   case 11:
    var $34 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($cx, $_idx2_val$0, $_idx2_val$1);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN2JS5Value9setStringEP8JSString($27, $34);
    var $37 = __ZN8JSString12ensureLinearEP9JSContext($34, $7);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      var $sepstr_0 = $37;
      var $re_0 = 0;
      var $limit_024 = $limit_01;
      var $39 = $25;
      __label__ = 13;
      break;
    }
   case 13:
    var $39;
    var $limit_024;
    var $re_0;
    var $sepstr_0;
    if (($limit_024 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    var $42 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($7);
    if (($42 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($42, $8);
    __ZN2JS5Value9setObjectER8JSObject($vp, $42);
    var $_0 = 1;
    __label__ = 25;
    break;
   case 16:
    if ($39) {
      __label__ = 17;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 17:
    __ZN2JSL11StringValueEP8JSString3909($v, $4);
    var $47 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($7, 1, $v);
    if (($47 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($47, $8);
    __ZN2JS5Value9setObjectER8JSObject($vp, $47);
    var $_0 = 1;
    __label__ = 25;
    break;
   case 19:
    var $51 = __ZN8JSString12ensureLinearEP9JSContext($4, $7);
    if (($51 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    if (($re_0 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $56 = __ZN9JSContext13regExpStaticsEv($7);
    __ZN18SplitRegExpMatcherC1EPN2js6RegExpEPNS0_13RegExpStaticsE($2, $re_0, $56);
    var $_07_val = HEAP32[$2 >> 2];
    var $_1_val = HEAP32[$2 + 4 >> 2];
    var $57 = __ZL11SplitHelperI18SplitRegExpMatcherEP8JSObjectP9JSContextP14JSLinearStringjT_PN2js5types10TypeObjectE($cx, $51, $limit_024, $_07_val, $_1_val, $9);
    var $aobj2_0 = $57;
    __label__ = 23;
    break;
   case 22:
    __ZN18SplitStringMatcherC1EP14JSLinearString($3, $sepstr_0);
    var $_08_val = HEAP32[$3 >> 2];
    var $_19_val = HEAP32[$3 + 4 >> 2];
    var $59 = __ZL11SplitHelperI18SplitStringMatcherEP8JSObjectP9JSContextP14JSLinearStringjT_PN2js5types10TypeObjectE($cx, $51, $limit_024, $_08_val, $_19_val);
    var $aobj2_0 = $59;
    __label__ = 23;
    break;
   case 23:
    var $aobj2_0;
    if (($aobj2_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $63 = $aobj2_0;
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($63, $8);
    __ZN2JS5Value9setObjectER8JSObject($vp, $63);
    var $_0 = 1;
    __label__ = 25;
    break;
   case 25:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9str_splitP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE8capacityEv($this_0_3_val) {
  return $this_0_3_val;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE5clearEv($this) {
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZL10str_substrP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $begin = __stackBase__ + 4;
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($argc | 0) == 0) {
      var $str_0 = $1;
      __label__ = 18;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx1_val = HEAP32[$1 >> 2];
    var $6 = __ZNK8JSString6lengthEv($_idx1_val);
    var $7 = $vp + 16 | 0;
    var $8 = __Z19ValueToIntegerRangeP9JSContextRKN2JS5ValueEPi($cx, $7, $begin);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 4:
    var $10 = HEAP32[$begin >> 2];
    if (($10 | 0) < ($6 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $str_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 18;
    break;
   case 6:
    if (($10 | 0) < 0) {
      __label__ = 7;
      break;
    } else {
      var $25 = $10;
      __label__ = 9;
      break;
    }
   case 7:
    var $21 = $10 + $6 | 0;
    HEAP32[$begin >> 2] = $21;
    if (($21 | 0) < 0) {
      __label__ = 8;
      break;
    } else {
      var $25 = $21;
      __label__ = 9;
      break;
    }
   case 8:
    HEAP32[$begin >> 2] = 0;
    var $25 = 0;
    __label__ = 9;
    break;
   case 9:
    var $25;
    if (($argc | 0) == 1) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $28 = $vp + 24 | 0;
    var $_idx = $28 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $29 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($29) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $31 = $6 - $25 | 0;
    HEAP32[$len >> 2] = $31;
    var $49 = $31;
    __label__ = 17;
    break;
   case 12:
    var $33 = __Z19ValueToIntegerRangeP9JSContextRKN2JS5ValueEPi($cx, $28, $len);
    if ($33) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 13:
    var $35 = HEAPU32[$len >> 2];
    if (($35 | 0) < 1) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $str_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 18;
    break;
   case 15:
    if ($6 >>> 0 < ($25 + $35 | 0) >>> 0) {
      __label__ = 16;
      break;
    } else {
      var $49 = $35;
      __label__ = 17;
      break;
    }
   case 16:
    var $47 = $6 - $25 | 0;
    HEAP32[$len >> 2] = $47;
    var $49 = $47;
    __label__ = 17;
    break;
   case 17:
    var $49;
    var $50 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $1, $25, $49);
    var $51 = $50 | 0;
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      var $str_0 = $51;
      __label__ = 18;
      break;
    }
   case 18:
    var $str_0;
    __ZN2JS5Value9setStringEP8JSString($vp, $str_0);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10str_substrP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL10str_concatP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $i_0 = 0;
    var $str_0 = $2;
    __label__ = 3;
    break;
   case 3:
    var $str_0;
    var $i_0;
    if ($i_0 >>> 0 < $argc >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $_idx = $vp + ($i_0 + 2 << 3) | 0;
    var $st$2$0 = $_idx | 0;
    var $_idx_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAP32[$st$2$1 >> 2];
    var $8 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($cx, $_idx_val$0, $_idx_val$1);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($4, $str_0, $8);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $i_0 = $i_0 + 1 | 0;
    var $str_0 = $11;
    __label__ = 3;
    break;
   case 7:
    __ZN2JSL11StringValueEP8JSString3909($1, $str_0);
    var $16 = $1 | 0;
    var $st$2$0 = $16 | 0;
    var $17$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $16 + 4 | 0;
    var $17$1 = HEAP32[$st$2$1 >> 2];
    var $18 = $vp | 0;
    HEAP32[$18 >> 2] = $17$0;
    HEAP32[$18 + 4 >> 2] = $17$1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9str_sliceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $begin2 = __stackBase__;
    var $end3 = __stackBase__ + 8;
    var $1 = ($argc | 0) == 1;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    var $_idx5 = $vp + 8 | 0;
    var $st$1$0 = $_idx5 | 0;
    var $_idx5_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx5 + 4 | 0;
    var $_idx5_val$1 = HEAP32[$st$1$1 >> 2];
    var $3 = __ZNK2JS5Value8isStringEv($_idx5_val$0, $_idx5_val$1);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 3:
    var $_idx6 = $vp + 16 | 0;
    var $st$1$0 = $_idx6 | 0;
    var $_idx6_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx6 + 4 | 0;
    var $_idx6_val$1 = HEAP32[$st$1$1 >> 2];
    var $5 = __ZNK2JS5Value7isInt32Ev($_idx6_val$0, $_idx6_val$1);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 4:
    var $7 = __ZNK2JS5Value8toStringEv($_idx5_val$0, $_idx5_val$1);
    var $8 = __ZNK2JS5Value7toInt32Ev($_idx6_val$0, $_idx6_val$1);
    var $_idx3_val = HEAP32[$7 >> 2];
    var $9 = __ZNK8JSString6lengthEv($_idx3_val);
    if ($8 >>> 0 > $9 >>> 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $9 - $8 | 0;
    if (($9 | 0) == ($8 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $str_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 11;
    break;
   case 7:
    if (($12 | 0) == 1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $25 = HEAP32[$cx + 52 >> 2] + 210584 | 0;
    var $26 = $cx;
    var $27 = __ZN2js13StaticStrings23getUnitStringForElementEP9JSContextP8JSStringj($25, $26, $7, $8);
    var $31 = $27;
    __label__ = 10;
    break;
   case 9:
    var $29 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $7, $8, $12);
    var $31 = $29;
    __label__ = 10;
    break;
   case 10:
    var $31;
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      var $str_0 = $31 | 0;
      __label__ = 11;
      break;
    }
   case 11:
    var $str_0;
    __ZN2JS5Value9setStringEP8JSString($vp, $str_0);
    var $_0 = 1;
    __label__ = 33;
    break;
   case 12:
    var $36 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if (($argc | 0) == 0) {
      var $str1_0 = $36;
      __label__ = 32;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $41 = $vp + 16 | 0;
    var $42 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd3824($cx, $41, $begin2);
    if ($42) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 33;
      break;
    }
   case 15:
    var $_idx2_val = HEAP32[$36 >> 2];
    var $44 = __ZNK8JSString6lengthEv($_idx2_val);
    var $45 = $44 >>> 0;
    var $46 = (tempDoubleI32[0] = HEAP32[$begin2 >> 2], tempDoubleI32[1] = HEAP32[$begin2 + 4 >> 2], tempDoubleF64[0]);
    if ($46 < 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 16:
    var $49 = $46 + $45;
    tempDoubleF64[0] = $49, HEAP32[$begin2 >> 2] = tempDoubleI32[0], HEAP32[$begin2 + 4 >> 2] = tempDoubleI32[1];
    if ($49 < 0) {
      __label__ = 17;
      break;
    } else {
      var $56 = $49;
      __label__ = 20;
      break;
    }
   case 17:
    tempDoubleF64[0] = 0, HEAP32[$begin2 >> 2] = tempDoubleI32[0], HEAP32[$begin2 + 4 >> 2] = tempDoubleI32[1];
    var $56 = 0;
    __label__ = 20;
    break;
   case 18:
    if ($46 > $45) {
      __label__ = 19;
      break;
    } else {
      var $56 = $46;
      __label__ = 20;
      break;
    }
   case 19:
    tempDoubleF64[0] = $45, HEAP32[$begin2 >> 2] = tempDoubleI32[0], HEAP32[$begin2 + 4 >> 2] = tempDoubleI32[1];
    var $56 = $45;
    __label__ = 20;
    break;
   case 20:
    var $56;
    if ($1) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $58 = $vp + 24 | 0;
    var $_idx1 = $58 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $59 = __ZNK2JS5Value11isUndefinedEv($_idx1_val$0, $_idx1_val$1);
    if ($59) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    tempDoubleF64[0] = $45, HEAP32[$end3 >> 2] = tempDoubleI32[0], HEAP32[$end3 + 4 >> 2] = tempDoubleI32[1];
    var $78 = $45;
    __label__ = 31;
    break;
   case 23:
    var $62 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd3824($cx, $58, $end3);
    if ($62) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 0;
      __label__ = 33;
      break;
    }
   case 24:
    var $64 = (tempDoubleI32[0] = HEAP32[$end3 >> 2], tempDoubleI32[1] = HEAP32[$end3 + 4 >> 2], tempDoubleF64[0]);
    if ($64 < 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 25:
    var $67 = $64 + $45;
    tempDoubleF64[0] = $67, HEAP32[$end3 >> 2] = tempDoubleI32[0], HEAP32[$end3 + 4 >> 2] = tempDoubleI32[1];
    if ($67 < 0) {
      __label__ = 26;
      break;
    } else {
      var $74 = $67;
      __label__ = 29;
      break;
    }
   case 26:
    tempDoubleF64[0] = 0, HEAP32[$end3 >> 2] = tempDoubleI32[0], HEAP32[$end3 + 4 >> 2] = tempDoubleI32[1];
    var $74 = 0;
    __label__ = 29;
    break;
   case 27:
    if ($64 > $45) {
      __label__ = 28;
      break;
    } else {
      var $74 = $64;
      __label__ = 29;
      break;
    }
   case 28:
    tempDoubleF64[0] = $45, HEAP32[$end3 >> 2] = tempDoubleI32[0], HEAP32[$end3 + 4 >> 2] = tempDoubleI32[1];
    var $74 = $45;
    __label__ = 29;
    break;
   case 29:
    var $74;
    if ($74 < $56) {
      __label__ = 30;
      break;
    } else {
      var $78 = $74;
      __label__ = 31;
      break;
    }
   case 30:
    tempDoubleF64[0] = $56, HEAP32[$end3 >> 2] = tempDoubleI32[0], HEAP32[$end3 + 4 >> 2] = tempDoubleI32[1];
    var $78 = $56;
    __label__ = 31;
    break;
   case 31:
    var $78;
    var $79 = $56 >= 0 ? Math.floor($56) : Math.ceil($56);
    var $80 = $78 - $56;
    var $81 = $80 >= 0 ? Math.floor($80) : Math.ceil($80);
    var $82 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $36, $79, $81);
    var $83 = $82 | 0;
    if (($82 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      var $str1_0 = $83;
      __label__ = 32;
      break;
    }
   case 32:
    var $str1_0;
    __ZN2JS5Value9setStringEP8JSString($vp, $str1_0);
    var $_0 = 1;
    __label__ = 33;
    break;
   case 33:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9str_sliceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL8str_boldP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE($cx, STRING_TABLE.__str463815 | 0, 0, 0, $vp);
  return $1 & 1;
}

function __ZL11str_italicsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE($cx, STRING_TABLE.__str453814 | 0, 0, 0, $vp);
  return $1 & 1;
}

function __ZL9str_fixedP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE($cx, STRING_TABLE.__str443813 | 0, 0, 0, $vp);
  return $1 & 1;
}

function __ZL12str_fontsizeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL12tagify_valueP9JSContextjPN2JS5ValueEPKcS5_($cx, $argc, $vp, STRING_TABLE.__str433812 | 0, STRING_TABLE.__str423811 | 0);
  return $1;
}

function __ZL13str_fontcolorP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL12tagify_valueP9JSContextjPN2JS5ValueEPKcS5_($cx, $argc, $vp, STRING_TABLE.__str413810 | 0, STRING_TABLE.__str423811 | 0);
  return $1;
}

function __ZL8str_linkP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL12tagify_valueP9JSContextjPN2JS5ValueEPKcS5_($cx, $argc, $vp, STRING_TABLE.__str403809 | 0, STRING_TABLE.__str494295 | 0);
  return $1;
}

function __ZL10str_anchorP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL12tagify_valueP9JSContextjPN2JS5ValueEPKcS5_($cx, $argc, $vp, STRING_TABLE.__str383807 | 0, STRING_TABLE.__str494295 | 0);
  return $1;
}

function __ZL10str_strikeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE($cx, STRING_TABLE.__str283791 | 0, 0, 0, $vp);
  return $1 & 1;
}

function __ZL9str_smallP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE($cx, STRING_TABLE.__str293792 | 0, 0, 0, $vp);
  return $1 & 1;
}

function __ZL7str_bigP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE($cx, STRING_TABLE.__str303793 | 0, 0, 0, $vp);
  return $1 & 1;
}

function __ZL9str_blinkP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE($cx, STRING_TABLE.__str313794 | 0, 0, 0, $vp);
  return $1 & 1;
}

function __ZL7str_supP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE($cx, STRING_TABLE.__str323795 | 0, 0, 0, $vp);
  return $1 & 1;
}

function __ZL7str_subP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE($cx, STRING_TABLE.__str333796 | 0, 0, 0, $vp);
  return $1 & 1;
}

function __Z9js_StringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx = $vp + 16 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $3 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($cx, $_idx_val$0, $_idx_val$1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      var $str_0 = $3;
      __label__ = 4;
      break;
    }
   case 3:
    var $str_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 4;
    break;
   case 4:
    var $str_0;
    var $12 = __ZN2jsL14IsConstructingEPKN2JS5ValueE3833($vp);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $14 = $cx;
    var $15 = __ZN2js12StringObject6createEP9JSContextP8JSString($14, $str_0);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = $15;
    __ZN2JS5Value9setObjectER8JSObject($vp, $18);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 7:
    __ZN2JS5Value9setStringEP8JSString($vp, $str_0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($cx, $arg_0_0_0_val$0, $arg_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $v | 0;
    HEAP32[$1 >> 2] = $arg_0_0_0_val$0;
    HEAP32[$1 + 4 >> 2] = $arg_0_0_0_val$1;
    var $2 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE3862($cx, $v);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 2:
    var $v_idx3_val$0 = HEAPU32[$1 >> 2];
    var $v_idx3_val$1 = HEAPU32[$1 + 4 >> 2];
    var $4 = __ZNK2JS5Value8isStringEv($v_idx3_val$0, $v_idx3_val$1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZNK2JS5Value8toStringEv($v_idx3_val$0, $v_idx3_val$1);
    var $_0 = $6;
    __label__ = 13;
    break;
   case 4:
    var $8 = __ZNK2JS5Value7isInt32Ev($v_idx3_val$0, $v_idx3_val$1);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $10 = __ZNK2JS5Value7toInt32Ev($v_idx3_val$0, $v_idx3_val$1);
    var $11 = $cx;
    var $12 = __Z14js_IntToStringP9JSContexti($11, $10);
    var $_0 = $12;
    __label__ = 13;
    break;
   case 6:
    var $14 = __ZNK2JS5Value8isDoubleEv($v_idx3_val$0, $v_idx3_val$1);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $16 = __ZNK2JS5Value8toDoubleEv($v);
    var $17 = $cx;
    var $18 = __Z17js_NumberToStringP9JSContextd($17, $16);
    var $_0 = $18;
    __label__ = 13;
    break;
   case 8:
    var $20 = __ZNK2JS5Value9isBooleanEv($v_idx3_val$0, $v_idx3_val$1);
    if ($20) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $22 = __ZNK2JS5Value9toBooleanEv($v_idx3_val$0, $v_idx3_val$1);
    var $23 = $22 & 1;
    var $_idx_val = HEAP32[$cx + 52 >> 2];
    var $25 = __Z18js_BooleanToStringP9JSContexti($_idx_val, $23);
    var $_0 = $25;
    __label__ = 13;
    break;
   case 10:
    var $27 = __ZNK2JS5Value6isNullEv($v_idx3_val$0, $v_idx3_val$1);
    var $29 = HEAP32[$cx + 52 >> 2];
    if ($27) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $_0 = HEAP32[$29 + 210016 >> 2] | 0;
    __label__ = 13;
    break;
   case 12:
    var $_0 = HEAP32[$29 + 209984 >> 2] | 0;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z16js_ValueToStringP9JSContextRKN2JS5ValueE["X"] = 1;

function __ZN2jsL14IsConstructingEPKN2JS5ValueE3833($vp) {
  var $_idx = $vp + 8 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $1 = __ZNK2JS5Value7isMagicEv($_idx_val$0, $_idx_val$1);
  return $1;
}

function __ZL16str_fromCharCodeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $code = __stackBase__;
    var $code1 = __stackBase__ + 4;
    var $1 = $vp + 16 | 0;
    var $3 = $cx;
    if (($argc | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      var $_pre_phi = $3;
      __label__ = 6;
      break;
    }
   case 2:
    var $5 = __ZN2js13ValueToUint16EP9JSContextRKN2JS5ValueEPt($3, $1, $code);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 3:
    var $7 = HEAPU16[$code >> 1];
    var $8 = __ZN2js13StaticStrings7hasUnitEt($7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $12 = HEAP32[$cx + 52 >> 2] + 210584 | 0;
    var $13 = __ZN2js13StaticStrings7getUnitEt($12, $7);
    var $14 = $13 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $14);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 5:
    var $16 = $7 & 65535;
    __ZN2JS5Value8setInt32Ei($1, $16);
    var $_pre_phi = $3;
    __label__ = 6;
    break;
   case 6:
    var $_pre_phi;
    var $18 = ($argc << 1) + 2 | 0;
    var $19 = __ZN9JSContext7malloc_Ej($_pre_phi, $18);
    var $20 = $19;
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      var $i_0 = 0;
      __label__ = 7;
      break;
    }
   case 7:
    var $i_0;
    if ($i_0 >>> 0 < $argc >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $24 = $vp + ($i_0 + 2 << 3) | 0;
    var $25 = __ZN2js13ValueToUint16EP9JSContextRKN2JS5ValueEPt($_pre_phi, $24, $code1);
    if ($25) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN9JSContext5free_EPv($19);
    var $_0 = 0;
    __label__ = 14;
    break;
   case 10:
    var $28 = HEAP16[$code1 >> 1];
    HEAP16[$20 + ($i_0 << 1) >> 1] = $28;
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 7;
    break;
   case 11:
    HEAP16[$20 + ($argc << 1) >> 1] = 0;
    var $33 = __Z12js_NewStringP9JSContextPtj($cx, $20, $argc);
    if (($33 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    __ZN9JSContext5free_EPv($19);
    var $_0 = 0;
    __label__ = 14;
    break;
   case 13:
    var $37 = $33 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $37);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16str_fromCharCodeP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2js12StringObject18assignInitialShapeEP9JSContext($this, $cx) {
  var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
  var $6 = __ZL12ATOM_TO_JSIDP6JSAtom3836($5);
  var $7 = $this;
  var $8 = $cx;
  var $9 = __ZN8JSObject15addDataPropertyEP9JSContextijj($7, $8, $6, 1, 6);
  return $9;
}

function __ZL12ATOM_TO_JSIDP6JSAtom3836($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj3911($1);
  return $2;
}

function __Z18js_InitStringClassP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $obj;
    var $3 = __ZN8JSObject8asGlobalEv($2);
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js11StringClassE);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $5;
    var $10 = __ZN8JSObject8asStringEv($9);
    var $11 = $cx + 52 | 0;
    var $15 = HEAP32[HEAP32[$11 >> 2] + 144136 >> 2] | 0;
    var $16 = $cx;
    var $17 = __ZN2js12StringObject4initEP9JSContextP8JSString($10, $16, $15);
    if ($17) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $22 = HEAP32[HEAP32[$11 >> 2] + 210056 >> 2];
    var $23 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 232, __ZN2js11StringClassE, $22, 1);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $23 | 0;
    var $27 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $26, $5);
    if ($27) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 5:
    var $29 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, 0, __ZL14string_methods);
    if ($29) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $31 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $26, 0, __ZL21string_static_methods);
    if ($31) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    var $33 = $5;
    var $34 = $cx;
    var $35 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($33, $34, 0, 0);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2js5types4Type9Int32TypeEv($1);
    var $38 = $cx;
    var $39 = $35;
    var $_01_val = HEAP32[$1 >> 2];
    __ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcNS0_4TypeE($38, $39, STRING_TABLE.__str353798 | 0, $_01_val);
    var $40 = $3;
    var $41 = $23;
    var $42 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($34, $40, 9, $41, $33);
    if ($42) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    var $44 = $3;
    var $45 = _JS_DefineFunctions($34, $44, __ZL16string_functions);
    var $_ = ($45 | 0) == 0 ? 0 : $6;
    var $_0 = $_;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18js_InitStringClassP9JSContextP8JSObject["X"] = 1;

function __ZN2jsL17CheckStringLengthEP9JSContextj3839($cx, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 268435455) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $cx;
    __Z27js_ReportAllocationOverflowP9JSContext($3);
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSFixedString4new_EP9JSContextPKtj($cx, $chars, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __Z14js_NewGCStringP9JSContext($1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN13JSFixedString4initEPKtj($3, $chars, $length);
    var $_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer16extractWellSizedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_idx1_val = HEAP32[$this + 12 >> 2];
    var $2 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE8capacityEv($_idx1_val);
    var $_idx_val = HEAP32[$this + 8 >> 2];
    var $4 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv($_idx_val);
    var $5 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16extractRawBufferEv($1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($4 >>> 0 > 32) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $5;
      __label__ = 7;
      break;
    }
   case 3:
    if (($2 - $4 | 0) >>> 0 > $4 >>> 2 >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $5;
      __label__ = 7;
      break;
    }
   case 4:
    var $15 = ($4 << 1) + 2 | 0;
    var $16 = $this;
    var $17 = __ZNK2js12StringBuffer7contextEv($16);
    var $18 = $5;
    var $19 = __ZN9JSContext8realloc_EPvj($17, $18, $15);
    if (($19 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN9JSContext5free_EPv($18);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $_0 = $19;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16extractRawBufferEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE18usingInlineStorageEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = $this + 8 | 0;
    var $6 = HEAP32[$4 >> 2] << 1;
    var $_idx_val = HEAP32[$this >> 2];
    var $7 = __ZN2js18ContextAllocPolicy7malloc_Ej($_idx_val, $6);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx1_val = HEAP32[$this + 4 >> 2];
    var $12 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE12beginNoCheckEv($_idx1_val);
    var $_idx3_val = HEAP32[$4 >> 2];
    var $13 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10endNoCheckEv($_idx1_val, $_idx3_val);
    __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_($8, $12, $13);
    HEAP32[$4 >> 2] = 0;
    var $_0 = $8;
    __label__ = 5;
    break;
   case 4:
    var $15 = $this + 4 | 0;
    var $16 = HEAP32[$15 >> 2];
    var $17 = $this + 16 | 0;
    var $18 = __ZN7mozilla14AlignedStorageILj64EE4addrEv($17);
    HEAP32[$15 >> 2] = $18;
    HEAP32[$this + 8 >> 2] = 0;
    HEAP32[$this + 12 >> 2] = 32;
    var $_0 = $16;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer12finishStringEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js12StringBuffer7contextEv($1);
    var $3 = $2;
    var $4 = $this | 0;
    var $_idx_val = HEAP32[$this + 8 >> 2];
    var $6 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE5emptyEv($_idx_val);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = HEAP32[HEAP32[$2 + 52 >> 2] + 209972 >> 2] | 0;
    __label__ = 10;
    break;
   case 3:
    var $14 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv($_idx_val);
    var $15 = __ZN2js12StringBuffer11checkLengthEj($1, $14);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 4:
    var $17 = __ZN13JSShortString10lengthFitsEj($14);
    if ($17) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $_idx2_val = HEAP32[$this + 4 >> 2];
    var $20 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE5beginEv($_idx2_val);
    var $21 = __ZL14NewShortStringP9JSContextPKtj($3, $20, $14);
    var $_0 = $21;
    __label__ = 10;
    break;
   case 6:
    var $23 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendIcEEbT_($4);
    if ($23) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    var $25 = __ZN2js12StringBuffer16extractWellSizedEv($this);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $28 = __Z12js_NewStringP9JSContextPtj($3, $25, $14);
    if (($28 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $_0 = $28;
      __label__ = 10;
      break;
    }
   case 9:
    var $31 = $25;
    __ZN9JSContext5free_EPv($31);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14NewShortStringP9JSContextPKtj($cx, $chars, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN14JSInlineString10lengthFitsEj($length);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN14JSInlineString4new_EP9JSContext($cx);
    var $8 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN13JSShortString4new_EP9JSContext($cx);
    var $8 = $5 | 0;
    __label__ = 4;
    break;
   case 4:
    var $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZN14JSInlineString4initEj($8, $length);
    __ZN2jsL7PodCopyItEEvPT_PKS1_j3900($11, $chars, $length);
    HEAP16[$11 + ($length << 1) >> 1] = 0;
    var $_0 = $8 | 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendIcEEbT_($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $this;
    var $8 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE13growStorageByEj($7, 1);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendIcEEvT_($this);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer10finishAtomEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js12StringBuffer7contextEv($1);
    var $_idx_val = HEAP32[$this + 8 >> 2];
    var $4 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv($_idx_val);
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = HEAP32[HEAP32[$2 + 52 >> 2] + 209972 >> 2] | 0;
    __label__ = 4;
    break;
   case 3:
    var $13 = $this | 0;
    var $_idx1_val = HEAP32[$this + 4 >> 2];
    var $15 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE5beginEv($_idx1_val);
    var $16 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($2, $15, $4, 0);
    __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE5clearEv($13);
    var $_0 = $16;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $baseArg, $start, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($length | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 9;
    break;
   case 3:
    var $9 = $cx;
    var $10 = __ZN8JSString12ensureLinearEP9JSContext($baseArg, $9);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($start | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $_idx_val = HEAP32[$10 >> 2];
    var $15 = __ZNK8JSString6lengthEv($_idx_val);
    if (($15 | 0) == ($length | 0)) {
      var $_0 = $10;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx1_val = HEAP32[$10 + 4 >> 2];
    var $18 = __ZNK14JSLinearString5charsEv($_idx1_val);
    var $19 = $18 + ($start << 1) | 0;
    var $22 = HEAP32[$cx + 52 >> 2] + 210584 | 0;
    var $23 = __ZN2js13StaticStrings6lookupEPKtj($22, $19, $length);
    if (($23 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_0 = $23 | 0;
    __label__ = 9;
    break;
   case 8:
    var $28 = __ZN17JSDependentString4new_EP9JSContextP14JSLinearStringPKtj($cx, $10, $19, $length);
    var $_0 = $28 | 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSDOUBLE_IS_NEGZERO3865($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d != 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $_0 = tempDoubleI32[1] >>> 31 | 0 << 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z9js_strlenPKt($s) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAP16[$s >> 1] << 16 >> 16 == 0) {
      var $t_0_lcssa = $s;
      __label__ = 3;
      break;
    } else {
      var $t_01 = $s;
      __label__ = 2;
      break;
    }
   case 2:
    var $t_01;
    var $3 = $t_01 + 2 | 0;
    if (HEAP16[$3 >> 1] << 16 >> 16 == 0) {
      var $t_0_lcssa = $3;
      __label__ = 3;
      break;
    } else {
      var $t_01 = $3;
      __label__ = 2;
      break;
    }
   case 3:
    var $t_0_lcssa;
    return $t_0_lcssa - $s >> 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z9js_strchrPKtt($s, $c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $s;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $2 = HEAP16[$_01 >> 1];
    if ($2 << 16 >> 16 == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($2 << 16 >> 16 == $c << 16 >> 16) {
      var $_0 = $_01;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_01 = $_01 + 2 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN17JSDependentString4new_EP9JSContextP14JSLinearStringPKtj($cx, $base, $chars, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx1_val = HEAP32[$base >> 2];
    var $1 = __ZNK8JSString11isDependentEv($_idx1_val);
    if ($1) {
      var $_pn = $base;
      __label__ = 2;
      break;
    } else {
      var $_01_lcssa = $base;
      __label__ = 3;
      break;
    }
   case 2:
    var $_pn;
    var $3 = __ZN8JSString11asDependentEv($_pn | 0);
    var $_idx2_val = HEAP32[$3 + 8 >> 2];
    var $4 = __ZNK17JSDependentString4baseEv($_idx2_val);
    var $_idx_val = HEAP32[$4 >> 2];
    var $5 = __ZNK8JSString11isDependentEv($_idx_val);
    if ($5) {
      var $_pn = $4;
      __label__ = 2;
      break;
    } else {
      var $_01_lcssa = $4;
      __label__ = 3;
      break;
    }
   case 3:
    var $_01_lcssa;
    var $6 = $cx;
    var $7 = __Z14js_NewGCStringP9JSContext($6);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN17JSDependentString4initEP14JSLinearStringPKtj($8, $_01_lcssa, $chars, $length);
    var $_0 = $8;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_NewStringCopyNP9JSContextPKtj($cx, $s, $n) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN13JSShortString10lengthFitsEj($n);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZL14NewShortStringP9JSContextPKtj($cx, $s, $n);
    var $_0 = $3;
    __label__ = 6;
    break;
   case 3:
    var $5 = $n << 1;
    var $6 = $5 + 2 | 0;
    var $7 = $cx;
    var $8 = __ZN9JSContext7malloc_Ej($7, $6);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $s;
    _memcpy($8, $12, $5, 1);
    HEAP16[$9 + ($n << 1) >> 1] = 0;
    var $14 = __Z12js_NewStringP9JSContextPtj($cx, $9, $n);
    if (($14 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $14;
      __label__ = 6;
      break;
    }
   case 5:
    __ZN9JSContext5free_EPv($8);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_NewStringCopyNP9JSContextPKcj($cx, $s, $n) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $n;
    var $2 = __ZN13JSShortString10lengthFitsEj($n);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZL14NewShortStringP9JSContextPKcj($cx, $s, $n);
    var $_0 = $4 | 0;
    __label__ = 6;
    break;
   case 3:
    var $7 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($cx, $s, $1, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = HEAP32[$1 >> 2];
    var $11 = __Z12js_NewStringP9JSContextPtj($cx, $7, $10);
    if (($11 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $11;
      __label__ = 6;
      break;
    }
   case 5:
    var $14 = $7;
    __ZN9JSContext5free_EPv($14);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14NewShortStringP9JSContextPKcj($cx, $chars, $length) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $length;
    var $2 = __ZN14JSInlineString10lengthFitsEj($length);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN14JSInlineString4new_EP9JSContext($cx);
    var $9 = $4;
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN13JSShortString4new_EP9JSContext($cx);
    var $9 = $6 | 0;
    __label__ = 4;
    break;
   case 4:
    var $9;
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = __ZN14JSInlineString4initEj($9, $length);
    if (HEAPU8[_js_CStringsAreUTF8_b]) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($length | 0) == 0) {
      var $p_0_lcssa = $12;
      __label__ = 11;
      break;
    } else {
      var $n_02 = $length;
      var $_013 = $chars;
      var $p_04 = $12;
      __label__ = 9;
      break;
    }
   case 7:
    var $15 = __ZN2js25InflateUTF8StringToBufferEP9JSContextPKcjPtPjNS_13FlationCodingE($cx, $chars, $length, $12, $1, 0);
    if ($15) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 8:
    var $17 = HEAP32[$1 >> 2];
    HEAP16[$12 + ($17 << 1) >> 1] = 0;
    __ZN14JSInlineString11resetLengthEj($9, $17);
    var $_0 = $9;
    __label__ = 12;
    break;
   case 9:
    var $p_04;
    var $_013;
    var $n_02;
    var $19 = $n_02 - 1 | 0;
    HEAP16[$p_04 >> 1] = HEAPU8[$_013] & 255;
    if (($19 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $n_02 = $19;
      var $_013 = $_013 + 1 | 0;
      var $p_04 = $p_04 + 2 | 0;
      __label__ = 9;
      break;
    }
   case 10:
    var $p_0_lcssa = $12 + ($length << 1) | 0;
    __label__ = 11;
    break;
   case 11:
    var $p_0_lcssa;
    HEAP16[$p_0_lcssa >> 1] = 0;
    var $_0 = $9;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($cx, $bytes, $lengthp, $fc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nchars = __stackBase__;
    var $1 = HEAPU32[$lengthp >> 2];
    if (HEAPU8[_js_CStringsAreUTF8_b] | ($fc | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = __ZN2js25InflateUTF8StringToBufferEP9JSContextPKcjPtPjNS_13FlationCodingE($cx, $bytes, $1, 0, $nchars, $fc);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 3:
    var $8 = (HEAP32[$nchars >> 2] << 1) + 2 | 0;
    var $9 = $cx;
    var $10 = __ZN9JSContext7malloc_Ej($9, $8);
    var $11 = $10;
    if (($10 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = __ZN2js25InflateUTF8StringToBufferEP9JSContextPKcjPtPjNS_13FlationCodingE($cx, $bytes, $1, $11, $nchars, $fc);
    var $chars_0 = $11;
    var $29 = HEAP32[$nchars >> 2];
    __label__ = 8;
    break;
   case 5:
    HEAP32[$nchars >> 2] = $1;
    var $17 = ($1 << 1) + 2 | 0;
    var $18 = $cx;
    var $19 = __ZN9JSContext7malloc_Ej($18, $17);
    var $20 = $19;
    if (($19 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($1 | 0) == 0) {
      var $chars_0 = $20;
      var $29 = $1;
      __label__ = 8;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 7;
      break;
    }
   case 7:
    var $i_01;
    HEAP16[$20 + ($i_01 << 1) >> 1] = HEAPU8[$bytes + $i_01 | 0] & 255;
    var $27 = $i_01 + 1 | 0;
    if ($27 >>> 0 < $1 >>> 0) {
      var $i_01 = $27;
      __label__ = 7;
      break;
    } else {
      var $chars_0 = $20;
      var $29 = $1;
      __label__ = 8;
      break;
    }
   case 8:
    var $29;
    var $chars_0;
    HEAP32[$lengthp >> 2] = $29;
    HEAP16[$chars_0 + ($29 << 1) >> 1] = 0;
    var $_0 = $chars_0;
    __label__ = 10;
    break;
   case 9:
    HEAP32[$lengthp >> 2] = 0;
    var $_0 = 0;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_NewStringCopyZP9JSContextPKc($cx, $s) {
  var $1 = _strlen($s);
  var $2 = __Z17js_NewStringCopyNP9JSContextPKcj($cx, $s, $1);
  return $2;
}

function __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($cx, $v_0_0_0_val$0, $v_0_0_0_val$1, $bytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($cx, $v_0_0_0_val$0, $v_0_0_0_val$1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = _js_QuoteString($4, $1, 0);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $bytes;
    var $9 = __ZN16JSAutoByteString6encodeEP9JSContextP8JSString($8, $4, $5);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_ValueToSourceP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $rval = __stackBase__ + 4;
    var $fval = __stackBase__ + 12;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx;
    __Z21js_ReportOverRecursedP9JSContext($6);
    var $_0 = 0;
    __label__ = 16;
    break;
   case 3:
    var $v_idx1 = $v | 0;
    var $st$1$0 = $v_idx1 | 0;
    var $v_idx1_val$0 = HEAPU32[$st$1$0 >> 2];
    var $st$1$1 = $v_idx1 + 4 | 0;
    var $v_idx1_val$1 = HEAPU32[$st$1$1 >> 2];
    var $8 = __ZNK2JS5Value11isUndefinedEv($v_idx1_val$0, $v_idx1_val$1);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 210340 >> 2] | 0;
    __label__ = 16;
    break;
   case 5:
    var $16 = __ZNK2JS5Value8isStringEv($v_idx1_val$0, $v_idx1_val$1);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $18 = __ZNK2JS5Value8toStringEv($v_idx1_val$0, $v_idx1_val$1);
    var $19 = $cx;
    var $20 = _js_QuoteString($19, $18, 34);
    var $_0 = $20;
    __label__ = 16;
    break;
   case 7:
    var $22 = __ZNK2JS5Value11isPrimitiveEv($v_idx1_val$0, $v_idx1_val$1);
    if ($22) {
      __label__ = 8;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 8:
    var $24 = __ZNK2JS5Value8isDoubleEv($v_idx1_val$0, $v_idx1_val$1);
    if ($24) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $26 = __ZNK2JS5Value8toDoubleEv($v);
    var $27 = _JSDOUBLE_IS_NEGZERO3865($26);
    if (($27 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $30 = __Z17js_NewStringCopyNP9JSContextPKtj($cx, __ZZ16js_ValueToSourceP9JSContextRKN2JS5ValueEE17js_negzero_ucNstr | 0, 2);
    var $_0 = $30 | 0;
    __label__ = 16;
    break;
   case 11:
    var $33 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($cx, $v_idx1_val$0, $v_idx1_val$1);
    var $_0 = $33;
    __label__ = 16;
    break;
   case 12:
    __ZN2JSL9NullValueEv3866($rval);
    var $39 = HEAP32[HEAP32[$cx + 52 >> 2] + 210320 >> 2] | 0;
    var $40 = __ZL12ATOM_TO_JSIDP6JSAtom3836($39);
    var $v_idx_val$0 = HEAP32[$v_idx1 >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx1 + 4 >> 2];
    var $41 = __ZNK2JS5Value8toObjectEv($v_idx_val$0, $v_idx_val$1);
    var $42 = $cx;
    var $43 = $41;
    var $44 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($42, $43, $40, 2, $fval);
    if (($44 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $fval_idx = $fval | 0;
    var $st$1$0 = $fval_idx | 0;
    var $fval_idx_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $fval_idx + 4 | 0;
    var $fval_idx_val$1 = HEAP32[$st$1$1 >> 2];
    var $47 = __ZL13js_IsCallableRKN2JS5ValueE3827($fval_idx_val$0, $fval_idx_val$1);
    if ($47) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $49 = $cx;
    var $50 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($49, $v, $fval, 0, 0, $rval);
    if ($50) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 15:
    var $rval_idx = $rval | 0;
    var $st$1$0 = $rval_idx | 0;
    var $rval_idx_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $rval_idx + 4 | 0;
    var $rval_idx_val$1 = HEAP32[$st$1$1 >> 2];
    var $52 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($cx, $rval_idx_val$0, $rval_idx_val$1);
    var $_0 = $52;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z16js_ValueToSourceP9JSContextRKN2JS5ValueE["X"] = 1;

function __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE3862($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $vp_idx1 = $vp | 0;
    var $vp_idx1_val$0 = HEAP32[$vp_idx1 >> 2];
    var $vp_idx1_val$1 = HEAP32[$vp_idx1 + 4 >> 2];
    var $1 = __ZNK2JS5Value11isPrimitiveEv($vp_idx1_val$0, $vp_idx1_val$1);
    if ($1) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($vp_idx1_val$0, $vp_idx1_val$1);
    var $4 = $3;
    var $5 = $cx;
    var $6 = __ZN8JSObject12defaultValueEP9JSContext6JSTypePN2JS5ValueE($4, $5, 3, $vp);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js23ValueToStringBufferSlowEP9JSContextRKN2JS5ValueERNS_12StringBufferE($cx, $arg_0_0_0_val$0, $arg_0_0_0_val$1, $sb) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $v | 0;
    HEAP32[$1 >> 2] = $arg_0_0_0_val$0;
    HEAP32[$1 + 4 >> 2] = $arg_0_0_0_val$1;
    var $2 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE3862($cx, $v);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    var $v_idx1_val$0 = HEAPU32[$1 >> 2];
    var $v_idx1_val$1 = HEAPU32[$1 + 4 >> 2];
    var $4 = __ZNK2JS5Value8isStringEv($v_idx1_val$0, $v_idx1_val$1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZNK2JS5Value8toStringEv($v_idx1_val$0, $v_idx1_val$1);
    var $7 = $sb;
    var $8 = __ZN2js12StringBuffer6appendEP8JSString($7, $6);
    var $_0 = $8;
    __label__ = 11;
    break;
   case 4:
    var $10 = __ZNK2JS5Value8isNumberEv($v_idx1_val$0, $v_idx1_val$1);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $12 = $cx;
    var $13 = $sb;
    var $14 = __ZN2js25NumberValueToStringBufferEP9JSContextRKN2JS5ValueERNS_12StringBufferE($12, $v, $13);
    var $_0 = $14;
    __label__ = 11;
    break;
   case 6:
    var $16 = __ZNK2JS5Value9isBooleanEv($v_idx1_val$0, $v_idx1_val$1);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $18 = __ZNK2JS5Value9toBooleanEv($v_idx1_val$0, $v_idx1_val$1);
    var $19 = $18 & 1;
    var $20 = $sb;
    var $21 = __ZN2js21BooleanToStringBufferEP9JSContextiRNS_12StringBufferE($19, $20);
    var $_0 = $21;
    __label__ = 11;
    break;
   case 8:
    var $23 = __ZNK2JS5Value6isNullEv($v_idx1_val$0, $v_idx1_val$1);
    var $25 = HEAPU32[$cx + 52 >> 2];
    if ($23) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $29 = HEAP32[$25 + 210016 >> 2] | 0;
    var $30 = __ZN2js12StringBuffer6appendEP6JSAtom($sb, $29);
    var $_0 = $30;
    __label__ = 11;
    break;
   case 10:
    var $34 = HEAP32[$25 + 209984 >> 2] | 0;
    var $35 = __ZN2js12StringBuffer6appendEP6JSAtom($sb, $34);
    var $_0 = $35;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js23ValueToStringBufferSlowEP9JSContextRKN2JS5ValueERNS_12StringBufferE["X"] = 1;

function __ZN2js12StringBuffer6appendEP6JSAtom($this, $atom) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$atom >> 2];
    var $1 = __ZNK8JSString6lengthEv($_idx_val);
    var $_idx2_val = HEAP32[$this + 8 >> 2];
    var $3 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv($_idx2_val);
    var $4 = $3 + $1 | 0;
    var $5 = $this;
    var $6 = __ZN2js12StringBuffer11checkLengthEj($5, $4);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $this;
    var $_idx1_val = HEAP32[$atom + 4 >> 2];
    var $9 = __ZNK14JSLinearString5charsEv($_idx1_val);
    var $10 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbPKT_j($8, $9, $1);
    var $_0 = $10;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL9NullValueEv3866($agg_result) {
  __ZN2JS5Value7setNullEv($agg_result);
  return;
}

function __ZN2js12EqualStringsEP9JSContextP8JSStringS3_Pi($cx, $str1, $str2, $result) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($str1 | 0) == ($str2 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$result >> 2] = 1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 3:
    var $str1_idx_val = HEAP32[$str1 >> 2];
    var $4 = __ZNK8JSString6lengthEv($str1_idx_val);
    var $str2_idx_val = HEAP32[$str2 >> 2];
    var $5 = __ZNK8JSString6lengthEv($str2_idx_val);
    if (($4 | 0) == ($5 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$result >> 2] = 0;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 5:
    var $9 = $cx;
    var $10 = __ZN8JSString12ensureLinearEP9JSContext($str1, $9);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $13 = __ZN8JSString12ensureLinearEP9JSContext($str2, $9);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx1_val = HEAP32[$10 + 4 >> 2];
    var $16 = __ZNK14JSLinearString5charsEv($_idx1_val);
    var $_idx_val = HEAP32[$13 + 4 >> 2];
    var $17 = __ZNK14JSLinearString5charsEv($_idx_val);
    var $18 = __ZN2jsL8PodEqualIKtEEbPT_S3_j3869($16, $17, $4);
    var $19 = $18 & 1;
    HEAP32[$result >> 2] = $19;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL8PodEqualIKtEEbPT_S3_j3869($one, $two, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($len >>> 0 < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $3 = $one + ($len << 1) | 0;
    var $p2_0 = $two;
    var $p1_0 = $one;
    __label__ = 3;
    break;
   case 3:
    var $p1_0;
    var $p2_0;
    if (($p1_0 | 0) == ($3 | 0)) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (HEAP16[$p1_0 >> 1] << 16 >> 16 == HEAP16[$p2_0 >> 1] << 16 >> 16) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $p2_0 = $p2_0 + 2 | 0;
    var $p1_0 = $p1_0 + 2 | 0;
    __label__ = 3;
    break;
   case 6:
    var $14 = $one;
    var $15 = $two;
    var $16 = $len << 1;
    var $17 = _memcmp($14, $15, $16);
    var $_0 = ($17 | 0) == 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12EqualStringsEP14JSLinearStringS1_($str1, $str2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($str1 | 0) == ($str2 | 0)) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$str1 >> 2];
    var $3 = __ZNK8JSString6lengthEv($_idx1_val);
    var $_idx_val = HEAP32[$str2 >> 2];
    var $4 = __ZNK8JSString6lengthEv($_idx_val);
    if (($3 | 0) == ($4 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $str1_idx_val = HEAP32[$str1 + 4 >> 2];
    var $7 = __ZNK14JSLinearString5charsEv($str1_idx_val);
    var $str2_idx_val = HEAP32[$str2 + 4 >> 2];
    var $8 = __ZNK14JSLinearString5charsEv($str2_idx_val);
    var $9 = __ZN2jsL8PodEqualIKtEEbPT_S3_j3869($7, $8, $3);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14CompareStringsEP9JSContextP8JSStringS3_Pi($cx, $str1, $str2, $result) {
  var $1 = __ZN2jsL18CompareStringsImplEP9JSContextP8JSStringS3_Pi($cx, $str1, $str2, $result);
  return $1;
}

function __ZN2jsL18CompareStringsImplEP9JSContextP8JSStringS3_Pi($cx, $str1, $str2, $result) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($str1 | 0) == ($str2 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$result >> 2] = 0;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 3:
    var $str1_idx_val = HEAP32[$str1 >> 2];
    var $4 = __ZNK8JSString6lengthEv($str1_idx_val);
    var $5 = $cx;
    var $6 = __ZN8JSString8getCharsEP9JSContext($str1, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $str2_idx_val = HEAP32[$str2 >> 2];
    var $9 = __ZNK8JSString6lengthEv($str2_idx_val);
    var $10 = __ZN8JSString8getCharsEP9JSContext($str2, $5);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = $4 >>> 0 < $9 >>> 0 ? $4 : $9;
    var $i_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $i_0;
    if ($i_0 >>> 0 < $14 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    var $19 = HEAPU16[$6 + ($i_0 << 1) >> 1];
    var $21 = HEAPU16[$10 + ($i_0 << 1) >> 1];
    if ($19 << 16 >> 16 == $21 << 16 >> 16) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP32[$result >> 2] = ($19 & 65535) - ($21 & 65535) | 0;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 9:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 6;
    break;
   case 10:
    var $30 = $4 - $9 | 0;
    HEAP32[$result >> 2] = $30;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17StringEqualsAsciiEP14JSLinearStringPKc($str, $asciiBytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _strlen($asciiBytes);
    var $_idx_val = HEAP32[$str >> 2];
    var $2 = __ZNK8JSString6lengthEv($_idx_val);
    if (($1 | 0) == ($2 | 0)) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $str_idx_val = HEAP32[$str + 4 >> 2];
    var $5 = __ZNK14JSLinearString5charsEv($str_idx_val);
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    if (($i_0 | 0) == ($1 | 0)) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP8[$asciiBytes + $i_0 | 0] << 24 >> 24 | 0) == (HEAPU16[$5 + ($i_0 << 1) >> 1] & 65535 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 3;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js25InflateUTF8StringToBufferEP9JSContextPKcjPtPjNS_13FlationCodingE($cx, $src, $srclen, $dst, $dstlenp, $fc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $buffer = __stackBase__;
    var $buffer1 = __stackBase__ + 12;
    if (($dst | 0) == 0) {
      var $5 = -1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$dstlenp >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    var $6 = ($fc | 0) == 1;
    var $_02 = $src;
    var $_03 = $srclen;
    var $_04 = $dst;
    var $dstlen_0 = $5;
    var $offset_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $offset_0;
    var $dstlen_0;
    var $_04;
    var $_03;
    var $_02;
    if (($_03 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = HEAPU8[$_02] & 255;
    if (($11 & 128 | 0) == 0) {
      var $v_1 = $11;
      var $_2 = $_04;
      var $n_1 = 1;
      var $dstlen_1 = $dstlen_0;
      __label__ = 21;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($11 & 64 | 0) == 0) {
      var $n_0_lcssa = 1;
      __label__ = 8;
      break;
    } else {
      var $n_06 = 1;
      __label__ = 7;
      break;
    }
   case 7:
    var $n_06;
    var $16 = $n_06 + 1 | 0;
    if ((128 >>> ($16 >>> 0) & $11 | 0) == 0) {
      var $n_0_lcssa = $16;
      __label__ = 8;
      break;
    } else {
      var $n_06 = $16;
      __label__ = 7;
      break;
    }
   case 8:
    var $n_0_lcssa;
    if ($n_0_lcssa >>> 0 > $_03 >>> 0) {
      var $dstlen_2 = $dstlen_0;
      __label__ = 28;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (($n_0_lcssa | 0) == 1 | $n_0_lcssa >>> 0 > 4) {
      __label__ = 26;
      break;
    } else {
      var $j_0 = 1;
      __label__ = 10;
      break;
    }
   case 10:
    var $j_0;
    if ($j_0 >>> 0 < $n_0_lcssa >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    if ((HEAP8[$_02 + $j_0 | 0] & -64) << 24 >> 24 == -128) {
      __label__ = 12;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 12:
    var $j_0 = $j_0 + 1 | 0;
    __label__ = 10;
    break;
   case 13:
    var $33 = __ZL17Utf8ToOneUcs4CharPKhi($_02, $n_0_lcssa);
    if ($33 >>> 0 > 65535) {
      __label__ = 14;
      break;
    } else {
      var $v_1 = $33;
      var $_2 = $_04;
      var $n_1 = $n_0_lcssa;
      var $dstlen_1 = $dstlen_0;
      __label__ = 21;
      break;
    }
   case 14:
    if ($6) {
      var $v_1 = $33;
      var $_2 = $_04;
      var $n_1 = $n_0_lcssa;
      var $dstlen_1 = $dstlen_0;
      __label__ = 21;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $37 = $33 - 65536 | 0;
    if ($37 >>> 0 > 1048575 | $dstlen_0 >>> 0 < 2) {
      __label__ = 16;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 16:
    HEAP32[$dstlenp >> 2] = $5 - $dstlen_0 | 0;
    if (($cx | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $44 = $buffer | 0;
    var $45 = _JS_snprintf($44, 10, STRING_TABLE.__str363799 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $33, tempInt));
    var $46 = $cx;
    var $47 = _JS_ReportErrorFlagsAndNumber($46, 0, 204, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $44, tempInt));
    var $_0 = 0;
    __label__ = 30;
    break;
   case 18:
    if (($_04 | 0) == 0) {
      var $v_0 = $37;
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    HEAP16[$_04 >> 1] = ($37 >>> 10) + 55296 & 65535;
    var $v_0 = $37 & 1023 | 56320;
    var $_1 = $_04 + 2 | 0;
    __label__ = 20;
    break;
   case 20:
    var $_1;
    var $v_0;
    var $v_1 = $v_0;
    var $_2 = $_1;
    var $n_1 = $n_0_lcssa;
    var $dstlen_1 = $dstlen_0 - 1 | 0;
    __label__ = 21;
    break;
   case 21:
    var $dstlen_1;
    var $n_1;
    var $_2;
    var $v_1;
    if (($dstlen_1 | 0) == 0) {
      var $dstlen_2 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    if (($_2 | 0) == 0) {
      var $_3 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    HEAP16[$_2 >> 1] = $v_1 & 65535;
    var $_3 = $_2 + 2 | 0;
    __label__ = 24;
    break;
   case 24:
    var $_3;
    var $_02 = $_02 + $n_1 | 0;
    var $_03 = $_03 - $n_1 | 0;
    var $_04 = $_3;
    var $dstlen_0 = $dstlen_1 - 1 | 0;
    var $offset_0 = $n_1 + $offset_0 | 0;
    __label__ = 4;
    break;
   case 25:
    HEAP32[$dstlenp >> 2] = $5 - $dstlen_0 | 0;
    var $_0 = 1;
    __label__ = 30;
    break;
   case 26:
    HEAP32[$dstlenp >> 2] = $5 - $dstlen_0 | 0;
    if (($cx | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $76 = $buffer1 | 0;
    var $77 = _JS_snprintf($76, 10, STRING_TABLE.__str4498 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $offset_0, tempInt));
    var $78 = $cx;
    var $79 = _JS_ReportErrorFlagsAndNumber($78, 0, 205, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $76, tempInt));
    var $_0 = 0;
    __label__ = 30;
    break;
   case 28:
    var $dstlen_2;
    HEAP32[$dstlenp >> 2] = $5 - $dstlen_2 | 0;
    if (($cx | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $84 = $cx;
    _JS_ReportErrorNumber($84, 4, 202, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 30;
    break;
   case 30:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js25InflateUTF8StringToBufferEP9JSContextPKcjPtPjNS_13FlationCodingE["X"] = 1;

function __ZN2js13DeflateStringEP9JSContextPKtj($cx, $chars, $nchars) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nbytes = __stackBase__;
    if (HEAPU8[_js_CStringsAreUTF8_b]) {
      __label__ = 2;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $2 = __ZN2js23GetDeflatedStringLengthEP9JSContextPKtj($cx, $chars, $nchars);
    HEAP32[$nbytes >> 2] = $2;
    if (($2 | 0) == -1) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = $2 + 1 | 0;
    if (($cx | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = $cx;
    var $9 = __ZN9JSContext7malloc_Ej($8, $6);
    var $13 = $9;
    __label__ = 6;
    break;
   case 5:
    var $11 = __ZN2js11OffTheBooks7malloc_Ej($6);
    var $13 = $11;
    __label__ = 6;
    break;
   case 6:
    var $13;
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $16 = __ZN2js21DeflateStringToBufferEP9JSContextPKtjPcPj($cx, $chars, $nchars, $13, $nbytes);
    var $bytes_0 = $13;
    var $35 = HEAP32[$nbytes >> 2];
    __label__ = 14;
    break;
   case 8:
    HEAP32[$nbytes >> 2] = $nchars;
    var $19 = $nchars + 1 | 0;
    if (($cx | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $21 = $cx;
    var $22 = __ZN9JSContext7malloc_Ej($21, $19);
    var $26 = $22;
    __label__ = 11;
    break;
   case 10:
    var $24 = __ZN2js11OffTheBooks7malloc_Ej($19);
    var $26 = $24;
    __label__ = 11;
    break;
   case 11:
    var $26;
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (($nchars | 0) == 0) {
      var $bytes_0 = $26;
      var $35 = $nchars;
      __label__ = 14;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 13;
      break;
    }
   case 13:
    var $i_01;
    HEAP8[$26 + $i_01 | 0] = HEAP16[$chars + ($i_01 << 1) >> 1] & 255;
    var $33 = $i_01 + 1 | 0;
    if ($33 >>> 0 < $nchars >>> 0) {
      var $i_01 = $33;
      __label__ = 13;
      break;
    } else {
      var $bytes_0 = $26;
      var $35 = $nchars;
      __label__ = 14;
      break;
    }
   case 14:
    var $35;
    var $bytes_0;
    HEAP8[$bytes_0 + $35 | 0] = 0;
    var $_0 = $bytes_0;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13DeflateStringEP9JSContextPKtj["X"] = 1;

function __Z20js_OneUcs4ToUtf8CharPhj($utf8Buffer, $ucs4Char) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($ucs4Char >>> 0 < 128) {
      var $utf8Length_1 = 1;
      var $storemerge_in = $ucs4Char;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $ucs4Char >>> 11;
    if (($3 | 0) == 0) {
      var $utf8Length_0_lcssa8 = 2;
      var $6 = 1;
      __label__ = 4;
      break;
    } else {
      var $utf8Length_02 = 2;
      var $a_03 = $3;
      __label__ = 5;
      break;
    }
   case 3:
    if (($utf8Length_02 | 0) == 0) {
      var $_0_lcssa = $ucs4Char;
      var $utf8Length_0_lcssa9 = $8;
      __label__ = 7;
      break;
    } else {
      var $utf8Length_0_lcssa8 = $8;
      var $6 = $utf8Length_02;
      __label__ = 4;
      break;
    }
   case 4:
    var $6;
    var $utf8Length_0_lcssa8;
    var $_01 = $ucs4Char;
    var $11 = $6;
    __label__ = 6;
    break;
   case 5:
    var $a_03;
    var $utf8Length_02;
    var $7 = $a_03 >>> 5;
    var $8 = $utf8Length_02 + 1 | 0;
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $utf8Length_02 = $8;
      var $a_03 = $7;
      __label__ = 5;
      break;
    }
   case 6:
    var $11;
    var $_01;
    HEAP8[$utf8Buffer + $11 | 0] = ($_01 & 63 | 128) & 255;
    var $16 = $_01 >>> 6;
    var $17 = $11 - 1 | 0;
    if (($17 | 0) == 0) {
      var $_0_lcssa = $16;
      var $utf8Length_0_lcssa9 = $utf8Length_0_lcssa8;
      __label__ = 7;
      break;
    } else {
      var $_01 = $16;
      var $11 = $17;
      __label__ = 6;
      break;
    }
   case 7:
    var $utf8Length_0_lcssa9;
    var $_0_lcssa;
    var $utf8Length_1 = $utf8Length_0_lcssa9;
    var $storemerge_in = (-1 << 8 - $utf8Length_0_lcssa9) + 256 + $_0_lcssa | 0;
    __label__ = 8;
    break;
   case 8:
    var $storemerge_in;
    var $utf8Length_1;
    HEAP8[$utf8Buffer] = $storemerge_in & 255;
    return $utf8Length_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17Utf8ToOneUcs4CharPKhi($utf8Buffer, $utf8Length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAPU8[$utf8Buffer] & 255;
    if (($utf8Length | 0) == 1) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $3 & (1 << 7 - $utf8Length) - 1;
    var $11 = HEAPU32[__ZZL17Utf8ToOneUcs4CharPKhiE12minucs4Table + ($utf8Length - 2 << 2) >> 2];
    var $12 = $utf8Length - 1 | 0;
    if (($12 | 0) == 0) {
      var $ucs4Char_0_lcssa = $8;
      __label__ = 4;
      break;
    } else {
      var $ucs4Char_06 = $8;
      var $utf8Buffer_pn = $utf8Buffer;
      var $14 = $12;
      __label__ = 3;
      break;
    }
   case 3:
    var $14;
    var $utf8Buffer_pn;
    var $ucs4Char_06;
    var $_027 = $utf8Buffer_pn + 1 | 0;
    var $19 = HEAPU8[$_027] & 255 & 63 | $ucs4Char_06 << 6;
    var $20 = $14 - 1 | 0;
    if (($20 | 0) == 0) {
      var $ucs4Char_0_lcssa = $19;
      __label__ = 4;
      break;
    } else {
      var $ucs4Char_06 = $19;
      var $utf8Buffer_pn = $_027;
      var $14 = $20;
      __label__ = 3;
      break;
    }
   case 4:
    var $ucs4Char_0_lcssa;
    if ($ucs4Char_0_lcssa >>> 0 < $11 >>> 0 | ($ucs4Char_0_lcssa - 55296 | 0) >>> 0 < 2048) {
      var $_0 = -1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_0 = $ucs4Char_0_lcssa;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js23GetDeflatedStringLengthEP9JSContextPKtj($cx, $chars, $nchars) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU8[_js_CStringsAreUTF8_b]) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $nchars;
      __label__ = 3;
      break;
    }
   case 2:
    var $2 = __ZN2js27GetDeflatedUTF8StringLengthEP9JSContextPKtjNS_13FlationCodingE($cx, $chars, $nchars);
    var $_0 = $2;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js21DeflateStringToBufferEP9JSContextPKtjPcPj($cx, $src, $srclen, $dst, $dstlenp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[$dstlenp >> 2];
    if (HEAPU8[_js_CStringsAreUTF8_b]) {
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($1 >>> 0 < $srclen >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    if (($1 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $i_03 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    if (($srclen | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $i_11 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $i_03;
    HEAP8[$dst + $i_03 | 0] = HEAP16[$src + ($i_03 << 1) >> 1] & 255;
    var $10 = $i_03 + 1 | 0;
    if (($10 | 0) == ($1 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $i_03 = $10;
      __label__ = 5;
      break;
    }
   case 6:
    if (($cx | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $13 = $cx;
    _JS_ReportErrorNumber($13, 4, 202, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 11;
    break;
   case 8:
    var $i_11;
    HEAP8[$dst + $i_11 | 0] = HEAP16[$src + ($i_11 << 1) >> 1] & 255;
    var $18 = $i_11 + 1 | 0;
    if (($18 | 0) == ($srclen | 0)) {
      __label__ = 9;
      break;
    } else {
      var $i_11 = $18;
      __label__ = 8;
      break;
    }
   case 9:
    HEAP32[$dstlenp >> 2] = $srclen;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 10:
    var $20 = __ZN2js25DeflateStringToUTF8BufferEP9JSContextPKtjPcPjNS_13FlationCodingE($cx, $src, $srclen, $dst, $dstlenp);
    var $_0 = $20;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js27GetDeflatedUTF8StringLengthEP9JSContextPKtjNS_13FlationCodingE($cx, $chars, $nchars) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $buffer = __stackBase__;
    var $1 = $chars + ($nchars << 1) | 0;
    var $_04 = $chars;
    var $nbytes_0 = $nchars;
    __label__ = 2;
    break;
   case 2:
    var $nbytes_0;
    var $_04;
    if (($_04 | 0) == ($1 | 0)) {
      var $_0 = $nbytes_0;
      __label__ = 13;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = HEAPU16[$_04 >> 1];
    var $6 = $5 & 65535;
    if (($5 & 65535) < 128) {
      var $_2 = $_04;
      var $nbytes_3 = $nbytes_0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($5 + 10240 & 65535 & 65535) > 2047) {
      var $c_0 = $6;
      var $_1 = $_04;
      var $nbytes_1 = $nbytes_0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = $_04 + 2 | 0;
    var $11 = $nbytes_0 - 1 | 0;
    if (($5 & 65535) > 56319 | ($10 | 0) == ($1 | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = HEAPU16[$10 >> 1];
    if (($15 + 9216 & 65535 & 65535) > 1023) {
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $c_0 = ($6 << 10) - 56613888 + ($15 & 65535) | 0;
    var $_1 = $10;
    var $nbytes_1 = $11;
    __label__ = 8;
    break;
   case 8:
    var $nbytes_1;
    var $_1;
    var $c_0;
    var $23 = $c_0 >>> 11;
    var $nbytes_26 = $nbytes_1 + 1 | 0;
    if (($23 | 0) == 0) {
      var $_2 = $_1;
      var $nbytes_3 = $nbytes_26;
      __label__ = 10;
      break;
    } else {
      var $c_17 = $23;
      var $nbytes_28 = $nbytes_26;
      __label__ = 9;
      break;
    }
   case 9:
    var $nbytes_28;
    var $c_17;
    var $25 = $c_17 >>> 5;
    var $nbytes_2 = $nbytes_28 + 1 | 0;
    if (($25 | 0) == 0) {
      var $_2 = $_1;
      var $nbytes_3 = $nbytes_2;
      __label__ = 10;
      break;
    } else {
      var $c_17 = $25;
      var $nbytes_28 = $nbytes_2;
      __label__ = 9;
      break;
    }
   case 10:
    var $nbytes_3;
    var $_2;
    var $_04 = $_2 + 2 | 0;
    var $nbytes_0 = $nbytes_3;
    __label__ = 2;
    break;
   case 11:
    if (($cx | 0) == 0) {
      var $_0 = -1;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $31 = $buffer | 0;
    var $32 = _JS_snprintf($31, 10, STRING_TABLE.__str363799 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $6, tempInt));
    var $33 = $cx;
    var $34 = _JS_ReportErrorFlagsAndNumber($33, 0, 203, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $31, tempInt));
    var $_0 = -1;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js27GetDeflatedUTF8StringLengthEP9JSContextPKtjNS_13FlationCodingE["X"] = 1;

function __ZN2js25DeflateStringToUTF8BufferEP9JSContextPKtjPcPjNS_13FlationCodingE($cx, $src, $srclen, $dst, $dstlenp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $utf8buf = __stackBase__;
    var $1 = HEAPU32[$dstlenp >> 2];
    var $2 = $utf8buf | 0;
    var $dstlen_0 = $1;
    var $_01 = $src;
    var $_02 = $srclen;
    var $_04 = $dst;
    __label__ = 2;
    break;
   case 2:
    var $_04;
    var $_02;
    var $_01;
    var $dstlen_0;
    if (($_02 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = $_01 + 2 | 0;
    var $7 = HEAPU16[$_01 >> 1];
    var $8 = $_02 - 1 | 0;
    var $9 = $7 & 65535;
    if (($7 + 9216 & 65535 & 65535) > 1023) {
      __label__ = 4;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 4:
    if (($7 + 10240 & 65535 & 65535) > 1023) {
      var $_1 = $6;
      var $_13 = $8;
      var $v_0 = $9;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($8 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = HEAPU16[$6 >> 1];
    if (($15 + 9216 & 65535 & 65535) > 1023) {
      __label__ = 17;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_1 = $_01 + 4 | 0;
    var $_13 = $_02 - 2 | 0;
    var $v_0 = ($9 << 10) - 56613888 + ($15 & 65535) | 0;
    __label__ = 8;
    break;
   case 8:
    var $v_0;
    var $_13;
    var $_1;
    if ($v_0 >>> 0 < 128) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    if (($dstlen_0 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    HEAP8[$_04] = $v_0 & 255;
    var $_2 = $_04 + 1 | 0;
    var $utf8Len_0 = 1;
    __label__ = 15;
    break;
   case 11:
    var $32 = __Z20js_OneUcs4ToUtf8CharPhj($2, $v_0);
    if ($32 >>> 0 > $dstlen_0 >>> 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (($32 | 0) == 0) {
      var $_2 = $_04;
      var $utf8Len_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $lftr_limit = $_04 + $32 | 0;
    var $i_011 = 0;
    var $_1512 = $_04;
    __label__ = 14;
    break;
   case 14:
    var $_1512;
    var $i_011;
    var $37 = HEAP8[$utf8buf + $i_011 | 0];
    var $38 = $_1512 + 1 | 0;
    HEAP8[$_1512] = $37;
    if (($38 | 0) == ($lftr_limit | 0)) {
      var $_2 = $lftr_limit;
      var $utf8Len_0 = $32;
      __label__ = 15;
      break;
    } else {
      var $i_011 = $i_011 + 1 | 0;
      var $_1512 = $38;
      __label__ = 14;
      break;
    }
   case 15:
    var $utf8Len_0;
    var $_2;
    var $dstlen_0 = $dstlen_0 - $utf8Len_0 | 0;
    var $_01 = $_1;
    var $_02 = $_13;
    var $_04 = $_2;
    __label__ = 2;
    break;
   case 16:
    HEAP32[$dstlenp >> 2] = $1 - $dstlen_0 | 0;
    var $_0 = 1;
    __label__ = 21;
    break;
   case 17:
    HEAP32[$dstlenp >> 2] = $1 - $dstlen_0 | 0;
    if (($cx | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $47 = __ZN2js23GetDeflatedStringLengthEP9JSContextPKtj($cx, $_01, $_02);
    var $_0 = 0;
    __label__ = 21;
    break;
   case 19:
    HEAP32[$dstlenp >> 2] = $1 - $dstlen_0 | 0;
    if (($cx | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $52 = $cx;
    _JS_ReportErrorNumber($52, 4, 202, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js25DeflateStringToUTF8BufferEP9JSContextPKtjPcPjNS_13FlationCodingE["X"] = 1;

function __ZN2js21InflateStringToBufferEP9JSContextPKcjPtPj($cx, $src, $srclen, $dst, $dstlenp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU8[_js_CStringsAreUTF8_b]) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $2 = __ZN2js25InflateUTF8StringToBufferEP9JSContextPKcjPtPjNS_13FlationCodingE($cx, $src, $srclen, $dst, $dstlenp, 0);
    var $_0 = $2;
    __label__ = 12;
    break;
   case 3:
    if (($dst | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $6 = HEAPU32[$dstlenp >> 2];
    if ($6 >>> 0 < $srclen >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    if (($6 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $i_03 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    if (($srclen | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $i_11 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    var $i_03;
    HEAP16[$dst + ($i_03 << 1) >> 1] = HEAPU8[$src + $i_03 | 0] & 255;
    var $14 = $i_03 + 1 | 0;
    if (($14 | 0) == ($6 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $i_03 = $14;
      __label__ = 7;
      break;
    }
   case 8:
    if (($cx | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $17 = $cx;
    _JS_ReportErrorNumber($17, 4, 202, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 12;
    break;
   case 10:
    var $i_11;
    HEAP16[$dst + ($i_11 << 1) >> 1] = HEAPU8[$src + $i_11 | 0] & 255;
    var $22 = $i_11 + 1 | 0;
    if (($22 | 0) == ($srclen | 0)) {
      __label__ = 11;
      break;
    } else {
      var $i_11 = $22;
      __label__ = 10;
      break;
    }
   case 11:
    HEAP32[$dstlenp >> 2] = $srclen;
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js20PutEscapedStringImplEPcjP7__sFILEP14JSLinearStringj($fp, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str_idx_val = HEAP32[$str + 4 >> 2];
    var $1 = __ZNK14JSLinearString5charsEv($str_idx_val);
    var $_idx_val = HEAP32[$str >> 2];
    var $2 = __ZNK8JSString6lengthEv($_idx_val);
    var $3 = $1 + ($2 << 1) | 0;
    var $4 = ($fp | 0) == 0;
    var $c_0_ph = 0;
    var $u_0_ph = 0;
    var $hex_0_ph = 0;
    var $state_0_ph = 1;
    var $chars_0_ph = $1;
    var $shift_0_ph = 0;
    var $n_0_ph = 0;
    __label__ = 2;
    break;
   case 2:
    var $n_0_ph;
    var $shift_0_ph;
    var $chars_0_ph;
    var $state_0_ph;
    var $hex_0_ph;
    var $u_0_ph;
    var $c_0_ph;
    var $5 = ($chars_0_ph | 0) == ($3 | 0);
    var $state_0_ph8 = $state_0_ph;
    var $shift_0_ph6 = $shift_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $shift_0_ph6;
    var $state_0_ph8;
    var $state_0 = $state_0_ph8;
    __label__ = 4;
    break;
   case 4:
    var $state_0;
    if (($state_0 | 0) == 1) {
      var $state_0 = 3;
      __label__ = 4;
      break;
    } else if (($state_0 | 0) == 2) {
      __label__ = 5;
      break;
    } else if (($state_0 | 0) == 3) {
      __label__ = 6;
      break;
    } else if (($state_0 | 0) == 4) {
      __label__ = 16;
      break;
    } else if (($state_0 | 0) == 5) {
      __label__ = 17;
      break;
    } else if (($state_0 | 0) == 0) {
      var $_0 = $n_0_ph;
      __label__ = 22;
      break;
    } else {
      var $c_1 = $c_0_ph;
      var $u_2 = $u_0_ph;
      var $hex_2 = $hex_0_ph;
      var $state_2 = $state_0;
      var $chars_1 = $chars_0_ph;
      var $shift_2 = $shift_0_ph6;
      __label__ = 19;
      break;
    }
   case 5:
    var $state_0 = 0;
    __label__ = 4;
    break;
   case 6:
    if ($5) {
      var $state_0 = 2;
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $9 = $chars_0_ph + 2 | 0;
    var $10 = HEAPU16[$chars_0_ph >> 1];
    var $11 = $10 & 65535;
    if (($10 & 65535) < 32) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    if ($10 << 16 >> 16 == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $memchr = _memchr(STRING_TABLE._js_EscapeMap | 0, $11, 19);
    if (($memchr | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $c_1 = 92;
    var $u_2 = HEAP8[$memchr + 1 | 0] << 24 >> 24;
    var $hex_2 = $hex_0_ph;
    var $state_2 = 4;
    var $chars_1 = $9;
    var $shift_2 = $shift_0_ph6;
    __label__ = 19;
    break;
   case 11:
    if (($10 & 65535) < 127) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    if ($10 << 16 >> 16 == 92 || $10 << 16 >> 16 == 0) {
      var $c_1 = 92;
      var $u_2 = $11;
      var $hex_2 = $hex_0_ph;
      var $state_2 = 4;
      var $chars_1 = $9;
      var $shift_2 = $shift_0_ph6;
      __label__ = 19;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $c_1 = $10 & 255;
    var $u_2 = $11;
    var $hex_2 = $hex_0_ph;
    var $state_2 = $state_0;
    var $chars_1 = $9;
    var $shift_2 = $shift_0_ph6;
    __label__ = 19;
    break;
   case 14:
    if (($10 & 65535) < 256) {
      __label__ = 15;
      break;
    } else {
      var $c_1 = 92;
      var $u_2 = 117;
      var $hex_2 = $11;
      var $state_2 = 4;
      var $chars_1 = $9;
      var $shift_2 = 16;
      __label__ = 19;
      break;
    }
   case 15:
    var $c_1 = 92;
    var $u_2 = 120;
    var $hex_2 = $11;
    var $state_2 = 4;
    var $chars_1 = $9;
    var $shift_2 = 8;
    __label__ = 19;
    break;
   case 16:
    var $c_1 = $u_0_ph & 255;
    var $u_2 = $u_0_ph;
    var $hex_2 = $hex_0_ph;
    var $state_2 = 5;
    var $chars_1 = $chars_0_ph;
    var $shift_2 = $shift_0_ph6;
    __label__ = 19;
    break;
   case 17:
    if (($shift_0_ph6 | 0) == 0) {
      var $state_0_ph8 = 3;
      var $shift_0_ph6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $34 = $shift_0_ph6 - 4 | 0;
    var $36 = $hex_0_ph >>> ($34 >>> 0) & 15;
    var $38 = $36 >>> 0 < 10 ? 48 : 55;
    var $c_1 = $38 + $36 & 255;
    var $u_2 = $36;
    var $hex_2 = $hex_0_ph;
    var $state_2 = $state_0;
    var $chars_1 = $chars_0_ph;
    var $shift_2 = $34;
    __label__ = 19;
    break;
   case 19:
    var $shift_2;
    var $chars_1;
    var $state_2;
    var $hex_2;
    var $u_2;
    var $c_1;
    if ($4) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $43 = _fputc($c_1 << 24 >> 24, $fp);
    if (($43 | 0) < 0) {
      var $_0 = -1;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $c_0_ph = $c_1;
    var $u_0_ph = $u_2;
    var $hex_0_ph = $hex_2;
    var $state_0_ph = $state_2;
    var $chars_0_ph = $chars_1;
    var $shift_0_ph = $shift_2;
    var $n_0_ph = $n_0_ph + 1 | 0;
    __label__ = 2;
    break;
   case 22:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js20PutEscapedStringImplEPcjP7__sFILEP14JSLinearStringj["X"] = 1;

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendIcEEvT_($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this + 4 >> 2];
    var $2 = $this + 8 | 0;
    var $_idx1_val = HEAP32[$2 >> 2];
    var $3 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10endNoCheckEv($_idx_val, $_idx1_val);
    if (($3 | 0) == 0) {
      var $7 = $_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP16[$3 >> 1] = 0;
    var $7 = HEAP32[$2 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $7;
    HEAP32[$2 >> 2] = $7 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail17PrimitiveBehaviorIP8JSStringE6isTypeERKN2JS5ValueE($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var $1 = __ZNK2JS5Value8isStringEv($v_0_0_0_val$0, $v_0_0_0_val$1);
  return $1;
}

function __ZN2js6detail17PrimitiveBehaviorIP8JSStringE7extractERKN2JS5ValueE($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var $1 = __ZNK2JS5Value8toStringEv($v_0_0_0_val$0, $v_0_0_0_val$1);
  return $1;
}

function __ZL6EncodeP9JSContextP8JSStringPKtS4_PN2JS5ValueE($cx, $str, $unescapedSet, $unescapedSet2, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 92;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sb = __stackBase__;
    var $hexBuf = __stackBase__ + 80;
    var $utf8buf = __stackBase__ + 88;
    var $str_idx_val = HEAP32[$str >> 2];
    var $1 = __ZNK8JSString6lengthEv($str_idx_val);
    var $2 = $cx;
    var $3 = __ZN8JSString8getCharsEP9JSContext($str, $2);
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($rval, $12);
    var $_1 = 1;
    __label__ = 25;
    break;
   case 4:
    var $14 = $sb;
    __ZN2js12StringBufferC1EP9JSContext($14, $2);
    var $15 = $hexBuf | 0;
    HEAP16[$15 >> 1] = 37;
    HEAP16[$hexBuf + 6 >> 1] = 0;
    var $17 = ($unescapedSet2 | 0) == 0;
    var $18 = $utf8buf | 0;
    var $19 = $hexBuf + 2 | 0;
    var $20 = $hexBuf + 4 | 0;
    var $k_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $k_0;
    if ($k_0 >>> 0 < $1 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 6:
    var $25 = HEAPU16[$3 + ($k_0 << 1) >> 1];
    var $26 = __Z9js_strchrPKtt($unescapedSet, $25);
    if (($26 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    if ($17) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $30 = __Z9js_strchrPKtt($unescapedSet2, $25);
    if (($30 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $33 = __ZN2js12StringBuffer6appendEt($14, $25);
    if ($33) {
      var $k_2 = $k_0;
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 10:
    var $35 = $25 & 65535;
    if (($25 + 9216 & 65535 & 65535) < 1024) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    _JS_ReportErrorNumber($2, 4, 159, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 12:
    if (($25 + 10240 & 65535 & 65535) > 1023) {
      var $v_0 = $35;
      var $k_1 = $k_0;
      __label__ = 18;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $41 = $k_0 + 1 | 0;
    if (($41 | 0) == ($1 | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    _JS_ReportErrorNumber($2, 4, 159, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 15:
    var $46 = HEAPU16[$3 + ($41 << 1) >> 1];
    if (($46 + 9216 & 65535 & 65535) > 1023) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($2, 4, 159, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 17:
    var $v_0 = ($35 << 10) - 56613888 + ($46 & 65535) | 0;
    var $k_1 = $41;
    __label__ = 18;
    break;
   case 18:
    var $k_1;
    var $v_0;
    var $55 = __Z20js_OneUcs4ToUtf8CharPhj($18, $v_0);
    var $j_0 = 0;
    __label__ = 19;
    break;
   case 19:
    var $j_0;
    if ($j_0 >>> 0 < $55 >>> 0) {
      __label__ = 20;
      break;
    } else {
      var $k_2 = $k_1;
      __label__ = 22;
      break;
    }
   case 20:
    var $61 = HEAPU8[$utf8buf + $j_0 | 0] & 255;
    var $63 = STRING_TABLE.__ZZL6EncodeP9JSContextP8JSStringPKtS4_PN2JS5ValueEE9HexDigits + ($61 >>> 4) | 0;
    HEAP16[$19 >> 1] = HEAP8[$63] << 24 >> 24;
    var $67 = STRING_TABLE.__ZZL6EncodeP9JSContextP8JSStringPKtS4_PN2JS5ValueEE9HexDigits + ($61 & 15) | 0;
    HEAP16[$20 >> 1] = HEAP8[$67] << 24 >> 24;
    var $70 = __ZN2js12StringBuffer6appendEPKtj($14, $15, 3);
    if ($70) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 21:
    var $j_0 = $j_0 + 1 | 0;
    __label__ = 19;
    break;
   case 22:
    var $k_2;
    var $k_0 = $k_2 + 1 | 0;
    __label__ = 5;
    break;
   case 23:
    var $75 = __ZL22TransferBufferToStringP9JSContextRN2js12StringBufferEPN2JS5ValueE($sb, $rval);
    var $_0 = $75 & 1;
    __label__ = 24;
    break;
   case 24:
    var $_0;
    __ZN2js12StringBufferD1Ev($14);
    var $_1 = $_0;
    __label__ = 25;
    break;
   case 25:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL6EncodeP9JSContextP8JSStringPKtS4_PN2JS5ValueE["X"] = 1;

function __ZL22TransferBufferToStringP9JSContextRN2js12StringBufferEPN2JS5ValueE($sb, $rval) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js12StringBuffer12finishStringEv($sb);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1 | 0;
    __ZN2JS5Value9setStringEP8JSString($rval, $4);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14JSID_FROM_BITSj3911($bits) {
  return $bits;
}

function __ZNK16SplitMatchResult6lengthEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZN14JSInlineString10lengthFitsEj($length) {
  return $length >>> 0 < 4;
}

function _JSID_IS_INT3906($iden) {
  return $iden & 1;
}

function __ZN2js13StaticStrings7hasUnitEt($c) {
  return ($c & 65535) < 256;
}

function __ZNK16SplitMatchResult9isFailureEv($this_0_0_val) {
  return ($this_0_0_val | 0) == -1;
}

function __ZL6DecodeP9JSContextP8JSStringPKtPN2JS5ValueE($cx, $str, $reservedSet, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 84;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sb = __stackBase__;
    var $octets = __stackBase__ + 80;
    var $str_idx_val = HEAP32[$str >> 2];
    var $1 = __ZNK8JSString6lengthEv($str_idx_val);
    var $2 = $cx;
    var $3 = __ZN8JSString8getCharsEP9JSContext($str, $2);
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 44;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($rval, $12);
    var $_1 = 1;
    __label__ = 44;
    break;
   case 4:
    var $14 = $sb;
    __ZN2js12StringBufferC1EP9JSContext($14, $2);
    var $15 = $octets | 0;
    var $k_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $k_0;
    if ($k_0 >>> 0 < $1 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 6:
    var $19 = $3 + ($k_0 << 1) | 0;
    var $20 = HEAPU16[$19 >> 1];
    if ($20 << 16 >> 16 == 37) {
      __label__ = 7;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 7:
    var $23 = $k_0 + 2 | 0;
    if ($23 >>> 0 < $1 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 8:
    var $27 = $3 + ($k_0 + 1 << 1) | 0;
    var $28 = HEAPU16[$27 >> 1];
    if (($28 & 65535) < 128) {
      __label__ = 9;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 9:
    var $31 = $28 & 65535;
    var $32 = _isxdigit($31);
    if (($32 | 0) == 0) {
      __label__ = 42;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $35 = $3 + ($23 << 1) | 0;
    var $36 = HEAPU16[$35 >> 1];
    if (($36 & 65535) < 128) {
      __label__ = 11;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 11:
    var $39 = $36 & 65535;
    var $40 = _isxdigit($39);
    if (($40 | 0) == 0) {
      __label__ = 42;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $44 = HEAPU16[$27 >> 1] & 65535;
    var $45 = $44 - 48 | 0;
    if ($45 >>> 0 < 10) {
      var $51 = $45;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $48 = _tolower($44);
    var $51 = $48 - 87 | 0;
    __label__ = 14;
    break;
   case 14:
    var $51;
    var $52 = $51 << 4;
    var $54 = HEAPU16[$35 >> 1] & 65535;
    var $55 = $54 - 48 | 0;
    if ($55 >>> 0 < 10) {
      var $61 = $55;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $58 = _tolower($54);
    var $61 = $58 - 87 | 0;
    __label__ = 16;
    break;
   case 16:
    var $61;
    var $62 = $61 + $52 | 0;
    if (($62 & 128 | 0) == 0) {
      var $c_0_in = $62;
      var $k_2 = $23;
      __label__ = 36;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    if (($62 & 64 | 0) == 0) {
      __label__ = 42;
      break;
    } else {
      var $n_02 = 1;
      __label__ = 18;
      break;
    }
   case 18:
    var $n_02;
    var $67 = $n_02 + 1 | 0;
    if ((128 >>> ($67 >>> 0) & $62 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      var $n_02 = $67;
      __label__ = 18;
      break;
    }
   case 19:
    if (($n_02 | 0) == 0 | ($67 | 0) > 4) {
      __label__ = 42;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    HEAP8[$15] = $62 & 255;
    if (($k_0 - 1 + $67 * 3 | 0) >>> 0 < $1 >>> 0) {
      var $j_0 = 1;
      var $k_1 = $23;
      __label__ = 21;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 21:
    var $k_1;
    var $j_0;
    if (($j_0 | 0) < ($67 | 0)) {
      __label__ = 22;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 22:
    if (HEAP16[$3 + ($k_1 + 1 << 1) >> 1] << 16 >> 16 == 37) {
      __label__ = 23;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 23:
    var $87 = $3 + ($k_1 + 2 << 1) | 0;
    var $88 = HEAPU16[$87 >> 1];
    if (($88 & 65535) < 128) {
      __label__ = 24;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 24:
    var $91 = $88 & 65535;
    var $92 = _isxdigit($91);
    if (($92 | 0) == 0) {
      __label__ = 42;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $95 = $k_1 + 3 | 0;
    var $96 = $3 + ($95 << 1) | 0;
    var $97 = HEAPU16[$96 >> 1];
    if (($97 & 65535) < 128) {
      __label__ = 26;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 26:
    var $100 = $97 & 65535;
    var $101 = _isxdigit($100);
    if (($101 | 0) == 0) {
      __label__ = 42;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $105 = HEAPU16[$87 >> 1] & 65535;
    var $106 = $105 - 48 | 0;
    if ($106 >>> 0 < 10) {
      var $112 = $106;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $109 = _tolower($105);
    var $112 = $109 - 87 | 0;
    __label__ = 29;
    break;
   case 29:
    var $112;
    var $113 = $112 << 4;
    var $115 = HEAPU16[$96 >> 1] & 65535;
    var $116 = $115 - 48 | 0;
    if ($116 >>> 0 < 10) {
      var $122 = $116;
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $119 = _tolower($115);
    var $122 = $119 - 87 | 0;
    __label__ = 31;
    break;
   case 31:
    var $122;
    var $123 = $122 + $113 | 0;
    if (($123 & 192 | 0) == 128) {
      __label__ = 32;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 32:
    HEAP8[$octets + $j_0 | 0] = $123 & 255;
    var $j_0 = $j_0 + 1 | 0;
    var $k_1 = $95;
    __label__ = 21;
    break;
   case 33:
    var $131 = __ZL17Utf8ToOneUcs4CharPKhi($15, $67);
    if ($131 >>> 0 > 65535) {
      __label__ = 34;
      break;
    } else {
      var $c_0_in = $131;
      var $k_2 = $k_1;
      __label__ = 36;
      break;
    }
   case 34:
    var $134 = $131 - 65536 | 0;
    if ($134 >>> 0 > 1048575) {
      __label__ = 42;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $138 = $134 & 1023 | 56320;
    var $141 = ($134 >>> 10) + 55296 & 65535;
    var $142 = __ZN2js12StringBuffer6appendEt($14, $141);
    if ($142) {
      var $c_0_in = $138;
      var $k_2 = $k_1;
      __label__ = 36;
      break;
    } else {
      var $_0 = 0;
      __label__ = 43;
      break;
    }
   case 36:
    var $k_2;
    var $c_0_in;
    var $c_0 = $c_0_in & 65535;
    var $144 = __Z9js_strchrPKtt($reservedSet, $c_0);
    if (($144 | 0) == 0) {
      __label__ = 38;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $149 = __ZN2js12StringBuffer6appendEPKtj($14, $19, 1 - $k_0 + $k_2 | 0);
    if ($149) {
      var $k_3 = $k_2;
      __label__ = 40;
      break;
    } else {
      var $_0 = 0;
      __label__ = 43;
      break;
    }
   case 38:
    var $151 = __ZN2js12StringBuffer6appendEt($14, $c_0);
    if ($151) {
      var $k_3 = $k_2;
      __label__ = 40;
      break;
    } else {
      var $_0 = 0;
      __label__ = 43;
      break;
    }
   case 39:
    var $153 = __ZN2js12StringBuffer6appendEt($14, $20);
    if ($153) {
      var $k_3 = $k_0;
      __label__ = 40;
      break;
    } else {
      var $_0 = 0;
      __label__ = 43;
      break;
    }
   case 40:
    var $k_3;
    var $k_0 = $k_3 + 1 | 0;
    __label__ = 5;
    break;
   case 41:
    var $157 = __ZL22TransferBufferToStringP9JSContextRN2js12StringBufferEPN2JS5ValueE($sb, $rval);
    var $_0 = $157 & 1;
    __label__ = 43;
    break;
   case 42:
    _JS_ReportErrorNumber($2, 4, 159, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 43;
    break;
   case 43:
    var $_0;
    __ZN2js12StringBufferD1Ev($14);
    var $_1 = $_0;
    __label__ = 44;
    break;
   case 44:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL6DecodeP9JSContextP8JSStringPKtPN2JS5ValueE["X"] = 1;

function __ZN14JSInlineString4new_EP9JSContext($cx) {
  var $1 = $cx;
  var $2 = __Z14js_NewGCStringP9JSContext($1);
  return $2;
}

function __ZN13JSShortString4new_EP9JSContext($cx) {
  var $1 = $cx;
  var $2 = __Z19js_NewGCShortStringP9JSContext($1);
  return $2;
}

function __ZN14JSInlineString11resetLengthEj($this, $length) {
  var $1 = __ZN8JSString19buildLengthAndFlagsEjj($length, 4);
  HEAP32[$this >> 2] = $1;
  return;
}

function __ZN17JSDependentString4initEP14JSLinearStringPKtj($this, $base, $chars, $length) {
  var $1 = __ZN8JSString19buildLengthAndFlagsEjj($length, 2);
  HEAP32[$this >> 2] = $1;
  HEAP32[$this + 4 >> 2] = $chars;
  HEAP32[$this + 8 >> 2] = $base;
  return;
}

function __ZN2jsL7PodCopyItEEvPT_PKS1_j3900($dst, $src, $nelem) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($nelem >>> 0 < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $src + ($nelem << 1) | 0;
    if (($nelem | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $src;
      var $_03 = $dst;
      __label__ = 3;
      break;
    }
   case 3:
    var $_03;
    var $_012;
    var $5 = HEAP16[$_012 >> 1];
    HEAP16[$_03 >> 1] = $5;
    var $6 = $_012 + 2 | 0;
    if (($6 | 0) == ($3 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $6;
      var $_03 = $_03 + 2 | 0;
      __label__ = 3;
      break;
    }
   case 4:
    var $10 = $dst;
    var $11 = $src;
    var $12 = $nelem << 1;
    _memcpy($10, $11, $12, 1);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSFixedString4initEPKtj($this, $chars, $length) {
  var $1 = __ZN8JSString19buildLengthAndFlagsEjj($length, 4);
  HEAP32[$this >> 2] = $1;
  HEAP32[$this + 4 >> 2] = $chars;
  return;
}

function __ZN2JSL11ObjectValueER8JSObject3902($agg_result, $obj) {
  var $1 = $obj;
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $1);
  return;
}

function __ZN2JSL11StringValueEP8JSString3909($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2JSL10Int32ValueEi3910($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE($cx, $begin, $param, $end, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = __ZN8JSString12ensureLinearEP9JSContext($1, $4);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_01 = ($end | 0) == 0 ? $begin : $end;
    var $9 = _strlen($begin);
    var $10 = $9 + 2 | 0;
    var $11 = ($param | 0) != 0;
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $parlen_0 = 0;
      var $taglen_0 = $10;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx3_val = HEAP32[$param >> 2];
    var $13 = __ZNK8JSString6lengthEv($_idx3_val);
    var $parlen_0 = $13;
    var $taglen_0 = $13 + ($9 + 5) | 0;
    __label__ = 5;
    break;
   case 5:
    var $taglen_0;
    var $parlen_0;
    var $17 = _strlen($_01);
    var $_idx2 = $5 | 0;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $18 = __ZNK8JSString6lengthEv($_idx2_val);
    var $21 = $18 + ($17 + ($taglen_0 + 3)) | 0;
    if ($21 >>> 0 > 2147483646) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __Z27js_ReportAllocationOverflowP9JSContext($4);
    var $_0 = 0;
    __label__ = 20;
    break;
   case 7:
    var $26 = ($21 << 1) + 2 | 0;
    var $27 = __ZN9JSContext7malloc_Ej($4, $26);
    var $28 = $27;
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP16[$28 >> 1] = 60;
    if (($9 | 0) == 0) {
      var $j_0_lcssa = 1;
      __label__ = 11;
      break;
    } else {
      var $j_04 = 1;
      var $i_05 = 0;
      __label__ = 9;
      break;
    }
   case 9:
    var $i_05;
    var $j_04;
    HEAP16[$28 + ($j_04 << 1) >> 1] = HEAP8[$begin + $i_05 | 0] << 24 >> 24;
    var $37 = $i_05 + 1 | 0;
    if (($37 | 0) == ($9 | 0)) {
      __label__ = 10;
      break;
    } else {
      var $j_04 = $j_04 + 1 | 0;
      var $i_05 = $37;
      __label__ = 9;
      break;
    }
   case 10:
    var $j_0_lcssa = $9 + 1 | 0;
    __label__ = 11;
    break;
   case 11:
    var $j_0_lcssa;
    if ($11) {
      __label__ = 12;
      break;
    } else {
      var $j_1 = $j_0_lcssa;
      __label__ = 13;
      break;
    }
   case 12:
    HEAP16[$28 + ($j_0_lcssa << 1) >> 1] = 61;
    var $43 = $j_0_lcssa + 2 | 0;
    HEAP16[$28 + ($j_0_lcssa + 1 << 1) >> 1] = 34;
    var $46 = $28 + ($43 << 1) | 0;
    var $param_idx_val = HEAP32[$param + 4 >> 2];
    var $47 = __ZNK14JSLinearString5charsEv($param_idx_val);
    var $48 = $47;
    _memcpy($46, $48, $parlen_0 << 1, 1);
    var $50 = $43 + $parlen_0 | 0;
    HEAP16[$28 + ($50 << 1) >> 1] = 34;
    var $j_1 = $50 + 1 | 0;
    __label__ = 13;
    break;
   case 13:
    var $j_1;
    var $54 = $j_1 + 1 | 0;
    HEAP16[$28 + ($j_1 << 1) >> 1] = 62;
    var $57 = $28 + ($54 << 1) | 0;
    var $_idx4_val = HEAP32[$5 + 4 >> 2];
    var $58 = __ZNK14JSLinearString5charsEv($_idx4_val);
    var $59 = $58;
    var $_idx1_val = HEAP32[$_idx2 >> 2];
    var $60 = __ZNK8JSString6lengthEv($_idx1_val);
    var $61 = $60 << 1;
    _memcpy($57, $59, $61, 1);
    var $_idx_val = HEAP32[$_idx2 >> 2];
    var $62 = __ZNK8JSString6lengthEv($_idx_val);
    var $63 = $62 + $54 | 0;
    var $64 = $63 + 1 | 0;
    HEAP16[$28 + ($63 << 1) >> 1] = 60;
    var $66 = $63 + 2 | 0;
    HEAP16[$28 + ($64 << 1) >> 1] = 47;
    if (($17 | 0) == 0) {
      var $j_2_lcssa = $66;
      __label__ = 17;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $70 = $17 + $62 + $j_1 | 0;
    var $j_22 = $66;
    var $i1_03 = 0;
    __label__ = 15;
    break;
   case 15:
    var $i1_03;
    var $j_22;
    HEAP16[$28 + ($j_22 << 1) >> 1] = HEAP8[$_01 + $i1_03 | 0] << 24 >> 24;
    var $77 = $i1_03 + 1 | 0;
    if (($77 | 0) == ($17 | 0)) {
      __label__ = 16;
      break;
    } else {
      var $j_22 = $j_22 + 1 | 0;
      var $i1_03 = $77;
      __label__ = 15;
      break;
    }
   case 16:
    var $j_2_lcssa = $70 + 3 | 0;
    __label__ = 17;
    break;
   case 17:
    var $j_2_lcssa;
    HEAP16[$28 + ($j_2_lcssa << 1) >> 1] = 62;
    HEAP16[$28 + ($j_2_lcssa + 1 << 1) >> 1] = 0;
    var $83 = __Z12js_NewStringP9JSContextPtj($cx, $28, $21);
    if (($83 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    __ZN2js10Foreground5free_EPv($27);
    var $_0 = 0;
    __label__ = 20;
    break;
   case 19:
    var $87 = $83 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $87);
    var $_0 = 1;
    __label__ = 20;
    break;
   case 20:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE["X"] = 1;

function __ZL12tagify_valueP9JSContextjPN2JS5ValueEPKcS5_($cx, $argc, $vp, $begin, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($cx, $argc, $vp, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE($cx, $begin, $1, $end, $vp);
    var $_0 = $4 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19ValueToIntegerRangeP9JSContextRKN2JS5ValueEPi($cx, $v, $out) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $v_idx1 = $v | 0;
    var $v_idx1_val$0 = HEAP32[$v_idx1 >> 2];
    var $v_idx1_val$1 = HEAP32[$v_idx1 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx1_val$0, $v_idx1_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx1_val$0, $v_idx1_val$1);
    HEAP32[$out >> 2] = $3;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    var $5 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd3824($cx, $v, $d);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 4:
    var $7 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    if ($7 > 2147483647) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    HEAP32[$out >> 2] = 2147483647;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 6:
    if ($7 < -2147483648) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    HEAP32[$out >> 2] = -2147483648;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 8:
    var $14 = $7 & -1;
    HEAP32[$out >> 2] = $14;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15VALUE_IS_REGEXPP9JSContextN2JS5ValueE($_0_0_0_val$0, $_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value11isPrimitiveEv($_0_0_0_val$0, $_0_0_0_val$1);
    if ($1) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($_0_0_0_val$0, $_0_0_0_val$1);
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZNK8JSObject8isRegExpEv($_idx_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11SplitHelperI18SplitRegExpMatcherEP8JSObjectP9JSContextP14JSLinearStringjT_PN2js5types10TypeObjectE($cx, $str, $limit, $splitMatch_0, $splitMatch_1, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $splitMatch = __stackBase__;
    HEAP32[$splitMatch >> 2] = $splitMatch_0;
    HEAP32[$splitMatch + 4 >> 2] = $splitMatch_1;
    var $result = STACKTOP;
    STACKTOP += 8;
    var $v = STACKTOP;
    STACKTOP += 8;
    var $splits = STACKTOP;
    STACKTOP += 92;
    var $1 = STACKTOP;
    STACKTOP += 8;
    var $parsub = STACKTOP;
    STACKTOP += 8;
    var $2 = STACKTOP;
    STACKTOP += 8;
    var $3 = STACKTOP;
    STACKTOP += 8;
    var $4 = STACKTOP;
    STACKTOP += 8;
    var $5 = STACKTOP;
    STACKTOP += 8;
    var $6 = $str | 0;
    var $_idx_val = HEAP32[$str >> 2];
    var $7 = __ZNK8JSString6lengthEv($_idx_val);
    if (($7 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $10 = __ZN18SplitRegExpMatcherclEP9JSContextP14JSLinearStringjP16SplitMatchResult($splitMatch, $cx, $str, 0, $result);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 3:
    var $result_idx5_val = HEAP32[$result >> 2];
    var $12 = __ZNK16SplitMatchResult9isFailureEv($result_idx5_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $cx;
    var $15 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($14);
    var $_1 = $15;
    __label__ = 30;
    break;
   case 5:
    __ZN2JSL11StringValueEP8JSString3909($v, $6);
    var $18 = $cx;
    var $19 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($18, 1, $v);
    var $_1 = $19;
    __label__ = 30;
    break;
   case 6:
    var $22 = $splits;
    var $23 = $cx;
    __ZN2js15AutoValueVectorC1EP9JSContext($22, $23);
    var $24 = $splits;
    var $25 = $parsub + 4 | 0;
    var $26 = $parsub | 0;
    var $result_idx = $result | 0;
    var $result_idx6 = $result + 4 | 0;
    var $_idx4 = $1 | 0;
    var $_idx3 = $2 | 0;
    var $_idx8 = $3 | 0;
    var $_idx2 = $4 | 0;
    var $lastEndIndex_0_ph = 0;
    __label__ = 7;
    break;
   case 7:
    var $lastEndIndex_0_ph;
    var $index_0 = $lastEndIndex_0_ph;
    __label__ = 8;
    break;
   case 8:
    var $index_0;
    if ($index_0 >>> 0 < $7 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 9:
    var $30 = __ZN18SplitRegExpMatcherclEP9JSContextP14JSLinearStringjP16SplitMatchResult($splitMatch, $cx, $str, $index_0, $result);
    if ($30) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 10:
    var $result_idx_val = HEAPU32[$result_idx >> 2];
    var $32 = __ZNK16SplitMatchResult9isFailureEv($result_idx_val);
    if ($32) {
      __label__ = 26;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $result_idx6_val = HEAP32[$result_idx6 >> 2];
    var $34 = __ZNK16SplitMatchResult6lengthEv($result_idx6_val);
    var $35 = __ZNK16SplitMatchResult8endIndexEv($result_idx_val);
    if (($34 | 0) == 0 & ($35 | 0) == ($7 | 0)) {
      __label__ = 26;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (($35 | 0) == ($lastEndIndex_0_ph | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $index_0 = $index_0 + 1 | 0;
    __label__ = 8;
    break;
   case 14:
    var $43 = $35 - ($34 + $lastEndIndex_0_ph) | 0;
    var $44 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $6, $lastEndIndex_0_ph, $43);
    if (($44 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $47 = $44 | 0;
    __ZN2JSL11StringValueEP8JSString3909($1, $47);
    var $st$2$0 = $_idx4 | 0;
    var $_idx4_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx4 + 4 | 0;
    var $_idx4_val$1 = HEAP32[$st$2$1 >> 2];
    var $48 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($24, $_idx4_val$0, $_idx4_val$1);
    if ($48) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 16:
    var $50 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($24);
    if (($50 | 0) == ($limit | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $53 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($24);
    var $54 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($23, $50, $53);
    var $_0 = $54;
    __label__ = 29;
    break;
   case 18:
    var $57 = __ZN9JSContext13regExpStaticsEv($23);
    var $i_0 = 0;
    __label__ = 19;
    break;
   case 19:
    var $i_0;
    var $59 = __ZNK2js13RegExpStatics10parenCountEv($57);
    if ($i_0 >>> 0 < $59 >>> 0) {
      __label__ = 20;
      break;
    } else {
      var $lastEndIndex_0_ph = $35;
      __label__ = 7;
      break;
    }
   case 20:
    var $62 = $i_0 + 1 | 0;
    var $63 = __ZNK2js13RegExpStatics13pairIsPresentEj($57, $62);
    if ($63) {
      __label__ = 21;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 21:
    __ZNK2js13RegExpStatics8getParenEjP11JSSubString($57, $62, $parsub);
    var $65 = HEAP32[$25 >> 2];
    var $66 = HEAP32[$26 >> 2];
    var $67 = __Z17js_NewStringCopyNP9JSContextPKtj($cx, $65, $66);
    if (($67 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $70 = $67 | 0;
    __ZN2JSL11StringValueEP8JSString3909($2, $70);
    var $st$2$0 = $_idx3 | 0;
    var $_idx3_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx3 + 4 | 0;
    var $_idx3_val$1 = HEAP32[$st$2$1 >> 2];
    var $71 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($24, $_idx3_val$0, $_idx3_val$1);
    if ($71) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 23:
    __ZN2JSL14UndefinedValueEv3828($3);
    var $_idx8_val$0 = HEAP32[$_idx8 >> 2];
    var $_idx8_val$1 = HEAP32[$_idx8 + 4 >> 2];
    __ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcRKN2JS5ValueE($cx, $type, $_idx8_val$0, $_idx8_val$1);
    __ZN2JSL14UndefinedValueEv3828($4);
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    var $73 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($24, $_idx2_val$0, $_idx2_val$1);
    if ($73) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 24:
    var $75 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($24);
    if (($75 | 0) == ($limit | 0)) {
      __label__ = 25;
      break;
    } else {
      var $i_0 = $62;
      __label__ = 19;
      break;
    }
   case 25:
    var $78 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($24);
    var $79 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($23, $75, $78);
    var $_0 = $79;
    __label__ = 29;
    break;
   case 26:
    var $82 = $7 - $lastEndIndex_0_ph | 0;
    var $83 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $6, $lastEndIndex_0_ph, $82);
    if (($83 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $86 = $83 | 0;
    __ZN2JSL11StringValueEP8JSString3909($5, $86);
    var $_idx1 = $5 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $87 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($24, $_idx1_val$0, $_idx1_val$1);
    if ($87) {
      __label__ = 28;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 28:
    var $89 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($24);
    var $90 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($24);
    var $91 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($23, $89, $90);
    var $_0 = $91;
    __label__ = 29;
    break;
   case 29:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($22);
    var $_1 = $_0;
    __label__ = 30;
    break;
   case 30:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11SplitHelperI18SplitRegExpMatcherEP8JSObjectP9JSContextP14JSLinearStringjT_PN2js5types10TypeObjectE["X"] = 1;

function __ZN18SplitRegExpMatcherC1EPN2js6RegExpEPNS0_13RegExpStaticsE($this, $re, $res) {
  __ZN18SplitRegExpMatcherC2EPN2js6RegExpEPNS0_13RegExpStaticsE($this, $re, $res);
  return;
}

function __ZL11SplitHelperI18SplitStringMatcherEP8JSObjectP9JSContextP14JSLinearStringjT_PN2js5types10TypeObjectE($cx, $str, $limit, $splitMatch_0, $splitMatch_1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 124;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $v = __stackBase__ + 8;
    var $splits = __stackBase__ + 16;
    var $1 = __stackBase__ + 108;
    var $2 = __stackBase__ + 116;
    var $3 = $str | 0;
    var $_idx_val = HEAP32[$str >> 2];
    var $4 = __ZNK8JSString6lengthEv($_idx_val);
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    __ZN18SplitStringMatcherclEP9JSContextP14JSLinearStringjP16SplitMatchResult($splitMatch_0, $splitMatch_1, $str, 0, $result);
    var $result_idx3_val = HEAP32[$result >> 2];
    var $7 = __ZNK16SplitMatchResult9isFailureEv($result_idx3_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $cx;
    var $10 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($9);
    var $_1 = $10;
    __label__ = 20;
    break;
   case 4:
    __ZN2JSL11StringValueEP8JSString3909($v, $3);
    var $13 = $cx;
    var $14 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($13, 1, $v);
    var $_1 = $14;
    __label__ = 20;
    break;
   case 5:
    var $17 = $splits;
    var $18 = $cx;
    __ZN2js15AutoValueVectorC1EP9JSContext($17, $18);
    var $19 = $splits;
    var $result_idx = $result | 0;
    var $result_idx4 = $result + 4 | 0;
    var $_idx2 = $1 | 0;
    var $lastEndIndex_0_ph = 0;
    __label__ = 6;
    break;
   case 6:
    var $lastEndIndex_0_ph;
    var $index_0 = $lastEndIndex_0_ph;
    __label__ = 7;
    break;
   case 7:
    var $index_0;
    if ($index_0 >>> 0 < $4 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 8:
    __ZN18SplitStringMatcherclEP9JSContextP14JSLinearStringjP16SplitMatchResult($splitMatch_0, $splitMatch_1, $str, $index_0, $result);
    var $result_idx_val = HEAPU32[$result_idx >> 2];
    var $23 = __ZNK16SplitMatchResult9isFailureEv($result_idx_val);
    if ($23) {
      __label__ = 16;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $result_idx4_val = HEAP32[$result_idx4 >> 2];
    var $25 = __ZNK16SplitMatchResult6lengthEv($result_idx4_val);
    var $26 = __ZNK16SplitMatchResult8endIndexEv($result_idx_val);
    if (($25 | 0) == 0 & ($26 | 0) == ($4 | 0)) {
      __label__ = 16;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if (($26 | 0) == ($lastEndIndex_0_ph | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $index_0 = $index_0 + 1 | 0;
    __label__ = 7;
    break;
   case 12:
    var $34 = $26 - ($25 + $lastEndIndex_0_ph) | 0;
    var $35 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $3, $lastEndIndex_0_ph, $34);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $38 = $35 | 0;
    __ZN2JSL11StringValueEP8JSString3909($1, $38);
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    var $39 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($19, $_idx2_val$0, $_idx2_val$1);
    if ($39) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 14:
    var $41 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($19);
    if (($41 | 0) == ($limit | 0)) {
      __label__ = 15;
      break;
    } else {
      var $lastEndIndex_0_ph = $26;
      __label__ = 6;
      break;
    }
   case 15:
    var $44 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($19);
    var $45 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($18, $41, $44);
    var $_0 = $45;
    __label__ = 19;
    break;
   case 16:
    var $48 = $4 - $lastEndIndex_0_ph | 0;
    var $49 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $3, $lastEndIndex_0_ph, $48);
    if (($49 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $52 = $49 | 0;
    __ZN2JSL11StringValueEP8JSString3909($2, $52);
    var $_idx1 = $2 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $53 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($19, $_idx1_val$0, $_idx1_val$1);
    if ($53) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 18:
    var $55 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($19);
    var $56 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($19);
    var $57 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($18, $55, $56);
    var $_0 = $57;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($17);
    var $_1 = $_0;
    __label__ = 20;
    break;
   case 20:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11SplitHelperI18SplitStringMatcherEP8JSObjectP9JSContextP14JSLinearStringjT_PN2js5types10TypeObjectE["X"] = 1;

function __ZN18SplitStringMatcherC1EP14JSLinearString($this, $sep) {
  __ZN18SplitStringMatcherC2EP14JSLinearString($this, $sep);
  return;
}

function __ZN18SplitStringMatcherC2EP14JSLinearString($this, $sep) {
  var $sep_idx_val = HEAP32[$sep + 4 >> 2];
  var $1 = __ZNK14JSLinearString5charsEv($sep_idx_val);
  HEAP32[$this >> 2] = $1;
  var $_idx_val = HEAP32[$sep >> 2];
  var $3 = __ZNK8JSString6lengthEv($_idx_val);
  HEAP32[$this + 4 >> 2] = $3;
  return;
}

function __ZN18SplitStringMatcherclEP9JSContextP14JSLinearStringjP16SplitMatchResult($this_0_0_val, $this_0_1_val, $str, $index, $res) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str_idx_val = HEAP32[$str + 4 >> 2];
    var $1 = __ZNK14JSLinearString5charsEv($str_idx_val);
    var $2 = $1 + ($index << 1) | 0;
    var $_idx_val = HEAP32[$str >> 2];
    var $3 = __ZNK8JSString6lengthEv($_idx_val);
    var $4 = $3 - $index | 0;
    var $5 = __ZL11StringMatchPKtjS0_j($2, $4, $this_0_0_val, $this_0_1_val);
    if (($5 | 0) == -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN16SplitMatchResult10setFailureEv($res);
    __label__ = 4;
    break;
   case 3:
    var $10 = $this_0_1_val + $index + $5 | 0;
    __ZN16SplitMatchResult9setResultEjj($res, $this_0_1_val, $10);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK16SplitMatchResult8endIndexEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js12AutoRefCountINS_6RegExpEEdeEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK10RegExpPair5reobjEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK9FlatMatch13patternLengthEv($this_0_2_val) {
  return $this_0_2_val;
}

function __ZNK2js18StringSegmentRange5frontEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZN2js6RegExp10isMetaCharEt($c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $c & 65535;
    if (($1 | 0) == 94 || ($1 | 0) == 36 || ($1 | 0) == 92 || ($1 | 0) == 46 || ($1 | 0) == 42 || ($1 | 0) == 43 || ($1 | 0) == 63 || ($1 | 0) == 40 || ($1 | 0) == 41 || ($1 | 0) == 91 || ($1 | 0) == 93 || ($1 | 0) == 123 || ($1 | 0) == 125 || ($1 | 0) == 124) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12AutoRefCountINS_6RegExpEE4nullEv($this_0_1_val) {
  return ($this_0_1_val | 0) == 0;
}

function __ZNK2js18StringSegmentRange5emptyEv($this_0_1_val) {
  return ($this_0_1_val | 0) == 0;
}

function __ZL15JSDOUBLE_IS_NaNd3930($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZL18JSDOUBLE_IS_FINITEd3932($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function __ZN16SplitMatchResult10setFailureEv($this) {
  HEAP32[$this >> 2] = -1;
  return;
}

function __ZN16SplitMatchResult9setResultEjj($this, $length, $endIndex) {
  HEAP32[$this + 4 >> 2] = $length;
  HEAP32[$this >> 2] = $endIndex;
  return;
}

function __ZN9ManualCmp13computeExtentEPKtj($pat, $patlen) {
  return $pat + ($patlen << 1) | 0;
}

function __ZN9ManualCmp5matchEPKtS1_S1_($p, $t, $extent) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $p;
    var $_02 = $t;
    __label__ = 2;
    break;
   case 2:
    var $_02;
    var $_01;
    if (($_01 | 0) == ($extent | 0)) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (HEAP16[$_01 >> 1] << 16 >> 16 == HEAP16[$_02 >> 1] << 16 >> 16) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_01 = $_01 + 2 | 0;
    var $_02 = $_02 + 2 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18SplitRegExpMatcherC2EPN2js6RegExpEPNS0_13RegExpStaticsE($this, $re, $res) {
  HEAP32[$this >> 2] = $res;
  HEAP32[$this + 4 >> 2] = $re;
  return;
}

function __ZN9FlatMatchC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  return;
}

function __ZN2js12AutoRefCountINS_6RegExpEEC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZNK9FlatMatch7patternEv($this_0_0_val) {
  return $this_0_0_val | 0;
}

function __ZL11StringMatchPKtjS0_j($text, $textlen, $pat, $patlen) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($patlen | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($textlen >>> 0 < $patlen >>> 0) {
      var $_0 = -1;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($textlen >>> 0 > 511) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    if (($patlen - 11 | 0) >>> 0 < 245) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $9 = __Z21js_BoyerMooreHorspoolPKtjS0_j($text, $textlen, $pat, $patlen);
    if (($9 | 0) == -2) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $9;
      __label__ = 7;
      break;
    }
   case 6:
    var $12 = __ZL13UnrolledMatchI9ManualCmpEiPKtjS2_j($text, $textlen, $pat, $patlen);
    var $_0 = $12;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13UnrolledMatchI9ManualCmpEiPKtjS2_j($text, $textlen, $pat, $patlen) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_sum = 1 - $patlen + $textlen | 0;
    var $2 = $text + ($_sum << 1) | 0;
    var $3 = HEAP16[$pat >> 1];
    var $4 = $pat + 2 | 0;
    var $5 = __ZN9ManualCmp13computeExtentEPKtj($pat, $patlen);
    var $6 = $text;
    var $7 = $_sum & 7;
    if (($7 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($7 | 0) == 7) {
      var $t_0 = $text;
      __label__ = 3;
      break;
    } else if (($7 | 0) == 6) {
      var $t_1 = $text;
      __label__ = 4;
      break;
    } else if (($7 | 0) == 5) {
      var $t_2 = $text;
      __label__ = 5;
      break;
    } else if (($7 | 0) == 4) {
      var $t_3 = $text;
      __label__ = 6;
      break;
    } else if (($7 | 0) == 3) {
      var $t_4 = $text;
      __label__ = 7;
      break;
    } else if (($7 | 0) == 2) {
      var $t_5 = $text;
      __label__ = 8;
      break;
    } else if (($7 | 0) == 1) {
      var $t_6 = $text;
      __label__ = 9;
      break;
    } else {
      var $t_7 = $text;
      __label__ = 10;
      break;
    }
   case 2:
    var $9 = $text + 2 | 0;
    if (HEAP16[$text >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $9;
      var $fixup_0 = 8;
      __label__ = 20;
      break;
    } else {
      var $t_0 = $9;
      __label__ = 3;
      break;
    }
   case 3:
    var $t_0;
    var $13 = $t_0 + 2 | 0;
    if (HEAP16[$t_0 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $13;
      var $fixup_0 = 7;
      __label__ = 20;
      break;
    } else {
      var $t_1 = $13;
      __label__ = 4;
      break;
    }
   case 4:
    var $t_1;
    var $17 = $t_1 + 2 | 0;
    if (HEAP16[$t_1 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $17;
      var $fixup_0 = 6;
      __label__ = 20;
      break;
    } else {
      var $t_2 = $17;
      __label__ = 5;
      break;
    }
   case 5:
    var $t_2;
    var $21 = $t_2 + 2 | 0;
    if (HEAP16[$t_2 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $21;
      var $fixup_0 = 5;
      __label__ = 20;
      break;
    } else {
      var $t_3 = $21;
      __label__ = 6;
      break;
    }
   case 6:
    var $t_3;
    var $25 = $t_3 + 2 | 0;
    if (HEAP16[$t_3 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $25;
      var $fixup_0 = 4;
      __label__ = 20;
      break;
    } else {
      var $t_4 = $25;
      __label__ = 7;
      break;
    }
   case 7:
    var $t_4;
    var $29 = $t_4 + 2 | 0;
    if (HEAP16[$t_4 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $29;
      var $fixup_0 = 3;
      __label__ = 20;
      break;
    } else {
      var $t_5 = $29;
      __label__ = 8;
      break;
    }
   case 8:
    var $t_5;
    var $33 = $t_5 + 2 | 0;
    if (HEAP16[$t_5 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $33;
      var $fixup_0 = 2;
      __label__ = 20;
      break;
    } else {
      var $t_6 = $33;
      __label__ = 9;
      break;
    }
   case 9:
    var $t_6;
    var $37 = $t_6 + 2 | 0;
    if (HEAP16[$t_6 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $37;
      var $fixup_0 = 1;
      __label__ = 20;
      break;
    } else {
      var $t_7 = $37;
      __label__ = 10;
      break;
    }
   case 10:
    var $t_7;
    if (($t_7 | 0) == ($2 | 0)) {
      var $_0 = -1;
      __label__ = 23;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $44 = $t_7 + 2 | 0;
    if (HEAP16[$t_7 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $44;
      var $fixup_0 = 8;
      __label__ = 20;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $48 = $t_7 + 4 | 0;
    if (HEAP16[$44 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $48;
      var $fixup_0 = 7;
      __label__ = 20;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $52 = $t_7 + 6 | 0;
    if (HEAP16[$48 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $52;
      var $fixup_0 = 6;
      __label__ = 20;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $56 = $t_7 + 8 | 0;
    if (HEAP16[$52 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $56;
      var $fixup_0 = 5;
      __label__ = 20;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $60 = $t_7 + 10 | 0;
    if (HEAP16[$56 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $60;
      var $fixup_0 = 4;
      __label__ = 20;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $64 = $t_7 + 12 | 0;
    if (HEAP16[$60 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $64;
      var $fixup_0 = 3;
      __label__ = 20;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $68 = $t_7 + 14 | 0;
    if (HEAP16[$64 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $68;
      var $fixup_0 = 2;
      __label__ = 20;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $72 = $t_7 + 16 | 0;
    if (HEAP16[$68 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $72;
      var $fixup_0 = 1;
      __label__ = 20;
      break;
    } else {
      var $t_7 = $72;
      __label__ = 10;
      break;
    }
   case 19:
    var $74 = $t_9 + 2 | 0;
    if (HEAP16[$t_9 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $74;
      var $fixup_0 = $83;
      __label__ = 20;
      break;
    } else {
      var $t_9 = $74;
      var $fixup_1 = $83;
      __label__ = 22;
      break;
    }
   case 20:
    var $fixup_0;
    var $t_8;
    var $77 = __ZN9ManualCmp5matchEPKtS1_S1_($4, $t_8, $5);
    if ($77) {
      __label__ = 21;
      break;
    } else {
      var $t_9 = $t_8;
      var $fixup_1 = $fixup_0;
      __label__ = 22;
      break;
    }
   case 21:
    var $_0 = ($t_8 - $6 >> 1) - 1 | 0;
    __label__ = 23;
    break;
   case 22:
    var $fixup_1;
    var $t_9;
    var $83 = $fixup_1 - 1 & 255;
    if ($83 << 24 >> 24 == 0) {
      var $t_7 = $t_9;
      __label__ = 10;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 23:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13UnrolledMatchI9ManualCmpEiPKtjS2_j["X"] = 1;

function __ZN18SplitRegExpMatcherclEP9JSContextP14JSLinearStringjP16SplitMatchResult($this, $cx, $str, $index, $result) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $rval = __stackBase__ + 4;
    var $sep = __stackBase__ + 12;
    HEAP32[$1 >> 2] = $index;
    __ZN2JSL14UndefinedValueEv3828($rval);
    var $3 = HEAP32[$this + 4 >> 2];
    var $4 = $this | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $str | 0;
    var $7 = $cx;
    var $8 = __ZN2js6RegExp7executeEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE($3, $7, $5, $6, $1, 1, $rval);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $rval_idx = $rval | 0;
    var $rval_idx_val$0 = HEAP32[$rval_idx >> 2];
    var $rval_idx_val$1 = HEAP32[$rval_idx + 4 >> 2];
    var $10 = __ZNK2JS5Value6isTrueEv($rval_idx_val$0, $rval_idx_val$1);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN16SplitMatchResult10setFailureEv($result);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 4:
    var $13 = HEAP32[$4 >> 2];
    __ZNK2js13RegExpStatics12getLastMatchEP11JSSubString($13, $sep);
    var $15 = HEAP32[$sep >> 2];
    var $16 = HEAP32[$1 >> 2];
    __ZN16SplitMatchResult9setResultEjj($result, $15, $16);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics10parenCountEv($this) {
  var $1 = __ZNK2js13RegExpStatics9pairCountEv($this);
  return $1 - 1 | 0;
}

function __ZNK2js13RegExpStatics13pairIsPresentEj($this, $pairNum) {
  var $1 = __ZNK2js13RegExpStatics3getEjb($this, $pairNum, 0);
  return ($1 | 0) > -1;
}

function __ZNK2js13RegExpStatics8getParenEjP11JSSubString($this, $pairNum, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js13RegExpStatics13pairIsPresentEj($this, $pairNum);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $out;
    var $$emscripten$temp$0 = _js_EmptySubString;
    var $4$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $4$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    HEAP32[$3 >> 2] = $4$0;
    HEAP32[$3 + 4 >> 2] = $4$1;
    __label__ = 4;
    break;
   case 3:
    var $_idx_val = HEAP32[HEAP32[$this + 92 >> 2] + 4 >> 2];
    var $8 = __ZNK14JSLinearString5charsEv($_idx_val);
    var $9 = __ZNK2js13RegExpStatics3getEjb($this, $pairNum, 0);
    var $10 = $8 + ($9 << 1) | 0;
    HEAP32[$out + 4 >> 2] = $10;
    var $12 = __ZNK2js13RegExpStatics14getParenLengthEj($this, $pairNum);
    HEAP32[$out >> 2] = $12;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcRKN2JS5ValueE($cx, $obj, $value_0_0_0_val$0, $value_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $_idx_val = HEAP8[$cx + 232 | 0];
    var $3 = __ZN9JSContext20typeInferenceEnabledEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$obj + 12 >> 2];
    var $6 = __ZN2js5types10TypeObject17unknownPropertiesEv($_idx1_val);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $obj;
    __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextPKcRKN2JS5ValueE($8, $1, $value_0_0_0_val$0, $value_0_0_0_val$1);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics14getParenLengthEj($this, $pairNum) {
  var $1 = __ZNK2js13RegExpStatics3getEjb($this, $pairNum, 1);
  var $2 = __ZNK2js13RegExpStatics3getEjb($this, $pairNum, 0);
  return $1 - $2 | 0;
}

function __ZNK2js13RegExpStatics12getLastMatchEP11JSSubString($this, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js13RegExpStatics9pairCountEv($this);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $out;
    var $$emscripten$temp$0 = _js_EmptySubString;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    HEAP32[$4 >> 2] = $5$0;
    HEAP32[$4 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 3:
    var $_idx_val = HEAP32[HEAP32[$this + 92 >> 2] + 4 >> 2];
    var $9 = __ZNK14JSLinearString5charsEv($_idx_val);
    var $10 = __ZNK2js13RegExpStatics3getEjb($this, 0, 0);
    var $11 = $9 + ($10 << 1) | 0;
    HEAP32[$out + 4 >> 2] = $11;
    var $13 = __ZNK2js13RegExpStatics3getEjb($this, 0, 1);
    var $14 = __ZNK2js13RegExpStatics3getEjb($this, 0, 0);
    HEAP32[$out >> 2] = $13 - $14 | 0;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11RegExpGuardC1EP9JSContext($this, $cx) {
  __ZN11RegExpGuardC2EP9JSContext($this, $cx);
  return;
}

function __ZN11RegExpGuard15normalizeRegExpEbjjPN2JS5ValueE($this, $flat, $optarg, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $re = __stackBase__;
    var $1 = $this + 4 | 0;
    var $2 = __ZNK10RegExpPair9hasRegExpEv($1);
    if ($2) {
      var $_0 = $1;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($optarg >>> 0 < $argc >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $opt_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = HEAP32[$this >> 2];
    var $_idx = $vp + ($optarg + 2 << 3) | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $9 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($7, $_idx_val$0, $_idx_val$1);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      var $opt_0 = $9;
      __label__ = 4;
      break;
    }
   case 4:
    var $opt_0;
    if ($flat) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $13 = $this | 0;
    var $14 = HEAP32[$13 >> 2];
    var $16 = HEAP32[$this + 16 >> 2];
    var $17 = __ZN11RegExpGuard14flattenPatternEP9JSContextP14JSLinearString($14, $16);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      var $patstr_0 = $17;
      var $_pre_phi = $13;
      __label__ = 7;
      break;
    }
   case 6:
    var $patstr_0 = HEAP32[$this + 16 >> 2] | 0;
    var $_pre_phi = $this | 0;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $patstr_0;
    var $25 = HEAP32[$_pre_phi >> 2];
    __ZN2js6RegExp13createFlaggedEP9JSContextP8JSStringS4_PNS_11TokenStreamE($re, $25, $patstr_0, $opt_0);
    var $re_idx_val = HEAP32[$re >> 2];
    var $26 = __ZNK2js15AlreadyIncRefedINS_6RegExpEEcvPPPPPS1_Ev($re_idx_val);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN10RegExpPair5resetEN2js15AlreadyIncRefedINS0_6RegExpEEE($1, $re_idx_val);
    var $_0 = $1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK10RegExpPair2reEv($this) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $1 = __ZNK2js12AutoRefCountINS_6RegExpEEdeEv($_idx_val);
  return $1;
}

function __ZNK2js13RegExpStatics10matchStartEv($this) {
  var $1 = __ZNK2js13RegExpStatics3getEjb($this, 0, 0);
  return $1;
}

function __ZN11RegExpGuardD1Ev($this) {
  __ZN11RegExpGuardD2Ev($this);
  return;
}

function __ZN11RegExpGuardD2Ev($this) {
  var $1 = $this + 4 | 0;
  __ZN10RegExpPairD1Ev($1);
  return;
}

function __ZN10RegExpPairD1Ev($this) {
  __ZN10RegExpPairD2Ev($this);
  return;
}

function __ZN10RegExpPairD2Ev($this) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  __ZN2js12AutoRefCountINS_6RegExpEED1Ev($_idx_val);
  return;
}

function __ZNK10RegExpPair9hasRegExpEv($this) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $1 = __ZNK2js12AutoRefCountINS_6RegExpEE4nullEv($_idx_val);
  return $1 ^ 1;
}

function __ZN11RegExpGuard14flattenPatternEP9JSContextP14JSLinearString($cx, $patstr) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sb = __stackBase__;
    var $1 = $sb;
    var $2 = $cx;
    __ZN2js12StringBufferC1EP9JSContext($1, $2);
    var $_idx1 = $patstr | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $3 = __ZNK8JSString6lengthEv($_idx1_val);
    var $4 = __ZN2js12StringBuffer7reserveEj($1, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 2:
    var $patstr_idx_val = HEAP32[$patstr + 4 >> 2];
    var $6 = __ZNK14JSLinearString5charsEv($patstr_idx_val);
    var $_idx_val = HEAP32[$_idx1 >> 2];
    var $7 = __ZNK8JSString6lengthEv($_idx_val);
    var $8 = $6 + ($7 << 1) | 0;
    var $it_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $it_0;
    if (($it_0 | 0) == ($8 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = HEAP16[$it_0 >> 1];
    var $13 = __ZN2js6RegExp10isMetaCharEt($12);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $15 = __ZN2js12StringBuffer6appendEt($1, 92);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $17 = HEAP16[$it_0 >> 1];
    var $18 = __ZN2js12StringBuffer6appendEt($1, $17);
    if ($18) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    var $20 = __ZN2js12StringBuffer6appendEt($1, $12);
    if ($20) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $it_0 = $it_0 + 2 | 0;
    __label__ = 3;
    break;
   case 9:
    var $24 = __ZN2js12StringBuffer12finishStringEv($sb);
    var $_0 = $24 | 0;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    __ZN2js12StringBufferD1Ev($1);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10RegExpPair5resetEN2js15AlreadyIncRefedINS0_6RegExpEEE($this, $re_0) {
  HEAP32[$this + 8 >> 2] = 0;
  var $2 = $this | 0;
  __ZN2js12AutoRefCountINS_6RegExpEE5resetENS_15AlreadyIncRefedIS1_EE($2, $re_0);
  return;
}

function __ZN2js12AutoRefCountINS_6RegExpEE5resetENS_15AlreadyIncRefedIS1_EE($this, $aobj_0) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6RegExp6decrefEP9JSContext($2);
    __label__ = 3;
    break;
   case 3:
    var $6 = __ZNK2js15AlreadyIncRefedINS_6RegExpEE3getEv($aobj_0);
    HEAP32[$1 >> 2] = $6;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11RegExpGuardC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  var $2 = $this + 4 | 0;
  __ZN10RegExpPairC1EP9JSContext($2, $cx);
  var $3 = $this + 16 | 0;
  __ZN9FlatMatchC1Ev($3);
  return;
}

function __ZN10RegExpPairC1EP9JSContext($this, $cx) {
  __ZN10RegExpPairC2EP9JSContext($this, $cx);
  return;
}

function __ZN9FlatMatchC1Ev($this) {
  __ZN9FlatMatchC2Ev($this);
  return;
}

function __ZN10RegExpPairC2EP9JSContext($this, $cx) {
  var $1 = $this | 0;
  __ZN2js12AutoRefCountINS_6RegExpEEC1EP9JSContext($1, $cx);
  return;
}

function __ZN2js12AutoRefCountINS_6RegExpEEC1EP9JSContext($this, $cx) {
  __ZN2js12AutoRefCountINS_6RegExpEEC2EP9JSContext($this, $cx);
  return;
}

function __ZL19BuildFlatMatchArrayP9JSContextP8JSStringRK9FlatMatchPN2JS5ValueE($cx, $textstr, $fm, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $fm_idx1 = $fm + 12 | 0;
    var $fm_idx1_val = HEAP32[$fm_idx1 >> 2];
    var $4 = __ZNK9FlatMatch5matchEv($fm_idx1_val);
    if (($4 | 0) < 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value7setNullEv($vp);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 3:
    var $8 = $cx;
    var $9 = __ZN2js17NewSlowEmptyArrayEP9JSContext($8);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $9;
    __ZN2JS5Value9setObjectER8JSObject($vp, $9);
    var $fm_idx2_val = HEAP32[$fm >> 2];
    var $13 = __ZNK9FlatMatch7patternEv($fm_idx2_val);
    __ZN2JSL11StringValueEP8JSString3909($1, $13);
    var $14 = __ZN8JSObject13defineElementEP9JSContextjRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($12, $cx, 0, $1, 10, 12, 1);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = $cx + 52 | 0;
    var $21 = HEAP32[HEAP32[$17 >> 2] + 210232 >> 2] | 0;
    var $22 = __ZL12ATOM_TO_JSIDP6JSAtom3836($21);
    var $fm_idx_val = HEAP32[$fm_idx1 >> 2];
    var $23 = __ZNK9FlatMatch5matchEv($fm_idx_val);
    __ZN2JSL10Int32ValueEi3910($2, $23);
    var $24 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($9, $8, $22, $2, 10, 12, 1);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $30 = HEAP32[HEAP32[$17 >> 2] + 210236 >> 2] | 0;
    var $31 = __ZL12ATOM_TO_JSIDP6JSAtom3836($30);
    __ZN2JSL11StringValueEP8JSString3909($3, $textstr);
    var $32 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($9, $8, $31, $3, 10, 12, 1);
    var $_0 = ($32 | 0) != 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL7DoMatchP9JSContextPN2js13RegExpStaticsEP8JSStringRK10RegExpPairPFbS0_S3_jPvES9_17MatchControlFlagsPN2JS5ValueE($cx, $res, $str, $rep, $callback, $data, $flags, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $i1 = __stackBase__ + 4;
    var $1 = __ZNK10RegExpPair2reEv($rep);
    var $_idx_val = HEAP32[$1 + 16 >> 2];
    var $2 = __ZNK2js6RegExp6globalEv($_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    var $5 = ($flags & 1 | 0) != 0;
    var $rep_idx_val = HEAP32[$rep + 8 >> 2];
    var $6 = __ZNK10RegExpPair5reobjEv($rep_idx_val);
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $6;
    __ZN8JSObject19zeroRegExpLastIndexEv($9);
    __label__ = 4;
    break;
   case 4:
    HEAP32[$i >> 2] = 0;
    var $str_idx_val = HEAP32[$str >> 2];
    var $11 = __ZNK8JSString6lengthEv($str_idx_val);
    var $12 = $cx;
    var $count_0 = 0;
    var $14 = 0;
    __label__ = 5;
    break;
   case 5:
    var $14;
    var $count_0;
    if ($14 >>> 0 > $11 >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = __ZN2js6RegExp7executeEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE($1, $12, $res, $str, $i, $5, $rval);
    if ($17) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 7:
    var $19 = __ZL7MatchedbRKN2JS5ValueE($5, $rval);
    if ($19) {
      __label__ = 8;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 8:
    var $21 = FUNCTION_TABLE[$callback]($cx, $res, $count_0, $data);
    if ($21) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 9:
    var $23 = __ZNK2js13RegExpStatics7matchedEv($res);
    var $_pre_pre = HEAP32[$i >> 2];
    if ($23) {
      var $_pre = $_pre_pre;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $25 = $_pre_pre + 1 | 0;
    HEAP32[$i >> 2] = $25;
    var $_pre = $25;
    __label__ = 11;
    break;
   case 11:
    var $_pre;
    var $count_0 = $count_0 + 1 | 0;
    var $14 = $_pre;
    __label__ = 5;
    break;
   case 12:
    var $29 = ($flags & 2 | 0) != 0;
    HEAP32[$i1 >> 2] = 0;
    var $30 = $cx;
    var $31 = __ZN2js6RegExp7executeEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE($1, $30, $res, $str, $i1, $29, $rval);
    if ($31) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 13:
    if (($flags & 4 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $36 = __ZL7MatchedbRKN2JS5ValueE($29, $rval);
    if ($36) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $38 = FUNCTION_TABLE[$callback]($cx, $res, 0, $data);
    if ($38) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 16:
    var $_0 = 1;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL7DoMatchP9JSContextPN2js13RegExpStaticsEP8JSStringRK10RegExpPairPFbS0_S3_jPvES9_17MatchControlFlagsPN2JS5ValueE["X"] = 1;

function __ZL13MatchCallbackP9JSContextPN2js13RegExpStaticsEjPv($cx, $res, $count, $p) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $p;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $cx;
    var $6 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($5);
    HEAP32[$1 >> 2] = $6;
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $cx;
    var $11 = __ZNK2js13RegExpStatics15createLastMatchEP9JSContextPN2JS5ValueE($res, $10, $v);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = HEAP32[$1 >> 2];
    var $14 = __ZN8JSObject13defineElementEP9JSContextjRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($13, $cx, $count, $v, 10, 12, 1);
    var $_0 = ($14 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject13defineElementEP9JSContextjRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($this, $cx, $index, $value, $getter, $setter, $attrs) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $2 = __ZNK8JSObject6getOpsEv($_idx_val);
  var $4 = HEAP32[$2 + 24 >> 2];
  var $7 = ($4 | 0) != 0 ? $4 : 234;
  var $8 = FUNCTION_TABLE[$7]($cx, $this, $index, $value, $getter, $setter, $attrs);
  return $8;
}

function __ZL7MatchedbRKN2JS5ValueE($test, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx1 = $v | 0;
    var $v_idx1_val$0 = HEAP32[$v_idx1 >> 2];
    var $v_idx1_val$1 = HEAP32[$v_idx1 + 4 >> 2];
    if ($test) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $2 = __ZNK2JS5Value6isTrueEv($v_idx1_val$0, $v_idx1_val$1);
    var $7 = $2;
    __label__ = 4;
    break;
   case 3:
    var $4 = __ZNK2JS5Value6isNullEv($v_idx1_val$0, $v_idx1_val$1);
    var $7 = $4 ^ 1;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics7matchedEv($this) {
  var $1 = __ZNK2js13RegExpStatics3getEjb($this, 0, 1);
  var $2 = __ZNK2js13RegExpStatics3getEjb($this, 0, 0);
  return ($1 - $2 | 0) > 0;
}

function __ZL13js_TrimStringP9JSContextPN2JS5ValueEii($cx, $vp, $trimLeft, $trimRight) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$1 >> 2];
    var $4 = __ZNK8JSString6lengthEv($_idx_val);
    var $5 = $cx;
    var $6 = __ZN8JSString8getCharsEP9JSContext($1, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($trimLeft | 0) == 0) {
      var $begin_1 = 0;
      __label__ = 7;
      break;
    } else {
      var $begin_0 = 0;
      __label__ = 4;
      break;
    }
   case 4:
    var $begin_0;
    if ($begin_0 >>> 0 < $4 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $begin_1 = $begin_0;
      __label__ = 7;
      break;
    }
   case 5:
    var $13 = HEAP16[$6 + ($begin_0 << 1) >> 1];
    var $14 = __ZN2js7unicode7IsSpaceEt($13);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      var $begin_1 = $begin_0;
      __label__ = 7;
      break;
    }
   case 6:
    var $begin_0 = $begin_0 + 1 | 0;
    __label__ = 4;
    break;
   case 7:
    var $begin_1;
    if (($trimRight | 0) == 0) {
      var $end_1 = $4;
      __label__ = 10;
      break;
    } else {
      var $end_0 = $4;
      __label__ = 8;
      break;
    }
   case 8:
    var $end_0;
    if ($end_0 >>> 0 > $begin_1 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $end_1 = $end_0;
      __label__ = 10;
      break;
    }
   case 9:
    var $20 = $end_0 - 1 | 0;
    var $22 = HEAP16[$6 + ($20 << 1) >> 1];
    var $23 = __ZN2js7unicode7IsSpaceEt($22);
    if ($23) {
      var $end_0 = $20;
      __label__ = 8;
      break;
    } else {
      var $end_1 = $end_0;
      __label__ = 10;
      break;
    }
   case 10:
    var $end_1;
    var $25 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $1, $begin_1, $end_1 - $begin_1 | 0);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $28 = $25 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $28);
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18js_DoubleToIntegerd3931($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d == 0) {
      var $_0 = $d;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL18JSDOUBLE_IS_FINITEd3932($d);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZL15JSDOUBLE_IS_NaNd3930($d);
    var $d_ = ($6 | 0) == 0 ? $d : 0;
    var $_0 = $d_;
    __label__ = 7;
    break;
   case 4:
    if ($d < 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = _floor($d);
    var $_0 = $10;
    __label__ = 7;
    break;
   case 6:
    var $12 = -$d;
    var $13 = _floor($12);
    var $_0 = -$13;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11ReplaceDataD2Ev($this) {
  var $2 = $this + 96 | 0;
  __ZN2js12StringBufferD1Ev($2);
  var $4 = $this + 72 | 0;
  __ZN2js15InvokeArgsGuardD1Ev($4);
  var $5 = $this + 4 | 0;
  __ZN11RegExpGuardD1Ev($5);
  return;
}

function __ZN2js11RopeBuilderC1EP9JSContext($this, $cx) {
  __ZN2js11RopeBuilderC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js18StringSegmentRangeC1EP9JSContext($this, $cx) {
  __ZN2js18StringSegmentRangeC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js18StringSegmentRange4initEP8JSString($this, $str) {
  var $1 = __ZN2js18StringSegmentRange6settleEP8JSString($this, $str);
  return $1;
}

function __ZN2js11RopeBuilder6resultEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE12beginNoCheckEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE5emptyEv($this_0_2_val) {
  return ($this_0_2_val | 0) == 0;
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE10endNoCheckEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE7popBackEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val) {
  return $this_0_1_val + ($this_0_2_val << 2) | 0;
}

function __ZN2js10VectorImplIP8JSStringLj32ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11RopeBuilderC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  var $7 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
  HEAP32[$this + 4 >> 2] = $7;
  return;
}

function __ZN2js11RopeBuilder6appendEP8JSString($this, $str) {
  var $3 = $this + 4 | 0;
  var $4 = HEAP32[$3 >> 2];
  var $5 = HEAP32[$this >> 2];
  var $6 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($5, $4, $str);
  HEAP32[$3 >> 2] = $6;
  return ($6 | 0) != 0;
}

function __ZN2js18StringSegmentRange8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this + 8 >> 2];
    var $1 = __ZNK2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE5emptyEv($_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$this + 144 >> 2] = 0;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $5 = $this | 0;
    var $6 = __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE7popCopyEv($5);
    var $7 = __ZN2js18StringSegmentRange6settleEP8JSString($this, $6);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18StringSegmentRangeD1Ev($this) {
  __ZN2js18StringSegmentRangeD2Ev($this);
  return;
}

function __ZN2js18StringSegmentRangeD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEED1Ev($1);
  return;
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZNK2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj128EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js18StringSegmentRange6settleEP8JSString($this, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_01 = $str;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $_01_idx_val = HEAP32[$_01 >> 2];
    var $3 = __ZNK8JSString6isRopeEv($_01_idx_val);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $5 = __ZN8JSString6asRopeEv($_01);
    var $6 = __ZNK6JSRope10rightChildEv($5);
    var $7 = __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE6appendIS2_EEbT_($1, $6);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZNK6JSRope9leftChildEv($5);
    var $_01 = $9;
    __label__ = 2;
    break;
   case 5:
    var $11 = __ZN8JSString8asLinearEv($_01);
    HEAP32[$this + 144 >> 2] = $11;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE7popCopyEv($this) {
  var $this_idx_val = HEAP32[$this + 4 >> 2];
  var $this_idx1_val = HEAP32[$this + 8 >> 2];
  var $1 = __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE4backEv($this_idx_val, $this_idx1_val);
  var $2 = HEAP32[$1 >> 2];
  __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE7popBackEv($this);
  return $2;
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE4backEv($this_0_1_val, $this_0_2_val) {
  var $1 = __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE3endEv($this_0_1_val, $this_0_2_val);
  return $1 - 4 | 0;
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE13growStorageByEj($this);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE13growStorageByEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE17growHeapStorageByEj($this);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $5 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    var $5 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    HEAP32[$this_idx1 >> 2] = $5 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 2;
    var $7 = $this;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($7, $6);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this + 4 | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $12 = __ZNK2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $13 = __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplIP8JSStringLj32ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $12, $13);
    HEAP32[$this_idx >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE17growHeapStorageByEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIP8JSStringLj32ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj32ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, 1);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx1_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $6;
    if ($6 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$this >> 2];
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($_idx_val);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP8JSStringLj32ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj32ES3_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v + 4 | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = $v;
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($5, $4, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $v + 12 | 0;
    var $10 = $6;
    HEAP32[$2 >> 2] = $10;
    HEAP32[$9 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP8JSStringLj32ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIP8JSStringLj32ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js18StringSegmentRangeC2EP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $3 = $1;
  var $4 = $cx;
  __ZN2js15TempAllocPolicyC1EP9JSContext($3, $4);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEEC1ES3_($2, $_0_val);
  HEAP32[$this + 144 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEEC1ES3_($this, $ap_01) {
  __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEEC2ES3_($this, $ap_01);
  return;
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEEC2ES3_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  var $2 = $this + 4 | 0;
  var $3 = $this + 16 | 0;
  var $4 = __ZN7mozilla14AlignedStorageILj128EE4addrEv($3);
  HEAP32[$2 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 32;
  return;
}

function __ZN2js12StringBuffer16infallibleAppendEPKtS2_($this, $begin, $end) {
  var $1 = $this | 0;
  __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16infallibleAppendItEEvPKT_S6_($1, $begin, $end);
  return;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16infallibleAppendItEEvPKT_S6_($this, $begin, $end) {
  var $4 = ($end - $begin | 0) >>> 1;
  var $5 = $this;
  __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendItEEvPKT_j($5, $begin, $4);
  return;
}

function __ZL21ReplaceRegExpCallbackP9JSContextPN2js13RegExpStaticsEjPv($cx, $res, $count, $p) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $replen = __stackBase__;
    var $1 = $p;
    HEAP8[$p + 68 | 0] = 1;
    var $4 = HEAP32[$p >> 2];
    var $5 = __ZN8JSString8asLinearEv($4);
    var $7 = $p + 56 | 0;
    var $8 = HEAP32[$7 >> 2];
    var $_idx_val = HEAP32[$5 + 4 >> 2];
    var $9 = __ZNK14JSLinearString5charsEv($_idx_val);
    var $10 = $9 + ($8 << 1) | 0;
    var $11 = __ZNK2js13RegExpStatics10matchStartEv($res);
    var $12 = $11 - $8 | 0;
    var $13 = __ZNK2js13RegExpStatics10matchLimitEv($res);
    HEAP32[$7 >> 2] = $13;
    HEAP32[$replen >> 2] = 0;
    var $14 = __ZL17FindReplaceLengthP9JSContextPN2js13RegExpStaticsER11ReplaceDataPj($cx, $res, $1, $replen);
    if ($14) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $16 = HEAP32[$replen >> 2];
    var $18 = $p + 96 | 0;
    var $19 = __ZNK2js12StringBuffer6lengthEv($18);
    var $21 = $16 + $12 + $19 | 0;
    var $22 = __ZN2js12StringBuffer7reserveEj($18, $21);
    if ($22) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js12StringBuffer16infallibleAppendEPKtj($18, $10, $12);
    __ZL9DoReplaceP9JSContextPN2js13RegExpStaticsER11ReplaceData($res, $1);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics15getRightContextEP11JSSubString($this, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js13RegExpStatics9pairCountEv($this);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $out;
    var $$emscripten$temp$0 = _js_EmptySubString;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    HEAP32[$4 >> 2] = $5$0;
    HEAP32[$4 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 3:
    var $7 = $this + 92 | 0;
    var $_idx1_val = HEAP32[HEAP32[$7 >> 2] + 4 >> 2];
    var $9 = __ZNK14JSLinearString5charsEv($_idx1_val);
    var $10 = __ZNK2js13RegExpStatics3getEjb($this, 0, 1);
    var $11 = $9 + ($10 << 1) | 0;
    HEAP32[$out + 4 >> 2] = $11;
    var $_idx_val = HEAP32[HEAP32[$7 >> 2] >> 2];
    var $14 = __ZNK8JSString6lengthEv($_idx_val);
    var $15 = __ZNK2js13RegExpStatics3getEjb($this, 0, 1);
    var $16 = $14 - $15 | 0;
    HEAP32[$out >> 2] = $16;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics10matchLimitEv($this) {
  var $1 = __ZNK2js13RegExpStatics3getEjb($this, 0, 1);
  return $1;
}

function __ZL17FindReplaceLengthP9JSContextPN2js13RegExpStaticsER11ReplaceDataPj($cx, $res, $rdata, $sizep) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 160;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $match = __stackBase__;
    var $holder = __stackBase__ + 8;
    var $prop = __stackBase__ + 12;
    var $staticsGuard = __stackBase__ + 16;
    var $1 = __stackBase__ + 132;
    var $2 = __stackBase__ + 140;
    var $sub = __stackBase__ + 148;
    var $skip = __stackBase__ + 156;
    var $3 = $rdata + 40 | 0;
    var $4 = HEAP32[$3 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $cx;
    var $8 = __ZNK2js13RegExpStatics15createLastMatchEP9JSContextPN2JS5ValueE($res, $7, $match);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 0;
      __label__ = 35;
      break;
    }
   case 3:
    var $match_idx = $match | 0;
    var $match_idx_val$0 = HEAP32[$match_idx >> 2];
    var $match_idx_val$1 = HEAP32[$match_idx + 4 >> 2];
    var $10 = __ZNK2JS5Value8toStringEv($match_idx_val$0, $match_idx_val$1);
    var $_idx11_val = HEAP32[$10 >> 2];
    var $11 = __ZNK8JSString6isAtomEv($_idx11_val);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = __ZNK8JSString6asAtomEv($10);
    var $atom_0 = $13;
    __label__ = 6;
    break;
   case 5:
    var $15 = $cx;
    var $16 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($15, $10);
    if (($16 | 0) == 0) {
      var $_1 = 0;
      __label__ = 35;
      break;
    } else {
      var $atom_0 = $16;
      __label__ = 6;
      break;
    }
   case 6:
    var $atom_0;
    var $19 = __ZL12ATOM_TO_JSIDP6JSAtom3836($atom_0);
    HEAP32[$prop >> 2] = 0;
    var $20 = $cx;
    var $21 = $4;
    var $22 = $holder;
    var $23 = $prop;
    var $24 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($20, $21, $19, 1, $22, $23);
    if ($24) {
      __label__ = 7;
      break;
    } else {
      var $_1 = 0;
      __label__ = 35;
      break;
    }
   case 7:
    var $26 = HEAP32[$prop >> 2];
    if (($26 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((HEAP32[$holder >> 2] | 0) == ($4 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 9:
    var $34 = HEAP32[$26 + 24 >> 2];
    if (($34 | 0) == -1) {
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_idx5_val = HEAP32[$26 + 16 >> 2];
    var $38 = __ZNK2js5Shape16hasDefaultGetterEv($_idx5_val);
    if ($38) {
      __label__ = 11;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 11:
    var $40 = $4;
    var $41 = __ZNK8JSObject7getSlotEj($40, $34);
    var $42 = $41 | 0;
    var $st$3$0 = $42 | 0;
    var $43$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $42 + 4 | 0;
    var $43$1 = HEAP32[$st$3$1 >> 2];
    var $44 = __ZNK2JS5Value8isStringEv($43$0, $43$1);
    if ($44) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $46 = __ZNK2JS5Value8toStringEv($43$0, $43$1);
    var $47 = $cx;
    var $48 = __ZN8JSString12ensureLinearEP9JSContext($46, $47);
    HEAP32[$rdata + 44 >> 2] = $48;
    if (($48 | 0) == 0) {
      var $_1 = 0;
      __label__ = 35;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $_idx4_val = HEAP32[$48 >> 2];
    var $52 = __ZNK8JSString6lengthEv($_idx4_val);
    HEAP32[$sizep >> 2] = $52;
    var $_1 = 1;
    __label__ = 35;
    break;
   case 14:
    HEAP32[$3 >> 2] = 0;
    __label__ = 15;
    break;
   case 15:
    var $56 = HEAP32[$rdata + 36 >> 2];
    if (($56 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN2js21PreserveRegExpStaticsC1EPNS_13RegExpStaticsE($staticsGuard, $res);
    var $59 = __ZN2js21PreserveRegExpStatics4initEP9JSContext($staticsGuard, $cx);
    if ($59) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 27;
      break;
    }
   case 17:
    var $61 = $rdata + 72 | 0;
    var $62 = $61;
    var $_idx13_val = HEAP32[$rdata + 88 >> 2];
    var $64 = __ZNK2js15InvokeArgsGuard6pushedEv($_idx13_val);
    if ($64) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $66 = __ZNK2js13RegExpStatics10parenCountEv($res);
    var $67 = $66 + 3 | 0;
    var $69 = $cx + 60 | 0;
    var $70 = $cx;
    var $71 = $61;
    var $72 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($69, $70, $67, $71);
    if ($72) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 27;
      break;
    }
   case 19:
    var $_idx = $61 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $74 = __ZNK2js12CallReceiver7calleevEv($_idx_val);
    __ZN2JSL11ObjectValueER8JSObject3902($1, $56);
    var $75 = $1 | 0;
    var $76$0 = HEAP32[$75 >> 2];
    var $76$1 = HEAP32[$75 + 4 >> 2];
    var $77 = $74 | 0;
    var $st$10$0 = $77 | 0;
    HEAP32[$st$10$0 >> 2] = $76$0;
    var $st$10$1 = $77 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $76$1;
    var $_idx1_val = HEAP32[$_idx >> 2];
    var $78 = __ZNK2js12CallReceiver5thisvEv($_idx1_val);
    __ZN2JSL14UndefinedValueEv3828($2);
    var $79 = $2 | 0;
    var $80$0 = HEAP32[$79 >> 2];
    var $80$1 = HEAP32[$79 + 4 >> 2];
    var $81 = $78 | 0;
    var $st$23$0 = $81 | 0;
    HEAP32[$st$23$0 >> 2] = $80$0;
    var $st$23$1 = $81 + 4 | 0;
    HEAP32[$st$23$1 >> 2] = $80$1;
    var $_idx10_val = HEAP32[$_idx >> 2];
    var $82 = __ZNK2js8CallArgsixEj($_idx10_val, 0);
    var $83 = $cx;
    var $84 = __ZNK2js13RegExpStatics15createLastMatchEP9JSContextPN2JS5ValueE($res, $83, $82);
    if ($84) {
      var $i_0 = 0;
      var $argi_0 = 1;
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 27;
      break;
    }
   case 20:
    var $argi_0;
    var $i_0;
    var $85 = __ZNK2js13RegExpStatics10parenCountEv($res);
    if ($i_0 >>> 0 < $85 >>> 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 21:
    var $88 = $i_0 + 1 | 0;
    var $_idx9_val = HEAP32[$_idx >> 2];
    var $89 = __ZNK2js8CallArgsixEj($_idx9_val, $argi_0);
    var $90 = __ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE($res, $83, $88, $89);
    if ($90) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 27;
      break;
    }
   case 22:
    var $i_0 = $88;
    var $argi_0 = $argi_0 + 1 | 0;
    __label__ = 20;
    break;
   case 23:
    var $94 = $argi_0 + 1 | 0;
    var $_idx8_val = HEAP32[$_idx >> 2];
    var $95 = __ZNK2js8CallArgsixEj($_idx8_val, $argi_0);
    var $96 = __ZNK2js13RegExpStatics10matchStartEv($res);
    __ZN2JS5Value8setInt32Ei($95, $96);
    var $_idx7_val = HEAP32[$_idx >> 2];
    var $97 = __ZNK2js8CallArgsixEj($_idx7_val, $94);
    var $99 = HEAP32[$rdata >> 2];
    __ZN2JS5Value9setStringEP8JSString($97, $99);
    var $100 = $cx;
    var $101 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($100, $62, 0);
    if ($101) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 0;
      __label__ = 27;
      break;
    }
   case 24:
    var $_idx12_val = HEAP32[$_idx >> 2];
    var $103 = __ZNK2js12CallReceiver4rvalEv($_idx12_val);
    var $_idx14 = $103 | 0;
    var $st$3$0 = $_idx14 | 0;
    var $_idx14_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx14 + 4 | 0;
    var $_idx14_val$1 = HEAP32[$st$3$1 >> 2];
    var $104 = __ZN2jsL33ValueToString_TestForStringInlineEP9JSContextRKN2JS5ValueE($cx, $_idx14_val$0, $_idx14_val$1);
    if (($104 | 0) == 0) {
      var $_0 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $107 = __ZN8JSString12ensureLinearEP9JSContext($104, $100);
    HEAP32[$rdata + 44 >> 2] = $107;
    if (($107 | 0) == 0) {
      var $_0 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $_idx3_val = HEAP32[$107 >> 2];
    var $111 = __ZNK8JSString6lengthEv($_idx3_val);
    HEAP32[$sizep >> 2] = $111;
    var $_0 = 1;
    __label__ = 27;
    break;
   case 27:
    var $_0;
    __ZN2js21PreserveRegExpStaticsD1Ev($staticsGuard);
    var $_1 = $_0;
    __label__ = 35;
    break;
   case 28:
    var $_idx2_val = HEAP32[HEAP32[$rdata + 44 >> 2] >> 2];
    var $115 = __ZNK8JSString6lengthEv($_idx2_val);
    var $117 = HEAP32[$rdata + 48 >> 2];
    var $119 = HEAP32[$rdata + 52 >> 2];
    if (($117 | 0) == 0) {
      var $replen_0_lcssa = $115;
      __label__ = 34;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $121 = $sub | 0;
    var $replen_02 = $115;
    var $dp_03 = $117;
    __label__ = 30;
    break;
   case 30:
    var $dp_03;
    var $replen_02;
    var $123 = __ZL15InterpretDollarP9JSContextPN2js13RegExpStaticsEPKtS5_R11ReplaceDataP11JSSubStringPj($res, $dp_03, $119, $rdata, $sub, $skip);
    if ($123) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    var $126 = HEAP32[$skip >> 2];
    var $dp_1 = $dp_03 + ($126 << 1) | 0;
    var $replen_1 = HEAP32[$121 >> 2] + $replen_02 - $126 | 0;
    __label__ = 33;
    break;
   case 32:
    var $dp_1 = $dp_03 + 2 | 0;
    var $replen_1 = $replen_02;
    __label__ = 33;
    break;
   case 33:
    var $replen_1;
    var $dp_1;
    var $133 = __Z15js_strchr_limitPKttS0_($dp_1, 36, $119);
    if (($133 | 0) == 0) {
      var $replen_0_lcssa = $replen_1;
      __label__ = 34;
      break;
    } else {
      var $replen_02 = $replen_1;
      var $dp_03 = $133;
      __label__ = 30;
      break;
    }
   case 34:
    var $replen_0_lcssa;
    HEAP32[$sizep >> 2] = $replen_0_lcssa;
    var $_1 = 1;
    __label__ = 35;
    break;
   case 35:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17FindReplaceLengthP9JSContextPN2js13RegExpStaticsER11ReplaceDataPj["X"] = 1;

function __ZL9DoReplaceP9JSContextPN2js13RegExpStaticsER11ReplaceData($res, $rdata) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sub = __stackBase__;
    var $skip = __stackBase__ + 8;
    var $2 = HEAP32[$rdata + 44 >> 2];
    var $_idx1_val = HEAP32[$2 + 4 >> 2];
    var $3 = __ZNK14JSLinearString5charsEv($_idx1_val);
    var $5 = HEAP32[$rdata + 48 >> 2];
    var $7 = HEAP32[$rdata + 52 >> 2];
    var $_pre2 = $rdata + 96 | 0;
    if (($5 | 0) == 0) {
      var $cp_0_lcssa = $3;
      var $_pre_phi3 = $_pre2;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $sub | 0;
    var $10 = $sub + 4 | 0;
    var $cp_01 = $3;
    var $dp_02 = $5;
    __label__ = 3;
    break;
   case 3:
    var $dp_02;
    var $cp_01;
    __ZN2js12StringBuffer16infallibleAppendEPKtj($_pre2, $cp_01, $dp_02 - $cp_01 >> 1);
    var $16 = __ZL15InterpretDollarP9JSContextPN2js13RegExpStaticsEPKtS5_R11ReplaceDataP11JSSubStringPj($res, $dp_02, $7, $rdata, $sub, $skip);
    if ($16) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $18 = HEAP32[$9 >> 2];
    var $19 = HEAP32[$10 >> 2];
    __ZN2js12StringBuffer16infallibleAppendEPKtj($_pre2, $19, $18);
    var $21 = $dp_02 + (HEAP32[$skip >> 2] << 1) | 0;
    var $dp_1 = $21;
    var $cp_1 = $21;
    __label__ = 6;
    break;
   case 5:
    var $dp_1 = $dp_02 + 2 | 0;
    var $cp_1 = $dp_02;
    __label__ = 6;
    break;
   case 6:
    var $cp_1;
    var $dp_1;
    var $25 = __Z15js_strchr_limitPKttS0_($dp_1, 36, $7);
    if (($25 | 0) == 0) {
      var $cp_0_lcssa = $cp_1;
      var $_pre_phi3 = $_pre2;
      __label__ = 7;
      break;
    } else {
      var $cp_01 = $cp_1;
      var $dp_02 = $25;
      __label__ = 3;
      break;
    }
   case 7:
    var $_pre_phi3;
    var $cp_0_lcssa;
    var $_idx_val = HEAP32[$2 >> 2];
    var $27 = __ZNK8JSString6lengthEv($_idx_val);
    var $32 = $27 - ($cp_0_lcssa - $3 >> 1) | 0;
    var $33 = __ZN2js12StringBuffer6appendEPKtj($_pre_phi3, $cp_0_lcssa, $32);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9DoReplaceP9JSContextPN2js13RegExpStaticsER11ReplaceData["X"] = 1;

function __ZL15InterpretDollarP9JSContextPN2js13RegExpStaticsEPKtS5_R11ReplaceDataP11JSSubStringPj($res, $dp, $ep, $rdata, $out, $skip) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $dp + 2 | 0;
    if ($1 >>> 0 < $ep >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 2:
    var $5 = HEAPU16[$1 >> 1] & 65535;
    var $6 = $5 - 48 | 0;
    if ($6 >>> 0 < 10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 3:
    var $9 = __ZNK2js13RegExpStatics10parenCountEv($res);
    if ($6 >>> 0 > $9 >>> 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $dp + 4 | 0;
    if ($12 >>> 0 < $ep >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $cp_0 = $12;
      var $num_0 = $6;
      __label__ = 8;
      break;
    }
   case 5:
    var $16 = HEAPU16[$12 >> 1] & 65535;
    if (($16 - 48 | 0) >>> 0 < 10) {
      __label__ = 6;
      break;
    } else {
      var $cp_0 = $12;
      var $num_0 = $6;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $6 * 10 - 48 + $16 | 0;
    if ($22 >>> 0 > $9 >>> 0) {
      var $cp_0 = $12;
      var $num_0 = $6;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $cp_0 = $dp + 6 | 0;
    var $num_0 = $22;
    __label__ = 8;
    break;
   case 8:
    var $num_0;
    var $cp_0;
    if (($num_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    HEAP32[$skip >> 2] = $cp_0 - $dp >> 1;
    __ZNK2js13RegExpStatics8getParenEjP11JSSubString($res, $num_0, $out);
    var $_0 = 1;
    __label__ = 16;
    break;
   case 10:
    HEAP32[$skip >> 2] = 2;
    if (($5 | 0) == 36) {
      __label__ = 11;
      break;
    } else if (($5 | 0) == 38) {
      __label__ = 12;
      break;
    } else if (($5 | 0) == 43) {
      __label__ = 13;
      break;
    } else if (($5 | 0) == 96) {
      __label__ = 14;
      break;
    } else if (($5 | 0) == 39) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 11:
    var $35 = $rdata + 60 | 0;
    HEAP32[$rdata + 64 >> 2] = $dp;
    HEAP32[$35 >> 2] = 1;
    var $38 = $35;
    var $39 = $out;
    var $40$0 = HEAP32[$38 >> 2];
    var $40$1 = HEAP32[$38 + 4 >> 2];
    HEAP32[$39 >> 2] = $40$0;
    HEAP32[$39 + 4 >> 2] = $40$1;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 12:
    __ZNK2js13RegExpStatics12getLastMatchEP11JSSubString($res, $out);
    var $_0 = 1;
    __label__ = 16;
    break;
   case 13:
    __ZNK2js13RegExpStatics12getLastParenEP11JSSubString($res, $out);
    var $_0 = 1;
    __label__ = 16;
    break;
   case 14:
    __ZNK2js13RegExpStatics14getLeftContextEP11JSSubString($res, $out);
    var $_0 = 1;
    __label__ = 16;
    break;
   case 15:
    __ZNK2js13RegExpStatics15getRightContextEP11JSSubString($res, $out);
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15InterpretDollarP9JSContextPN2js13RegExpStaticsEPKtS5_R11ReplaceDataP11JSSubStringPj["X"] = 1;

function __ZNK2js13RegExpStatics12getLastParenEP11JSSubString($this, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js13RegExpStatics9pairCountEv($this);
    if ($1 >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $out;
    var $$emscripten$temp$0 = _js_EmptySubString;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    HEAP32[$4 >> 2] = $5$0;
    HEAP32[$4 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 3:
    var $7 = $1 - 1 | 0;
    __ZNK2js13RegExpStatics8getParenEjP11JSSubString($this, $7, $out);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics14getLeftContextEP11JSSubString($this, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js13RegExpStatics9pairCountEv($this);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $out;
    var $$emscripten$temp$0 = _js_EmptySubString;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    HEAP32[$4 >> 2] = $5$0;
    HEAP32[$4 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 3:
    var $_idx_val = HEAP32[HEAP32[$this + 92 >> 2] + 4 >> 2];
    var $9 = __ZNK14JSLinearString5charsEv($_idx_val);
    HEAP32[$out + 4 >> 2] = $9;
    var $11 = __ZNK2js13RegExpStatics3getEjb($this, 0, 0);
    HEAP32[$out >> 2] = $11;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js21PreserveRegExpStaticsC1EPNS_13RegExpStaticsE($this, $original) {
  __ZN2js21PreserveRegExpStaticsC2EPNS_13RegExpStaticsE($this, $original);
  return;
}

function __ZN2js21PreserveRegExpStatics4initEP9JSContext($this, $cx) {
  var $2 = HEAP32[$this >> 2];
  var $3 = $this + 4 | 0;
  var $4 = __ZN2js13RegExpStatics4saveEP9JSContextPS0_($2, $cx, $3);
  return $4;
}

function __ZN2jsL33ValueToString_TestForStringInlineEP9JSContextRKN2JS5ValueE($cx, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isStringEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toStringEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_0 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($cx, $v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js21PreserveRegExpStaticsD1Ev($this) {
  __ZN2js21PreserveRegExpStaticsD2Ev($this);
  return;
}

function __ZN2js21PreserveRegExpStaticsD2Ev($this) {
  var $2 = HEAP32[$this >> 2];
  __ZN2js13RegExpStatics7restoreEv($2);
  var $3 = $this + 4 | 0;
  __ZN2js13RegExpStaticsD1Ev($3);
  return;
}

function __ZN2js13RegExpStatics7restoreEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 104 | 0;
    var $2 = HEAP32[$1 >> 2];
    if ((HEAP8[$2 + 108 | 0] & 1) << 24 >> 24 == 0) {
      var $11 = $2;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $2;
    var $9 = $this;
    __ZN2js13RegExpStatics6copyToERS0_($8, $9);
    var $11 = HEAP32[$1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $11;
    var $13 = HEAP32[$11 + 104 >> 2];
    HEAP32[$1 >> 2] = $13;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE5beginEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_0_0_val) {
  return $sid_0_0_val;
}

function _JSID_TO_INT3948($iden) {
  return $iden >> 1;
}

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE3endEv($this_0_0_val, $this_0_1_val) {
  return $this_0_0_val + ($this_0_1_val << 2) | 0;
}

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE10endNoCheckEv($this_0_0_val, $this_0_1_val) {
  return $this_0_0_val + ($this_0_1_val << 2) | 0;
}

function __ZN2js10VectorImplIP14JSLinearStringLj16ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject8setClassEPN2js5ClassE($this, $c) {
  HEAP32[$this + 4 >> 2] = $c;
  return;
}

function __ZN2js13RegExpStatics4saveEP9JSContextPS0_($this, $cx, $buffer) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 104 | 0;
    var $2 = HEAP32[$1 >> 2];
    HEAP32[$buffer + 104 >> 2] = $2;
    HEAP32[$1 >> 2] = $buffer;
    var $4 = $buffer | 0;
    var $_idx_val = HEAP32[$this + 4 >> 2];
    var $5 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE6lengthEv($_idx_val);
    var $6 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE7reserveEj($4, $5);
    if ($6) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $cx;
    __Z20js_ReportOutOfMemoryP9JSContext($8);
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE7reserveEj($this, $request) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$this + 8 >> 2] >>> 0 < $request >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $request - HEAP32[$this + 4 >> 2] | 0;
    var $8 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE13growStorageByEj($this, $7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js21PreserveRegExpStaticsC2EPNS_13RegExpStaticsE($this, $original) {
  HEAP32[$this >> 2] = $original;
  var $2 = $this + 4 | 0;
  __ZN2js13RegExpStaticsC1ENS0_10InitBufferE($2);
  return;
}

function __ZN2js13RegExpStaticsC1ENS0_10InitBufferE($this) {
  __ZN2js13RegExpStaticsC2ENS0_10InitBufferE($this);
  return;
}

function __ZN2js13RegExpStaticsC2ENS0_10InitBufferE($this) {
  var $1 = $this | 0;
  __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEEC1ES1_($1);
  HEAP32[$this + 104 >> 2] = 0;
  HEAP8[$this + 108 | 0] = 0;
  return;
}

function __ZN2js6RegExp12hasMetaCharsEPKtj($chars, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if ($i_0 >>> 0 < $length >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $5 = HEAP16[$chars + ($i_0 << 1) >> 1];
    var $6 = __ZN2js6RegExp10isMetaCharEt($5);
    if ($6) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9RopeMatchP9JSContextP8JSStringPKtjPi($cx, $textstr, $pat, $patlen, $match) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 224;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $strs = __stackBase__;
    var $r = __stackBase__ + 76;
    if (($patlen | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$match >> 2] = 0;
    var $_2 = 1;
    __label__ = 33;
    break;
   case 3:
    var $textstr_idx2 = $textstr | 0;
    var $textstr_idx2_val = HEAP32[$textstr_idx2 >> 2];
    var $4 = __ZNK8JSString6lengthEv($textstr_idx2_val);
    if ($4 >>> 0 < $patlen >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$match >> 2] = -1;
    var $_2 = 1;
    __label__ = 33;
    break;
   case 5:
    __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEEC1ES3_($strs);
    var $textstr_idx_val = HEAP32[$textstr_idx2 >> 2];
    var $8 = __ZNK8JSString6lengthEv($textstr_idx_val);
    __ZN2js18StringSegmentRangeC1EP9JSContext($r, $cx);
    var $9 = __ZN2js18StringSegmentRange4initEP8JSString($r, $textstr);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      var $_0_ph = 0;
      __label__ = 13;
      break;
    }
   case 6:
    var $r_idx = $r + 144 | 0;
    var $threshold_0 = $8 >>> 5;
    __label__ = 7;
    break;
   case 7:
    var $threshold_0;
    var $r_idx_val = HEAPU32[$r_idx >> 2];
    var $12 = __ZNK2js18StringSegmentRange5emptyEv($r_idx_val);
    if ($12) {
      __label__ = 14;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $14 = $threshold_0 - 1 | 0;
    if (($threshold_0 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $17 = __ZNK2js18StringSegmentRange5frontEv($r_idx_val);
    var $18 = __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE6appendIS2_EEbT_($strs, $17);
    if ($18) {
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $20 = $cx;
    var $21 = __ZN8JSString8getCharsEP9JSContext($textstr, $20);
    if (($21 | 0) == 0) {
      var $_0_ph = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $24 = __ZL11StringMatchPKtjS0_j($21, $8, $pat, $patlen);
    HEAP32[$match >> 2] = $24;
    var $_0_ph = 1;
    __label__ = 13;
    break;
   case 12:
    var $26 = __ZN2js18StringSegmentRange8popFrontEv($r);
    if ($26) {
      var $threshold_0 = $14;
      __label__ = 7;
      break;
    } else {
      var $_0_ph = 0;
      __label__ = 13;
      break;
    }
   case 13:
    var $_0_ph;
    __ZN2js18StringSegmentRangeD1Ev($r);
    var $_1 = $_0_ph;
    __label__ = 32;
    break;
   case 14:
    __ZN2js18StringSegmentRangeD1Ev($r);
    var $strs_idx_val = HEAP32[$strs >> 2];
    var $28 = __ZNK2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE5beginEv($strs_idx_val);
    var $strs_idx9_val = HEAP32[$strs + 4 >> 2];
    var $29 = __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE3endEv($strs_idx_val, $strs_idx9_val);
    var $30 = $pat + ($patlen << 1) | 0;
    var $31 = 1 - $patlen | 0;
    var $outerp_0 = $28;
    var $pos_0 = 0;
    __label__ = 15;
    break;
   case 15:
    var $pos_0;
    var $outerp_0;
    if (($outerp_0 | 0) == ($29 | 0)) {
      __label__ = 31;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $35 = HEAP32[$outerp_0 >> 2];
    var $_idx4_val = HEAP32[$35 + 4 >> 2];
    var $36 = __ZNK14JSLinearString5charsEv($_idx4_val);
    var $_idx1_val = HEAP32[$35 >> 2];
    var $37 = __ZNK8JSString6lengthEv($_idx1_val);
    var $38 = __ZL11StringMatchPKtjS0_j($36, $37, $pat, $patlen);
    if (($38 | 0) == -1) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $41 = $38 + $pos_0 | 0;
    HEAP32[$match >> 2] = $41;
    var $_1 = 1;
    __label__ = 32;
    break;
   case 18:
    var $_ = $37 >>> 0 < $patlen >>> 0 ? 0 : $31 + $37 | 0;
    var $46 = $36 + ($37 << 1) | 0;
    var $47 = HEAP16[$pat >> 1];
    var $t_0_ph = $36 + ($_ << 1) | 0;
    var $innerp_0_ph = $outerp_0;
    __label__ = 19;
    break;
   case 19:
    var $innerp_0_ph;
    var $t_0_ph;
    var $t_0 = $t_0_ph;
    __label__ = 20;
    break;
   case 20:
    var $t_0;
    if (($t_0 | 0) == ($46 | 0)) {
      __label__ = 30;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $51 = $t_0 + 2 | 0;
    if (HEAP16[$t_0 >> 1] << 16 >> 16 == $47 << 16 >> 16) {
      var $tt_0 = $51;
      var $pat_pn = $pat;
      var $ttend_0 = $46;
      var $innerp_1 = $innerp_0_ph;
      __label__ = 22;
      break;
    } else {
      var $t_0 = $51;
      __label__ = 20;
      break;
    }
   case 22:
    var $innerp_1;
    var $ttend_0;
    var $pat_pn;
    var $tt_0;
    var $pp_0 = $pat_pn + 2 | 0;
    if (($pp_0 | 0) == ($30 | 0)) {
      __label__ = 29;
      break;
    } else {
      var $tt_1 = $tt_0;
      var $ttend_1 = $ttend_0;
      var $innerp_2 = $innerp_1;
      __label__ = 23;
      break;
    }
   case 23:
    var $innerp_2;
    var $ttend_1;
    var $tt_1;
    if (($tt_1 | 0) == ($ttend_1 | 0)) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $57 = $innerp_2 + 4 | 0;
    if (($57 | 0) == ($29 | 0)) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    HEAP32[$match >> 2] = -1;
    var $_1 = 1;
    __label__ = 32;
    break;
   case 26:
    var $61 = HEAP32[$57 >> 2];
    var $_idx3_val = HEAP32[$61 + 4 >> 2];
    var $62 = __ZNK14JSLinearString5charsEv($_idx3_val);
    var $_idx_val = HEAP32[$61 >> 2];
    var $63 = __ZNK8JSString6lengthEv($_idx_val);
    var $tt_1 = $62;
    var $ttend_1 = $62 + ($63 << 1) | 0;
    var $innerp_2 = $57;
    __label__ = 23;
    break;
   case 27:
    if (HEAP16[$pp_0 >> 1] << 16 >> 16 == HEAP16[$tt_1 >> 1] << 16 >> 16) {
      __label__ = 28;
      break;
    } else {
      var $t_0_ph = $51;
      var $innerp_0_ph = $innerp_2;
      __label__ = 19;
      break;
    }
   case 28:
    var $tt_0 = $tt_1 + 2 | 0;
    var $pat_pn = $pp_0;
    var $ttend_0 = $ttend_1;
    var $innerp_1 = $innerp_2;
    __label__ = 22;
    break;
   case 29:
    var $77 = $pos_0 - 1 + ($51 - $36 >> 1) | 0;
    HEAP32[$match >> 2] = $77;
    var $_1 = 1;
    __label__ = 32;
    break;
   case 30:
    var $79 = $37 + $pos_0 | 0;
    var $outerp_0 = $outerp_0 + 4 | 0;
    var $pos_0 = $79;
    __label__ = 15;
    break;
   case 31:
    HEAP32[$match >> 2] = -1;
    var $_1 = 1;
    __label__ = 32;
    break;
   case 32:
    var $_1;
    __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEED1Ev($strs);
    var $_2 = $_1;
    __label__ = 33;
    break;
   case 33:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9RopeMatchP9JSContextP8JSStringPKtjPi["X"] = 1;

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEEC1ES3_($this) {
  __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEEC2ES3_($this);
  return;
}

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 4 >> 2] | 0) == (HEAP32[$this + 8 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE13growStorageByEj($this);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this >> 2];
    var $3 = __ZNK2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js17SystemAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = $this + 12 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj64EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE13growStorageByEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this >> 2];
    var $this_idx1 = $this + 4 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $5 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    var $5 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    HEAP32[$this_idx1 >> 2] = $5 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 2;
    var $7 = __ZN2js17SystemAllocPolicy7malloc_Ej($6);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $11 = __ZNK2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $12 = __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplIP14JSLinearStringLj16ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($8, $11, $12);
    HEAP32[$this_idx >> 2] = $8;
    HEAP32[$this + 8 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIP14JSLinearStringLj16ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj16ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($curLength, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, 1);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $5;
    if ($5 >>> 0 > 536870911) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP14JSLinearStringLj16ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj16ES3_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = __ZN2js17SystemAllocPolicy8realloc_EPvjj($4, $1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5;
    var $9 = $v + 8 | 0;
    HEAP32[$2 >> 2] = $8;
    HEAP32[$9 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP14JSLinearStringLj16ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIP14JSLinearStringLj16ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEEC2ES3_($this) {
  var $1 = $this | 0;
  var $2 = $this + 12 | 0;
  var $3 = __ZN7mozilla14AlignedStorageILj64EE4addrEv($2);
  HEAP32[$1 >> 2] = $3;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 16;
  return;
}

function __ZN10RegExpPair5resetER8JSObject($this, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$this + 8 >> 2] = $obj;
  var $_idx_val = HEAP32[$obj + 24 >> 2];
  var $4 = __ZN2js6RegExp11extractFromEP8JSObject($_idx_val);
  var $5 = $this | 0;
  __ZN2js11NeedsIncRefINS_6RegExpEEC1EPS1_($1, $4);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js12AutoRefCountINS_6RegExpEE5resetENS_11NeedsIncRefIS1_EE($5, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12AutoRefCountINS_6RegExpEE5resetENS_11NeedsIncRefIS1_EE($this, $aobj_0) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6RegExp6decrefEP9JSContext($2);
    __label__ = 3;
    break;
   case 3:
    var $6 = __ZNK2js11NeedsIncRefINS_6RegExpEE3getEv($aobj_0);
    HEAP32[$1 >> 2] = $6;
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6RegExp6increfEP9JSContext($6);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11ReplaceDataC2EP9JSContext($this, $cx) {
  var $1 = $this + 4 | 0;
  __ZN11RegExpGuardC1EP9JSContext($1, $cx);
  var $3 = $this + 72 | 0;
  __ZN2js15InvokeArgsGuardC1Ev($3);
  var $5 = $this + 96 | 0;
  var $6 = $cx;
  __ZN2js12StringBufferC1EP9JSContext($5, $6);
  return;
}

function __ZN2jsL19ClassMethodIsNativeEP9JSContextP8JSObjectPNS_5ClassEiPFiS1_jPN2JS5ValueEE3938($cx, $obj, $methodid) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $cx;
    var $2 = $obj;
    var $3 = __ZN2js15HasDataPropertyEP9JSContextP8JSObjectiPN2JS5ValueE($1, $2, $methodid, $v);
    if ($3) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $6 = __ZNK8JSObject8getProtoEv($_idx1_val_idx_val);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$6 + 4 >> 2];
    var $9 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($9 | 0) == (__ZN2js11StringClassE | 0)) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $12 = $6;
    var $13 = __ZN2js15HasDataPropertyEP9JSContextP8JSObjectiPN2JS5ValueE($1, $12, $methodid, $v);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $15 = __ZN2jsL16IsNativeFunctionERKN2JS5ValueEPFiP9JSContextjPS1_E3939($v_idx_val$0, $v_idx_val$1);
    var $_0 = $15;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16IsNativeFunctionERKN2JS5ValueEPFiP9JSContextjPS1_E3939($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fun = __stackBase__;
    var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP10JSFunction3940($v_0_0_0_val$0, $v_0_0_0_val$1, $fun);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$fun >> 2];
    var $5 = __ZNK10JSFunction11maybeNativeEv($4);
    var $8 = ($5 | 0) == 186;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP10JSFunction3940($v_0_0_0_val$0, $v_0_0_0_val$1, $fun) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $funobj = __stackBase__;
  var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction3941($v_0_0_0_val$0, $v_0_0_0_val$1, $funobj, $fun);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction3941($v_0_0_0_val$0, $v_0_0_0_val$1, $funobj, $fun) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject3942($v_0_0_0_val$0, $v_0_0_0_val$1, $funobj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[HEAP32[$funobj >> 2] + 24 >> 2];
    var $5 = __ZNK8JSObject18getFunctionPrivateEv($_idx_val);
    var $6 = $5;
    HEAP32[$fun >> 2] = $6;
    __label__ = 3;
    break;
   case 3:
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject3942($v_0_0_0_val$0, $v_0_0_0_val$1, $funobj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    HEAP32[$funobj >> 2] = $3;
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $5 = __ZNK8JSObject10isFunctionEv($_idx_val);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer14getArrayBufferEP8JSObject($obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_0 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $_0;
    if (($_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_0_idx1_val = HEAP32[$_0 + 4 >> 2];
    var $4 = __Z16js_IsArrayBufferP8JSObject($_0_idx1_val);
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_0_idx_val_idx_val = HEAP32[HEAP32[$_0 + 36 >> 2] >> 2];
    var $7 = __ZNK8JSObject8getProtoEv($_0_idx_val_idx_val);
    var $_0 = $7;
    __label__ = 2;
    break;
   case 5:
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_IsArrayBufferP8JSObject($obj_0_1_val) {
  var $1 = __ZNK8JSObject13isArrayBufferEv($obj_0_1_val);
  return $1 & 1;
}

function __ZN2js11ArrayBuffer18prop_getByteLengthEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11ArrayBuffer14getArrayBufferEP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value8setInt32Ei($vp, 0);
    __label__ = 4;
    break;
   case 3:
    var $_idx_val = HEAP32[$1 + 32 >> 2];
    var $5 = __ZN8JSObject21arrayBufferByteLengthEv($_idx_val);
    __ZN2JS5Value8setInt32Ei($vp, $5);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer17class_constructorEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nbytes = __stackBase__;
    HEAP32[$nbytes >> 2] = 0;
    if (($argc | 0) == 0) {
      var $6 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $vp + 16 | 0;
    var $4 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $3, $nbytes);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $6 = HEAP32[$nbytes >> 2];
    __label__ = 4;
    break;
   case 4:
    var $6;
    var $7 = __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $6);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JS5Value9setObjectER8JSObject($vp, $7);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $nbytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981($cx, __ZN2js11ArrayBuffer9slowClassE);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($nbytes | 0) < 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 4, 152, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    __ZN8JSObject21setSharedNonNativeMapEv($1);
    __ZN8JSObject8setClassEPN2js5ClassE($1, __ZN2js16ArrayBufferClassE);
    var $7 = __ZN8JSObject24allocateArrayBufferSlotsEP9JSContextj($1, $cx, $nbytes);
    var $_ = $7 ? $1 : 0;
    var $_0 = $_;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject24allocateArrayBufferSlotsEP9JSContextj($this, $cx, $size) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $size + 8 | 0;
    if ($size >>> 0 > 120) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZN9JSContext7calloc_Ej($cx, $1);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $4;
    HEAP32[$this + 32 >> 2] = $7;
    HEAP32[$this + 28 >> 2] = $1 >>> 3;
    var $16 = $7;
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZNK8JSObject10fixedSlotsEv($this);
    var $13 = $this + 32 | 0;
    HEAP32[$13 >> 2] = $12;
    var $14 = $12;
    _memset($14, 0, $1, 1);
    var $16 = HEAP32[$13 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $16;
    HEAP32[$16 >> 2] = $size;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981($cx, $clasp) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb4033($4);
  var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE4041($cx, $clasp, $5);
  return $6;
}

function __ZN2js11ArrayBuffer9obj_traceEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj_idx_val = HEAP32[$obj + 24 >> 2];
    var $1 = __ZNK8JSObject10getPrivateEv($obj_idx_val);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer18obj_lookupPropertyEP9JSContextP8JSObjectiPS4_PP10JSProperty($cx, $obj, $id, $objp, $propp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210484 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$propp >> 2] = 1;
    var $9 = __ZN2js11ArrayBuffer14getArrayBufferEP8JSObject($obj);
    HEAP32[$objp >> 2] = $9;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 3:
    var $11 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($11, $cx, $id, $objp, $propp);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$propp >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$objp >> 2] | 0) == ($11 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 7:
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 8:
    var $obj_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $24 = __ZNK8JSObject8getProtoEv($obj_idx_val_idx_val);
    if (($24 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    HEAP32[$objp >> 2] = 0;
    HEAP32[$propp >> 2] = 0;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 10:
    var $28 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($24, $cx, $id, $objp, $propp);
    var $_0 = $28;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $atom) {
  var $1 = __ZL12ATOM_TO_JSIDP6JSAtom3984($atom);
  return ($1 | 0) == ($id | 0) & 1;
}

function __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj_idx_val = HEAP32[$obj + 24 >> 2];
    var $1 = __ZNK8JSObject10getPrivateEv($obj_idx_val);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $obj_idx1_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $4 = __ZNK8JSObject8getProtoEv($obj_idx1_val_idx_val);
    var $5 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_4032($cx, $4);
    var $6 = $5;
    __ZN8JSObject10setPrivateEPv($obj, $6);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $_0 = $1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer17obj_lookupElementEP9JSContextP8JSObjectjPS4_PP10JSProperty($cx, $obj, $index, $objp, $propp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN8JSObject13lookupElementEP9JSContextjPPS_PP10JSProperty($1, $cx, $index, $objp, $propp);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$propp >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP32[$objp >> 2] | 0) == ($1 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 5:
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 6:
    var $obj_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $14 = __ZNK8JSObject8getProtoEv($obj_idx_val_idx_val);
    if (($14 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $17 = __ZN8JSObject13lookupElementEP9JSContextjPPS_PP10JSProperty($14, $cx, $index, $objp, $propp);
    var $_0 = $17;
    __label__ = 9;
    break;
   case 8:
    HEAP32[$objp >> 2] = 0;
    HEAP32[$propp >> 2] = 0;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer17obj_lookupSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPS4_PP10JSProperty($cx, $obj, $sid, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN2js11ArrayBuffer18obj_lookupPropertyEP9JSContextP8JSObjectiPS4_PP10JSProperty($cx, $obj, $1, $objp, $propp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js11ArrayBuffer10obj_typeOfEP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZN2js10TypedArray24obj_getElementAttributesEP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  HEAP32[$attrsp >> 2] = 5;
  return 1;
}

function __Z32js_TypedArray_uint8_clamp_doubled($x) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($x < 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($x > 255) {
      var $_0 = 255;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = $x + .5;
    var $6 = $5 >= 0 ? Math.floor($5) : Math.ceil($5);
    var $7 = $6 & 255;
    if (($7 | 0) == $5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $7;
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = $7 & 254;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15JSDOUBLE_IS_NaNd3989($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZN2js11ArrayBuffer18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $id, $v, $getter, $setter, $attrs) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210484 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 2:
    var $9 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $cx;
    var $13 = $9;
    var $14 = $getter;
    var $15 = $setter;
    var $16 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($12, $13, $id, $v, $14, $15, $attrs);
    var $_0 = $16;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $index, $v, $getter, $setter, $attrs) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $1;
    var $6 = $getter;
    var $7 = $setter;
    var $8 = __Z16js_DefineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($4, $5, $index, $v, $6, $7, $attrs);
    var $_0 = $8;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer17obj_defineSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS7_EPFiS2_S4_iiSA_Ej($cx, $obj, $sid, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN2js11ArrayBuffer18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $1, $v, $getter, $setter, $attrs);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js11ArrayBuffer14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11ArrayBuffer14getArrayBufferEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210484 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$1 + 32 >> 2];
    var $10 = __ZN8JSObject21arrayBufferByteLengthEv($_idx_val);
    __ZN2JS5Value8setInt32Ei($vp, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $12 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $1);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = $cx;
    var $16 = $12;
    var $17 = $receiver;
    var $18 = __Z14js_GetPropertyP9JSContextP8JSObjectS2_iPN2JS5ValueE($15, $16, $17, $id, $vp);
    var $_0 = $18;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer15obj_getPropertyEP9JSContextP8JSObjectS4_PNS_12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom3984($1);
  var $3 = __ZN2js11ArrayBuffer14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $2, $vp);
  return $3;
}

function __ZL12ATOM_TO_JSIDP6JSAtom3984($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj4031($1);
  return $2;
}

function __ZN2js11ArrayBuffer14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11ArrayBuffer14getArrayBufferEP8JSObject($obj);
    var $2 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $cx;
    var $6 = $2;
    var $7 = $receiver;
    var $8 = __Z13js_GetElementP9JSContextP8JSObjectS2_jPN2JS5ValueE($5, $6, $7, $index, $vp);
    var $_0 = $8;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer14obj_getSpecialEP9JSContextP8JSObjectS4_NS_9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN2js11ArrayBuffer14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js11ArrayBuffer15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 52 >> 2];
    var $5 = HEAP32[$2 + 210484 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 10;
      break;
    }
   case 2:
    var $11 = HEAP32[$2 + 210292 >> 2] | 0;
    var $12 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $11);
    var $13 = ($12 | 0) == 0;
    var $14 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    var $15 = ($14 | 0) == 0;
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($15) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx1 = $14 + 36 | 0;
    var $_idx1_val_idx_val = HEAP32[HEAP32[$_idx1 >> 2] >> 2];
    var $18 = __ZNK8JSObject8getProtoEv($_idx1_val_idx_val);
    var $19 = $cx;
    var $20 = $14;
    var $21 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($19, $20, $id, 0, $vp, $strict);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx_val_idx_val = HEAP32[HEAP32[$_idx1 >> 2] >> 2];
    var $24 = __ZNK8JSObject8getProtoEv($_idx_val_idx_val);
    if (($24 | 0) == ($18 | 0)) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $27 = __ZNK2JS5Value14toObjectOrNullEv($vp_idx_val$0, $vp_idx_val$1);
    var $28 = $obj;
    var $29 = $27;
    var $30 = __ZN2js8SetProtoEP9JSContextP8JSObjectS3_b($19, $28, $29, 1);
    if ($30) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $32 = $18;
    var $33 = __ZN2js8SetProtoEP9JSContextP8JSObjectS3_b($19, $20, $32, 1);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 8:
    if ($15) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $36 = $cx;
    var $37 = $14;
    var $38 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($36, $37, $id, 0, $vp, $strict);
    var $_0 = $38;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11ArrayBuffer15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi["X"] = 1;

function __ZN2js11ArrayBuffer14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $1;
    var $6 = __Z19js_SetElementHelperP9JSContextP8JSObjectjjPN2JS5ValueEi($4, $5, $index, $vp, $strict);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer14obj_setSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN2js11ArrayBuffer15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, $strict);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js11ArrayBuffer17obj_getAttributesEP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210484 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$attrsp >> 2] = 6;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $10 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $cx;
    var $14 = $10;
    var $15 = __Z16js_GetAttributesP9JSContextP8JSObjectiPj($13, $14, $id, $attrsp);
    var $_0 = $15;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer24obj_getElementAttributesEP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $1;
    var $6 = __Z23js_GetElementAttributesP9JSContextP8JSObjectjPj($4, $5, $index, $attrsp);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer24obj_getSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN2js11ArrayBuffer17obj_getAttributesEP9JSContextP8JSObjectiPj($cx, $obj, $1, $attrsp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js11ArrayBuffer17obj_setAttributesEP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210484 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 4, 225, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $10 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $cx;
    var $14 = $10;
    var $15 = __Z16js_SetAttributesP9JSContextP8JSObjectiPj($13, $14, $id, $attrsp);
    var $_0 = $15;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer24obj_setElementAttributesEP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $1;
    var $6 = __Z23js_SetElementAttributesP9JSContextP8JSObjectjPj($4, $5, $index, $attrsp);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer24obj_setSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN2js11ArrayBuffer17obj_setAttributesEP9JSContextP8JSObjectiPj($cx, $obj, $1, $attrsp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js11ArrayBuffer18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210484 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $10 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $cx;
    var $14 = $10;
    var $15 = __Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($13, $14, $id, $rval, $strict);
    var $_0 = $15;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $1;
    var $6 = __Z16js_DeleteElementP9JSContextP8JSObjectjPN2JS5ValueEi($4, $5, $index, $rval, $strict);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer17obj_deleteSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN2js11ArrayBuffer18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, $strict);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js11ArrayBuffer13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  __ZN2JS5Value7setNullEv($statep);
  return 1;
}

function __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $1 = __Z15js_IsTypedArrayP8JSObject($obj_idx_val);
    if (($1 | 0) == 0) {
      var $_01 = $obj;
      __label__ = 2;
      break;
    } else {
      var $_0_lcssa = $obj;
      __label__ = 3;
      break;
    }
   case 2:
    var $_01;
    var $_01_idx_val_idx_val = HEAP32[HEAP32[$_01 + 36 >> 2] >> 2];
    var $3 = __ZNK8JSObject8getProtoEv($_01_idx_val_idx_val);
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __Z15js_IsTypedArrayP8JSObject($_idx_val);
    if (($4 | 0) == 0) {
      var $_01 = $3;
      __label__ = 2;
      break;
    } else {
      var $_0_lcssa = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $_0_lcssa;
    return $_0_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z15js_IsTypedArrayP8JSObject($obj_0_1_val) {
  var $1 = __ZNK8JSObject8getClassEv($obj_0_1_val);
  var $2 = __ZN2js21IsFastTypedArrayClassEPKNS_5ClassE($1);
  return $2 & 1;
}

function __ZN2js10TypedArray14prop_getBufferEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  __ZN16TypedArrayGetterIXadL_Z14getBufferValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE($obj, $vp);
  return 1;
}

function __ZN16TypedArrayGetterIXadL_Z14getBufferValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE($obj, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $_01 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $_01_idx1_val = HEAP32[$_01 + 4 >> 2];
    var $3 = __Z15js_IsTypedArrayP8JSObject($_01_idx1_val);
    if (($3 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($_01);
    if (($6 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __Z14getBufferValueP8JSObject($1, $6);
    var $9 = $1 | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $vp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    __label__ = 6;
    break;
   case 5:
    var $_01_idx_val_idx_val = HEAP32[HEAP32[$_01 + 36 >> 2] >> 2];
    var $13 = __ZNK8JSObject8getProtoEv($_01_idx_val_idx_val);
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_01 = $13;
      __label__ = 2;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10TypedArray18prop_getByteOffsetEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  __ZN16TypedArrayGetterIXadL_Z18getByteOffsetValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE($obj, $vp);
  return 1;
}

function __ZN16TypedArrayGetterIXadL_Z18getByteOffsetValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE($obj, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $_01 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $_01_idx1_val = HEAP32[$_01 + 4 >> 2];
    var $3 = __Z15js_IsTypedArrayP8JSObject($_01_idx1_val);
    if (($3 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($_01);
    if (($6 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __Z18getByteOffsetValueP8JSObject($1, $6);
    var $9 = $1 | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $vp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    __label__ = 6;
    break;
   case 5:
    var $_01_idx_val_idx_val = HEAP32[HEAP32[$_01 + 36 >> 2] >> 2];
    var $13 = __ZNK8JSObject8getProtoEv($_01_idx_val_idx_val);
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_01 = $13;
      __label__ = 2;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10TypedArray18prop_getByteLengthEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  __ZN16TypedArrayGetterIXadL_Z18getByteLengthValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE($obj, $vp);
  return 1;
}

function __ZN16TypedArrayGetterIXadL_Z18getByteLengthValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE($obj, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $_01 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $_01_idx1_val = HEAP32[$_01 + 4 >> 2];
    var $3 = __Z15js_IsTypedArrayP8JSObject($_01_idx1_val);
    if (($3 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($_01);
    if (($6 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __Z18getByteLengthValueP8JSObject($1, $6);
    var $9 = $1 | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $vp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    __label__ = 6;
    break;
   case 5:
    var $_01_idx_val_idx_val = HEAP32[HEAP32[$_01 + 36 >> 2] >> 2];
    var $13 = __ZNK8JSObject8getProtoEv($_01_idx_val_idx_val);
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_01 = $13;
      __label__ = 2;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10TypedArray14prop_getLengthEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  __ZN16TypedArrayGetterIXadL_Z14getLengthValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE($obj, $vp);
  return 1;
}

function __ZN16TypedArrayGetterIXadL_Z14getLengthValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE($obj, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $_01 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $_01_idx1_val = HEAP32[$_01 + 4 >> 2];
    var $3 = __Z15js_IsTypedArrayP8JSObject($_01_idx1_val);
    if (($3 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($_01);
    if (($6 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __Z14getLengthValueP8JSObject($1, $6);
    var $9 = $1 | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $vp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    __label__ = 6;
    break;
   case 5:
    var $_01_idx_val_idx_val = HEAP32[HEAP32[$_01 + 36 >> 2] >> 2];
    var $13 = __ZNK8JSObject8getProtoEv($_01_idx_val_idx_val);
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_01 = $13;
      __label__ = 2;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10TypedArray18obj_lookupPropertyEP9JSContextP8JSObjectiPS4_PP10JSProperty($cx, $obj, $id, $objp, $propp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($1, $id, 0);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$propp >> 2] = 1;
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $obj_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $5 = __ZNK8JSObject8getProtoEv($obj_idx_val_idx_val);
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$objp >> 2] = 0;
    HEAP32[$propp >> 2] = 0;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $9 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($5, $cx, $id, $objp, $propp);
    var $_0 = $9;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($obj, $id, $ip) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = __Z12js_IdIsIndexiPj($id, $index);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAPU32[$index >> 2];
    var $5 = __ZN2js10TypedArray9getLengthEP8JSObject($obj);
    if ($4 >>> 0 < $5 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    if (($ip | 0) == 0) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$ip >> 2] = $4;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10TypedArray17obj_lookupElementEP9JSContextP8JSObjectjPS4_PP10JSProperty($cx, $obj, $index, $objp, $propp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$propp >> 2] = 1;
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $obj_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $6 = __ZNK8JSObject8getProtoEv($obj_idx_val_idx_val);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZN8JSObject13lookupElementEP9JSContextjPPS_PP10JSProperty($6, $cx, $index, $objp, $propp);
    var $_0 = $9;
    __label__ = 6;
    break;
   case 5:
    HEAP32[$objp >> 2] = 0;
    HEAP32[$propp >> 2] = 0;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10TypedArray17obj_lookupSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPS4_PP10JSProperty($cx, $obj, $sid, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN2js10TypedArray18obj_lookupPropertyEP9JSContextP8JSObjectiPS4_PP10JSProperty($cx, $obj, $1, $objp, $propp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js10TypedArray17obj_getAttributesEP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
  var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
  var $8 = ($6 | 0) != 0 ? 6 : 5;
  HEAP32[$attrsp >> 2] = $8;
  return 1;
}

function __ZN2js10TypedArray24obj_getSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN2js10TypedArray17obj_getAttributesEP9JSContextP8JSObjectiPj($cx, undef, $1, $attrsp);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN2js10TypedArray17obj_setAttributesEP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var __stackBase__ = STACKTOP;
  _JS_ReportErrorNumber($cx, 4, 225, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
  STACKTOP = __stackBase__;
  return 0;
}

function __ZN2js10TypedArray24obj_setElementAttributesEP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __stackBase__ = STACKTOP;
  _JS_ReportErrorNumber($cx, 4, 225, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
  STACKTOP = __stackBase__;
  return 0;
}

function __ZN2js10TypedArray24obj_setSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $1 = __ZN2js10TypedArray17obj_setAttributesEP9JSContextP8JSObjectiPj($cx, undef, undef, undef);
  STACKTOP = __stackBase__;
  return 0;
}

function __ZN18TypedArrayTemplateIiE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($tarray_0_6_val, $index, $vp) {
  var $1 = __ZN18TypedArrayTemplateIiE8getIndexEP8JSObjectj($tarray_0_6_val, $index);
  __ZN2JS5Value8setInt32Ei($vp, $1);
  return;
}

function __ZN18TypedArrayTemplateIiE8getIndexEP8JSObjectj($obj_0_6_val, $index) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj_0_6_val);
  return HEAP32[$1 + ($index << 2) >> 2];
}

function __ZN18TypedArrayTemplateIjE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($tarray_0_6_val, $index, $vp) {
  var $1 = __ZN18TypedArrayTemplateIjE8getIndexEP8JSObjectj($tarray_0_6_val, $index);
  var $2 = __ZN2JS5Value9setNumberEj($vp, $1);
  return;
}

function __ZN18TypedArrayTemplateIjE8getIndexEP8JSObjectj($obj_0_6_val, $index) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj_0_6_val);
  return HEAP32[$1 + ($index << 2) >> 2];
}

function __ZN18TypedArrayTemplateIfE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($tarray_0_6_val, $index, $vp) {
  var $1 = __ZN18TypedArrayTemplateIfE8getIndexEP8JSObjectj($tarray_0_6_val, $index);
  var $2 = $1;
  var $3 = __ZL15JSDOUBLE_IS_NaNd3989($2);
  var $4 = ($3 | 0) == 0;
  var $5 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
  var $dval_0 = $4 ? $2 : $5;
  __ZN2JS5Value9setDoubleEd($vp, $dval_0);
  return;
}

function __ZN18TypedArrayTemplateIfE8getIndexEP8JSObjectj($obj_0_6_val, $index) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj_0_6_val);
  return HEAPF32[$1 + ($index << 2) >> 2];
}

function __ZN18TypedArrayTemplateIdE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($tarray_0_6_val, $index, $vp) {
  var $1 = __ZN18TypedArrayTemplateIdE8getIndexEP8JSObjectj($tarray_0_6_val, $index);
  var $2 = __ZL15JSDOUBLE_IS_NaNd3989($1);
  var $3 = ($2 | 0) == 0;
  var $4 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
  var $val_0 = $3 ? $1 : $4;
  __ZN2JS5Value9setDoubleEd($vp, $val_0);
  return;
}

function __ZN18TypedArrayTemplateIdE8getIndexEP8JSObjectj($obj_0_6_val, $index) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj_0_6_val);
  var $3 = $1 + ($index << 3) | 0;
  var $4 = (tempDoubleI32[0] = HEAP32[$3 >> 2], tempDoubleI32[1] = HEAP32[$3 + 4 >> 2], tempDoubleF64[0]);
  return $4;
}

function __ZN18TypedArrayTemplateIaE12fun_subarrayEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $begin = __stackBase__;
    var $end = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$2 + 4 >> 2];
    var $5 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$begin >> 2] = 0;
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    HEAP32[$end >> 2] = $12;
    if (($argc | 0) == 0) {
      var $45 = 0;
      var $44 = $12;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $vp + 16 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $begin);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAP32[$begin >> 2];
    if (($18 | 0) < 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $21 = $18 + $12 | 0;
    HEAP32[$begin >> 2] = $21;
    if (($21 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      var $28 = $21;
      __label__ = 12;
      break;
    }
   case 9:
    HEAP32[$begin >> 2] = 0;
    var $28 = 0;
    __label__ = 12;
    break;
   case 10:
    if (($18 | 0) > ($12 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $28 = $18;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$begin >> 2] = $12;
    var $28 = $12;
    __label__ = 12;
    break;
   case 12:
    var $28;
    if ($argc >>> 0 > 1) {
      __label__ = 13;
      break;
    } else {
      var $45 = $28;
      var $44 = $12;
      __label__ = 19;
      break;
    }
   case 13:
    var $31 = $vp + 24 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $end);
    if ($32) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 14:
    var $34 = HEAPU32[$end >> 2];
    if (($34 | 0) < 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $37 = $34 + $12 | 0;
    HEAP32[$end >> 2] = $37;
    if (($37 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      var $45 = $28;
      var $44 = $37;
      __label__ = 19;
      break;
    }
   case 16:
    HEAP32[$end >> 2] = 0;
    var $45 = $28;
    var $44 = 0;
    __label__ = 19;
    break;
   case 17:
    if (($34 | 0) > ($12 | 0)) {
      __label__ = 18;
      break;
    } else {
      var $45 = $28;
      var $44 = $34;
      __label__ = 19;
      break;
    }
   case 18:
    HEAP32[$end >> 2] = $12;
    var $45 = $28;
    var $44 = $12;
    __label__ = 19;
    break;
   case 19:
    var $44;
    var $45;
    if (($45 | 0) > ($44 | 0)) {
      __label__ = 20;
      break;
    } else {
      var $49 = $45;
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[$begin >> 2] = $44;
    var $49 = $44;
    __label__ = 21;
    break;
   case 21:
    var $49;
    var $50 = __ZN18TypedArrayTemplateIaE14createSubarrayEP9JSContextP8JSObjectjj($cx, $9, $49, $44);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    __ZN2JS5Value9setObjectER8JSObject($vp, $50);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIaE12fun_subarrayEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIaE7fun_setEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $off = __stackBase__;
    var $len = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$2 + 4 >> 2];
    var $5 = __ZNK8JSObject8getClassEv($_idx1_val);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$off >> 2] = 0;
    if ($argc >>> 0 > 1) {
      __label__ = 6;
      break;
    } else {
      var $24 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $14 = $vp + 24 | 0;
    var $15 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $14, $off);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $17 = HEAPU32[$off >> 2];
    if (($17 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($17 >>> 0 > $20 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $24 = $17;
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 10:
    var $24;
    if (($argc | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_idx = $vp + 16 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $27 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($27) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 13:
    var $30 = __ZNK2JS5Value14toObjectOrNullEv($_idx_val$0, $_idx_val$1);
    var $_idx3_val = HEAP32[$30 + 4 >> 2];
    var $31 = __Z15js_IsTypedArrayP8JSObject($_idx3_val);
    if (($31 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $34 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($30);
    if (($34 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $37 = __ZN2js10TypedArray9getLengthEP8JSObject($34);
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($37 >>> 0 > ($38 - $24 | 0) >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 17:
    var $43 = __ZN18TypedArrayTemplateIaE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $2, $34, $24);
    if ($43) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 18:
    var $45 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $30, $len);
    if (($45 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $48 = HEAPU32[$len >> 2];
    var $49 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($48 >>> 0 > ($49 - $24 | 0) >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 21:
    var $54 = __ZN18TypedArrayTemplateIaE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $2, $30, $48, $24);
    if ($54) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 22:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIaE7fun_setEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIhE12fun_subarrayEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $begin = __stackBase__;
    var $end = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$2 + 4 >> 2];
    var $5 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 232 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 232 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$begin >> 2] = 0;
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    HEAP32[$end >> 2] = $12;
    if (($argc | 0) == 0) {
      var $45 = 0;
      var $44 = $12;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $vp + 16 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $begin);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAP32[$begin >> 2];
    if (($18 | 0) < 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $21 = $18 + $12 | 0;
    HEAP32[$begin >> 2] = $21;
    if (($21 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      var $28 = $21;
      __label__ = 12;
      break;
    }
   case 9:
    HEAP32[$begin >> 2] = 0;
    var $28 = 0;
    __label__ = 12;
    break;
   case 10:
    if (($18 | 0) > ($12 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $28 = $18;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$begin >> 2] = $12;
    var $28 = $12;
    __label__ = 12;
    break;
   case 12:
    var $28;
    if ($argc >>> 0 > 1) {
      __label__ = 13;
      break;
    } else {
      var $45 = $28;
      var $44 = $12;
      __label__ = 19;
      break;
    }
   case 13:
    var $31 = $vp + 24 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $end);
    if ($32) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 14:
    var $34 = HEAPU32[$end >> 2];
    if (($34 | 0) < 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $37 = $34 + $12 | 0;
    HEAP32[$end >> 2] = $37;
    if (($37 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      var $45 = $28;
      var $44 = $37;
      __label__ = 19;
      break;
    }
   case 16:
    HEAP32[$end >> 2] = 0;
    var $45 = $28;
    var $44 = 0;
    __label__ = 19;
    break;
   case 17:
    if (($34 | 0) > ($12 | 0)) {
      __label__ = 18;
      break;
    } else {
      var $45 = $28;
      var $44 = $34;
      __label__ = 19;
      break;
    }
   case 18:
    HEAP32[$end >> 2] = $12;
    var $45 = $28;
    var $44 = $12;
    __label__ = 19;
    break;
   case 19:
    var $44;
    var $45;
    if (($45 | 0) > ($44 | 0)) {
      __label__ = 20;
      break;
    } else {
      var $49 = $45;
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[$begin >> 2] = $44;
    var $49 = $44;
    __label__ = 21;
    break;
   case 21:
    var $49;
    var $50 = __ZN18TypedArrayTemplateIhE14createSubarrayEP9JSContextP8JSObjectjj($cx, $9, $49, $44);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    __ZN2JS5Value9setObjectER8JSObject($vp, $50);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIhE12fun_subarrayEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIhE7fun_setEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $off = __stackBase__;
    var $len = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$2 + 4 >> 2];
    var $5 = __ZNK8JSObject8getClassEv($_idx1_val);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 232 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 232 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$off >> 2] = 0;
    if ($argc >>> 0 > 1) {
      __label__ = 6;
      break;
    } else {
      var $24 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $14 = $vp + 24 | 0;
    var $15 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $14, $off);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $17 = HEAPU32[$off >> 2];
    if (($17 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($17 >>> 0 > $20 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $24 = $17;
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 10:
    var $24;
    if (($argc | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_idx = $vp + 16 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $27 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($27) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 13:
    var $30 = __ZNK2JS5Value14toObjectOrNullEv($_idx_val$0, $_idx_val$1);
    var $_idx3_val = HEAP32[$30 + 4 >> 2];
    var $31 = __Z15js_IsTypedArrayP8JSObject($_idx3_val);
    if (($31 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $34 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($30);
    if (($34 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $37 = __ZN2js10TypedArray9getLengthEP8JSObject($34);
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($37 >>> 0 > ($38 - $24 | 0) >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 17:
    var $43 = __ZN18TypedArrayTemplateIhE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $2, $34, $24);
    if ($43) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 18:
    var $45 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $30, $len);
    if (($45 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $48 = HEAPU32[$len >> 2];
    var $49 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($48 >>> 0 > ($49 - $24 | 0) >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 21:
    var $54 = __ZN18TypedArrayTemplateIhE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $2, $30, $48, $24);
    if ($54) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 22:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIhE7fun_setEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIsE12fun_subarrayEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $begin = __stackBase__;
    var $end = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$2 + 4 >> 2];
    var $5 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 464 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 464 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$begin >> 2] = 0;
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    HEAP32[$end >> 2] = $12;
    if (($argc | 0) == 0) {
      var $45 = 0;
      var $44 = $12;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $vp + 16 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $begin);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAP32[$begin >> 2];
    if (($18 | 0) < 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $21 = $18 + $12 | 0;
    HEAP32[$begin >> 2] = $21;
    if (($21 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      var $28 = $21;
      __label__ = 12;
      break;
    }
   case 9:
    HEAP32[$begin >> 2] = 0;
    var $28 = 0;
    __label__ = 12;
    break;
   case 10:
    if (($18 | 0) > ($12 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $28 = $18;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$begin >> 2] = $12;
    var $28 = $12;
    __label__ = 12;
    break;
   case 12:
    var $28;
    if ($argc >>> 0 > 1) {
      __label__ = 13;
      break;
    } else {
      var $45 = $28;
      var $44 = $12;
      __label__ = 19;
      break;
    }
   case 13:
    var $31 = $vp + 24 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $end);
    if ($32) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 14:
    var $34 = HEAPU32[$end >> 2];
    if (($34 | 0) < 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $37 = $34 + $12 | 0;
    HEAP32[$end >> 2] = $37;
    if (($37 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      var $45 = $28;
      var $44 = $37;
      __label__ = 19;
      break;
    }
   case 16:
    HEAP32[$end >> 2] = 0;
    var $45 = $28;
    var $44 = 0;
    __label__ = 19;
    break;
   case 17:
    if (($34 | 0) > ($12 | 0)) {
      __label__ = 18;
      break;
    } else {
      var $45 = $28;
      var $44 = $34;
      __label__ = 19;
      break;
    }
   case 18:
    HEAP32[$end >> 2] = $12;
    var $45 = $28;
    var $44 = $12;
    __label__ = 19;
    break;
   case 19:
    var $44;
    var $45;
    if (($45 | 0) > ($44 | 0)) {
      __label__ = 20;
      break;
    } else {
      var $49 = $45;
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[$begin >> 2] = $44;
    var $49 = $44;
    __label__ = 21;
    break;
   case 21:
    var $49;
    var $50 = __ZN18TypedArrayTemplateIsE14createSubarrayEP9JSContextP8JSObjectjj($cx, $9, $49, $44);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    __ZN2JS5Value9setObjectER8JSObject($vp, $50);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIsE12fun_subarrayEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIsE7fun_setEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $off = __stackBase__;
    var $len = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$2 + 4 >> 2];
    var $5 = __ZNK8JSObject8getClassEv($_idx1_val);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 464 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 464 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$off >> 2] = 0;
    if ($argc >>> 0 > 1) {
      __label__ = 6;
      break;
    } else {
      var $24 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $14 = $vp + 24 | 0;
    var $15 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $14, $off);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $17 = HEAPU32[$off >> 2];
    if (($17 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($17 >>> 0 > $20 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $24 = $17;
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 10:
    var $24;
    if (($argc | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_idx = $vp + 16 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $27 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($27) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 13:
    var $30 = __ZNK2JS5Value14toObjectOrNullEv($_idx_val$0, $_idx_val$1);
    var $_idx3_val = HEAP32[$30 + 4 >> 2];
    var $31 = __Z15js_IsTypedArrayP8JSObject($_idx3_val);
    if (($31 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $34 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($30);
    if (($34 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $37 = __ZN2js10TypedArray9getLengthEP8JSObject($34);
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($37 >>> 0 > ($38 - $24 | 0) >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 17:
    var $43 = __ZN18TypedArrayTemplateIsE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $2, $34, $24);
    if ($43) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 18:
    var $45 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $30, $len);
    if (($45 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $48 = HEAPU32[$len >> 2];
    var $49 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($48 >>> 0 > ($49 - $24 | 0) >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 21:
    var $54 = __ZN18TypedArrayTemplateIsE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $2, $30, $48, $24);
    if ($54) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 22:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIsE7fun_setEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateItE12fun_subarrayEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $begin = __stackBase__;
    var $end = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$2 + 4 >> 2];
    var $5 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 696 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 696 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$begin >> 2] = 0;
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    HEAP32[$end >> 2] = $12;
    if (($argc | 0) == 0) {
      var $45 = 0;
      var $44 = $12;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $vp + 16 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $begin);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAP32[$begin >> 2];
    if (($18 | 0) < 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $21 = $18 + $12 | 0;
    HEAP32[$begin >> 2] = $21;
    if (($21 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      var $28 = $21;
      __label__ = 12;
      break;
    }
   case 9:
    HEAP32[$begin >> 2] = 0;
    var $28 = 0;
    __label__ = 12;
    break;
   case 10:
    if (($18 | 0) > ($12 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $28 = $18;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$begin >> 2] = $12;
    var $28 = $12;
    __label__ = 12;
    break;
   case 12:
    var $28;
    if ($argc >>> 0 > 1) {
      __label__ = 13;
      break;
    } else {
      var $45 = $28;
      var $44 = $12;
      __label__ = 19;
      break;
    }
   case 13:
    var $31 = $vp + 24 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $end);
    if ($32) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 14:
    var $34 = HEAPU32[$end >> 2];
    if (($34 | 0) < 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $37 = $34 + $12 | 0;
    HEAP32[$end >> 2] = $37;
    if (($37 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      var $45 = $28;
      var $44 = $37;
      __label__ = 19;
      break;
    }
   case 16:
    HEAP32[$end >> 2] = 0;
    var $45 = $28;
    var $44 = 0;
    __label__ = 19;
    break;
   case 17:
    if (($34 | 0) > ($12 | 0)) {
      __label__ = 18;
      break;
    } else {
      var $45 = $28;
      var $44 = $34;
      __label__ = 19;
      break;
    }
   case 18:
    HEAP32[$end >> 2] = $12;
    var $45 = $28;
    var $44 = $12;
    __label__ = 19;
    break;
   case 19:
    var $44;
    var $45;
    if (($45 | 0) > ($44 | 0)) {
      __label__ = 20;
      break;
    } else {
      var $49 = $45;
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[$begin >> 2] = $44;
    var $49 = $44;
    __label__ = 21;
    break;
   case 21:
    var $49;
    var $50 = __ZN18TypedArrayTemplateItE14createSubarrayEP9JSContextP8JSObjectjj($cx, $9, $49, $44);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    __ZN2JS5Value9setObjectER8JSObject($vp, $50);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateItE12fun_subarrayEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateItE7fun_setEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $off = __stackBase__;
    var $len = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$2 + 4 >> 2];
    var $5 = __ZNK8JSObject8getClassEv($_idx1_val);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 696 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 696 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$off >> 2] = 0;
    if ($argc >>> 0 > 1) {
      __label__ = 6;
      break;
    } else {
      var $24 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $14 = $vp + 24 | 0;
    var $15 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $14, $off);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $17 = HEAPU32[$off >> 2];
    if (($17 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($17 >>> 0 > $20 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $24 = $17;
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 10:
    var $24;
    if (($argc | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_idx = $vp + 16 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $27 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($27) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 13:
    var $30 = __ZNK2JS5Value14toObjectOrNullEv($_idx_val$0, $_idx_val$1);
    var $_idx3_val = HEAP32[$30 + 4 >> 2];
    var $31 = __Z15js_IsTypedArrayP8JSObject($_idx3_val);
    if (($31 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $34 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($30);
    if (($34 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $37 = __ZN2js10TypedArray9getLengthEP8JSObject($34);
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($37 >>> 0 > ($38 - $24 | 0) >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 17:
    var $43 = __ZN18TypedArrayTemplateItE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $2, $34, $24);
    if ($43) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 18:
    var $45 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $30, $len);
    if (($45 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $48 = HEAPU32[$len >> 2];
    var $49 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($48 >>> 0 > ($49 - $24 | 0) >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 21:
    var $54 = __ZN18TypedArrayTemplateItE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $2, $30, $48, $24);
    if ($54) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 22:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateItE7fun_setEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIiE12fun_subarrayEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $begin = __stackBase__;
    var $end = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$2 + 4 >> 2];
    var $5 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 928 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 928 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$begin >> 2] = 0;
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    HEAP32[$end >> 2] = $12;
    if (($argc | 0) == 0) {
      var $45 = 0;
      var $44 = $12;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $vp + 16 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $begin);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAP32[$begin >> 2];
    if (($18 | 0) < 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $21 = $18 + $12 | 0;
    HEAP32[$begin >> 2] = $21;
    if (($21 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      var $28 = $21;
      __label__ = 12;
      break;
    }
   case 9:
    HEAP32[$begin >> 2] = 0;
    var $28 = 0;
    __label__ = 12;
    break;
   case 10:
    if (($18 | 0) > ($12 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $28 = $18;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$begin >> 2] = $12;
    var $28 = $12;
    __label__ = 12;
    break;
   case 12:
    var $28;
    if ($argc >>> 0 > 1) {
      __label__ = 13;
      break;
    } else {
      var $45 = $28;
      var $44 = $12;
      __label__ = 19;
      break;
    }
   case 13:
    var $31 = $vp + 24 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $end);
    if ($32) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 14:
    var $34 = HEAPU32[$end >> 2];
    if (($34 | 0) < 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $37 = $34 + $12 | 0;
    HEAP32[$end >> 2] = $37;
    if (($37 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      var $45 = $28;
      var $44 = $37;
      __label__ = 19;
      break;
    }
   case 16:
    HEAP32[$end >> 2] = 0;
    var $45 = $28;
    var $44 = 0;
    __label__ = 19;
    break;
   case 17:
    if (($34 | 0) > ($12 | 0)) {
      __label__ = 18;
      break;
    } else {
      var $45 = $28;
      var $44 = $34;
      __label__ = 19;
      break;
    }
   case 18:
    HEAP32[$end >> 2] = $12;
    var $45 = $28;
    var $44 = $12;
    __label__ = 19;
    break;
   case 19:
    var $44;
    var $45;
    if (($45 | 0) > ($44 | 0)) {
      __label__ = 20;
      break;
    } else {
      var $49 = $45;
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[$begin >> 2] = $44;
    var $49 = $44;
    __label__ = 21;
    break;
   case 21:
    var $49;
    var $50 = __ZN18TypedArrayTemplateIiE14createSubarrayEP9JSContextP8JSObjectjj($cx, $9, $49, $44);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    __ZN2JS5Value9setObjectER8JSObject($vp, $50);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIiE12fun_subarrayEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIiE7fun_setEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $off = __stackBase__;
    var $len = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$2 + 4 >> 2];
    var $5 = __ZNK8JSObject8getClassEv($_idx1_val);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 928 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 928 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$off >> 2] = 0;
    if ($argc >>> 0 > 1) {
      __label__ = 6;
      break;
    } else {
      var $24 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $14 = $vp + 24 | 0;
    var $15 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $14, $off);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $17 = HEAPU32[$off >> 2];
    if (($17 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($17 >>> 0 > $20 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $24 = $17;
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 10:
    var $24;
    if (($argc | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_idx = $vp + 16 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $27 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($27) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 13:
    var $30 = __ZNK2JS5Value14toObjectOrNullEv($_idx_val$0, $_idx_val$1);
    var $_idx3_val = HEAP32[$30 + 4 >> 2];
    var $31 = __Z15js_IsTypedArrayP8JSObject($_idx3_val);
    if (($31 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $34 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($30);
    if (($34 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $37 = __ZN2js10TypedArray9getLengthEP8JSObject($34);
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($37 >>> 0 > ($38 - $24 | 0) >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 17:
    var $43 = __ZN18TypedArrayTemplateIiE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $2, $34, $24);
    if ($43) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 18:
    var $45 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $30, $len);
    if (($45 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $48 = HEAPU32[$len >> 2];
    var $49 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($48 >>> 0 > ($49 - $24 | 0) >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 21:
    var $54 = __ZN18TypedArrayTemplateIiE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $2, $30, $48, $24);
    if ($54) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 22:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIiE7fun_setEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIjE12fun_subarrayEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $begin = __stackBase__;
    var $end = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$2 + 4 >> 2];
    var $5 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 1160 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 1160 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$begin >> 2] = 0;
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    HEAP32[$end >> 2] = $12;
    if (($argc | 0) == 0) {
      var $45 = 0;
      var $44 = $12;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $vp + 16 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $begin);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAP32[$begin >> 2];
    if (($18 | 0) < 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $21 = $18 + $12 | 0;
    HEAP32[$begin >> 2] = $21;
    if (($21 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      var $28 = $21;
      __label__ = 12;
      break;
    }
   case 9:
    HEAP32[$begin >> 2] = 0;
    var $28 = 0;
    __label__ = 12;
    break;
   case 10:
    if (($18 | 0) > ($12 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $28 = $18;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$begin >> 2] = $12;
    var $28 = $12;
    __label__ = 12;
    break;
   case 12:
    var $28;
    if ($argc >>> 0 > 1) {
      __label__ = 13;
      break;
    } else {
      var $45 = $28;
      var $44 = $12;
      __label__ = 19;
      break;
    }
   case 13:
    var $31 = $vp + 24 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $end);
    if ($32) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 14:
    var $34 = HEAPU32[$end >> 2];
    if (($34 | 0) < 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $37 = $34 + $12 | 0;
    HEAP32[$end >> 2] = $37;
    if (($37 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      var $45 = $28;
      var $44 = $37;
      __label__ = 19;
      break;
    }
   case 16:
    HEAP32[$end >> 2] = 0;
    var $45 = $28;
    var $44 = 0;
    __label__ = 19;
    break;
   case 17:
    if (($34 | 0) > ($12 | 0)) {
      __label__ = 18;
      break;
    } else {
      var $45 = $28;
      var $44 = $34;
      __label__ = 19;
      break;
    }
   case 18:
    HEAP32[$end >> 2] = $12;
    var $45 = $28;
    var $44 = $12;
    __label__ = 19;
    break;
   case 19:
    var $44;
    var $45;
    if (($45 | 0) > ($44 | 0)) {
      __label__ = 20;
      break;
    } else {
      var $49 = $45;
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[$begin >> 2] = $44;
    var $49 = $44;
    __label__ = 21;
    break;
   case 21:
    var $49;
    var $50 = __ZN18TypedArrayTemplateIjE14createSubarrayEP9JSContextP8JSObjectjj($cx, $9, $49, $44);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    __ZN2JS5Value9setObjectER8JSObject($vp, $50);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIjE12fun_subarrayEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIjE7fun_setEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $off = __stackBase__;
    var $len = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$2 + 4 >> 2];
    var $5 = __ZNK8JSObject8getClassEv($_idx1_val);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 1160 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 1160 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$off >> 2] = 0;
    if ($argc >>> 0 > 1) {
      __label__ = 6;
      break;
    } else {
      var $24 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $14 = $vp + 24 | 0;
    var $15 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $14, $off);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $17 = HEAPU32[$off >> 2];
    if (($17 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($17 >>> 0 > $20 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $24 = $17;
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 10:
    var $24;
    if (($argc | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_idx = $vp + 16 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $27 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($27) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 13:
    var $30 = __ZNK2JS5Value14toObjectOrNullEv($_idx_val$0, $_idx_val$1);
    var $_idx3_val = HEAP32[$30 + 4 >> 2];
    var $31 = __Z15js_IsTypedArrayP8JSObject($_idx3_val);
    if (($31 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $34 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($30);
    if (($34 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $37 = __ZN2js10TypedArray9getLengthEP8JSObject($34);
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($37 >>> 0 > ($38 - $24 | 0) >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 17:
    var $43 = __ZN18TypedArrayTemplateIjE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $2, $34, $24);
    if ($43) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 18:
    var $45 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $30, $len);
    if (($45 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $48 = HEAPU32[$len >> 2];
    var $49 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($48 >>> 0 > ($49 - $24 | 0) >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 21:
    var $54 = __ZN18TypedArrayTemplateIjE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $2, $30, $48, $24);
    if ($54) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 22:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIjE7fun_setEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIfE12fun_subarrayEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $begin = __stackBase__;
    var $end = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$2 + 4 >> 2];
    var $5 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 1392 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 1392 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$begin >> 2] = 0;
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    HEAP32[$end >> 2] = $12;
    if (($argc | 0) == 0) {
      var $45 = 0;
      var $44 = $12;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $vp + 16 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $begin);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAP32[$begin >> 2];
    if (($18 | 0) < 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $21 = $18 + $12 | 0;
    HEAP32[$begin >> 2] = $21;
    if (($21 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      var $28 = $21;
      __label__ = 12;
      break;
    }
   case 9:
    HEAP32[$begin >> 2] = 0;
    var $28 = 0;
    __label__ = 12;
    break;
   case 10:
    if (($18 | 0) > ($12 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $28 = $18;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$begin >> 2] = $12;
    var $28 = $12;
    __label__ = 12;
    break;
   case 12:
    var $28;
    if ($argc >>> 0 > 1) {
      __label__ = 13;
      break;
    } else {
      var $45 = $28;
      var $44 = $12;
      __label__ = 19;
      break;
    }
   case 13:
    var $31 = $vp + 24 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $end);
    if ($32) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 14:
    var $34 = HEAPU32[$end >> 2];
    if (($34 | 0) < 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $37 = $34 + $12 | 0;
    HEAP32[$end >> 2] = $37;
    if (($37 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      var $45 = $28;
      var $44 = $37;
      __label__ = 19;
      break;
    }
   case 16:
    HEAP32[$end >> 2] = 0;
    var $45 = $28;
    var $44 = 0;
    __label__ = 19;
    break;
   case 17:
    if (($34 | 0) > ($12 | 0)) {
      __label__ = 18;
      break;
    } else {
      var $45 = $28;
      var $44 = $34;
      __label__ = 19;
      break;
    }
   case 18:
    HEAP32[$end >> 2] = $12;
    var $45 = $28;
    var $44 = $12;
    __label__ = 19;
    break;
   case 19:
    var $44;
    var $45;
    if (($45 | 0) > ($44 | 0)) {
      __label__ = 20;
      break;
    } else {
      var $49 = $45;
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[$begin >> 2] = $44;
    var $49 = $44;
    __label__ = 21;
    break;
   case 21:
    var $49;
    var $50 = __ZN18TypedArrayTemplateIfE14createSubarrayEP9JSContextP8JSObjectjj($cx, $9, $49, $44);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    __ZN2JS5Value9setObjectER8JSObject($vp, $50);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIfE12fun_subarrayEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIfE7fun_setEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $off = __stackBase__;
    var $len = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$2 + 4 >> 2];
    var $5 = __ZNK8JSObject8getClassEv($_idx1_val);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 1392 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 1392 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$off >> 2] = 0;
    if ($argc >>> 0 > 1) {
      __label__ = 6;
      break;
    } else {
      var $24 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $14 = $vp + 24 | 0;
    var $15 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $14, $off);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $17 = HEAPU32[$off >> 2];
    if (($17 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($17 >>> 0 > $20 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $24 = $17;
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 10:
    var $24;
    if (($argc | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_idx = $vp + 16 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $27 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($27) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 13:
    var $30 = __ZNK2JS5Value14toObjectOrNullEv($_idx_val$0, $_idx_val$1);
    var $_idx3_val = HEAP32[$30 + 4 >> 2];
    var $31 = __Z15js_IsTypedArrayP8JSObject($_idx3_val);
    if (($31 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $34 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($30);
    if (($34 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $37 = __ZN2js10TypedArray9getLengthEP8JSObject($34);
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($37 >>> 0 > ($38 - $24 | 0) >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 17:
    var $43 = __ZN18TypedArrayTemplateIfE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $2, $34, $24);
    if ($43) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 18:
    var $45 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $30, $len);
    if (($45 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $48 = HEAPU32[$len >> 2];
    var $49 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($48 >>> 0 > ($49 - $24 | 0) >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 21:
    var $54 = __ZN18TypedArrayTemplateIfE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $2, $30, $48, $24);
    if ($54) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 22:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIfE7fun_setEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIdE12fun_subarrayEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $begin = __stackBase__;
    var $end = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$2 + 4 >> 2];
    var $5 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 1624 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 1624 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$begin >> 2] = 0;
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    HEAP32[$end >> 2] = $12;
    if (($argc | 0) == 0) {
      var $45 = 0;
      var $44 = $12;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $vp + 16 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $begin);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAP32[$begin >> 2];
    if (($18 | 0) < 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $21 = $18 + $12 | 0;
    HEAP32[$begin >> 2] = $21;
    if (($21 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      var $28 = $21;
      __label__ = 12;
      break;
    }
   case 9:
    HEAP32[$begin >> 2] = 0;
    var $28 = 0;
    __label__ = 12;
    break;
   case 10:
    if (($18 | 0) > ($12 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $28 = $18;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$begin >> 2] = $12;
    var $28 = $12;
    __label__ = 12;
    break;
   case 12:
    var $28;
    if ($argc >>> 0 > 1) {
      __label__ = 13;
      break;
    } else {
      var $45 = $28;
      var $44 = $12;
      __label__ = 19;
      break;
    }
   case 13:
    var $31 = $vp + 24 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $end);
    if ($32) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 14:
    var $34 = HEAPU32[$end >> 2];
    if (($34 | 0) < 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $37 = $34 + $12 | 0;
    HEAP32[$end >> 2] = $37;
    if (($37 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      var $45 = $28;
      var $44 = $37;
      __label__ = 19;
      break;
    }
   case 16:
    HEAP32[$end >> 2] = 0;
    var $45 = $28;
    var $44 = 0;
    __label__ = 19;
    break;
   case 17:
    if (($34 | 0) > ($12 | 0)) {
      __label__ = 18;
      break;
    } else {
      var $45 = $28;
      var $44 = $34;
      __label__ = 19;
      break;
    }
   case 18:
    HEAP32[$end >> 2] = $12;
    var $45 = $28;
    var $44 = $12;
    __label__ = 19;
    break;
   case 19:
    var $44;
    var $45;
    if (($45 | 0) > ($44 | 0)) {
      __label__ = 20;
      break;
    } else {
      var $49 = $45;
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[$begin >> 2] = $44;
    var $49 = $44;
    __label__ = 21;
    break;
   case 21:
    var $49;
    var $50 = __ZN18TypedArrayTemplateIdE14createSubarrayEP9JSContextP8JSObjectjj($cx, $9, $49, $44);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    __ZN2JS5Value9setObjectER8JSObject($vp, $50);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIdE12fun_subarrayEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIdE7fun_setEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $off = __stackBase__;
    var $len = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$2 + 4 >> 2];
    var $5 = __ZNK8JSObject8getClassEv($_idx1_val);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 1624 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 1624 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$off >> 2] = 0;
    if ($argc >>> 0 > 1) {
      __label__ = 6;
      break;
    } else {
      var $24 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $14 = $vp + 24 | 0;
    var $15 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $14, $off);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $17 = HEAPU32[$off >> 2];
    if (($17 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($17 >>> 0 > $20 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $24 = $17;
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 10:
    var $24;
    if (($argc | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_idx = $vp + 16 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $27 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($27) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 13:
    var $30 = __ZNK2JS5Value14toObjectOrNullEv($_idx_val$0, $_idx_val$1);
    var $_idx3_val = HEAP32[$30 + 4 >> 2];
    var $31 = __Z15js_IsTypedArrayP8JSObject($_idx3_val);
    if (($31 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $34 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($30);
    if (($34 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $37 = __ZN2js10TypedArray9getLengthEP8JSObject($34);
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($37 >>> 0 > ($38 - $24 | 0) >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 17:
    var $43 = __ZN18TypedArrayTemplateIdE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $2, $34, $24);
    if ($43) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 18:
    var $45 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $30, $len);
    if (($45 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $48 = HEAPU32[$len >> 2];
    var $49 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($48 >>> 0 > ($49 - $24 | 0) >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 21:
    var $54 = __ZN18TypedArrayTemplateIdE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $2, $30, $48, $24);
    if ($54) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 22:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIdE7fun_setEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateI13uint8_clampedE12fun_subarrayEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $begin = __stackBase__;
    var $end = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$2 + 4 >> 2];
    var $5 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 1856 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 1856 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$begin >> 2] = 0;
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    HEAP32[$end >> 2] = $12;
    if (($argc | 0) == 0) {
      var $45 = 0;
      var $44 = $12;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $vp + 16 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $begin);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAP32[$begin >> 2];
    if (($18 | 0) < 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $21 = $18 + $12 | 0;
    HEAP32[$begin >> 2] = $21;
    if (($21 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      var $28 = $21;
      __label__ = 12;
      break;
    }
   case 9:
    HEAP32[$begin >> 2] = 0;
    var $28 = 0;
    __label__ = 12;
    break;
   case 10:
    if (($18 | 0) > ($12 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $28 = $18;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$begin >> 2] = $12;
    var $28 = $12;
    __label__ = 12;
    break;
   case 12:
    var $28;
    if ($argc >>> 0 > 1) {
      __label__ = 13;
      break;
    } else {
      var $45 = $28;
      var $44 = $12;
      __label__ = 19;
      break;
    }
   case 13:
    var $31 = $vp + 24 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $end);
    if ($32) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 14:
    var $34 = HEAPU32[$end >> 2];
    if (($34 | 0) < 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $37 = $34 + $12 | 0;
    HEAP32[$end >> 2] = $37;
    if (($37 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      var $45 = $28;
      var $44 = $37;
      __label__ = 19;
      break;
    }
   case 16:
    HEAP32[$end >> 2] = 0;
    var $45 = $28;
    var $44 = 0;
    __label__ = 19;
    break;
   case 17:
    if (($34 | 0) > ($12 | 0)) {
      __label__ = 18;
      break;
    } else {
      var $45 = $28;
      var $44 = $34;
      __label__ = 19;
      break;
    }
   case 18:
    HEAP32[$end >> 2] = $12;
    var $45 = $28;
    var $44 = $12;
    __label__ = 19;
    break;
   case 19:
    var $44;
    var $45;
    if (($45 | 0) > ($44 | 0)) {
      __label__ = 20;
      break;
    } else {
      var $49 = $45;
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[$begin >> 2] = $44;
    var $49 = $44;
    __label__ = 21;
    break;
   case 21:
    var $49;
    var $50 = __ZN18TypedArrayTemplateI13uint8_clampedE14createSubarrayEP9JSContextP8JSObjectjj($cx, $9, $49, $44);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    __ZN2JS5Value9setObjectER8JSObject($vp, $50);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateI13uint8_clampedE12fun_subarrayEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIaE10obj_typeOfEP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZN18TypedArrayTemplateIhE10obj_typeOfEP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE7fun_setEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $off = __stackBase__;
    var $len = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$2 + 4 >> 2];
    var $5 = __ZNK8JSObject8getClassEv($_idx1_val);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 1856 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 1856 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$off >> 2] = 0;
    if ($argc >>> 0 > 1) {
      __label__ = 6;
      break;
    } else {
      var $24 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $14 = $vp + 24 | 0;
    var $15 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $14, $off);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $17 = HEAPU32[$off >> 2];
    if (($17 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($17 >>> 0 > $20 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $24 = $17;
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 10:
    var $24;
    if (($argc | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_idx = $vp + 16 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $27 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($27) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 13:
    var $30 = __ZNK2JS5Value14toObjectOrNullEv($_idx_val$0, $_idx_val$1);
    var $_idx3_val = HEAP32[$30 + 4 >> 2];
    var $31 = __Z15js_IsTypedArrayP8JSObject($_idx3_val);
    if (($31 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $34 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($30);
    if (($34 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $37 = __ZN2js10TypedArray9getLengthEP8JSObject($34);
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($37 >>> 0 > ($38 - $24 | 0) >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 17:
    var $43 = __ZN18TypedArrayTemplateI13uint8_clampedE18copyFromTypedArrayEP9JSContextP8JSObjectS5_j($cx, $2, $34, $24);
    if ($43) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 18:
    var $45 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $30, $len);
    if (($45 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $48 = HEAPU32[$len >> 2];
    var $49 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($48 >>> 0 > ($49 - $24 | 0) >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 21:
    var $54 = __ZN18TypedArrayTemplateI13uint8_clampedE13copyFromArrayEP9JSContextP8JSObjectS5_jj($cx, $2, $30, $48, $24);
    if ($54) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 22:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateI13uint8_clampedE7fun_setEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIaE9obj_traceEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $id, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $v | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $tmp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZN18TypedArrayTemplateIaE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $tmp, 0);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $index, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $tmp = __stackBase__;
  var $1 = $v | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $tmp | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  var $4 = __ZN18TypedArrayTemplateIaE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $tmp, 0);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIaE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej($cx, $obj, $sid, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIaE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $1, $v, undef, undef, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIaE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($1, $id, $index);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = HEAP32[$index >> 2];
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    __ZN18TypedArrayTemplateIaE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($_idx1_val, $15, $vp);
    __label__ = 10;
    break;
   case 5:
    var $obj_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $17 = __ZNK8JSObject8getProtoEv($obj_idx_val_idx_val);
    var $18 = ($17 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($18) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = HEAP32[$cx + 208 >> 2];
    var $22 = $cx;
    var $23 = $17;
    var $24 = $obj2;
    var $25 = $prop;
    var $26 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($22, $23, $id, $21, $24, $25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $28 = HEAP32[$prop >> 2];
    if (($28 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAP32[$obj2 >> 2];
    var $_idx_val = HEAP32[$31 >> 2];
    var $32 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = $obj;
    var $35 = $31;
    var $36 = $28;
    var $37 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($22, $34, $35, $36, 0, $vp);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIaE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIaE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom3984($1);
  var $3 = __ZN18TypedArrayTemplateIaE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $2, $vp);
  return $3;
}

function __ZN18TypedArrayTemplateIaE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    __ZN18TypedArrayTemplateIaE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($_idx1_val, $index, $vp);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    var $obj_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $6 = __ZNK8JSObject8getProtoEv($obj_idx_val_idx_val);
    var $7 = ($6 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($7) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = HEAP32[$id >> 2];
    var $13 = HEAP32[$cx + 208 >> 2];
    var $14 = $cx;
    var $15 = $6;
    var $16 = $obj2;
    var $17 = $prop;
    var $18 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($14, $15, $11, $13, $16, $17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $20 = HEAP32[$prop >> 2];
    if (($20 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = HEAP32[$obj2 >> 2];
    var $_idx_val = HEAP32[$23 >> 2];
    var $24 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = $obj;
    var $27 = $23;
    var $28 = $20;
    var $29 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($14, $26, $27, $28, 0, $vp);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIaE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN18TypedArrayTemplateIaE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    __label__ = 6;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($1, $id, $index);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 6;
    break;
   case 5:
    var $16 = HEAP32[$index >> 2];
    __ZN18TypedArrayTemplateIaE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $16, $vp);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 4;
    break;
   case 3:
    __ZN18TypedArrayTemplateIaE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $index, $vp);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIaE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, $strict);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIaE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 3:
    var $10 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $11 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($10, $id, 0);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 5:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 6;
    break;
   case 6:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIaE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIaE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    if (($enum_op | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($enum_op | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($enum_op | 0) == 2) {
      __label__ = 6;
      break;
    } else if (($enum_op | 0) == 3) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($statep, 1);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $6 = $5 + 1 | 0;
    var $7 = _INT_TO_JSID4006($6);
    HEAP32[$idp >> 2] = $7;
    __label__ = 12;
    break;
   case 4:
    __ZN2JS5Value8setInt32Ei($statep, 0);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $12 = _INT_TO_JSID4006($11);
    HEAP32[$idp >> 2] = $12;
    __label__ = 12;
    break;
   case 6:
    var $statep_idx1 = $statep | 0;
    var $statep_idx1_val$0 = HEAP32[$statep_idx1 >> 2];
    var $statep_idx1_val$1 = HEAP32[$statep_idx1 + 4 >> 2];
    var $14 = __ZNK2JS5Value6isTrueEv($statep_idx1_val$0, $statep_idx1_val$1);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom3984($20);
    HEAP32[$idp >> 2] = $21;
    __ZN2JS5Value8setInt32Ei($statep, 0);
    __label__ = 12;
    break;
   case 8:
    var $23 = __ZNK2JS5Value7toInt32Ev($statep_idx1_val$0, $statep_idx1_val$1);
    var $24 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($23 >>> 0 < $24 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = _INT_TO_JSID4006($23);
    HEAP32[$idp >> 2] = $27;
    var $28 = $23 + 1 | 0;
    __ZN2JS5Value8setInt32Ei($statep, $28);
    __label__ = 12;
    break;
   case 10:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 11:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 12:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE9obj_traceEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $id, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $v | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $tmp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZN18TypedArrayTemplateIhE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $tmp, 0);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $index, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $tmp = __stackBase__;
  var $1 = $v | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $tmp | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  var $4 = __ZN18TypedArrayTemplateIhE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $tmp, 0);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIhE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej($cx, $obj, $sid, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIhE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $1, $v, undef, undef, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIhE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($1, $id, $index);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = HEAP32[$index >> 2];
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    __ZN18TypedArrayTemplateIhE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($_idx1_val, $15, $vp);
    __label__ = 10;
    break;
   case 5:
    var $obj_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $17 = __ZNK8JSObject8getProtoEv($obj_idx_val_idx_val);
    var $18 = ($17 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($18) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = HEAP32[$cx + 208 >> 2];
    var $22 = $cx;
    var $23 = $17;
    var $24 = $obj2;
    var $25 = $prop;
    var $26 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($22, $23, $id, $21, $24, $25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $28 = HEAP32[$prop >> 2];
    if (($28 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAP32[$obj2 >> 2];
    var $_idx_val = HEAP32[$31 >> 2];
    var $32 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = $obj;
    var $35 = $31;
    var $36 = $28;
    var $37 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($22, $34, $35, $36, 0, $vp);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIhE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIhE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom3984($1);
  var $3 = __ZN18TypedArrayTemplateIhE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $2, $vp);
  return $3;
}

function __ZN18TypedArrayTemplateIhE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    __ZN18TypedArrayTemplateIhE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($_idx1_val, $index, $vp);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    var $obj_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $6 = __ZNK8JSObject8getProtoEv($obj_idx_val_idx_val);
    var $7 = ($6 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($7) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = HEAP32[$id >> 2];
    var $13 = HEAP32[$cx + 208 >> 2];
    var $14 = $cx;
    var $15 = $6;
    var $16 = $obj2;
    var $17 = $prop;
    var $18 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($14, $15, $11, $13, $16, $17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $20 = HEAP32[$prop >> 2];
    if (($20 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = HEAP32[$obj2 >> 2];
    var $_idx_val = HEAP32[$23 >> 2];
    var $24 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = $obj;
    var $27 = $23;
    var $28 = $20;
    var $29 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($14, $26, $27, $28, 0, $vp);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIhE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN18TypedArrayTemplateIhE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    __label__ = 6;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($1, $id, $index);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 6;
    break;
   case 5:
    var $16 = HEAP32[$index >> 2];
    __ZN18TypedArrayTemplateIhE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $16, $vp);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 4;
    break;
   case 3:
    __ZN18TypedArrayTemplateIhE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $index, $vp);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIhE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, $strict);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIhE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 3:
    var $10 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $11 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($10, $id, 0);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 5:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 6;
    break;
   case 6:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIhE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIhE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    if (($enum_op | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($enum_op | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($enum_op | 0) == 2) {
      __label__ = 6;
      break;
    } else if (($enum_op | 0) == 3) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($statep, 1);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $6 = $5 + 1 | 0;
    var $7 = _INT_TO_JSID4006($6);
    HEAP32[$idp >> 2] = $7;
    __label__ = 12;
    break;
   case 4:
    __ZN2JS5Value8setInt32Ei($statep, 0);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $12 = _INT_TO_JSID4006($11);
    HEAP32[$idp >> 2] = $12;
    __label__ = 12;
    break;
   case 6:
    var $statep_idx1 = $statep | 0;
    var $statep_idx1_val$0 = HEAP32[$statep_idx1 >> 2];
    var $statep_idx1_val$1 = HEAP32[$statep_idx1 + 4 >> 2];
    var $14 = __ZNK2JS5Value6isTrueEv($statep_idx1_val$0, $statep_idx1_val$1);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom3984($20);
    HEAP32[$idp >> 2] = $21;
    __ZN2JS5Value8setInt32Ei($statep, 0);
    __label__ = 12;
    break;
   case 8:
    var $23 = __ZNK2JS5Value7toInt32Ev($statep_idx1_val$0, $statep_idx1_val$1);
    var $24 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($23 >>> 0 < $24 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = _INT_TO_JSID4006($23);
    HEAP32[$idp >> 2] = $27;
    var $28 = $23 + 1 | 0;
    __ZN2JS5Value8setInt32Ei($statep, $28);
    __label__ = 12;
    break;
   case 10:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 11:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 12:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE9obj_traceEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $id, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $v | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $tmp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZN18TypedArrayTemplateIsE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $tmp, 0);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $index, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $tmp = __stackBase__;
  var $1 = $v | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $tmp | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  var $4 = __ZN18TypedArrayTemplateIsE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $tmp, 0);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIsE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej($cx, $obj, $sid, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIsE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $1, $v, undef, undef, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIsE10obj_typeOfEP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZN18TypedArrayTemplateItE10obj_typeOfEP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZN18TypedArrayTemplateIsE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($1, $id, $index);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = HEAP32[$index >> 2];
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    __ZN18TypedArrayTemplateIsE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($_idx1_val, $15, $vp);
    __label__ = 10;
    break;
   case 5:
    var $obj_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $17 = __ZNK8JSObject8getProtoEv($obj_idx_val_idx_val);
    var $18 = ($17 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($18) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = HEAP32[$cx + 208 >> 2];
    var $22 = $cx;
    var $23 = $17;
    var $24 = $obj2;
    var $25 = $prop;
    var $26 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($22, $23, $id, $21, $24, $25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $28 = HEAP32[$prop >> 2];
    if (($28 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAP32[$obj2 >> 2];
    var $_idx_val = HEAP32[$31 >> 2];
    var $32 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = $obj;
    var $35 = $31;
    var $36 = $28;
    var $37 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($22, $34, $35, $36, 0, $vp);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIsE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIsE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom3984($1);
  var $3 = __ZN18TypedArrayTemplateIsE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $2, $vp);
  return $3;
}

function __ZN18TypedArrayTemplateIsE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    __ZN18TypedArrayTemplateIsE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($_idx1_val, $index, $vp);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    var $obj_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $6 = __ZNK8JSObject8getProtoEv($obj_idx_val_idx_val);
    var $7 = ($6 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($7) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = HEAP32[$id >> 2];
    var $13 = HEAP32[$cx + 208 >> 2];
    var $14 = $cx;
    var $15 = $6;
    var $16 = $obj2;
    var $17 = $prop;
    var $18 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($14, $15, $11, $13, $16, $17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $20 = HEAP32[$prop >> 2];
    if (($20 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = HEAP32[$obj2 >> 2];
    var $_idx_val = HEAP32[$23 >> 2];
    var $24 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = $obj;
    var $27 = $23;
    var $28 = $20;
    var $29 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($14, $26, $27, $28, 0, $vp);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIsE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN18TypedArrayTemplateIsE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    __label__ = 6;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($1, $id, $index);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 6;
    break;
   case 5:
    var $16 = HEAP32[$index >> 2];
    __ZN18TypedArrayTemplateIsE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $16, $vp);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 4;
    break;
   case 3:
    __ZN18TypedArrayTemplateIsE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $index, $vp);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIsE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, $strict);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIsE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 3:
    var $10 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $11 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($10, $id, 0);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 5:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 6;
    break;
   case 6:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIsE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIsE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    if (($enum_op | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($enum_op | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($enum_op | 0) == 2) {
      __label__ = 6;
      break;
    } else if (($enum_op | 0) == 3) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($statep, 1);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $6 = $5 + 1 | 0;
    var $7 = _INT_TO_JSID4006($6);
    HEAP32[$idp >> 2] = $7;
    __label__ = 12;
    break;
   case 4:
    __ZN2JS5Value8setInt32Ei($statep, 0);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $12 = _INT_TO_JSID4006($11);
    HEAP32[$idp >> 2] = $12;
    __label__ = 12;
    break;
   case 6:
    var $statep_idx1 = $statep | 0;
    var $statep_idx1_val$0 = HEAP32[$statep_idx1 >> 2];
    var $statep_idx1_val$1 = HEAP32[$statep_idx1 + 4 >> 2];
    var $14 = __ZNK2JS5Value6isTrueEv($statep_idx1_val$0, $statep_idx1_val$1);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom3984($20);
    HEAP32[$idp >> 2] = $21;
    __ZN2JS5Value8setInt32Ei($statep, 0);
    __label__ = 12;
    break;
   case 8:
    var $23 = __ZNK2JS5Value7toInt32Ev($statep_idx1_val$0, $statep_idx1_val$1);
    var $24 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($23 >>> 0 < $24 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = _INT_TO_JSID4006($23);
    HEAP32[$idp >> 2] = $27;
    var $28 = $23 + 1 | 0;
    __ZN2JS5Value8setInt32Ei($statep, $28);
    __label__ = 12;
    break;
   case 10:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 11:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 12:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE9obj_traceEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $id, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $v | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $tmp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZN18TypedArrayTemplateItE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $tmp, 0);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $index, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $tmp = __stackBase__;
  var $1 = $v | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $tmp | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  var $4 = __ZN18TypedArrayTemplateItE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $tmp, 0);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateItE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej($cx, $obj, $sid, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateItE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $1, $v, undef, undef, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateItE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($1, $id, $index);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = HEAP32[$index >> 2];
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    __ZN18TypedArrayTemplateItE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($_idx1_val, $15, $vp);
    __label__ = 10;
    break;
   case 5:
    var $obj_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $17 = __ZNK8JSObject8getProtoEv($obj_idx_val_idx_val);
    var $18 = ($17 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($18) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = HEAP32[$cx + 208 >> 2];
    var $22 = $cx;
    var $23 = $17;
    var $24 = $obj2;
    var $25 = $prop;
    var $26 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($22, $23, $id, $21, $24, $25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $28 = HEAP32[$prop >> 2];
    if (($28 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAP32[$obj2 >> 2];
    var $_idx_val = HEAP32[$31 >> 2];
    var $32 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = $obj;
    var $35 = $31;
    var $36 = $28;
    var $37 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($22, $34, $35, $36, 0, $vp);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateItE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateItE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom3984($1);
  var $3 = __ZN18TypedArrayTemplateItE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $2, $vp);
  return $3;
}

function __ZN18TypedArrayTemplateItE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    __ZN18TypedArrayTemplateItE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($_idx1_val, $index, $vp);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    var $obj_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $6 = __ZNK8JSObject8getProtoEv($obj_idx_val_idx_val);
    var $7 = ($6 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($7) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = HEAP32[$id >> 2];
    var $13 = HEAP32[$cx + 208 >> 2];
    var $14 = $cx;
    var $15 = $6;
    var $16 = $obj2;
    var $17 = $prop;
    var $18 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($14, $15, $11, $13, $16, $17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $20 = HEAP32[$prop >> 2];
    if (($20 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = HEAP32[$obj2 >> 2];
    var $_idx_val = HEAP32[$23 >> 2];
    var $24 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = $obj;
    var $27 = $23;
    var $28 = $20;
    var $29 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($14, $26, $27, $28, 0, $vp);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateItE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN18TypedArrayTemplateItE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    __label__ = 6;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($1, $id, $index);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 6;
    break;
   case 5:
    var $16 = HEAP32[$index >> 2];
    __ZN18TypedArrayTemplateItE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $16, $vp);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 4;
    break;
   case 3:
    __ZN18TypedArrayTemplateItE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $index, $vp);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateItE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, $strict);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateItE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 3:
    var $10 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $11 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($10, $id, 0);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 5:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 6;
    break;
   case 6:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateItE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateItE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    if (($enum_op | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($enum_op | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($enum_op | 0) == 2) {
      __label__ = 6;
      break;
    } else if (($enum_op | 0) == 3) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($statep, 1);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $6 = $5 + 1 | 0;
    var $7 = _INT_TO_JSID4006($6);
    HEAP32[$idp >> 2] = $7;
    __label__ = 12;
    break;
   case 4:
    __ZN2JS5Value8setInt32Ei($statep, 0);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $12 = _INT_TO_JSID4006($11);
    HEAP32[$idp >> 2] = $12;
    __label__ = 12;
    break;
   case 6:
    var $statep_idx1 = $statep | 0;
    var $statep_idx1_val$0 = HEAP32[$statep_idx1 >> 2];
    var $statep_idx1_val$1 = HEAP32[$statep_idx1 + 4 >> 2];
    var $14 = __ZNK2JS5Value6isTrueEv($statep_idx1_val$0, $statep_idx1_val$1);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom3984($20);
    HEAP32[$idp >> 2] = $21;
    __ZN2JS5Value8setInt32Ei($statep, 0);
    __label__ = 12;
    break;
   case 8:
    var $23 = __ZNK2JS5Value7toInt32Ev($statep_idx1_val$0, $statep_idx1_val$1);
    var $24 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($23 >>> 0 < $24 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = _INT_TO_JSID4006($23);
    HEAP32[$idp >> 2] = $27;
    var $28 = $23 + 1 | 0;
    __ZN2JS5Value8setInt32Ei($statep, $28);
    __label__ = 12;
    break;
   case 10:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 11:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 12:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE9obj_traceEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $id, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $v | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $tmp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZN18TypedArrayTemplateIiE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $tmp, 0);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $index, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $tmp = __stackBase__;
  var $1 = $v | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $tmp | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  var $4 = __ZN18TypedArrayTemplateIiE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $tmp, 0);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIiE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej($cx, $obj, $sid, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIiE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $1, $v, undef, undef, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIiE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($1, $id, $index);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = HEAP32[$index >> 2];
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    __ZN18TypedArrayTemplateIiE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($_idx1_val, $15, $vp);
    __label__ = 10;
    break;
   case 5:
    var $obj_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $17 = __ZNK8JSObject8getProtoEv($obj_idx_val_idx_val);
    var $18 = ($17 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($18) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = HEAP32[$cx + 208 >> 2];
    var $22 = $cx;
    var $23 = $17;
    var $24 = $obj2;
    var $25 = $prop;
    var $26 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($22, $23, $id, $21, $24, $25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $28 = HEAP32[$prop >> 2];
    if (($28 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAP32[$obj2 >> 2];
    var $_idx_val = HEAP32[$31 >> 2];
    var $32 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = $obj;
    var $35 = $31;
    var $36 = $28;
    var $37 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($22, $34, $35, $36, 0, $vp);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIiE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIiE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom3984($1);
  var $3 = __ZN18TypedArrayTemplateIiE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $2, $vp);
  return $3;
}

function __ZN18TypedArrayTemplateIiE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    __ZN18TypedArrayTemplateIiE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($_idx1_val, $index, $vp);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    var $obj_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $6 = __ZNK8JSObject8getProtoEv($obj_idx_val_idx_val);
    var $7 = ($6 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($7) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = HEAP32[$id >> 2];
    var $13 = HEAP32[$cx + 208 >> 2];
    var $14 = $cx;
    var $15 = $6;
    var $16 = $obj2;
    var $17 = $prop;
    var $18 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($14, $15, $11, $13, $16, $17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $20 = HEAP32[$prop >> 2];
    if (($20 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = HEAP32[$obj2 >> 2];
    var $_idx_val = HEAP32[$23 >> 2];
    var $24 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = $obj;
    var $27 = $23;
    var $28 = $20;
    var $29 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($14, $26, $27, $28, 0, $vp);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIiE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN18TypedArrayTemplateIiE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    __label__ = 6;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($1, $id, $index);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 6;
    break;
   case 5:
    var $16 = HEAP32[$index >> 2];
    __ZN18TypedArrayTemplateIiE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $16, $vp);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 4;
    break;
   case 3:
    __ZN18TypedArrayTemplateIiE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $index, $vp);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIiE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, $strict);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIiE10obj_typeOfEP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZN18TypedArrayTemplateIjE10obj_typeOfEP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZN18TypedArrayTemplateIfE10obj_typeOfEP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZN18TypedArrayTemplateIiE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 3:
    var $10 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $11 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($10, $id, 0);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 5:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 6;
    break;
   case 6:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIiE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIiE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    if (($enum_op | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($enum_op | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($enum_op | 0) == 2) {
      __label__ = 6;
      break;
    } else if (($enum_op | 0) == 3) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($statep, 1);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $6 = $5 + 1 | 0;
    var $7 = _INT_TO_JSID4006($6);
    HEAP32[$idp >> 2] = $7;
    __label__ = 12;
    break;
   case 4:
    __ZN2JS5Value8setInt32Ei($statep, 0);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $12 = _INT_TO_JSID4006($11);
    HEAP32[$idp >> 2] = $12;
    __label__ = 12;
    break;
   case 6:
    var $statep_idx1 = $statep | 0;
    var $statep_idx1_val$0 = HEAP32[$statep_idx1 >> 2];
    var $statep_idx1_val$1 = HEAP32[$statep_idx1 + 4 >> 2];
    var $14 = __ZNK2JS5Value6isTrueEv($statep_idx1_val$0, $statep_idx1_val$1);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom3984($20);
    HEAP32[$idp >> 2] = $21;
    __ZN2JS5Value8setInt32Ei($statep, 0);
    __label__ = 12;
    break;
   case 8:
    var $23 = __ZNK2JS5Value7toInt32Ev($statep_idx1_val$0, $statep_idx1_val$1);
    var $24 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($23 >>> 0 < $24 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = _INT_TO_JSID4006($23);
    HEAP32[$idp >> 2] = $27;
    var $28 = $23 + 1 | 0;
    __ZN2JS5Value8setInt32Ei($statep, $28);
    __label__ = 12;
    break;
   case 10:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 11:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 12:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE9obj_traceEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $id, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $v | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $tmp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZN18TypedArrayTemplateIjE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $tmp, 0);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $index, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $tmp = __stackBase__;
  var $1 = $v | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $tmp | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  var $4 = __ZN18TypedArrayTemplateIjE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $tmp, 0);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIjE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej($cx, $obj, $sid, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIjE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $1, $v, undef, undef, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIjE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($1, $id, $index);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = HEAP32[$index >> 2];
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    __ZN18TypedArrayTemplateIjE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($_idx1_val, $15, $vp);
    __label__ = 10;
    break;
   case 5:
    var $obj_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $17 = __ZNK8JSObject8getProtoEv($obj_idx_val_idx_val);
    var $18 = ($17 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($18) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = HEAP32[$cx + 208 >> 2];
    var $22 = $cx;
    var $23 = $17;
    var $24 = $obj2;
    var $25 = $prop;
    var $26 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($22, $23, $id, $21, $24, $25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $28 = HEAP32[$prop >> 2];
    if (($28 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAP32[$obj2 >> 2];
    var $_idx_val = HEAP32[$31 >> 2];
    var $32 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = $obj;
    var $35 = $31;
    var $36 = $28;
    var $37 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($22, $34, $35, $36, 0, $vp);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIjE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIjE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom3984($1);
  var $3 = __ZN18TypedArrayTemplateIjE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $2, $vp);
  return $3;
}

function __ZN18TypedArrayTemplateIjE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    __ZN18TypedArrayTemplateIjE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($_idx1_val, $index, $vp);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    var $obj_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $6 = __ZNK8JSObject8getProtoEv($obj_idx_val_idx_val);
    var $7 = ($6 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($7) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = HEAP32[$id >> 2];
    var $13 = HEAP32[$cx + 208 >> 2];
    var $14 = $cx;
    var $15 = $6;
    var $16 = $obj2;
    var $17 = $prop;
    var $18 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($14, $15, $11, $13, $16, $17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $20 = HEAP32[$prop >> 2];
    if (($20 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = HEAP32[$obj2 >> 2];
    var $_idx_val = HEAP32[$23 >> 2];
    var $24 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = $obj;
    var $27 = $23;
    var $28 = $20;
    var $29 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($14, $26, $27, $28, 0, $vp);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIjE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN18TypedArrayTemplateIjE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    __label__ = 6;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($1, $id, $index);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 6;
    break;
   case 5:
    var $16 = HEAP32[$index >> 2];
    __ZN18TypedArrayTemplateIjE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $16, $vp);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 4;
    break;
   case 3:
    __ZN18TypedArrayTemplateIjE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $index, $vp);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIjE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, $strict);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIjE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 3:
    var $10 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $11 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($10, $id, 0);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 5:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 6;
    break;
   case 6:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIjE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIjE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    if (($enum_op | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($enum_op | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($enum_op | 0) == 2) {
      __label__ = 6;
      break;
    } else if (($enum_op | 0) == 3) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($statep, 1);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $6 = $5 + 1 | 0;
    var $7 = _INT_TO_JSID4006($6);
    HEAP32[$idp >> 2] = $7;
    __label__ = 12;
    break;
   case 4:
    __ZN2JS5Value8setInt32Ei($statep, 0);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $12 = _INT_TO_JSID4006($11);
    HEAP32[$idp >> 2] = $12;
    __label__ = 12;
    break;
   case 6:
    var $statep_idx1 = $statep | 0;
    var $statep_idx1_val$0 = HEAP32[$statep_idx1 >> 2];
    var $statep_idx1_val$1 = HEAP32[$statep_idx1 + 4 >> 2];
    var $14 = __ZNK2JS5Value6isTrueEv($statep_idx1_val$0, $statep_idx1_val$1);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom3984($20);
    HEAP32[$idp >> 2] = $21;
    __ZN2JS5Value8setInt32Ei($statep, 0);
    __label__ = 12;
    break;
   case 8:
    var $23 = __ZNK2JS5Value7toInt32Ev($statep_idx1_val$0, $statep_idx1_val$1);
    var $24 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($23 >>> 0 < $24 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = _INT_TO_JSID4006($23);
    HEAP32[$idp >> 2] = $27;
    var $28 = $23 + 1 | 0;
    __ZN2JS5Value8setInt32Ei($statep, $28);
    __label__ = 12;
    break;
   case 10:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 11:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 12:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE9obj_traceEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $id, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $v | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $tmp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZN18TypedArrayTemplateIfE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $tmp, 0);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $index, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $tmp = __stackBase__;
  var $1 = $v | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $tmp | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  var $4 = __ZN18TypedArrayTemplateIfE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $tmp, 0);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIfE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej($cx, $obj, $sid, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIfE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $1, $v, undef, undef, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIfE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($1, $id, $index);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = HEAP32[$index >> 2];
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    __ZN18TypedArrayTemplateIfE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($_idx1_val, $15, $vp);
    __label__ = 10;
    break;
   case 5:
    var $obj_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $17 = __ZNK8JSObject8getProtoEv($obj_idx_val_idx_val);
    var $18 = ($17 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($18) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = HEAP32[$cx + 208 >> 2];
    var $22 = $cx;
    var $23 = $17;
    var $24 = $obj2;
    var $25 = $prop;
    var $26 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($22, $23, $id, $21, $24, $25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $28 = HEAP32[$prop >> 2];
    if (($28 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAP32[$obj2 >> 2];
    var $_idx_val = HEAP32[$31 >> 2];
    var $32 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = $obj;
    var $35 = $31;
    var $36 = $28;
    var $37 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($22, $34, $35, $36, 0, $vp);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIfE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIfE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom3984($1);
  var $3 = __ZN18TypedArrayTemplateIfE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $2, $vp);
  return $3;
}

function __ZN18TypedArrayTemplateIfE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    __ZN18TypedArrayTemplateIfE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($_idx1_val, $index, $vp);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    var $obj_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $6 = __ZNK8JSObject8getProtoEv($obj_idx_val_idx_val);
    var $7 = ($6 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($7) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = HEAP32[$id >> 2];
    var $13 = HEAP32[$cx + 208 >> 2];
    var $14 = $cx;
    var $15 = $6;
    var $16 = $obj2;
    var $17 = $prop;
    var $18 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($14, $15, $11, $13, $16, $17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $20 = HEAP32[$prop >> 2];
    if (($20 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = HEAP32[$obj2 >> 2];
    var $_idx_val = HEAP32[$23 >> 2];
    var $24 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = $obj;
    var $27 = $23;
    var $28 = $20;
    var $29 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($14, $26, $27, $28, 0, $vp);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIfE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN18TypedArrayTemplateIfE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    __label__ = 6;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($1, $id, $index);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 6;
    break;
   case 5:
    var $16 = HEAP32[$index >> 2];
    __ZN18TypedArrayTemplateIfE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $16, $vp);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 4;
    break;
   case 3:
    __ZN18TypedArrayTemplateIfE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $index, $vp);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIfE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, $strict);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIfE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 3:
    var $10 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $11 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($10, $id, 0);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 5:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 6;
    break;
   case 6:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIfE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIfE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    if (($enum_op | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($enum_op | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($enum_op | 0) == 2) {
      __label__ = 6;
      break;
    } else if (($enum_op | 0) == 3) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($statep, 1);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $6 = $5 + 1 | 0;
    var $7 = _INT_TO_JSID4006($6);
    HEAP32[$idp >> 2] = $7;
    __label__ = 12;
    break;
   case 4:
    __ZN2JS5Value8setInt32Ei($statep, 0);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $12 = _INT_TO_JSID4006($11);
    HEAP32[$idp >> 2] = $12;
    __label__ = 12;
    break;
   case 6:
    var $statep_idx1 = $statep | 0;
    var $statep_idx1_val$0 = HEAP32[$statep_idx1 >> 2];
    var $statep_idx1_val$1 = HEAP32[$statep_idx1 + 4 >> 2];
    var $14 = __ZNK2JS5Value6isTrueEv($statep_idx1_val$0, $statep_idx1_val$1);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom3984($20);
    HEAP32[$idp >> 2] = $21;
    __ZN2JS5Value8setInt32Ei($statep, 0);
    __label__ = 12;
    break;
   case 8:
    var $23 = __ZNK2JS5Value7toInt32Ev($statep_idx1_val$0, $statep_idx1_val$1);
    var $24 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($23 >>> 0 < $24 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = _INT_TO_JSID4006($23);
    HEAP32[$idp >> 2] = $27;
    var $28 = $23 + 1 | 0;
    __ZN2JS5Value8setInt32Ei($statep, $28);
    __label__ = 12;
    break;
   case 10:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 11:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 12:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE9obj_traceEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $id, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $v | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $tmp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZN18TypedArrayTemplateIdE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $tmp, 0);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $index, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $tmp = __stackBase__;
  var $1 = $v | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $tmp | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  var $4 = __ZN18TypedArrayTemplateIdE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $tmp, 0);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIdE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej($cx, $obj, $sid, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIdE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $1, $v, undef, undef, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIdE10obj_typeOfEP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE10obj_typeOfEP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZN18TypedArrayTemplateIdE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($1, $id, $index);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = HEAP32[$index >> 2];
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    __ZN18TypedArrayTemplateIdE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($_idx1_val, $15, $vp);
    __label__ = 10;
    break;
   case 5:
    var $obj_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $17 = __ZNK8JSObject8getProtoEv($obj_idx_val_idx_val);
    var $18 = ($17 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($18) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = HEAP32[$cx + 208 >> 2];
    var $22 = $cx;
    var $23 = $17;
    var $24 = $obj2;
    var $25 = $prop;
    var $26 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($22, $23, $id, $21, $24, $25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $28 = HEAP32[$prop >> 2];
    if (($28 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAP32[$obj2 >> 2];
    var $_idx_val = HEAP32[$31 >> 2];
    var $32 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = $obj;
    var $35 = $31;
    var $36 = $28;
    var $37 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($22, $34, $35, $36, 0, $vp);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIdE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIdE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom3984($1);
  var $3 = __ZN18TypedArrayTemplateIdE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $2, $vp);
  return $3;
}

function __ZN18TypedArrayTemplateIdE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    __ZN18TypedArrayTemplateIdE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($_idx1_val, $index, $vp);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    var $obj_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $6 = __ZNK8JSObject8getProtoEv($obj_idx_val_idx_val);
    var $7 = ($6 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($7) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = HEAP32[$id >> 2];
    var $13 = HEAP32[$cx + 208 >> 2];
    var $14 = $cx;
    var $15 = $6;
    var $16 = $obj2;
    var $17 = $prop;
    var $18 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($14, $15, $11, $13, $16, $17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $20 = HEAP32[$prop >> 2];
    if (($20 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = HEAP32[$obj2 >> 2];
    var $_idx_val = HEAP32[$23 >> 2];
    var $24 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = $obj;
    var $27 = $23;
    var $28 = $20;
    var $29 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($14, $26, $27, $28, 0, $vp);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIdE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN18TypedArrayTemplateIdE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    __label__ = 6;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($1, $id, $index);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 6;
    break;
   case 5:
    var $16 = HEAP32[$index >> 2];
    __ZN18TypedArrayTemplateIdE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $16, $vp);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 4;
    break;
   case 3:
    __ZN18TypedArrayTemplateIdE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $index, $vp);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIdE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, $strict);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIdE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 3:
    var $10 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $11 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($10, $id, 0);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 5:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 6;
    break;
   case 6:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIdE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIdE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    if (($enum_op | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($enum_op | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($enum_op | 0) == 2) {
      __label__ = 6;
      break;
    } else if (($enum_op | 0) == 3) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($statep, 1);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $6 = $5 + 1 | 0;
    var $7 = _INT_TO_JSID4006($6);
    HEAP32[$idp >> 2] = $7;
    __label__ = 12;
    break;
   case 4:
    __ZN2JS5Value8setInt32Ei($statep, 0);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $12 = _INT_TO_JSID4006($11);
    HEAP32[$idp >> 2] = $12;
    __label__ = 12;
    break;
   case 6:
    var $statep_idx1 = $statep | 0;
    var $statep_idx1_val$0 = HEAP32[$statep_idx1 >> 2];
    var $statep_idx1_val$1 = HEAP32[$statep_idx1 + 4 >> 2];
    var $14 = __ZNK2JS5Value6isTrueEv($statep_idx1_val$0, $statep_idx1_val$1);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom3984($20);
    HEAP32[$idp >> 2] = $21;
    __ZN2JS5Value8setInt32Ei($statep, 0);
    __label__ = 12;
    break;
   case 8:
    var $23 = __ZNK2JS5Value7toInt32Ev($statep_idx1_val$0, $statep_idx1_val$1);
    var $24 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($23 >>> 0 < $24 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = _INT_TO_JSID4006($23);
    HEAP32[$idp >> 2] = $27;
    var $28 = $23 + 1 | 0;
    __ZN2JS5Value8setInt32Ei($statep, $28);
    __label__ = 12;
    break;
   case 10:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 11:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 12:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE9obj_traceEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS3_S5_iPS7_EPFiS3_S5_iiSA_Ej($cx, $obj, $id, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $v | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $tmp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZN18TypedArrayTemplateI13uint8_clampedE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $tmp, 0);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS3_S5_iPS7_EPFiS3_S5_iiSA_Ej($cx, $obj, $index, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $tmp = __stackBase__;
  var $1 = $v | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $tmp | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  var $4 = __ZN18TypedArrayTemplateI13uint8_clampedE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $tmp, 0);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS3_S5_iPS9_EPFiS3_S5_iiSC_Ej($cx, $obj, $sid, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateI13uint8_clampedE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS3_S5_iPS7_EPFiS3_S5_iiSA_Ej($cx, $obj, $1, $v, undef, undef, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE14obj_getGenericEP9JSContextP8JSObjectS5_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($1, $id, $index);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = HEAP32[$index >> 2];
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    __ZN18TypedArrayTemplateI13uint8_clampedE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($_idx1_val, $15, $vp);
    __label__ = 10;
    break;
   case 5:
    var $obj_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $17 = __ZNK8JSObject8getProtoEv($obj_idx_val_idx_val);
    var $18 = ($17 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($18) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = HEAP32[$cx + 208 >> 2];
    var $22 = $cx;
    var $23 = $17;
    var $24 = $obj2;
    var $25 = $prop;
    var $26 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($22, $23, $id, $21, $24, $25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $28 = HEAP32[$prop >> 2];
    if (($28 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAP32[$obj2 >> 2];
    var $_idx_val = HEAP32[$31 >> 2];
    var $32 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = $obj;
    var $35 = $31;
    var $36 = $28;
    var $37 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($22, $34, $35, $36, 0, $vp);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateI13uint8_clampedE14obj_getGenericEP9JSContextP8JSObjectS5_iPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateI13uint8_clampedE15obj_getPropertyEP9JSContextP8JSObjectS5_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom3984($1);
  var $3 = __ZN18TypedArrayTemplateI13uint8_clampedE14obj_getGenericEP9JSContextP8JSObjectS5_iPN2JS5ValueE($cx, $obj, undef, $2, $vp);
  return $3;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE14obj_getElementEP9JSContextP8JSObjectS5_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$1 + 24 >> 2];
    __ZN18TypedArrayTemplateI13uint8_clampedE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($_idx1_val, $index, $vp);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    var $obj_idx_val_idx_val = HEAP32[HEAP32[$obj + 36 >> 2] >> 2];
    var $6 = __ZNK8JSObject8getProtoEv($obj_idx_val_idx_val);
    var $7 = ($6 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($7) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = HEAP32[$id >> 2];
    var $13 = HEAP32[$cx + 208 >> 2];
    var $14 = $cx;
    var $15 = $6;
    var $16 = $obj2;
    var $17 = $prop;
    var $18 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($14, $15, $11, $13, $16, $17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $20 = HEAP32[$prop >> 2];
    if (($20 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = HEAP32[$obj2 >> 2];
    var $_idx_val = HEAP32[$23 >> 2];
    var $24 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = $obj;
    var $27 = $23;
    var $28 = $20;
    var $29 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($14, $26, $27, $28, 0, $vp);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE14obj_getSpecialEP9JSContextP8JSObjectS5_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateI13uint8_clampedE14obj_getGenericEP9JSContextP8JSObjectS5_iPN2JS5ValueE($cx, $obj, undef, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    __label__ = 6;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($1, $id, $index);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 6;
    break;
   case 5:
    var $16 = HEAP32[$index >> 2];
    __ZN18TypedArrayTemplateI13uint8_clampedE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $16, $vp);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 4;
    break;
   case 3:
    __ZN18TypedArrayTemplateI13uint8_clampedE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $index, $vp);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateI13uint8_clampedE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, $strict);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 3:
    var $10 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $11 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($10, $id, 0);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 5:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 6;
    break;
   case 6:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateI13uint8_clampedE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    if (($enum_op | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($enum_op | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($enum_op | 0) == 2) {
      __label__ = 6;
      break;
    } else if (($enum_op | 0) == 3) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($statep, 1);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $6 = $5 + 1 | 0;
    var $7 = _INT_TO_JSID4006($6);
    HEAP32[$idp >> 2] = $7;
    __label__ = 12;
    break;
   case 4:
    __ZN2JS5Value8setInt32Ei($statep, 0);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $12 = _INT_TO_JSID4006($11);
    HEAP32[$idp >> 2] = $12;
    __label__ = 12;
    break;
   case 6:
    var $statep_idx1 = $statep | 0;
    var $statep_idx1_val$0 = HEAP32[$statep_idx1 >> 2];
    var $statep_idx1_val$1 = HEAP32[$statep_idx1 + 4 >> 2];
    var $14 = __ZNK2JS5Value6isTrueEv($statep_idx1_val$0, $statep_idx1_val$1);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom3984($20);
    HEAP32[$idp >> 2] = $21;
    __ZN2JS5Value8setInt32Ei($statep, 0);
    __label__ = 12;
    break;
   case 8:
    var $23 = __ZNK2JS5Value7toInt32Ev($statep_idx1_val$0, $statep_idx1_val$1);
    var $24 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($23 >>> 0 < $24 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = _INT_TO_JSID4006($23);
    HEAP32[$idp >> 2] = $27;
    var $28 = $23 + 1 | 0;
    __ZN2JS5Value8setInt32Ei($statep, $28);
    __label__ = 12;
    break;
   case 10:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 11:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 12:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z24js_InitTypedArrayClassesP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stop = __stackBase__;
    var $1 = $obj;
    var $2 = __ZN8JSObject8asGlobalEv($1);
    var $3 = $2;
    var $4 = $cx;
    var $5 = $2;
    var $6 = $stop;
    var $7 = __Z17js_GetClassObjectP9JSContextP8JSObject10JSProtoKeyPS2_($4, $5, 24, $6);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAP32[$stop >> 2];
    if (($10 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $10;
      __label__ = 13;
      break;
    }
   case 3:
    var $13 = __ZL19InitTypedArrayClassI9Int8ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $3);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = __ZL19InitTypedArrayClassI10Uint8ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $3);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = __ZL19InitTypedArrayClassI10Int16ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $3);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = __ZL19InitTypedArrayClassI11Uint16ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $3);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = __ZL19InitTypedArrayClassI10Int32ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $3);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $28 = __ZL19InitTypedArrayClassI11Uint32ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $3);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $31 = __ZL19InitTypedArrayClassI12Float32ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $3);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $34 = __ZL19InitTypedArrayClassI12Float64ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $3);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $37 = __ZL19InitTypedArrayClassI17Uint8ClampedArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $3);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $40 = __ZL20InitArrayBufferClassP9JSContextPN2js12GlobalObjectE($cx, $3);
    var $_0 = $40;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19InitTypedArrayClassI9Int8ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $global;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js10TypedArray11slowClassesE);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $cx + 52 | 0;
    var $13 = HEAP32[HEAP32[$9 >> 2] + 210120 >> 2];
    var $14 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 236, __ZN2js10TypedArray11fastClassesE, $13, 3);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $14;
    var $18 = $14 | 0;
    var $19 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $18, $5);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $24 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $25 = __ZL12ATOM_TO_JSIDP6JSAtom3984($24);
    __ZN2JSL10Int32ValueEi3996($1, 1);
    var $26 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($17, $cx, $25, $1, 10, 12, 6);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $32 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom3984($32);
    __ZN2JSL10Int32ValueEi3996($2, 1);
    var $34 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($6, $cx, $33, $2, 10, 12, 6);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $37 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, __ZN2js10TypedArray7jspropsE, __ZN9Int8Array7jsfuncsE);
    if ($37) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $global, 25, $17, $6);
    var $_ = $39 ? $6 : 0;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19InitTypedArrayClassI10Uint8ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $global;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js10TypedArray11slowClassesE + 232 | 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $cx + 52 | 0;
    var $13 = HEAP32[HEAP32[$9 >> 2] + 210124 >> 2];
    var $14 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 238, __ZN2js10TypedArray11fastClassesE + 232 | 0, $13, 3);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $14;
    var $18 = $14 | 0;
    var $19 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $18, $5);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $24 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $25 = __ZL12ATOM_TO_JSIDP6JSAtom3984($24);
    __ZN2JSL10Int32ValueEi3996($1, 1);
    var $26 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($17, $cx, $25, $1, 10, 12, 6);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $32 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom3984($32);
    __ZN2JSL10Int32ValueEi3996($2, 1);
    var $34 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($6, $cx, $33, $2, 10, 12, 6);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $37 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, __ZN2js10TypedArray7jspropsE, __ZN10Uint8Array7jsfuncsE);
    if ($37) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $global, 26, $17, $6);
    var $_ = $39 ? $6 : 0;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19InitTypedArrayClassI10Int16ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $global;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js10TypedArray11slowClassesE + 464 | 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $cx + 52 | 0;
    var $13 = HEAP32[HEAP32[$9 >> 2] + 210128 >> 2];
    var $14 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 240, __ZN2js10TypedArray11fastClassesE + 464 | 0, $13, 3);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $14;
    var $18 = $14 | 0;
    var $19 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $18, $5);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $24 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $25 = __ZL12ATOM_TO_JSIDP6JSAtom3984($24);
    __ZN2JSL10Int32ValueEi3996($1, 2);
    var $26 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($17, $cx, $25, $1, 10, 12, 6);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $32 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom3984($32);
    __ZN2JSL10Int32ValueEi3996($2, 2);
    var $34 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($6, $cx, $33, $2, 10, 12, 6);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $37 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, __ZN2js10TypedArray7jspropsE, __ZN10Int16Array7jsfuncsE);
    if ($37) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $global, 27, $17, $6);
    var $_ = $39 ? $6 : 0;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject13isArrayBufferEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js16ArrayBufferClassE | 0);
}

function __ZN2js21IsFastTypedArrayClassEPKNS_5ClassE($clasp) {
  return $clasp >>> 0 < (__ZN2js10TypedArray11fastClassesE + 2088 | 0) >>> 0 & $clasp >>> 0 >= __ZN2js10TypedArray11fastClassesE >>> 0;
}

function __ZL19InitTypedArrayClassI11Uint16ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $global;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js10TypedArray11slowClassesE + 696 | 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $cx + 52 | 0;
    var $13 = HEAP32[HEAP32[$9 >> 2] + 210132 >> 2];
    var $14 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 242, __ZN2js10TypedArray11fastClassesE + 696 | 0, $13, 3);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $14;
    var $18 = $14 | 0;
    var $19 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $18, $5);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $24 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $25 = __ZL12ATOM_TO_JSIDP6JSAtom3984($24);
    __ZN2JSL10Int32ValueEi3996($1, 2);
    var $26 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($17, $cx, $25, $1, 10, 12, 6);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $32 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom3984($32);
    __ZN2JSL10Int32ValueEi3996($2, 2);
    var $34 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($6, $cx, $33, $2, 10, 12, 6);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $37 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, __ZN2js10TypedArray7jspropsE, __ZN11Uint16Array7jsfuncsE);
    if ($37) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $global, 28, $17, $6);
    var $_ = $39 ? $6 : 0;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19InitTypedArrayClassI10Int32ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $global;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js10TypedArray11slowClassesE + 928 | 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $cx + 52 | 0;
    var $13 = HEAP32[HEAP32[$9 >> 2] + 210136 >> 2];
    var $14 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 244, __ZN2js10TypedArray11fastClassesE + 928 | 0, $13, 3);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $14;
    var $18 = $14 | 0;
    var $19 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $18, $5);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $24 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $25 = __ZL12ATOM_TO_JSIDP6JSAtom3984($24);
    __ZN2JSL10Int32ValueEi3996($1, 4);
    var $26 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($17, $cx, $25, $1, 10, 12, 6);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $32 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom3984($32);
    __ZN2JSL10Int32ValueEi3996($2, 4);
    var $34 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($6, $cx, $33, $2, 10, 12, 6);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $37 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, __ZN2js10TypedArray7jspropsE, __ZN10Int32Array7jsfuncsE);
    if ($37) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $global, 29, $17, $6);
    var $_ = $39 ? $6 : 0;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19InitTypedArrayClassI11Uint32ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $global;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js10TypedArray11slowClassesE + 1160 | 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $cx + 52 | 0;
    var $13 = HEAP32[HEAP32[$9 >> 2] + 210140 >> 2];
    var $14 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 246, __ZN2js10TypedArray11fastClassesE + 1160 | 0, $13, 3);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $14;
    var $18 = $14 | 0;
    var $19 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $18, $5);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $24 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $25 = __ZL12ATOM_TO_JSIDP6JSAtom3984($24);
    __ZN2JSL10Int32ValueEi3996($1, 4);
    var $26 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($17, $cx, $25, $1, 10, 12, 6);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $32 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom3984($32);
    __ZN2JSL10Int32ValueEi3996($2, 4);
    var $34 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($6, $cx, $33, $2, 10, 12, 6);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $37 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, __ZN2js10TypedArray7jspropsE, __ZN11Uint32Array7jsfuncsE);
    if ($37) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $global, 30, $17, $6);
    var $_ = $39 ? $6 : 0;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19InitTypedArrayClassI12Float32ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $global;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js10TypedArray11slowClassesE + 1392 | 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $cx + 52 | 0;
    var $13 = HEAP32[HEAP32[$9 >> 2] + 210144 >> 2];
    var $14 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 248, __ZN2js10TypedArray11fastClassesE + 1392 | 0, $13, 3);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $14;
    var $18 = $14 | 0;
    var $19 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $18, $5);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $24 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $25 = __ZL12ATOM_TO_JSIDP6JSAtom3984($24);
    __ZN2JSL10Int32ValueEi3996($1, 4);
    var $26 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($17, $cx, $25, $1, 10, 12, 6);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $32 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom3984($32);
    __ZN2JSL10Int32ValueEi3996($2, 4);
    var $34 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($6, $cx, $33, $2, 10, 12, 6);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $37 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, __ZN2js10TypedArray7jspropsE, __ZN12Float32Array7jsfuncsE);
    if ($37) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $global, 31, $17, $6);
    var $_ = $39 ? $6 : 0;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19InitTypedArrayClassI12Float64ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $global;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js10TypedArray11slowClassesE + 1624 | 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $cx + 52 | 0;
    var $13 = HEAP32[HEAP32[$9 >> 2] + 210148 >> 2];
    var $14 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 250, __ZN2js10TypedArray11fastClassesE + 1624 | 0, $13, 3);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $14;
    var $18 = $14 | 0;
    var $19 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $18, $5);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $24 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $25 = __ZL12ATOM_TO_JSIDP6JSAtom3984($24);
    __ZN2JSL10Int32ValueEi3996($1, 8);
    var $26 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($17, $cx, $25, $1, 10, 12, 6);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $32 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom3984($32);
    __ZN2JSL10Int32ValueEi3996($2, 8);
    var $34 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($6, $cx, $33, $2, 10, 12, 6);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $37 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, __ZN2js10TypedArray7jspropsE, __ZN12Float64Array7jsfuncsE);
    if ($37) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $global, 32, $17, $6);
    var $_ = $39 ? $6 : 0;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19InitTypedArrayClassI17Uint8ClampedArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $global;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js10TypedArray11slowClassesE + 1856 | 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $cx + 52 | 0;
    var $13 = HEAP32[HEAP32[$9 >> 2] + 210152 >> 2];
    var $14 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 252, __ZN2js10TypedArray11fastClassesE + 1856 | 0, $13, 3);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $14;
    var $18 = $14 | 0;
    var $19 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $18, $5);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $24 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $25 = __ZL12ATOM_TO_JSIDP6JSAtom3984($24);
    __ZN2JSL10Int32ValueEi3996($1, 1);
    var $26 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($17, $cx, $25, $1, 10, 12, 6);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $32 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom3984($32);
    __ZN2JSL10Int32ValueEi3996($2, 1);
    var $34 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($6, $cx, $33, $2, 10, 12, 6);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $37 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, __ZN2js10TypedArray7jspropsE, __ZN17Uint8ClampedArray7jsfuncsE);
    if ($37) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $global, 33, $17, $6);
    var $_ = $39 ? $6 : 0;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20InitArrayBufferClassP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $global;
    var $2 = $cx;
    var $3 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($1, $2, __ZN2js11ArrayBuffer9slowClassE);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = HEAP32[HEAP32[$cx + 52 >> 2] + 210116 >> 2];
    var $12 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($1, $2, 254, __ZN2js16ArrayBufferClassE, $11, 1);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = $12;
    var $16 = $12 | 0;
    var $17 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($2, $16, $3);
    if ($17) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $19 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($2, $3, __ZN2js11ArrayBuffer7jspropsE, 0);
    if ($19) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $21 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $global, 24, $15, $4);
    var $_ = $21 ? $4 : 0;
    var $_0 = $_;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z20js_CreateArrayBufferP9JSContextj($cx, $nbytes) {
  var $1 = __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $nbytes);
  return $1;
}

function __Z19js_CreateTypedArrayP9JSContextij($cx, $atype, $nelements) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $nelems = __stackBase__;
  __ZN2JSL10Int32ValueEi3996($nelems, $nelements);
  var $1 = __ZL19TypedArrayConstructP9JSContextijPN2JS5ValueE($cx, $atype, $nelems);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZN2JSL10Int32ValueEi3996($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZL19TypedArrayConstructP9JSContextijPN2JS5ValueE($cx, $atype, $argv) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($atype | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($atype | 0) == 1) {
      __label__ = 3;
      break;
    } else if (($atype | 0) == 2) {
      __label__ = 4;
      break;
    } else if (($atype | 0) == 3) {
      __label__ = 5;
      break;
    } else if (($atype | 0) == 4) {
      __label__ = 6;
      break;
    } else if (($atype | 0) == 5) {
      __label__ = 7;
      break;
    } else if (($atype | 0) == 6) {
      __label__ = 8;
      break;
    } else if (($atype | 0) == 7) {
      __label__ = 9;
      break;
    } else if (($atype | 0) == 8) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    var $2 = __ZN18TypedArrayTemplateIaE6createEP9JSContextjPN2JS5ValueE($cx, 1, $argv);
    var $_0 = $2;
    __label__ = 11;
    break;
   case 3:
    var $4 = __ZN18TypedArrayTemplateIhE6createEP9JSContextjPN2JS5ValueE($cx, 1, $argv);
    var $_0 = $4;
    __label__ = 11;
    break;
   case 4:
    var $6 = __ZN18TypedArrayTemplateIsE6createEP9JSContextjPN2JS5ValueE($cx, 1, $argv);
    var $_0 = $6;
    __label__ = 11;
    break;
   case 5:
    var $8 = __ZN18TypedArrayTemplateItE6createEP9JSContextjPN2JS5ValueE($cx, 1, $argv);
    var $_0 = $8;
    __label__ = 11;
    break;
   case 6:
    var $10 = __ZN18TypedArrayTemplateIiE6createEP9JSContextjPN2JS5ValueE($cx, 1, $argv);
    var $_0 = $10;
    __label__ = 11;
    break;
   case 7:
    var $12 = __ZN18TypedArrayTemplateIjE6createEP9JSContextjPN2JS5ValueE($cx, 1, $argv);
    var $_0 = $12;
    __label__ = 11;
    break;
   case 8:
    var $14 = __ZN18TypedArrayTemplateIfE6createEP9JSContextjPN2JS5ValueE($cx, 1, $argv);
    var $_0 = $14;
    __label__ = 11;
    break;
   case 9:
    var $16 = __ZN18TypedArrayTemplateIdE6createEP9JSContextjPN2JS5ValueE($cx, 1, $argv);
    var $_0 = $16;
    __label__ = 11;
    break;
   case 10:
    var $18 = __ZN18TypedArrayTemplateI13uint8_clampedE6createEP9JSContextjPN2JS5ValueE($cx, 1, $argv);
    var $_0 = $18;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11ObjectValueER8JSObject3997($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE17class_constructorEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 16 | 0;
    var $2 = __ZN18TypedArrayTemplateI13uint8_clampedE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $byteOffset = __stackBase__ + 4;
    var $length = __stackBase__ + 8;
    HEAP32[$len >> 2] = 0;
    if (($argc | 0) == 0) {
      var $5 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL13ValueIsLengthP9JSContextRKN2JS5ValueEPj($argv, $len);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $5 = HEAP32[$len >> 2];
    __label__ = 4;
    break;
   case 4:
    var $5;
    var $6 = __ZN18TypedArrayTemplateI13uint8_clampedE28createBufferWithSizeAndCountEP9JSContextj($cx, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZN18TypedArrayTemplateI13uint8_clampedE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $6, 0, $5);
    var $_0 = $9;
    __label__ = 22;
    break;
   case 6:
    var $argv_idx = $argv | 0;
    var $argv_idx_val$0 = HEAP32[$argv_idx >> 2];
    var $argv_idx_val$1 = HEAP32[$argv_idx + 4 >> 2];
    var $11 = __ZNK2JS5Value8isObjectEv($argv_idx_val$0, $argv_idx_val$1);
    if ($11) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 8:
    var $14 = __ZNK2JS5Value8toObjectEv($argv_idx_val$0, $argv_idx_val$1);
    var $_idx_val = HEAP32[$14 + 4 >> 2];
    var $15 = __Z15js_IsTypedArrayP8JSObject($_idx_val);
    if (($15 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $18 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($14);
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($18);
    var $20 = __ZN18TypedArrayTemplateI13uint8_clampedE28createBufferWithSizeAndCountEP9JSContextj($cx, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $23 = __ZN18TypedArrayTemplateI13uint8_clampedE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $20, 0, $19);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = __ZN18TypedArrayTemplateI13uint8_clampedE18copyFromTypedArrayEP9JSContextP8JSObjectS5_j($cx, $23, $18, 0);
    if ($26) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 12:
    var $_0 = $23;
    __label__ = 22;
    break;
   case 13:
    HEAP32[$byteOffset >> 2] = -1;
    HEAP32[$length >> 2] = -1;
    if ($argc >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      var $48 = -1;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 14:
    var $31 = $argv + 8 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $byteOffset);
    if ($32) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 15:
    var $34 = HEAPU32[$byteOffset >> 2];
    if (($34 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 4, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str163973 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 17:
    if ($argc >>> 0 > 2) {
      __label__ = 18;
      break;
    } else {
      var $48 = $34;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 18:
    var $40 = $argv + 16 | 0;
    var $41 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $40, $length);
    if ($41) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 19:
    var $43 = HEAPU32[$length >> 2];
    if (($43 | 0) < 0) {
      __label__ = 20;
      break;
    } else {
      var $48 = $34;
      var $47 = $43;
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 4, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str173974 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 21:
    var $47;
    var $48;
    var $49 = __ZN18TypedArrayTemplateI13uint8_clampedE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $14, $48, $47);
    var $_0 = $49;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateI13uint8_clampedE6createEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL13ValueIsLengthP9JSContextRKN2JS5ValueEPj($v, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx2 = $v | 0;
    var $v_idx2_val$0 = HEAP32[$v_idx2 >> 2];
    var $v_idx2_val$1 = HEAP32[$v_idx2 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx2_val$0, $v_idx2_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx2_val$0, $v_idx2_val$1);
    if (($3 | 0) < 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$len >> 2] = $3;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 4:
    var $7 = __ZNK2JS5Value8isDoubleEv($v_idx2_val$0, $v_idx2_val$1);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $9 = __ZNK2JS5Value8toDoubleEv($v);
    var $10 = __ZL15JSDOUBLE_IS_NaNd3989($9);
    if (($10 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $13 = $9 >= 0 ? Math.floor($9) : Math.ceil($9);
    if ($9 != $13 >>> 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$len >> 2] = $13;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE28createBufferWithSizeAndCountEP9JSContextj($cx, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 > 2147483646) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 4, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str183975 | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $4 = __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $count);
    var $_0 = $4;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $bufobj, $byteOffset, $len) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981($cx, __ZN2js10TypedArray11slowClassesE + 1856 | 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAPU32[__ZN2js10TypedArray11slowClassesE + 1860 >> 2] >>> 24;
    var $11 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($6, $11);
    __ZN2JSL10Int32ValueEi3996($1, 8);
    var $_idx4 = $1 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 3, $_idx4_val$0, $_idx4_val$1);
    __ZN2JSL11ObjectValueER8JSObject3997($2, $bufobj);
    var $_idx3 = $2 | 0;
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 4, $_idx3_val$0, $_idx3_val$1);
    var $bufobj_idx_val = HEAP32[$bufobj + 32 >> 2];
    var $14 = __ZN8JSObject21arrayBufferDataOffsetEv($bufobj_idx_val);
    var $15 = $14 + $byteOffset | 0;
    __ZN8JSObject10setPrivateEPv($6, $15);
    __ZN2JSL10Int32ValueEi3996($3, $len);
    var $_idx2 = $3 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 0, $_idx2_val$0, $_idx2_val$1);
    __ZN2JSL10Int32ValueEi3996($4, $byteOffset);
    var $_idx1 = $4 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 1, $_idx1_val$0, $_idx1_val$1);
    __ZN2JSL10Int32ValueEi3996($5, $len);
    var $_idx = $5 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 2, $_idx_val$0, $_idx_val$1);
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    __ZN8JSObject8setClassEPN2js5ClassE($6, __ZN2js10TypedArray11fastClassesE + 1856 | 0);
    var $16 = $6 + 8 | 0;
    var $18 = HEAP32[$16 >> 2] | 4;
    HEAP32[$16 >> 2] = $18;
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateI13uint8_clampedE16createTypedArrayEP9JSContextP8JSObjectjj["X"] = 1;

function __ZN18TypedArrayTemplateI13uint8_clampedE18copyFromTypedArrayEP9JSContextP8JSObjectS5_j($cx, $thisTypedArrayObj, $tarray, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 12;
    var $5 = __stackBase__ + 16;
    var $6 = __stackBase__ + 20;
    var $7 = __stackBase__ + 24;
    var $8 = __stackBase__ + 28;
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $10 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
    var $11 = __ZN2js10TypedArray9getBufferEP8JSObject($9);
    if (($10 | 0) == ($11 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $14 = __ZN18TypedArrayTemplateI13uint8_clampedE19copyFromWithOverlapEP9JSContextP8JSObjectS5_j($cx, $9, $tarray, $offset);
    var $_0 = $14;
    __label__ = 30;
    break;
   case 3:
    var $_idx_val = HEAP32[$9 + 24 >> 2];
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx_val);
    var $17 = $16;
    var $18 = $17 + $offset | 0;
    var $19 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $20 = __ZN2js10TypedArray7getTypeEP8JSObject($9);
    if (($19 | 0) == ($20 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $23 = $18 | 0;
    var $tarray_idx8_val = HEAP32[$tarray + 24 >> 2];
    var $24 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx8_val);
    var $25 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($23, $24, $25, 1);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 5:
    var $27 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($19 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($19 | 0) == 1 || ($19 | 0) == 8) {
      __label__ = 9;
      break;
    } else if (($19 | 0) == 2) {
      __label__ = 12;
      break;
    } else if (($19 | 0) == 3) {
      __label__ = 15;
      break;
    } else if (($19 | 0) == 4) {
      __label__ = 18;
      break;
    } else if (($19 | 0) == 5) {
      __label__ = 21;
      break;
    } else if (($19 | 0) == 6) {
      __label__ = 24;
      break;
    } else if (($19 | 0) == 7) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 6:
    if (($27 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $tarray_idx7_val = HEAP32[$tarray + 24 >> 2];
    var $30 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx7_val);
    var $lftr_limit51 = $17 + ($27 + $offset) | 0;
    var $_idx9 = $1 | 0;
    var $src_036 = $30;
    var $dest_037 = $18;
    __label__ = 8;
    break;
   case 8:
    var $dest_037;
    var $src_036;
    var $32 = $dest_037 + 1 | 0;
    var $33 = $src_036 + 1 | 0;
    var $34 = HEAP8[$src_036];
    __ZN13uint8_clampedC1Ea($1, $34);
    var $_idx9_val = HEAP8[$_idx9];
    __ZN13uint8_clampedaSERKS_($dest_037, $_idx9_val);
    if (($32 | 0) == ($lftr_limit51 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src_036 = $33;
      var $dest_037 = $32;
      __label__ = 8;
      break;
    }
   case 9:
    if (($27 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $tarray_idx6_val = HEAP32[$tarray + 24 >> 2];
    var $37 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx6_val);
    var $lftr_limit49 = $17 + ($27 + $offset) | 0;
    var $_idx10 = $2 | 0;
    var $src1_031 = $37;
    var $dest_132 = $18;
    __label__ = 11;
    break;
   case 11:
    var $dest_132;
    var $src1_031;
    var $39 = $dest_132 + 1 | 0;
    var $40 = $src1_031 + 1 | 0;
    var $41 = HEAP8[$src1_031];
    __ZN13uint8_clampedC1Eh($2, $41);
    var $_idx10_val = HEAP8[$_idx10];
    __ZN13uint8_clampedaSERKS_($dest_132, $_idx10_val);
    if (($39 | 0) == ($lftr_limit49 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src1_031 = $40;
      var $dest_132 = $39;
      __label__ = 11;
      break;
    }
   case 12:
    if (($27 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $tarray_idx5_val = HEAP32[$tarray + 24 >> 2];
    var $44 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx5_val);
    var $lftr_limit47 = $17 + ($27 + $offset) | 0;
    var $_idx11 = $3 | 0;
    var $src3_026 = $44;
    var $dest_227 = $18;
    __label__ = 14;
    break;
   case 14:
    var $dest_227;
    var $src3_026;
    var $47 = $dest_227 + 1 | 0;
    var $48 = $src3_026 + 2 | 0;
    var $49 = HEAP16[$src3_026 >> 1];
    __ZN13uint8_clampedC1Es($3, $49);
    var $_idx11_val = HEAP8[$_idx11];
    __ZN13uint8_clampedaSERKS_($dest_227, $_idx11_val);
    if (($47 | 0) == ($lftr_limit47 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src3_026 = $48;
      var $dest_227 = $47;
      __label__ = 14;
      break;
    }
   case 15:
    if (($27 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $tarray_idx4_val = HEAP32[$tarray + 24 >> 2];
    var $52 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx4_val);
    var $lftr_limit45 = $17 + ($27 + $offset) | 0;
    var $_idx12 = $4 | 0;
    var $src5_021 = $52;
    var $dest_322 = $18;
    __label__ = 17;
    break;
   case 17:
    var $dest_322;
    var $src5_021;
    var $55 = $dest_322 + 1 | 0;
    var $56 = $src5_021 + 2 | 0;
    var $57 = HEAP16[$src5_021 >> 1];
    __ZN13uint8_clampedC1Et($4, $57);
    var $_idx12_val = HEAP8[$_idx12];
    __ZN13uint8_clampedaSERKS_($dest_322, $_idx12_val);
    if (($55 | 0) == ($lftr_limit45 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src5_021 = $56;
      var $dest_322 = $55;
      __label__ = 17;
      break;
    }
   case 18:
    if (($27 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $tarray_idx3_val = HEAP32[$tarray + 24 >> 2];
    var $60 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx3_val);
    var $lftr_limit43 = $17 + ($27 + $offset) | 0;
    var $_idx13 = $5 | 0;
    var $src7_016 = $60;
    var $dest_417 = $18;
    __label__ = 20;
    break;
   case 20:
    var $dest_417;
    var $src7_016;
    var $63 = $dest_417 + 1 | 0;
    var $64 = $src7_016 + 4 | 0;
    var $65 = HEAP32[$src7_016 >> 2];
    __ZN13uint8_clampedC1Ei($5, $65);
    var $_idx13_val = HEAP8[$_idx13];
    __ZN13uint8_clampedaSERKS_($dest_417, $_idx13_val);
    if (($63 | 0) == ($lftr_limit43 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src7_016 = $64;
      var $dest_417 = $63;
      __label__ = 20;
      break;
    }
   case 21:
    if (($27 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $tarray_idx2_val = HEAP32[$tarray + 24 >> 2];
    var $68 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx2_val);
    var $lftr_limit41 = $17 + ($27 + $offset) | 0;
    var $_idx14 = $6 | 0;
    var $src9_011 = $68;
    var $dest_512 = $18;
    __label__ = 23;
    break;
   case 23:
    var $dest_512;
    var $src9_011;
    var $71 = $dest_512 + 1 | 0;
    var $72 = $src9_011 + 4 | 0;
    var $73 = HEAP32[$src9_011 >> 2];
    __ZN13uint8_clampedC1Ej($6, $73);
    var $_idx14_val = HEAP8[$_idx14];
    __ZN13uint8_clampedaSERKS_($dest_512, $_idx14_val);
    if (($71 | 0) == ($lftr_limit41 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src9_011 = $72;
      var $dest_512 = $71;
      __label__ = 23;
      break;
    }
   case 24:
    if (($27 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $tarray_idx1_val = HEAP32[$tarray + 24 >> 2];
    var $76 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx1_val);
    var $lftr_limit39 = $17 + ($27 + $offset) | 0;
    var $_idx15 = $7 | 0;
    var $src11_05 = $76;
    var $dest_66 = $18;
    __label__ = 26;
    break;
   case 26:
    var $dest_66;
    var $src11_05;
    var $79 = $dest_66 + 1 | 0;
    var $80 = $src11_05 + 4 | 0;
    var $82 = HEAPF32[$src11_05 >> 2];
    __ZN13uint8_clampedC1Ed($7, $82);
    var $_idx15_val = HEAP8[$_idx15];
    __ZN13uint8_clampedaSERKS_($dest_66, $_idx15_val);
    if (($79 | 0) == ($lftr_limit39 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src11_05 = $80;
      var $dest_66 = $79;
      __label__ = 26;
      break;
    }
   case 27:
    if (($27 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    var $85 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx_val);
    var $lftr_limit = $17 + ($27 + $offset) | 0;
    var $_idx16 = $8 | 0;
    var $dest_71 = $18;
    var $src13_02 = $85;
    __label__ = 29;
    break;
   case 29:
    var $src13_02;
    var $dest_71;
    var $88 = $dest_71 + 1 | 0;
    var $89 = $src13_02 + 8 | 0;
    var $90 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    __ZN13uint8_clampedC1Ed($8, $90);
    var $_idx16_val = HEAP8[$_idx16];
    __ZN13uint8_clampedaSERKS_($dest_71, $_idx16_val);
    if (($88 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $dest_71 = $88;
      var $src13_02 = $89;
      __label__ = 29;
      break;
    }
   case 30:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateI13uint8_clampedE18copyFromTypedArrayEP9JSContextP8JSObjectS5_j["X"] = 1;

function _INT_TO_JSID4006($i) {
  return $i << 1 | 1;
}

function __ZL18JSDOUBLE_IS_FINITEd4011($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function __ZN13uint8_clampedaSERKS_($this, $x_0_0_val) {
  HEAP8[$this | 0] = $x_0_0_val;
  return;
}

function __ZN13uint8_clampedaSEj($this, $x) {
  var $2 = $x >>> 0 > 255 ? -1 : $x & 255;
  HEAP8[$this | 0] = $2;
  return;
}

function __ZN13uint8_clampedaSEi($this, $x) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($x | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    if (($x | 0) < 255) {
      __label__ = 3;
      break;
    } else {
      var $7 = -1;
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = $x & 255;
    __label__ = 4;
    break;
   case 4:
    var $7;
    HEAP8[$this | 0] = $7;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13uint8_clampedaSEt($this, $x) {
  var $2 = ($x & 65535) > 255 ? -1 : $x & 255;
  HEAP8[$this | 0] = $2;
  return;
}

function __ZN13uint8_clampedaSEs($this, $x) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($x << 16 >> 16 > -1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    if ($x << 16 >> 16 < 255) {
      __label__ = 3;
      break;
    } else {
      var $7 = -1;
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = $x & 255;
    __label__ = 4;
    break;
   case 4:
    var $7;
    HEAP8[$this | 0] = $7;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13uint8_clampedaSEh($this, $x) {
  HEAP8[$this | 0] = $x;
  return;
}

function __ZN13uint8_clampedaSEa($this, $x) {
  var $2 = $x << 24 >> 24 < 0 ? 0 : $x;
  HEAP8[$this | 0] = $2;
  return;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $other, $byteOffsetInt, $lengthInt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len1 = __stackBase__;
    var $other_idx_val = HEAP32[$other + 4 >> 2];
    var $1 = __ZNK8JSObject13isArrayBufferEv($other_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    var $4 = ($byteOffsetInt | 0) < 0 ? 0 : $byteOffsetInt;
    var $other_idx2_val = HEAP32[$other + 32 >> 2];
    var $5 = __ZN8JSObject21arrayBufferByteLengthEv($other_idx2_val);
    if ($4 >>> 0 > $5 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 4:
    var $_lengthInt = ($lengthInt | 0) < 0 ? $5 - $4 | 0 : $lengthInt;
    if ($_lengthInt >>> 0 < 2147483647 & $4 >>> 0 < (2147483647 - $_lengthInt | 0) >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 6:
    if (($_lengthInt + $4 | 0) >>> 0 > $5 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 8:
    var $20 = __ZN18TypedArrayTemplateI13uint8_clampedE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $other, $4, $_lengthInt);
    var $_0 = $20;
    __label__ = 14;
    break;
   case 9:
    var $22 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $other, $len1);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $25 = HEAP32[$len1 >> 2];
    var $26 = __ZN18TypedArrayTemplateI13uint8_clampedE28createBufferWithSizeAndCountEP9JSContextj($cx, $25);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $29 = __ZN18TypedArrayTemplateI13uint8_clampedE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $26, 0, $25);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $32 = __ZN18TypedArrayTemplateI13uint8_clampedE13copyFromArrayEP9JSContextP8JSObjectS5_jj($cx, $29, $other, $25, 0);
    if ($32) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 13:
    var $_0 = $29;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE13copyFromArrayEP9JSContextP8JSObjectS5_jj($cx, $thisTypedArrayObj, $ar, $len, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $v = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $3 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $_idx_val = HEAP32[$3 + 24 >> 2];
    var $4 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx_val);
    var $5 = $4;
    var $6 = $5 + $offset | 0;
    var $ar_idx_val = HEAP32[$ar + 4 >> 2];
    var $7 = __ZNK8JSObject12isDenseArrayEv($ar_idx_val);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = __ZN8JSObject30getDenseArrayInitializedLengthEv($ar);
    if ($9 >>> 0 < $len >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $_idx3 = $2 | 0;
    var $i1_0 = 0;
    var $dest_1 = $6;
    __label__ = 7;
    break;
   case 4:
    if (($len | 0) == 0) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $ar_idx1_val = HEAP32[$ar + 32 >> 2];
    var $13 = __ZN8JSObject21getDenseArrayElementsEv($ar_idx1_val);
    var $lftr_limit = $5 + ($offset + $len) | 0;
    var $_idx2 = $1 | 0;
    var $dest_01 = $6;
    var $src_02 = $13;
    __label__ = 6;
    break;
   case 6:
    var $src_02;
    var $dest_01;
    var $15 = $dest_01 + 1 | 0;
    var $16 = $src_02 + 8 | 0;
    __ZN18TypedArrayTemplateI13uint8_clampedE15nativeFromValueEP9JSContextRKN2JS5ValueE($1, $cx, $src_02);
    var $_idx2_val = HEAP8[$_idx2];
    __ZN13uint8_clampedaSERKS_($dest_01, $_idx2_val);
    if (($15 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      var $dest_01 = $15;
      var $src_02 = $16;
      __label__ = 6;
      break;
    }
   case 7:
    var $dest_1;
    var $i1_0;
    if ($i1_0 >>> 0 < $len >>> 0) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 10;
      break;
    }
   case 8:
    var $19 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($ar, $cx, $i1_0, $v);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $22 = $dest_1 + 1 | 0;
    __ZN18TypedArrayTemplateI13uint8_clampedE15nativeFromValueEP9JSContextRKN2JS5ValueE($2, $cx, $v);
    var $_idx3_val = HEAP8[$_idx3];
    __ZN13uint8_clampedaSERKS_($dest_1, $_idx3_val);
    var $i1_0 = $i1_0 + 1 | 0;
    var $dest_1 = $22;
    __label__ = 7;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateI13uint8_clampedE13copyFromArrayEP9JSContextP8JSObjectS5_jj["X"] = 1;

function __ZN18TypedArrayTemplateI13uint8_clampedE15nativeFromValueEP9JSContextRKN2JS5ValueE($agg_result, $cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $dval = __stackBase__;
    var $v_idx3 = $v | 0;
    var $v_idx3_val$0 = HEAP32[$v_idx3 >> 2];
    var $v_idx3_val$1 = HEAP32[$v_idx3 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx3_val$0, $v_idx3_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx3_val$0, $v_idx3_val$1);
    __ZN13uint8_clampedC1Ei($agg_result, $3);
    __label__ = 11;
    break;
   case 3:
    var $5 = __ZNK2JS5Value8isDoubleEv($v_idx3_val$0, $v_idx3_val$1);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $7 = __ZNK2JS5Value8toDoubleEv($v);
    var $8 = __ZL15JSDOUBLE_IS_NaNd3989($7);
    if (($8 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN13uint8_clampedC1Ei($agg_result, 0);
    __label__ = 11;
    break;
   case 6:
    var $12 = __ZL20js_DoubleToECMAInt32d4007($7);
    __ZN13uint8_clampedC1Ei($agg_result, $12);
    __label__ = 11;
    break;
   case 7:
    var $14 = __ZNK2JS5Value11isPrimitiveEv($v_idx3_val$0, $v_idx3_val$1);
    if ($14) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $16 = __ZNK2JS5Value7isMagicEv($v_idx3_val$0, $v_idx3_val$1);
    if ($16) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $18 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $v, $dval);
    var $19 = (tempDoubleI32[0] = HEAP32[$dval >> 2], tempDoubleI32[1] = HEAP32[$dval + 4 >> 2], tempDoubleF64[0]);
    __ZN13uint8_clampedC1Ed($agg_result, $19);
    __label__ = 11;
    break;
   case 10:
    __ZN13uint8_clampedC1Ei($agg_result, 0);
    __label__ = 11;
    break;
   case 11:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13uint8_clampedC1Ei($this, $x) {
  __ZN13uint8_clampedC2Ei($this, $x);
  return;
}

function __ZN13uint8_clampedC1Ed($this, $x) {
  __ZN13uint8_clampedC2Ed($this, $x);
  return;
}

function __ZN13uint8_clampedC1Ej($this, $x) {
  __ZN13uint8_clampedC2Ej($this, $x);
  return;
}

function __ZL20js_DoubleToECMAInt32d4007($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL18JSDOUBLE_IS_FINITEd4011($d);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $d & -1;
    if (($4 | 0) == $d) {
      var $_0 = $4;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = _fmod($d, 4294967296);
    if ($8 < 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = _floor($8);
    var $16 = $11;
    __label__ = 6;
    break;
   case 5:
    var $13 = _ceil($8);
    var $16 = $13 + 4294967296;
    __label__ = 6;
    break;
   case 6:
    var $16;
    if ($16 < 2147483648) {
      var $21 = $16;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $21 = $16 - 4294967296;
    __label__ = 8;
    break;
   case 8:
    var $21;
    var $_0 = $21 & -1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13uint8_clampedC2Ej($this, $x) {
  __ZN13uint8_clampedaSEj($this, $x);
  return;
}

function __ZN13uint8_clampedC2Ed($this, $x) {
  __ZN13uint8_clampedaSEd($this, $x);
  return;
}

function __ZN13uint8_clampedaSEd($this, $x) {
  var $1 = __Z32js_TypedArray_uint8_clamp_doubled($x);
  HEAP8[$this | 0] = $1 & 255;
  return;
}

function __ZN13uint8_clampedC2Ei($this, $x) {
  __ZN13uint8_clampedaSEi($this, $x);
  return;
}

function __ZN2js10TypedArray9getBufferEP8JSObject($obj) {
  var $1 = __ZNK8JSObject12getFixedSlotEj($obj, 4);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $2 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
  return $2;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE19copyFromWithOverlapEP9JSContextP8JSObjectS5_j($cx, $self, $tarray, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 12;
    var $5 = __stackBase__ + 16;
    var $6 = __stackBase__ + 20;
    var $7 = __stackBase__ + 24;
    var $8 = __stackBase__ + 28;
    var $self_idx_val = HEAP32[$self + 24 >> 2];
    var $9 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($self_idx_val);
    var $11 = $9 + $offset | 0;
    var $12 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $13 = __ZN2js10TypedArray7getTypeEP8JSObject($self);
    if (($12 | 0) == ($13 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = $11 | 0;
    var $tarray_idx1_val = HEAP32[$tarray + 24 >> 2];
    var $17 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx1_val);
    var $18 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _llvm_memmove_p0i8_p0i8_i32($16, $17, $18, 1, 0);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 3:
    var $20 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    var $21 = __ZN9JSContext7malloc_Ej($cx, $20);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    var $24 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx_val);
    var $25 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($21, $24, $25, 1);
    var $26 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    if (($26 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($26 | 0) == 1 || ($26 | 0) == 8) {
      __label__ = 7;
      break;
    } else if (($26 | 0) == 2) {
      __label__ = 11;
      break;
    } else if (($26 | 0) == 3) {
      __label__ = 14;
      break;
    } else if (($26 | 0) == 4) {
      __label__ = 17;
      break;
    } else if (($26 | 0) == 5) {
      __label__ = 20;
      break;
    } else if (($26 | 0) == 6) {
      __label__ = 23;
      break;
    } else if (($26 | 0) == 7) {
      __label__ = 26;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 5:
    var $27 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($27 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx = $1 | 0;
    var $i_036 = 0;
    var $src_037 = $21;
    var $dest_038 = $11;
    __label__ = 9;
    break;
   case 7:
    var $29 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($29 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx2 = $2 | 0;
    var $i2_030 = 0;
    var $src1_031 = $21;
    var $dest_132 = $11;
    __label__ = 10;
    break;
   case 9:
    var $dest_038;
    var $src_037;
    var $i_036;
    var $31 = $dest_038 + 1 | 0;
    var $32 = $src_037 + 1 | 0;
    var $33 = HEAP8[$src_037];
    __ZN13uint8_clampedC1Ea($1, $33);
    var $_idx_val = HEAP8[$_idx];
    __ZN13uint8_clampedaSERKS_($dest_038, $_idx_val);
    var $34 = $i_036 + 1 | 0;
    var $35 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($34 >>> 0 < $35 >>> 0) {
      var $i_036 = $34;
      var $src_037 = $32;
      var $dest_038 = $31;
      __label__ = 9;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 10:
    var $dest_132;
    var $src1_031;
    var $i2_030;
    var $37 = $dest_132 + 1 | 0;
    var $38 = $src1_031 + 1 | 0;
    var $39 = HEAP8[$src1_031];
    __ZN13uint8_clampedC1Eh($2, $39);
    var $_idx2_val = HEAP8[$_idx2];
    __ZN13uint8_clampedaSERKS_($dest_132, $_idx2_val);
    var $40 = $i2_030 + 1 | 0;
    var $41 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($40 >>> 0 < $41 >>> 0) {
      var $i2_030 = $40;
      var $src1_031 = $38;
      var $dest_132 = $37;
      __label__ = 10;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 11:
    var $44 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($44 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $_idx3 = $3 | 0;
    var $i4_025 = 0;
    var $src3_026 = $21;
    var $dest_227 = $11;
    __label__ = 13;
    break;
   case 13:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    var $48 = $dest_227 + 1 | 0;
    var $49 = $src3_026 + 2 | 0;
    var $50 = HEAP16[$src3_026 >> 1];
    __ZN13uint8_clampedC1Es($3, $50);
    var $_idx3_val = HEAP8[$_idx3];
    __ZN13uint8_clampedaSERKS_($dest_227, $_idx3_val);
    var $51 = $i4_025 + 1 | 0;
    var $52 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($51 >>> 0 < $52 >>> 0) {
      var $i4_025 = $51;
      var $src3_026 = $49;
      var $dest_227 = $48;
      __label__ = 13;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 14:
    var $55 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($55 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $_idx4 = $4 | 0;
    var $i6_020 = 0;
    var $src5_021 = $21;
    var $dest_322 = $11;
    __label__ = 16;
    break;
   case 16:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    var $59 = $dest_322 + 1 | 0;
    var $60 = $src5_021 + 2 | 0;
    var $61 = HEAP16[$src5_021 >> 1];
    __ZN13uint8_clampedC1Et($4, $61);
    var $_idx4_val = HEAP8[$_idx4];
    __ZN13uint8_clampedaSERKS_($dest_322, $_idx4_val);
    var $62 = $i6_020 + 1 | 0;
    var $63 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($62 >>> 0 < $63 >>> 0) {
      var $i6_020 = $62;
      var $src5_021 = $60;
      var $dest_322 = $59;
      __label__ = 16;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 17:
    var $66 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($66 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $_idx5 = $5 | 0;
    var $i8_015 = 0;
    var $src7_016 = $21;
    var $dest_417 = $11;
    __label__ = 19;
    break;
   case 19:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    var $70 = $dest_417 + 1 | 0;
    var $71 = $src7_016 + 4 | 0;
    var $72 = HEAP32[$src7_016 >> 2];
    __ZN13uint8_clampedC1Ei($5, $72);
    var $_idx5_val = HEAP8[$_idx5];
    __ZN13uint8_clampedaSERKS_($dest_417, $_idx5_val);
    var $73 = $i8_015 + 1 | 0;
    var $74 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($73 >>> 0 < $74 >>> 0) {
      var $i8_015 = $73;
      var $src7_016 = $71;
      var $dest_417 = $70;
      __label__ = 19;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 20:
    var $77 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($77 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $_idx6 = $6 | 0;
    var $src9_010 = $21;
    var $i10_011 = 0;
    var $dest_512 = $11;
    __label__ = 22;
    break;
   case 22:
    var $dest_512;
    var $i10_011;
    var $src9_010;
    var $81 = $dest_512 + 1 | 0;
    var $82 = $src9_010 + 4 | 0;
    var $83 = HEAP32[$src9_010 >> 2];
    __ZN13uint8_clampedC1Ej($6, $83);
    var $_idx6_val = HEAP8[$_idx6];
    __ZN13uint8_clampedaSERKS_($dest_512, $_idx6_val);
    var $84 = $i10_011 + 1 | 0;
    var $85 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($84 >>> 0 < $85 >>> 0) {
      var $src9_010 = $82;
      var $i10_011 = $84;
      var $dest_512 = $81;
      __label__ = 22;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 23:
    var $88 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($88 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $_idx7 = $7 | 0;
    var $dest_65 = $11;
    var $src11_06 = $21;
    var $i12_07 = 0;
    __label__ = 25;
    break;
   case 25:
    var $i12_07;
    var $src11_06;
    var $dest_65;
    var $92 = $dest_65 + 1 | 0;
    var $93 = $src11_06 + 4 | 0;
    var $95 = HEAPF32[$src11_06 >> 2];
    __ZN13uint8_clampedC1Ed($7, $95);
    var $_idx7_val = HEAP8[$_idx7];
    __ZN13uint8_clampedaSERKS_($dest_65, $_idx7_val);
    var $96 = $i12_07 + 1 | 0;
    var $97 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($96 >>> 0 < $97 >>> 0) {
      var $dest_65 = $92;
      var $src11_06 = $93;
      var $i12_07 = $96;
      __label__ = 25;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 26:
    var $100 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($100 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $_idx8 = $8 | 0;
    var $dest_71 = $11;
    var $src13_02 = $21;
    var $i14_03 = 0;
    __label__ = 28;
    break;
   case 28:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $104 = $dest_71 + 1 | 0;
    var $105 = $src13_02 + 8 | 0;
    var $106 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    __ZN13uint8_clampedC1Ed($8, $106);
    var $_idx8_val = HEAP8[$_idx8];
    __ZN13uint8_clampedaSERKS_($dest_71, $_idx8_val);
    var $107 = $i14_03 + 1 | 0;
    var $108 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($107 >>> 0 < $108 >>> 0) {
      var $dest_71 = $104;
      var $src13_02 = $105;
      var $i14_03 = $107;
      __label__ = 28;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    __ZN2js10Foreground5free_EPv($21);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 30:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateI13uint8_clampedE19copyFromWithOverlapEP9JSContextP8JSObjectS5_j["X"] = 1;

function __ZN2js10TypedArray13getByteLengthEP8JSObject($obj) {
  var $1 = __ZNK8JSObject12getFixedSlotEj($obj, 2);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $2 = __ZNK2JS5Value7toInt32Ev($_idx_val$0, $_idx_val$1);
  return $2;
}

function __ZN13uint8_clampedC1Ea($this, $x) {
  __ZN13uint8_clampedC2Ea($this, $x);
  return;
}

function __ZN13uint8_clampedC1Eh($this, $x) {
  __ZN13uint8_clampedC2Eh($this, $x);
  return;
}

function __ZN13uint8_clampedC1Es($this, $x) {
  __ZN13uint8_clampedC2Es($this, $x);
  return;
}

function __ZN13uint8_clampedC1Et($this, $x) {
  __ZN13uint8_clampedC2Et($this, $x);
  return;
}

function __ZN13uint8_clampedC2Et($this, $x) {
  __ZN13uint8_clampedaSEt($this, $x);
  return;
}

function __ZN13uint8_clampedC2Es($this, $x) {
  __ZN13uint8_clampedaSEs($this, $x);
  return;
}

function __ZN13uint8_clampedC2Eh($this, $x) {
  __ZN13uint8_clampedaSEh($this, $x);
  return;
}

function __ZN13uint8_clampedC2Ea($this, $x) {
  __ZN13uint8_clampedaSEa($this, $x);
  return;
}

function __ZN18TypedArrayTemplateIdE17class_constructorEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 16 | 0;
    var $2 = __ZN18TypedArrayTemplateIdE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $byteOffset = __stackBase__ + 4;
    var $length = __stackBase__ + 8;
    HEAP32[$len >> 2] = 0;
    if (($argc | 0) == 0) {
      var $5 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL13ValueIsLengthP9JSContextRKN2JS5ValueEPj($argv, $len);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $5 = HEAP32[$len >> 2];
    __label__ = 4;
    break;
   case 4:
    var $5;
    var $6 = __ZN18TypedArrayTemplateIdE28createBufferWithSizeAndCountEP9JSContextj($cx, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZN18TypedArrayTemplateIdE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $6, 0, $5);
    var $_0 = $9;
    __label__ = 22;
    break;
   case 6:
    var $argv_idx = $argv | 0;
    var $argv_idx_val$0 = HEAP32[$argv_idx >> 2];
    var $argv_idx_val$1 = HEAP32[$argv_idx + 4 >> 2];
    var $11 = __ZNK2JS5Value8isObjectEv($argv_idx_val$0, $argv_idx_val$1);
    if ($11) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 8:
    var $14 = __ZNK2JS5Value8toObjectEv($argv_idx_val$0, $argv_idx_val$1);
    var $_idx_val = HEAP32[$14 + 4 >> 2];
    var $15 = __Z15js_IsTypedArrayP8JSObject($_idx_val);
    if (($15 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $18 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($14);
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($18);
    var $20 = __ZN18TypedArrayTemplateIdE28createBufferWithSizeAndCountEP9JSContextj($cx, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $23 = __ZN18TypedArrayTemplateIdE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $20, 0, $19);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = __ZN18TypedArrayTemplateIdE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $23, $18, 0);
    if ($26) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 12:
    var $_0 = $23;
    __label__ = 22;
    break;
   case 13:
    HEAP32[$byteOffset >> 2] = -1;
    HEAP32[$length >> 2] = -1;
    if ($argc >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      var $48 = -1;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 14:
    var $31 = $argv + 8 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $byteOffset);
    if ($32) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 15:
    var $34 = HEAPU32[$byteOffset >> 2];
    if (($34 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 4, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str163973 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 17:
    if ($argc >>> 0 > 2) {
      __label__ = 18;
      break;
    } else {
      var $48 = $34;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 18:
    var $40 = $argv + 16 | 0;
    var $41 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $40, $length);
    if ($41) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 19:
    var $43 = HEAPU32[$length >> 2];
    if (($43 | 0) < 0) {
      __label__ = 20;
      break;
    } else {
      var $48 = $34;
      var $47 = $43;
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 4, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str173974 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 21:
    var $47;
    var $48;
    var $49 = __ZN18TypedArrayTemplateIdE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $14, $48, $47);
    var $_0 = $49;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIdE6createEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIdE28createBufferWithSizeAndCountEP9JSContextj($cx, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 > 268435454) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 4, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str183975 | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $4 = $count << 3;
    var $5 = __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $4);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $bufobj, $byteOffset, $len) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981($cx, __ZN2js10TypedArray11slowClassesE + 1624 | 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAPU32[__ZN2js10TypedArray11slowClassesE + 1628 >> 2] >>> 24;
    var $11 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($6, $11);
    __ZN2JSL10Int32ValueEi3996($1, 7);
    var $_idx4 = $1 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 3, $_idx4_val$0, $_idx4_val$1);
    __ZN2JSL11ObjectValueER8JSObject3997($2, $bufobj);
    var $_idx3 = $2 | 0;
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 4, $_idx3_val$0, $_idx3_val$1);
    var $bufobj_idx_val = HEAP32[$bufobj + 32 >> 2];
    var $14 = __ZN8JSObject21arrayBufferDataOffsetEv($bufobj_idx_val);
    var $15 = $14 + $byteOffset | 0;
    __ZN8JSObject10setPrivateEPv($6, $15);
    __ZN2JSL10Int32ValueEi3996($3, $len);
    var $_idx2 = $3 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 0, $_idx2_val$0, $_idx2_val$1);
    __ZN2JSL10Int32ValueEi3996($4, $byteOffset);
    var $_idx1 = $4 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 1, $_idx1_val$0, $_idx1_val$1);
    var $16 = $len << 3;
    __ZN2JSL10Int32ValueEi3996($5, $16);
    var $_idx = $5 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 2, $_idx_val$0, $_idx_val$1);
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    __ZN8JSObject8setClassEPN2js5ClassE($6, __ZN2js10TypedArray11fastClassesE + 1624 | 0);
    var $17 = $6 + 8 | 0;
    var $19 = HEAP32[$17 >> 2] | 4;
    HEAP32[$17 >> 2] = $19;
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIdE16createTypedArrayEP9JSContextP8JSObjectjj["X"] = 1;

function __ZN18TypedArrayTemplateIdE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $thisTypedArrayObj, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
    var $3 = __ZN2js10TypedArray9getBufferEP8JSObject($1);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZN18TypedArrayTemplateIdE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $1, $tarray, $offset);
    var $_0 = $6;
    __label__ = 30;
    break;
   case 3:
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $8 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx_val);
    var $10 = $8 + ($offset << 3) | 0;
    var $11 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $12 = __ZN2js10TypedArray7getTypeEP8JSObject($1);
    if (($11 | 0) == ($12 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = $10;
    var $tarray_idx8_val = HEAP32[$tarray + 24 >> 2];
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx8_val);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($15, $16, $17, 1);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($11 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($11 | 0) == 1 || ($11 | 0) == 8) {
      __label__ = 9;
      break;
    } else if (($11 | 0) == 2) {
      __label__ = 12;
      break;
    } else if (($11 | 0) == 3) {
      __label__ = 15;
      break;
    } else if (($11 | 0) == 4) {
      __label__ = 18;
      break;
    } else if (($11 | 0) == 5) {
      __label__ = 21;
      break;
    } else if (($11 | 0) == 6) {
      __label__ = 24;
      break;
    } else if (($11 | 0) == 7) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 6:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $tarray_idx7_val = HEAP32[$tarray + 24 >> 2];
    var $22 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx7_val);
    var $lftr_limit45 = $22 + $19 | 0;
    var $src_036 = $22;
    var $dest_037 = $10;
    __label__ = 8;
    break;
   case 8:
    var $dest_037;
    var $src_036;
    var $24 = $src_036 + 1 | 0;
    tempDoubleF64[0] = HEAP8[$src_036] << 24 >> 24, HEAP32[$dest_037 >> 2] = tempDoubleI32[0], HEAP32[$dest_037 + 4 >> 2] = tempDoubleI32[1];
    if (($24 | 0) == ($lftr_limit45 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src_036 = $24;
      var $dest_037 = $dest_037 + 8 | 0;
      __label__ = 8;
      break;
    }
   case 9:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $tarray_idx6_val = HEAP32[$tarray + 24 >> 2];
    var $30 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx6_val);
    var $lftr_limit = $30 + $19 | 0;
    var $src1_031 = $30;
    var $dest_132 = $10;
    __label__ = 11;
    break;
   case 11:
    var $dest_132;
    var $src1_031;
    var $32 = $src1_031 + 1 | 0;
    tempDoubleF64[0] = HEAPU8[$src1_031] & 255, HEAP32[$dest_132 >> 2] = tempDoubleI32[0], HEAP32[$dest_132 + 4 >> 2] = tempDoubleI32[1];
    if (($32 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src1_031 = $32;
      var $dest_132 = $dest_132 + 8 | 0;
      __label__ = 11;
      break;
    }
   case 12:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $tarray_idx5_val = HEAP32[$tarray + 24 >> 2];
    var $38 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx5_val);
    var $i4_025 = 0;
    var $src3_026 = $38;
    var $dest_227 = $10;
    __label__ = 14;
    break;
   case 14:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    tempDoubleF64[0] = HEAP16[$src3_026 >> 1] << 16 >> 16, HEAP32[$dest_227 >> 2] = tempDoubleI32[0], HEAP32[$dest_227 + 4 >> 2] = tempDoubleI32[1];
    var $45 = $i4_025 + 1 | 0;
    if (($45 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i4_025 = $45;
      var $src3_026 = $src3_026 + 2 | 0;
      var $dest_227 = $dest_227 + 8 | 0;
      __label__ = 14;
      break;
    }
   case 15:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $tarray_idx4_val = HEAP32[$tarray + 24 >> 2];
    var $48 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx4_val);
    var $i6_020 = 0;
    var $src5_021 = $48;
    var $dest_322 = $10;
    __label__ = 17;
    break;
   case 17:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    tempDoubleF64[0] = HEAPU16[$src5_021 >> 1] & 65535, HEAP32[$dest_322 >> 2] = tempDoubleI32[0], HEAP32[$dest_322 + 4 >> 2] = tempDoubleI32[1];
    var $55 = $i6_020 + 1 | 0;
    if (($55 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i6_020 = $55;
      var $src5_021 = $src5_021 + 2 | 0;
      var $dest_322 = $dest_322 + 8 | 0;
      __label__ = 17;
      break;
    }
   case 18:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $tarray_idx3_val = HEAP32[$tarray + 24 >> 2];
    var $58 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx3_val);
    var $i8_015 = 0;
    var $src7_016 = $58;
    var $dest_417 = $10;
    __label__ = 20;
    break;
   case 20:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    tempDoubleF64[0] = HEAP32[$src7_016 >> 2] | 0, HEAP32[$dest_417 >> 2] = tempDoubleI32[0], HEAP32[$dest_417 + 4 >> 2] = tempDoubleI32[1];
    var $65 = $i8_015 + 1 | 0;
    if (($65 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i8_015 = $65;
      var $src7_016 = $src7_016 + 4 | 0;
      var $dest_417 = $dest_417 + 8 | 0;
      __label__ = 20;
      break;
    }
   case 21:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $tarray_idx2_val = HEAP32[$tarray + 24 >> 2];
    var $68 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx2_val);
    var $i10_010 = 0;
    var $src9_011 = $68;
    var $dest_512 = $10;
    __label__ = 23;
    break;
   case 23:
    var $dest_512;
    var $src9_011;
    var $i10_010;
    tempDoubleF64[0] = HEAPU32[$src9_011 >> 2] >>> 0, HEAP32[$dest_512 >> 2] = tempDoubleI32[0], HEAP32[$dest_512 + 4 >> 2] = tempDoubleI32[1];
    var $75 = $i10_010 + 1 | 0;
    if (($75 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i10_010 = $75;
      var $src9_011 = $src9_011 + 4 | 0;
      var $dest_512 = $dest_512 + 8 | 0;
      __label__ = 23;
      break;
    }
   case 24:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $tarray_idx1_val = HEAP32[$tarray + 24 >> 2];
    var $78 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx1_val);
    var $src11_05 = $78;
    var $dest_66 = $10;
    var $i12_07 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i12_07;
    var $dest_66;
    var $src11_05;
    tempDoubleF64[0] = HEAPF32[$src11_05 >> 2], HEAP32[$dest_66 >> 2] = tempDoubleI32[0], HEAP32[$dest_66 + 4 >> 2] = tempDoubleI32[1];
    var $85 = $i12_07 + 1 | 0;
    if (($85 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src11_05 = $src11_05 + 4 | 0;
      var $dest_66 = $dest_66 + 8 | 0;
      var $i12_07 = $85;
      __label__ = 26;
      break;
    }
   case 27:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    var $88 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx_val);
    var $dest_71 = $10;
    var $src13_02 = $88;
    var $i14_03 = 0;
    __label__ = 29;
    break;
   case 29:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $92 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $92, HEAP32[$dest_71 >> 2] = tempDoubleI32[0], HEAP32[$dest_71 + 4 >> 2] = tempDoubleI32[1];
    var $94 = $i14_03 + 1 | 0;
    if (($94 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $dest_71 = $dest_71 + 8 | 0;
      var $src13_02 = $src13_02 + 8 | 0;
      var $i14_03 = $94;
      __label__ = 29;
      break;
    }
   case 30:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIdE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIdE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $other, $byteOffsetInt, $lengthInt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len1 = __stackBase__;
    var $other_idx_val = HEAP32[$other + 4 >> 2];
    var $1 = __ZNK8JSObject13isArrayBufferEv($other_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 2:
    var $4 = ($byteOffsetInt | 0) < 0 ? 0 : $byteOffsetInt;
    var $other_idx2_val = HEAP32[$other + 32 >> 2];
    var $5 = __ZN8JSObject21arrayBufferByteLengthEv($other_idx2_val);
    if ($4 >>> 0 <= $5 >>> 0 & ($4 & 7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 4:
    if (($lengthInt | 0) < 0) {
      __label__ = 5;
      break;
    } else {
      var $len_0 = $lengthInt;
      __label__ = 7;
      break;
    }
   case 5:
    var $13 = $5 - $4 | 0;
    if (($13 & -8 | 0) == ($13 | 0)) {
      var $len_0 = $13 >>> 3;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 7:
    var $len_0;
    var $19 = $len_0 << 3;
    if ($len_0 >>> 0 > 268435454) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($4 >>> 0 < (2147483647 - $19 | 0) >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 10:
    if (($19 + $4 | 0) >>> 0 > $5 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 12:
    var $30 = __ZN18TypedArrayTemplateIdE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $other, $4, $len_0);
    var $_0 = $30;
    __label__ = 18;
    break;
   case 13:
    var $32 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $other, $len1);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $35 = HEAP32[$len1 >> 2];
    var $36 = __ZN18TypedArrayTemplateIdE28createBufferWithSizeAndCountEP9JSContextj($cx, $35);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $39 = __ZN18TypedArrayTemplateIdE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $36, 0, $35);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $42 = __ZN18TypedArrayTemplateIdE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $39, $other, $35, 0);
    if ($42) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 17:
    var $_0 = $39;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIdE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii["X"] = 1;

function __ZN18TypedArrayTemplateIdE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $thisTypedArrayObj, $ar, $len, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $2 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx_val);
    var $4 = $2 + ($offset << 3) | 0;
    var $ar_idx_val = HEAP32[$ar + 4 >> 2];
    var $5 = __ZNK8JSObject12isDenseArrayEv($ar_idx_val);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    }
   case 2:
    var $7 = __ZN8JSObject30getDenseArrayInitializedLengthEv($ar);
    if ($7 >>> 0 < $len >>> 0) {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($len | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $ar_idx1_val = HEAP32[$ar + 32 >> 2];
    var $11 = __ZN8JSObject21getDenseArrayElementsEv($ar_idx1_val);
    var $dest_01 = $4;
    var $src_02 = $11;
    var $i_03 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_03;
    var $src_02;
    var $dest_01;
    var $13 = $src_02 + 8 | 0;
    var $14 = __ZN18TypedArrayTemplateIdE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $src_02);
    tempDoubleF64[0] = $14, HEAP32[$dest_01 >> 2] = tempDoubleI32[0], HEAP32[$dest_01 + 4 >> 2] = tempDoubleI32[1];
    var $16 = $i_03 + 1 | 0;
    if (($16 | 0) == ($len | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      var $dest_01 = $dest_01 + 8 | 0;
      var $src_02 = $13;
      var $i_03 = $16;
      __label__ = 5;
      break;
    }
   case 6:
    var $dest_1;
    var $i1_0;
    if ($i1_0 >>> 0 < $len >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 7:
    var $19 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($ar, $cx, $i1_0, $v);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = __ZN18TypedArrayTemplateIdE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v);
    tempDoubleF64[0] = $22, HEAP32[$dest_1 >> 2] = tempDoubleI32[0], HEAP32[$dest_1 + 4 >> 2] = tempDoubleI32[1];
    var $i1_0 = $i1_0 + 1 | 0;
    var $dest_1 = $dest_1 + 8 | 0;
    __label__ = 6;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $dval = __stackBase__;
    var $v_idx3 = $v | 0;
    var $v_idx3_val$0 = HEAP32[$v_idx3 >> 2];
    var $v_idx3_val$1 = HEAP32[$v_idx3 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx3_val$0, $v_idx3_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx3_val$0, $v_idx3_val$1);
    var $_0 = $3 | 0;
    __label__ = 9;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($v_idx3_val$0, $v_idx3_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($v);
    var $_0 = $8;
    __label__ = 9;
    break;
   case 5:
    var $10 = __ZNK2JS5Value11isPrimitiveEv($v_idx3_val$0, $v_idx3_val$1);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $12 = __ZNK2JS5Value7isMagicEv($v_idx3_val$0, $v_idx3_val$1);
    if ($12) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $14 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $v, $dval);
    var $15 = (tempDoubleI32[0] = HEAP32[$dval >> 2], tempDoubleI32[1] = HEAP32[$dval + 4 >> 2], tempDoubleF64[0]);
    var $_0 = $15;
    __label__ = 9;
    break;
   case 8:
    var $17 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $_0 = $17;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $self, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $self_idx_val = HEAP32[$self + 24 >> 2];
    var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($self_idx_val);
    var $3 = $1 + ($offset << 3) | 0;
    var $4 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $5 = __ZN2js10TypedArray7getTypeEP8JSObject($self);
    if (($4 | 0) == ($5 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $3;
    var $tarray_idx1_val = HEAP32[$tarray + 24 >> 2];
    var $9 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx1_val);
    var $10 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _llvm_memmove_p0i8_p0i8_i32($8, $9, $10, 1, 0);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 3:
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    var $13 = __ZN9JSContext7malloc_Ej($cx, $12);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx_val);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($13, $16, $17, 1);
    var $18 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    if (($18 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($18 | 0) == 1 || ($18 | 0) == 8) {
      __label__ = 6;
      break;
    } else if (($18 | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($18 | 0) == 3) {
      __label__ = 12;
      break;
    } else if (($18 | 0) == 4) {
      __label__ = 15;
      break;
    } else if (($18 | 0) == 5) {
      __label__ = 18;
      break;
    } else if (($18 | 0) == 6) {
      __label__ = 21;
      break;
    } else if (($18 | 0) == 7) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($19 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i_036 = 0;
      var $src_037 = $13;
      var $dest_038 = $3;
      __label__ = 7;
      break;
    }
   case 6:
    var $21 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($21 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i2_030 = 0;
      var $src1_031 = $13;
      var $dest_132 = $3;
      __label__ = 8;
      break;
    }
   case 7:
    var $dest_038;
    var $src_037;
    var $i_036;
    var $23 = $src_037 + 1 | 0;
    var $26 = $dest_038 + 8 | 0;
    tempDoubleF64[0] = HEAP8[$src_037] << 24 >> 24, HEAP32[$dest_038 >> 2] = tempDoubleI32[0], HEAP32[$dest_038 + 4 >> 2] = tempDoubleI32[1];
    var $27 = $i_036 + 1 | 0;
    var $28 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($27 >>> 0 < $28 >>> 0) {
      var $i_036 = $27;
      var $src_037 = $23;
      var $dest_038 = $26;
      __label__ = 7;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 8:
    var $dest_132;
    var $src1_031;
    var $i2_030;
    var $30 = $src1_031 + 1 | 0;
    var $33 = $dest_132 + 8 | 0;
    tempDoubleF64[0] = HEAPU8[$src1_031] & 255, HEAP32[$dest_132 >> 2] = tempDoubleI32[0], HEAP32[$dest_132 + 4 >> 2] = tempDoubleI32[1];
    var $34 = $i2_030 + 1 | 0;
    var $35 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($34 >>> 0 < $35 >>> 0) {
      var $i2_030 = $34;
      var $src1_031 = $30;
      var $dest_132 = $33;
      __label__ = 8;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 9:
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($38 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $i4_025 = 0;
    var $src3_026 = $13;
    var $dest_227 = $3;
    __label__ = 11;
    break;
   case 11:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    var $42 = $src3_026 + 2 | 0;
    var $45 = $dest_227 + 8 | 0;
    tempDoubleF64[0] = HEAP16[$src3_026 >> 1] << 16 >> 16, HEAP32[$dest_227 >> 2] = tempDoubleI32[0], HEAP32[$dest_227 + 4 >> 2] = tempDoubleI32[1];
    var $46 = $i4_025 + 1 | 0;
    var $47 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($46 >>> 0 < $47 >>> 0) {
      var $i4_025 = $46;
      var $src3_026 = $42;
      var $dest_227 = $45;
      __label__ = 11;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 12:
    var $50 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($50 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i6_020 = 0;
    var $src5_021 = $13;
    var $dest_322 = $3;
    __label__ = 14;
    break;
   case 14:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    var $54 = $src5_021 + 2 | 0;
    var $57 = $dest_322 + 8 | 0;
    tempDoubleF64[0] = HEAPU16[$src5_021 >> 1] & 65535, HEAP32[$dest_322 >> 2] = tempDoubleI32[0], HEAP32[$dest_322 + 4 >> 2] = tempDoubleI32[1];
    var $58 = $i6_020 + 1 | 0;
    var $59 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($58 >>> 0 < $59 >>> 0) {
      var $i6_020 = $58;
      var $src5_021 = $54;
      var $dest_322 = $57;
      __label__ = 14;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    var $62 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($62 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i8_015 = 0;
    var $src7_016 = $13;
    var $dest_417 = $3;
    __label__ = 17;
    break;
   case 17:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    var $66 = $src7_016 + 4 | 0;
    var $69 = $dest_417 + 8 | 0;
    tempDoubleF64[0] = HEAP32[$src7_016 >> 2] | 0, HEAP32[$dest_417 >> 2] = tempDoubleI32[0], HEAP32[$dest_417 + 4 >> 2] = tempDoubleI32[1];
    var $70 = $i8_015 + 1 | 0;
    var $71 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($70 >>> 0 < $71 >>> 0) {
      var $i8_015 = $70;
      var $src7_016 = $66;
      var $dest_417 = $69;
      __label__ = 17;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 18:
    var $74 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($74 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $src9_010 = $13;
    var $i10_011 = 0;
    var $dest_512 = $3;
    __label__ = 20;
    break;
   case 20:
    var $dest_512;
    var $i10_011;
    var $src9_010;
    var $78 = $src9_010 + 4 | 0;
    var $81 = $dest_512 + 8 | 0;
    tempDoubleF64[0] = HEAPU32[$src9_010 >> 2] >>> 0, HEAP32[$dest_512 >> 2] = tempDoubleI32[0], HEAP32[$dest_512 + 4 >> 2] = tempDoubleI32[1];
    var $82 = $i10_011 + 1 | 0;
    var $83 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($82 >>> 0 < $83 >>> 0) {
      var $src9_010 = $78;
      var $i10_011 = $82;
      var $dest_512 = $81;
      __label__ = 20;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 21:
    var $86 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($86 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $dest_65 = $3;
    var $src11_06 = $13;
    var $i12_07 = 0;
    __label__ = 23;
    break;
   case 23:
    var $i12_07;
    var $src11_06;
    var $dest_65;
    var $90 = $src11_06 + 4 | 0;
    var $93 = $dest_65 + 8 | 0;
    tempDoubleF64[0] = HEAPF32[$src11_06 >> 2], HEAP32[$dest_65 >> 2] = tempDoubleI32[0], HEAP32[$dest_65 + 4 >> 2] = tempDoubleI32[1];
    var $94 = $i12_07 + 1 | 0;
    var $95 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($94 >>> 0 < $95 >>> 0) {
      var $dest_65 = $93;
      var $src11_06 = $90;
      var $i12_07 = $94;
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $98 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($98 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $dest_71 = $3;
    var $src13_02 = $13;
    var $i14_03 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $102 = $src13_02 + 8 | 0;
    var $103 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $104 = $dest_71 + 8 | 0;
    tempDoubleF64[0] = $103, HEAP32[$dest_71 >> 2] = tempDoubleI32[0], HEAP32[$dest_71 + 4 >> 2] = tempDoubleI32[1];
    var $105 = $i14_03 + 1 | 0;
    var $106 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($105 >>> 0 < $106 >>> 0) {
      var $dest_71 = $104;
      var $src13_02 = $102;
      var $i14_03 = $105;
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2js10Foreground5free_EPv($13);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIdE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIfE17class_constructorEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 16 | 0;
    var $2 = __ZN18TypedArrayTemplateIfE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $byteOffset = __stackBase__ + 4;
    var $length = __stackBase__ + 8;
    HEAP32[$len >> 2] = 0;
    if (($argc | 0) == 0) {
      var $5 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL13ValueIsLengthP9JSContextRKN2JS5ValueEPj($argv, $len);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $5 = HEAP32[$len >> 2];
    __label__ = 4;
    break;
   case 4:
    var $5;
    var $6 = __ZN18TypedArrayTemplateIfE28createBufferWithSizeAndCountEP9JSContextj($cx, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZN18TypedArrayTemplateIfE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $6, 0, $5);
    var $_0 = $9;
    __label__ = 22;
    break;
   case 6:
    var $argv_idx = $argv | 0;
    var $argv_idx_val$0 = HEAP32[$argv_idx >> 2];
    var $argv_idx_val$1 = HEAP32[$argv_idx + 4 >> 2];
    var $11 = __ZNK2JS5Value8isObjectEv($argv_idx_val$0, $argv_idx_val$1);
    if ($11) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 8:
    var $14 = __ZNK2JS5Value8toObjectEv($argv_idx_val$0, $argv_idx_val$1);
    var $_idx_val = HEAP32[$14 + 4 >> 2];
    var $15 = __Z15js_IsTypedArrayP8JSObject($_idx_val);
    if (($15 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $18 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($14);
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($18);
    var $20 = __ZN18TypedArrayTemplateIfE28createBufferWithSizeAndCountEP9JSContextj($cx, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $23 = __ZN18TypedArrayTemplateIfE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $20, 0, $19);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = __ZN18TypedArrayTemplateIfE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $23, $18, 0);
    if ($26) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 12:
    var $_0 = $23;
    __label__ = 22;
    break;
   case 13:
    HEAP32[$byteOffset >> 2] = -1;
    HEAP32[$length >> 2] = -1;
    if ($argc >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      var $48 = -1;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 14:
    var $31 = $argv + 8 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $byteOffset);
    if ($32) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 15:
    var $34 = HEAPU32[$byteOffset >> 2];
    if (($34 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 4, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str163973 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 17:
    if ($argc >>> 0 > 2) {
      __label__ = 18;
      break;
    } else {
      var $48 = $34;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 18:
    var $40 = $argv + 16 | 0;
    var $41 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $40, $length);
    if ($41) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 19:
    var $43 = HEAPU32[$length >> 2];
    if (($43 | 0) < 0) {
      __label__ = 20;
      break;
    } else {
      var $48 = $34;
      var $47 = $43;
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 4, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str173974 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 21:
    var $47;
    var $48;
    var $49 = __ZN18TypedArrayTemplateIfE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $14, $48, $47);
    var $_0 = $49;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIfE6createEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIfE28createBufferWithSizeAndCountEP9JSContextj($cx, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 > 536870910) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 4, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str183975 | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $4 = $count << 2;
    var $5 = __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $4);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $bufobj, $byteOffset, $len) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981($cx, __ZN2js10TypedArray11slowClassesE + 1392 | 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAPU32[__ZN2js10TypedArray11slowClassesE + 1396 >> 2] >>> 24;
    var $11 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($6, $11);
    __ZN2JSL10Int32ValueEi3996($1, 6);
    var $_idx4 = $1 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 3, $_idx4_val$0, $_idx4_val$1);
    __ZN2JSL11ObjectValueER8JSObject3997($2, $bufobj);
    var $_idx3 = $2 | 0;
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 4, $_idx3_val$0, $_idx3_val$1);
    var $bufobj_idx_val = HEAP32[$bufobj + 32 >> 2];
    var $14 = __ZN8JSObject21arrayBufferDataOffsetEv($bufobj_idx_val);
    var $15 = $14 + $byteOffset | 0;
    __ZN8JSObject10setPrivateEPv($6, $15);
    __ZN2JSL10Int32ValueEi3996($3, $len);
    var $_idx2 = $3 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 0, $_idx2_val$0, $_idx2_val$1);
    __ZN2JSL10Int32ValueEi3996($4, $byteOffset);
    var $_idx1 = $4 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 1, $_idx1_val$0, $_idx1_val$1);
    var $16 = $len << 2;
    __ZN2JSL10Int32ValueEi3996($5, $16);
    var $_idx = $5 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 2, $_idx_val$0, $_idx_val$1);
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    __ZN8JSObject8setClassEPN2js5ClassE($6, __ZN2js10TypedArray11fastClassesE + 1392 | 0);
    var $17 = $6 + 8 | 0;
    var $19 = HEAP32[$17 >> 2] | 4;
    HEAP32[$17 >> 2] = $19;
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIfE16createTypedArrayEP9JSContextP8JSObjectjj["X"] = 1;

function __ZN18TypedArrayTemplateIfE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $thisTypedArrayObj, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
    var $3 = __ZN2js10TypedArray9getBufferEP8JSObject($1);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZN18TypedArrayTemplateIfE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $1, $tarray, $offset);
    var $_0 = $6;
    __label__ = 30;
    break;
   case 3:
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $8 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx_val);
    var $10 = $8 + ($offset << 2) | 0;
    var $11 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $12 = __ZN2js10TypedArray7getTypeEP8JSObject($1);
    if (($11 | 0) == ($12 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = $10;
    var $tarray_idx8_val = HEAP32[$tarray + 24 >> 2];
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx8_val);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($15, $16, $17, 1);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($11 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($11 | 0) == 1 || ($11 | 0) == 8) {
      __label__ = 9;
      break;
    } else if (($11 | 0) == 2) {
      __label__ = 12;
      break;
    } else if (($11 | 0) == 3) {
      __label__ = 15;
      break;
    } else if (($11 | 0) == 4) {
      __label__ = 18;
      break;
    } else if (($11 | 0) == 5) {
      __label__ = 21;
      break;
    } else if (($11 | 0) == 6) {
      __label__ = 24;
      break;
    } else if (($11 | 0) == 7) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 6:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $tarray_idx7_val = HEAP32[$tarray + 24 >> 2];
    var $22 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx7_val);
    var $lftr_limit45 = $22 + $19 | 0;
    var $src_036 = $22;
    var $dest_037 = $10;
    __label__ = 8;
    break;
   case 8:
    var $dest_037;
    var $src_036;
    var $24 = $src_036 + 1 | 0;
    HEAPF32[$dest_037 >> 2] = HEAP8[$src_036] << 24 >> 24;
    if (($24 | 0) == ($lftr_limit45 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src_036 = $24;
      var $dest_037 = $dest_037 + 4 | 0;
      __label__ = 8;
      break;
    }
   case 9:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $tarray_idx6_val = HEAP32[$tarray + 24 >> 2];
    var $30 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx6_val);
    var $lftr_limit = $30 + $19 | 0;
    var $src1_031 = $30;
    var $dest_132 = $10;
    __label__ = 11;
    break;
   case 11:
    var $dest_132;
    var $src1_031;
    var $32 = $src1_031 + 1 | 0;
    HEAPF32[$dest_132 >> 2] = HEAPU8[$src1_031] & 255;
    if (($32 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src1_031 = $32;
      var $dest_132 = $dest_132 + 4 | 0;
      __label__ = 11;
      break;
    }
   case 12:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $tarray_idx5_val = HEAP32[$tarray + 24 >> 2];
    var $38 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx5_val);
    var $i4_025 = 0;
    var $src3_026 = $38;
    var $dest_227 = $10;
    __label__ = 14;
    break;
   case 14:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    HEAPF32[$dest_227 >> 2] = HEAP16[$src3_026 >> 1] << 16 >> 16;
    var $45 = $i4_025 + 1 | 0;
    if (($45 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i4_025 = $45;
      var $src3_026 = $src3_026 + 2 | 0;
      var $dest_227 = $dest_227 + 4 | 0;
      __label__ = 14;
      break;
    }
   case 15:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $tarray_idx4_val = HEAP32[$tarray + 24 >> 2];
    var $48 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx4_val);
    var $i6_020 = 0;
    var $src5_021 = $48;
    var $dest_322 = $10;
    __label__ = 17;
    break;
   case 17:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    HEAPF32[$dest_322 >> 2] = HEAPU16[$src5_021 >> 1] & 65535;
    var $55 = $i6_020 + 1 | 0;
    if (($55 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i6_020 = $55;
      var $src5_021 = $src5_021 + 2 | 0;
      var $dest_322 = $dest_322 + 4 | 0;
      __label__ = 17;
      break;
    }
   case 18:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $tarray_idx3_val = HEAP32[$tarray + 24 >> 2];
    var $58 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx3_val);
    var $i8_015 = 0;
    var $src7_016 = $58;
    var $dest_417 = $10;
    __label__ = 20;
    break;
   case 20:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    HEAPF32[$dest_417 >> 2] = HEAP32[$src7_016 >> 2] | 0;
    var $65 = $i8_015 + 1 | 0;
    if (($65 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i8_015 = $65;
      var $src7_016 = $src7_016 + 4 | 0;
      var $dest_417 = $dest_417 + 4 | 0;
      __label__ = 20;
      break;
    }
   case 21:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $tarray_idx2_val = HEAP32[$tarray + 24 >> 2];
    var $68 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx2_val);
    var $i10_010 = 0;
    var $src9_011 = $68;
    var $dest_512 = $10;
    __label__ = 23;
    break;
   case 23:
    var $dest_512;
    var $src9_011;
    var $i10_010;
    HEAPF32[$dest_512 >> 2] = HEAPU32[$src9_011 >> 2] >>> 0;
    var $75 = $i10_010 + 1 | 0;
    if (($75 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i10_010 = $75;
      var $src9_011 = $src9_011 + 4 | 0;
      var $dest_512 = $dest_512 + 4 | 0;
      __label__ = 23;
      break;
    }
   case 24:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $tarray_idx1_val = HEAP32[$tarray + 24 >> 2];
    var $78 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx1_val);
    var $src11_05 = $78;
    var $dest_66 = $10;
    var $i12_07 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i12_07;
    var $dest_66;
    var $src11_05;
    var $82 = HEAPF32[$src11_05 >> 2];
    HEAPF32[$dest_66 >> 2] = $82;
    var $84 = $i12_07 + 1 | 0;
    if (($84 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src11_05 = $src11_05 + 4 | 0;
      var $dest_66 = $dest_66 + 4 | 0;
      var $i12_07 = $84;
      __label__ = 26;
      break;
    }
   case 27:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    var $87 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx_val);
    var $dest_71 = $10;
    var $src13_02 = $87;
    var $i14_03 = 0;
    __label__ = 29;
    break;
   case 29:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $91 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    HEAPF32[$dest_71 >> 2] = $91;
    var $94 = $i14_03 + 1 | 0;
    if (($94 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $dest_71 = $dest_71 + 4 | 0;
      var $src13_02 = $src13_02 + 8 | 0;
      var $i14_03 = $94;
      __label__ = 29;
      break;
    }
   case 30:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIfE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIfE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $other, $byteOffsetInt, $lengthInt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len1 = __stackBase__;
    var $other_idx_val = HEAP32[$other + 4 >> 2];
    var $1 = __ZNK8JSObject13isArrayBufferEv($other_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 2:
    var $4 = ($byteOffsetInt | 0) < 0 ? 0 : $byteOffsetInt;
    var $other_idx2_val = HEAP32[$other + 32 >> 2];
    var $5 = __ZN8JSObject21arrayBufferByteLengthEv($other_idx2_val);
    if ($4 >>> 0 <= $5 >>> 0 & ($4 & 3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 4:
    if (($lengthInt | 0) < 0) {
      __label__ = 5;
      break;
    } else {
      var $len_0 = $lengthInt;
      __label__ = 7;
      break;
    }
   case 5:
    var $13 = $5 - $4 | 0;
    if (($13 & -4 | 0) == ($13 | 0)) {
      var $len_0 = $13 >>> 2;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 7:
    var $len_0;
    var $19 = $len_0 << 2;
    if ($len_0 >>> 0 > 536870910) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($4 >>> 0 < (2147483647 - $19 | 0) >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 10:
    if (($19 + $4 | 0) >>> 0 > $5 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 12:
    var $30 = __ZN18TypedArrayTemplateIfE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $other, $4, $len_0);
    var $_0 = $30;
    __label__ = 18;
    break;
   case 13:
    var $32 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $other, $len1);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $35 = HEAP32[$len1 >> 2];
    var $36 = __ZN18TypedArrayTemplateIfE28createBufferWithSizeAndCountEP9JSContextj($cx, $35);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $39 = __ZN18TypedArrayTemplateIfE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $36, 0, $35);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $42 = __ZN18TypedArrayTemplateIfE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $39, $other, $35, 0);
    if ($42) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 17:
    var $_0 = $39;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIfE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii["X"] = 1;

function __ZN18TypedArrayTemplateIfE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $thisTypedArrayObj, $ar, $len, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $2 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx_val);
    var $4 = $2 + ($offset << 2) | 0;
    var $ar_idx_val = HEAP32[$ar + 4 >> 2];
    var $5 = __ZNK8JSObject12isDenseArrayEv($ar_idx_val);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    }
   case 2:
    var $7 = __ZN8JSObject30getDenseArrayInitializedLengthEv($ar);
    if ($7 >>> 0 < $len >>> 0) {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($len | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $ar_idx1_val = HEAP32[$ar + 32 >> 2];
    var $11 = __ZN8JSObject21getDenseArrayElementsEv($ar_idx1_val);
    var $dest_01 = $4;
    var $src_02 = $11;
    var $i_03 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_03;
    var $src_02;
    var $dest_01;
    var $13 = $src_02 + 8 | 0;
    var $14 = __ZN18TypedArrayTemplateIfE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $src_02);
    HEAPF32[$dest_01 >> 2] = $14;
    var $16 = $i_03 + 1 | 0;
    if (($16 | 0) == ($len | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      var $dest_01 = $dest_01 + 4 | 0;
      var $src_02 = $13;
      var $i_03 = $16;
      __label__ = 5;
      break;
    }
   case 6:
    var $dest_1;
    var $i1_0;
    if ($i1_0 >>> 0 < $len >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 7:
    var $19 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($ar, $cx, $i1_0, $v);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = __ZN18TypedArrayTemplateIfE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v);
    HEAPF32[$dest_1 >> 2] = $22;
    var $i1_0 = $i1_0 + 1 | 0;
    var $dest_1 = $dest_1 + 4 | 0;
    __label__ = 6;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $dval = __stackBase__;
    var $v_idx3 = $v | 0;
    var $v_idx3_val$0 = HEAP32[$v_idx3 >> 2];
    var $v_idx3_val$1 = HEAP32[$v_idx3 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx3_val$0, $v_idx3_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx3_val$0, $v_idx3_val$1);
    var $_0 = $3 | 0;
    __label__ = 9;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($v_idx3_val$0, $v_idx3_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($v);
    var $_0 = $8;
    __label__ = 9;
    break;
   case 5:
    var $11 = __ZNK2JS5Value11isPrimitiveEv($v_idx3_val$0, $v_idx3_val$1);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $13 = __ZNK2JS5Value7isMagicEv($v_idx3_val$0, $v_idx3_val$1);
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $15 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $v, $dval);
    var $16 = (tempDoubleI32[0] = HEAP32[$dval >> 2], tempDoubleI32[1] = HEAP32[$dval + 4 >> 2], tempDoubleF64[0]);
    var $_0 = $16;
    __label__ = 9;
    break;
   case 8:
    var $19 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $_0 = $19;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $self, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $self_idx_val = HEAP32[$self + 24 >> 2];
    var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($self_idx_val);
    var $3 = $1 + ($offset << 2) | 0;
    var $4 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $5 = __ZN2js10TypedArray7getTypeEP8JSObject($self);
    if (($4 | 0) == ($5 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $3;
    var $tarray_idx1_val = HEAP32[$tarray + 24 >> 2];
    var $9 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx1_val);
    var $10 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _llvm_memmove_p0i8_p0i8_i32($8, $9, $10, 1, 0);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 3:
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    var $13 = __ZN9JSContext7malloc_Ej($cx, $12);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx_val);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($13, $16, $17, 1);
    var $18 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    if (($18 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($18 | 0) == 1 || ($18 | 0) == 8) {
      __label__ = 6;
      break;
    } else if (($18 | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($18 | 0) == 3) {
      __label__ = 12;
      break;
    } else if (($18 | 0) == 4) {
      __label__ = 15;
      break;
    } else if (($18 | 0) == 5) {
      __label__ = 18;
      break;
    } else if (($18 | 0) == 6) {
      __label__ = 21;
      break;
    } else if (($18 | 0) == 7) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($19 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i_036 = 0;
      var $src_037 = $13;
      var $dest_038 = $3;
      __label__ = 7;
      break;
    }
   case 6:
    var $21 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($21 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i2_030 = 0;
      var $src1_031 = $13;
      var $dest_132 = $3;
      __label__ = 8;
      break;
    }
   case 7:
    var $dest_038;
    var $src_037;
    var $i_036;
    var $23 = $src_037 + 1 | 0;
    var $26 = $dest_038 + 4 | 0;
    HEAPF32[$dest_038 >> 2] = HEAP8[$src_037] << 24 >> 24;
    var $27 = $i_036 + 1 | 0;
    var $28 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($27 >>> 0 < $28 >>> 0) {
      var $i_036 = $27;
      var $src_037 = $23;
      var $dest_038 = $26;
      __label__ = 7;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 8:
    var $dest_132;
    var $src1_031;
    var $i2_030;
    var $30 = $src1_031 + 1 | 0;
    var $33 = $dest_132 + 4 | 0;
    HEAPF32[$dest_132 >> 2] = HEAPU8[$src1_031] & 255;
    var $34 = $i2_030 + 1 | 0;
    var $35 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($34 >>> 0 < $35 >>> 0) {
      var $i2_030 = $34;
      var $src1_031 = $30;
      var $dest_132 = $33;
      __label__ = 8;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 9:
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($38 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $i4_025 = 0;
    var $src3_026 = $13;
    var $dest_227 = $3;
    __label__ = 11;
    break;
   case 11:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    var $42 = $src3_026 + 2 | 0;
    var $45 = $dest_227 + 4 | 0;
    HEAPF32[$dest_227 >> 2] = HEAP16[$src3_026 >> 1] << 16 >> 16;
    var $46 = $i4_025 + 1 | 0;
    var $47 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($46 >>> 0 < $47 >>> 0) {
      var $i4_025 = $46;
      var $src3_026 = $42;
      var $dest_227 = $45;
      __label__ = 11;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 12:
    var $50 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($50 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i6_020 = 0;
    var $src5_021 = $13;
    var $dest_322 = $3;
    __label__ = 14;
    break;
   case 14:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    var $54 = $src5_021 + 2 | 0;
    var $57 = $dest_322 + 4 | 0;
    HEAPF32[$dest_322 >> 2] = HEAPU16[$src5_021 >> 1] & 65535;
    var $58 = $i6_020 + 1 | 0;
    var $59 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($58 >>> 0 < $59 >>> 0) {
      var $i6_020 = $58;
      var $src5_021 = $54;
      var $dest_322 = $57;
      __label__ = 14;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    var $62 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($62 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i8_015 = 0;
    var $src7_016 = $13;
    var $dest_417 = $3;
    __label__ = 17;
    break;
   case 17:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    var $66 = $src7_016 + 4 | 0;
    var $69 = $dest_417 + 4 | 0;
    HEAPF32[$dest_417 >> 2] = HEAP32[$src7_016 >> 2] | 0;
    var $70 = $i8_015 + 1 | 0;
    var $71 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($70 >>> 0 < $71 >>> 0) {
      var $i8_015 = $70;
      var $src7_016 = $66;
      var $dest_417 = $69;
      __label__ = 17;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 18:
    var $74 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($74 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $src9_010 = $13;
    var $i10_011 = 0;
    var $dest_512 = $3;
    __label__ = 20;
    break;
   case 20:
    var $dest_512;
    var $i10_011;
    var $src9_010;
    var $78 = $src9_010 + 4 | 0;
    var $81 = $dest_512 + 4 | 0;
    HEAPF32[$dest_512 >> 2] = HEAPU32[$src9_010 >> 2] >>> 0;
    var $82 = $i10_011 + 1 | 0;
    var $83 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($82 >>> 0 < $83 >>> 0) {
      var $src9_010 = $78;
      var $i10_011 = $82;
      var $dest_512 = $81;
      __label__ = 20;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 21:
    var $86 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($86 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $dest_65 = $3;
    var $src11_06 = $13;
    var $i12_07 = 0;
    __label__ = 23;
    break;
   case 23:
    var $i12_07;
    var $src11_06;
    var $dest_65;
    var $90 = $src11_06 + 4 | 0;
    var $91 = HEAPF32[$src11_06 >> 2];
    var $92 = $dest_65 + 4 | 0;
    HEAPF32[$dest_65 >> 2] = $91;
    var $93 = $i12_07 + 1 | 0;
    var $94 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($93 >>> 0 < $94 >>> 0) {
      var $dest_65 = $92;
      var $src11_06 = $90;
      var $i12_07 = $93;
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $97 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($97 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $dest_71 = $3;
    var $src13_02 = $13;
    var $i14_03 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $101 = $src13_02 + 8 | 0;
    var $102 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $104 = $dest_71 + 4 | 0;
    HEAPF32[$dest_71 >> 2] = $102;
    var $105 = $i14_03 + 1 | 0;
    var $106 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($105 >>> 0 < $106 >>> 0) {
      var $dest_71 = $104;
      var $src13_02 = $101;
      var $i14_03 = $105;
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2js10Foreground5free_EPv($13);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIfE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIjE17class_constructorEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 16 | 0;
    var $2 = __ZN18TypedArrayTemplateIjE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $byteOffset = __stackBase__ + 4;
    var $length = __stackBase__ + 8;
    HEAP32[$len >> 2] = 0;
    if (($argc | 0) == 0) {
      var $5 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL13ValueIsLengthP9JSContextRKN2JS5ValueEPj($argv, $len);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $5 = HEAP32[$len >> 2];
    __label__ = 4;
    break;
   case 4:
    var $5;
    var $6 = __ZN18TypedArrayTemplateIjE28createBufferWithSizeAndCountEP9JSContextj($cx, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZN18TypedArrayTemplateIjE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $6, 0, $5);
    var $_0 = $9;
    __label__ = 22;
    break;
   case 6:
    var $argv_idx = $argv | 0;
    var $argv_idx_val$0 = HEAP32[$argv_idx >> 2];
    var $argv_idx_val$1 = HEAP32[$argv_idx + 4 >> 2];
    var $11 = __ZNK2JS5Value8isObjectEv($argv_idx_val$0, $argv_idx_val$1);
    if ($11) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 8:
    var $14 = __ZNK2JS5Value8toObjectEv($argv_idx_val$0, $argv_idx_val$1);
    var $_idx_val = HEAP32[$14 + 4 >> 2];
    var $15 = __Z15js_IsTypedArrayP8JSObject($_idx_val);
    if (($15 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $18 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($14);
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($18);
    var $20 = __ZN18TypedArrayTemplateIjE28createBufferWithSizeAndCountEP9JSContextj($cx, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $23 = __ZN18TypedArrayTemplateIjE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $20, 0, $19);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = __ZN18TypedArrayTemplateIjE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $23, $18, 0);
    if ($26) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 12:
    var $_0 = $23;
    __label__ = 22;
    break;
   case 13:
    HEAP32[$byteOffset >> 2] = -1;
    HEAP32[$length >> 2] = -1;
    if ($argc >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      var $48 = -1;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 14:
    var $31 = $argv + 8 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $byteOffset);
    if ($32) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 15:
    var $34 = HEAPU32[$byteOffset >> 2];
    if (($34 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 4, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str163973 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 17:
    if ($argc >>> 0 > 2) {
      __label__ = 18;
      break;
    } else {
      var $48 = $34;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 18:
    var $40 = $argv + 16 | 0;
    var $41 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $40, $length);
    if ($41) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 19:
    var $43 = HEAPU32[$length >> 2];
    if (($43 | 0) < 0) {
      __label__ = 20;
      break;
    } else {
      var $48 = $34;
      var $47 = $43;
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 4, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str173974 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 21:
    var $47;
    var $48;
    var $49 = __ZN18TypedArrayTemplateIjE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $14, $48, $47);
    var $_0 = $49;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIjE6createEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIjE28createBufferWithSizeAndCountEP9JSContextj($cx, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 > 536870910) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 4, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str183975 | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $4 = $count << 2;
    var $5 = __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $4);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $bufobj, $byteOffset, $len) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981($cx, __ZN2js10TypedArray11slowClassesE + 1160 | 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAPU32[__ZN2js10TypedArray11slowClassesE + 1164 >> 2] >>> 24;
    var $11 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($6, $11);
    __ZN2JSL10Int32ValueEi3996($1, 5);
    var $_idx4 = $1 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 3, $_idx4_val$0, $_idx4_val$1);
    __ZN2JSL11ObjectValueER8JSObject3997($2, $bufobj);
    var $_idx3 = $2 | 0;
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 4, $_idx3_val$0, $_idx3_val$1);
    var $bufobj_idx_val = HEAP32[$bufobj + 32 >> 2];
    var $14 = __ZN8JSObject21arrayBufferDataOffsetEv($bufobj_idx_val);
    var $15 = $14 + $byteOffset | 0;
    __ZN8JSObject10setPrivateEPv($6, $15);
    __ZN2JSL10Int32ValueEi3996($3, $len);
    var $_idx2 = $3 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 0, $_idx2_val$0, $_idx2_val$1);
    __ZN2JSL10Int32ValueEi3996($4, $byteOffset);
    var $_idx1 = $4 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 1, $_idx1_val$0, $_idx1_val$1);
    var $16 = $len << 2;
    __ZN2JSL10Int32ValueEi3996($5, $16);
    var $_idx = $5 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 2, $_idx_val$0, $_idx_val$1);
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    __ZN8JSObject8setClassEPN2js5ClassE($6, __ZN2js10TypedArray11fastClassesE + 1160 | 0);
    var $17 = $6 + 8 | 0;
    var $19 = HEAP32[$17 >> 2] | 4;
    HEAP32[$17 >> 2] = $19;
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIjE16createTypedArrayEP9JSContextP8JSObjectjj["X"] = 1;

function __ZN18TypedArrayTemplateIjE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $thisTypedArrayObj, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
    var $3 = __ZN2js10TypedArray9getBufferEP8JSObject($1);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZN18TypedArrayTemplateIjE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $1, $tarray, $offset);
    var $_0 = $6;
    __label__ = 30;
    break;
   case 3:
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $8 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx_val);
    var $10 = $8 + ($offset << 2) | 0;
    var $11 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $12 = __ZN2js10TypedArray7getTypeEP8JSObject($1);
    if (($11 | 0) == ($12 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = $10;
    var $tarray_idx8_val = HEAP32[$tarray + 24 >> 2];
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx8_val);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($15, $16, $17, 1);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($11 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($11 | 0) == 1 || ($11 | 0) == 8) {
      __label__ = 9;
      break;
    } else if (($11 | 0) == 2) {
      __label__ = 12;
      break;
    } else if (($11 | 0) == 3) {
      __label__ = 15;
      break;
    } else if (($11 | 0) == 4) {
      __label__ = 18;
      break;
    } else if (($11 | 0) == 5) {
      __label__ = 21;
      break;
    } else if (($11 | 0) == 6) {
      __label__ = 24;
      break;
    } else if (($11 | 0) == 7) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 6:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $tarray_idx7_val = HEAP32[$tarray + 24 >> 2];
    var $22 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx7_val);
    var $lftr_limit45 = $22 + $19 | 0;
    var $src_036 = $22;
    var $dest_037 = $10;
    __label__ = 8;
    break;
   case 8:
    var $dest_037;
    var $src_036;
    var $24 = $src_036 + 1 | 0;
    HEAP32[$dest_037 >> 2] = HEAP8[$src_036] << 24 >> 24;
    if (($24 | 0) == ($lftr_limit45 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src_036 = $24;
      var $dest_037 = $dest_037 + 4 | 0;
      __label__ = 8;
      break;
    }
   case 9:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $tarray_idx6_val = HEAP32[$tarray + 24 >> 2];
    var $30 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx6_val);
    var $lftr_limit = $30 + $19 | 0;
    var $src1_031 = $30;
    var $dest_132 = $10;
    __label__ = 11;
    break;
   case 11:
    var $dest_132;
    var $src1_031;
    var $32 = $src1_031 + 1 | 0;
    HEAP32[$dest_132 >> 2] = HEAPU8[$src1_031] & 255;
    if (($32 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src1_031 = $32;
      var $dest_132 = $dest_132 + 4 | 0;
      __label__ = 11;
      break;
    }
   case 12:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $tarray_idx5_val = HEAP32[$tarray + 24 >> 2];
    var $38 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx5_val);
    var $i4_025 = 0;
    var $src3_026 = $38;
    var $dest_227 = $10;
    __label__ = 14;
    break;
   case 14:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    HEAP32[$dest_227 >> 2] = HEAP16[$src3_026 >> 1] << 16 >> 16;
    var $45 = $i4_025 + 1 | 0;
    if (($45 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i4_025 = $45;
      var $src3_026 = $src3_026 + 2 | 0;
      var $dest_227 = $dest_227 + 4 | 0;
      __label__ = 14;
      break;
    }
   case 15:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $tarray_idx4_val = HEAP32[$tarray + 24 >> 2];
    var $48 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx4_val);
    var $i6_020 = 0;
    var $src5_021 = $48;
    var $dest_322 = $10;
    __label__ = 17;
    break;
   case 17:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    HEAP32[$dest_322 >> 2] = HEAPU16[$src5_021 >> 1] & 65535;
    var $55 = $i6_020 + 1 | 0;
    if (($55 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i6_020 = $55;
      var $src5_021 = $src5_021 + 2 | 0;
      var $dest_322 = $dest_322 + 4 | 0;
      __label__ = 17;
      break;
    }
   case 18:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $tarray_idx3_val = HEAP32[$tarray + 24 >> 2];
    var $58 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx3_val);
    var $i8_015 = 0;
    var $src7_016 = $58;
    var $dest_417 = $10;
    __label__ = 20;
    break;
   case 20:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    var $62 = HEAP32[$src7_016 >> 2];
    HEAP32[$dest_417 >> 2] = $62;
    var $64 = $i8_015 + 1 | 0;
    if (($64 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i8_015 = $64;
      var $src7_016 = $src7_016 + 4 | 0;
      var $dest_417 = $dest_417 + 4 | 0;
      __label__ = 20;
      break;
    }
   case 21:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $tarray_idx2_val = HEAP32[$tarray + 24 >> 2];
    var $67 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx2_val);
    var $i10_010 = 0;
    var $src9_011 = $67;
    var $dest_512 = $10;
    __label__ = 23;
    break;
   case 23:
    var $dest_512;
    var $src9_011;
    var $i10_010;
    var $71 = HEAP32[$src9_011 >> 2];
    HEAP32[$dest_512 >> 2] = $71;
    var $73 = $i10_010 + 1 | 0;
    if (($73 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i10_010 = $73;
      var $src9_011 = $src9_011 + 4 | 0;
      var $dest_512 = $dest_512 + 4 | 0;
      __label__ = 23;
      break;
    }
   case 24:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $tarray_idx1_val = HEAP32[$tarray + 24 >> 2];
    var $76 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx1_val);
    var $src11_05 = $76;
    var $dest_66 = $10;
    var $i12_07 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i12_07;
    var $dest_66;
    var $src11_05;
    var $79 = $src11_05 + 4 | 0;
    var $80 = HEAPF32[$src11_05 >> 2];
    var $81 = $80 >= 0 ? Math.floor($80) : Math.ceil($80);
    HEAP32[$dest_66 >> 2] = $81;
    var $83 = $i12_07 + 1 | 0;
    if (($83 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src11_05 = $79;
      var $dest_66 = $dest_66 + 4 | 0;
      var $i12_07 = $83;
      __label__ = 26;
      break;
    }
   case 27:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    var $86 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx_val);
    var $dest_71 = $10;
    var $src13_02 = $86;
    var $i14_03 = 0;
    __label__ = 29;
    break;
   case 29:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $89 = $src13_02 + 8 | 0;
    var $90 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $91 = $90 >= 0 ? Math.floor($90) : Math.ceil($90);
    HEAP32[$dest_71 >> 2] = $91;
    var $93 = $i14_03 + 1 | 0;
    if (($93 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $dest_71 = $dest_71 + 4 | 0;
      var $src13_02 = $89;
      var $i14_03 = $93;
      __label__ = 29;
      break;
    }
   case 30:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIjE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIjE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $other, $byteOffsetInt, $lengthInt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len1 = __stackBase__;
    var $other_idx_val = HEAP32[$other + 4 >> 2];
    var $1 = __ZNK8JSObject13isArrayBufferEv($other_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 2:
    var $4 = ($byteOffsetInt | 0) < 0 ? 0 : $byteOffsetInt;
    var $other_idx2_val = HEAP32[$other + 32 >> 2];
    var $5 = __ZN8JSObject21arrayBufferByteLengthEv($other_idx2_val);
    if ($4 >>> 0 <= $5 >>> 0 & ($4 & 3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 4:
    if (($lengthInt | 0) < 0) {
      __label__ = 5;
      break;
    } else {
      var $len_0 = $lengthInt;
      __label__ = 7;
      break;
    }
   case 5:
    var $13 = $5 - $4 | 0;
    if (($13 & -4 | 0) == ($13 | 0)) {
      var $len_0 = $13 >>> 2;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 7:
    var $len_0;
    var $19 = $len_0 << 2;
    if ($len_0 >>> 0 > 536870910) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($4 >>> 0 < (2147483647 - $19 | 0) >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 10:
    if (($19 + $4 | 0) >>> 0 > $5 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 12:
    var $30 = __ZN18TypedArrayTemplateIjE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $other, $4, $len_0);
    var $_0 = $30;
    __label__ = 18;
    break;
   case 13:
    var $32 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $other, $len1);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $35 = HEAP32[$len1 >> 2];
    var $36 = __ZN18TypedArrayTemplateIjE28createBufferWithSizeAndCountEP9JSContextj($cx, $35);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $39 = __ZN18TypedArrayTemplateIjE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $36, 0, $35);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $42 = __ZN18TypedArrayTemplateIjE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $39, $other, $35, 0);
    if ($42) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 17:
    var $_0 = $39;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIjE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii["X"] = 1;

function __ZN18TypedArrayTemplateIjE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $thisTypedArrayObj, $ar, $len, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $2 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx_val);
    var $4 = $2 + ($offset << 2) | 0;
    var $ar_idx_val = HEAP32[$ar + 4 >> 2];
    var $5 = __ZNK8JSObject12isDenseArrayEv($ar_idx_val);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    }
   case 2:
    var $7 = __ZN8JSObject30getDenseArrayInitializedLengthEv($ar);
    if ($7 >>> 0 < $len >>> 0) {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($len | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $ar_idx1_val = HEAP32[$ar + 32 >> 2];
    var $11 = __ZN8JSObject21getDenseArrayElementsEv($ar_idx1_val);
    var $dest_01 = $4;
    var $src_02 = $11;
    var $i_03 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_03;
    var $src_02;
    var $dest_01;
    var $13 = $src_02 + 8 | 0;
    var $14 = __ZN18TypedArrayTemplateIjE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $src_02);
    HEAP32[$dest_01 >> 2] = $14;
    var $16 = $i_03 + 1 | 0;
    if (($16 | 0) == ($len | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      var $dest_01 = $dest_01 + 4 | 0;
      var $src_02 = $13;
      var $i_03 = $16;
      __label__ = 5;
      break;
    }
   case 6:
    var $dest_1;
    var $i1_0;
    if ($i1_0 >>> 0 < $len >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 7:
    var $19 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($ar, $cx, $i1_0, $v);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = __ZN18TypedArrayTemplateIjE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v);
    HEAP32[$dest_1 >> 2] = $22;
    var $i1_0 = $i1_0 + 1 | 0;
    var $dest_1 = $dest_1 + 4 | 0;
    __label__ = 6;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $dval = __stackBase__;
    var $v_idx3 = $v | 0;
    var $v_idx3_val$0 = HEAP32[$v_idx3 >> 2];
    var $v_idx3_val$1 = HEAP32[$v_idx3 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx3_val$0, $v_idx3_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx3_val$0, $v_idx3_val$1);
    var $_0 = $3;
    __label__ = 9;
    break;
   case 3:
    var $5 = __ZNK2JS5Value8isDoubleEv($v_idx3_val$0, $v_idx3_val$1);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $7 = __ZNK2JS5Value8toDoubleEv($v);
    var $8 = __ZL15JSDOUBLE_IS_NaNd3989($7);
    if (($8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = __Z21js_DoubleToECMAUint32d($7);
    var $_0 = $11;
    __label__ = 9;
    break;
   case 6:
    var $13 = __ZNK2JS5Value11isPrimitiveEv($v_idx3_val$0, $v_idx3_val$1);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $15 = __ZNK2JS5Value7isMagicEv($v_idx3_val$0, $v_idx3_val$1);
    if ($15) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $17 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $v, $dval);
    var $18 = (tempDoubleI32[0] = HEAP32[$dval >> 2], tempDoubleI32[1] = HEAP32[$dval + 4 >> 2], tempDoubleF64[0]);
    var $19 = $18 >= 0 ? Math.floor($18) : Math.ceil($18);
    var $_0 = $19;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $self, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $self_idx_val = HEAP32[$self + 24 >> 2];
    var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($self_idx_val);
    var $3 = $1 + ($offset << 2) | 0;
    var $4 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $5 = __ZN2js10TypedArray7getTypeEP8JSObject($self);
    if (($4 | 0) == ($5 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $3;
    var $tarray_idx1_val = HEAP32[$tarray + 24 >> 2];
    var $9 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx1_val);
    var $10 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _llvm_memmove_p0i8_p0i8_i32($8, $9, $10, 1, 0);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 3:
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    var $13 = __ZN9JSContext7malloc_Ej($cx, $12);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx_val);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($13, $16, $17, 1);
    var $18 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    if (($18 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($18 | 0) == 1 || ($18 | 0) == 8) {
      __label__ = 6;
      break;
    } else if (($18 | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($18 | 0) == 3) {
      __label__ = 12;
      break;
    } else if (($18 | 0) == 4) {
      __label__ = 15;
      break;
    } else if (($18 | 0) == 5) {
      __label__ = 18;
      break;
    } else if (($18 | 0) == 6) {
      __label__ = 21;
      break;
    } else if (($18 | 0) == 7) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($19 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i_036 = 0;
      var $src_037 = $13;
      var $dest_038 = $3;
      __label__ = 7;
      break;
    }
   case 6:
    var $21 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($21 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i2_030 = 0;
      var $src1_031 = $13;
      var $dest_132 = $3;
      __label__ = 8;
      break;
    }
   case 7:
    var $dest_038;
    var $src_037;
    var $i_036;
    var $23 = $src_037 + 1 | 0;
    var $26 = $dest_038 + 4 | 0;
    HEAP32[$dest_038 >> 2] = HEAP8[$src_037] << 24 >> 24;
    var $27 = $i_036 + 1 | 0;
    var $28 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($27 >>> 0 < $28 >>> 0) {
      var $i_036 = $27;
      var $src_037 = $23;
      var $dest_038 = $26;
      __label__ = 7;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 8:
    var $dest_132;
    var $src1_031;
    var $i2_030;
    var $30 = $src1_031 + 1 | 0;
    var $33 = $dest_132 + 4 | 0;
    HEAP32[$dest_132 >> 2] = HEAPU8[$src1_031] & 255;
    var $34 = $i2_030 + 1 | 0;
    var $35 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($34 >>> 0 < $35 >>> 0) {
      var $i2_030 = $34;
      var $src1_031 = $30;
      var $dest_132 = $33;
      __label__ = 8;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 9:
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($38 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $i4_025 = 0;
    var $src3_026 = $13;
    var $dest_227 = $3;
    __label__ = 11;
    break;
   case 11:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    var $42 = $src3_026 + 2 | 0;
    var $45 = $dest_227 + 4 | 0;
    HEAP32[$dest_227 >> 2] = HEAP16[$src3_026 >> 1] << 16 >> 16;
    var $46 = $i4_025 + 1 | 0;
    var $47 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($46 >>> 0 < $47 >>> 0) {
      var $i4_025 = $46;
      var $src3_026 = $42;
      var $dest_227 = $45;
      __label__ = 11;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 12:
    var $50 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($50 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i6_020 = 0;
    var $src5_021 = $13;
    var $dest_322 = $3;
    __label__ = 14;
    break;
   case 14:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    var $54 = $src5_021 + 2 | 0;
    var $57 = $dest_322 + 4 | 0;
    HEAP32[$dest_322 >> 2] = HEAPU16[$src5_021 >> 1] & 65535;
    var $58 = $i6_020 + 1 | 0;
    var $59 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($58 >>> 0 < $59 >>> 0) {
      var $i6_020 = $58;
      var $src5_021 = $54;
      var $dest_322 = $57;
      __label__ = 14;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    var $62 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($62 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i8_015 = 0;
    var $src7_016 = $13;
    var $dest_417 = $3;
    __label__ = 17;
    break;
   case 17:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    var $66 = $src7_016 + 4 | 0;
    var $67 = HEAP32[$src7_016 >> 2];
    var $68 = $dest_417 + 4 | 0;
    HEAP32[$dest_417 >> 2] = $67;
    var $69 = $i8_015 + 1 | 0;
    var $70 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($69 >>> 0 < $70 >>> 0) {
      var $i8_015 = $69;
      var $src7_016 = $66;
      var $dest_417 = $68;
      __label__ = 17;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 18:
    var $73 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($73 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $src9_010 = $13;
    var $i10_011 = 0;
    var $dest_512 = $3;
    __label__ = 20;
    break;
   case 20:
    var $dest_512;
    var $i10_011;
    var $src9_010;
    var $77 = $src9_010 + 4 | 0;
    var $78 = HEAP32[$src9_010 >> 2];
    var $79 = $dest_512 + 4 | 0;
    HEAP32[$dest_512 >> 2] = $78;
    var $80 = $i10_011 + 1 | 0;
    var $81 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($80 >>> 0 < $81 >>> 0) {
      var $src9_010 = $77;
      var $i10_011 = $80;
      var $dest_512 = $79;
      __label__ = 20;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 21:
    var $84 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($84 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $dest_65 = $3;
    var $src11_06 = $13;
    var $i12_07 = 0;
    __label__ = 23;
    break;
   case 23:
    var $i12_07;
    var $src11_06;
    var $dest_65;
    var $88 = $src11_06 + 4 | 0;
    var $89 = HEAPF32[$src11_06 >> 2];
    var $90 = $89 >= 0 ? Math.floor($89) : Math.ceil($89);
    var $91 = $dest_65 + 4 | 0;
    HEAP32[$dest_65 >> 2] = $90;
    var $92 = $i12_07 + 1 | 0;
    var $93 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($92 >>> 0 < $93 >>> 0) {
      var $dest_65 = $91;
      var $src11_06 = $88;
      var $i12_07 = $92;
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $96 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($96 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $dest_71 = $3;
    var $src13_02 = $13;
    var $i14_03 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $100 = $src13_02 + 8 | 0;
    var $101 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $102 = $101 >= 0 ? Math.floor($101) : Math.ceil($101);
    var $103 = $dest_71 + 4 | 0;
    HEAP32[$dest_71 >> 2] = $102;
    var $104 = $i14_03 + 1 | 0;
    var $105 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($104 >>> 0 < $105 >>> 0) {
      var $dest_71 = $103;
      var $src13_02 = $100;
      var $i14_03 = $104;
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2js10Foreground5free_EPv($13);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIjE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIiE17class_constructorEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 16 | 0;
    var $2 = __ZN18TypedArrayTemplateIiE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $byteOffset = __stackBase__ + 4;
    var $length = __stackBase__ + 8;
    HEAP32[$len >> 2] = 0;
    if (($argc | 0) == 0) {
      var $5 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL13ValueIsLengthP9JSContextRKN2JS5ValueEPj($argv, $len);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $5 = HEAP32[$len >> 2];
    __label__ = 4;
    break;
   case 4:
    var $5;
    var $6 = __ZN18TypedArrayTemplateIiE28createBufferWithSizeAndCountEP9JSContextj($cx, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZN18TypedArrayTemplateIiE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $6, 0, $5);
    var $_0 = $9;
    __label__ = 22;
    break;
   case 6:
    var $argv_idx = $argv | 0;
    var $argv_idx_val$0 = HEAP32[$argv_idx >> 2];
    var $argv_idx_val$1 = HEAP32[$argv_idx + 4 >> 2];
    var $11 = __ZNK2JS5Value8isObjectEv($argv_idx_val$0, $argv_idx_val$1);
    if ($11) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 8:
    var $14 = __ZNK2JS5Value8toObjectEv($argv_idx_val$0, $argv_idx_val$1);
    var $_idx_val = HEAP32[$14 + 4 >> 2];
    var $15 = __Z15js_IsTypedArrayP8JSObject($_idx_val);
    if (($15 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $18 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($14);
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($18);
    var $20 = __ZN18TypedArrayTemplateIiE28createBufferWithSizeAndCountEP9JSContextj($cx, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $23 = __ZN18TypedArrayTemplateIiE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $20, 0, $19);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = __ZN18TypedArrayTemplateIiE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $23, $18, 0);
    if ($26) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 12:
    var $_0 = $23;
    __label__ = 22;
    break;
   case 13:
    HEAP32[$byteOffset >> 2] = -1;
    HEAP32[$length >> 2] = -1;
    if ($argc >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      var $48 = -1;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 14:
    var $31 = $argv + 8 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $byteOffset);
    if ($32) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 15:
    var $34 = HEAPU32[$byteOffset >> 2];
    if (($34 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 4, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str163973 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 17:
    if ($argc >>> 0 > 2) {
      __label__ = 18;
      break;
    } else {
      var $48 = $34;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 18:
    var $40 = $argv + 16 | 0;
    var $41 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $40, $length);
    if ($41) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 19:
    var $43 = HEAPU32[$length >> 2];
    if (($43 | 0) < 0) {
      __label__ = 20;
      break;
    } else {
      var $48 = $34;
      var $47 = $43;
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 4, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str173974 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 21:
    var $47;
    var $48;
    var $49 = __ZN18TypedArrayTemplateIiE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $14, $48, $47);
    var $_0 = $49;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIiE6createEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIiE28createBufferWithSizeAndCountEP9JSContextj($cx, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 > 536870910) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 4, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str183975 | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $4 = $count << 2;
    var $5 = __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $4);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $bufobj, $byteOffset, $len) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981($cx, __ZN2js10TypedArray11slowClassesE + 928 | 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAPU32[__ZN2js10TypedArray11slowClassesE + 932 >> 2] >>> 24;
    var $11 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($6, $11);
    __ZN2JSL10Int32ValueEi3996($1, 4);
    var $_idx4 = $1 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 3, $_idx4_val$0, $_idx4_val$1);
    __ZN2JSL11ObjectValueER8JSObject3997($2, $bufobj);
    var $_idx3 = $2 | 0;
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 4, $_idx3_val$0, $_idx3_val$1);
    var $bufobj_idx_val = HEAP32[$bufobj + 32 >> 2];
    var $14 = __ZN8JSObject21arrayBufferDataOffsetEv($bufobj_idx_val);
    var $15 = $14 + $byteOffset | 0;
    __ZN8JSObject10setPrivateEPv($6, $15);
    __ZN2JSL10Int32ValueEi3996($3, $len);
    var $_idx2 = $3 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 0, $_idx2_val$0, $_idx2_val$1);
    __ZN2JSL10Int32ValueEi3996($4, $byteOffset);
    var $_idx1 = $4 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 1, $_idx1_val$0, $_idx1_val$1);
    var $16 = $len << 2;
    __ZN2JSL10Int32ValueEi3996($5, $16);
    var $_idx = $5 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 2, $_idx_val$0, $_idx_val$1);
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    __ZN8JSObject8setClassEPN2js5ClassE($6, __ZN2js10TypedArray11fastClassesE + 928 | 0);
    var $17 = $6 + 8 | 0;
    var $19 = HEAP32[$17 >> 2] | 4;
    HEAP32[$17 >> 2] = $19;
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIiE16createTypedArrayEP9JSContextP8JSObjectjj["X"] = 1;

function __ZN18TypedArrayTemplateIiE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $thisTypedArrayObj, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
    var $3 = __ZN2js10TypedArray9getBufferEP8JSObject($1);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZN18TypedArrayTemplateIiE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $1, $tarray, $offset);
    var $_0 = $6;
    __label__ = 30;
    break;
   case 3:
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $8 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx_val);
    var $10 = $8 + ($offset << 2) | 0;
    var $11 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $12 = __ZN2js10TypedArray7getTypeEP8JSObject($1);
    if (($11 | 0) == ($12 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = $10;
    var $tarray_idx8_val = HEAP32[$tarray + 24 >> 2];
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx8_val);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($15, $16, $17, 1);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($11 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($11 | 0) == 1 || ($11 | 0) == 8) {
      __label__ = 9;
      break;
    } else if (($11 | 0) == 2) {
      __label__ = 12;
      break;
    } else if (($11 | 0) == 3) {
      __label__ = 15;
      break;
    } else if (($11 | 0) == 4) {
      __label__ = 18;
      break;
    } else if (($11 | 0) == 5) {
      __label__ = 21;
      break;
    } else if (($11 | 0) == 6) {
      __label__ = 24;
      break;
    } else if (($11 | 0) == 7) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 6:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $tarray_idx7_val = HEAP32[$tarray + 24 >> 2];
    var $22 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx7_val);
    var $lftr_limit45 = $22 + $19 | 0;
    var $src_036 = $22;
    var $dest_037 = $10;
    __label__ = 8;
    break;
   case 8:
    var $dest_037;
    var $src_036;
    var $24 = $src_036 + 1 | 0;
    HEAP32[$dest_037 >> 2] = HEAP8[$src_036] << 24 >> 24;
    if (($24 | 0) == ($lftr_limit45 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src_036 = $24;
      var $dest_037 = $dest_037 + 4 | 0;
      __label__ = 8;
      break;
    }
   case 9:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $tarray_idx6_val = HEAP32[$tarray + 24 >> 2];
    var $30 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx6_val);
    var $lftr_limit = $30 + $19 | 0;
    var $src1_031 = $30;
    var $dest_132 = $10;
    __label__ = 11;
    break;
   case 11:
    var $dest_132;
    var $src1_031;
    var $32 = $src1_031 + 1 | 0;
    HEAP32[$dest_132 >> 2] = HEAPU8[$src1_031] & 255;
    if (($32 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src1_031 = $32;
      var $dest_132 = $dest_132 + 4 | 0;
      __label__ = 11;
      break;
    }
   case 12:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $tarray_idx5_val = HEAP32[$tarray + 24 >> 2];
    var $38 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx5_val);
    var $i4_025 = 0;
    var $src3_026 = $38;
    var $dest_227 = $10;
    __label__ = 14;
    break;
   case 14:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    HEAP32[$dest_227 >> 2] = HEAP16[$src3_026 >> 1] << 16 >> 16;
    var $45 = $i4_025 + 1 | 0;
    if (($45 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i4_025 = $45;
      var $src3_026 = $src3_026 + 2 | 0;
      var $dest_227 = $dest_227 + 4 | 0;
      __label__ = 14;
      break;
    }
   case 15:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $tarray_idx4_val = HEAP32[$tarray + 24 >> 2];
    var $48 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx4_val);
    var $i6_020 = 0;
    var $src5_021 = $48;
    var $dest_322 = $10;
    __label__ = 17;
    break;
   case 17:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    HEAP32[$dest_322 >> 2] = HEAPU16[$src5_021 >> 1] & 65535;
    var $55 = $i6_020 + 1 | 0;
    if (($55 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i6_020 = $55;
      var $src5_021 = $src5_021 + 2 | 0;
      var $dest_322 = $dest_322 + 4 | 0;
      __label__ = 17;
      break;
    }
   case 18:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $tarray_idx3_val = HEAP32[$tarray + 24 >> 2];
    var $58 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx3_val);
    var $i8_015 = 0;
    var $src7_016 = $58;
    var $dest_417 = $10;
    __label__ = 20;
    break;
   case 20:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    var $62 = HEAP32[$src7_016 >> 2];
    HEAP32[$dest_417 >> 2] = $62;
    var $64 = $i8_015 + 1 | 0;
    if (($64 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i8_015 = $64;
      var $src7_016 = $src7_016 + 4 | 0;
      var $dest_417 = $dest_417 + 4 | 0;
      __label__ = 20;
      break;
    }
   case 21:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $tarray_idx2_val = HEAP32[$tarray + 24 >> 2];
    var $67 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx2_val);
    var $i10_010 = 0;
    var $src9_011 = $67;
    var $dest_512 = $10;
    __label__ = 23;
    break;
   case 23:
    var $dest_512;
    var $src9_011;
    var $i10_010;
    var $71 = HEAP32[$src9_011 >> 2];
    HEAP32[$dest_512 >> 2] = $71;
    var $73 = $i10_010 + 1 | 0;
    if (($73 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i10_010 = $73;
      var $src9_011 = $src9_011 + 4 | 0;
      var $dest_512 = $dest_512 + 4 | 0;
      __label__ = 23;
      break;
    }
   case 24:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $tarray_idx1_val = HEAP32[$tarray + 24 >> 2];
    var $76 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx1_val);
    var $src11_05 = $76;
    var $dest_66 = $10;
    var $i12_07 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i12_07;
    var $dest_66;
    var $src11_05;
    HEAP32[$dest_66 >> 2] = HEAPF32[$src11_05 >> 2] & -1;
    var $83 = $i12_07 + 1 | 0;
    if (($83 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src11_05 = $src11_05 + 4 | 0;
      var $dest_66 = $dest_66 + 4 | 0;
      var $i12_07 = $83;
      __label__ = 26;
      break;
    }
   case 27:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    var $86 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx_val);
    var $dest_71 = $10;
    var $src13_02 = $86;
    var $i14_03 = 0;
    __label__ = 29;
    break;
   case 29:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $90 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $91 = $90 & -1;
    HEAP32[$dest_71 >> 2] = $91;
    var $93 = $i14_03 + 1 | 0;
    if (($93 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $dest_71 = $dest_71 + 4 | 0;
      var $src13_02 = $src13_02 + 8 | 0;
      var $i14_03 = $93;
      __label__ = 29;
      break;
    }
   case 30:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIiE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIiE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $other, $byteOffsetInt, $lengthInt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len1 = __stackBase__;
    var $other_idx_val = HEAP32[$other + 4 >> 2];
    var $1 = __ZNK8JSObject13isArrayBufferEv($other_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 2:
    var $4 = ($byteOffsetInt | 0) < 0 ? 0 : $byteOffsetInt;
    var $other_idx2_val = HEAP32[$other + 32 >> 2];
    var $5 = __ZN8JSObject21arrayBufferByteLengthEv($other_idx2_val);
    if ($4 >>> 0 <= $5 >>> 0 & ($4 & 3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 4:
    if (($lengthInt | 0) < 0) {
      __label__ = 5;
      break;
    } else {
      var $len_0 = $lengthInt;
      __label__ = 7;
      break;
    }
   case 5:
    var $13 = $5 - $4 | 0;
    if (($13 & -4 | 0) == ($13 | 0)) {
      var $len_0 = $13 >>> 2;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 7:
    var $len_0;
    var $19 = $len_0 << 2;
    if ($len_0 >>> 0 > 536870910) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($4 >>> 0 < (2147483647 - $19 | 0) >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 10:
    if (($19 + $4 | 0) >>> 0 > $5 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 12:
    var $30 = __ZN18TypedArrayTemplateIiE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $other, $4, $len_0);
    var $_0 = $30;
    __label__ = 18;
    break;
   case 13:
    var $32 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $other, $len1);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $35 = HEAP32[$len1 >> 2];
    var $36 = __ZN18TypedArrayTemplateIiE28createBufferWithSizeAndCountEP9JSContextj($cx, $35);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $39 = __ZN18TypedArrayTemplateIiE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $36, 0, $35);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $42 = __ZN18TypedArrayTemplateIiE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $39, $other, $35, 0);
    if ($42) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 17:
    var $_0 = $39;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIiE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii["X"] = 1;

function __ZN18TypedArrayTemplateIiE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $thisTypedArrayObj, $ar, $len, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $2 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx_val);
    var $4 = $2 + ($offset << 2) | 0;
    var $ar_idx_val = HEAP32[$ar + 4 >> 2];
    var $5 = __ZNK8JSObject12isDenseArrayEv($ar_idx_val);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    }
   case 2:
    var $7 = __ZN8JSObject30getDenseArrayInitializedLengthEv($ar);
    if ($7 >>> 0 < $len >>> 0) {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($len | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $ar_idx1_val = HEAP32[$ar + 32 >> 2];
    var $11 = __ZN8JSObject21getDenseArrayElementsEv($ar_idx1_val);
    var $dest_01 = $4;
    var $src_02 = $11;
    var $i_03 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_03;
    var $src_02;
    var $dest_01;
    var $13 = $src_02 + 8 | 0;
    var $14 = __ZN18TypedArrayTemplateIiE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $src_02);
    HEAP32[$dest_01 >> 2] = $14;
    var $16 = $i_03 + 1 | 0;
    if (($16 | 0) == ($len | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      var $dest_01 = $dest_01 + 4 | 0;
      var $src_02 = $13;
      var $i_03 = $16;
      __label__ = 5;
      break;
    }
   case 6:
    var $dest_1;
    var $i1_0;
    if ($i1_0 >>> 0 < $len >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 7:
    var $19 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($ar, $cx, $i1_0, $v);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = __ZN18TypedArrayTemplateIiE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v);
    HEAP32[$dest_1 >> 2] = $22;
    var $i1_0 = $i1_0 + 1 | 0;
    var $dest_1 = $dest_1 + 4 | 0;
    __label__ = 6;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $dval = __stackBase__;
    var $v_idx3 = $v | 0;
    var $v_idx3_val$0 = HEAP32[$v_idx3 >> 2];
    var $v_idx3_val$1 = HEAP32[$v_idx3 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx3_val$0, $v_idx3_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx3_val$0, $v_idx3_val$1);
    var $_0 = $3;
    __label__ = 9;
    break;
   case 3:
    var $5 = __ZNK2JS5Value8isDoubleEv($v_idx3_val$0, $v_idx3_val$1);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $7 = __ZNK2JS5Value8toDoubleEv($v);
    var $8 = __ZL15JSDOUBLE_IS_NaNd3989($7);
    if (($8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = __ZL20js_DoubleToECMAInt32d4007($7);
    var $_0 = $11;
    __label__ = 9;
    break;
   case 6:
    var $13 = __ZNK2JS5Value11isPrimitiveEv($v_idx3_val$0, $v_idx3_val$1);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $15 = __ZNK2JS5Value7isMagicEv($v_idx3_val$0, $v_idx3_val$1);
    if ($15) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $17 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $v, $dval);
    var $18 = (tempDoubleI32[0] = HEAP32[$dval >> 2], tempDoubleI32[1] = HEAP32[$dval + 4 >> 2], tempDoubleF64[0]);
    var $_0 = $18 & -1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $self, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $self_idx_val = HEAP32[$self + 24 >> 2];
    var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($self_idx_val);
    var $3 = $1 + ($offset << 2) | 0;
    var $4 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $5 = __ZN2js10TypedArray7getTypeEP8JSObject($self);
    if (($4 | 0) == ($5 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $3;
    var $tarray_idx1_val = HEAP32[$tarray + 24 >> 2];
    var $9 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx1_val);
    var $10 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _llvm_memmove_p0i8_p0i8_i32($8, $9, $10, 1, 0);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 3:
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    var $13 = __ZN9JSContext7malloc_Ej($cx, $12);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx_val);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($13, $16, $17, 1);
    var $18 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    if (($18 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($18 | 0) == 1 || ($18 | 0) == 8) {
      __label__ = 6;
      break;
    } else if (($18 | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($18 | 0) == 3) {
      __label__ = 12;
      break;
    } else if (($18 | 0) == 4) {
      __label__ = 15;
      break;
    } else if (($18 | 0) == 5) {
      __label__ = 18;
      break;
    } else if (($18 | 0) == 6) {
      __label__ = 21;
      break;
    } else if (($18 | 0) == 7) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($19 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i_036 = 0;
      var $src_037 = $13;
      var $dest_038 = $3;
      __label__ = 7;
      break;
    }
   case 6:
    var $21 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($21 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i2_030 = 0;
      var $src1_031 = $13;
      var $dest_132 = $3;
      __label__ = 8;
      break;
    }
   case 7:
    var $dest_038;
    var $src_037;
    var $i_036;
    var $23 = $src_037 + 1 | 0;
    var $26 = $dest_038 + 4 | 0;
    HEAP32[$dest_038 >> 2] = HEAP8[$src_037] << 24 >> 24;
    var $27 = $i_036 + 1 | 0;
    var $28 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($27 >>> 0 < $28 >>> 0) {
      var $i_036 = $27;
      var $src_037 = $23;
      var $dest_038 = $26;
      __label__ = 7;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 8:
    var $dest_132;
    var $src1_031;
    var $i2_030;
    var $30 = $src1_031 + 1 | 0;
    var $33 = $dest_132 + 4 | 0;
    HEAP32[$dest_132 >> 2] = HEAPU8[$src1_031] & 255;
    var $34 = $i2_030 + 1 | 0;
    var $35 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($34 >>> 0 < $35 >>> 0) {
      var $i2_030 = $34;
      var $src1_031 = $30;
      var $dest_132 = $33;
      __label__ = 8;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 9:
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($38 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $i4_025 = 0;
    var $src3_026 = $13;
    var $dest_227 = $3;
    __label__ = 11;
    break;
   case 11:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    var $42 = $src3_026 + 2 | 0;
    var $45 = $dest_227 + 4 | 0;
    HEAP32[$dest_227 >> 2] = HEAP16[$src3_026 >> 1] << 16 >> 16;
    var $46 = $i4_025 + 1 | 0;
    var $47 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($46 >>> 0 < $47 >>> 0) {
      var $i4_025 = $46;
      var $src3_026 = $42;
      var $dest_227 = $45;
      __label__ = 11;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 12:
    var $50 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($50 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i6_020 = 0;
    var $src5_021 = $13;
    var $dest_322 = $3;
    __label__ = 14;
    break;
   case 14:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    var $54 = $src5_021 + 2 | 0;
    var $57 = $dest_322 + 4 | 0;
    HEAP32[$dest_322 >> 2] = HEAPU16[$src5_021 >> 1] & 65535;
    var $58 = $i6_020 + 1 | 0;
    var $59 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($58 >>> 0 < $59 >>> 0) {
      var $i6_020 = $58;
      var $src5_021 = $54;
      var $dest_322 = $57;
      __label__ = 14;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    var $62 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($62 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i8_015 = 0;
    var $src7_016 = $13;
    var $dest_417 = $3;
    __label__ = 17;
    break;
   case 17:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    var $66 = $src7_016 + 4 | 0;
    var $67 = HEAP32[$src7_016 >> 2];
    var $68 = $dest_417 + 4 | 0;
    HEAP32[$dest_417 >> 2] = $67;
    var $69 = $i8_015 + 1 | 0;
    var $70 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($69 >>> 0 < $70 >>> 0) {
      var $i8_015 = $69;
      var $src7_016 = $66;
      var $dest_417 = $68;
      __label__ = 17;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 18:
    var $73 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($73 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $src9_010 = $13;
    var $i10_011 = 0;
    var $dest_512 = $3;
    __label__ = 20;
    break;
   case 20:
    var $dest_512;
    var $i10_011;
    var $src9_010;
    var $77 = $src9_010 + 4 | 0;
    var $78 = HEAP32[$src9_010 >> 2];
    var $79 = $dest_512 + 4 | 0;
    HEAP32[$dest_512 >> 2] = $78;
    var $80 = $i10_011 + 1 | 0;
    var $81 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($80 >>> 0 < $81 >>> 0) {
      var $src9_010 = $77;
      var $i10_011 = $80;
      var $dest_512 = $79;
      __label__ = 20;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 21:
    var $84 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($84 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $dest_65 = $3;
    var $src11_06 = $13;
    var $i12_07 = 0;
    __label__ = 23;
    break;
   case 23:
    var $i12_07;
    var $src11_06;
    var $dest_65;
    var $88 = $src11_06 + 4 | 0;
    var $91 = $dest_65 + 4 | 0;
    HEAP32[$dest_65 >> 2] = HEAPF32[$src11_06 >> 2] & -1;
    var $92 = $i12_07 + 1 | 0;
    var $93 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($92 >>> 0 < $93 >>> 0) {
      var $dest_65 = $91;
      var $src11_06 = $88;
      var $i12_07 = $92;
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $96 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($96 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $dest_71 = $3;
    var $src13_02 = $13;
    var $i14_03 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $100 = $src13_02 + 8 | 0;
    var $101 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $102 = $101 & -1;
    var $103 = $dest_71 + 4 | 0;
    HEAP32[$dest_71 >> 2] = $102;
    var $104 = $i14_03 + 1 | 0;
    var $105 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($104 >>> 0 < $105 >>> 0) {
      var $dest_71 = $103;
      var $src13_02 = $100;
      var $i14_03 = $104;
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2js10Foreground5free_EPv($13);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIiE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateItE17class_constructorEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 16 | 0;
    var $2 = __ZN18TypedArrayTemplateItE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $byteOffset = __stackBase__ + 4;
    var $length = __stackBase__ + 8;
    HEAP32[$len >> 2] = 0;
    if (($argc | 0) == 0) {
      var $5 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL13ValueIsLengthP9JSContextRKN2JS5ValueEPj($argv, $len);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $5 = HEAP32[$len >> 2];
    __label__ = 4;
    break;
   case 4:
    var $5;
    var $6 = __ZN18TypedArrayTemplateItE28createBufferWithSizeAndCountEP9JSContextj($cx, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZN18TypedArrayTemplateItE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $6, 0, $5);
    var $_0 = $9;
    __label__ = 22;
    break;
   case 6:
    var $argv_idx = $argv | 0;
    var $argv_idx_val$0 = HEAP32[$argv_idx >> 2];
    var $argv_idx_val$1 = HEAP32[$argv_idx + 4 >> 2];
    var $11 = __ZNK2JS5Value8isObjectEv($argv_idx_val$0, $argv_idx_val$1);
    if ($11) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 8:
    var $14 = __ZNK2JS5Value8toObjectEv($argv_idx_val$0, $argv_idx_val$1);
    var $_idx_val = HEAP32[$14 + 4 >> 2];
    var $15 = __Z15js_IsTypedArrayP8JSObject($_idx_val);
    if (($15 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $18 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($14);
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($18);
    var $20 = __ZN18TypedArrayTemplateItE28createBufferWithSizeAndCountEP9JSContextj($cx, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $23 = __ZN18TypedArrayTemplateItE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $20, 0, $19);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = __ZN18TypedArrayTemplateItE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $23, $18, 0);
    if ($26) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 12:
    var $_0 = $23;
    __label__ = 22;
    break;
   case 13:
    HEAP32[$byteOffset >> 2] = -1;
    HEAP32[$length >> 2] = -1;
    if ($argc >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      var $48 = -1;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 14:
    var $31 = $argv + 8 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $byteOffset);
    if ($32) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 15:
    var $34 = HEAPU32[$byteOffset >> 2];
    if (($34 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 4, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str163973 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 17:
    if ($argc >>> 0 > 2) {
      __label__ = 18;
      break;
    } else {
      var $48 = $34;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 18:
    var $40 = $argv + 16 | 0;
    var $41 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $40, $length);
    if ($41) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 19:
    var $43 = HEAPU32[$length >> 2];
    if (($43 | 0) < 0) {
      __label__ = 20;
      break;
    } else {
      var $48 = $34;
      var $47 = $43;
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 4, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str173974 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 21:
    var $47;
    var $48;
    var $49 = __ZN18TypedArrayTemplateItE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $14, $48, $47);
    var $_0 = $49;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateItE6createEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateItE28createBufferWithSizeAndCountEP9JSContextj($cx, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 > 1073741822) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 4, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str183975 | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $4 = $count << 1;
    var $5 = __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $4);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $bufobj, $byteOffset, $len) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981($cx, __ZN2js10TypedArray11slowClassesE + 696 | 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAPU32[__ZN2js10TypedArray11slowClassesE + 700 >> 2] >>> 24;
    var $11 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($6, $11);
    __ZN2JSL10Int32ValueEi3996($1, 3);
    var $_idx4 = $1 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 3, $_idx4_val$0, $_idx4_val$1);
    __ZN2JSL11ObjectValueER8JSObject3997($2, $bufobj);
    var $_idx3 = $2 | 0;
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 4, $_idx3_val$0, $_idx3_val$1);
    var $bufobj_idx_val = HEAP32[$bufobj + 32 >> 2];
    var $14 = __ZN8JSObject21arrayBufferDataOffsetEv($bufobj_idx_val);
    var $15 = $14 + $byteOffset | 0;
    __ZN8JSObject10setPrivateEPv($6, $15);
    __ZN2JSL10Int32ValueEi3996($3, $len);
    var $_idx2 = $3 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 0, $_idx2_val$0, $_idx2_val$1);
    __ZN2JSL10Int32ValueEi3996($4, $byteOffset);
    var $_idx1 = $4 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 1, $_idx1_val$0, $_idx1_val$1);
    var $16 = $len << 1;
    __ZN2JSL10Int32ValueEi3996($5, $16);
    var $_idx = $5 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 2, $_idx_val$0, $_idx_val$1);
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    __ZN8JSObject8setClassEPN2js5ClassE($6, __ZN2js10TypedArray11fastClassesE + 696 | 0);
    var $17 = $6 + 8 | 0;
    var $19 = HEAP32[$17 >> 2] | 4;
    HEAP32[$17 >> 2] = $19;
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateItE16createTypedArrayEP9JSContextP8JSObjectjj["X"] = 1;

function __ZN18TypedArrayTemplateItE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $thisTypedArrayObj, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
    var $3 = __ZN2js10TypedArray9getBufferEP8JSObject($1);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZN18TypedArrayTemplateItE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $1, $tarray, $offset);
    var $_0 = $6;
    __label__ = 30;
    break;
   case 3:
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $8 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx_val);
    var $10 = $8 + ($offset << 1) | 0;
    var $11 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $12 = __ZN2js10TypedArray7getTypeEP8JSObject($1);
    if (($11 | 0) == ($12 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = $10;
    var $tarray_idx8_val = HEAP32[$tarray + 24 >> 2];
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx8_val);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($15, $16, $17, 1);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($11 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($11 | 0) == 1 || ($11 | 0) == 8) {
      __label__ = 9;
      break;
    } else if (($11 | 0) == 2) {
      __label__ = 12;
      break;
    } else if (($11 | 0) == 3) {
      __label__ = 15;
      break;
    } else if (($11 | 0) == 4) {
      __label__ = 18;
      break;
    } else if (($11 | 0) == 5) {
      __label__ = 21;
      break;
    } else if (($11 | 0) == 6) {
      __label__ = 24;
      break;
    } else if (($11 | 0) == 7) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 6:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $tarray_idx7_val = HEAP32[$tarray + 24 >> 2];
    var $22 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx7_val);
    var $lftr_limit45 = $22 + $19 | 0;
    var $src_036 = $22;
    var $dest_037 = $10;
    __label__ = 8;
    break;
   case 8:
    var $dest_037;
    var $src_036;
    var $24 = $src_036 + 1 | 0;
    HEAP16[$dest_037 >> 1] = HEAP8[$src_036] << 24 >> 24;
    if (($24 | 0) == ($lftr_limit45 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src_036 = $24;
      var $dest_037 = $dest_037 + 2 | 0;
      __label__ = 8;
      break;
    }
   case 9:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $tarray_idx6_val = HEAP32[$tarray + 24 >> 2];
    var $30 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx6_val);
    var $lftr_limit = $30 + $19 | 0;
    var $src1_031 = $30;
    var $dest_132 = $10;
    __label__ = 11;
    break;
   case 11:
    var $dest_132;
    var $src1_031;
    var $32 = $src1_031 + 1 | 0;
    HEAP16[$dest_132 >> 1] = HEAPU8[$src1_031] & 255;
    if (($32 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src1_031 = $32;
      var $dest_132 = $dest_132 + 2 | 0;
      __label__ = 11;
      break;
    }
   case 12:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $tarray_idx5_val = HEAP32[$tarray + 24 >> 2];
    var $38 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx5_val);
    var $i4_025 = 0;
    var $src3_026 = $38;
    var $dest_227 = $10;
    __label__ = 14;
    break;
   case 14:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    var $42 = HEAP16[$src3_026 >> 1];
    HEAP16[$dest_227 >> 1] = $42;
    var $44 = $i4_025 + 1 | 0;
    if (($44 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i4_025 = $44;
      var $src3_026 = $src3_026 + 2 | 0;
      var $dest_227 = $dest_227 + 2 | 0;
      __label__ = 14;
      break;
    }
   case 15:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $tarray_idx4_val = HEAP32[$tarray + 24 >> 2];
    var $47 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx4_val);
    var $i6_020 = 0;
    var $src5_021 = $47;
    var $dest_322 = $10;
    __label__ = 17;
    break;
   case 17:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    var $51 = HEAP16[$src5_021 >> 1];
    HEAP16[$dest_322 >> 1] = $51;
    var $53 = $i6_020 + 1 | 0;
    if (($53 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i6_020 = $53;
      var $src5_021 = $src5_021 + 2 | 0;
      var $dest_322 = $dest_322 + 2 | 0;
      __label__ = 17;
      break;
    }
   case 18:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $tarray_idx3_val = HEAP32[$tarray + 24 >> 2];
    var $56 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx3_val);
    var $i8_015 = 0;
    var $src7_016 = $56;
    var $dest_417 = $10;
    __label__ = 20;
    break;
   case 20:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    HEAP16[$dest_417 >> 1] = HEAP32[$src7_016 >> 2] & 65535;
    var $63 = $i8_015 + 1 | 0;
    if (($63 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i8_015 = $63;
      var $src7_016 = $src7_016 + 4 | 0;
      var $dest_417 = $dest_417 + 2 | 0;
      __label__ = 20;
      break;
    }
   case 21:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $tarray_idx2_val = HEAP32[$tarray + 24 >> 2];
    var $66 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx2_val);
    var $i10_010 = 0;
    var $src9_011 = $66;
    var $dest_512 = $10;
    __label__ = 23;
    break;
   case 23:
    var $dest_512;
    var $src9_011;
    var $i10_010;
    HEAP16[$dest_512 >> 1] = HEAP32[$src9_011 >> 2] & 65535;
    var $73 = $i10_010 + 1 | 0;
    if (($73 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i10_010 = $73;
      var $src9_011 = $src9_011 + 4 | 0;
      var $dest_512 = $dest_512 + 2 | 0;
      __label__ = 23;
      break;
    }
   case 24:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $tarray_idx1_val = HEAP32[$tarray + 24 >> 2];
    var $76 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx1_val);
    var $src11_05 = $76;
    var $dest_66 = $10;
    var $i12_07 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i12_07;
    var $dest_66;
    var $src11_05;
    var $79 = $src11_05 + 4 | 0;
    var $80 = HEAPF32[$src11_05 >> 2];
    var $81 = $80 >= 0 ? Math.floor($80) : Math.ceil($80);
    HEAP16[$dest_66 >> 1] = $81;
    var $83 = $i12_07 + 1 | 0;
    if (($83 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src11_05 = $79;
      var $dest_66 = $dest_66 + 2 | 0;
      var $i12_07 = $83;
      __label__ = 26;
      break;
    }
   case 27:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    var $86 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx_val);
    var $dest_71 = $10;
    var $src13_02 = $86;
    var $i14_03 = 0;
    __label__ = 29;
    break;
   case 29:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $89 = $src13_02 + 8 | 0;
    var $90 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $91 = $90 >= 0 ? Math.floor($90) : Math.ceil($90);
    HEAP16[$dest_71 >> 1] = $91;
    var $93 = $i14_03 + 1 | 0;
    if (($93 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $dest_71 = $dest_71 + 2 | 0;
      var $src13_02 = $89;
      var $i14_03 = $93;
      __label__ = 29;
      break;
    }
   case 30:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateItE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateItE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $other, $byteOffsetInt, $lengthInt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len1 = __stackBase__;
    var $other_idx_val = HEAP32[$other + 4 >> 2];
    var $1 = __ZNK8JSObject13isArrayBufferEv($other_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 2:
    var $4 = ($byteOffsetInt | 0) < 0 ? 0 : $byteOffsetInt;
    var $other_idx2_val = HEAP32[$other + 32 >> 2];
    var $5 = __ZN8JSObject21arrayBufferByteLengthEv($other_idx2_val);
    if ($4 >>> 0 <= $5 >>> 0 & ($4 & 1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 4:
    if (($lengthInt | 0) < 0) {
      __label__ = 5;
      break;
    } else {
      var $len_0 = $lengthInt;
      __label__ = 7;
      break;
    }
   case 5:
    var $13 = $5 - $4 | 0;
    if (($13 & -2 | 0) == ($13 | 0)) {
      var $len_0 = $13 >>> 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 7:
    var $len_0;
    var $19 = $len_0 << 1;
    if ($len_0 >>> 0 > 1073741822) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($4 >>> 0 < (2147483647 - $19 | 0) >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 10:
    if (($19 + $4 | 0) >>> 0 > $5 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 12:
    var $30 = __ZN18TypedArrayTemplateItE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $other, $4, $len_0);
    var $_0 = $30;
    __label__ = 18;
    break;
   case 13:
    var $32 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $other, $len1);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $35 = HEAP32[$len1 >> 2];
    var $36 = __ZN18TypedArrayTemplateItE28createBufferWithSizeAndCountEP9JSContextj($cx, $35);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $39 = __ZN18TypedArrayTemplateItE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $36, 0, $35);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $42 = __ZN18TypedArrayTemplateItE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $39, $other, $35, 0);
    if ($42) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 17:
    var $_0 = $39;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateItE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii["X"] = 1;

function __ZN18TypedArrayTemplateItE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $thisTypedArrayObj, $ar, $len, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $2 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx_val);
    var $4 = $2 + ($offset << 1) | 0;
    var $ar_idx_val = HEAP32[$ar + 4 >> 2];
    var $5 = __ZNK8JSObject12isDenseArrayEv($ar_idx_val);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    }
   case 2:
    var $7 = __ZN8JSObject30getDenseArrayInitializedLengthEv($ar);
    if ($7 >>> 0 < $len >>> 0) {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($len | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $ar_idx1_val = HEAP32[$ar + 32 >> 2];
    var $11 = __ZN8JSObject21getDenseArrayElementsEv($ar_idx1_val);
    var $dest_01 = $4;
    var $src_02 = $11;
    var $i_03 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_03;
    var $src_02;
    var $dest_01;
    var $13 = $src_02 + 8 | 0;
    var $14 = __ZN18TypedArrayTemplateItE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $src_02);
    HEAP16[$dest_01 >> 1] = $14;
    var $16 = $i_03 + 1 | 0;
    if (($16 | 0) == ($len | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      var $dest_01 = $dest_01 + 2 | 0;
      var $src_02 = $13;
      var $i_03 = $16;
      __label__ = 5;
      break;
    }
   case 6:
    var $dest_1;
    var $i1_0;
    if ($i1_0 >>> 0 < $len >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 7:
    var $19 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($ar, $cx, $i1_0, $v);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = __ZN18TypedArrayTemplateItE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v);
    HEAP16[$dest_1 >> 1] = $22;
    var $i1_0 = $i1_0 + 1 | 0;
    var $dest_1 = $dest_1 + 2 | 0;
    __label__ = 6;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $dval = __stackBase__;
    var $v_idx3 = $v | 0;
    var $v_idx3_val$0 = HEAP32[$v_idx3 >> 2];
    var $v_idx3_val$1 = HEAP32[$v_idx3 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx3_val$0, $v_idx3_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx3_val$0, $v_idx3_val$1);
    var $_0 = $3 & 65535;
    __label__ = 9;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($v_idx3_val$0, $v_idx3_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($v);
    var $9 = __ZL15JSDOUBLE_IS_NaNd3989($8);
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $12 = __Z21js_DoubleToECMAUint32d($8);
    var $_0 = $12 & 65535;
    __label__ = 9;
    break;
   case 6:
    var $15 = __ZNK2JS5Value11isPrimitiveEv($v_idx3_val$0, $v_idx3_val$1);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $17 = __ZNK2JS5Value7isMagicEv($v_idx3_val$0, $v_idx3_val$1);
    if ($17) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $19 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $v, $dval);
    var $20 = (tempDoubleI32[0] = HEAP32[$dval >> 2], tempDoubleI32[1] = HEAP32[$dval + 4 >> 2], tempDoubleF64[0]);
    var $21 = $20 >= 0 ? Math.floor($20) : Math.ceil($20);
    var $_0 = $21;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $self, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $self_idx_val = HEAP32[$self + 24 >> 2];
    var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($self_idx_val);
    var $3 = $1 + ($offset << 1) | 0;
    var $4 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $5 = __ZN2js10TypedArray7getTypeEP8JSObject($self);
    if (($4 | 0) == ($5 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $3;
    var $tarray_idx1_val = HEAP32[$tarray + 24 >> 2];
    var $9 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx1_val);
    var $10 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _llvm_memmove_p0i8_p0i8_i32($8, $9, $10, 1, 0);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 3:
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    var $13 = __ZN9JSContext7malloc_Ej($cx, $12);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx_val);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($13, $16, $17, 1);
    var $18 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    if (($18 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($18 | 0) == 1 || ($18 | 0) == 8) {
      __label__ = 6;
      break;
    } else if (($18 | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($18 | 0) == 3) {
      __label__ = 12;
      break;
    } else if (($18 | 0) == 4) {
      __label__ = 15;
      break;
    } else if (($18 | 0) == 5) {
      __label__ = 18;
      break;
    } else if (($18 | 0) == 6) {
      __label__ = 21;
      break;
    } else if (($18 | 0) == 7) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($19 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i_036 = 0;
      var $src_037 = $13;
      var $dest_038 = $3;
      __label__ = 7;
      break;
    }
   case 6:
    var $21 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($21 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i2_030 = 0;
      var $src1_031 = $13;
      var $dest_132 = $3;
      __label__ = 8;
      break;
    }
   case 7:
    var $dest_038;
    var $src_037;
    var $i_036;
    var $23 = $src_037 + 1 | 0;
    var $26 = $dest_038 + 2 | 0;
    HEAP16[$dest_038 >> 1] = HEAP8[$src_037] << 24 >> 24;
    var $27 = $i_036 + 1 | 0;
    var $28 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($27 >>> 0 < $28 >>> 0) {
      var $i_036 = $27;
      var $src_037 = $23;
      var $dest_038 = $26;
      __label__ = 7;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 8:
    var $dest_132;
    var $src1_031;
    var $i2_030;
    var $30 = $src1_031 + 1 | 0;
    var $33 = $dest_132 + 2 | 0;
    HEAP16[$dest_132 >> 1] = HEAPU8[$src1_031] & 255;
    var $34 = $i2_030 + 1 | 0;
    var $35 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($34 >>> 0 < $35 >>> 0) {
      var $i2_030 = $34;
      var $src1_031 = $30;
      var $dest_132 = $33;
      __label__ = 8;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 9:
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($38 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $i4_025 = 0;
    var $src3_026 = $13;
    var $dest_227 = $3;
    __label__ = 11;
    break;
   case 11:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    var $42 = $src3_026 + 2 | 0;
    var $43 = HEAP16[$src3_026 >> 1];
    var $44 = $dest_227 + 2 | 0;
    HEAP16[$dest_227 >> 1] = $43;
    var $45 = $i4_025 + 1 | 0;
    var $46 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($45 >>> 0 < $46 >>> 0) {
      var $i4_025 = $45;
      var $src3_026 = $42;
      var $dest_227 = $44;
      __label__ = 11;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 12:
    var $49 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($49 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i6_020 = 0;
    var $src5_021 = $13;
    var $dest_322 = $3;
    __label__ = 14;
    break;
   case 14:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    var $53 = $src5_021 + 2 | 0;
    var $54 = HEAP16[$src5_021 >> 1];
    var $55 = $dest_322 + 2 | 0;
    HEAP16[$dest_322 >> 1] = $54;
    var $56 = $i6_020 + 1 | 0;
    var $57 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($56 >>> 0 < $57 >>> 0) {
      var $i6_020 = $56;
      var $src5_021 = $53;
      var $dest_322 = $55;
      __label__ = 14;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    var $60 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($60 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i8_015 = 0;
    var $src7_016 = $13;
    var $dest_417 = $3;
    __label__ = 17;
    break;
   case 17:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    var $64 = $src7_016 + 4 | 0;
    var $67 = $dest_417 + 2 | 0;
    HEAP16[$dest_417 >> 1] = HEAP32[$src7_016 >> 2] & 65535;
    var $68 = $i8_015 + 1 | 0;
    var $69 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($68 >>> 0 < $69 >>> 0) {
      var $i8_015 = $68;
      var $src7_016 = $64;
      var $dest_417 = $67;
      __label__ = 17;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 18:
    var $72 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($72 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $src9_010 = $13;
    var $i10_011 = 0;
    var $dest_512 = $3;
    __label__ = 20;
    break;
   case 20:
    var $dest_512;
    var $i10_011;
    var $src9_010;
    var $76 = $src9_010 + 4 | 0;
    var $79 = $dest_512 + 2 | 0;
    HEAP16[$dest_512 >> 1] = HEAP32[$src9_010 >> 2] & 65535;
    var $80 = $i10_011 + 1 | 0;
    var $81 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($80 >>> 0 < $81 >>> 0) {
      var $src9_010 = $76;
      var $i10_011 = $80;
      var $dest_512 = $79;
      __label__ = 20;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 21:
    var $84 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($84 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $dest_65 = $3;
    var $src11_06 = $13;
    var $i12_07 = 0;
    __label__ = 23;
    break;
   case 23:
    var $i12_07;
    var $src11_06;
    var $dest_65;
    var $88 = $src11_06 + 4 | 0;
    var $89 = HEAPF32[$src11_06 >> 2];
    var $90 = $89 >= 0 ? Math.floor($89) : Math.ceil($89);
    var $91 = $dest_65 + 2 | 0;
    HEAP16[$dest_65 >> 1] = $90;
    var $92 = $i12_07 + 1 | 0;
    var $93 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($92 >>> 0 < $93 >>> 0) {
      var $dest_65 = $91;
      var $src11_06 = $88;
      var $i12_07 = $92;
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $96 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($96 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $dest_71 = $3;
    var $src13_02 = $13;
    var $i14_03 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $100 = $src13_02 + 8 | 0;
    var $101 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $102 = $101 >= 0 ? Math.floor($101) : Math.ceil($101);
    var $103 = $dest_71 + 2 | 0;
    HEAP16[$dest_71 >> 1] = $102;
    var $104 = $i14_03 + 1 | 0;
    var $105 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($104 >>> 0 < $105 >>> 0) {
      var $dest_71 = $103;
      var $src13_02 = $100;
      var $i14_03 = $104;
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2js10Foreground5free_EPv($13);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateItE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIsE17class_constructorEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 16 | 0;
    var $2 = __ZN18TypedArrayTemplateIsE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $byteOffset = __stackBase__ + 4;
    var $length = __stackBase__ + 8;
    HEAP32[$len >> 2] = 0;
    if (($argc | 0) == 0) {
      var $5 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL13ValueIsLengthP9JSContextRKN2JS5ValueEPj($argv, $len);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $5 = HEAP32[$len >> 2];
    __label__ = 4;
    break;
   case 4:
    var $5;
    var $6 = __ZN18TypedArrayTemplateIsE28createBufferWithSizeAndCountEP9JSContextj($cx, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZN18TypedArrayTemplateIsE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $6, 0, $5);
    var $_0 = $9;
    __label__ = 22;
    break;
   case 6:
    var $argv_idx = $argv | 0;
    var $argv_idx_val$0 = HEAP32[$argv_idx >> 2];
    var $argv_idx_val$1 = HEAP32[$argv_idx + 4 >> 2];
    var $11 = __ZNK2JS5Value8isObjectEv($argv_idx_val$0, $argv_idx_val$1);
    if ($11) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 8:
    var $14 = __ZNK2JS5Value8toObjectEv($argv_idx_val$0, $argv_idx_val$1);
    var $_idx_val = HEAP32[$14 + 4 >> 2];
    var $15 = __Z15js_IsTypedArrayP8JSObject($_idx_val);
    if (($15 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $18 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($14);
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($18);
    var $20 = __ZN18TypedArrayTemplateIsE28createBufferWithSizeAndCountEP9JSContextj($cx, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $23 = __ZN18TypedArrayTemplateIsE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $20, 0, $19);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = __ZN18TypedArrayTemplateIsE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $23, $18, 0);
    if ($26) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 12:
    var $_0 = $23;
    __label__ = 22;
    break;
   case 13:
    HEAP32[$byteOffset >> 2] = -1;
    HEAP32[$length >> 2] = -1;
    if ($argc >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      var $48 = -1;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 14:
    var $31 = $argv + 8 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $byteOffset);
    if ($32) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 15:
    var $34 = HEAPU32[$byteOffset >> 2];
    if (($34 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 4, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str163973 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 17:
    if ($argc >>> 0 > 2) {
      __label__ = 18;
      break;
    } else {
      var $48 = $34;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 18:
    var $40 = $argv + 16 | 0;
    var $41 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $40, $length);
    if ($41) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 19:
    var $43 = HEAPU32[$length >> 2];
    if (($43 | 0) < 0) {
      __label__ = 20;
      break;
    } else {
      var $48 = $34;
      var $47 = $43;
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 4, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str173974 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 21:
    var $47;
    var $48;
    var $49 = __ZN18TypedArrayTemplateIsE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $14, $48, $47);
    var $_0 = $49;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIsE6createEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIsE28createBufferWithSizeAndCountEP9JSContextj($cx, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 > 1073741822) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 4, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str183975 | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $4 = $count << 1;
    var $5 = __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $4);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $bufobj, $byteOffset, $len) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981($cx, __ZN2js10TypedArray11slowClassesE + 464 | 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAPU32[__ZN2js10TypedArray11slowClassesE + 468 >> 2] >>> 24;
    var $11 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($6, $11);
    __ZN2JSL10Int32ValueEi3996($1, 2);
    var $_idx4 = $1 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 3, $_idx4_val$0, $_idx4_val$1);
    __ZN2JSL11ObjectValueER8JSObject3997($2, $bufobj);
    var $_idx3 = $2 | 0;
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 4, $_idx3_val$0, $_idx3_val$1);
    var $bufobj_idx_val = HEAP32[$bufobj + 32 >> 2];
    var $14 = __ZN8JSObject21arrayBufferDataOffsetEv($bufobj_idx_val);
    var $15 = $14 + $byteOffset | 0;
    __ZN8JSObject10setPrivateEPv($6, $15);
    __ZN2JSL10Int32ValueEi3996($3, $len);
    var $_idx2 = $3 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 0, $_idx2_val$0, $_idx2_val$1);
    __ZN2JSL10Int32ValueEi3996($4, $byteOffset);
    var $_idx1 = $4 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 1, $_idx1_val$0, $_idx1_val$1);
    var $16 = $len << 1;
    __ZN2JSL10Int32ValueEi3996($5, $16);
    var $_idx = $5 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 2, $_idx_val$0, $_idx_val$1);
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    __ZN8JSObject8setClassEPN2js5ClassE($6, __ZN2js10TypedArray11fastClassesE + 464 | 0);
    var $17 = $6 + 8 | 0;
    var $19 = HEAP32[$17 >> 2] | 4;
    HEAP32[$17 >> 2] = $19;
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIsE16createTypedArrayEP9JSContextP8JSObjectjj["X"] = 1;

function __ZN18TypedArrayTemplateIsE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $thisTypedArrayObj, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
    var $3 = __ZN2js10TypedArray9getBufferEP8JSObject($1);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZN18TypedArrayTemplateIsE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $1, $tarray, $offset);
    var $_0 = $6;
    __label__ = 30;
    break;
   case 3:
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $8 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx_val);
    var $10 = $8 + ($offset << 1) | 0;
    var $11 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $12 = __ZN2js10TypedArray7getTypeEP8JSObject($1);
    if (($11 | 0) == ($12 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = $10;
    var $tarray_idx8_val = HEAP32[$tarray + 24 >> 2];
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx8_val);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($15, $16, $17, 1);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($11 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($11 | 0) == 1 || ($11 | 0) == 8) {
      __label__ = 9;
      break;
    } else if (($11 | 0) == 2) {
      __label__ = 12;
      break;
    } else if (($11 | 0) == 3) {
      __label__ = 15;
      break;
    } else if (($11 | 0) == 4) {
      __label__ = 18;
      break;
    } else if (($11 | 0) == 5) {
      __label__ = 21;
      break;
    } else if (($11 | 0) == 6) {
      __label__ = 24;
      break;
    } else if (($11 | 0) == 7) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 6:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $tarray_idx7_val = HEAP32[$tarray + 24 >> 2];
    var $22 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx7_val);
    var $lftr_limit45 = $22 + $19 | 0;
    var $src_036 = $22;
    var $dest_037 = $10;
    __label__ = 8;
    break;
   case 8:
    var $dest_037;
    var $src_036;
    var $24 = $src_036 + 1 | 0;
    HEAP16[$dest_037 >> 1] = HEAP8[$src_036] << 24 >> 24;
    if (($24 | 0) == ($lftr_limit45 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src_036 = $24;
      var $dest_037 = $dest_037 + 2 | 0;
      __label__ = 8;
      break;
    }
   case 9:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $tarray_idx6_val = HEAP32[$tarray + 24 >> 2];
    var $30 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx6_val);
    var $lftr_limit = $30 + $19 | 0;
    var $src1_031 = $30;
    var $dest_132 = $10;
    __label__ = 11;
    break;
   case 11:
    var $dest_132;
    var $src1_031;
    var $32 = $src1_031 + 1 | 0;
    HEAP16[$dest_132 >> 1] = HEAPU8[$src1_031] & 255;
    if (($32 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src1_031 = $32;
      var $dest_132 = $dest_132 + 2 | 0;
      __label__ = 11;
      break;
    }
   case 12:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $tarray_idx5_val = HEAP32[$tarray + 24 >> 2];
    var $38 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx5_val);
    var $i4_025 = 0;
    var $src3_026 = $38;
    var $dest_227 = $10;
    __label__ = 14;
    break;
   case 14:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    var $42 = HEAP16[$src3_026 >> 1];
    HEAP16[$dest_227 >> 1] = $42;
    var $44 = $i4_025 + 1 | 0;
    if (($44 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i4_025 = $44;
      var $src3_026 = $src3_026 + 2 | 0;
      var $dest_227 = $dest_227 + 2 | 0;
      __label__ = 14;
      break;
    }
   case 15:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $tarray_idx4_val = HEAP32[$tarray + 24 >> 2];
    var $47 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx4_val);
    var $i6_020 = 0;
    var $src5_021 = $47;
    var $dest_322 = $10;
    __label__ = 17;
    break;
   case 17:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    var $51 = HEAP16[$src5_021 >> 1];
    HEAP16[$dest_322 >> 1] = $51;
    var $53 = $i6_020 + 1 | 0;
    if (($53 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i6_020 = $53;
      var $src5_021 = $src5_021 + 2 | 0;
      var $dest_322 = $dest_322 + 2 | 0;
      __label__ = 17;
      break;
    }
   case 18:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $tarray_idx3_val = HEAP32[$tarray + 24 >> 2];
    var $56 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx3_val);
    var $i8_015 = 0;
    var $src7_016 = $56;
    var $dest_417 = $10;
    __label__ = 20;
    break;
   case 20:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    HEAP16[$dest_417 >> 1] = HEAP32[$src7_016 >> 2] & 65535;
    var $63 = $i8_015 + 1 | 0;
    if (($63 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i8_015 = $63;
      var $src7_016 = $src7_016 + 4 | 0;
      var $dest_417 = $dest_417 + 2 | 0;
      __label__ = 20;
      break;
    }
   case 21:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $tarray_idx2_val = HEAP32[$tarray + 24 >> 2];
    var $66 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx2_val);
    var $i10_010 = 0;
    var $src9_011 = $66;
    var $dest_512 = $10;
    __label__ = 23;
    break;
   case 23:
    var $dest_512;
    var $src9_011;
    var $i10_010;
    HEAP16[$dest_512 >> 1] = HEAP32[$src9_011 >> 2] & 65535;
    var $73 = $i10_010 + 1 | 0;
    if (($73 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i10_010 = $73;
      var $src9_011 = $src9_011 + 4 | 0;
      var $dest_512 = $dest_512 + 2 | 0;
      __label__ = 23;
      break;
    }
   case 24:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $tarray_idx1_val = HEAP32[$tarray + 24 >> 2];
    var $76 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx1_val);
    var $src11_05 = $76;
    var $dest_66 = $10;
    var $i12_07 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i12_07;
    var $dest_66;
    var $src11_05;
    HEAP16[$dest_66 >> 1] = HEAPF32[$src11_05 >> 2] & -1;
    var $83 = $i12_07 + 1 | 0;
    if (($83 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src11_05 = $src11_05 + 4 | 0;
      var $dest_66 = $dest_66 + 2 | 0;
      var $i12_07 = $83;
      __label__ = 26;
      break;
    }
   case 27:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    var $86 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx_val);
    var $dest_71 = $10;
    var $src13_02 = $86;
    var $i14_03 = 0;
    __label__ = 29;
    break;
   case 29:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $90 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    HEAP16[$dest_71 >> 1] = $90 & -1;
    var $93 = $i14_03 + 1 | 0;
    if (($93 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $dest_71 = $dest_71 + 2 | 0;
      var $src13_02 = $src13_02 + 8 | 0;
      var $i14_03 = $93;
      __label__ = 29;
      break;
    }
   case 30:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIsE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIsE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $other, $byteOffsetInt, $lengthInt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len1 = __stackBase__;
    var $other_idx_val = HEAP32[$other + 4 >> 2];
    var $1 = __ZNK8JSObject13isArrayBufferEv($other_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 2:
    var $4 = ($byteOffsetInt | 0) < 0 ? 0 : $byteOffsetInt;
    var $other_idx2_val = HEAP32[$other + 32 >> 2];
    var $5 = __ZN8JSObject21arrayBufferByteLengthEv($other_idx2_val);
    if ($4 >>> 0 <= $5 >>> 0 & ($4 & 1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 4:
    if (($lengthInt | 0) < 0) {
      __label__ = 5;
      break;
    } else {
      var $len_0 = $lengthInt;
      __label__ = 7;
      break;
    }
   case 5:
    var $13 = $5 - $4 | 0;
    if (($13 & -2 | 0) == ($13 | 0)) {
      var $len_0 = $13 >>> 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 7:
    var $len_0;
    var $19 = $len_0 << 1;
    if ($len_0 >>> 0 > 1073741822) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($4 >>> 0 < (2147483647 - $19 | 0) >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 10:
    if (($19 + $4 | 0) >>> 0 > $5 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 12:
    var $30 = __ZN18TypedArrayTemplateIsE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $other, $4, $len_0);
    var $_0 = $30;
    __label__ = 18;
    break;
   case 13:
    var $32 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $other, $len1);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $35 = HEAP32[$len1 >> 2];
    var $36 = __ZN18TypedArrayTemplateIsE28createBufferWithSizeAndCountEP9JSContextj($cx, $35);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $39 = __ZN18TypedArrayTemplateIsE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $36, 0, $35);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $42 = __ZN18TypedArrayTemplateIsE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $39, $other, $35, 0);
    if ($42) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 17:
    var $_0 = $39;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIsE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii["X"] = 1;

function __ZN18TypedArrayTemplateIsE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $thisTypedArrayObj, $ar, $len, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $2 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx_val);
    var $4 = $2 + ($offset << 1) | 0;
    var $ar_idx_val = HEAP32[$ar + 4 >> 2];
    var $5 = __ZNK8JSObject12isDenseArrayEv($ar_idx_val);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    }
   case 2:
    var $7 = __ZN8JSObject30getDenseArrayInitializedLengthEv($ar);
    if ($7 >>> 0 < $len >>> 0) {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($len | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $ar_idx1_val = HEAP32[$ar + 32 >> 2];
    var $11 = __ZN8JSObject21getDenseArrayElementsEv($ar_idx1_val);
    var $dest_01 = $4;
    var $src_02 = $11;
    var $i_03 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_03;
    var $src_02;
    var $dest_01;
    var $13 = $src_02 + 8 | 0;
    var $14 = __ZN18TypedArrayTemplateIsE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $src_02);
    HEAP16[$dest_01 >> 1] = $14;
    var $16 = $i_03 + 1 | 0;
    if (($16 | 0) == ($len | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      var $dest_01 = $dest_01 + 2 | 0;
      var $src_02 = $13;
      var $i_03 = $16;
      __label__ = 5;
      break;
    }
   case 6:
    var $dest_1;
    var $i1_0;
    if ($i1_0 >>> 0 < $len >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 7:
    var $19 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($ar, $cx, $i1_0, $v);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = __ZN18TypedArrayTemplateIsE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v);
    HEAP16[$dest_1 >> 1] = $22;
    var $i1_0 = $i1_0 + 1 | 0;
    var $dest_1 = $dest_1 + 2 | 0;
    __label__ = 6;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $dval = __stackBase__;
    var $v_idx3 = $v | 0;
    var $v_idx3_val$0 = HEAP32[$v_idx3 >> 2];
    var $v_idx3_val$1 = HEAP32[$v_idx3 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx3_val$0, $v_idx3_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx3_val$0, $v_idx3_val$1);
    var $_0 = $3 & 65535;
    __label__ = 9;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($v_idx3_val$0, $v_idx3_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($v);
    var $9 = __ZL15JSDOUBLE_IS_NaNd3989($8);
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $12 = __ZL20js_DoubleToECMAInt32d4007($8);
    var $_0 = $12 & 65535;
    __label__ = 9;
    break;
   case 6:
    var $15 = __ZNK2JS5Value11isPrimitiveEv($v_idx3_val$0, $v_idx3_val$1);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $17 = __ZNK2JS5Value7isMagicEv($v_idx3_val$0, $v_idx3_val$1);
    if ($17) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $19 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $v, $dval);
    var $20 = (tempDoubleI32[0] = HEAP32[$dval >> 2], tempDoubleI32[1] = HEAP32[$dval + 4 >> 2], tempDoubleF64[0]);
    var $_0 = $20 & -1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $self, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $self_idx_val = HEAP32[$self + 24 >> 2];
    var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($self_idx_val);
    var $3 = $1 + ($offset << 1) | 0;
    var $4 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $5 = __ZN2js10TypedArray7getTypeEP8JSObject($self);
    if (($4 | 0) == ($5 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $3;
    var $tarray_idx1_val = HEAP32[$tarray + 24 >> 2];
    var $9 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx1_val);
    var $10 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _llvm_memmove_p0i8_p0i8_i32($8, $9, $10, 1, 0);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 3:
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    var $13 = __ZN9JSContext7malloc_Ej($cx, $12);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx_val);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($13, $16, $17, 1);
    var $18 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    if (($18 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($18 | 0) == 1 || ($18 | 0) == 8) {
      __label__ = 6;
      break;
    } else if (($18 | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($18 | 0) == 3) {
      __label__ = 12;
      break;
    } else if (($18 | 0) == 4) {
      __label__ = 15;
      break;
    } else if (($18 | 0) == 5) {
      __label__ = 18;
      break;
    } else if (($18 | 0) == 6) {
      __label__ = 21;
      break;
    } else if (($18 | 0) == 7) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($19 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i_036 = 0;
      var $src_037 = $13;
      var $dest_038 = $3;
      __label__ = 7;
      break;
    }
   case 6:
    var $21 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($21 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i2_030 = 0;
      var $src1_031 = $13;
      var $dest_132 = $3;
      __label__ = 8;
      break;
    }
   case 7:
    var $dest_038;
    var $src_037;
    var $i_036;
    var $23 = $src_037 + 1 | 0;
    var $26 = $dest_038 + 2 | 0;
    HEAP16[$dest_038 >> 1] = HEAP8[$src_037] << 24 >> 24;
    var $27 = $i_036 + 1 | 0;
    var $28 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($27 >>> 0 < $28 >>> 0) {
      var $i_036 = $27;
      var $src_037 = $23;
      var $dest_038 = $26;
      __label__ = 7;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 8:
    var $dest_132;
    var $src1_031;
    var $i2_030;
    var $30 = $src1_031 + 1 | 0;
    var $33 = $dest_132 + 2 | 0;
    HEAP16[$dest_132 >> 1] = HEAPU8[$src1_031] & 255;
    var $34 = $i2_030 + 1 | 0;
    var $35 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($34 >>> 0 < $35 >>> 0) {
      var $i2_030 = $34;
      var $src1_031 = $30;
      var $dest_132 = $33;
      __label__ = 8;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 9:
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($38 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $i4_025 = 0;
    var $src3_026 = $13;
    var $dest_227 = $3;
    __label__ = 11;
    break;
   case 11:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    var $42 = $src3_026 + 2 | 0;
    var $43 = HEAP16[$src3_026 >> 1];
    var $44 = $dest_227 + 2 | 0;
    HEAP16[$dest_227 >> 1] = $43;
    var $45 = $i4_025 + 1 | 0;
    var $46 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($45 >>> 0 < $46 >>> 0) {
      var $i4_025 = $45;
      var $src3_026 = $42;
      var $dest_227 = $44;
      __label__ = 11;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 12:
    var $49 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($49 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i6_020 = 0;
    var $src5_021 = $13;
    var $dest_322 = $3;
    __label__ = 14;
    break;
   case 14:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    var $53 = $src5_021 + 2 | 0;
    var $54 = HEAP16[$src5_021 >> 1];
    var $55 = $dest_322 + 2 | 0;
    HEAP16[$dest_322 >> 1] = $54;
    var $56 = $i6_020 + 1 | 0;
    var $57 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($56 >>> 0 < $57 >>> 0) {
      var $i6_020 = $56;
      var $src5_021 = $53;
      var $dest_322 = $55;
      __label__ = 14;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    var $60 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($60 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i8_015 = 0;
    var $src7_016 = $13;
    var $dest_417 = $3;
    __label__ = 17;
    break;
   case 17:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    var $64 = $src7_016 + 4 | 0;
    var $67 = $dest_417 + 2 | 0;
    HEAP16[$dest_417 >> 1] = HEAP32[$src7_016 >> 2] & 65535;
    var $68 = $i8_015 + 1 | 0;
    var $69 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($68 >>> 0 < $69 >>> 0) {
      var $i8_015 = $68;
      var $src7_016 = $64;
      var $dest_417 = $67;
      __label__ = 17;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 18:
    var $72 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($72 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $src9_010 = $13;
    var $i10_011 = 0;
    var $dest_512 = $3;
    __label__ = 20;
    break;
   case 20:
    var $dest_512;
    var $i10_011;
    var $src9_010;
    var $76 = $src9_010 + 4 | 0;
    var $79 = $dest_512 + 2 | 0;
    HEAP16[$dest_512 >> 1] = HEAP32[$src9_010 >> 2] & 65535;
    var $80 = $i10_011 + 1 | 0;
    var $81 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($80 >>> 0 < $81 >>> 0) {
      var $src9_010 = $76;
      var $i10_011 = $80;
      var $dest_512 = $79;
      __label__ = 20;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 21:
    var $84 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($84 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $dest_65 = $3;
    var $src11_06 = $13;
    var $i12_07 = 0;
    __label__ = 23;
    break;
   case 23:
    var $i12_07;
    var $src11_06;
    var $dest_65;
    var $88 = $src11_06 + 4 | 0;
    var $91 = $dest_65 + 2 | 0;
    HEAP16[$dest_65 >> 1] = HEAPF32[$src11_06 >> 2] & -1;
    var $92 = $i12_07 + 1 | 0;
    var $93 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($92 >>> 0 < $93 >>> 0) {
      var $dest_65 = $91;
      var $src11_06 = $88;
      var $i12_07 = $92;
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $96 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($96 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $dest_71 = $3;
    var $src13_02 = $13;
    var $i14_03 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $100 = $src13_02 + 8 | 0;
    var $101 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $103 = $dest_71 + 2 | 0;
    HEAP16[$dest_71 >> 1] = $101 & -1;
    var $104 = $i14_03 + 1 | 0;
    var $105 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($104 >>> 0 < $105 >>> 0) {
      var $dest_71 = $103;
      var $src13_02 = $100;
      var $i14_03 = $104;
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2js10Foreground5free_EPv($13);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIsE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIhE17class_constructorEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 16 | 0;
    var $2 = __ZN18TypedArrayTemplateIhE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $byteOffset = __stackBase__ + 4;
    var $length = __stackBase__ + 8;
    HEAP32[$len >> 2] = 0;
    if (($argc | 0) == 0) {
      var $5 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL13ValueIsLengthP9JSContextRKN2JS5ValueEPj($argv, $len);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $5 = HEAP32[$len >> 2];
    __label__ = 4;
    break;
   case 4:
    var $5;
    var $6 = __ZN18TypedArrayTemplateIhE28createBufferWithSizeAndCountEP9JSContextj($cx, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZN18TypedArrayTemplateIhE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $6, 0, $5);
    var $_0 = $9;
    __label__ = 22;
    break;
   case 6:
    var $argv_idx = $argv | 0;
    var $argv_idx_val$0 = HEAP32[$argv_idx >> 2];
    var $argv_idx_val$1 = HEAP32[$argv_idx + 4 >> 2];
    var $11 = __ZNK2JS5Value8isObjectEv($argv_idx_val$0, $argv_idx_val$1);
    if ($11) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 8:
    var $14 = __ZNK2JS5Value8toObjectEv($argv_idx_val$0, $argv_idx_val$1);
    var $_idx_val = HEAP32[$14 + 4 >> 2];
    var $15 = __Z15js_IsTypedArrayP8JSObject($_idx_val);
    if (($15 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $18 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($14);
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($18);
    var $20 = __ZN18TypedArrayTemplateIhE28createBufferWithSizeAndCountEP9JSContextj($cx, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $23 = __ZN18TypedArrayTemplateIhE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $20, 0, $19);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = __ZN18TypedArrayTemplateIhE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $23, $18, 0);
    if ($26) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 12:
    var $_0 = $23;
    __label__ = 22;
    break;
   case 13:
    HEAP32[$byteOffset >> 2] = -1;
    HEAP32[$length >> 2] = -1;
    if ($argc >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      var $48 = -1;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 14:
    var $31 = $argv + 8 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $byteOffset);
    if ($32) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 15:
    var $34 = HEAPU32[$byteOffset >> 2];
    if (($34 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 4, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str163973 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 17:
    if ($argc >>> 0 > 2) {
      __label__ = 18;
      break;
    } else {
      var $48 = $34;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 18:
    var $40 = $argv + 16 | 0;
    var $41 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $40, $length);
    if ($41) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 19:
    var $43 = HEAPU32[$length >> 2];
    if (($43 | 0) < 0) {
      __label__ = 20;
      break;
    } else {
      var $48 = $34;
      var $47 = $43;
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 4, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str173974 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 21:
    var $47;
    var $48;
    var $49 = __ZN18TypedArrayTemplateIhE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $14, $48, $47);
    var $_0 = $49;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIhE6createEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIhE28createBufferWithSizeAndCountEP9JSContextj($cx, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 > 2147483646) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 4, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str183975 | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $4 = __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $count);
    var $_0 = $4;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $bufobj, $byteOffset, $len) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981($cx, __ZN2js10TypedArray11slowClassesE + 232 | 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAPU32[__ZN2js10TypedArray11slowClassesE + 236 >> 2] >>> 24;
    var $11 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($6, $11);
    __ZN2JSL10Int32ValueEi3996($1, 1);
    var $_idx4 = $1 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 3, $_idx4_val$0, $_idx4_val$1);
    __ZN2JSL11ObjectValueER8JSObject3997($2, $bufobj);
    var $_idx3 = $2 | 0;
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 4, $_idx3_val$0, $_idx3_val$1);
    var $bufobj_idx_val = HEAP32[$bufobj + 32 >> 2];
    var $14 = __ZN8JSObject21arrayBufferDataOffsetEv($bufobj_idx_val);
    var $15 = $14 + $byteOffset | 0;
    __ZN8JSObject10setPrivateEPv($6, $15);
    __ZN2JSL10Int32ValueEi3996($3, $len);
    var $_idx2 = $3 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 0, $_idx2_val$0, $_idx2_val$1);
    __ZN2JSL10Int32ValueEi3996($4, $byteOffset);
    var $_idx1 = $4 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 1, $_idx1_val$0, $_idx1_val$1);
    __ZN2JSL10Int32ValueEi3996($5, $len);
    var $_idx = $5 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 2, $_idx_val$0, $_idx_val$1);
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    __ZN8JSObject8setClassEPN2js5ClassE($6, __ZN2js10TypedArray11fastClassesE + 232 | 0);
    var $16 = $6 + 8 | 0;
    var $18 = HEAP32[$16 >> 2] | 4;
    HEAP32[$16 >> 2] = $18;
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIhE16createTypedArrayEP9JSContextP8JSObjectjj["X"] = 1;

function __ZN18TypedArrayTemplateIhE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $thisTypedArrayObj, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
    var $3 = __ZN2js10TypedArray9getBufferEP8JSObject($1);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZN18TypedArrayTemplateIhE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $1, $tarray, $offset);
    var $_0 = $6;
    __label__ = 30;
    break;
   case 3:
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $8 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx_val);
    var $9 = $8 + $offset | 0;
    var $10 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $11 = __ZN2js10TypedArray7getTypeEP8JSObject($1);
    if (($10 | 0) == ($11 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $tarray_idx8_val = HEAP32[$tarray + 24 >> 2];
    var $14 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx8_val);
    var $15 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($9, $14, $15, 1);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 5:
    var $17 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($10 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($10 | 0) == 1 || ($10 | 0) == 8) {
      __label__ = 9;
      break;
    } else if (($10 | 0) == 2) {
      __label__ = 12;
      break;
    } else if (($10 | 0) == 3) {
      __label__ = 15;
      break;
    } else if (($10 | 0) == 4) {
      __label__ = 18;
      break;
    } else if (($10 | 0) == 5) {
      __label__ = 21;
      break;
    } else if (($10 | 0) == 6) {
      __label__ = 24;
      break;
    } else if (($10 | 0) == 7) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 6:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $tarray_idx7_val = HEAP32[$tarray + 24 >> 2];
    var $20 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx7_val);
    var $lftr_limit51 = $8 + ($17 + $offset) | 0;
    var $src_036 = $20;
    var $dest_037 = $9;
    __label__ = 8;
    break;
   case 8:
    var $dest_037;
    var $src_036;
    var $23 = HEAP8[$src_036];
    var $24 = $dest_037 + 1 | 0;
    HEAP8[$dest_037] = $23;
    if (($24 | 0) == ($lftr_limit51 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src_036 = $src_036 + 1 | 0;
      var $dest_037 = $24;
      __label__ = 8;
      break;
    }
   case 9:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $tarray_idx6_val = HEAP32[$tarray + 24 >> 2];
    var $27 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx6_val);
    var $lftr_limit49 = $8 + ($17 + $offset) | 0;
    var $src1_031 = $27;
    var $dest_132 = $9;
    __label__ = 11;
    break;
   case 11:
    var $dest_132;
    var $src1_031;
    var $30 = HEAP8[$src1_031];
    var $31 = $dest_132 + 1 | 0;
    HEAP8[$dest_132] = $30;
    if (($31 | 0) == ($lftr_limit49 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src1_031 = $src1_031 + 1 | 0;
      var $dest_132 = $31;
      __label__ = 11;
      break;
    }
   case 12:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $tarray_idx5_val = HEAP32[$tarray + 24 >> 2];
    var $34 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx5_val);
    var $lftr_limit47 = $8 + ($17 + $offset) | 0;
    var $src3_026 = $34;
    var $dest_227 = $9;
    __label__ = 14;
    break;
   case 14:
    var $dest_227;
    var $src3_026;
    var $40 = $dest_227 + 1 | 0;
    HEAP8[$dest_227] = HEAP16[$src3_026 >> 1] & 255;
    if (($40 | 0) == ($lftr_limit47 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src3_026 = $src3_026 + 2 | 0;
      var $dest_227 = $40;
      __label__ = 14;
      break;
    }
   case 15:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $tarray_idx4_val = HEAP32[$tarray + 24 >> 2];
    var $43 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx4_val);
    var $lftr_limit45 = $8 + ($17 + $offset) | 0;
    var $src5_021 = $43;
    var $dest_322 = $9;
    __label__ = 17;
    break;
   case 17:
    var $dest_322;
    var $src5_021;
    var $49 = $dest_322 + 1 | 0;
    HEAP8[$dest_322] = HEAP16[$src5_021 >> 1] & 255;
    if (($49 | 0) == ($lftr_limit45 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src5_021 = $src5_021 + 2 | 0;
      var $dest_322 = $49;
      __label__ = 17;
      break;
    }
   case 18:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $tarray_idx3_val = HEAP32[$tarray + 24 >> 2];
    var $52 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx3_val);
    var $lftr_limit43 = $8 + ($17 + $offset) | 0;
    var $src7_016 = $52;
    var $dest_417 = $9;
    __label__ = 20;
    break;
   case 20:
    var $dest_417;
    var $src7_016;
    var $58 = $dest_417 + 1 | 0;
    HEAP8[$dest_417] = HEAP32[$src7_016 >> 2] & 255;
    if (($58 | 0) == ($lftr_limit43 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src7_016 = $src7_016 + 4 | 0;
      var $dest_417 = $58;
      __label__ = 20;
      break;
    }
   case 21:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $tarray_idx2_val = HEAP32[$tarray + 24 >> 2];
    var $61 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx2_val);
    var $lftr_limit41 = $8 + ($17 + $offset) | 0;
    var $src9_011 = $61;
    var $dest_512 = $9;
    __label__ = 23;
    break;
   case 23:
    var $dest_512;
    var $src9_011;
    var $67 = $dest_512 + 1 | 0;
    HEAP8[$dest_512] = HEAP32[$src9_011 >> 2] & 255;
    if (($67 | 0) == ($lftr_limit41 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src9_011 = $src9_011 + 4 | 0;
      var $dest_512 = $67;
      __label__ = 23;
      break;
    }
   case 24:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $tarray_idx1_val = HEAP32[$tarray + 24 >> 2];
    var $70 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx1_val);
    var $lftr_limit39 = $8 + ($17 + $offset) | 0;
    var $src11_05 = $70;
    var $dest_66 = $9;
    __label__ = 26;
    break;
   case 26:
    var $dest_66;
    var $src11_05;
    var $73 = $src11_05 + 4 | 0;
    var $74 = HEAPF32[$src11_05 >> 2];
    var $75 = $74 >= 0 ? Math.floor($74) : Math.ceil($74);
    var $76 = $dest_66 + 1 | 0;
    HEAP8[$dest_66] = $75;
    if (($76 | 0) == ($lftr_limit39 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src11_05 = $73;
      var $dest_66 = $76;
      __label__ = 26;
      break;
    }
   case 27:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    var $79 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx_val);
    var $lftr_limit = $8 + ($17 + $offset) | 0;
    var $dest_71 = $9;
    var $src13_02 = $79;
    __label__ = 29;
    break;
   case 29:
    var $src13_02;
    var $dest_71;
    var $82 = $src13_02 + 8 | 0;
    var $83 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $84 = $83 >= 0 ? Math.floor($83) : Math.ceil($83);
    var $85 = $dest_71 + 1 | 0;
    HEAP8[$dest_71] = $84;
    if (($85 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $dest_71 = $85;
      var $src13_02 = $82;
      __label__ = 29;
      break;
    }
   case 30:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIhE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIhE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $other, $byteOffsetInt, $lengthInt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len1 = __stackBase__;
    var $other_idx_val = HEAP32[$other + 4 >> 2];
    var $1 = __ZNK8JSObject13isArrayBufferEv($other_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    var $4 = ($byteOffsetInt | 0) < 0 ? 0 : $byteOffsetInt;
    var $other_idx2_val = HEAP32[$other + 32 >> 2];
    var $5 = __ZN8JSObject21arrayBufferByteLengthEv($other_idx2_val);
    if ($4 >>> 0 > $5 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 4:
    var $_lengthInt = ($lengthInt | 0) < 0 ? $5 - $4 | 0 : $lengthInt;
    if ($_lengthInt >>> 0 < 2147483647 & $4 >>> 0 < (2147483647 - $_lengthInt | 0) >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 6:
    if (($_lengthInt + $4 | 0) >>> 0 > $5 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 8:
    var $20 = __ZN18TypedArrayTemplateIhE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $other, $4, $_lengthInt);
    var $_0 = $20;
    __label__ = 14;
    break;
   case 9:
    var $22 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $other, $len1);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $25 = HEAP32[$len1 >> 2];
    var $26 = __ZN18TypedArrayTemplateIhE28createBufferWithSizeAndCountEP9JSContextj($cx, $25);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $29 = __ZN18TypedArrayTemplateIhE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $26, 0, $25);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $32 = __ZN18TypedArrayTemplateIhE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $29, $other, $25, 0);
    if ($32) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 13:
    var $_0 = $29;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $thisTypedArrayObj, $ar, $len, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $2 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx_val);
    var $3 = $2 + $offset | 0;
    var $ar_idx_val = HEAP32[$ar + 4 >> 2];
    var $4 = __ZNK8JSObject12isDenseArrayEv($ar_idx_val);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $i1_0 = 0;
      var $dest_1 = $3;
      __label__ = 6;
      break;
    }
   case 2:
    var $6 = __ZN8JSObject30getDenseArrayInitializedLengthEv($ar);
    if ($6 >>> 0 < $len >>> 0) {
      var $i1_0 = 0;
      var $dest_1 = $3;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($len | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $ar_idx1_val = HEAP32[$ar + 32 >> 2];
    var $10 = __ZN8JSObject21getDenseArrayElementsEv($ar_idx1_val);
    var $lftr_limit = $2 + ($offset + $len) | 0;
    var $dest_01 = $3;
    var $src_02 = $10;
    __label__ = 5;
    break;
   case 5:
    var $src_02;
    var $dest_01;
    var $12 = $src_02 + 8 | 0;
    var $13 = __ZN18TypedArrayTemplateIhE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $src_02);
    var $14 = $dest_01 + 1 | 0;
    HEAP8[$dest_01] = $13;
    if (($14 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      var $dest_01 = $14;
      var $src_02 = $12;
      __label__ = 5;
      break;
    }
   case 6:
    var $dest_1;
    var $i1_0;
    if ($i1_0 >>> 0 < $len >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 7:
    var $17 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($ar, $cx, $i1_0, $v);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = __ZN18TypedArrayTemplateIhE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v);
    HEAP8[$dest_1] = $20;
    var $i1_0 = $i1_0 + 1 | 0;
    var $dest_1 = $dest_1 + 1 | 0;
    __label__ = 6;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $dval = __stackBase__;
    var $v_idx3 = $v | 0;
    var $v_idx3_val$0 = HEAP32[$v_idx3 >> 2];
    var $v_idx3_val$1 = HEAP32[$v_idx3 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx3_val$0, $v_idx3_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx3_val$0, $v_idx3_val$1);
    var $_0 = $3 & 255;
    __label__ = 9;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($v_idx3_val$0, $v_idx3_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($v);
    var $9 = __ZL15JSDOUBLE_IS_NaNd3989($8);
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $12 = __Z21js_DoubleToECMAUint32d($8);
    var $_0 = $12 & 255;
    __label__ = 9;
    break;
   case 6:
    var $15 = __ZNK2JS5Value11isPrimitiveEv($v_idx3_val$0, $v_idx3_val$1);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $17 = __ZNK2JS5Value7isMagicEv($v_idx3_val$0, $v_idx3_val$1);
    if ($17) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $19 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $v, $dval);
    var $20 = (tempDoubleI32[0] = HEAP32[$dval >> 2], tempDoubleI32[1] = HEAP32[$dval + 4 >> 2], tempDoubleF64[0]);
    var $21 = $20 >= 0 ? Math.floor($20) : Math.ceil($20);
    var $_0 = $21;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $self, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $self_idx_val = HEAP32[$self + 24 >> 2];
    var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($self_idx_val);
    var $2 = $1 + $offset | 0;
    var $3 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $4 = __ZN2js10TypedArray7getTypeEP8JSObject($self);
    if (($3 | 0) == ($4 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $tarray_idx1_val = HEAP32[$tarray + 24 >> 2];
    var $7 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx1_val);
    var $8 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _llvm_memmove_p0i8_p0i8_i32($2, $7, $8, 1, 0);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 3:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    var $11 = __ZN9JSContext7malloc_Ej($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    var $14 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx_val);
    var $15 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($11, $14, $15, 1);
    var $16 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    if (($16 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($16 | 0) == 1 || ($16 | 0) == 8) {
      __label__ = 6;
      break;
    } else if (($16 | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($16 | 0) == 3) {
      __label__ = 12;
      break;
    } else if (($16 | 0) == 4) {
      __label__ = 15;
      break;
    } else if (($16 | 0) == 5) {
      __label__ = 18;
      break;
    } else if (($16 | 0) == 6) {
      __label__ = 21;
      break;
    } else if (($16 | 0) == 7) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 5:
    var $17 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($17 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i_036 = 0;
      var $src_037 = $11;
      var $dest_038 = $2;
      __label__ = 7;
      break;
    }
   case 6:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($19 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i2_030 = 0;
      var $src1_031 = $11;
      var $dest_132 = $2;
      __label__ = 8;
      break;
    }
   case 7:
    var $dest_038;
    var $src_037;
    var $i_036;
    var $21 = $src_037 + 1 | 0;
    var $22 = HEAP8[$src_037];
    var $23 = $dest_038 + 1 | 0;
    HEAP8[$dest_038] = $22;
    var $24 = $i_036 + 1 | 0;
    var $25 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($24 >>> 0 < $25 >>> 0) {
      var $i_036 = $24;
      var $src_037 = $21;
      var $dest_038 = $23;
      __label__ = 7;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 8:
    var $dest_132;
    var $src1_031;
    var $i2_030;
    var $27 = $src1_031 + 1 | 0;
    var $28 = HEAP8[$src1_031];
    var $29 = $dest_132 + 1 | 0;
    HEAP8[$dest_132] = $28;
    var $30 = $i2_030 + 1 | 0;
    var $31 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($30 >>> 0 < $31 >>> 0) {
      var $i2_030 = $30;
      var $src1_031 = $27;
      var $dest_132 = $29;
      __label__ = 8;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 9:
    var $34 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($34 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $i4_025 = 0;
    var $src3_026 = $11;
    var $dest_227 = $2;
    __label__ = 11;
    break;
   case 11:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    var $38 = $src3_026 + 2 | 0;
    var $41 = $dest_227 + 1 | 0;
    HEAP8[$dest_227] = HEAP16[$src3_026 >> 1] & 255;
    var $42 = $i4_025 + 1 | 0;
    var $43 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($42 >>> 0 < $43 >>> 0) {
      var $i4_025 = $42;
      var $src3_026 = $38;
      var $dest_227 = $41;
      __label__ = 11;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 12:
    var $46 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($46 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i6_020 = 0;
    var $src5_021 = $11;
    var $dest_322 = $2;
    __label__ = 14;
    break;
   case 14:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    var $50 = $src5_021 + 2 | 0;
    var $53 = $dest_322 + 1 | 0;
    HEAP8[$dest_322] = HEAP16[$src5_021 >> 1] & 255;
    var $54 = $i6_020 + 1 | 0;
    var $55 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($54 >>> 0 < $55 >>> 0) {
      var $i6_020 = $54;
      var $src5_021 = $50;
      var $dest_322 = $53;
      __label__ = 14;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    var $58 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($58 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i8_015 = 0;
    var $src7_016 = $11;
    var $dest_417 = $2;
    __label__ = 17;
    break;
   case 17:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    var $62 = $src7_016 + 4 | 0;
    var $65 = $dest_417 + 1 | 0;
    HEAP8[$dest_417] = HEAP32[$src7_016 >> 2] & 255;
    var $66 = $i8_015 + 1 | 0;
    var $67 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($66 >>> 0 < $67 >>> 0) {
      var $i8_015 = $66;
      var $src7_016 = $62;
      var $dest_417 = $65;
      __label__ = 17;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 18:
    var $70 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($70 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $src9_010 = $11;
    var $i10_011 = 0;
    var $dest_512 = $2;
    __label__ = 20;
    break;
   case 20:
    var $dest_512;
    var $i10_011;
    var $src9_010;
    var $74 = $src9_010 + 4 | 0;
    var $77 = $dest_512 + 1 | 0;
    HEAP8[$dest_512] = HEAP32[$src9_010 >> 2] & 255;
    var $78 = $i10_011 + 1 | 0;
    var $79 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($78 >>> 0 < $79 >>> 0) {
      var $src9_010 = $74;
      var $i10_011 = $78;
      var $dest_512 = $77;
      __label__ = 20;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 21:
    var $82 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($82 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $dest_65 = $2;
    var $src11_06 = $11;
    var $i12_07 = 0;
    __label__ = 23;
    break;
   case 23:
    var $i12_07;
    var $src11_06;
    var $dest_65;
    var $86 = $src11_06 + 4 | 0;
    var $87 = HEAPF32[$src11_06 >> 2];
    var $88 = $87 >= 0 ? Math.floor($87) : Math.ceil($87);
    var $89 = $dest_65 + 1 | 0;
    HEAP8[$dest_65] = $88;
    var $90 = $i12_07 + 1 | 0;
    var $91 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($90 >>> 0 < $91 >>> 0) {
      var $dest_65 = $89;
      var $src11_06 = $86;
      var $i12_07 = $90;
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $94 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($94 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $dest_71 = $2;
    var $src13_02 = $11;
    var $i14_03 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $98 = $src13_02 + 8 | 0;
    var $99 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $100 = $99 >= 0 ? Math.floor($99) : Math.ceil($99);
    var $101 = $dest_71 + 1 | 0;
    HEAP8[$dest_71] = $100;
    var $102 = $i14_03 + 1 | 0;
    var $103 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($102 >>> 0 < $103 >>> 0) {
      var $dest_71 = $101;
      var $src13_02 = $98;
      var $i14_03 = $102;
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2js10Foreground5free_EPv($11);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIhE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIaE17class_constructorEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 16 | 0;
    var $2 = __ZN18TypedArrayTemplateIaE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $byteOffset = __stackBase__ + 4;
    var $length = __stackBase__ + 8;
    HEAP32[$len >> 2] = 0;
    if (($argc | 0) == 0) {
      var $5 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL13ValueIsLengthP9JSContextRKN2JS5ValueEPj($argv, $len);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $5 = HEAP32[$len >> 2];
    __label__ = 4;
    break;
   case 4:
    var $5;
    var $6 = __ZN18TypedArrayTemplateIaE28createBufferWithSizeAndCountEP9JSContextj($cx, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZN18TypedArrayTemplateIaE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $6, 0, $5);
    var $_0 = $9;
    __label__ = 22;
    break;
   case 6:
    var $argv_idx = $argv | 0;
    var $argv_idx_val$0 = HEAP32[$argv_idx >> 2];
    var $argv_idx_val$1 = HEAP32[$argv_idx + 4 >> 2];
    var $11 = __ZNK2JS5Value8isObjectEv($argv_idx_val$0, $argv_idx_val$1);
    if ($11) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 8:
    var $14 = __ZNK2JS5Value8toObjectEv($argv_idx_val$0, $argv_idx_val$1);
    var $_idx_val = HEAP32[$14 + 4 >> 2];
    var $15 = __Z15js_IsTypedArrayP8JSObject($_idx_val);
    if (($15 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $18 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($14);
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($18);
    var $20 = __ZN18TypedArrayTemplateIaE28createBufferWithSizeAndCountEP9JSContextj($cx, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $23 = __ZN18TypedArrayTemplateIaE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $20, 0, $19);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = __ZN18TypedArrayTemplateIaE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $23, $18, 0);
    if ($26) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 12:
    var $_0 = $23;
    __label__ = 22;
    break;
   case 13:
    HEAP32[$byteOffset >> 2] = -1;
    HEAP32[$length >> 2] = -1;
    if ($argc >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      var $48 = -1;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 14:
    var $31 = $argv + 8 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $byteOffset);
    if ($32) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 15:
    var $34 = HEAPU32[$byteOffset >> 2];
    if (($34 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 4, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str163973 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 17:
    if ($argc >>> 0 > 2) {
      __label__ = 18;
      break;
    } else {
      var $48 = $34;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 18:
    var $40 = $argv + 16 | 0;
    var $41 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $40, $length);
    if ($41) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 19:
    var $43 = HEAPU32[$length >> 2];
    if (($43 | 0) < 0) {
      __label__ = 20;
      break;
    } else {
      var $48 = $34;
      var $47 = $43;
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 4, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str173974 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 21:
    var $47;
    var $48;
    var $49 = __ZN18TypedArrayTemplateIaE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $14, $48, $47);
    var $_0 = $49;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIaE6createEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIaE28createBufferWithSizeAndCountEP9JSContextj($cx, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 > 2147483646) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 4, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str183975 | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $4 = __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $count);
    var $_0 = $4;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $bufobj, $byteOffset, $len) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981($cx, __ZN2js10TypedArray11slowClassesE | 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAPU32[__ZN2js10TypedArray11slowClassesE + 4 >> 2] >>> 24;
    var $11 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($6, $11);
    __ZN2JSL10Int32ValueEi3996($1, 0);
    var $_idx4 = $1 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 3, $_idx4_val$0, $_idx4_val$1);
    __ZN2JSL11ObjectValueER8JSObject3997($2, $bufobj);
    var $_idx3 = $2 | 0;
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 4, $_idx3_val$0, $_idx3_val$1);
    var $bufobj_idx_val = HEAP32[$bufobj + 32 >> 2];
    var $14 = __ZN8JSObject21arrayBufferDataOffsetEv($bufobj_idx_val);
    var $15 = $14 + $byteOffset | 0;
    __ZN8JSObject10setPrivateEPv($6, $15);
    __ZN2JSL10Int32ValueEi3996($3, $len);
    var $_idx2 = $3 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 0, $_idx2_val$0, $_idx2_val$1);
    __ZN2JSL10Int32ValueEi3996($4, $byteOffset);
    var $_idx1 = $4 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 1, $_idx1_val$0, $_idx1_val$1);
    __ZN2JSL10Int32ValueEi3996($5, $len);
    var $_idx = $5 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 2, $_idx_val$0, $_idx_val$1);
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    __ZN8JSObject8setClassEPN2js5ClassE($6, __ZN2js10TypedArray11fastClassesE);
    var $16 = $6 + 8 | 0;
    var $18 = HEAP32[$16 >> 2] | 4;
    HEAP32[$16 >> 2] = $18;
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIaE16createTypedArrayEP9JSContextP8JSObjectjj["X"] = 1;

function __ZNK13uint8_clampedcvhEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN13uint8_clampedC2ERKS_($this, $other_0_0_val) {
  HEAP8[$this | 0] = $other_0_0_val;
  return;
}

function __ZN18TypedArrayTemplateIaE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $thisTypedArrayObj, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
    var $3 = __ZN2js10TypedArray9getBufferEP8JSObject($1);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZN18TypedArrayTemplateIaE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $1, $tarray, $offset);
    var $_0 = $6;
    __label__ = 30;
    break;
   case 3:
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $8 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx_val);
    var $9 = $8 + $offset | 0;
    var $10 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $11 = __ZN2js10TypedArray7getTypeEP8JSObject($1);
    if (($10 | 0) == ($11 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $tarray_idx8_val = HEAP32[$tarray + 24 >> 2];
    var $14 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx8_val);
    var $15 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($9, $14, $15, 1);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 5:
    var $17 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($10 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($10 | 0) == 1 || ($10 | 0) == 8) {
      __label__ = 9;
      break;
    } else if (($10 | 0) == 2) {
      __label__ = 12;
      break;
    } else if (($10 | 0) == 3) {
      __label__ = 15;
      break;
    } else if (($10 | 0) == 4) {
      __label__ = 18;
      break;
    } else if (($10 | 0) == 5) {
      __label__ = 21;
      break;
    } else if (($10 | 0) == 6) {
      __label__ = 24;
      break;
    } else if (($10 | 0) == 7) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 6:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $tarray_idx7_val = HEAP32[$tarray + 24 >> 2];
    var $20 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx7_val);
    var $lftr_limit51 = $8 + ($17 + $offset) | 0;
    var $src_036 = $20;
    var $dest_037 = $9;
    __label__ = 8;
    break;
   case 8:
    var $dest_037;
    var $src_036;
    var $23 = HEAP8[$src_036];
    var $24 = $dest_037 + 1 | 0;
    HEAP8[$dest_037] = $23;
    if (($24 | 0) == ($lftr_limit51 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src_036 = $src_036 + 1 | 0;
      var $dest_037 = $24;
      __label__ = 8;
      break;
    }
   case 9:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $tarray_idx6_val = HEAP32[$tarray + 24 >> 2];
    var $27 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx6_val);
    var $lftr_limit49 = $8 + ($17 + $offset) | 0;
    var $src1_031 = $27;
    var $dest_132 = $9;
    __label__ = 11;
    break;
   case 11:
    var $dest_132;
    var $src1_031;
    var $30 = HEAP8[$src1_031];
    var $31 = $dest_132 + 1 | 0;
    HEAP8[$dest_132] = $30;
    if (($31 | 0) == ($lftr_limit49 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src1_031 = $src1_031 + 1 | 0;
      var $dest_132 = $31;
      __label__ = 11;
      break;
    }
   case 12:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $tarray_idx5_val = HEAP32[$tarray + 24 >> 2];
    var $34 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx5_val);
    var $lftr_limit47 = $8 + ($17 + $offset) | 0;
    var $src3_026 = $34;
    var $dest_227 = $9;
    __label__ = 14;
    break;
   case 14:
    var $dest_227;
    var $src3_026;
    var $40 = $dest_227 + 1 | 0;
    HEAP8[$dest_227] = HEAP16[$src3_026 >> 1] & 255;
    if (($40 | 0) == ($lftr_limit47 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src3_026 = $src3_026 + 2 | 0;
      var $dest_227 = $40;
      __label__ = 14;
      break;
    }
   case 15:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $tarray_idx4_val = HEAP32[$tarray + 24 >> 2];
    var $43 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx4_val);
    var $lftr_limit45 = $8 + ($17 + $offset) | 0;
    var $src5_021 = $43;
    var $dest_322 = $9;
    __label__ = 17;
    break;
   case 17:
    var $dest_322;
    var $src5_021;
    var $49 = $dest_322 + 1 | 0;
    HEAP8[$dest_322] = HEAP16[$src5_021 >> 1] & 255;
    if (($49 | 0) == ($lftr_limit45 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src5_021 = $src5_021 + 2 | 0;
      var $dest_322 = $49;
      __label__ = 17;
      break;
    }
   case 18:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $tarray_idx3_val = HEAP32[$tarray + 24 >> 2];
    var $52 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx3_val);
    var $lftr_limit43 = $8 + ($17 + $offset) | 0;
    var $src7_016 = $52;
    var $dest_417 = $9;
    __label__ = 20;
    break;
   case 20:
    var $dest_417;
    var $src7_016;
    var $58 = $dest_417 + 1 | 0;
    HEAP8[$dest_417] = HEAP32[$src7_016 >> 2] & 255;
    if (($58 | 0) == ($lftr_limit43 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src7_016 = $src7_016 + 4 | 0;
      var $dest_417 = $58;
      __label__ = 20;
      break;
    }
   case 21:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $tarray_idx2_val = HEAP32[$tarray + 24 >> 2];
    var $61 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx2_val);
    var $lftr_limit41 = $8 + ($17 + $offset) | 0;
    var $src9_011 = $61;
    var $dest_512 = $9;
    __label__ = 23;
    break;
   case 23:
    var $dest_512;
    var $src9_011;
    var $67 = $dest_512 + 1 | 0;
    HEAP8[$dest_512] = HEAP32[$src9_011 >> 2] & 255;
    if (($67 | 0) == ($lftr_limit41 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src9_011 = $src9_011 + 4 | 0;
      var $dest_512 = $67;
      __label__ = 23;
      break;
    }
   case 24:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $tarray_idx1_val = HEAP32[$tarray + 24 >> 2];
    var $70 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx1_val);
    var $lftr_limit39 = $8 + ($17 + $offset) | 0;
    var $src11_05 = $70;
    var $dest_66 = $9;
    __label__ = 26;
    break;
   case 26:
    var $dest_66;
    var $src11_05;
    var $76 = $dest_66 + 1 | 0;
    HEAP8[$dest_66] = HEAPF32[$src11_05 >> 2] & -1;
    if (($76 | 0) == ($lftr_limit39 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src11_05 = $src11_05 + 4 | 0;
      var $dest_66 = $76;
      __label__ = 26;
      break;
    }
   case 27:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    var $79 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx_val);
    var $lftr_limit = $8 + ($17 + $offset) | 0;
    var $dest_71 = $9;
    var $src13_02 = $79;
    __label__ = 29;
    break;
   case 29:
    var $src13_02;
    var $dest_71;
    var $83 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $85 = $dest_71 + 1 | 0;
    HEAP8[$dest_71] = $83 & -1;
    if (($85 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $dest_71 = $85;
      var $src13_02 = $src13_02 + 8 | 0;
      __label__ = 29;
      break;
    }
   case 30:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIaE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIaE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $other, $byteOffsetInt, $lengthInt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len1 = __stackBase__;
    var $other_idx_val = HEAP32[$other + 4 >> 2];
    var $1 = __ZNK8JSObject13isArrayBufferEv($other_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    var $4 = ($byteOffsetInt | 0) < 0 ? 0 : $byteOffsetInt;
    var $other_idx2_val = HEAP32[$other + 32 >> 2];
    var $5 = __ZN8JSObject21arrayBufferByteLengthEv($other_idx2_val);
    if ($4 >>> 0 > $5 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 4:
    var $_lengthInt = ($lengthInt | 0) < 0 ? $5 - $4 | 0 : $lengthInt;
    if ($_lengthInt >>> 0 < 2147483647 & $4 >>> 0 < (2147483647 - $_lengthInt | 0) >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 6:
    if (($_lengthInt + $4 | 0) >>> 0 > $5 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 4, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 8:
    var $20 = __ZN18TypedArrayTemplateIaE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $other, $4, $_lengthInt);
    var $_0 = $20;
    __label__ = 14;
    break;
   case 9:
    var $22 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $other, $len1);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $25 = HEAP32[$len1 >> 2];
    var $26 = __ZN18TypedArrayTemplateIaE28createBufferWithSizeAndCountEP9JSContextj($cx, $25);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $29 = __ZN18TypedArrayTemplateIaE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $26, 0, $25);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $32 = __ZN18TypedArrayTemplateIaE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $29, $other, $25, 0);
    if ($32) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 13:
    var $_0 = $29;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $thisTypedArrayObj, $ar, $len, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $2 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx_val);
    var $3 = $2 + $offset | 0;
    var $ar_idx_val = HEAP32[$ar + 4 >> 2];
    var $4 = __ZNK8JSObject12isDenseArrayEv($ar_idx_val);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $i1_0 = 0;
      var $dest_1 = $3;
      __label__ = 6;
      break;
    }
   case 2:
    var $6 = __ZN8JSObject30getDenseArrayInitializedLengthEv($ar);
    if ($6 >>> 0 < $len >>> 0) {
      var $i1_0 = 0;
      var $dest_1 = $3;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($len | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $ar_idx1_val = HEAP32[$ar + 32 >> 2];
    var $10 = __ZN8JSObject21getDenseArrayElementsEv($ar_idx1_val);
    var $lftr_limit = $2 + ($offset + $len) | 0;
    var $dest_01 = $3;
    var $src_02 = $10;
    __label__ = 5;
    break;
   case 5:
    var $src_02;
    var $dest_01;
    var $12 = $src_02 + 8 | 0;
    var $13 = __ZN18TypedArrayTemplateIaE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $src_02);
    var $14 = $dest_01 + 1 | 0;
    HEAP8[$dest_01] = $13;
    if (($14 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      var $dest_01 = $14;
      var $src_02 = $12;
      __label__ = 5;
      break;
    }
   case 6:
    var $dest_1;
    var $i1_0;
    if ($i1_0 >>> 0 < $len >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 7:
    var $17 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($ar, $cx, $i1_0, $v);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = __ZN18TypedArrayTemplateIaE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v);
    HEAP8[$dest_1] = $20;
    var $i1_0 = $i1_0 + 1 | 0;
    var $dest_1 = $dest_1 + 1 | 0;
    __label__ = 6;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $dval = __stackBase__;
    var $v_idx3 = $v | 0;
    var $v_idx3_val$0 = HEAP32[$v_idx3 >> 2];
    var $v_idx3_val$1 = HEAP32[$v_idx3 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($v_idx3_val$0, $v_idx3_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v_idx3_val$0, $v_idx3_val$1);
    var $_0 = $3 & 255;
    __label__ = 9;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($v_idx3_val$0, $v_idx3_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($v);
    var $9 = __ZL15JSDOUBLE_IS_NaNd3989($8);
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $12 = __ZL20js_DoubleToECMAInt32d4007($8);
    var $_0 = $12 & 255;
    __label__ = 9;
    break;
   case 6:
    var $15 = __ZNK2JS5Value11isPrimitiveEv($v_idx3_val$0, $v_idx3_val$1);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $17 = __ZNK2JS5Value7isMagicEv($v_idx3_val$0, $v_idx3_val$1);
    if ($17) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $19 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $v, $dval);
    var $20 = (tempDoubleI32[0] = HEAP32[$dval >> 2], tempDoubleI32[1] = HEAP32[$dval + 4 >> 2], tempDoubleF64[0]);
    var $_0 = $20 & -1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $self, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $self_idx_val = HEAP32[$self + 24 >> 2];
    var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($self_idx_val);
    var $2 = $1 + $offset | 0;
    var $3 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $4 = __ZN2js10TypedArray7getTypeEP8JSObject($self);
    if (($3 | 0) == ($4 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $tarray_idx1_val = HEAP32[$tarray + 24 >> 2];
    var $7 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx1_val);
    var $8 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _llvm_memmove_p0i8_p0i8_i32($2, $7, $8, 1, 0);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 3:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    var $11 = __ZN9JSContext7malloc_Ej($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    var $14 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray_idx_val);
    var $15 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($11, $14, $15, 1);
    var $16 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    if (($16 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($16 | 0) == 1 || ($16 | 0) == 8) {
      __label__ = 6;
      break;
    } else if (($16 | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($16 | 0) == 3) {
      __label__ = 12;
      break;
    } else if (($16 | 0) == 4) {
      __label__ = 15;
      break;
    } else if (($16 | 0) == 5) {
      __label__ = 18;
      break;
    } else if (($16 | 0) == 6) {
      __label__ = 21;
      break;
    } else if (($16 | 0) == 7) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 5:
    var $17 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($17 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i_036 = 0;
      var $src_037 = $11;
      var $dest_038 = $2;
      __label__ = 7;
      break;
    }
   case 6:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($19 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i2_030 = 0;
      var $src1_031 = $11;
      var $dest_132 = $2;
      __label__ = 8;
      break;
    }
   case 7:
    var $dest_038;
    var $src_037;
    var $i_036;
    var $21 = $src_037 + 1 | 0;
    var $22 = HEAP8[$src_037];
    var $23 = $dest_038 + 1 | 0;
    HEAP8[$dest_038] = $22;
    var $24 = $i_036 + 1 | 0;
    var $25 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($24 >>> 0 < $25 >>> 0) {
      var $i_036 = $24;
      var $src_037 = $21;
      var $dest_038 = $23;
      __label__ = 7;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 8:
    var $dest_132;
    var $src1_031;
    var $i2_030;
    var $27 = $src1_031 + 1 | 0;
    var $28 = HEAP8[$src1_031];
    var $29 = $dest_132 + 1 | 0;
    HEAP8[$dest_132] = $28;
    var $30 = $i2_030 + 1 | 0;
    var $31 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($30 >>> 0 < $31 >>> 0) {
      var $i2_030 = $30;
      var $src1_031 = $27;
      var $dest_132 = $29;
      __label__ = 8;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 9:
    var $34 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($34 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $i4_025 = 0;
    var $src3_026 = $11;
    var $dest_227 = $2;
    __label__ = 11;
    break;
   case 11:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    var $38 = $src3_026 + 2 | 0;
    var $41 = $dest_227 + 1 | 0;
    HEAP8[$dest_227] = HEAP16[$src3_026 >> 1] & 255;
    var $42 = $i4_025 + 1 | 0;
    var $43 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($42 >>> 0 < $43 >>> 0) {
      var $i4_025 = $42;
      var $src3_026 = $38;
      var $dest_227 = $41;
      __label__ = 11;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 12:
    var $46 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($46 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i6_020 = 0;
    var $src5_021 = $11;
    var $dest_322 = $2;
    __label__ = 14;
    break;
   case 14:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    var $50 = $src5_021 + 2 | 0;
    var $53 = $dest_322 + 1 | 0;
    HEAP8[$dest_322] = HEAP16[$src5_021 >> 1] & 255;
    var $54 = $i6_020 + 1 | 0;
    var $55 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($54 >>> 0 < $55 >>> 0) {
      var $i6_020 = $54;
      var $src5_021 = $50;
      var $dest_322 = $53;
      __label__ = 14;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    var $58 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($58 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i8_015 = 0;
    var $src7_016 = $11;
    var $dest_417 = $2;
    __label__ = 17;
    break;
   case 17:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    var $62 = $src7_016 + 4 | 0;
    var $65 = $dest_417 + 1 | 0;
    HEAP8[$dest_417] = HEAP32[$src7_016 >> 2] & 255;
    var $66 = $i8_015 + 1 | 0;
    var $67 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($66 >>> 0 < $67 >>> 0) {
      var $i8_015 = $66;
      var $src7_016 = $62;
      var $dest_417 = $65;
      __label__ = 17;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 18:
    var $70 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($70 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $src9_010 = $11;
    var $i10_011 = 0;
    var $dest_512 = $2;
    __label__ = 20;
    break;
   case 20:
    var $dest_512;
    var $i10_011;
    var $src9_010;
    var $74 = $src9_010 + 4 | 0;
    var $77 = $dest_512 + 1 | 0;
    HEAP8[$dest_512] = HEAP32[$src9_010 >> 2] & 255;
    var $78 = $i10_011 + 1 | 0;
    var $79 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($78 >>> 0 < $79 >>> 0) {
      var $src9_010 = $74;
      var $i10_011 = $78;
      var $dest_512 = $77;
      __label__ = 20;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 21:
    var $82 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($82 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $dest_65 = $2;
    var $src11_06 = $11;
    var $i12_07 = 0;
    __label__ = 23;
    break;
   case 23:
    var $i12_07;
    var $src11_06;
    var $dest_65;
    var $86 = $src11_06 + 4 | 0;
    var $89 = $dest_65 + 1 | 0;
    HEAP8[$dest_65] = HEAPF32[$src11_06 >> 2] & -1;
    var $90 = $i12_07 + 1 | 0;
    var $91 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($90 >>> 0 < $91 >>> 0) {
      var $dest_65 = $89;
      var $src11_06 = $86;
      var $i12_07 = $90;
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $94 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($94 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $dest_71 = $2;
    var $src13_02 = $11;
    var $i14_03 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $98 = $src13_02 + 8 | 0;
    var $99 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $101 = $dest_71 + 1 | 0;
    HEAP8[$dest_71] = $99 & -1;
    var $102 = $i14_03 + 1 | 0;
    var $103 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($102 >>> 0 < $103 >>> 0) {
      var $dest_71 = $101;
      var $src13_02 = $98;
      var $i14_03 = $102;
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2js10Foreground5free_EPv($11);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIaE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateI13uint8_clampedE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $tarray, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $d = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $vp_idx5 = $vp | 0;
    var $vp_idx5_val$0 = HEAP32[$vp_idx5 >> 2];
    var $vp_idx5_val$1 = HEAP32[$vp_idx5 + 4 >> 2];
    var $3 = __ZNK2JS5Value7isInt32Ev($vp_idx5_val$0, $vp_idx5_val$1);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZNK2JS5Value7toInt32Ev($vp_idx5_val$0, $vp_idx5_val$1);
    __ZN13uint8_clampedC1Ei($1, $5);
    var $tarray_idx8_val = HEAP32[$tarray + 24 >> 2];
    var $_idx9_val = HEAP8[$1 | 0];
    __ZN18TypedArrayTemplateI13uint8_clampedE8setIndexEP8JSObjectjS0_($tarray_idx8_val, $index, $_idx9_val);
    __label__ = 15;
    break;
   case 3:
    var $7 = __ZNK2JS5Value8isDoubleEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZNK2JS5Value8toDoubleEv($vp);
    tempDoubleF64[0] = $9, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $29 = $9;
    __label__ = 14;
    break;
   case 5:
    var $11 = __ZNK2JS5Value6isNullEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $29 = 0;
    __label__ = 14;
    break;
   case 7:
    var $14 = __ZNK2JS5Value11isPrimitiveEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($14) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $16 = __ZNK2JS5Value8isStringEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($16) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $18 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d);
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $29 = $_pre;
    __label__ = 14;
    break;
   case 10:
    var $20 = __ZNK2JS5Value11isUndefinedEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($20) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $22 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $22, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $29 = $22;
    __label__ = 14;
    break;
   case 12:
    var $24 = __ZNK2JS5Value9toBooleanEv($vp_idx5_val$0, $vp_idx5_val$1);
    var $25 = $24 & 1;
    tempDoubleF64[0] = $25, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $29 = $25;
    __label__ = 14;
    break;
   case 13:
    var $27 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $27, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $29 = $27;
    __label__ = 14;
    break;
   case 14:
    var $29;
    __ZN13uint8_clampedC1Ed($2, $29);
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    var $_idx_val = HEAP8[$2 | 0];
    __ZN18TypedArrayTemplateI13uint8_clampedE8setIndexEP8JSObjectjS0_($tarray_idx_val, $index, $_idx_val);
    __label__ = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateI13uint8_clampedE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi["X"] = 1;

function __ZN18TypedArrayTemplateI13uint8_clampedE8setIndexEP8JSObjectjS0_($obj_0_6_val, $index, $val_0_0_val) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj_0_6_val);
  var $3 = $1 + $index | 0;
  __ZN13uint8_clampedaSERKS_($3, $val_0_0_val);
  return;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($tarray_0_6_val, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  __ZN18TypedArrayTemplateI13uint8_clampedE8getIndexEP8JSObjectj($1, $tarray_0_6_val, $index);
  var $_idx_val = HEAP8[$1 | 0];
  var $2 = __ZNK13uint8_clampedcvhEv($_idx_val);
  var $3 = $2 & 255;
  __ZN2JS5Value8setInt32Ei($vp, $3);
  STACKTOP = __stackBase__;
  return;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE8getIndexEP8JSObjectj($agg_result, $obj_0_6_val, $index) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj_0_6_val);
  var $_idx_val = HEAP8[$1 + $index | 0];
  __ZN13uint8_clampedC1ERKS_($agg_result, $_idx_val);
  return;
}

function __ZN13uint8_clampedC1ERKS_($this, $other_0_0_val) {
  __ZN13uint8_clampedC2ERKS_($this, $other_0_0_val);
  return;
}

function __ZN18TypedArrayTemplateIdE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $tarray, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $vp_idx5 = $vp | 0;
    var $vp_idx5_val$0 = HEAP32[$vp_idx5 >> 2];
    var $vp_idx5_val$1 = HEAP32[$vp_idx5 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($vp_idx5_val$0, $vp_idx5_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($vp_idx5_val$0, $vp_idx5_val$1);
    var $4 = $3 | 0;
    var $tarray_idx8_val = HEAP32[$tarray + 24 >> 2];
    __ZN18TypedArrayTemplateIdE8setIndexEP8JSObjectjd($tarray_idx8_val, $index, $4);
    __label__ = 15;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($vp);
    tempDoubleF64[0] = $8, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $8;
    __label__ = 14;
    break;
   case 5:
    var $10 = __ZNK2JS5Value6isNullEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = 0;
    __label__ = 14;
    break;
   case 7:
    var $13 = __ZNK2JS5Value11isPrimitiveEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $15 = __ZNK2JS5Value8isStringEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($15) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $17 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d);
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $28 = $_pre;
    __label__ = 14;
    break;
   case 10:
    var $19 = __ZNK2JS5Value11isUndefinedEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($19) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $21 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $21, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $21;
    __label__ = 14;
    break;
   case 12:
    var $23 = __ZNK2JS5Value9toBooleanEv($vp_idx5_val$0, $vp_idx5_val$1);
    var $24 = $23 & 1;
    tempDoubleF64[0] = $24, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $24;
    __label__ = 14;
    break;
   case 13:
    var $26 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $26, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $26;
    __label__ = 14;
    break;
   case 14:
    var $28;
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    __ZN18TypedArrayTemplateIdE8setIndexEP8JSObjectjd($tarray_idx_val, $index, $28);
    __label__ = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIdE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi["X"] = 1;

function __ZN18TypedArrayTemplateIdE8setIndexEP8JSObjectjd($obj_0_6_val, $index, $val) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj_0_6_val);
  var $3 = $1 + ($index << 3) | 0;
  tempDoubleF64[0] = $val, HEAP32[$3 >> 2] = tempDoubleI32[0], HEAP32[$3 + 4 >> 2] = tempDoubleI32[1];
  return;
}

function __ZN18TypedArrayTemplateIfE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $tarray, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $vp_idx5 = $vp | 0;
    var $vp_idx5_val$0 = HEAP32[$vp_idx5 >> 2];
    var $vp_idx5_val$1 = HEAP32[$vp_idx5 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($vp_idx5_val$0, $vp_idx5_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($vp_idx5_val$0, $vp_idx5_val$1);
    var $4 = $3 | 0;
    var $tarray_idx8_val = HEAP32[$tarray + 24 >> 2];
    __ZN18TypedArrayTemplateIfE8setIndexEP8JSObjectjf($tarray_idx8_val, $index, $4);
    __label__ = 15;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($vp);
    tempDoubleF64[0] = $8, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $8;
    __label__ = 14;
    break;
   case 5:
    var $10 = __ZNK2JS5Value6isNullEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = 0;
    __label__ = 14;
    break;
   case 7:
    var $13 = __ZNK2JS5Value11isPrimitiveEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $15 = __ZNK2JS5Value8isStringEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($15) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $17 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d);
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $28 = $_pre;
    __label__ = 14;
    break;
   case 10:
    var $19 = __ZNK2JS5Value11isUndefinedEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($19) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $21 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $21, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $21;
    __label__ = 14;
    break;
   case 12:
    var $23 = __ZNK2JS5Value9toBooleanEv($vp_idx5_val$0, $vp_idx5_val$1);
    var $24 = $23 & 1;
    tempDoubleF64[0] = $24, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $24;
    __label__ = 14;
    break;
   case 13:
    var $26 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $26, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $26;
    __label__ = 14;
    break;
   case 14:
    var $28;
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    __ZN18TypedArrayTemplateIfE8setIndexEP8JSObjectjf($tarray_idx_val, $index, $28);
    __label__ = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIfE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi["X"] = 1;

function __ZN18TypedArrayTemplateIfE8setIndexEP8JSObjectjf($obj_0_6_val, $index, $val) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj_0_6_val);
  HEAPF32[$1 + ($index << 2) >> 2] = $val;
  return;
}

function __ZN18TypedArrayTemplateIjE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $tarray, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $vp_idx5 = $vp | 0;
    var $vp_idx5_val$0 = HEAP32[$vp_idx5 >> 2];
    var $vp_idx5_val$1 = HEAP32[$vp_idx5 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($vp_idx5_val$0, $vp_idx5_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($vp_idx5_val$0, $vp_idx5_val$1);
    var $tarray_idx8_val = HEAP32[$tarray + 24 >> 2];
    __ZN18TypedArrayTemplateIjE8setIndexEP8JSObjectjj($tarray_idx8_val, $index, $3);
    __label__ = 15;
    break;
   case 3:
    var $5 = __ZNK2JS5Value8isDoubleEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZNK2JS5Value8toDoubleEv($vp);
    tempDoubleF64[0] = $7, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $27 = $7;
    __label__ = 14;
    break;
   case 5:
    var $9 = __ZNK2JS5Value6isNullEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $27 = 0;
    __label__ = 14;
    break;
   case 7:
    var $12 = __ZNK2JS5Value11isPrimitiveEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($12) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $14 = __ZNK2JS5Value8isStringEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($14) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $16 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d);
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $27 = $_pre;
    __label__ = 14;
    break;
   case 10:
    var $18 = __ZNK2JS5Value11isUndefinedEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($18) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $20 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $20, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $27 = $20;
    __label__ = 14;
    break;
   case 12:
    var $22 = __ZNK2JS5Value9toBooleanEv($vp_idx5_val$0, $vp_idx5_val$1);
    var $23 = $22 & 1;
    tempDoubleF64[0] = $23, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $27 = $23;
    __label__ = 14;
    break;
   case 13:
    var $25 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $25, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $27 = $25;
    __label__ = 14;
    break;
   case 14:
    var $27;
    var $28 = __Z21js_DoubleToECMAUint32d($27);
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    __ZN18TypedArrayTemplateIjE8setIndexEP8JSObjectjj($tarray_idx_val, $index, $28);
    __label__ = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIjE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi["X"] = 1;

function __ZL14JSID_FROM_BITSj4031($bits) {
  return $bits;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($this_0_0_val, $this_0_1_val) {
  return ($this_0_0_val | 0) == ($this_0_1_val | 0);
}

function __ZN2js2gcL15GetGCObjectKindEjb4033($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN18TypedArrayTemplateIjE8setIndexEP8JSObjectjj($obj_0_6_val, $index, $val) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj_0_6_val);
  HEAP32[$1 + ($index << 2) >> 2] = $val;
  return;
}

function __ZN18TypedArrayTemplateIiE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $tarray, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $vp_idx5 = $vp | 0;
    var $vp_idx5_val$0 = HEAP32[$vp_idx5 >> 2];
    var $vp_idx5_val$1 = HEAP32[$vp_idx5 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($vp_idx5_val$0, $vp_idx5_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($vp_idx5_val$0, $vp_idx5_val$1);
    var $tarray_idx8_val = HEAP32[$tarray + 24 >> 2];
    __ZN18TypedArrayTemplateIiE8setIndexEP8JSObjectji($tarray_idx8_val, $index, $3);
    __label__ = 15;
    break;
   case 3:
    var $5 = __ZNK2JS5Value8isDoubleEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZNK2JS5Value8toDoubleEv($vp);
    tempDoubleF64[0] = $7, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $27 = $7;
    __label__ = 14;
    break;
   case 5:
    var $9 = __ZNK2JS5Value6isNullEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $27 = 0;
    __label__ = 14;
    break;
   case 7:
    var $12 = __ZNK2JS5Value11isPrimitiveEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($12) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $14 = __ZNK2JS5Value8isStringEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($14) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $16 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d);
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $27 = $_pre;
    __label__ = 14;
    break;
   case 10:
    var $18 = __ZNK2JS5Value11isUndefinedEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($18) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $20 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $20, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $27 = $20;
    __label__ = 14;
    break;
   case 12:
    var $22 = __ZNK2JS5Value9toBooleanEv($vp_idx5_val$0, $vp_idx5_val$1);
    var $23 = $22 & 1;
    tempDoubleF64[0] = $23, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $27 = $23;
    __label__ = 14;
    break;
   case 13:
    var $25 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $25, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $27 = $25;
    __label__ = 14;
    break;
   case 14:
    var $27;
    var $28 = __ZL20js_DoubleToECMAInt32d4007($27);
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    __ZN18TypedArrayTemplateIiE8setIndexEP8JSObjectji($tarray_idx_val, $index, $28);
    __label__ = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIiE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi["X"] = 1;

function __ZN18TypedArrayTemplateIiE8setIndexEP8JSObjectji($obj_0_6_val, $index, $val) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj_0_6_val);
  HEAP32[$1 + ($index << 2) >> 2] = $val;
  return;
}

function __ZN18TypedArrayTemplateItE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $tarray, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $vp_idx5 = $vp | 0;
    var $vp_idx5_val$0 = HEAP32[$vp_idx5 >> 2];
    var $vp_idx5_val$1 = HEAP32[$vp_idx5 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($vp_idx5_val$0, $vp_idx5_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($vp_idx5_val$0, $vp_idx5_val$1);
    var $4 = $3 & 65535;
    var $tarray_idx8_val = HEAP32[$tarray + 24 >> 2];
    __ZN18TypedArrayTemplateItE8setIndexEP8JSObjectjt($tarray_idx8_val, $index, $4);
    __label__ = 15;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($vp);
    tempDoubleF64[0] = $8, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $8;
    __label__ = 14;
    break;
   case 5:
    var $10 = __ZNK2JS5Value6isNullEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = 0;
    __label__ = 14;
    break;
   case 7:
    var $13 = __ZNK2JS5Value11isPrimitiveEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $15 = __ZNK2JS5Value8isStringEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($15) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $17 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d);
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $28 = $_pre;
    __label__ = 14;
    break;
   case 10:
    var $19 = __ZNK2JS5Value11isUndefinedEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($19) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $21 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $21, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $21;
    __label__ = 14;
    break;
   case 12:
    var $23 = __ZNK2JS5Value9toBooleanEv($vp_idx5_val$0, $vp_idx5_val$1);
    var $24 = $23 & 1;
    tempDoubleF64[0] = $24, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $24;
    __label__ = 14;
    break;
   case 13:
    var $26 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $26, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $26;
    __label__ = 14;
    break;
   case 14:
    var $28;
    var $29 = __Z21js_DoubleToECMAUint32d($28);
    var $30 = $29 & 65535;
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    __ZN18TypedArrayTemplateItE8setIndexEP8JSObjectjt($tarray_idx_val, $index, $30);
    __label__ = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateItE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi["X"] = 1;

function __ZN18TypedArrayTemplateItE8setIndexEP8JSObjectjt($obj_0_6_val, $index, $val) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj_0_6_val);
  HEAP16[$1 + ($index << 1) >> 1] = $val;
  return;
}

function __ZN18TypedArrayTemplateItE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($tarray_0_6_val, $index, $vp) {
  var $1 = __ZN18TypedArrayTemplateItE8getIndexEP8JSObjectj($tarray_0_6_val, $index);
  var $2 = $1 & 65535;
  __ZN2JS5Value8setInt32Ei($vp, $2);
  return;
}

function __ZN18TypedArrayTemplateItE8getIndexEP8JSObjectj($obj_0_6_val, $index) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj_0_6_val);
  return HEAP16[$1 + ($index << 1) >> 1];
}

function __ZN18TypedArrayTemplateIsE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $tarray, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $vp_idx5 = $vp | 0;
    var $vp_idx5_val$0 = HEAP32[$vp_idx5 >> 2];
    var $vp_idx5_val$1 = HEAP32[$vp_idx5 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($vp_idx5_val$0, $vp_idx5_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($vp_idx5_val$0, $vp_idx5_val$1);
    var $4 = $3 & 65535;
    var $tarray_idx8_val = HEAP32[$tarray + 24 >> 2];
    __ZN18TypedArrayTemplateIsE8setIndexEP8JSObjectjs($tarray_idx8_val, $index, $4);
    __label__ = 15;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($vp);
    tempDoubleF64[0] = $8, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $8;
    __label__ = 14;
    break;
   case 5:
    var $10 = __ZNK2JS5Value6isNullEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = 0;
    __label__ = 14;
    break;
   case 7:
    var $13 = __ZNK2JS5Value11isPrimitiveEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $15 = __ZNK2JS5Value8isStringEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($15) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $17 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d);
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $28 = $_pre;
    __label__ = 14;
    break;
   case 10:
    var $19 = __ZNK2JS5Value11isUndefinedEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($19) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $21 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $21, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $21;
    __label__ = 14;
    break;
   case 12:
    var $23 = __ZNK2JS5Value9toBooleanEv($vp_idx5_val$0, $vp_idx5_val$1);
    var $24 = $23 & 1;
    tempDoubleF64[0] = $24, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $24;
    __label__ = 14;
    break;
   case 13:
    var $26 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $26, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $26;
    __label__ = 14;
    break;
   case 14:
    var $28;
    var $29 = __ZL20js_DoubleToECMAInt32d4007($28);
    var $30 = $29 & 65535;
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    __ZN18TypedArrayTemplateIsE8setIndexEP8JSObjectjs($tarray_idx_val, $index, $30);
    __label__ = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIsE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi["X"] = 1;

function __ZN18TypedArrayTemplateIsE8setIndexEP8JSObjectjs($obj_0_6_val, $index, $val) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj_0_6_val);
  HEAP16[$1 + ($index << 1) >> 1] = $val;
  return;
}

function __ZN18TypedArrayTemplateIsE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($tarray_0_6_val, $index, $vp) {
  var $1 = __ZN18TypedArrayTemplateIsE8getIndexEP8JSObjectj($tarray_0_6_val, $index);
  var $2 = $1 << 16 >> 16;
  __ZN2JS5Value8setInt32Ei($vp, $2);
  return;
}

function __ZN18TypedArrayTemplateIsE8getIndexEP8JSObjectj($obj_0_6_val, $index) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj_0_6_val);
  return HEAP16[$1 + ($index << 1) >> 1];
}

function __ZN18TypedArrayTemplateIhE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $tarray, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $vp_idx5 = $vp | 0;
    var $vp_idx5_val$0 = HEAP32[$vp_idx5 >> 2];
    var $vp_idx5_val$1 = HEAP32[$vp_idx5 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($vp_idx5_val$0, $vp_idx5_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($vp_idx5_val$0, $vp_idx5_val$1);
    var $4 = $3 & 255;
    var $tarray_idx8_val = HEAP32[$tarray + 24 >> 2];
    __ZN18TypedArrayTemplateIhE8setIndexEP8JSObjectjh($tarray_idx8_val, $index, $4);
    __label__ = 15;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($vp);
    tempDoubleF64[0] = $8, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $8;
    __label__ = 14;
    break;
   case 5:
    var $10 = __ZNK2JS5Value6isNullEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = 0;
    __label__ = 14;
    break;
   case 7:
    var $13 = __ZNK2JS5Value11isPrimitiveEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $15 = __ZNK2JS5Value8isStringEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($15) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $17 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d);
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $28 = $_pre;
    __label__ = 14;
    break;
   case 10:
    var $19 = __ZNK2JS5Value11isUndefinedEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($19) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $21 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $21, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $21;
    __label__ = 14;
    break;
   case 12:
    var $23 = __ZNK2JS5Value9toBooleanEv($vp_idx5_val$0, $vp_idx5_val$1);
    var $24 = $23 & 1;
    tempDoubleF64[0] = $24, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $24;
    __label__ = 14;
    break;
   case 13:
    var $26 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $26, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $26;
    __label__ = 14;
    break;
   case 14:
    var $28;
    var $29 = __Z21js_DoubleToECMAUint32d($28);
    var $30 = $29 & 255;
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    __ZN18TypedArrayTemplateIhE8setIndexEP8JSObjectjh($tarray_idx_val, $index, $30);
    __label__ = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIhE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi["X"] = 1;

function __ZN18TypedArrayTemplateIhE8setIndexEP8JSObjectjh($obj_0_6_val, $index, $val) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj_0_6_val);
  HEAP8[$1 + $index | 0] = $val;
  return;
}

function __ZN18TypedArrayTemplateIhE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($tarray_0_6_val, $index, $vp) {
  var $1 = __ZN18TypedArrayTemplateIhE8getIndexEP8JSObjectj($tarray_0_6_val, $index);
  var $2 = $1 & 255;
  __ZN2JS5Value8setInt32Ei($vp, $2);
  return;
}

function __ZN18TypedArrayTemplateIhE8getIndexEP8JSObjectj($obj_0_6_val, $index) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj_0_6_val);
  return HEAP8[$1 + $index | 0];
}

function __ZN18TypedArrayTemplateIaE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $tarray, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $vp_idx5 = $vp | 0;
    var $vp_idx5_val$0 = HEAP32[$vp_idx5 >> 2];
    var $vp_idx5_val$1 = HEAP32[$vp_idx5 + 4 >> 2];
    var $1 = __ZNK2JS5Value7isInt32Ev($vp_idx5_val$0, $vp_idx5_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($vp_idx5_val$0, $vp_idx5_val$1);
    var $4 = $3 & 255;
    var $tarray_idx8_val = HEAP32[$tarray + 24 >> 2];
    __ZN18TypedArrayTemplateIaE8setIndexEP8JSObjectja($tarray_idx8_val, $index, $4);
    __label__ = 15;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($vp);
    tempDoubleF64[0] = $8, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $8;
    __label__ = 14;
    break;
   case 5:
    var $10 = __ZNK2JS5Value6isNullEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = 0;
    __label__ = 14;
    break;
   case 7:
    var $13 = __ZNK2JS5Value11isPrimitiveEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $15 = __ZNK2JS5Value8isStringEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($15) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $17 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d);
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $28 = $_pre;
    __label__ = 14;
    break;
   case 10:
    var $19 = __ZNK2JS5Value11isUndefinedEv($vp_idx5_val$0, $vp_idx5_val$1);
    if ($19) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $21 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $21, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $21;
    __label__ = 14;
    break;
   case 12:
    var $23 = __ZNK2JS5Value9toBooleanEv($vp_idx5_val$0, $vp_idx5_val$1);
    var $24 = $23 & 1;
    tempDoubleF64[0] = $24, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $24;
    __label__ = 14;
    break;
   case 13:
    var $26 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $26, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $26;
    __label__ = 14;
    break;
   case 14:
    var $28;
    var $29 = __ZL20js_DoubleToECMAInt32d4007($28);
    var $30 = $29 & 255;
    var $tarray_idx_val = HEAP32[$tarray + 24 >> 2];
    __ZN18TypedArrayTemplateIaE8setIndexEP8JSObjectja($tarray_idx_val, $index, $30);
    __label__ = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIaE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi["X"] = 1;

function __ZN18TypedArrayTemplateIaE8setIndexEP8JSObjectja($obj_0_6_val, $index, $val) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj_0_6_val);
  HEAP8[$1 + $index | 0] = $val;
  return;
}

function __ZN18TypedArrayTemplateIaE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($tarray_0_6_val, $index, $vp) {
  var $1 = __ZN18TypedArrayTemplateIaE8getIndexEP8JSObjectj($tarray_0_6_val, $index);
  var $2 = $1 << 24 >> 24;
  __ZN2JS5Value8setInt32Ei($vp, $2);
  return;
}

function __ZN18TypedArrayTemplateIaE8getIndexEP8JSObjectj($obj_0_6_val, $index) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj_0_6_val);
  return HEAP8[$1 + $index | 0];
}

function __ZN18TypedArrayTemplateI13uint8_clampedE14createSubarrayEP9JSContextP8JSObjectjj($cx, $tarray, $begin, $end) {
  var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
  var $2 = $end - $begin | 0;
  var $3 = __ZN2js10TypedArray13getByteOffsetEP8JSObject($tarray);
  var $4 = $3 + $begin | 0;
  var $5 = __ZN18TypedArrayTemplateI13uint8_clampedE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $1, $4, $2);
  return $5;
}

function __ZN2js10TypedArray13getByteOffsetEP8JSObject($obj) {
  var $1 = __ZNK8JSObject12getFixedSlotEj($obj, 1);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $2 = __ZNK2JS5Value7toInt32Ev($_idx_val$0, $_idx_val$1);
  return $2;
}

function __ZN18TypedArrayTemplateIdE14createSubarrayEP9JSContextP8JSObjectjj($cx, $tarray, $begin, $end) {
  var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
  var $2 = $end - $begin | 0;
  var $3 = __ZN2js10TypedArray13getByteOffsetEP8JSObject($tarray);
  var $5 = $3 + ($begin << 3) | 0;
  var $6 = __ZN18TypedArrayTemplateIdE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $1, $5, $2);
  return $6;
}

function __ZN18TypedArrayTemplateIfE14createSubarrayEP9JSContextP8JSObjectjj($cx, $tarray, $begin, $end) {
  var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
  var $2 = $end - $begin | 0;
  var $3 = __ZN2js10TypedArray13getByteOffsetEP8JSObject($tarray);
  var $5 = $3 + ($begin << 2) | 0;
  var $6 = __ZN18TypedArrayTemplateIfE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $1, $5, $2);
  return $6;
}

function __ZN18TypedArrayTemplateIjE14createSubarrayEP9JSContextP8JSObjectjj($cx, $tarray, $begin, $end) {
  var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
  var $2 = $end - $begin | 0;
  var $3 = __ZN2js10TypedArray13getByteOffsetEP8JSObject($tarray);
  var $5 = $3 + ($begin << 2) | 0;
  var $6 = __ZN18TypedArrayTemplateIjE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $1, $5, $2);
  return $6;
}

function __ZN18TypedArrayTemplateIiE14createSubarrayEP9JSContextP8JSObjectjj($cx, $tarray, $begin, $end) {
  var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
  var $2 = $end - $begin | 0;
  var $3 = __ZN2js10TypedArray13getByteOffsetEP8JSObject($tarray);
  var $5 = $3 + ($begin << 2) | 0;
  var $6 = __ZN18TypedArrayTemplateIiE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $1, $5, $2);
  return $6;
}

function __ZN18TypedArrayTemplateItE14createSubarrayEP9JSContextP8JSObjectjj($cx, $tarray, $begin, $end) {
  var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
  var $2 = $end - $begin | 0;
  var $3 = __ZN2js10TypedArray13getByteOffsetEP8JSObject($tarray);
  var $5 = $3 + ($begin << 1) | 0;
  var $6 = __ZN18TypedArrayTemplateItE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $1, $5, $2);
  return $6;
}

function __ZN18TypedArrayTemplateIsE14createSubarrayEP9JSContextP8JSObjectjj($cx, $tarray, $begin, $end) {
  var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
  var $2 = $end - $begin | 0;
  var $3 = __ZN2js10TypedArray13getByteOffsetEP8JSObject($tarray);
  var $5 = $3 + ($begin << 1) | 0;
  var $6 = __ZN18TypedArrayTemplateIsE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $1, $5, $2);
  return $6;
}

function __ZN18TypedArrayTemplateIhE14createSubarrayEP9JSContextP8JSObjectjj($cx, $tarray, $begin, $end) {
  var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
  var $2 = $end - $begin | 0;
  var $3 = __ZN2js10TypedArray13getByteOffsetEP8JSObject($tarray);
  var $4 = $3 + $begin | 0;
  var $5 = __ZN18TypedArrayTemplateIhE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $1, $4, $2);
  return $5;
}

function __ZN18TypedArrayTemplateIaE14createSubarrayEP9JSContextP8JSObjectjj($cx, $tarray, $begin, $end) {
  var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
  var $2 = $end - $begin | 0;
  var $3 = __ZN2js10TypedArray13getByteOffsetEP8JSObject($tarray);
  var $4 = $3 + $begin | 0;
  var $5 = __ZN18TypedArrayTemplateIaE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $1, $4, $2);
  return $5;
}

function __Z14getLengthValueP8JSObject($agg_result, $tarray) {
  var $1 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
  __ZN2JSL10Int32ValueEi3996($agg_result, $1);
  return;
}

function __Z18getByteLengthValueP8JSObject($agg_result, $tarray) {
  var $1 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
  __ZN2JSL10Int32ValueEi3996($agg_result, $1);
  return;
}

function __Z18getByteOffsetValueP8JSObject($agg_result, $tarray) {
  var $1 = __ZN2js10TypedArray13getByteOffsetEP8JSObject($tarray);
  __ZN2JSL10Int32ValueEi3996($agg_result, $1);
  return;
}

function __Z14getBufferValueP8JSObject($agg_result, $tarray) {
  var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
  __ZN2JSL11ObjectValueER8JSObject3997($agg_result, $1);
  return;
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_4032($cx, $proto) {
  var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb4033($3);
  var $5 = __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE4034($cx, $proto, $4);
  return $5;
}

function __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE4034($cx, $proto, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($proto | 0) != 0;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $5 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      var $5 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $5;
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ($1) {
      __label__ = 5;
      break;
    } else {
      var $12 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $proto_idx_val = HEAP32[$proto + 20 >> 2];
    var $10 = __ZNK8JSObject9getParentEv($proto_idx_val);
    var $12 = $10;
    __label__ = 6;
    break;
   case 6:
    var $12;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, __ZN2js11ObjectClassE, $5, $12, 0, (__ZN2js11ObjectClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $_idx_val = HEAP32[__ZN2js11ObjectClassE + 4 >> 2];
    var $13 = __ZNK2js5Class8isNativeEv($_idx_val);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $15 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE4037($cx, $6, $5, $kind);
    if ($15) {
      var $_0 = $6;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = 0;
    __label__ = 10;
    break;
   case 9:
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    var $_0 = $6;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE4037($cx, $obj, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 8 & 255;
    var $obj_idx_val = HEAP32[$obj + 28 >> 2];
    var $4 = __ZNK8JSObject8numSlotsEv($obj_idx_val);
    if ($3 >>> 0 > $4 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $obj;
    var $8 = $cx;
    var $9 = __ZN8JSObject10allocSlotsEP9JSContextj($7, $8, $3);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $11 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($type, __ZN2js11ObjectClassE);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($type, $cx, __ZN2js11ObjectClassE, $kind);
    var $empty_0 = $13;
    __label__ = 6;
    break;
   case 5:
    var $15 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, __ZN2js11ObjectClassE);
    var $empty_0 = $15;
    __label__ = 6;
    break;
   case 6:
    var $empty_0;
    if (($empty_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($obj, $empty_0 | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE4041($cx, $clasp, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $4 = HEAPU32[$clasp + 4 >> 2] >>> 24;
    var $5 = __ZNK9JSContext5hasfpEv($cx);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $8;
    var $9 = $cx;
    var $10 = $global;
    var $11 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($9, $10);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $19 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $13 = __ZNK9JSContext2fpEv($cx);
    var $14 = __ZNK2js10StackFrame10scopeChainEv($13);
    var $15 = $14;
    var $16 = __ZNK8JSObject9getGlobalEv($15);
    var $17 = $16;
    HEAP32[$global >> 2] = $17;
    var $19 = $17;
    __label__ = 5;
    break;
   case 5:
    var $19;
    var $20 = $4 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $19, $20);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $21 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $23 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    HEAP32[$proto >> 2] = $23;
    var $31 = $23;
    __label__ = 9;
    break;
   case 7:
    var $25 = $cx;
    var $27 = $proto;
    var $28 = $clasp;
    var $29 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($25, $19, $4, $27, $28);
    if ($29) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $31 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $31;
    var $32 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE4042($cx, $clasp, $31, $19, $kind);
    var $_0 = $32;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE4041["X"] = 1;

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE4042($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, $clasp, $1, $parent, 0, $7);
    var $8 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, $clasp, $kind);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $8 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $11);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_Assert($s, $file, $ln) {
  var __stackBase__ = STACKTOP;
  var $1 = HEAP32[_stderr >> 2];
  var $2 = _fprintf($1, STRING_TABLE.__str4046 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $s, HEAP32[tempInt + 4 >> 2] = $file, HEAP32[tempInt + 8 >> 2] = $ln, tempInt));
  var $3 = HEAP32[_stderr >> 2];
  var $4 = _fflush($3);
  __ZL9CrashInJSv();
  STACKTOP = __stackBase__;
  return;
}

function __ZL9CrashInJSv() {
  var $1 = _raise(6);
  return;
}

function __ZN2js13WatchpointMap4initEv($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE4initEj($1);
  return $2;
}

function __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj($1);
  return $2;
}

function __ZN2js13WatchpointMap5watchEP9JSContextP8JSObjectiPFiS2_S4_iN2JS5ValueEPS6_PvES4_($this, $cx, $obj, $id, $closure) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $w = __stackBase__;
    var $1 = __stackBase__ + 12;
    __ZN8JSObject10setWatchedEP9JSContext($obj, $cx);
    HEAP32[$w >> 2] = 256;
    HEAP32[$w + 4 >> 2] = $closure;
    HEAP8[$w + 8 | 0] = 0;
    var $5 = $this | 0;
    __ZN2js8WatchKeyC1EP8JSObjecti($1, $obj, $id);
    var $6 = __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3putERKS1_RKS2_($5, $1, $w);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject10setWatchedEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 8 | 0;
    var $_idx_val = HEAP32[$1 >> 2];
    var $2 = __ZNK8JSObject7watchedEv($_idx_val);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $_idx_val | 8192;
    HEAP32[$1 >> 2] = $4;
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN8JSObject16generateOwnShapeEP9JSContext($this, $cx_idx_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3putERKS1_RKS2_($this, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE12lookupForAddERKS1_($p, $this, $k);
    var $_idx = $p | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $_idx_val_idx_val = HEAP32[$_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($1, $_idx_val_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($_idx_val);
    var $8 = $6 + 8 | 0;
    var $9 = $v;
    HEAP32[$8 >> 2] = HEAP32[$9 >> 2];
    HEAP32[$8 + 4 >> 2] = HEAP32[$9 + 4 >> 2];
    HEAP32[$8 + 8 >> 2] = HEAP32[$9 + 8 >> 2];
    var $10 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrdeEv($_idx_val);
    var $_0 = $10;
    __label__ = 5;
    break;
   case 3:
    var $12 = __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E6AddPtrERKS1_RKS2_($this, $p, $k, $v);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx2_val = HEAP32[$_idx >> 2];
    var $14 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrdeEv($_idx2_val);
    var $_0 = $14;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8WatchKeyC1EP8JSObjecti($this, $obj, $id) {
  __ZN2js8WatchKeyC2EP8JSObjecti($this, $obj, $id);
  return;
}

function __ZN2js13WatchpointMap7unwatchEP8JSObjectiPPFiP9JSContextS2_iN2JS5ValueEPS6_PvEPS2_($this, $obj, $id) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $3 = $this | 0;
    __ZN2js8WatchKeyC1EP8JSObjecti($1, $obj, $id);
    __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6lookupERKS1_($p, $3, $1);
    var $p_idx_val = HEAP32[$p >> 2];
    var $p_idx_val_idx_val = HEAP32[$p_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($2, $p_idx_val_idx_val);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E3PtrE($3, $p_idx_val);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6lookupERKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 258,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E3PtrE($this, $p_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeENSC_3PtrE($1, $p_0);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC1ISA_EERT_($this, $map) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC2ISA_EERT_($this, $map);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS5_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 24 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$5 >> 2];
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isLiveEv($_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev($this);
  return;
}

function __ZN2js13WatchpointMap5clearEv($this) {
  var $1 = $this | 0;
  __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE5clearEv($1);
  return;
}

function __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE5clearEv($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5clearEv($1);
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_8WatchKeyEEcvRS1_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_10WatchpointEEcvRS1_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE12hasCollisionEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this_0_1_val, $this_0_2_val, $this_0_4_val) {
  return ($this_0_4_val + $this_0_2_val | 0) >>> 0 >= ($this_0_1_val * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEC2ERS7_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC2ERS4_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_10WatchpointEEC2ERS1_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_8WatchKeyEEC2ERS1_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrdeEv($this_0_0_val) {
  return $this_0_0_val + 4 | 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js13WatchpointMap17triggerWatchpointEP9JSContextP8JSObjectiPN2JS5ValueE($this, $cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $holder = __stackBase__ + 20;
    var $old = __stackBase__ + 40;
    var $method = __stackBase__ + 48;
    var $3 = __stackBase__ + 56;
    var $4 = $this | 0;
    __ZN2js8WatchKeyC1EP8JSObjecti($1, $obj, $id);
    __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6lookupERKS1_($p, $4, $1);
    var $p_idx_val = HEAP32[$p >> 2];
    var $p_idx_val_idx_val = HEAP32[$p_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($2, $p_idx_val_idx_val);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      var $_1 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($p_idx_val);
    if ((HEAP8[$9 + 16 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 1;
      __label__ = 12;
      break;
    }
   case 3:
    __ZN15AutoEntryHolderC1ERN2js7HashMapINS0_8WatchKeyENS0_10WatchpointENS0_13DefaultHasherIS2_EENS0_17SystemAllocPolicyEEENS0_6detail9HashTableINS0_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E3PtrE($holder, $4, $p_idx_val);
    var $16 = HEAP32[$9 + 8 >> 2];
    var $18 = HEAP32[$9 + 12 >> 2];
    __ZN2JS5Value12setUndefinedEv($old);
    var $obj_idx = $obj | 0;
    var $obj_idx_val = HEAP32[$obj_idx >> 2];
    var $19 = __ZNK8JSObject8isNativeEv($obj_idx_val);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 4:
    var $21 = __ZN8JSObject12nativeLookupEP9JSContexti($obj, $cx, $id);
    if (($21 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $25 = HEAP32[$21 + 24 >> 2];
    var $obj_idx1_val_idx_val = HEAP32[HEAP32[$obj_idx >> 2] + 4 >> 2];
    var $26 = __ZNK8JSObject12containsSlotEj($obj_idx1_val_idx_val, $25);
    if ($26) {
      __label__ = 6;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $_idx_val = HEAP8[$21 + 29 | 0];
    var $28 = __ZNK2js5Shape8isMethodEv($_idx_val);
    if ($28) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $30 = __ZNK2js5Shape12methodObjectEv($21);
    __ZN2JSL11ObjectValueER8JSObject4064($method, $30);
    var $31 = __ZN8JSObject17methodReadBarrierEP9JSContextRKN2js5ShapeEPN2JS5ValueE($obj, $cx, $21, $method);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $34 = __ZN8JSObject12nativeLookupEP9JSContexti($obj, $cx, $id);
    var $35 = $method | 0;
    var $st$2$0 = $35 | 0;
    var $36$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $35 + 4 | 0;
    var $36$1 = HEAP32[$st$2$1 >> 2];
    var $37 = $old | 0;
    var $st$7$0 = $37 | 0;
    HEAP32[$st$7$0 >> 2] = $36$0;
    var $st$7$1 = $37 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $36$1;
    __label__ = 10;
    break;
   case 9:
    var $39 = __ZNK8JSObject13nativeGetSlotEj($obj, $25);
    var $40 = $39 | 0;
    var $st$2$0 = $40 | 0;
    var $41$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $40 + 4 | 0;
    var $41$1 = HEAP32[$st$2$1 >> 2];
    var $42 = $old | 0;
    var $st$7$0 = $42 | 0;
    HEAP32[$st$7$0 >> 2] = $41$0;
    var $st$7$1 = $42 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $41$1;
    __label__ = 10;
    break;
   case 10:
    var $43 = $old | 0;
    var $44$0 = HEAP32[$43 >> 2];
    var $44$1 = HEAP32[$43 + 4 >> 2];
    var $45 = $3 | 0;
    HEAP32[$45 >> 2] = $44$0;
    HEAP32[$45 + 4 >> 2] = $44$1;
    var $46 = $18;
    var $47 = FUNCTION_TABLE[$16]($cx, $obj, $id, $3, $vp, $46);
    var $_0 = ($47 | 0) != 0;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    __ZN15AutoEntryHolderD1Ev($holder);
    var $_1 = $_0;
    __label__ = 12;
    break;
   case 12:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13WatchpointMap17triggerWatchpointEP9JSContextP8JSObjectiPN2JS5ValueE["X"] = 1;

function __ZN15AutoEntryHolderC1ERN2js7HashMapINS0_8WatchKeyENS0_10WatchpointENS0_13DefaultHasherIS2_EENS0_17SystemAllocPolicyEEENS0_6detail9HashTableINS0_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E3PtrE($this, $map, $p_01) {
  __ZN15AutoEntryHolderC2ERN2js7HashMapINS0_8WatchKeyENS0_10WatchpointENS0_13DefaultHasherIS2_EENS0_17SystemAllocPolicyEEENS0_6detail9HashTableINS0_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E3PtrE($this, $map, $p_01);
  return;
}

function __ZN2JSL11ObjectValueER8JSObject4064($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN15AutoEntryHolderD1Ev($this) {
  __ZN15AutoEntryHolderD2Ev($this);
  return;
}

function __ZN2js13WatchpointMap18markAllIterativelyEP8JSTracer($trc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAP32[HEAP32[$trc >> 2] + 52 >> 2];
    var $6 = HEAP32[$4 + 144080 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAP32[$6 + 1984 >> 2];
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = __ZN2js13WatchpointMap15markIterativelyEP8JSTracer($10, $trc);
    var $_0 = $13;
    __label__ = 9;
    break;
   case 4:
    var $_idx = $4 + 4 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $15 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($_idx_val);
    var $_idx4 = $4 + 8 | 0;
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $16 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx_val, $_idx4_val);
    if (($15 | 0) == ($16 | 0)) {
      var $mutated_0_lcssa = 0;
      __label__ = 8;
      break;
    } else {
      var $mutated_01 = 0;
      var $c_02 = $15;
      var $_idx1_val5 = $_idx_val;
      var $_idx2_val7 = $_idx4_val;
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx2_val7;
    var $_idx1_val5;
    var $c_02;
    var $mutated_01;
    var $20 = HEAP32[HEAP32[$c_02 >> 2] + 1984 >> 2];
    if (($20 | 0) == 0) {
      var $mutated_1 = $mutated_01;
      var $_idx1_val = $_idx1_val5;
      var $_idx2_val = $_idx2_val7;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = __ZN2js13WatchpointMap15markIterativelyEP8JSTracer($20, $trc);
    var $mutated_1 = $23 & 1 | $mutated_01 & 1;
    var $_idx1_val = HEAP32[$_idx >> 2];
    var $_idx2_val = HEAP32[$_idx4 >> 2];
    __label__ = 7;
    break;
   case 7:
    var $_idx2_val;
    var $_idx1_val;
    var $mutated_1;
    var $28 = $c_02 + 4 | 0;
    var $29 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx1_val, $_idx2_val);
    if (($28 | 0) == ($29 | 0)) {
      var $mutated_0_lcssa = $mutated_1;
      __label__ = 8;
      break;
    } else {
      var $mutated_01 = $mutated_1;
      var $c_02 = $28;
      var $_idx1_val5 = $_idx1_val;
      var $_idx2_val7 = $_idx2_val;
      __label__ = 5;
      break;
    }
   case 8:
    var $mutated_0_lcssa;
    var $_0 = ($mutated_0_lcssa & 1) << 24 >> 24 != 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13WatchpointMap18markAllIterativelyEP8JSTracer["X"] = 1;

function __ZN2js13WatchpointMap15markIterativelyEP8JSTracer($this, $trc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $2 = HEAP32[$trc >> 2];
    var $3 = $this | 0;
    __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3allEv($r, $3);
    var $r_idx3 = $r | 0;
    var $r_idx3_val = HEAP32[$r_idx3 >> 2];
    var $r_idx4 = $r + 4 | 0;
    var $r_idx4_val = HEAP32[$r_idx4 >> 2];
    var $4 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r_idx3_val, $r_idx4_val);
    if ($4) {
      var $marked_0_lcssa = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1 = $2 + 52 | 0;
    var $marked_01 = 0;
    var $r_idx5_val = $r_idx3_val;
    __label__ = 3;
    break;
   case 3:
    var $r_idx5_val;
    var $marked_01;
    var $5 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($r_idx5_val);
    var $6 = $5 | 0;
    var $8 = HEAP32[$6 >> 2];
    var $_idx1_val_idx_val = HEAP32[HEAP32[$_idx1 >> 2] + 144080 >> 2];
    var $9 = __Z20IsAboutToBeFinalizedP9JSContextPKv($_idx1_val_idx_val, $8);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $marked_1 = $marked_01;
      __label__ = 6;
      break;
    }
   case 4:
    if ((HEAP8[$5 + 16 | 0] & 1) << 24 >> 24 == 0) {
      var $marked_2 = $marked_01;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = HEAP32[$6 >> 2];
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $16);
    var $marked_1 = 1;
    __label__ = 6;
    break;
   case 6:
    var $marked_1;
    var $18 = HEAP32[$5 + 4 >> 2];
    __ZN2js2gc6MarkIdEP8JSTraceriPKc($trc, $18);
    var $19 = $5 + 12 | 0;
    var $20 = HEAP32[$19 >> 2];
    if (($20 | 0) == 0) {
      var $marked_2 = $marked_1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = $20;
    var $_idx_val_idx_val = HEAP32[HEAP32[$_idx1 >> 2] + 144080 >> 2];
    var $24 = __Z20IsAboutToBeFinalizedP9JSContextPKv($_idx_val_idx_val, $23);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $marked_2 = $marked_1;
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = HEAP32[$19 >> 2];
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $26);
    var $marked_2 = 1;
    __label__ = 9;
    break;
   case 9:
    var $marked_2;
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($r);
    var $r_idx_val = HEAP32[$r_idx3 >> 2];
    var $r_idx2_val = HEAP32[$r_idx4 >> 2];
    var $28 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r_idx_val, $r_idx2_val);
    if ($28) {
      var $marked_0_lcssa = $marked_2;
      __label__ = 10;
      break;
    } else {
      var $marked_01 = $marked_2;
      var $r_idx5_val = $r_idx_val;
      __label__ = 3;
      break;
    }
   case 10:
    var $marked_0_lcssa;
    STACKTOP = __stackBase__;
    return ($marked_0_lcssa & 1) << 24 >> 24 != 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13WatchpointMap15markIterativelyEP8JSTracer["X"] = 1;

function __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3allEv($agg_result, $this) {
  var $_idx_val = HEAP32[$this + 4 >> 2];
  var $_idx1_val = HEAP32[$this + 20 >> 2];
  __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $_idx_val, $_idx1_val);
  return;
}

function __ZN2js13WatchpointMap8sweepAllEP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 52 >> 2];
    var $4 = HEAP32[$2 + 144080 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$4 + 1984 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js13WatchpointMap5sweepEP9JSContext($8, $cx);
    __label__ = 8;
    break;
   case 4:
    var $_idx = $2 + 4 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $12 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($_idx_val);
    var $_idx4 = $2 + 8 | 0;
    var $_idx4_val = HEAP32[$_idx4 >> 2];
    var $13 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx_val, $_idx4_val);
    if (($12 | 0) == ($13 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $c_01 = $12;
      var $_idx1_val5 = $_idx_val;
      var $_idx2_val7 = $_idx4_val;
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx2_val7;
    var $_idx1_val5;
    var $c_01;
    var $17 = HEAP32[HEAP32[$c_01 >> 2] + 1984 >> 2];
    if (($17 | 0) == 0) {
      var $_idx1_val = $_idx1_val5;
      var $_idx2_val = $_idx2_val7;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js13WatchpointMap5sweepEP9JSContext($17, $cx);
    var $_idx1_val = HEAP32[$_idx >> 2];
    var $_idx2_val = HEAP32[$_idx4 >> 2];
    __label__ = 7;
    break;
   case 7:
    var $_idx2_val;
    var $_idx1_val;
    var $21 = $c_01 + 4 | 0;
    var $22 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($_idx1_val, $_idx2_val);
    if (($21 | 0) == ($22 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $c_01 = $21;
      var $_idx1_val5 = $_idx1_val;
      var $_idx2_val7 = $_idx2_val;
      __label__ = 5;
      break;
    }
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13WatchpointMap5sweepEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $this | 0;
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC1ISA_EERT_($r, $1);
    var $2 = $r | 0;
    var $_idx2 = $r | 0;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $_idx3 = $r + 4 | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($_idx2_val, $_idx3_val);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $cx_idx = $cx + 52 | 0;
    var $_idx4_val = $_idx2_val;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev($r);
    STACKTOP = __stackBase__;
    return;
   case 4:
    var $_idx4_val;
    var $4 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($_idx4_val);
    var $7 = HEAP32[$4 >> 2];
    var $cx_idx_val_idx_val = HEAP32[HEAP32[$cx_idx >> 2] + 144080 >> 2];
    var $8 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx_idx_val_idx_val, $7);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv($r);
    __label__ = 6;
    break;
   case 6:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($2);
    var $_idx_val = HEAP32[$_idx2 >> 2];
    var $_idx1_val = HEAP32[$_idx3 >> 2];
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($_idx_val, $_idx1_val);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_idx4_val = $_idx_val;
      __label__ = 4;
      break;
    }
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $this_0_1_val, $this_0_5_val) {
  var $1 = $this_0_5_val + $this_0_1_val * 24 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_($agg_result, $this_0_5_val, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$4 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isLiveEv($_idx_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 24 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5clearEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $4 = HEAP32[$this + 20 >> 2];
    var $6 = HEAP32[$this + 4 >> 2];
    var $7 = $4 + $6 * 24 | 0;
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = $1 | 0;
    var $e_01 = $4;
    __label__ = 3;
    break;
   case 3:
    var $e_01;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC1Ev($2);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEENS_7MoveRefIT_EERKS9_($1, $2);
    var $_0_val = HEAP32[$_0 >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEaSENS_7MoveRefIS6_EE($e_01, $_0_val);
    var $9 = $e_01 + 24 | 0;
    if (($9 | 0) == ($7 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $e_01 = $9;
      __label__ = 3;
      break;
    }
   case 4:
    HEAP32[$this + 16 >> 2] = 0;
    HEAP32[$this + 8 >> 2] = 0;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEaSENS_7MoveRefIS6_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = $2 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEENS_7MoveRefIT_EERS6_($1, $7);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEaSENS_7MoveRefIS3_EE($6, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEENS_7MoveRefIT_EERKS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEC1Ev($this) {
  __ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEC2Ev($this);
  return;
}

function __ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEC2Ev($this) {
  var $2 = $this + 8 | 0;
  HEAP32[$2 >> 2] = 0;
  HEAP32[$2 + 4 >> 2] = 0;
  HEAP32[$2 + 8 >> 2] = 0;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEC1ERS7_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEC2ERS7_($this, $t);
  return;
}

function __ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEaSENS_7MoveRefIS3_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEptEv($rhs_0);
  var $4 = $3 | 0;
  __ZN2js4MoveINS_8WatchKeyEEENS_7MoveRefIT_EERKS3_($1, $4);
  var $_idx_val = HEAP32[$1 >> 2];
  var $5 = __ZNK2js7MoveRefINS_8WatchKeyEEcvRS1_Ev($_idx_val);
  var $6 = $5;
  var $7 = $this;
  var $8$0 = HEAP32[$6 >> 2];
  var $8$1 = HEAP32[$6 + 4 >> 2];
  HEAP32[$7 >> 2] = $8$0;
  HEAP32[$7 + 4 >> 2] = $8$1;
  var $9 = $this + 8 | 0;
  var $10 = $3 + 8 | 0;
  __ZN2js4MoveINS_10WatchpointEEENS_7MoveRefIT_EERS3_($2, $10);
  var $_idx2_val = HEAP32[$2 >> 2];
  var $11 = __ZNK2js7MoveRefINS_10WatchpointEEcvRS1_Ev($_idx2_val);
  var $12 = $9;
  var $13 = $11;
  HEAP32[$12 >> 2] = HEAP32[$13 >> 2];
  HEAP32[$12 + 4 >> 2] = HEAP32[$13 + 4 >> 2];
  HEAP32[$12 + 8 >> 2] = HEAP32[$13 + 8 >> 2];
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEENS_7MoveRefIT_EERS6_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC1ERS4_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC1ERS4_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC2ERS4_($this, $t);
  return;
}

function __ZN2js4MoveINS_8WatchKeyEEENS_7MoveRefIT_EERKS3_($agg_result, $t) {
  __ZN2js7MoveRefINS_8WatchKeyEEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js4MoveINS_10WatchpointEEENS_7MoveRefIT_EERS3_($agg_result, $t) {
  __ZN2js7MoveRefINS_10WatchpointEEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_10WatchpointEEC1ERS1_($this, $t) {
  __ZN2js7MoveRefINS_10WatchpointEEC2ERS1_($this, $t);
  return;
}

function __ZN2js7MoveRefINS_8WatchKeyEEC1ERS1_($this, $t) {
  __ZN2js7MoveRefINS_8WatchKeyEEC2ERS1_($this, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS5_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e_idx_val = HEAP32[$e >> 2];
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE12hasCollisionEv($e_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEC1Ev($1);
  __ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEaSERKS3_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEC1Ev($1);
  __ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEaSERKS3_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEaSERKS3_($this, $rhs) {
  var $1 = $rhs;
  var $2 = $this;
  var $3$0 = HEAP32[$1 >> 2];
  var $3$1 = HEAP32[$1 + 4 >> 2];
  HEAP32[$2 >> 2] = $3$0;
  HEAP32[$2 + 4 >> 2] = $3$1;
  var $6 = $this + 8 | 0;
  var $7 = $rhs + 8 | 0;
  HEAP32[$6 >> 2] = HEAP32[$7 >> 2];
  HEAP32[$6 + 4 >> 2] = HEAP32[$7 + 4 >> 2];
  HEAP32[$6 + 8 >> 2] = HEAP32[$7 + 8 >> 2];
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + $5 * 24 | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 5;
    break;
   case 5:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $22 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isLiveEv($src_01_idx_val);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE10getKeyHashEv($src_01_idx1_val);
    var $25 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEENS_7MoveRefIT_EERS9_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEaSENS_7MoveRefIS6_EE($25, $_02_val);
    __label__ = 7;
    break;
   case 7:
    var $27 = $src_01 + 24 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($3);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 24 | 0;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej($1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 24 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 24 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 24 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 24 | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEENS_7MoveRefIT_EERS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC2ISA_EERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3allEv($1, $map);
  var $2 = $1;
  var $3 = $this;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  HEAP32[$this + 8 >> 2] = $map | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeENSC_3PtrE($this, $p_0) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS5_EE($this, $p_0);
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv($this);
  return;
}

function __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE12lookupForAddERKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS3_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E6AddPtrERKS1_RKS2_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$pentry >> 2];
    var $5 = $k;
    var $6 = $4;
    var $7$0 = HEAP32[$5 >> 2];
    var $7$1 = HEAP32[$5 + 4 >> 2];
    var $st$7$0 = $6 | 0;
    HEAP32[$st$7$0 >> 2] = $7$0;
    var $st$7$1 = $6 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $7$1;
    var $9 = $4 + 8 | 0;
    var $10 = $v;
    HEAP32[$9 >> 2] = HEAP32[$10 >> 2];
    HEAP32[$9 + 4 >> 2] = HEAP32[$10 + 4 >> 2];
    HEAP32[$9 + 8 >> 2] = HEAP32[$10 + 8 >> 2];
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 8 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 4 >> 2];
    var $this_idx1 = $this + 8 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 16 >> 2];
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv($this) {
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10generationEv($this_0_3_val) {
  return $this_0_3_val;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZN2jsL6HashIdEi4071($id) {
  return $id * -1640531527 | 0;
}

function __ZNK8JSObject9isWeakMapEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js12WeakMapClassE | 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js13DefaultHasherINS_8WatchKeyEE5matchERKS1_S4_($k, $l) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$k >> 2] | 0) == (HEAP32[$l >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      var $13 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $13 = (HEAP32[$k + 4 >> 2] | 0) == (HEAP32[$l + 4 >> 2] | 0);
    __label__ = 3;
    break;
   case 3:
    var $13;
    return $13;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S2_EE($e) {
  return $e | 0;
}

function __ZN2js8WatchKeyC2EP8JSObjecti($this, $obj, $id) {
  HEAP32[$this >> 2] = $obj;
  HEAP32[$this + 4 >> 2] = $id;
  return;
}

function __ZN2js2gcL15GetGCObjectKindEjb4109($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($this_0_0_val) {
  return $this_0_0_val + 8 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv($this_0_0_val) {
  return $this_0_0_val + 8 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS3_($agg_result, $this, $l) {
  var $l_idx_val = HEAP32[$l >> 2];
  var $l_idx1_val = HEAP32[$l + 4 >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS3_($l_idx_val, $l_idx1_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS3_($l_0_0_val, $l_0_1_val) {
  var $1 = __ZN2js13DefaultHasherINS_8WatchKeyEE4hashERKS1_($l_0_0_val, $l_0_1_val);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 24 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS3_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 24 | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS3_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_jj["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS3_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S2_EE($1);
  var $3 = __ZN2js13DefaultHasherINS_8WatchKeyEE5matchERKS1_S4_($2, $l);
  return $3;
}

function __ZN2js13DefaultHasherINS_8WatchKeyEE4hashERKS1_($key_0_0_val, $key_0_1_val) {
  var $1 = __ZN2js13PointerHasherIP8JSObjectLj2EE4hashERKS2_($key_0_0_val);
  var $2 = __ZN2jsL6HashIdEi4071($key_0_1_val);
  return $2 ^ $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $0 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j(16);
    HEAP32[$this + 20 >> 2] = $0;
    if (($0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, 4);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_($agg_result, $this, $l) {
  var $l_idx_val = HEAP32[$l >> 2];
  var $l_idx1_val = HEAP32[$l + 4 >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS3_($l_idx_val, $l_idx1_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS5_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry);
  return;
}

function __ZN15AutoEntryHolderD2Ev($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $4 = HEAP32[$this + 8 >> 2];
    var $6 = HEAP32[$this >> 2];
    var $7 = __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE10generationEv($6);
    if (($4 | 0) == ($7 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_phi_trans_insert = $this + 4 | 0;
    var $_idx_val = HEAP32[$_idx_phi_trans_insert >> 2];
    var $_idx_pre_phi = $_idx_phi_trans_insert;
    __label__ = 4;
    break;
   case 3:
    var $10 = $this + 12 | 0;
    __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6lookupERKS1_($1, $6, $10);
    var $12 = HEAP32[$1 >> 2];
    HEAP32[$this + 4 >> 2] = $12;
    var $_idx_val = $12;
    var $_idx_pre_phi = $this + 4 | 0;
    __label__ = 4;
    break;
   case 4:
    var $_idx_pre_phi;
    var $_idx_val;
    var $_idx_val_idx_val = HEAP32[$_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($2, $_idx_val_idx_val);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx1_val = HEAP32[$_idx_pre_phi >> 2];
    var $19 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($_idx1_val);
    HEAP8[$19 + 16 | 0] = 0;
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE10generationEv($this) {
  var $_idx_val = HEAP32[$this + 12 >> 2];
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10generationEv($_idx_val);
  return $1;
}

function __ZN15AutoEntryHolderC2ERN2js7HashMapINS0_8WatchKeyENS0_10WatchpointENS0_13DefaultHasherIS2_EENS0_17SystemAllocPolicyEEENS0_6detail9HashTableINS0_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E3PtrE($this, $map, $p_0) {
  HEAP32[$this >> 2] = $map;
  HEAP32[$this + 4 >> 2] = $p_0;
  var $3 = $this + 8 | 0;
  var $4 = __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE10generationEv($map);
  HEAP32[$3 >> 2] = $4;
  var $5 = $this + 12 | 0;
  var $6 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($p_0);
  var $7 = $6;
  var $8 = $5;
  var $9$0 = HEAP32[$7 >> 2];
  var $9$1 = HEAP32[$7 + 4 >> 2];
  HEAP32[$8 >> 2] = $9$0;
  HEAP32[$8 + 4 >> 2] = $9$1;
  HEAP8[$6 + 16 | 0] = 1;
  return;
}

function __ZN2js11WeakMapBase18markAllIterativelyEP8JSTracer($tracer) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $m_01 = HEAP32[HEAP32[HEAP32[$tracer >> 2] + 52 >> 2] + 200 >> 2];
    if (($m_01 | 0) == 0) {
      var $markedAny_0_lcssa = 0;
      __label__ = 4;
      break;
    } else {
      var $markedAny_02 = 0;
      var $m_03 = $m_01;
      __label__ = 2;
      break;
    }
   case 2:
    var $m_03;
    var $markedAny_02;
    var $10 = HEAP32[HEAP32[$m_03 >> 2] + 4 >> 2];
    var $11 = FUNCTION_TABLE[$10]($m_03, $tracer);
    var $markedAny_1 = $11 ? 1 : $markedAny_02;
    var $m_0 = HEAP32[$m_03 + 4 >> 2];
    if (($m_0 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $markedAny_02 = $markedAny_1;
      var $m_03 = $m_0;
      __label__ = 2;
      break;
    }
   case 3:
    var $markedAny_0_lcssa = ($markedAny_1 & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 4:
    var $markedAny_0_lcssa;
    return $markedAny_0_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11WeakMapBase8sweepAllEP8JSTracer($tracer) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $m_01 = HEAP32[HEAP32[HEAP32[$tracer >> 2] + 52 >> 2] + 200 >> 2];
    if (($m_01 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $m_02 = $m_01;
      __label__ = 2;
      break;
    }
   case 2:
    var $m_02;
    var $10 = HEAP32[HEAP32[$m_02 >> 2] + 8 >> 2];
    FUNCTION_TABLE[$10]($m_02, $tracer);
    var $m_0 = HEAP32[$m_02 + 4 >> 2];
    if (($m_0 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $m_02 = $m_0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16WeakMap_finalizeP9JSContextP8JSObject($cx, $obj) {
  var $obj_idx_val = HEAP32[$obj + 24 >> 2];
  var $1 = __ZL12GetObjectMapP8JSObject($obj_idx_val);
  __ZN9JSContext7delete_IN2js7WeakMapIP8JSObjectN2JS5ValueENS1_13DefaultHasherIS4_EENS1_17DefaultMarkPolicyIS4_S6_EEEEEEvPT_($1);
  return;
}

function __ZL12WeakMap_markP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj_idx_val = HEAP32[$obj + 24 >> 2];
    var $1 = __ZL12GetObjectMapP8JSObject($obj_idx_val);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1 | 0;
    __ZN2js11WeakMapBase5traceEP8JSTracer($4, $trc);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11WeakMap_hasP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $key = __stackBase__;
    var $ptr = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 24;
    var $4 = $vp + 8 | 0;
    var $5 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $4);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$5 + 4 >> 2];
    var $8 = __ZNK8JSObject9isWeakMapEv($_idx1_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js12WeakMapClassE);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 4:
    if (($argc | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 4, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str124089 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str225518 | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str226519 | 0, tempInt));
    var $_0 = 0;
    __label__ = 11;
    break;
   case 6:
    var $_idx2 = $vp + 16 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    var $14 = __ZL13NonNullObjectP9JSContextPN2JS5ValueE($cx, $_idx2_val$0, $_idx2_val$1);
    HEAP32[$key >> 2] = $14;
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx_val = HEAP32[$5 + 24 >> 2];
    var $17 = __ZL12GetObjectMapP8JSObject($_idx_val);
    if (($17 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = $17 + 8 | 0;
    __ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_($ptr, $20, $key);
    var $ptr_idx_val_idx_val = HEAP32[HEAP32[$ptr >> 2] >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($1, $ptr_idx_val_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2JSL12BooleanValueEb4125($2, 1);
    var $25 = $2 | 0;
    var $st$2$0 = $25 | 0;
    var $26$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $25 + 4 | 0;
    var $26$1 = HEAP32[$st$2$1 >> 2];
    var $27 = $vp | 0;
    var $st$7$0 = $27 | 0;
    HEAP32[$st$7$0 >> 2] = $26$0;
    var $st$7$1 = $27 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $26$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 10:
    __ZN2JSL12BooleanValueEb4125($3, 0);
    var $29 = $3 | 0;
    var $st$2$0 = $29 | 0;
    var $30$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $29 + 4 | 0;
    var $30$1 = HEAP32[$st$2$1 >> 2];
    var $31 = $vp | 0;
    var $st$7$0 = $31 | 0;
    HEAP32[$st$7$0 >> 2] = $30$0;
    var $st$7$1 = $31 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $30$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11WeakMap_hasP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL11WeakMap_getP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $key = __stackBase__;
    var $ptr = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = $vp + 8 | 0;
    var $4 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $3);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$4 + 4 >> 2];
    var $7 = __ZNK8JSObject9isWeakMapEv($_idx1_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js12WeakMapClassE);
    var $_0 = 0;
    __label__ = 14;
    break;
   case 4:
    if (($argc | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 4, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str114088 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str225518 | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str226519 | 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 6:
    var $_idx2 = $vp + 16 | 0;
    var $st$1$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$1$1 >> 2];
    var $13 = __ZL13NonNullObjectP9JSContextPN2JS5ValueE($cx, $_idx2_val$0, $_idx2_val$1);
    HEAP32[$key >> 2] = $13;
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx_val = HEAP32[$4 + 24 >> 2];
    var $16 = __ZL12GetObjectMapP8JSObject($_idx_val);
    if (($16 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $19 = $16 + 8 | 0;
    __ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_($ptr, $19, $key);
    var $ptr_idx_val = HEAP32[$ptr >> 2];
    var $ptr_idx_val_idx_val = HEAP32[$ptr_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($1, $ptr_idx_val_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $24 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($ptr_idx_val);
    var $25 = $24 + 8 | 0;
    var $st$2$0 = $25 | 0;
    var $26$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $25 + 4 | 0;
    var $26$1 = HEAP32[$st$2$1 >> 2];
    var $27 = $vp | 0;
    HEAP32[$27 >> 2] = $26$0;
    HEAP32[$27 + 4 >> 2] = $26$1;
    var $_0 = 1;
    __label__ = 14;
    break;
   case 10:
    if ($argc >>> 0 > 1) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $31 = $vp + 24 | 0;
    var $st$1$0 = $31 | 0;
    var $32$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $31 + 4 | 0;
    var $32$1 = HEAPU32[$st$1$1 >> 2];
    var $33 = $2 | 0;
    HEAP32[$33 >> 2] = $32$0;
    HEAP32[$33 + 4 >> 2] = $32$1;
    var $36$1 = $32$1;
    var $36$0 = $32$0;
    __label__ = 13;
    break;
   case 12:
    __ZN2JSL14UndefinedValueEv4098($2);
    var $_phi_trans_insert = $2 | 0;
    var $st$2$0 = $_phi_trans_insert | 0;
    var $st$2$1 = $_phi_trans_insert + 4 | 0;
    var $36$1 = HEAP32[$st$2$1 >> 2];
    var $36$0 = HEAP32[$st$2$0 >> 2];
    __label__ = 13;
    break;
   case 13:
    var $36$0;
    var $36$1;
    var $37 = $vp | 0;
    HEAP32[$37 >> 2] = $36$0;
    HEAP32[$37 + 4 >> 2] = $36$1;
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11WeakMap_getP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL14WeakMap_deleteP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $key = __stackBase__;
    var $ptr = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 24;
    var $4 = $vp + 8 | 0;
    var $5 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $4);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$5 + 4 >> 2];
    var $8 = __ZNK8JSObject9isWeakMapEv($_idx1_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js12WeakMapClassE);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 4:
    if (($argc | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 4, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str104087 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str225518 | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str226519 | 0, tempInt));
    var $_0 = 0;
    __label__ = 11;
    break;
   case 6:
    var $_idx2 = $vp + 16 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    var $14 = __ZL13NonNullObjectP9JSContextPN2JS5ValueE($cx, $_idx2_val$0, $_idx2_val$1);
    HEAP32[$key >> 2] = $14;
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx_val = HEAP32[$5 + 24 >> 2];
    var $17 = __ZL12GetObjectMapP8JSObject($_idx_val);
    if (($17 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = $17 + 8 | 0;
    __ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_($ptr, $20, $key);
    var $ptr_idx_val = HEAP32[$ptr >> 2];
    var $ptr_idx_val_idx_val = HEAP32[$ptr_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($1, $ptr_idx_val_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE($20, $ptr_idx_val);
    __ZN2JSL12BooleanValueEb4125($2, 1);
    var $25 = $2 | 0;
    var $26$0 = HEAP32[$25 >> 2];
    var $26$1 = HEAP32[$25 + 4 >> 2];
    var $27 = $vp | 0;
    HEAP32[$27 >> 2] = $26$0;
    HEAP32[$27 + 4 >> 2] = $26$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 10:
    __ZN2JSL12BooleanValueEb4125($3, 0);
    var $29 = $3 | 0;
    var $30$0 = HEAP32[$29 >> 2];
    var $30$1 = HEAP32[$29 + 4 >> 2];
    var $31 = $vp | 0;
    HEAP32[$31 >> 2] = $30$0;
    HEAP32[$31 + 4 >> 2] = $30$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14WeakMap_deleteP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL11WeakMap_setP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $key = __stackBase__;
    var $value = __stackBase__ + 4;
    var $1 = __stackBase__ + 12;
    var $2 = $vp + 8 | 0;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$3 + 4 >> 2];
    var $6 = __ZNK8JSObject9isWeakMapEv($_idx1_val);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js12WeakMapClassE);
    var $_0 = 0;
    __label__ = 16;
    break;
   case 4:
    if (($argc | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 4, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str54082 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str225518 | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str226519 | 0, tempInt));
    var $_0 = 0;
    __label__ = 16;
    break;
   case 6:
    var $_idx2 = $vp + 16 | 0;
    var $st$1$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$1$1 >> 2];
    var $12 = __ZL13NonNullObjectP9JSContextPN2JS5ValueE($cx, $_idx2_val$0, $_idx2_val$1);
    HEAP32[$key >> 2] = $12;
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ($argc >>> 0 > 1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $17 = $vp + 24 | 0;
    var $st$1$0 = $17 | 0;
    var $18$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $17 + 4 | 0;
    var $18$1 = HEAP32[$st$1$1 >> 2];
    var $19 = $value | 0;
    HEAP32[$19 >> 2] = $18$0;
    HEAP32[$19 + 4 >> 2] = $18$1;
    __label__ = 10;
    break;
   case 9:
    __ZN2JSL14UndefinedValueEv4098($value);
    __label__ = 10;
    break;
   case 10:
    var $_idx_val = HEAP32[$3 + 24 >> 2];
    var $22 = __ZL12GetObjectMapP8JSObject($_idx_val);
    if (($22 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $map_0 = $22;
      __label__ = 14;
      break;
    }
   case 11:
    var $25 = __ZN9JSContext4new_IN2js7WeakMapIP8JSObjectN2JS5ValueENS1_13DefaultHasherIS4_EENS1_17DefaultMarkPolicyIS4_S6_EEEEPS_EEPT_T0_($cx, $cx);
    var $26 = $25 + 8 | 0;
    var $27 = __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj($26);
    if ($27) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN9JSContext7delete_IN2js7WeakMapIP8JSObjectN2JS5ValueENS1_13DefaultHasherIS4_EENS1_17DefaultMarkPolicyIS4_S6_EEEEEEvPT_($25);
    __label__ = 15;
    break;
   case 13:
    var $30 = $25;
    __ZN8JSObject10setPrivateEPv($3, $30);
    var $map_0 = $25;
    __label__ = 14;
    break;
   case 14:
    var $map_0;
    __ZN2JSL14UndefinedValueEv4098($1);
    var $32 = $1 | 0;
    var $33$0 = HEAP32[$32 >> 2];
    var $33$1 = HEAP32[$32 + 4 >> 2];
    var $34 = $vp | 0;
    HEAP32[$34 >> 2] = $33$0;
    HEAP32[$34 + 4 >> 2] = $33$1;
    var $36 = __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3putERKS2_RKS4_($map_0 + 8 | 0, $key, $value);
    if (($36 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 1;
      __label__ = 16;
      break;
    }
   case 15:
    _JS_ReportOutOfMemory($cx);
    var $_0 = 0;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11WeakMap_setP9JSContextjPN2JS5ValueE["X"] = 1;

function __Z19js_InitWeakMapClassP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZN8JSObject8asGlobalEv($1);
    var $3 = $2;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($2, $4, __ZN2js12WeakMapClassE);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN8JSObject10setPrivateEPv($6, 0);
    var $13 = HEAP32[HEAP32[$cx + 52 >> 2] + 210164 >> 2];
    var $14 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($2, $4, 262, __ZN2js12WeakMapClassE, $13, 0);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $14;
    var $18 = $14 | 0;
    var $19 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $18, $5);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $21 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, 0, __ZL16weak_map_methods);
    if ($21) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $23 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $3, 36, $17, $6);
    var $_ = $23 ? $6 : 0;
    var $_0 = $_;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17WeakMap_constructP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE4108($cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN8JSObject10setPrivateEPv($1, 0);
    __ZN2JS5Value9setObjectER8JSObject($vp, $1);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL14UndefinedValueEv4098($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE4108($cx) {
  var $3 = HEAPU32[__ZN2js12WeakMapClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb4109($3);
  var $5 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE4110($cx, $4);
  return $5;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE4110($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js12WeakMapClassE + 4 >> 2] >>> 24;
    var $4 = __ZNK9JSContext5hasfpEv($cx);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $7;
    var $8 = $cx;
    var $9 = $global;
    var $10 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($8, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $18 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZNK9JSContext2fpEv($cx);
    var $13 = __ZNK2js10StackFrame10scopeChainEv($12);
    var $14 = $13;
    var $15 = __ZNK8JSObject9getGlobalEv($14);
    var $16 = $15;
    HEAP32[$global >> 2] = $16;
    var $18 = $16;
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $18, $19);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $20 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    HEAP32[$proto >> 2] = $22;
    var $29 = $22;
    __label__ = 9;
    break;
   case 7:
    var $24 = $cx;
    var $26 = $proto;
    var $27 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($24, $18, $3, $26, __ZN2js12WeakMapClassE);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $29 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $29;
    var $30 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE4111($cx, $29, $18, $kind);
    var $_0 = $30;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE4111($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, __ZN2js12WeakMapClassE, $1, $parent, 0, (__ZN2js12WeakMapClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $7 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, __ZN2js12WeakMapClassE, $kind);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $10);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13NonNullObjectP9JSContextPN2JS5ValueE($cx, $vp_0_0_0_val$0, $vp_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value11isPrimitiveEv($vp_0_0_0_val$0, $vp_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 4, 231, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $4 = __ZNK2JS5Value8toObjectEv($vp_0_0_0_val$0, $vp_0_0_0_val$1);
    var $_0 = $4;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12GetObjectMapP8JSObject($obj_0_6_val) {
  var $1 = __ZNK8JSObject10getPrivateEv($obj_0_6_val);
  return $1;
}

function __ZN9JSContext4new_IN2js7WeakMapIP8JSObjectN2JS5ValueENS1_13DefaultHasherIS4_EENS1_17DefaultMarkPolicyIS4_S6_EEEEPS_EEPT_T0_($this, $p1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 36);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    var $p1_idx_val = HEAP32[$p1 + 52 >> 2];
    __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEEC1EP9JSContext($4, $p1_idx_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4initEj($1);
  return $2;
}

function __ZN9JSContext7delete_IN2js7WeakMapIP8JSObjectN2JS5ValueENS1_13DefaultHasherIS4_EENS1_17DefaultMarkPolicyIS4_S6_EEEEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEED1Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3putERKS2_RKS4_($this, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_($p, $this, $k);
    var $_idx = $p | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $_idx_val_idx_val = HEAP32[$_idx_val >> 2];
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($1, $_idx_val_idx_val);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($_idx_val);
    var $7 = $v | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $6 + 8 | 0;
    var $st$7$0 = $9 | 0;
    HEAP32[$st$7$0 >> 2] = $8$0;
    var $st$7$1 = $9 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $8$1;
    var $10 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv($_idx_val);
    var $_0 = $10;
    __label__ = 5;
    break;
   case 3:
    var $12 = __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($this, $p, $k, $v);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_idx2_val = HEAP32[$_idx >> 2];
    var $14 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv($_idx2_val);
    var $_0 = $14;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($agg_result, $this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($this_0_0_val_0_0_val);
  var $_ = $1 ? {
    f0: 260,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE10getKeyHashEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEptEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv($this) {
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE9isRemovedEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this_0_2_val, $this_0_3_val, $this_0_5_val) {
  return ($this_0_5_val + $this_0_3_val | 0) >>> 0 >= ($this_0_2_val * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isFreeEv($this_0_0_val) {
  return ($this_0_0_val | 0) == 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE9matchHashEj($this_0_0_val, $hn) {
  return ($this_0_0_val & -2 | 0) == ($hn | 0);
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($this_0_0_val, $this_0_1_val) {
  return ($this_0_0_val | 0) == ($this_0_1_val | 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE12hasCollisionEv($this_0_0_val) {
  return ($this_0_0_val & 1 | 0) != 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEC2ERS9_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 8 | 0;
  HEAP32[$2 >> 2] = 0;
  HEAP32[$2 + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($e) {
  return $e | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($this_0_0_val) {
  return $this_0_0_val + 8 | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 8 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 12 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEaSERKS5_($this, $rhs) {
  var $2 = HEAP32[$rhs >> 2];
  HEAP32[$this >> 2] = $2;
  var $4 = $rhs + 8 | 0;
  var $5$0 = HEAP32[$4 >> 2];
  var $5$1 = HEAP32[$4 + 4 >> 2];
  var $6 = $this + 8 | 0;
  HEAP32[$6 >> 2] = $5$0;
  HEAP32[$6 + 4 >> 2] = $5$1;
  return;
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEEC2EP8JSTracer($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $7 = $v | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $5 + 8 | 0;
    var $st$10$0 = $9 | 0;
    HEAP32[$st$10$0 >> 2] = $8$0;
    var $st$10$1 = $9 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $8$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 8 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $_idx_val = HEAP32[$2 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE9isRemovedEv($_idx_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $22 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    var $_pre_phi5 = $this + 12 | 0;
    __label__ = 7;
    break;
   case 3:
    var $this_idx_val = HEAPU32[$this + 8 >> 2];
    var $this_idx1 = $this + 12 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $this_idx2_val = HEAPU32[$this + 20 >> 2];
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this_idx_val, $this_idx1_val, $this_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $2;
    var $_pre_phi = $p + 4 | 0;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 5:
    var $_ = $this_idx2_val >>> 0 < $this_idx_val >>> 2 >>> 0 & 1;
    var $16 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $_);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $p + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $19);
    HEAP32[$1 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $18;
    var $_pre_phi5 = $this_idx1;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi5;
    var $_pre_phi;
    var $22;
    var $23 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE7setLiveEj($22, $23);
    var $25 = HEAP32[$_pre_phi5 >> 2] + 1 | 0;
    HEAP32[$_pre_phi5 >> 2] = $25;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$this >> 2];
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($_idx_val, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $17 = $this + 16 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + $5 * 24 | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_02 = $1 | 0;
    var $src_01 = $3;
    __label__ = 5;
    break;
   case 5:
    var $src_01;
    var $src_01_idx = $src_01 | 0;
    var $src_01_idx_val = HEAP32[$src_01_idx >> 2];
    var $22 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isLiveEv($src_01_idx_val);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE14unsetCollisionEv($src_01);
    var $src_01_idx1_val = HEAP32[$src_01_idx >> 2];
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE10getKeyHashEv($src_01_idx1_val);
    var $25 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEENS_7MoveRefIT_EERSB_($1, $src_01);
    var $_02_val = HEAP32[$_02 >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEaSENS_7MoveRefIS8_EE($25, $_02_val);
    __label__ = 7;
    break;
   case 7:
    var $27 = $src_01 + 24 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($3);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 24 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 24 | 0;
    var $_idx_val = HEAP32[$17 >> 2];
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isFreeEv($_idx_val);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($alloc_0_0_val, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 24 | 0;
    var $2 = __ZN2js18RuntimeAllocPolicy7malloc_Ej($alloc_0_0_val, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 24 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 24 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isLiveEv($this_0_0_val) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE10isLiveHashEj($this_0_0_val);
  return $1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEaSENS_7MoveRefIS8_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEptEv($rhs_0);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 8 | 0;
  var $7 = $2 + 8 | 0;
  __ZN2js4MoveINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEENS_7MoveRefIT_EERS8_($1, $7);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEaSENS_7MoveRefIS5_EE($6, $_0_val);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEENS_7MoveRefIT_EERSB_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEC1ERS9_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($oldTable) {
  var $0 = $oldTable;
  __ZN2js18RuntimeAllocPolicy5free_EPv($0);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEC1ERS9_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEC2ERS9_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEaSENS_7MoveRefIS5_EE($this, $rhs_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEptEv($rhs_0);
  var $4 = $3 | 0;
  __ZN2js4MoveIP8JSObjectEENS_7MoveRefIT_EERKS4_($1, $4);
  var $_idx_val = HEAP32[$1 >> 2];
  var $5 = __ZNK2js7MoveRefIP8JSObjectEcvRS2_Ev($_idx_val);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = $3 + 8 | 0;
  __ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERS4_($2, $8);
  var $_idx1_val = HEAP32[$2 >> 2];
  var $9 = __ZNK2js7MoveRefIN2JS5ValueEEcvRS2_Ev($_idx1_val);
  var $10 = $9 | 0;
  var $11$0 = HEAP32[$10 >> 2];
  var $11$1 = HEAP32[$10 + 4 >> 2];
  var $12 = $this + 8 | 0;
  HEAP32[$12 >> 2] = $11$0;
  HEAP32[$12 + 4 >> 2] = $11$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 8 | 0;
  __ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEC1Ev($this) {
  __ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEC2Ev($this);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($this_0_0_val_0_0_val) {
  var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isLiveEv($this_0_0_val_0_0_val);
  return $1;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l_val1) {
  var $1 = __ZN2js13PointerHasherIP8JSObjectLj2EE4hashERKS2_($l_val1);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 24 | 0;
    var $_idx1_val = HEAP32[$6 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isFreeEv($_idx1_val);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE9matchHashEj($_idx1_val, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $l_val4 = HEAP32[$l >> 2];
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($6, $l_val4);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $entry_0_idx_val = $_idx1_val;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $entry_0_idx_val;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE9isRemovedEv($entry_0_idx_val);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 24 | 0;
    var $_idx_val = HEAP32[$27 >> 2];
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isFreeEv($_idx_val);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE9matchHashEj($_idx_val, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $l_val = HEAP32[$l >> 2];
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($27, $l_val);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $entry_0_idx_val = $_idx_val;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($e, $l_val1) {
  var $1 = $e + 8 | 0;
  var $2 = __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($1);
  var $_val = HEAP32[$2 >> 2];
  var $3 = __ZN2js13PointerHasherIP8JSObjectLj2EE5matchERKS2_S5_($_val, $l_val1);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEED1Ev($this) {
  __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEED2Ev($this);
  return;
}

function __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEED2Ev($this) {
  var $1 = $this + 8 | 0;
  __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev($1);
  return;
}

function __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev($this) {
  var $_idx_val = HEAP32[$this + 24 >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED1Ev($_idx_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED1Ev($this_0_6_val) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED2Ev($this_0_6_val);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED2Ev($this_0_6_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_6_val | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($this_0_6_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4initEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this >> 2];
    var $0 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($_idx_val, 16);
    HEAP32[$this + 24 >> 2] = $0;
    if (($0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, 4);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEEC1EP9JSContext($this, $cx_0_11_val) {
  __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEEC2EP9JSContext($this, $cx_0_11_val);
  return;
}

function __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEEC2EP9JSContext($this, $cx_0_11_val) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this + 8 | 0;
  __ZN2js18RuntimeAllocPolicyC1EP9JSContext($1, $cx_0_11_val);
  var $_0_val = HEAP32[$1 >> 2];
  __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES7_($2, $_0_val);
  var $3 = $this | 0;
  __ZN2js11WeakMapBaseC2Ev($3);
  HEAP32[$this >> 2] = __ZTVN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEEE + 8 | 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES7_($this, $a_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC1ESB_($1, $a_0);
  return;
}

function __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEE15nonMarkingTraceEP8JSTracer($this, $tracer) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $t = __stackBase__;
    var $r = __stackBase__ + 4;
    __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEEC1EP8JSTracer($t, $tracer);
    var $1 = $this + 8 | 0;
    __ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($r, $1);
    var $r_idx2 = $r | 0;
    var $r_idx2_val = HEAP32[$r_idx2 >> 2];
    var $r_idx3 = $r + 4 | 0;
    var $r_idx3_val = HEAP32[$r_idx3 >> 2];
    var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($r_idx2_val, $r_idx3_val);
    if ($2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $t_idx_val = HEAP32[$t >> 2];
    var $r_idx4_val = $r_idx2_val;
    __label__ = 3;
    break;
   case 3:
    var $r_idx4_val;
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($r_idx4_val);
    var $_idx = $3 + 8 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE9markEntryERKS4_($t_idx_val, $_idx_val$0, $_idx_val$1);
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($r);
    var $r_idx_val = HEAP32[$r_idx2 >> 2];
    var $r_idx1_val = HEAP32[$r_idx3 >> 2];
    var $4 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($r_idx_val, $r_idx1_val);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      var $r_idx4_val = $r_idx_val;
      __label__ = 3;
      break;
    }
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEE15markIterativelyEP8JSTracer($this, $tracer) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $t = __stackBase__;
    var $r = __stackBase__ + 4;
    __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEEC1EP8JSTracer($t, $tracer);
    var $1 = $this + 8 | 0;
    __ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($r, $1);
    var $r_idx2 = $r | 0;
    var $r_idx2_val = HEAP32[$r_idx2 >> 2];
    var $r_idx3 = $r + 4 | 0;
    var $r_idx3_val = HEAP32[$r_idx3 >> 2];
    var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($r_idx2_val, $r_idx3_val);
    if ($2) {
      var $markedAny_0_lcssa = 0;
      __label__ = 4;
      break;
    } else {
      var $markedAny_01 = 0;
      var $r_idx4_val = $r_idx2_val;
      __label__ = 2;
      break;
    }
   case 2:
    var $r_idx4_val;
    var $markedAny_01;
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($r_idx4_val);
    var $5 = HEAP32[$3 >> 2];
    var $6 = $3 + 8 | 0;
    var $7 = __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE15markEntryIfLiveES2_RKS4_($t, $5, $6);
    var $markedAny_1 = $7 ? 1 : $markedAny_01;
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($r);
    var $r_idx_val = HEAP32[$r_idx2 >> 2];
    var $r_idx1_val = HEAP32[$r_idx3 >> 2];
    var $8 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($r_idx_val, $r_idx1_val);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $markedAny_01 = $markedAny_1;
      var $r_idx4_val = $r_idx_val;
      __label__ = 2;
      break;
    }
   case 3:
    var $markedAny_0_lcssa = ($markedAny_1 & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 4:
    var $markedAny_0_lcssa;
    STACKTOP = __stackBase__;
    return $markedAny_0_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEE5sweepEP8JSTracer($this, $tracer) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $t = __stackBase__;
    var $e = __stackBase__ + 4;
    __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEEC1EP8JSTracer($t, $tracer);
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC1INS_7WeakMapIS4_S6_SA_NS_17DefaultMarkPolicyIS4_S6_EEEEEERT_($e, $this);
    var $1 = $e | 0;
    var $_idx2 = $e | 0;
    var $_idx2_val = HEAP32[$_idx2 >> 2];
    var $_idx3 = $e + 4 | 0;
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($_idx2_val, $_idx3_val);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $t_idx_val_idx = HEAP32[$t >> 2] | 0;
    var $_idx4_val = $_idx2_val;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD1Ev($e);
    STACKTOP = __stackBase__;
    return;
   case 4:
    var $_idx4_val;
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($_idx4_val);
    var $5 = HEAP32[$3 >> 2];
    var $t_idx_val_idx_val_idx_val_idx_val = HEAP32[HEAP32[HEAP32[$t_idx_val_idx >> 2] + 52 >> 2] + 144080 >> 2];
    var $6 = __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE9keyMarkedES2_($t_idx_val_idx_val_idx_val_idx_val, $5);
    if ($6) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4Enum11removeFrontEv($e);
    __label__ = 6;
    break;
   case 6:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($1);
    var $_idx_val = HEAP32[$_idx2 >> 2];
    var $_idx1_val = HEAP32[$_idx3 >> 2];
    var $9 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($_idx_val, $_idx1_val);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_idx4_val = $_idx_val;
      __label__ = 4;
      break;
    }
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEEC1EP8JSTracer($this, $t) {
  __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEEC2EP8JSTracer($this, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC1INS_7WeakMapIS4_S6_SA_NS_17DefaultMarkPolicyIS4_S6_EEEEEERT_($this, $map) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC2INS_7WeakMapIS4_S6_SA_NS_17DefaultMarkPolicyIS4_S6_EEEEEERT_($this, $map);
  return;
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE9keyMarkedES2_($this_0_0_val_0_0_val_0_11_val_0_36_val, $k) {
  var $1 = $k;
  var $2 = __Z20IsAboutToBeFinalizedP9JSContextPKv($this_0_0_val_0_0_val_0_11_val_0_36_val, $1);
  return $2 ^ 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 24 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$5 >> 2];
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isLiveEv($_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e_idx_val = HEAP32[$e >> 2];
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE12hasCollisionEv($e_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE10setRemovedEv($e);
    var $3 = $this + 20 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 12 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 8 | 0;
  __ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEC1Ev($1);
  __ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 8 | 0;
  __ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEC1Ev($1);
  __ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC2INS_7WeakMapIS4_S6_SA_NS_17DefaultMarkPolicyIS4_S6_EEEEEERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $map + 8 | 0;
  __ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($1, $2);
  var $3 = $1;
  var $4 = $this;
  var $5$0 = HEAP32[$3 >> 2];
  var $5$1 = HEAP32[$3 + 4 >> 2];
  HEAP32[$4 >> 2] = $5$0;
  HEAP32[$4 + 4 >> 2] = $5$1;
  HEAP32[$this + 8 >> 2] = $2 | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($agg_result, $this) {
  var $_idx_val = HEAP32[$this + 8 >> 2];
  var $_idx1_val = HEAP32[$this + 24 >> 2];
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3allEv($agg_result, $_idx_val, $_idx1_val);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3allEv($agg_result, $this_0_2_val, $this_0_6_val) {
  var $1 = $this_0_6_val + $this_0_2_val * 24 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_($agg_result, $this_0_6_val, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$4 >> 2];
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isLiveEv($_idx_val);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 24 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE15markEntryIfLiveES2_RKS4_($this, $k, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx = $this | 0;
    var $this_idx_val_idx_val_idx_val_idx_val = HEAP32[HEAP32[HEAP32[HEAP32[$this_idx >> 2] >> 2] + 52 >> 2] + 144080 >> 2];
    var $1 = __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE9keyMarkedES2_($this_idx_val_idx_val_idx_val_idx_val, $k);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE17markUnmarkedValueERKS4_($this, $v);
    var $_0 = $3;
    __label__ = 5;
    break;
   case 3:
    var $this_idx1_val = HEAP32[$this_idx >> 2];
    var $this_idx1_val_idx_val = HEAP32[$this_idx1_val + 4 >> 2];
    var $5 = __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE18overrideKeyMarkingES2_($this_idx1_val_idx_val, $k);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($this_idx1_val, $k);
    var $7 = __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE17markUnmarkedValueERKS4_($this, $v);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14JSProxyHandler6familyEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZN9JSWrapperD2Ev($this) {
  return;
}

function __ZN9JSWrapper5enterEP9JSContextP8JSObjectiNS_6ActionEPb($this, $cx, $wrapper, $id, $act, $bp) {
  HEAP8[$bp] = 1;
  return 1;
}

function __ZN9JSWrapper5leaveEP9JSContextP8JSObject($this, $cx, $wrapper) {
  return;
}

function __ZL4CondiPb($b, $bp) {
  HEAP8[$bp] = ($b | 0) != 0 & 1;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC2ESB_($this, $ap_0) {
  HEAP32[$this >> 2] = $ap_0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  return;
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE17markUnmarkedValueERKS4_($this, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx1 = $v | 0;
    var $v_idx1_val$0 = HEAP32[$v_idx1 >> 2];
    var $v_idx1_val$1 = HEAP32[$v_idx1 + 4 >> 2];
    var $1 = __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE11valueMarkedERKS4_($this, $v_idx1_val$0, $v_idx1_val$1);
    if ($1) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$this >> 2];
    var $v_idx_val$0 = HEAP32[$v_idx1 >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx1 + 4 >> 2];
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($4, $v_idx_val$0, $v_idx_val$1);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE18overrideKeyMarkingES2_($this_0_0_val_0_1_val, $k) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_0_val_0_1_val | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $k_idx_val = HEAP32[$k + 4 >> 2];
    var $3 = __ZNK8JSObject8getClassEv($k_idx_val);
    var $_0 = (HEAP8[$3 + 88 | 0] & 1) << 24 >> 24 != 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE11valueMarkedERKS4_($this, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value10isMarkableEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = HEAP32[HEAP32[$this >> 2] >> 2];
    var $7 = __ZNK2JS5Value9toGCThingEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_idx_val_idx_val = HEAP32[HEAP32[$6 + 52 >> 2] + 144080 >> 2];
    var $8 = __Z20IsAboutToBeFinalizedP9JSContextPKv($_idx_val_idx_val, $7);
    var $_0 = $8 ^ 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE9markEntryERKS4_($this_0_0_val, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($this_0_0_val, $v_0_0_0_val$0, $v_0_0_0_val$1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC1ESB_($this, $ap_01) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC2ESB_($this, $ap_01);
  return;
}

function __ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE($this, $p_0) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE($1, $p_0);
  return;
}

function __ZN2JSL12BooleanValueEb4125($agg_result, $boo) {
  __ZN2JS5Value10setBooleanEb($agg_result, $boo);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE($this, $p_0) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE($this, $p_0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv($this);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $this, $l) {
  var $l_val = HEAP32[$l >> 2];
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l_val);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry);
  return;
}

function __ZNK8JSObject9isWrapperEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 4 >> 2];
    var $1 = __ZNK8JSObject7isProxyEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject15getProxyHandlerEv($this);
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZN2js14JSProxyHandler6familyEv($_idx_val);
    var $7 = ($4 | 0) == (__ZL14sWrapperFamily | 0);
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject25isCrossCompartmentWrapperEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject9isWrapperEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $9 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject17getWrapperHandlerEv($this);
    var $_idx_val = HEAP32[$3 + 8 >> 2];
    var $5 = __ZNK9JSWrapper5flagsEv($_idx_val);
    var $9 = ($5 & 1 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject17getWrapperHandlerEv($this) {
  var $1 = __ZNK8JSObject15getProxyHandlerEv($this);
  return $1;
}

function __ZN8JSObject6unwrapEPj($this, $flagsp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $flags_0 = 0;
    var $wrapped_0 = $this;
    __label__ = 2;
    break;
   case 2:
    var $wrapped_0;
    var $flags_0;
    var $2 = __ZNK8JSObject9isWrapperEv($wrapped_0);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      var $flags_1 = $flags_0;
      var $wrapped_1 = $wrapped_0;
      __label__ = 4;
      break;
    }
   case 3:
    var $4 = __ZNK8JSObject15getProxyHandlerEv($wrapped_0);
    var $_idx1_val = HEAP32[$4 + 8 >> 2];
    var $6 = __ZNK9JSWrapper5flagsEv($_idx1_val);
    var $7 = $6 | $flags_0;
    var $8 = __ZNK8JSObject15getProxyPrivateEv($wrapped_0);
    var $_idx2 = $8 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    var $9 = __ZNK2JS5Value14toObjectOrNullEv($_idx2_val$0, $_idx2_val$1);
    var $_idx_val = HEAP32[$9 + 4 >> 2];
    var $10 = __ZNK8JSObject8getClassEv($_idx_val);
    if ((HEAP32[$10 + 76 >> 2] | 0) == 0) {
      var $flags_0 = $7;
      var $wrapped_0 = $9;
      __label__ = 2;
      break;
    } else {
      var $flags_1 = $7;
      var $wrapped_1 = $9;
      __label__ = 4;
      break;
    }
   case 4:
    var $wrapped_1;
    var $flags_1;
    if (($flagsp | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$flagsp >> 2] = $flags_1;
    __label__ = 6;
    break;
   case 6:
    return $wrapped_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapperD0Ev($this) {
  var $1 = $this;
  __ZdlPv($1);
  return;
}

function __ZN9JSWrapper21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($this, $cx, $wrapper, $id, $set, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    HEAP32[$desc >> 2] = 0;
    var $5 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $6 = $set & 1;
    var $7 = FUNCTION_TABLE[$5]($this, $cx, $wrapper, $id, $6, $status);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $13 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $14 = _JS_GetPropertyDescriptorById($cx, $13, $id, $desc);
    var $15 = ($14 | 0) != 0;
    var $19 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$19]($this, $cx, $wrapper);
    var $_0 = $15;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper) {
  var $1 = __ZNK8JSObject15getProxyPrivateEv($wrapper);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $2 = __ZNK2JS5Value14toObjectOrNullEv($_idx_val$0, $_idx_val$1);
  return $2;
}

function __ZN9JSWrapper24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($this, $cx, $wrapper, $id, $set, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    HEAP32[$desc >> 2] = 0;
    var $5 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $6 = $set & 1;
    var $7 = FUNCTION_TABLE[$5]($this, $cx, $wrapper, $id, $6, $status);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $13 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $14 = __ZL24GetOwnPropertyDescriptorP9JSContextP8JSObjectijP20JSPropertyDescriptor($cx, $13, $id, $desc);
    var $18 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$18]($this, $cx, $wrapper);
    var $_0 = $14;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24GetOwnPropertyDescriptorP9JSContextP8JSObjectijP20JSPropertyDescriptor($cx, $obj, $id, $desc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $1 = __ZNK8JSObject7isProxyEv($obj_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js7JSProxy24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($cx, $obj, $id, 0, $desc);
    var $_0 = $3;
    __label__ = 6;
    break;
   case 3:
    var $5 = _JS_GetPropertyDescriptorById($cx, $obj, $id, $desc);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = $desc | 0;
    if ((HEAP32[$8 >> 2] | 0) == ($obj | 0)) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$8 >> 2] = 0;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor($this, $cx, $wrapper, $id, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, $id, 1, $status);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $11 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $12 = $desc + 16 | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    var $15 = HEAP32[$desc + 8 >> 2];
    var $17 = HEAP32[$desc + 12 >> 2];
    var $19 = HEAP32[$desc + 4 >> 2];
    var $20 = _JS_DefinePropertyById($cx, $11, $id, $13$0, $13$1, $15, $17, $19);
    var $21 = ($20 | 0) != 0;
    var $25 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$25]($this, $cx, $wrapper);
    var $_0 = $21;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper19getOwnPropertyNamesEP9JSContextP8JSObjectRN2js12AutoIdVectorE($this, $cx, $wrapper, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, 2, 0, $status);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $11 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $12 = $cx;
    var $13 = $11;
    var $14 = $props;
    var $15 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($12, $13, 24, $14);
    var $19 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$19]($this, $cx, $wrapper);
    var $_0 = $15;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper7delete_EP9JSContextP8JSObjectiPb($this, $cx, $wrapper, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $status = __stackBase__ + 8;
    HEAP8[$bp] = 1;
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, $id, 1, $status);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 6;
    break;
   case 3:
    var $11 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $12 = _JS_DeletePropertyById2($cx, $11, $id, $v);
    if (($12 | 0) == 0) {
      var $16 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZL14ValueToBooleanPN2JS5ValueEPb($v, $bp);
    var $16 = 1;
    __label__ = 5;
    break;
   case 5:
    var $16;
    var $20 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$20]($this, $cx, $wrapper);
    var $_0 = $16;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14ValueToBooleanPN2JS5ValueEPb($vp, $bp) {
  var $1 = __Z17js_ValueToBooleanRKN2JS5ValueE($vp);
  HEAP8[$bp] = ($1 | 0) != 0 & 1;
  return;
}

function __ZN9JSWrapper9enumerateEP9JSContextP8JSObjectRN2js12AutoIdVectorE($this, $cx, $wrapper, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, 2, 0, $status);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $11 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $12 = $cx;
    var $13 = $11;
    var $14 = $props;
    var $15 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($12, $13, 0, $14);
    var $19 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$19]($this, $cx, $wrapper);
    var $_0 = $15;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper3fixEP9JSContextP8JSObjectPN2JS5ValueE($this, $cx, $wrapper, $vp) {
  __ZN2JS5Value12setUndefinedEv($vp);
  return 1;
}

function __ZN9JSWrapper3hasEP9JSContextP8JSObjectiPb($this, $cx, $wrapper, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $found = __stackBase__;
    var $status = __stackBase__ + 4;
    HEAP8[$bp] = 0;
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, $id, 0, $status);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 6;
    break;
   case 3:
    var $11 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $12 = _JS_HasPropertyById($cx, $11, $id, $found);
    if (($12 | 0) == 0) {
      var $17 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = HEAP32[$found >> 2];
    __ZL4CondiPb($15, $bp);
    var $17 = 1;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $21 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$21]($this, $cx, $wrapper);
    var $_0 = $17;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper6hasOwnEP9JSContextP8JSObjectiPb($this, $cx, $wrapper, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $desc = __stackBase__;
    var $status = __stackBase__ + 32;
    HEAP8[$bp] = 0;
    var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $5 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $6 = FUNCTION_TABLE[$5]($this, $cx, $wrapper, $id, 0, $status);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 6;
    break;
   case 3:
    var $12 = _JS_GetPropertyDescriptorById($cx, $1, $id, $desc);
    if (($12 | 0) == 0) {
      var $20 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $18 = (HEAP32[$desc >> 2] | 0) == ($1 | 0) & 1;
    __ZL4CondiPb($18, $bp);
    var $20 = 1;
    __label__ = 5;
    break;
   case 5:
    var $20;
    var $24 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$24]($this, $cx, $wrapper);
    var $_0 = $20;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper3getEP9JSContextP8JSObjectS3_iPN2JS5ValueE($this, $cx, $wrapper, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    __ZN2JS5Value12setUndefinedEv($vp);
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, $id, 0, $status);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $11 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $12 = __ZN8JSObject10getGenericEP9JSContextPS_iPN2JS5ValueE($11, $cx, $receiver, $id, $vp);
    var $13 = ($12 | 0) != 0;
    var $17 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$17]($this, $cx, $wrapper);
    var $_0 = $13;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper3setEP9JSContextP8JSObjectS3_ibPN2JS5ValueE($this, $cx, $wrapper, $receiver, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, $id, 1, $status);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $11 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $12 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($11, $cx, $id, $vp, 0);
    var $13 = ($12 | 0) != 0;
    var $17 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$17]($this, $cx, $wrapper);
    var $_0 = $13;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper4keysEP9JSContextP8JSObjectRN2js12AutoIdVectorE($this, $cx, $wrapper, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, 2, 0, $status);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $11 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $12 = $cx;
    var $13 = $11;
    var $14 = $props;
    var $15 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($12, $13, 8, $14);
    var $19 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$19]($this, $cx, $wrapper);
    var $_0 = $15;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper7iterateEP9JSContextP8JSObjectjPN2JS5ValueE($this, $cx, $wrapper, $flags, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    __ZN2JS5Value12setUndefinedEv($vp);
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, 2, 0, $status);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $11 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $12 = $cx;
    var $13 = $11;
    var $14 = __ZN2js11GetIteratorEP9JSContextP8JSObjectjPN2JS5ValueE($12, $13, $flags, $vp);
    var $18 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$18]($this, $cx, $wrapper);
    var $_0 = $14;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper4callEP9JSContextP8JSObjectjPN2JS5ValueE($this, $cx, $wrapper, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    __ZN2JS5Value12setUndefinedEv($vp);
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, 2, 2, $status);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $11 = __ZN2js14JSProxyHandler4callEP9JSContextP8JSObjectjPN2JS5ValueE(undef, $cx, $wrapper, $argc, $vp);
    var $15 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$15]($this, $cx, $wrapper);
    var $_0 = $11;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper9constructEP9JSContextP8JSObjectjPN2JS5ValueES6_($this, $cx, $wrapper, $argc, $argv, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    __ZN2JS5Value12setUndefinedEv($vp);
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, 2, 0, $status);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $11 = __ZN2js14JSProxyHandler9constructEP9JSContextP8JSObjectjPN2JS5ValueES7_(undef, $cx, $wrapper, $argc, $argv, $vp);
    var $15 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$15]($this, $cx, $wrapper);
    var $_0 = $11;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb($this, $cx, $wrapper, $vp, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $b = __stackBase__;
    var $status = __stackBase__ + 4;
    HEAP8[$bp] = 0;
    HEAP32[$b >> 2] = 0;
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, 2, 0, $status);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 6;
    break;
   case 3:
    var $11 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $12 = $vp | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    var $14 = _JS_HasInstance($cx, $11, $13$0, $13$1, $b);
    if (($14 | 0) == 0) {
      var $19 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = HEAP32[$b >> 2];
    __ZL4CondiPb($17, $bp);
    var $19 = 1;
    __label__ = 5;
    break;
   case 5:
    var $19;
    var $23 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$23]($this, $cx, $wrapper);
    var $_0 = $19;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper6typeOfEP9JSContextP8JSObject($this, $cx, $wrapper) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
  __ZN2JSL11ObjectValueER8JSObject4137($1, $2);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $3 = __ZN2js11TypeOfValueEP9JSContextRKN2JS5ValueE($cx, $_idx_val$0, $_idx_val$1);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN2JSL11ObjectValueER8JSObject4137($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN9JSWrapper12obj_toStringEP9JSContextP8JSObject($this, $cx, $wrapper) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, 2, 0, $status);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP8[$status] & 1) << 24 >> 24 == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = _JS_NewStringCopyZ($cx, STRING_TABLE.__str4127 | 0);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 4:
    var $13 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $14 = $cx;
    var $15 = $13;
    var $16 = __ZN2js18obj_toStringHelperEP9JSContextP8JSObject($14, $15);
    var $20 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$20]($this, $cx, $wrapper);
    var $_0 = $16;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper12fun_toStringEP9JSContextP8JSObjectj($this, $cx, $wrapper, $indent) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    var $v = __stackBase__ + 4;
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, 2, 0, $status);
    if ($5) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP8[$status] & 1) << 24 >> 24 == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $wrapper_idx_val = HEAP32[$wrapper + 4 >> 2];
    var $11 = __ZN8JSObject10isCallableEv($wrapper_idx_val);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = _JS_NewStringCopyZ($cx, STRING_TABLE.__str14128 | 0);
    var $_0 = $13;
    __label__ = 7;
    break;
   case 5:
    __ZN2JSL11ObjectValueER8JSObject4137($v, $wrapper);
    __Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj($cx, $v, 0);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $16 = __ZN2js14JSProxyHandler12fun_toStringEP9JSContextP8JSObjectj(undef, $cx, $wrapper, $indent);
    var $20 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$20]($this, $cx, $wrapper);
    var $_0 = $16;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE($this, $cx, $wrapper, $hint, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2JSL11ObjectValueER8JSObject4137($1, $2);
    var $3 = $1 | 0;
    var $4$0 = HEAP32[$3 >> 2];
    var $4$1 = HEAP32[$3 + 4 >> 2];
    var $5 = $vp | 0;
    HEAP32[$5 >> 2] = $4$0;
    HEAP32[$5 + 4 >> 2] = $4$1;
    if (($hint | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = __ZN2jsL11ToPrimitiveEP9JSContextPN2JS5ValueE4138($cx, $vp);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 3:
    var $10 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE4139($cx, $hint, $vp);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL11ToPrimitiveEP9JSContextPN2JS5ValueE4138($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $vp_idx1 = $vp | 0;
    var $vp_idx1_val$0 = HEAP32[$vp_idx1 >> 2];
    var $vp_idx1_val$1 = HEAP32[$vp_idx1 + 4 >> 2];
    var $1 = __ZNK2JS5Value11isPrimitiveEv($vp_idx1_val$0, $vp_idx1_val$1);
    if ($1) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($vp_idx1_val$0, $vp_idx1_val$1);
    var $4 = $3;
    var $5 = $cx;
    var $6 = __ZN8JSObject12defaultValueEP9JSContext6JSTypePN2JS5ValueE($4, $5, 0, $vp);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE4139($cx, $preferredType, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $vp_idx1 = $vp | 0;
    var $vp_idx1_val$0 = HEAP32[$vp_idx1 >> 2];
    var $vp_idx1_val$1 = HEAP32[$vp_idx1 + 4 >> 2];
    var $1 = __ZNK2JS5Value11isPrimitiveEv($vp_idx1_val$0, $vp_idx1_val$1);
    if ($1) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($vp_idx1_val$0, $vp_idx1_val$1);
    var $4 = $3;
    var $5 = $cx;
    var $6 = __ZN8JSObject12defaultValueEP9JSContext6JSTypePN2JS5ValueE($4, $5, $preferredType, $vp);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper5traceEP8JSTracerP8JSObject($this, $trc, $wrapper) {
  var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
  __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $1);
  return;
}

function __ZN9JSWrapper14wrapperHandlerEPK8JSObject($wrapper) {
  var $1 = __ZNK8JSObject15getProxyHandlerEv($wrapper);
  return $1;
}

function __ZN9JSWrapper3NewEP9JSContextP8JSObjectS3_S3_PS_($cx, $obj, $proto, $parent, $handler) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $obj_idx = $obj + 4 | 0;
    var $obj_idx_val = HEAP32[$obj_idx >> 2];
    var $2 = __ZNK8JSObject5isXMLEv($obj_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 4, 263, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $5 = $handler | 0;
    __ZN2JSL11ObjectValueER8JSObject4137($1, $obj);
    var $obj_idx1_val = HEAP32[$obj_idx >> 2];
    var $6 = __ZN8JSObject10isCallableEv($obj_idx1_val);
    var $7 = $6 ? $obj : 0;
    var $8 = __ZN2js14NewProxyObjectEP9JSContextPNS_14JSProxyHandlerERKN2JS5ValueEP8JSObjectS9_S9_S9_($cx, $5, $1, $proto, $parent, $7, 0);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _TransparentObjectWrapper($cx, $obj, $wrappedProto, $parent, $flags) {
  var $1 = __ZN9JSWrapper3NewEP9JSContextP8JSObjectS3_S3_PS_($cx, $obj, $wrappedProto, $parent, __ZN25JSCrossCompartmentWrapper9singletonE | 0);
  return $1;
}

function __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($this, $cx, $target) {
  HEAP32[$this >> 2] = $cx;
  var $4 = HEAP32[$cx + 56 >> 2];
  HEAP32[$this + 4 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = $target;
  var $6 = $this + 12 | 0;
  var $7 = __ZNK8JSObject14getCompartmentEv($target);
  HEAP32[$6 >> 2] = $7;
  var $8 = $this + 16 | 0;
  __ZN7mozilla5MaybeIN2js15DummyFrameGuardEEC1Ev($8);
  HEAP8[$this + 48 | 0] = 0;
  return;
}

function __ZN7mozilla5MaybeIN2js15DummyFrameGuardEEC1Ev($this) {
  __ZN7mozilla5MaybeIN2js15DummyFrameGuardEEC2Ev($this);
  return;
}

function __ZN7mozilla15AlignedStorage2IN2js15DummyFrameGuardEE4addrEv($this) {
  return $this;
}

function __ZN7mozilla5MaybeIN2js15DummyFrameGuardEEC2Ev($this) {
  HEAP8[$this + 28 | 0] = 0;
  return;
}

function __ZN2js15AutoCompartmentD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 48 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js15AutoCompartment5leaveEv($this);
    __label__ = 3;
    break;
   case 3:
    var $7 = $this + 16 | 0;
    __ZN7mozilla5MaybeIN2js15DummyFrameGuardEED1Ev($7);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15AutoCompartment5leaveEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 4 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this + 16 | 0;
    __ZN7mozilla5MaybeIN2js15DummyFrameGuardEE7destroyEv($7);
    var $9 = HEAP32[$this >> 2];
    __ZN9JSContext16resetCompartmentEv($9);
    __label__ = 3;
    break;
   case 3:
    HEAP8[$this + 48 | 0] = 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla5MaybeIN2js15DummyFrameGuardEED1Ev($this) {
  __ZN7mozilla5MaybeIN2js15DummyFrameGuardEED2Ev($this);
  return;
}

function __ZN2js15AutoCompartment5enterEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 12 | 0;
    if ((HEAP32[$this + 4 >> 2] | 0) == (HEAP32[$3 >> 2] | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this | 0;
    var $10 = HEAP32[$this + 8 >> 2];
    var $11 = __ZNK8JSObject9getGlobalEv($10);
    var $12 = $this + 16 | 0;
    __ZN7mozilla5MaybeIN2js15DummyFrameGuardEE9constructEv($12);
    var $13 = HEAP32[$7 >> 2];
    var $14 = $13 + 60 | 0;
    var $15 = HEAP32[$3 >> 2];
    var $16 = __ZN7mozilla5MaybeIN2js15DummyFrameGuardEE3refEv($12);
    var $17 = $14;
    var $18 = $13;
    var $19 = $15;
    var $20 = $11;
    var $21 = $16;
    var $22 = __ZN2js12ContextStack14pushDummyFrameEP9JSContextP13JSCompartmentR8JSObjectPNS_15DummyFrameGuardE($17, $18, $19, $20, $21);
    if ($22) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $24 = HEAP32[$7 >> 2];
    var $_idx_val = HEAP32[$24 + 20 >> 2];
    var $25 = __ZN9JSContext18isExceptionPendingEv($_idx_val);
    if ($25) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN9JSContext20wrapPendingExceptionEv($24);
    __label__ = 5;
    break;
   case 5:
    HEAP8[$this + 48 | 0] = 1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla5MaybeIN2js15DummyFrameGuardEE9constructEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZN7mozilla15AlignedStorage2IN2js15DummyFrameGuardEE4addrEv($1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    HEAP32[$5 >> 2] = 0;
    HEAP32[$5 + 4 >> 2] = 0;
    HEAP32[$5 + 8 >> 2] = 0;
    HEAP32[$5 + 12 >> 2] = 0;
    HEAP32[$5 + 16 >> 2] = 0;
    HEAP32[$5 + 20 >> 2] = 0;
    HEAP32[$5 + 24 >> 2] = 0;
    __ZN2js15DummyFrameGuardC1Ev($2);
    __label__ = 3;
    break;
   case 3:
    HEAP8[$this + 28 | 0] = 1;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla5MaybeIN2js15DummyFrameGuardEE3refEv($this) {
  var $1 = __ZN7mozilla5MaybeIN2js15DummyFrameGuardEE3asTEv($this);
  return $1;
}

function __ZN7mozilla5MaybeIN2js15DummyFrameGuardEE7destroyEv($this) {
  var $1 = __ZN7mozilla5MaybeIN2js15DummyFrameGuardEE3refEv($this);
  __ZN2js15DummyFrameGuardD1Ev($1);
  HEAP8[$this + 28 | 0] = 0;
  return;
}

function __ZN2js11ErrorCopierD2Ev($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $exc = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = $this | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$3 >> 2];
    var $9 = HEAP32[$3 + 12 >> 2];
    if ((HEAP32[$5 + 56 >> 2] | 0) == ($9 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    if ((HEAP32[$3 + 4 >> 2] | 0) == ($9 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx3_val = HEAP32[$5 + 20 >> 2];
    var $16 = __ZN9JSContext18isExceptionPendingEv($_idx3_val);
    if ($16) {
      __label__ = 4;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    var $_idx4 = $5 + 24 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    __ZN9JSContext19getPendingExceptionEv($exc, $_idx4_val$0, $_idx4_val$1);
    var $exc_idx = $exc | 0;
    var $exc_idx_val$0 = HEAP32[$exc_idx >> 2];
    var $exc_idx_val$1 = HEAP32[$exc_idx + 4 >> 2];
    var $18 = __ZNK2JS5Value8isObjectEv($exc_idx_val$0, $exc_idx_val$1);
    if ($18) {
      __label__ = 5;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 5:
    var $20 = __ZNK2JS5Value8toObjectEv($exc_idx_val$0, $exc_idx_val$1);
    var $_idx6_val = HEAP32[$20 + 4 >> 2];
    var $22 = __ZNK8JSObject7isErrorEv($_idx6_val);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $_idx_val = HEAP32[$20 + 24 >> 2];
    var $24 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($24 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN9JSContext21clearPendingExceptionEv($5);
    var $27 = HEAP32[$2 >> 2];
    __ZN2js15AutoCompartment5leaveEv($27);
    var $30 = $5;
    var $31 = $20;
    var $32 = HEAP32[$this + 4 >> 2];
    var $33 = __Z18js_CopyErrorObjectP9JSContextP8JSObjectS2_($30, $31, $32);
    if (($33 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $36 = $33;
    __ZN2JSL11ObjectValueER8JSObject4137($1, $36);
    var $_idx5 = $1 | 0;
    var $_idx5_val$0 = HEAP32[$_idx5 >> 2];
    var $_idx5_val$1 = HEAP32[$_idx5 + 4 >> 2];
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($5, $_idx5_val$0, $_idx5_val$1);
    __label__ = 9;
    break;
   case 9:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11ErrorCopierD2Ev["X"] = 1;

function __ZN25JSCrossCompartmentWrapperD0Ev($this) {
  var $1 = $this;
  __ZdlPv($1);
  return;
}

function __ZN25JSCrossCompartmentWrapper21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($this, $cx, $wrapper, $id, $set, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $call = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $id;
    var $2 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $2);
    var $3 = __ZN2js15AutoCompartment5enterEv($call);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $6 = HEAP32[$call + 12 >> 2];
    var $7 = __ZN13JSCompartment6wrapIdEP9JSContextPi($6, $cx, $1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = $this | 0;
    var $10 = HEAP32[$1 >> 2];
    var $11 = __ZN9JSWrapper21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($9, $cx, $wrapper, $10, $set, $desc);
    __ZN2js15AutoCompartment5leaveEv($call);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $14 = HEAP32[$call + 4 >> 2];
    var $15 = $desc;
    var $16 = __ZN13JSCompartment4wrapEP9JSContextP20JSPropertyDescriptor($14, $cx, $15);
    var $_0 = $16;
    __label__ = 6;
    break;
   case 5:
    __ZN2js15AutoCompartment5leaveEv($call);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($this, $cx, $wrapper, $id, $set, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $call = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $id;
    var $2 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $2);
    var $3 = __ZN2js15AutoCompartment5enterEv($call);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $6 = HEAP32[$call + 12 >> 2];
    var $7 = __ZN13JSCompartment6wrapIdEP9JSContextPi($6, $cx, $1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = $this | 0;
    var $10 = HEAP32[$1 >> 2];
    var $11 = __ZN9JSWrapper24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($9, $cx, $wrapper, $10, $set, $desc);
    __ZN2js15AutoCompartment5leaveEv($call);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $14 = HEAP32[$call + 4 >> 2];
    var $15 = $desc;
    var $16 = __ZN13JSCompartment4wrapEP9JSContextP20JSPropertyDescriptor($14, $cx, $15);
    var $_0 = $16;
    __label__ = 6;
    break;
   case 5:
    __ZN2js15AutoCompartment5leaveEv($call);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor($this, $cx, $wrapper, $id, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 104;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $desc2 = __stackBase__ + 4;
    var $call = __stackBase__ + 52;
    HEAP32[$1 >> 2] = $id;
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContextP20JSPropertyDescriptor($desc2, $cx, $desc);
    var $2 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $2);
    var $3 = __ZN2js15AutoCompartment5enterEv($call);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $5 = $call + 12 | 0;
    var $6 = HEAP32[$5 >> 2];
    var $7 = __ZN13JSCompartment6wrapIdEP9JSContextPi($6, $cx, $1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $17 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = HEAP32[$5 >> 2];
    var $10 = $desc2 + 16 | 0;
    var $phitmp = $10;
    var $11 = __ZN13JSCompartment4wrapEP9JSContextP20JSPropertyDescriptor($9, $cx, $phitmp);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $17 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = $this | 0;
    var $14 = HEAP32[$1 >> 2];
    var $15 = __ZN9JSWrapper14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor($13, $cx, $wrapper, $14, $10);
    var $17 = $15;
    __label__ = 5;
    break;
   case 5:
    var $17;
    __ZN2js15AutoCompartment5leaveEv($call);
    var $_0 = $17;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc2);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContextP20JSPropertyDescriptor($this, $cx, $desc) {
  __ZN2js28AutoPropertyDescriptorRooterC2EP9JSContextP20JSPropertyDescriptor($this, $cx, $desc);
  return;
}

function __ZN25JSCrossCompartmentWrapper19getOwnPropertyNamesEP9JSContextP8JSObjectRN2js12AutoIdVectorE($this, $cx, $wrapper, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $1);
    var $2 = __ZN2js15AutoCompartment5enterEv($call);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = $this | 0;
    var $5 = __ZN9JSWrapper19getOwnPropertyNamesEP9JSContextP8JSObjectRN2js12AutoIdVectorE($4, $cx, $wrapper, $props);
    __ZN2js15AutoCompartment5leaveEv($call);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = HEAP32[$call + 4 >> 2];
    var $9 = __ZN13JSCompartment4wrapEP9JSContextRN2js12AutoIdVectorE($8, $cx, $props);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper7delete_EP9JSContextP8JSObjectiPb($this, $cx, $wrapper, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $call = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $id;
    var $2 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $2);
    var $3 = __ZN2js15AutoCompartment5enterEv($call);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $6 = HEAP32[$call + 12 >> 2];
    var $7 = __ZN13JSCompartment6wrapIdEP9JSContextPi($6, $cx, $1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $13 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = $this | 0;
    var $10 = HEAP32[$1 >> 2];
    var $11 = __ZN9JSWrapper7delete_EP9JSContextP8JSObjectiPb($9, $cx, $wrapper, $10, $bp);
    var $13 = $11;
    __label__ = 4;
    break;
   case 4:
    var $13;
    __ZN2js15AutoCompartment5leaveEv($call);
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper9enumerateEP9JSContextP8JSObjectRN2js12AutoIdVectorE($this, $cx, $wrapper, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $1);
    var $2 = __ZN2js15AutoCompartment5enterEv($call);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = $this | 0;
    var $5 = __ZN9JSWrapper9enumerateEP9JSContextP8JSObjectRN2js12AutoIdVectorE($4, $cx, $wrapper, $props);
    __ZN2js15AutoCompartment5leaveEv($call);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = HEAP32[$call + 4 >> 2];
    var $9 = __ZN13JSCompartment4wrapEP9JSContextRN2js12AutoIdVectorE($8, $cx, $props);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper3hasEP9JSContextP8JSObjectiPb($this, $cx, $wrapper, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $call = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $id;
    var $2 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $2);
    var $3 = __ZN2js15AutoCompartment5enterEv($call);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $6 = HEAP32[$call + 12 >> 2];
    var $7 = __ZN13JSCompartment6wrapIdEP9JSContextPi($6, $cx, $1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $13 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = $this | 0;
    var $10 = HEAP32[$1 >> 2];
    var $11 = __ZN9JSWrapper3hasEP9JSContextP8JSObjectiPb($9, $cx, $wrapper, $10, $bp);
    var $13 = $11;
    __label__ = 4;
    break;
   case 4:
    var $13;
    __ZN2js15AutoCompartment5leaveEv($call);
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper6hasOwnEP9JSContextP8JSObjectiPb($this, $cx, $wrapper, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $call = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $id;
    var $2 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $2);
    var $3 = __ZN2js15AutoCompartment5enterEv($call);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $6 = HEAP32[$call + 12 >> 2];
    var $7 = __ZN13JSCompartment6wrapIdEP9JSContextPi($6, $cx, $1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $13 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = $this | 0;
    var $10 = HEAP32[$1 >> 2];
    var $11 = __ZN9JSWrapper6hasOwnEP9JSContextP8JSObjectiPb($9, $cx, $wrapper, $10, $bp);
    var $13 = $11;
    __label__ = 4;
    break;
   case 4:
    var $13;
    __ZN2js15AutoCompartment5leaveEv($call);
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper3getEP9JSContextP8JSObjectS3_iPN2JS5ValueE($this, $cx, $wrapper, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $call = __stackBase__ + 8;
    HEAP32[$1 >> 2] = $receiver;
    HEAP32[$2 >> 2] = $id;
    var $3 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $3);
    var $4 = __ZN2js15AutoCompartment5enterEv($call);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    var $6 = $call + 12 | 0;
    var $7 = HEAP32[$6 >> 2];
    var $8 = __ZN13JSCompartment4wrapEP9JSContextPP8JSObject($7, $cx, $1);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    var $10 = HEAP32[$6 >> 2];
    var $11 = __ZN13JSCompartment6wrapIdEP9JSContextPi($10, $cx, $2);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $13 = $this | 0;
    var $14 = HEAP32[$1 >> 2];
    var $15 = HEAP32[$2 >> 2];
    var $16 = __ZN9JSWrapper3getEP9JSContextP8JSObjectS3_iPN2JS5ValueE($13, $cx, $wrapper, $14, $15, $vp);
    __ZN2js15AutoCompartment5leaveEv($call);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $19 = HEAP32[$call + 4 >> 2];
    var $20 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($19, $cx, $vp);
    var $_0 = $20;
    __label__ = 8;
    break;
   case 6:
    __ZN2js15AutoCompartment5leaveEv($call);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 7:
    __ZN2js15AutoCompartment5leaveEv($call);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper3setEP9JSContextP8JSObjectS3_ibPN2JS5ValueE($this, $cx, $wrapper, $receiver, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 84;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $tvr = __stackBase__ + 8;
    var $call = __stackBase__ + 32;
    HEAP32[$1 >> 2] = $receiver;
    HEAP32[$2 >> 2] = $id;
    __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr, $cx, $vp);
    var $3 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $3);
    var $4 = __ZN2js15AutoCompartment5enterEv($call);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $6 = $call + 12 | 0;
    var $7 = HEAP32[$6 >> 2];
    var $8 = __ZN13JSCompartment4wrapEP9JSContextPP8JSObject($7, $cx, $1);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $21 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $10 = HEAP32[$6 >> 2];
    var $11 = __ZN13JSCompartment6wrapIdEP9JSContextPi($10, $cx, $2);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $21 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $13 = HEAP32[$6 >> 2];
    var $14 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $15 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($13, $cx, $14);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      var $21 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $17 = $this | 0;
    var $18 = HEAP32[$2 >> 2];
    var $19 = __ZN9JSWrapper3setEP9JSContextP8JSObjectS3_ibPN2JS5ValueE($17, $cx, $wrapper, undef, $18, undef, $14);
    var $21 = $19;
    __label__ = 6;
    break;
   case 6:
    var $21;
    __ZN2js15AutoCompartment5leaveEv($call);
    var $_0 = $21;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper4keysEP9JSContextP8JSObjectRN2js12AutoIdVectorE($this, $cx, $wrapper, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $1);
    var $2 = __ZN2js15AutoCompartment5enterEv($call);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = $this | 0;
    var $5 = __ZN9JSWrapper4keysEP9JSContextP8JSObjectRN2js12AutoIdVectorE($4, $cx, $wrapper, $props);
    __ZN2js15AutoCompartment5leaveEv($call);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = HEAP32[$call + 4 >> 2];
    var $9 = __ZN13JSCompartment4wrapEP9JSContextRN2js12AutoIdVectorE($8, $cx, $props);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper7iterateEP9JSContextP8JSObjectjPN2JS5ValueE($this, $cx, $wrapper, $flags, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $1);
    var $2 = __ZN2js15AutoCompartment5enterEv($call);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $4 = $this | 0;
    var $5 = __ZN9JSWrapper7iterateEP9JSContextP8JSObjectjPN2JS5ValueE($4, $cx, $wrapper, $flags, $vp);
    __ZN2js15AutoCompartment5leaveEv($call);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $7 = __ZL8CanReifyPN2JS5ValueE($vp_idx_val$0, $vp_idx_val$1);
    var $9 = HEAP32[$call + 4 >> 2];
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = __ZL5ReifyP9JSContextP13JSCompartmentPN2JS5ValueE($cx, $9, $vp);
    var $_0 = $11;
    __label__ = 6;
    break;
   case 5:
    var $13 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($9, $cx, $vp);
    var $_0 = $13;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8CanReifyPN2JS5ValueE($vp_0_0_0_val$0, $vp_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($vp_0_0_0_val$0, $vp_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $13 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($vp_0_0_0_val$0, $vp_0_0_0_val$1);
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($4 | 0) == (__ZN2js13IteratorClassE | 0)) {
      __label__ = 3;
      break;
    } else {
      var $13 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_idx2_val = HEAP32[$3 + 24 >> 2];
    var $7 = __ZNK8JSObject17getNativeIteratorEv($_idx2_val);
    var $13 = (HEAP32[$7 + 28 >> 2] & 1 | 0) != 0;
    __label__ = 4;
    break;
   case 4:
    var $13;
    return $13;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5ReifyP9JSContextP13JSCompartmentPN2JS5ValueE($cx, $origin, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $close = __stackBase__;
    var $obj = __stackBase__ + 8;
    var $keys = __stackBase__ + 12;
    var $vp_idx = $vp | 0;
    var $vp_idx_val$0 = HEAP32[$vp_idx >> 2];
    var $vp_idx_val$1 = HEAP32[$vp_idx + 4 >> 2];
    var $1 = __ZNK2JS5Value8toObjectEv($vp_idx_val$0, $vp_idx_val$1);
    var $_idx_val = HEAP32[$1 + 24 >> 2];
    var $2 = __ZNK8JSObject17getNativeIteratorEv($_idx_val);
    __ZN17AutoCloseIteratorC1EP9JSContextP8JSObject($close, $cx, $1);
    var $4 = HEAP32[$2 >> 2];
    HEAP32[$obj >> 2] = $4;
    var $5 = __ZN13JSCompartment4wrapEP9JSContextPP8JSObject($origin, $cx, $obj);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 13;
      break;
    }
   case 2:
    var $7 = __ZNK2js14NativeIterator7numKeysEv($2);
    var $_idx1 = $2 + 28 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $8 = __ZNK2js14NativeIterator9isKeyIterEv($_idx1_val);
    __ZN2js12AutoIdVectorC1EP9JSContext($keys, $cx);
    if (($7 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = $keys | 0;
    var $12 = __ZN2js16AutoVectorRooterIiE6resizeEj($11, $7);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 4:
    var $13 = $2 + 4 | 0;
    var $i_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_0;
    if ($i_0 >>> 0 < $7 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $_idx2_val = HEAP32[$13 >> 2];
    var $16 = __ZNK2js14NativeIterator5beginEv($_idx2_val);
    var $18 = HEAP32[$16 + ($i_0 << 2) >> 2];
    var $19 = __ZN2js16AutoVectorRooterIiEixEj($11, $i_0);
    HEAP32[$19 >> 2] = $18;
    var $20 = __ZN2js16AutoVectorRooterIiEixEj($11, $i_0);
    var $21 = __ZN13JSCompartment6wrapIdEP9JSContextPi($origin, $cx, $20);
    if ($21) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 5;
    break;
   case 8:
    __ZN17AutoCloseIterator5clearEv($close);
    var $24 = $cx;
    var $25 = $1;
    var $26 = __Z16js_CloseIteratorP9JSContextP8JSObject($24, $25);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $30 = HEAP32[$_idx1 >> 2];
    var $31 = HEAP32[$obj >> 2];
    var $32 = $keys;
    if ($8) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $34 = __ZN2js19VectorToKeyIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE($24, $31, $30, $32, $vp);
    var $_0 = $34;
    __label__ = 12;
    break;
   case 11:
    var $36 = __ZN2js21VectorToValueIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE($24, $31, $30, $32, $vp);
    var $_0 = $36;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    __ZN2js12AutoIdVectorD1Ev($keys);
    var $_1 = $_0;
    __label__ = 13;
    break;
   case 13:
    var $_1;
    __ZN17AutoCloseIteratorD1Ev($close);
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL5ReifyP9JSContextP13JSCompartmentPN2JS5ValueE["X"] = 1;

function __ZN25JSCrossCompartmentWrapper4callEP9JSContextP8JSObjectjPN2JS5ValueE($this, $cx, $wrapper, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $1 = __stackBase__ + 52;
    var $2 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $2);
    var $3 = __ZN2js15AutoCompartment5enterEv($call);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    var $6 = HEAP32[$call + 8 >> 2];
    __ZN2JSL11ObjectValueER8JSObject4137($1, $6);
    var $7 = $1 | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $vp | 0;
    HEAP32[$9 >> 2] = $8$0;
    HEAP32[$9 + 4 >> 2] = $8$1;
    var $10 = $call + 12 | 0;
    var $11 = HEAP32[$10 >> 2];
    var $12 = $vp + 8 | 0;
    var $13 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($11, $cx, $12);
    if ($13) {
      var $n_0 = 0;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $n_0;
    if ($n_0 >>> 0 < $argc >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $16 = HEAP32[$10 >> 2];
    var $17 = $vp + ($n_0 + 2 << 3) | 0;
    var $18 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($16, $cx, $17);
    if ($18) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $n_0 = $n_0 + 1 | 0;
    __label__ = 3;
    break;
   case 6:
    var $22 = $this | 0;
    var $23 = __ZN9JSWrapper4callEP9JSContextP8JSObjectjPN2JS5ValueE($22, $cx, $wrapper, $argc, $vp);
    if ($23) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2js15AutoCompartment5leaveEv($call);
    var $26 = HEAP32[$call + 4 >> 2];
    var $27 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($26, $cx, $vp);
    var $_0 = $27;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper9constructEP9JSContextP8JSObjectjPN2JS5ValueES6_($this, $cx, $wrapper, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $1);
    var $2 = __ZN2js15AutoCompartment5enterEv($call);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    var $3 = $call + 12 | 0;
    var $n_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $n_0;
    if ($n_0 >>> 0 < $argc >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $7 = HEAP32[$3 >> 2];
    var $8 = $argv + ($n_0 << 3) | 0;
    var $9 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($7, $cx, $8);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $n_0 = $n_0 + 1 | 0;
    __label__ = 3;
    break;
   case 6:
    var $13 = $this | 0;
    var $14 = __ZN9JSWrapper9constructEP9JSContextP8JSObjectjPN2JS5ValueES6_($13, $cx, $wrapper, $argc, $argv, $rval);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2js15AutoCompartment5leaveEv($call);
    var $17 = HEAP32[$call + 4 >> 2];
    var $18 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($17, $cx, $rval);
    var $_0 = $18;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb($this, $cx, $wrapper, $vp, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $v = __stackBase__ + 52;
    var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $1);
    var $2 = __ZN2js15AutoCompartment5enterEv($call);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = $vp | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = $v | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    var $8 = HEAP32[$call + 12 >> 2];
    var $9 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($8, $cx, $v);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = $this | 0;
    var $12 = __ZN9JSWrapper11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb($11, $cx, $wrapper, $v, $bp);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper12obj_toStringEP9JSContextP8JSObject($this, $cx, $wrapper) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $str = __stackBase__ + 52;
    var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $1);
    var $2 = __ZN2js15AutoCompartment5enterEv($call);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = $this | 0;
    var $5 = __ZN9JSWrapper12obj_toStringEP9JSContextP8JSObject($4, $cx, $wrapper);
    HEAP32[$str >> 2] = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js15AutoCompartment5leaveEv($call);
    var $9 = HEAP32[$call + 4 >> 2];
    var $10 = __ZN13JSCompartment4wrapEP9JSContextPP8JSString($9, $cx, $str);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = HEAP32[$str >> 2];
    __label__ = 5;
    break;
   case 5:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper12fun_toStringEP9JSContextP8JSObjectj($this, $cx, $wrapper, $indent) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $str = __stackBase__ + 52;
    var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $1);
    var $2 = __ZN2js15AutoCompartment5enterEv($call);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = $this | 0;
    var $5 = __ZN9JSWrapper12fun_toStringEP9JSContextP8JSObjectj($4, $cx, $wrapper, $indent);
    HEAP32[$str >> 2] = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js15AutoCompartment5leaveEv($call);
    var $9 = HEAP32[$call + 4 >> 2];
    var $10 = __ZN13JSCompartment4wrapEP9JSContextPP8JSString($9, $cx, $str);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = HEAP32[$str >> 2];
    __label__ = 5;
    break;
   case 5:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE($this, $cx, $wrapper, $hint, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $1);
    var $2 = __ZN2js15AutoCompartment5enterEv($call);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZN9JSWrapper12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE(undef, $cx, $wrapper, $hint, $vp);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js15AutoCompartment5leaveEv($call);
    var $7 = HEAP32[$call + 4 >> 2];
    var $8 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($7, $cx, $vp);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper5traceEP8JSTracerP8JSObject($this, $trc, $wrapper) {
  var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
  __ZN2js2gc26MarkCrossCompartmentObjectEP8JSTracerR8JSObjectPKc($trc, $1);
  return;
}

function __ZN2js15DummyFrameGuardD1Ev($this) {
  __ZN2js15DummyFrameGuardD2Ev($this);
  return;
}

function __ZN2js15DummyFrameGuardD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js10FrameGuardD2Ev($1);
  return;
}

function __ZN7mozilla5MaybeIN2js15DummyFrameGuardEE3asTEv($this) {
  var $1 = $this | 0;
  var $2 = __ZN7mozilla15AlignedStorage2IN2js15DummyFrameGuardEE4addrEv($1);
  return $2;
}

function __ZN2js15DummyFrameGuardC1Ev($this) {
  __ZN2js15DummyFrameGuardC2Ev($this);
  return;
}

function __ZN2js15DummyFrameGuardC2Ev($this) {
  var $1 = $this | 0;
  __ZN2js10FrameGuardC2Ev($1);
  return;
}

function __ZN7mozilla5MaybeIN2js15DummyFrameGuardEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 28 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN7mozilla5MaybeIN2js15DummyFrameGuardEE3asTEv($this);
    __ZN2js15DummyFrameGuardD1Ev($6);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN17AutoCloseIteratorC1EP9JSContextP8JSObject($this, $cx, $obj) {
  __ZN17AutoCloseIteratorC2EP9JSContextP8JSObject($this, $cx, $obj);
  return;
}

function __ZN17AutoCloseIterator5clearEv($this) {
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN17AutoCloseIteratorC2EP9JSContextP8JSObject($this, $cx, $obj) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $obj;
  return;
}

function _JS_XDRInitBase($xdr, $mode, $cx) {
  HEAP32[$xdr >> 2] = $mode;
  HEAP32[$xdr + 8 >> 2] = $cx;
  HEAP32[$xdr + 12 >> 2] = 0;
  HEAP32[$xdr + 20 >> 2] = 0;
  HEAP32[$xdr + 16 >> 2] = 0;
  HEAP32[$xdr + 24 >> 2] = 0;
  HEAP32[$xdr + 28 >> 2] = 0;
  HEAP32[$xdr + 32 >> 2] = 0;
  HEAP32[$xdr + 36 >> 2] = 0;
  return;
}

function _JS_XDRMemGetData($xdr, $lp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$xdr + 4 >> 2] | 0) == (__ZL10xdrmem_ops | 0)) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = HEAP32[$xdr + 44 >> 2];
    HEAP32[$lp >> 2] = $7;
    var $_0 = HEAP32[$xdr + 40 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_XDRMemSetData($xdr, $data, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$xdr + 4 >> 2] | 0) == (__ZL10xdrmem_ops | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$xdr + 48 >> 2] = $len;
    HEAP32[$xdr + 40 >> 2] = $data;
    HEAP32[$xdr + 44 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14XDRScriptStateC2EP10JSXDRState($this, $x) {
  HEAP32[$this >> 2] = $x;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP8[$this + 8 | 0] = 0;
  HEAP32[$x + 36 >> 2] = $this;
  return;
}

function __ZNK2js14NativeIterator7numKeysEv($this) {
  var $_idx_val = HEAP32[$this + 12 >> 2];
  var $2 = __ZNK2js14NativeIterator3endEv($_idx_val);
  var $_idx1_val = HEAP32[$this + 4 >> 2];
  var $4 = __ZNK2js14NativeIterator5beginEv($_idx1_val);
  return $2 - $4 >> 2;
}

function __ZN17AutoCloseIteratorD1Ev($this) {
  __ZN17AutoCloseIteratorD2Ev($this);
  return;
}

function __ZN17AutoCloseIteratorD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this >> 2];
    var $8 = $2;
    var $9 = __Z16js_CloseIteratorP9JSContextP8JSObject($7, $8);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js28AutoPropertyDescriptorRooterC2EP9JSContextP20JSPropertyDescriptor($this, $cx, $desc) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($1, $cx, -13);
  var $3 = HEAP32[$desc >> 2];
  HEAP32[$this + 16 >> 2] = $3;
  var $6 = HEAP32[$desc + 4 >> 2];
  HEAP32[$this + 20 >> 2] = $6;
  var $9 = HEAP32[$desc + 8 >> 2];
  HEAP32[$this + 24 >> 2] = $9;
  var $12 = HEAP32[$desc + 12 >> 2];
  HEAP32[$this + 28 >> 2] = $12;
  var $14 = $desc + 16 | 0;
  var $15$0 = HEAP32[$14 >> 2];
  var $15$1 = HEAP32[$14 + 4 >> 2];
  var $16 = $this + 32 | 0;
  HEAP32[$16 >> 2] = $15$0;
  HEAP32[$16 + 4 >> 2] = $15$1;
  return;
}

function _JS_XDRNewMem($cx, $mode) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __ZN9JSContext7malloc_Ej($1, 52);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_XDRInitBase($3, $mode, $cx);
    if (($mode | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $8 = __ZN9JSContext7malloc_Ej($1, 8192);
    HEAP32[$2 + 40 >> 2] = $8;
    if (($8 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    __ZN9JSContext5free_EPv($2);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 5:
    HEAP32[$2 + 40 >> 2] = 0;
    __label__ = 6;
    break;
   case 6:
    HEAP32[$2 + 4 >> 2] = __ZL10xdrmem_ops;
    HEAP32[$2 + 44 >> 2] = 0;
    HEAP32[$2 + 48 >> 2] = 8192;
    var $_0 = $3;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_XDRDestroy($xdr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAP32[HEAP32[$xdr + 4 >> 2] + 28 >> 2];
    FUNCTION_TABLE[$4]($xdr);
    var $6 = HEAP32[$xdr + 12 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    __ZN9JSContext5free_EPv($9);
    var $11 = HEAP32[$xdr + 24 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = $11;
    _JS_DHashTableDestroy($14);
    __label__ = 4;
    break;
   case 4:
    var $16 = $xdr;
    __ZN9JSContext5free_EPv($16);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_XDRUint32($xdr, $lp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $xl = __stackBase__;
    var $2 = HEAP32[$xdr >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      var $ok_0 = 1;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = HEAP32[$lp >> 2];
    HEAP32[$xl >> 2] = $4;
    var $8 = HEAP32[HEAP32[$xdr + 4 >> 2] + 4 >> 2];
    var $9 = FUNCTION_TABLE[$8]($xdr, $xl);
    var $ok_0 = $9;
    __label__ = 4;
    break;
   case 3:
    var $14 = HEAP32[HEAP32[$xdr + 4 >> 2] >> 2];
    var $15 = FUNCTION_TABLE[$14]($xdr, $lp);
    var $ok_0 = $15;
    __label__ = 4;
    break;
   case 4:
    var $ok_0;
    STACKTOP = __stackBase__;
    return $ok_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_XDRBytes($xdr, $bytes, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $xdr | 0;
    var $4 = $xdr + 4 | 0;
    var $5 = HEAP32[$4 >> 2];
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = HEAP32[$5 + 12 >> 2];
    var $9 = FUNCTION_TABLE[$8]($xdr, $bytes, $len);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $13 = HEAP32[$5 + 8 >> 2];
    var $14 = FUNCTION_TABLE[$13]($xdr, $bytes, $len);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = HEAP32[HEAP32[$4 >> 2] + 24 >> 2];
    var $20 = FUNCTION_TABLE[$19]($xdr);
    var $21 = $20 & 3;
    if (($21 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = 4 - $21 | 0;
    var $27 = HEAP32[$4 >> 2];
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $30 = HEAP32[$27 + 12 >> 2];
    var $31 = FUNCTION_TABLE[$30]($xdr, __ZZ11JS_XDRBytesE6padbuf | 0, $24);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $35 = HEAP32[$27 + 20 >> 2];
    var $36 = FUNCTION_TABLE[$35]($xdr, $24, 1);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_XDRString($xdr, $strp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nchars = __stackBase__;
    var $1 = $xdr | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[HEAP32[$strp >> 2] >> 2];
    var $6 = __ZNK8JSString6lengthEv($_idx_val);
    HEAP32[$nchars >> 2] = $6;
    __label__ = 3;
    break;
   case 3:
    var $8 = _JS_XDRUint32($xdr, $nchars);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP32[$1 >> 2] | 0) == 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $18 = (HEAP32[$nchars >> 2] << 1) + 2 | 0;
    var $19 = HEAP32[$xdr + 8 >> 2];
    var $20 = __ZN9JSContext7malloc_Ej($19, $18);
    var $chars_0 = $20;
    __label__ = 7;
    break;
   case 6:
    var $23 = HEAP32[$strp >> 2];
    var $26 = HEAP32[$xdr + 8 >> 2];
    var $27 = __ZN8JSString8getCharsEP9JSContext($23, $26);
    var $chars_0 = $27;
    __label__ = 7;
    break;
   case 7:
    var $chars_0;
    if (($chars_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAP32[$nchars >> 2];
    var $32 = __ZL8XDRCharsP10JSXDRStatePtj($xdr, $chars_0, $31);
    if (($32 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ((HEAP32[$1 >> 2] | 0) == 1) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 13;
      break;
    }
   case 10:
    HEAP16[$chars_0 + (HEAP32[$nchars >> 2] << 1) >> 1] = 0;
    var $42 = HEAP32[$nchars >> 2];
    var $43 = HEAP32[$xdr + 8 >> 2];
    var $44 = _JS_NewUCString($43, $chars_0, $42);
    HEAP32[$strp >> 2] = $44;
    if (($44 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 13;
      break;
    }
   case 11:
    if ((HEAP32[$1 >> 2] | 0) == 1) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 12:
    __ZN9JSContext5free_EPv($chars_0);
    var $_0 = 0;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_XDRString["X"] = 1;

function __ZL8XDRCharsP10JSXDRStatePtj($xdr, $chars, $nchars) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $nchars << 1;
    var $2 = $1 & 2;
    if (($2 | 0) == 0) {
      var $nbytes_0 = $1;
      var $padlen_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = 4 - $2 | 0;
    var $nbytes_0 = $5 + $1 | 0;
    var $padlen_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $padlen_0;
    var $nbytes_0;
    var $11 = HEAP32[HEAP32[$xdr + 4 >> 2] + 16 >> 2];
    var $12 = FUNCTION_TABLE[$11]($xdr, $nbytes_0);
    var $13 = $12;
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = HEAP32[$xdr >> 2];
    if (($17 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($17 | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 5:
    if (($nchars | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $i_03 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    if (($nchars | 0) == 0) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      var $i_11 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    var $i_03;
    var $21 = HEAP16[$chars + ($i_03 << 1) >> 1];
    HEAP16[$13 + ($i_03 << 1) >> 1] = $21;
    var $23 = $i_03 + 1 | 0;
    if (($23 | 0) == ($nchars | 0)) {
      __label__ = 8;
      break;
    } else {
      var $i_03 = $23;
      __label__ = 7;
      break;
    }
   case 8:
    if (($padlen_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $27 = $12 + ($nbytes_0 - $padlen_0) | 0;
    _memset($27, 0, $padlen_0, 1);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 10:
    var $i_11;
    var $29 = HEAP16[$13 + ($i_11 << 1) >> 1];
    HEAP16[$chars + ($i_11 << 1) >> 1] = $29;
    var $31 = $i_11 + 1 | 0;
    if (($31 | 0) == ($nchars | 0)) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      var $i_11 = $31;
      __label__ = 10;
      break;
    }
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_XDRDouble($xdr, $dp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = $xdr | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = (tempDoubleI32[0] = HEAP32[$dp >> 2], tempDoubleI32[1] = HEAP32[$dp + 4 >> 2], tempDoubleF64[0]);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    tempDoubleF64[0] = $7, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $8 = __ZL14XDRDoubleValueP10JSXDRStatePd($xdr, $d);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP32[$1 >> 2] | 0) == 1) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 5:
    var $14 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $14, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14XDRDoubleValueP10JSXDRStatePd($xdr, $dp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $u = __stackBase__;
    var $1 = $xdr | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = (tempDoubleI32[0] = HEAP32[$dp >> 2], tempDoubleI32[1] = HEAP32[$dp + 4 >> 2], tempDoubleF64[0]);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    var $8 = $u;
    tempDoubleF64[0] = $7, HEAP32[$8 >> 2] = tempDoubleI32[0], HEAP32[$8 + 4 >> 2] = tempDoubleI32[1];
    var $9 = $u | 0;
    var $10 = _JS_XDRUint32($xdr, $9);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $u + 4 | 0;
    var $14 = _JS_XDRUint32($xdr, $13);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$1 >> 2] | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 6:
    var $20 = (tempDoubleI32[0] = HEAP32[$8 >> 2], tempDoubleI32[1] = HEAP32[$8 + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $20, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_XDRValue($xdr, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $type = __stackBase__;
    if ((HEAP32[$xdr >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $vp | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = __ZL9GetXDRTagN2JS5ValueE($6$0, $6$1);
    HEAP32[$type >> 2] = $7;
    __label__ = 3;
    break;
   case 3:
    var $9 = _JS_XDRUint32($xdr, $type);
    if (($9 | 0) == 0) {
      var $16 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = HEAP32[$type >> 2];
    var $13 = __ZL12XDRValueBodyP10JSXDRStatejPN2JS5ValueE($xdr, $12, $vp);
    var $16 = ($13 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $16;
    STACKTOP = __stackBase__;
    return $16 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9GetXDRTagN2JS5ValueE($_0_0_0_val$0, $_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSVAL_IS_NULL($_0_0_0_val$0, $_0_0_0_val$1);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 5;
      __label__ = 7;
      break;
    }
   case 2:
    var $4 = _JSVAL_IS_VOID($_0_0_0_val$0, $_0_0_0_val$1);
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 6;
      __label__ = 7;
      break;
    }
   case 3:
    var $7 = _JSVAL_IS_OBJECT($_0_0_0_val$0, $_0_0_0_val$1);
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 4:
    var $10 = _JSVAL_IS_INT($_0_0_0_val$0, $_0_0_0_val$1);
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 5:
    var $13 = _JSVAL_IS_DOUBLE4214($_0_0_0_val$0, $_0_0_0_val$1);
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 2;
      __label__ = 7;
      break;
    }
   case 6:
    var $16 = _JSVAL_IS_STRING4215($_0_0_0_val$0, $_0_0_0_val$1);
    var $_ = ($16 | 0) == 0 ? 4 : 3;
    var $_0 = $_;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12XDRValueBodyP10JSXDRStatejPN2JS5ValueE($xdr, $type, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $d = __stackBase__ + 12;
    var $2 = __stackBase__ + 20;
    var $obj = __stackBase__ + 28;
    var $3 = __stackBase__ + 32;
    var $b = __stackBase__ + 40;
    var $4 = __stackBase__ + 44;
    var $i = __stackBase__ + 52;
    var $5 = __stackBase__ + 56;
    if (($type | 0) == 5) {
      __label__ = 2;
      break;
    } else if (($type | 0) == 6) {
      __label__ = 3;
      break;
    } else if (($type | 0) == 3) {
      __label__ = 4;
      break;
    } else if (($type | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($type | 0) == 0) {
      __label__ = 14;
      break;
    } else if (($type | 0) == 4) {
      __label__ = 19;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 2:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $7$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $7$1 = HEAP32[$st$1$1 >> 2];
    var $8 = $vp | 0;
    var $st$6$0 = $8 | 0;
    HEAP32[$st$6$0 >> 2] = $7$0;
    var $st$6$1 = $8 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $7$1;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 3:
    var $$emscripten$temp$1 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$1 | 0;
    var $10$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$1 + 4 | 0;
    var $10$1 = HEAP32[$st$1$1 >> 2];
    var $11 = $vp | 0;
    var $st$6$0 = $11 | 0;
    HEAP32[$st$6$0 >> 2] = $10$0;
    var $st$6$1 = $11 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $10$1;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 4:
    var $13 = $xdr | 0;
    if ((HEAP32[$13 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $17 = $vp | 0;
    var $st$1$0 = $17 | 0;
    var $18$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $17 + 4 | 0;
    var $18$1 = HEAP32[$st$1$1 >> 2];
    var $19 = _JSVAL_TO_STRING4194($18$0, $18$1);
    HEAP32[$str >> 2] = $19;
    __label__ = 6;
    break;
   case 6:
    var $21 = _JS_XDRString($xdr, $str);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ((HEAP32[$13 >> 2] | 0) == 1) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 29;
      break;
    }
   case 8:
    var $27 = HEAP32[$str >> 2];
    _STRING_TO_JSVAL4195($1, $27);
    var $28 = $1 | 0;
    var $st$3$0 = $28 | 0;
    var $29$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $28 + 4 | 0;
    var $29$1 = HEAP32[$st$3$1 >> 2];
    var $30 = $vp | 0;
    var $st$8$0 = $30 | 0;
    HEAP32[$st$8$0 >> 2] = $29$0;
    var $st$8$1 = $30 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $29$1;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 9:
    var $32 = $xdr | 0;
    if ((HEAP32[$32 >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $40 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $36 = $vp | 0;
    var $st$1$0 = $36 | 0;
    var $37$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $36 + 4 | 0;
    var $37$1 = HEAP32[$st$1$1 >> 2];
    var $38 = _JSVAL_TO_DOUBLE4196($37$0, $37$1);
    var $40 = $38;
    __label__ = 11;
    break;
   case 11:
    var $40;
    tempDoubleF64[0] = $40, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $41 = _JS_XDRDouble($xdr, $d);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[$32 >> 2] | 0) == 1) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 1;
      __label__ = 29;
      break;
    }
   case 13:
    var $47 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    _DOUBLE_TO_JSVAL4197($2, $47);
    var $48 = $2 | 0;
    var $st$3$0 = $48 | 0;
    var $49$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $48 + 4 | 0;
    var $49$1 = HEAP32[$st$3$1 >> 2];
    var $50 = $vp | 0;
    var $st$8$0 = $50 | 0;
    HEAP32[$st$8$0 >> 2] = $49$0;
    var $st$8$1 = $50 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $49$1;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 14:
    var $52 = $xdr | 0;
    if ((HEAP32[$52 >> 2] | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $56 = $vp | 0;
    var $st$1$0 = $56 | 0;
    var $57$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $56 + 4 | 0;
    var $57$1 = HEAP32[$st$1$1 >> 2];
    var $58 = _JSVAL_TO_OBJECT4198($57$0, $57$1);
    HEAP32[$obj >> 2] = $58;
    __label__ = 16;
    break;
   case 16:
    var $60 = $xdr;
    var $61 = $obj;
    var $62 = __Z12js_XDRObjectP10JSXDRStatePP8JSObject($60, $61);
    if (($62 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    if ((HEAP32[$52 >> 2] | 0) == 1) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 1;
      __label__ = 29;
      break;
    }
   case 18:
    var $68 = HEAP32[$obj >> 2];
    _OBJECT_TO_JSVAL4199($3, $68);
    var $69 = $3 | 0;
    var $st$3$0 = $69 | 0;
    var $70$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $69 + 4 | 0;
    var $70$1 = HEAP32[$st$3$1 >> 2];
    var $71 = $vp | 0;
    var $st$8$0 = $71 | 0;
    HEAP32[$st$8$0 >> 2] = $70$0;
    var $st$8$1 = $71 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $70$1;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 19:
    var $73 = $xdr | 0;
    if ((HEAP32[$73 >> 2] | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $77 = $vp | 0;
    var $st$1$0 = $77 | 0;
    var $78$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $77 + 4 | 0;
    var $78$1 = HEAP32[$st$1$1 >> 2];
    var $79 = _JSVAL_TO_BOOLEAN4200($78$0, $78$1);
    HEAP32[$b >> 2] = $79;
    __label__ = 21;
    break;
   case 21:
    var $81 = _JS_XDRUint32($xdr, $b);
    if (($81 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    if ((HEAP32[$73 >> 2] | 0) == 1) {
      __label__ = 23;
      break;
    } else {
      var $_0 = 1;
      __label__ = 29;
      break;
    }
   case 23:
    var $89 = (HEAP32[$b >> 2] | 0) != 0 & 1;
    _BOOLEAN_TO_JSVAL4201($4, $89);
    var $90 = $4 | 0;
    var $91$0 = HEAP32[$90 >> 2];
    var $91$1 = HEAP32[$90 + 4 >> 2];
    var $92 = $vp | 0;
    HEAP32[$92 >> 2] = $91$0;
    HEAP32[$92 + 4 >> 2] = $91$1;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 24:
    var $94 = $xdr | 0;
    if ((HEAP32[$94 >> 2] | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    var $98 = $vp | 0;
    var $st$1$0 = $98 | 0;
    var $99$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $98 + 4 | 0;
    var $99$1 = HEAP32[$st$1$1 >> 2];
    var $100 = _JSVAL_TO_INT4202($99$0, $99$1);
    HEAP32[$i >> 2] = $100;
    __label__ = 26;
    break;
   case 26:
    var $102 = _JS_XDRUint32($xdr, $i);
    if (($102 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    if ((HEAP32[$94 >> 2] | 0) == 1) {
      __label__ = 28;
      break;
    } else {
      var $_0 = 1;
      __label__ = 29;
      break;
    }
   case 28:
    var $108 = HEAP32[$i >> 2];
    _INT_TO_JSVAL4203($5, $108);
    var $109 = $5 | 0;
    var $st$3$0 = $109 | 0;
    var $110$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $109 + 4 | 0;
    var $110$1 = HEAP32[$st$3$1 >> 2];
    var $111 = $vp | 0;
    var $st$8$0 = $111 | 0;
    HEAP32[$st$8$0 >> 2] = $110$0;
    var $st$8$1 = $111 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $110$1;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 29:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12XDRValueBodyP10JSXDRStatejPN2JS5ValueE["X"] = 1;

function _js_XDRAtom($xdr, $atomp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 520;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str = __stackBase__;
    var $nchars = __stackBase__ + 4;
    var $stackChars = __stackBase__ + 8;
    if ((HEAP32[$xdr >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = HEAP32[$atomp >> 2] | 0;
    HEAP32[$str >> 2] = $6;
    var $7 = _JS_XDRString($xdr, $str);
    var $_0 = $7;
    __label__ = 14;
    break;
   case 3:
    var $9 = _JS_XDRUint32($xdr, $nchars);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = HEAP32[$xdr + 8 >> 2];
    var $14 = HEAPU32[$nchars >> 2];
    if ($14 >>> 0 < 257) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $chars_0 = $stackChars | 0;
    var $25 = $14;
    __label__ = 8;
    break;
   case 6:
    var $19 = $14 << 1;
    var $20 = $13;
    var $21 = __ZN9JSContext7malloc_Ej($20, $19);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $chars_0 = $21;
    var $25 = HEAP32[$nchars >> 2];
    __label__ = 8;
    break;
   case 8:
    var $25;
    var $chars_0;
    var $26 = __ZL8XDRCharsP10JSXDRStatePtj($xdr, $chars_0, $25);
    if (($26 | 0) == 0) {
      var $atom_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $29 = HEAP32[$nchars >> 2];
    var $30 = $13;
    var $31 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($30, $chars_0, $29, 0);
    var $atom_0 = $31;
    __label__ = 10;
    break;
   case 10:
    var $atom_0;
    if (($chars_0 | 0) == ($stackChars | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN9JSContext5free_EPv($chars_0);
    __label__ = 12;
    break;
   case 12:
    if (($atom_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    HEAP32[$atomp >> 2] = $atom_0;
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_XDRAtom["X"] = 1;

function __ZN2js14XDRScriptStateD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $3 = HEAP32[$1 >> 2] + 36 | 0;
    HEAP32[$3 >> 2] = 0;
    if ((HEAP32[HEAP32[$1 >> 2] >> 2] | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $10 = HEAP32[$this + 4 >> 2];
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP8[$this + 8 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN9JSContext5free_EPv($10);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_XDRRegisterClass($xdr, $clasp, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $xdr + 16 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $xdr + 20 | 0;
    var $4 = HEAP32[$3 >> 2];
    if (($2 | 0) == ($4 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $_ = ($4 | 0) == 0 ? 8 : $4 << 1;
    var $11 = $xdr + 12 | 0;
    var $13 = HEAP32[$11 >> 2];
    var $14 = $_ << 2;
    var $15 = HEAP32[$xdr + 8 >> 2];
    var $16 = __ZN9JSContext8realloc_EPvj($15, $13, $14);
    var $17 = $16;
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$11 >> 2] = $17;
    HEAP32[$3 >> 2] = $_;
    var $registry_0 = $17;
    __label__ = 5;
    break;
   case 4:
    var $registry_0 = HEAP32[$xdr + 12 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $registry_0;
    var $24 = $registry_0 + ($2 << 2) | 0;
    HEAP32[$24 >> 2] = $clasp;
    var $26 = HEAP32[$xdr + 24 >> 2];
    if (($26 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $29 = $clasp | 0;
    var $30 = HEAP32[$29 >> 2];
    var $31 = $26;
    var $32 = _JS_DHashTableOperate($31, $30, 1);
    if (($32 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $37 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportOutOfMemory($37);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 8:
    var $40 = $32 + 4 | 0;
    var $_c = HEAP32[$29 >> 2];
    HEAP32[$40 >> 2] = $_c;
    var $41 = $32 + 8 | 0;
    HEAP32[$41 >> 2] = $2;
    __label__ = 9;
    break;
   case 9:
    var $43 = $2 + 1 | 0;
    HEAP32[$idp >> 2] = $43;
    HEAP32[$1 >> 2] = $43;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_XDRRegisterClass["X"] = 1;

function _JSVAL_TO_INT32_IMPL4206($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_TO_BOOLEAN_IMPL4209($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_TO_OBJECT_IMPL4211($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_TO_STRING_IMPL4213($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_IS_STRING_IMPL4216($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -123) & 1;
}

function _JSVAL_IS_DOUBLE_IMPL4217($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 < 4294967169 & 1;
}

function _JSVAL_IS_INT32_IMPL4218($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -127) & 1;
}

function _JSVAL_IS_OBJECT_OR_NULL_IMPL4219($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 > 4294967173 & 1;
}

function _JSVAL_IS_UNDEFINED_IMPL4220($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -126) & 1;
}

function _JSVAL_IS_NULL_IMPL4221($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -122) & 1;
}

function _JS_XDRFindClassById($xdr, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $id - 1 | 0;
    if ($1 >>> 0 < HEAPU32[$xdr + 16 >> 2] >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = HEAP32[HEAP32[$xdr + 12 >> 2] + ($1 << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13IMPL_TO_JSVAL12jsval_layout4204($agg_result, $l_0$0, $l_0$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $l_0$0;
  HEAP32[$1 + 4 >> 2] = $l_0$1;
  return;
}

function _INT32_TO_JSVAL_IMPL4205($agg_result, $i) {
  HEAP32[$agg_result + 4 >> 2] = -127;
  HEAP32[$agg_result >> 2] = $i;
  return;
}

function __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($agg_result, $_0_0_0_val$0, $_0_0_0_val$1) {
  var $agg_result_0 = $agg_result | 0;
  HEAP32[$agg_result_0 >> 2] = $_0_0_0_val$0;
  HEAP32[$agg_result_0 + 4 >> 2] = $_0_0_0_val$1;
  return;
}

function _BOOLEAN_TO_JSVAL_IMPL4208($agg_result, $b) {
  HEAP32[$agg_result + 4 >> 2] = -125;
  HEAP32[$agg_result >> 2] = $b;
  return;
}

function _OBJECT_TO_JSVAL_IMPL4210($agg_result, $obj) {
  HEAP32[$agg_result + 4 >> 2] = -121;
  HEAP32[$agg_result >> 2] = $obj;
  return;
}

function _STRING_TO_JSVAL_IMPL4212($agg_result, $str) {
  HEAP32[$agg_result + 4 >> 2] = -123;
  HEAP32[$agg_result >> 2] = $str;
  return;
}

function __ZL8mem_tellP10JSXDRState($xdr) {
  return HEAP32[$xdr + 44 >> 2];
}

function _JS_XDRFindClassIdByName($xdr, $name) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$xdr + 16 >> 2];
    if ($2 >>> 0 > 9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $xdr + 12 | 0;
    var $i_1 = 0;
    __label__ = 10;
    break;
   case 3:
    var $6 = $xdr + 24 | 0;
    var $7 = HEAPU32[$6 >> 2];
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $37 = $7;
      __label__ = 8;
      break;
    }
   case 4:
    var $11 = ($2 >>> 0) / .75;
    var $12 = $11 >= 0 ? Math.floor($11) : Math.ceil($11);
    var $17 = (($12 * 192 | 0) >>> 8 >>> 0 < $2 >>> 0 & 1) + $12 | 0;
    var $18 = _JS_NewDHashTable($17);
    var $19 = $18;
    HEAP32[$6 >> 2] = $19;
    if (($18 | 0) == 0 | ($2 | 0) == 0) {
      var $35 = $19;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $22 = $xdr + 12 | 0;
    var $i_01 = 0;
    var $23 = $19;
    __label__ = 6;
    break;
   case 6:
    var $23;
    var $i_01;
    var $27 = HEAP32[HEAP32[$22 >> 2] + ($i_01 << 2) >> 2] | 0;
    var $28 = HEAP32[$27 >> 2];
    var $30 = _JS_DHashTableOperate($23, $28, 1);
    var $32 = $30 + 4 | 0;
    var $_c = HEAP32[$27 >> 2];
    HEAP32[$32 >> 2] = $_c;
    var $33 = $30 + 8 | 0;
    HEAP32[$33 >> 2] = $i_01;
    var $34 = $i_01 + 1 | 0;
    var $_pr_pre = HEAPU32[$6 >> 2];
    if (($34 | 0) == ($2 | 0)) {
      var $35 = $_pr_pre;
      __label__ = 7;
      break;
    } else {
      var $i_01 = $34;
      var $23 = $_pr_pre;
      __label__ = 6;
      break;
    }
   case 7:
    var $35;
    if (($35 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $37 = $35;
      __label__ = 8;
      break;
    }
   case 8:
    var $37;
    var $39 = _JS_DHashTableOperate($37, $name, 0);
    if ((HEAP32[$39 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_0 = HEAP32[$39 + 8 >> 2] + 1 | 0;
    __label__ = 12;
    break;
   case 10:
    var $i_1;
    if ($i_1 >>> 0 < $2 >>> 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 11:
    var $54 = HEAP32[HEAP32[HEAP32[$4 >> 2] + ($i_1 << 2) >> 2] >> 2];
    var $55 = _strcmp($name, $54);
    var $57 = $i_1 + 1 | 0;
    if (($55 | 0) == 0) {
      var $_0 = $57;
      __label__ = 12;
      break;
    } else {
      var $i_1 = $57;
      __label__ = 10;
      break;
    }
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_XDRFindClassIdByName["X"] = 1;

function _JSVAL_TO_STRING4194($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_STRING_IMPL4213($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _STRING_TO_JSVAL4195($agg_result, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _STRING_TO_JSVAL_IMPL4212($1, $str);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout4204($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function _JSVAL_TO_DOUBLE4196($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $tmp$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = (tempDoubleI32[0] = HEAP32[$_0 >> 2], tempDoubleI32[1] = $tmp$1, tempDoubleF64[0]);
  STACKTOP = __stackBase__;
  return $2;
}

function _DOUBLE_TO_JSVAL4197($agg_result, $d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = isNaN($d) || isNaN(0);
    if ($1) {
      var $l_0_0$1 = 2146959360;
      var $l_0_0$0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $l_0_0$1 = tempDoubleI32[1];
    var $l_0_0$0 = tempDoubleI32[0];
    __label__ = 3;
    break;
   case 3:
    var $l_0_0$0;
    var $l_0_0$1;
    __ZL13IMPL_TO_JSVAL12jsval_layout4204($agg_result, $l_0_0$0, $l_0_0$1);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSVAL_TO_OBJECT4198($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_OBJECT_IMPL4211($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _OBJECT_TO_JSVAL4199($agg_result, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL_IMPL4210($1, $obj);
    var $_0 = $1 | 0;
    var $_0_val$0 = HEAP32[$_0 >> 2];
    var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
    __ZL13IMPL_TO_JSVAL12jsval_layout4204($agg_result, $_0_val$0, $_0_val$1);
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $6 = $agg_result | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSVAL_TO_BOOLEAN4200($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_BOOLEAN_IMPL4209($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _BOOLEAN_TO_JSVAL4201($agg_result, $b) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BOOLEAN_TO_JSVAL_IMPL4208($1, $b);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout4204($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function _JSVAL_TO_INT4202($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_INT32_IMPL4206($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _INT_TO_JSVAL4203($agg_result, $i) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _INT32_TO_JSVAL_IMPL4205($1, $i);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout4204($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function _JSVAL_IS_NULL($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_NULL_IMPL4221($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_IS_VOID($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_UNDEFINED_IMPL4220($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_IS_OBJECT($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_OBJECT_OR_NULL_IMPL4219($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_IS_INT($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_INT32_IMPL4218($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_IS_DOUBLE4214($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_DOUBLE_IMPL4217($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_IS_STRING4215($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_STRING_IMPL4216($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL9mem_get32P10JSXDRStatePj($xdr, $lp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $6 = HEAPU32[$xdr + 44 >> 2];
    if ((HEAP32[$xdr >> 2] | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      var $17 = $6;
      __label__ = 4;
      break;
    }
   case 2:
    if (($6 + 4 | 0) >>> 0 > HEAPU32[$xdr + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $17 = $6;
      __label__ = 4;
      break;
    }
   case 3:
    var $16 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportErrorNumber($16, 4, 63, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $17;
    var $21 = $xdr + 44 | 0;
    var $22 = $21;
    var $25 = HEAP32[HEAP32[$xdr + 40 >> 2] + $17 >> 2];
    HEAP32[$lp >> 2] = $25;
    var $_c = HEAP32[$22 >> 2] + 4 | 0;
    HEAP32[$21 >> 2] = $_c;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9mem_set32P10JSXDRStatePj($xdr, $lp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$xdr >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $4 = $xdr + 48 | 0;
    var $6 = HEAPU32[$4 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = HEAPU32[$xdr + 44 >> 2];
    if (($11 + 4 | 0) >>> 0 > $6 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $16 = $11 + 8195 & -8192;
    var $19 = $xdr + 40 | 0;
    var $21 = HEAP32[$19 >> 2];
    var $22 = HEAP32[$xdr + 8 >> 2];
    var $23 = __ZN9JSContext8realloc_EPvj($22, $21, $16);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_c1 = $23;
    HEAP32[$19 >> 2] = $_c1;
    HEAP32[$4 >> 2] = $16;
    __label__ = 8;
    break;
   case 6:
    if ((HEAP32[$xdr + 44 >> 2] + 4 | 0) >>> 0 > HEAPU32[$xdr + 48 >> 2] >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportErrorNumber($39, 4, 63, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 8:
    var $40 = HEAP32[$lp >> 2];
    var $44 = $xdr + 44 | 0;
    var $45 = $44;
    var $48 = HEAP32[$xdr + 40 >> 2] + HEAP32[$45 >> 2] | 0;
    HEAP32[$48 >> 2] = $40;
    var $_c = HEAP32[$45 >> 2] + 4 | 0;
    HEAP32[$44 >> 2] = $_c;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9mem_set32P10JSXDRStatePj["X"] = 1;

function __ZL12mem_getbytesP10JSXDRStatePcj($xdr, $bytes, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $6 = HEAPU32[$xdr + 44 >> 2];
    if ((HEAP32[$xdr >> 2] | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      var $17 = $6;
      __label__ = 4;
      break;
    }
   case 2:
    if (($6 + $len | 0) >>> 0 > HEAPU32[$xdr + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $17 = $6;
      __label__ = 4;
      break;
    }
   case 3:
    var $16 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportErrorNumber($16, 4, 63, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $17;
    var $21 = $xdr + 44 | 0;
    var $22 = $21;
    var $23 = HEAP32[$xdr + 40 >> 2] + $17 | 0;
    _memcpy($bytes, $23, $len, 1);
    var $_c = HEAP32[$22 >> 2] + $len | 0;
    HEAP32[$21 >> 2] = $_c;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12mem_setbytesP10JSXDRStatePcj($xdr, $bytes, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$xdr >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $4 = $xdr + 48 | 0;
    var $6 = HEAPU32[$4 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAP32[$xdr + 44 >> 2] + $len | 0;
    if ($12 >>> 0 > $6 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $16 = $12 + 8191 & -8192;
    var $19 = $xdr + 40 | 0;
    var $21 = HEAP32[$19 >> 2];
    var $22 = HEAP32[$xdr + 8 >> 2];
    var $23 = __ZN9JSContext8realloc_EPvj($22, $21, $16);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_c1 = $23;
    HEAP32[$19 >> 2] = $_c1;
    var $_c2 = $16;
    HEAP32[$4 >> 2] = $_c2;
    __label__ = 8;
    break;
   case 6:
    if ((HEAP32[$xdr + 44 >> 2] + $len | 0) >>> 0 > HEAPU32[$xdr + 48 >> 2] >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportErrorNumber($39, 4, 63, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 8:
    var $43 = $xdr + 44 | 0;
    var $44 = $43;
    var $46 = HEAP32[$xdr + 40 >> 2] + HEAP32[$44 >> 2] | 0;
    _memcpy($46, $bytes, $len, 1);
    var $_c = HEAP32[$44 >> 2] + $len | 0;
    HEAP32[$43 >> 2] = $_c;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12mem_setbytesP10JSXDRStatePcj["X"] = 1;

function __ZL7mem_rawP10JSXDRStatej($xdr, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$xdr >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $4 = $xdr + 48 | 0;
    var $6 = HEAPU32[$4 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAP32[$xdr + 44 >> 2] + $len | 0;
    if ($12 >>> 0 > $6 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $16 = $12 + 8191 & -8192;
    var $19 = $xdr + 40 | 0;
    var $21 = HEAP32[$19 >> 2];
    var $22 = HEAP32[$xdr + 8 >> 2];
    var $23 = __ZN9JSContext8realloc_EPvj($22, $21, $16);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_c1 = $23;
    HEAP32[$19 >> 2] = $_c1;
    var $_c2 = $16;
    HEAP32[$4 >> 2] = $_c2;
    __label__ = 8;
    break;
   case 6:
    if ((HEAP32[$xdr + 44 >> 2] + $len | 0) >>> 0 > HEAPU32[$xdr + 48 >> 2] >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportErrorNumber($39, 4, 63, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 8:
    var $43 = $xdr + 44 | 0;
    var $45 = HEAP32[$43 >> 2];
    var $46 = HEAP32[$xdr + 40 >> 2] + $45 | 0;
    var $_c = $45 + $len | 0;
    HEAP32[$43 >> 2] = $_c;
    var $_0 = $46;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL7mem_rawP10JSXDRStatej["X"] = 1;

function __ZL8mem_seekP10JSXDRStatei11JSXDRWhence($xdr, $offset, $whence) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $numBuf = __stackBase__;
    if (($whence | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($whence | 0) == 0) {
      __label__ = 12;
      break;
    } else if (($whence | 0) == 2) {
      __label__ = 23;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 2:
    var $2 = $xdr + 44 | 0;
    var $3 = $2;
    var $4 = HEAPU32[$3 >> 2];
    var $5 = $4 + $offset | 0;
    if (($5 | 0) < 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportErrorNumber($10, 4, 64, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 29;
    break;
   case 4:
    if (($offset | 0) > 0) {
      __label__ = 5;
      break;
    } else {
      var $45 = $4;
      __label__ = 11;
      break;
    }
   case 5:
    var $15 = HEAP32[$xdr >> 2];
    if (($15 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($15 | 0) == 1) {
      __label__ = 9;
      break;
    } else {
      var $45 = $4;
      __label__ = 11;
      break;
    }
   case 6:
    var $17 = $xdr + 48 | 0;
    var $19 = HEAPU32[$17 >> 2];
    if (($19 | 0) != 0 & $5 >>> 0 > $19 >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $45 = $4;
      __label__ = 11;
      break;
    }
   case 7:
    var $24 = $5 + 8191 & -8192;
    var $27 = $xdr + 40 | 0;
    var $29 = HEAP32[$27 >> 2];
    var $30 = HEAP32[$xdr + 8 >> 2];
    var $31 = __ZN9JSContext8realloc_EPvj($30, $29, $24);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_c5 = $31;
    HEAP32[$27 >> 2] = $_c5;
    HEAP32[$17 >> 2] = $24;
    var $45 = HEAP32[$3 >> 2];
    __label__ = 11;
    break;
   case 9:
    if ($5 >>> 0 > HEAPU32[$xdr + 48 >> 2] >>> 0) {
      __label__ = 10;
      break;
    } else {
      var $45 = $4;
      __label__ = 11;
      break;
    }
   case 10:
    var $43 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportErrorNumber($43, 4, 63, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 29;
    break;
   case 11:
    var $45;
    HEAP32[$2 >> 2] = $45 + $offset | 0;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 12:
    if (($offset | 0) < 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $52 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportErrorNumber($52, 4, 64, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 29;
    break;
   case 14:
    if ((HEAP32[$xdr >> 2] | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 15:
    var $58 = $xdr + 44 | 0;
    if (HEAPU32[$58 >> 2] >>> 0 < $offset >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 16:
    var $63 = $xdr + 48 | 0;
    var $65 = HEAPU32[$63 >> 2];
    if (($65 | 0) != 0 & $65 >>> 0 < $offset >>> 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 17:
    var $70 = $offset + 8191 & -8192;
    var $73 = $xdr + 40 | 0;
    var $75 = HEAP32[$73 >> 2];
    var $76 = HEAP32[$xdr + 8 >> 2];
    var $77 = __ZN9JSContext8realloc_EPvj($76, $75, $70);
    if (($77 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $_c2 = $77;
    HEAP32[$73 >> 2] = $_c2;
    HEAP32[$63 >> 2] = $70;
    __label__ = 19;
    break;
   case 19:
    HEAP32[$58 >> 2] = $offset;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 20:
    if (HEAPU32[$xdr + 48 >> 2] >>> 0 < $offset >>> 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    var $90 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportErrorNumber($90, 4, 65, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 29;
    break;
   case 22:
    HEAP32[$xdr + 44 >> 2] = $offset;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 23:
    if (($offset | 0) > -1) {
      __label__ = 26;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    if ((HEAP32[$xdr >> 2] | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $103 = HEAP32[$xdr + 48 >> 2] + $offset | 0;
    if (($103 | 0) < 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $108 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportErrorNumber($108, 4, 66, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 29;
    break;
   case 27:
    var $_c = $103;
    HEAP32[$xdr + 44 >> 2] = $_c;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 28:
    var $112 = $numBuf | 0;
    var $113 = _JS_snprintf($112, 12, STRING_TABLE.__str4498 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $whence, tempInt));
    var $116 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportErrorNumber($116, 4, 67, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $112, tempInt));
    var $_0 = 0;
    __label__ = 29;
    break;
   case 29:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL8mem_seekP10JSXDRStatei11JSXDRWhence["X"] = 1;

function __ZL12mem_finalizeP10JSXDRState($xdr) {
  var $3 = HEAP32[$xdr + 40 >> 2];
  __ZN9JSContext5free_EPv($3);
  return;
}

function __ZL18namespace_equalityP9JSContextP8JSObjectPKN2JS5ValueEPi($cx, $obj, $v, $bp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $1 = __ZNK2JS5Value14toObjectOrNullEv($v_idx_val$0, $v_idx_val$1);
    var $2 = $1;
    if (($1 | 0) == 0) {
      var $13 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$1 + 4 >> 2];
    var $5 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($5 | 0) == (__ZN2js14NamespaceClassE | 0)) {
      __label__ = 3;
      break;
    } else {
      var $13 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZNK8JSObject10getNameURIEv($obj);
    var $9 = __ZNK8JSObject10getNameURIEv($2);
    var $10 = __ZN2js12EqualStringsEP14JSLinearStringS1_($8, $9);
    var $13 = $10 & 1;
    __label__ = 4;
    break;
   case 4:
    var $13;
    HEAP32[$bp >> 2] = $13;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18namespace_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $vp + 8 | 0;
    var $3 = $cx;
    var $4 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($3, $2);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$4 + 4 >> 2];
    var $9 = __ZNK8JSObject11isNamespaceEv($_idx_val);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($3, $vp, __ZN2js14NamespaceClassE);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    __ZNK8JSObject13getNameURIValEv($1, $5);
    var $12 = $1 | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    var $14 = $vp | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject7isQNameEv($this_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this_0_1_val | 0) == (__ZN2js10QNameClassE | 0) | ($this_0_1_val | 0) == (__ZN2js18AttributeNameClassE | 0)) {
      var $6 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = ($this_0_1_val | 0) == (__ZN2js12AnyNameClassE | 0);
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSID_IS_OBJECT4314($iden) {
  return ($iden & 7 | 0) == 4 & ($iden | 0) != 4 & 1;
}

function _JSID_TO_OBJECT4315($iden) {
  return $iden & -8;
}

function __ZN16JSXMLArrayCursor10disconnectEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $this + 8 | 0;
    var $6 = HEAP32[$5 >> 2];
    var $_pre1 = $this + 12 | 0;
    if (($6 | 0) == 0) {
      var $11 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAP32[$_pre1 >> 2];
    var $10 = $6 + 12 | 0;
    HEAP32[$10 >> 2] = $9;
    var $11 = HEAP32[$5 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $11;
    var $12 = HEAP32[$_pre1 >> 2];
    HEAP32[$12 >> 2] = $11;
    HEAP32[$1 >> 2] = 0;
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14qname_equalityP9JSContextP8JSObjectPKN2JS5ValueEPi($cx, $qn, $v, $bp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $1 = __ZNK2JS5Value14toObjectOrNullEv($v_idx_val$0, $v_idx_val$1);
    var $2 = $1;
    if (($1 | 0) == 0) {
      var $10 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$1 + 4 >> 2];
    var $5 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($5 | 0) == (__ZN2js10QNameClassE | 0)) {
      __label__ = 3;
      break;
    } else {
      var $10 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZL14qname_identityP8JSObjectS0_($qn, $2);
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    HEAP32[$bp >> 2] = $10;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14qname_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $8 = __ZNK8JSObject7isQNameEv($_idx_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($2, $vp, __ZN2js10QNameClassE);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    var $11 = __ZL20ConvertQNameToStringP9JSContextP8JSObject($cx, $4);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JS5Value9setStringEP8JSString($vp, $11);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z26js_ConstructXMLQNameObjectP9JSContextRKN2JS5ValueES4_($cx, $nsval_0_0_0_val$0, $nsval_0_0_0_val$1, $lnval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $argv = __stackBase__;
    var $1 = __ZNK2JS5Value8isObjectEv($nsval_0_0_0_val$0, $nsval_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($nsval_0_0_0_val$0, $nsval_0_0_0_val$1);
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($4 | 0) == (__ZN2js12AnyNameClassE | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = $argv | 0;
    __ZN2JS5Value7setNullEv($7);
    var $_pre_phi = $7;
    __label__ = 5;
    break;
   case 4:
    var $9 = $argv | 0;
    HEAP32[$9 >> 2] = $nsval_0_0_0_val$0;
    HEAP32[$9 + 4 >> 2] = $nsval_0_0_0_val$1;
    var $_pre_phi = $argv | 0;
    __label__ = 5;
    break;
   case 5:
    var $_pre_phi;
    var $11 = $lnval | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $argv + 8 | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $14 = $cx;
    var $15 = __Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE($14, __ZN2js10QNameClassE, 0, 2, $_pre_phi);
    var $16 = $15;
    STACKTOP = __stackBase__;
    return $16;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z12js_IsXMLNameP9JSContextN2JS5ValueE($cx, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSVAL_IS_PRIMITIVE4303($_0_0_0_val$0, $_0_0_0_val$1);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = _JSVAL_TO_OBJECT4304($_0_0_0_val$0, $_0_0_0_val$1);
    var $_idx1_val = HEAP32[$4 + 4 >> 2];
    var $5 = __ZNK8JSObject7isQNameEv($_idx1_val);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = _JSVAL_TO_OBJECT4304($_0_0_0_val$0, $_0_0_0_val$1);
    var $8 = __ZNK8JSObject17getQNameLocalNameEv($7);
    var $name_1 = $8 | 0;
    __label__ = 8;
    break;
   case 4:
    var $11 = $cx;
    var $12 = _JS_SetErrorReporter($11, 0);
    var $13 = $cx;
    var $14 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($13, $_0_0_0_val$0, $_0_0_0_val$1);
    if (($14 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = _JS_SetErrorReporter($11, $12);
    __label__ = 7;
    break;
   case 6:
    var $18 = __ZN8JSString12ensureLinearEP9JSContext($14, $11);
    var $19 = _JS_SetErrorReporter($11, $12);
    if (($18 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $name_1 = $18;
      __label__ = 8;
      break;
    }
   case 7:
    _JS_ClearPendingException($11);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 8:
    var $name_1;
    var $name_1_idx_val = HEAP32[$name_1 + 4 >> 2];
    var $23 = __ZNK14JSLinearString5charsEv($name_1_idx_val);
    var $_idx_val = HEAP32[$name_1 >> 2];
    var $24 = __ZNK8JSString6lengthEv($_idx_val);
    var $25 = __ZL9IsXMLNamePKtj($23, $24);
    var $_0 = $25;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSVAL_IS_PRIMITIVE4303($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_PRIMITIVE_IMPL4409($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_OBJECT4304($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_OBJECT_IMPL4449($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZNK8JSObject17getQNameLocalNameEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK8JSObject7getSlotEj($1, 2);
    var $_idx = $2 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $3 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($3) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2JS5Value8toStringEv($_idx_val$0, $_idx_val$1);
    var $6 = __ZNK8JSString6asAtomEv($5);
    var $9 = $6;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9IsXMLNamePKtj($cp, $n) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($n | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = HEAP16[$cp >> 1];
    var $4 = __ZN2js7unicode19IsXMLNamespaceStartEt($3);
    if ($4) {
      var $_01 = $cp;
      var $_02 = $n;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $_02;
    var $_01;
    var $5 = $_02 - 1 | 0;
    if (($5 | 0) == 0) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = $_01 + 2 | 0;
    var $9 = HEAP16[$8 >> 1];
    var $10 = __ZN2js7unicode18IsXMLNamespacePartEt($9);
    if ($10) {
      var $_01 = $8;
      var $_02 = $5;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN16JSXMLArrayCursor5traceEP8JSTracer($this, $trc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $2 = $this + 4 | 0;
    var $3 = $trc;
    var $cursor_01 = $this;
    __label__ = 3;
    break;
   case 3:
    var $cursor_01;
    var $6 = HEAP32[$cursor_01 + 16 >> 2];
    var $8 = HEAP32[$2 >> 2] + 1 | 0;
    HEAP32[$2 >> 2] = $8;
    __ZN2js2gc11MarkGCThingEP8JSTracerPvPKcj($3, $6);
    var $10 = HEAP32[$cursor_01 + 8 >> 2];
    if (($10 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $cursor_01 = $10;
      __label__ = 3;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSXMLArray11setCapacityEP9JSContextj($this, $cx, $newCapacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($newCapacity | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $3 = $this + 8 | 0;
    var $4 = HEAP32[$3 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $4;
    if (($cx | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN9JSContext5free_EPv($8);
    __label__ = 6;
    break;
   case 5:
    __ZN2js10Foreground5free_EPv($8);
    __label__ = 6;
    break;
   case 6:
    HEAP32[$3 >> 2] = 0;
    __label__ = 12;
    break;
   case 7:
    if ($newCapacity >>> 0 > 1073741823) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $15 = $this + 8 | 0;
    var $17 = HEAP32[$15 >> 2];
    var $18 = $newCapacity << 2;
    var $19 = __ZN2js11OffTheBooks8realloc_EPvj($17, $18);
    if (($19 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    if (($cx | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $24 = $cx;
    _JS_ReportOutOfMemory($24);
    var $_0 = 0;
    __label__ = 13;
    break;
   case 11:
    var $26 = $19;
    HEAP32[$15 >> 2] = $26;
    __label__ = 12;
    break;
   case 12:
    HEAP32[$this + 4 >> 2] = $newCapacity | -2147483648;
    var $_0 = 1;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSXMLArray4trimEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if (($2 | 0) < 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAPU32[$this >> 2];
    if ($6 >>> 0 < $2 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = __ZN10JSXMLArray11setCapacityEP9JSContextj($this, 0, $6);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSXMLArray6finishEP9JSContext($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$this + 8 >> 2];
    __ZN9JSContext5free_EPv($3);
    var $4 = $this + 12 | 0;
    var $5 = HEAP32[$4 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $7 = $5;
      __label__ = 2;
      break;
    }
   case 2:
    var $7;
    __ZN16JSXMLArrayCursor10disconnectEv($7);
    var $8 = HEAP32[$4 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $7 = $8;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z32js_GetLocalNameFromFunctionQNameP8JSObjectPiP9JSContext($obj, $funidp, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj_idx_val = HEAP32[$obj + 4 >> 2];
    var $1 = __ZNK8JSObject7isQNameEv($obj_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZL29GetLocalNameFromFunctionQNameP8JSObjectPiP9JSContext($obj, $funidp, $cx);
    var $_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL29GetLocalNameFromFunctionQNameP8JSObjectPiP9JSContext($qn, $funidp, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject10getNameURIEv($qn);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[HEAP32[$cx + 52 >> 2] + 210428 >> 2] | 0;
    if (($1 | 0) == ($8 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZN2js12EqualStringsEP14JSLinearStringS1_($1, $8);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = __ZNK8JSObject17getQNameLocalNameEv($qn);
    var $14 = __ZL12ATOM_TO_JSIDP6JSAtom4336($13);
    HEAP32[$funidp >> 2] = $14;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z11xml_convertP9JSContextP8JSObject6JSTypePN2JS5ValueE($cx, $obj, $hint, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $anch = __stackBase__;
    var $1 = __stackBase__ + 4;
    __ZN2JS6AnchorIP8JSObjectEC1ES2_($anch, $obj);
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $3 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $4 = $3;
    var $5 = __ZL19xml_toString_helperP9JSContextP5JSXML($cx, $4);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL11StringValueEP8JSString4311($1, $5);
    var $8 = $1 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $rval | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JS6AnchorIP8JSObjectEC1ES2_($this, $t) {
  __ZN2JS6AnchorIP8JSObjectEC2ES2_($this, $t);
  return;
}

function __ZL19xml_toString_helperP9JSContextP5JSXML($cx, $xml) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $cursor = __stackBase__ + 8;
    var $3 = HEAP32[$xml + 16 >> 2];
    if (($3 | 0) == 2 || ($3 | 0) == 4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = HEAP32[$xml + 24 >> 2];
    __label__ = 12;
    break;
   case 3:
    var $9 = __ZL16HasSimpleContentP5JSXML($xml);
    if (($9 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = HEAP32[$xml >> 2];
    _OBJECT_TO_JSVAL4318($1, $13);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $14 = __ZL11ToXMLStringP9JSContextN2JS5ValueEj($cx, $_idx_val$0, $_idx_val$1, 0);
    var $_0 = $14;
    __label__ = 12;
    break;
   case 5:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    var $21 = $xml + 24 | 0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor, $21);
    var $22 = $cx;
    var $str_0_ph = $20;
    __label__ = 6;
    break;
   case 6:
    var $str_0_ph;
    __label__ = 7;
    break;
   case 7:
    var $23 = __ZN16JSXMLArrayCursor7getNextEv($cursor);
    if (($23 | 0) == 0) {
      var $str_1 = $str_0_ph;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $28 = HEAP32[$23 + 16 >> 2];
    if (($28 | 0) == 5 || ($28 | 0) == 3) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $30 = $23;
    var $31 = __ZL19xml_toString_helperP9JSContextP5JSXML($cx, $30);
    if (($31 | 0) == 0) {
      var $str_1 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $34 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($22, $str_0_ph, $31);
    if (($34 | 0) == 0) {
      var $str_1 = 0;
      __label__ = 11;
      break;
    } else {
      var $str_0_ph = $34;
      __label__ = 6;
      break;
    }
   case 11:
    var $str_1;
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_0 = $str_1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19xml_toString_helperP9JSContextP5JSXML["X"] = 1;

function __ZN2JSL11StringValueEP8JSString4311($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __Z15js_GetXMLMethodP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $tvr = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $id;
    var $2 = _JSID_IS_OBJECT4314($id);
    if (($2 | 0) == 0) {
      var $8 = $id;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = _JSID_TO_OBJECT4315($id);
    var $6 = __Z32js_GetLocalNameFromFunctionQNameP8JSObjectPiP9JSContext($5, $1, $cx);
    var $8 = HEAP32[$1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $8;
    var $9 = $cx;
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $9);
    var $10 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $11 = __ZL14GetXMLFunctionP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $8, $10);
    var $12 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $13 = $12 | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $vp | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14GetXMLFunctionP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = $tvr;
    var $2 = $cx;
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($1, $2, 0);
    var $3 = $vp | 0;
    var $target_0 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $target_0;
    var $6 = __Z14js_GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($2, $target_0, $id, $vp);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $st$0$0 = $3 | 0;
    var $9$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $3 + 4 | 0;
    var $9$1 = HEAP32[$st$0$1 >> 2];
    var $10 = _JSVAL_IS_PRIMITIVE4303($9$0, $9$1);
    if (($10 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $st$0$0 = $3 | 0;
    var $13$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $3 + 4 | 0;
    var $13$1 = HEAP32[$st$0$1 >> 2];
    var $14 = _JSVAL_TO_OBJECT4304($13$0, $13$1);
    var $_idx1_val = HEAP32[$14 + 4 >> 2];
    var $16 = __ZNK8JSObject10isFunctionEv($_idx1_val);
    if ($16) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx3_val_idx_val = HEAP32[HEAP32[$target_0 + 36 >> 2] >> 2];
    var $19 = __ZNK8JSObject8getProtoEv($_idx3_val_idx_val);
    var $20 = $19;
    if (($19 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx2_val = HEAP32[$19 >> 2];
    var $23 = __ZNK8JSObject8isNativeEv($_idx2_val);
    if ($23) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2js16AutoObjectRooter9setObjectEP8JSObject($tvr, $20);
    var $target_0 = $20;
    __label__ = 2;
    break;
   case 8:
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $27 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $28 = $27;
    var $29 = __ZL16HasSimpleContentP5JSXML($28);
    if (($29 | 0) == 0) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = $tvr;
    var $33 = __ZN2js16AutoObjectRooter4addrEv($32);
    var $34 = $cx;
    var $35 = $33;
    var $36 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($34, 0, 9, $35, 0);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_idx6_val = HEAP32[$tvr + 12 >> 2];
    var $40 = __ZNK2js16AutoObjectRooter6objectEv($_idx6_val);
    var $41 = $40;
    var $42 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($41, $2, $id, $vp);
    var $_0 = $42;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    __ZN2js16AutoObjectRooterD1Ev($1);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14GetXMLFunctionP9JSContextP8JSObjectiPN2JS5ValueE["X"] = 1;

function __Z18js_TestXMLEqualityP9JSContextRKN2JS5ValueES4_Pi($cx, $v1_0_0_0_val$0, $v1_0_0_0_val$1, $v2, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 24;
    var $4 = __stackBase__ + 32;
    var $5 = __stackBase__ + 40;
    var $6 = __ZNK2JS5Value8isObjectEv($v1_0_0_0_val$0, $v1_0_0_0_val$1);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = __ZNK2JS5Value8toObjectEv($v1_0_0_0_val$0, $v1_0_0_0_val$1);
    var $_idx3_val = HEAP32[$8 + 4 >> 2];
    var $9 = __ZNK8JSObject5isXMLEv($_idx3_val);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = $v2 | 0;
    var $st$1$0 = $11 | 0;
    var $st$1$1 = $11 + 4 | 0;
    var $obj_0_in = $8;
    var $v_0_0_0$1 = HEAP32[$st$1$1 >> 2];
    var $v_0_0_0$0 = HEAP32[$st$1$0 >> 2];
    __label__ = 5;
    break;
   case 4:
    var $v2_idx = $v2 | 0;
    var $st$1$0 = $v2_idx | 0;
    var $v2_idx_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $v2_idx + 4 | 0;
    var $v2_idx_val$1 = HEAP32[$st$1$1 >> 2];
    var $14 = __ZNK2JS5Value8toObjectEv($v2_idx_val$0, $v2_idx_val$1);
    var $obj_0_in = $14;
    var $v_0_0_0$1 = $v1_0_0_0_val$1;
    var $v_0_0_0$0 = $v1_0_0_0_val$0;
    __label__ = 5;
    break;
   case 5:
    var $v_0_0_0$0;
    var $v_0_0_0$1;
    var $obj_0_in;
    var $obj_0 = $obj_0_in;
    var $obj_0_in_idx_val = HEAP32[$obj_0_in + 24 >> 2];
    var $16 = __ZNK8JSObject10getPrivateEv($obj_0_in_idx_val);
    var $17 = $16;
    var $18 = _JSVAL_IS_PRIMITIVE4303($v_0_0_0$0, $v_0_0_0$1);
    if (($18 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $vxml_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $21 = _JSVAL_TO_OBJECT4304($v_0_0_0$0, $v_0_0_0$1);
    var $_idx2_val = HEAP32[$21 + 4 >> 2];
    var $23 = __ZNK8JSObject5isXMLEv($_idx2_val);
    if ($23) {
      __label__ = 7;
      break;
    } else {
      var $vxml_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $_idx_val = HEAP32[$21 + 24 >> 2];
    var $26 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $vxml_0 = $26;
    __label__ = 8;
    break;
   case 8:
    var $vxml_0;
    var $31 = HEAP32[$16 + 16 >> 2];
    if (($31 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = __ZL6EqualsP9JSContextP5JSXMLN2JS5ValueEPi($cx, $17, $v_0_0_0$0, $v_0_0_0$1, $bp);
    var $ok_2 = $34;
    __label__ = 36;
    break;
   case 10:
    if (($vxml_0 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $39 = HEAP32[$vxml_0 + 16 >> 2];
    if (($39 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    _OBJECT_TO_JSVAL4318($1, $obj_0);
    var $_idx14 = $1 | 0;
    var $_idx14_val$0 = HEAP32[$_idx14 >> 2];
    var $_idx14_val$1 = HEAP32[$_idx14 + 4 >> 2];
    var $42 = __ZL6EqualsP9JSContextP5JSXMLN2JS5ValueEPi($cx, $vxml_0, $_idx14_val$0, $_idx14_val$1, $bp);
    var $ok_2 = $42;
    __label__ = 36;
    break;
   case 13:
    if (($31 | 0) == 4 || ($31 | 0) == 2) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $45 = __ZL16HasSimpleContentP5JSXML($vxml_0);
    if (($45 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    if (($39 | 0) == 4 || ($39 | 0) == 2) {
      __label__ = 16;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 16:
    var $49 = __ZL16HasSimpleContentP5JSXML($17);
    if (($49 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    __ZN2JSL11ObjectValueER8JSObject4319($2, $obj_0);
    var $52 = $cx;
    var $_idx18 = $2 | 0;
    var $st$3$0 = $_idx18 | 0;
    var $_idx18_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx18 + 4 | 0;
    var $_idx18_val$1 = HEAP32[$st$3$1 >> 2];
    var $53 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($52, $_idx18_val$0, $_idx18_val$1);
    if (($53 | 0) == 0) {
      var $ok_2 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $56 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($52, $v_0_0_0$0, $v_0_0_0$1);
    var $57 = ($56 | 0) != 0;
    var $58 = $57 & 1;
    if ($57) {
      __label__ = 19;
      break;
    } else {
      var $ok_2 = $58;
      __label__ = 36;
      break;
    }
   case 19:
    var $60 = __ZN2js12EqualStringsEP9JSContextP8JSStringS3_Pi($52, $53, $56, $bp);
    var $ok_2 = $60 & 1;
    __label__ = 36;
    break;
   case 20:
    var $63 = __ZL9XMLEqualsP9JSContextP5JSXMLS2_Pi($cx, $17, $vxml_0, $bp);
    var $ok_2 = $63;
    __label__ = 36;
    break;
   case 21:
    var $65 = __ZL16HasSimpleContentP5JSXML($17);
    if (($65 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    __ZN2JSL11ObjectValueER8JSObject4319($3, $obj_0);
    var $68 = $cx;
    var $_idx16 = $3 | 0;
    var $st$3$0 = $_idx16 | 0;
    var $_idx16_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx16 + 4 | 0;
    var $_idx16_val$1 = HEAP32[$st$3$1 >> 2];
    var $69 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($68, $_idx16_val$0, $_idx16_val$1);
    if (($69 | 0) == 0) {
      var $ok_2 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $72 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($68, $v_0_0_0$0, $v_0_0_0$1);
    var $73 = ($72 | 0) != 0;
    var $74 = $73 & 1;
    if ($73) {
      __label__ = 24;
      break;
    } else {
      var $ok_2 = $74;
      __label__ = 36;
      break;
    }
   case 24:
    var $76 = __ZN2js12EqualStringsEP9JSContextP8JSStringS3_Pi($68, $69, $72, $bp);
    var $ok_2 = $76 & 1;
    __label__ = 36;
    break;
   case 25:
    var $79 = _JSVAL_IS_STRING4320($v_0_0_0$0, $v_0_0_0$1);
    if (($79 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $82 = _JSVAL_IS_NUMBER($v_0_0_0$0, $v_0_0_0$1);
    if (($82 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2JSL11ObjectValueER8JSObject4319($4, $obj_0);
    var $85 = $cx;
    var $_idx1 = $4 | 0;
    var $st$3$0 = $_idx1 | 0;
    var $_idx1_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx1 + 4 | 0;
    var $_idx1_val$1 = HEAP32[$st$3$1 >> 2];
    var $86 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($85, $_idx1_val$0, $_idx1_val$1);
    if (($86 | 0) == 0) {
      var $ok_2 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $89 = _JSVAL_IS_STRING4320($v_0_0_0$0, $v_0_0_0$1);
    if (($89 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $92 = _JSVAL_TO_STRING4321($v_0_0_0$0, $v_0_0_0$1);
    var $93 = __ZN2js12EqualStringsEP9JSContextP8JSStringS3_Pi($85, $86, $92, $bp);
    var $ok_2 = $93 & 1;
    __label__ = 36;
    break;
   case 30:
    _STRING_TO_JSVAL4322($5, $86);
    var $96 = $cx;
    var $_idx10 = $5 | 0;
    var $st$3$0 = $_idx10 | 0;
    var $_idx10_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx10 + 4 | 0;
    var $_idx10_val$1 = HEAP32[$st$3$1 >> 2];
    var $97 = _JS_ValueToNumber($96, $_idx10_val$0, $_idx10_val$1, $d);
    if (($97 | 0) == 0) {
      var $ok_2 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $100 = _JSVAL_IS_INT4323($v_0_0_0$0, $v_0_0_0$1);
    if (($100 | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $103 = _JSVAL_TO_INT4324($v_0_0_0$0, $v_0_0_0$1);
    var $108 = $103 | 0;
    __label__ = 34;
    break;
   case 33:
    var $106 = _JSVAL_TO_DOUBLE4325($v_0_0_0$0, $v_0_0_0$1);
    var $108 = $106;
    __label__ = 34;
    break;
   case 34:
    var $108;
    var $109 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $111 = $109 == $108 & 1;
    HEAP32[$bp >> 2] = $111;
    var $ok_2 = $97;
    __label__ = 36;
    break;
   case 35:
    HEAP32[$bp >> 2] = 0;
    var $ok_2 = 1;
    __label__ = 36;
    break;
   case 36:
    var $ok_2;
    STACKTOP = __stackBase__;
    return $ok_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18js_TestXMLEqualityP9JSContextRKN2JS5ValueES4_Pi["X"] = 1;

function __ZL6EqualsP9JSContextP5JSXMLN2JS5ValueEPi($cx, $xml, $_0_0_0_val$0, $_0_0_0_val$1, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = $v | 0;
    HEAP32[$2 >> 2] = $_0_0_0_val$0;
    HEAP32[$2 + 4 >> 2] = $_0_0_0_val$1;
    var $3 = _JSVAL_IS_PRIMITIVE4303($_0_0_0_val$0, $_0_0_0_val$1);
    if (($3 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$bp >> 2] = 0;
    if ((HEAP32[$xml + 16 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 3:
    var $10 = $xml + 24 | 0;
    if ((HEAP32[$10 >> 2] | 0) == 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $16 = HEAP32[HEAP32[$xml + 32 >> 2] >> 2];
    if (($16 | 0) == 0) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = $16;
    var $20 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2JSL11ObjectValueER8JSObject4319($1, $20);
    var $_idx5 = $1 | 0;
    var $_idx5_val$0 = HEAP32[$_idx5 >> 2];
    var $_idx5_val$1 = HEAP32[$_idx5 + 4 >> 2];
    var $23 = __Z18js_TestXMLEqualityP9JSContextRKN2JS5ValueES4_Pi($cx, $_idx5_val$0, $_idx5_val$1, $v, $bp);
    var $_0 = $23;
    __label__ = 14;
    break;
   case 7:
    var $25 = _JSVAL_IS_VOID4396($_0_0_0_val$0, $_0_0_0_val$1);
    if (($25 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((HEAP32[$10 >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 9:
    HEAP32[$bp >> 2] = 1;
    __label__ = 13;
    break;
   case 10:
    var $32 = _JSVAL_TO_OBJECT4304($_0_0_0_val$0, $_0_0_0_val$1);
    var $_idx1_val = HEAP32[$32 + 4 >> 2];
    var $34 = __ZNK8JSObject5isXMLEv($_idx1_val);
    if ($34) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    HEAP32[$bp >> 2] = 0;
    __label__ = 13;
    break;
   case 12:
    var $_idx_val = HEAP32[$32 + 24 >> 2];
    var $38 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $39 = $38;
    var $40 = __ZL9XMLEqualsP9JSContextP5JSXMLS2_Pi($cx, $xml, $39, $bp);
    if (($40 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL6EqualsP9JSContextP5JSXMLN2JS5ValueEPi["X"] = 1;

function _OBJECT_TO_JSVAL4318($agg_result, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL_IMPL4443($1, $obj);
    var $_0 = $1 | 0;
    var $_0_val$0 = HEAP32[$_0 >> 2];
    var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
    __ZL13IMPL_TO_JSVAL12jsval_layout4416($agg_result, $_0_val$0, $_0_val$1);
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $6 = $agg_result | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15xml_hasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi($cx, $obj, $0, $bp) {
  return 1;
}

function __ZL16HasSimpleContentP5JSXML($xml) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $xml;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $3 = HEAPU32[$_01 + 16 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else if (($3 | 0) == 5 || ($3 | 0) == 3) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $6 = HEAP32[$_01 + 24 >> 2];
    if (($6 | 0) == 1) {
      __label__ = 4;
      break;
    } else if (($6 | 0) == 0) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $10 = HEAP32[HEAP32[$_01 + 32 >> 2] >> 2];
    var $11 = $10;
    if (($10 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $_01 = $11;
      __label__ = 2;
      break;
    }
   case 5:
    if ($3 >>> 0 < 2) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = 0;
    var $_pre_phi = $_01 + 24 | 0;
    __label__ = 8;
    break;
   case 7:
    var $14 = $_01 + 24 | 0;
    var $17 = HEAP32[$14 >> 2];
    var $_pre_phi = $14;
    __label__ = 8;
    break;
   case 8:
    var $_pre_phi;
    var $17;
    var $18 = $_01 + 32 | 0;
    var $i_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $i_0;
    if ($i_0 >>> 0 < $17 >>> 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 14;
      break;
    }
   case 10:
    if ($i_0 >>> 0 < HEAPU32[$_pre_phi >> 2] >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $27 = HEAP32[HEAP32[$18 >> 2] + ($i_0 << 2) >> 2];
    if (($27 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[$27 + 16 >> 2] | 0) == 1) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 9;
    break;
   case 14:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11ObjectValueER8JSObject4319($agg_result, $obj) {
  var $1 = $obj;
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $1);
  return;
}

function __ZL9XMLEqualsP9JSContextP5JSXMLS2_Pi($cx, $xml, $vxml, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cursor = __stackBase__;
    var $vcursor = __stackBase__ + 20;
    var $1 = __stackBase__ + 40;
    var $2 = __stackBase__ + 48;
    var $_02_ph = $xml;
    var $_04_ph = $vxml;
    __label__ = 2;
    break;
   case 2:
    var $_04_ph;
    var $_02_ph;
    var $4 = HEAP32[$_04_ph + 16 >> 2];
    var $_02 = $_02_ph;
    __label__ = 3;
    break;
   case 3:
    var $_02;
    var $6 = $_02 + 16 | 0;
    var $7 = HEAP32[$6 >> 2];
    if (($7 | 0) == ($4 | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_13 = $_02;
      __label__ = 7;
      break;
    }
   case 5:
    if ((HEAP32[$_02 + 24 >> 2] | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      var $_13 = $_02;
      __label__ = 7;
      break;
    }
   case 6:
    var $18 = HEAP32[HEAP32[$_02 + 32 >> 2] >> 2];
    var $19 = $18;
    if (($18 | 0) == 0) {
      var $_13 = 0;
      __label__ = 7;
      break;
    } else {
      var $_02 = $19;
      __label__ = 3;
      break;
    }
   case 7:
    var $_13;
    if (($4 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    if ((HEAP32[$_04_ph + 24 >> 2] | 0) == 1) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $30 = HEAP32[HEAP32[$_04_ph + 32 >> 2] >> 2];
    var $31 = $30;
    if (($30 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_02_ph = $_13;
      var $_04_ph = $31;
      __label__ = 2;
      break;
    }
   case 10:
    HEAP32[$bp >> 2] = 0;
    var $_1 = 1;
    __label__ = 45;
    break;
   case 11:
    var $36 = HEAP32[$_02 + 12 >> 2];
    var $38 = HEAP32[$_04_ph + 12 >> 2];
    var $40 = ($38 | 0) == 0;
    if (($36 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ($40) {
      var $53 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $43 = __ZNK8JSObject17getQNameLocalNameEv($36);
    var $44 = $43 | 0;
    var $45 = __ZNK8JSObject17getQNameLocalNameEv($38);
    var $46 = $45 | 0;
    var $47 = __ZN2js12EqualStringsEP14JSLinearStringS1_($44, $46);
    if ($47) {
      __label__ = 14;
      break;
    } else {
      var $53 = 0;
      __label__ = 15;
      break;
    }
   case 14:
    var $49 = __ZNK8JSObject10getNameURIEv($36);
    var $50 = __ZNK8JSObject10getNameURIEv($38);
    var $51 = __ZN2js12EqualStringsEP14JSLinearStringS1_($49, $50);
    var $53 = $51;
    __label__ = 15;
    break;
   case 15:
    var $53;
    var $storemerge = $53 & 1;
    __label__ = 17;
    break;
   case 16:
    var $storemerge = $40 & 1;
    __label__ = 17;
    break;
   case 17:
    var $storemerge;
    HEAP32[$bp >> 2] = $storemerge;
    if (($storemerge | 0) == 0) {
      var $_1 = 1;
      __label__ = 45;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $62 = $_02 + 24 | 0;
    if (HEAPU32[$6 >> 2] >>> 0 > 1) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $65 = HEAP32[$62 >> 2];
    var $68 = HEAP32[$_04_ph + 24 >> 2];
    var $69 = $cx;
    var $70 = __ZN2js12EqualStringsEP9JSContextP8JSStringS3_Pi($69, $65, $68, $bp);
    if ($70) {
      __label__ = 42;
      break;
    } else {
      var $_1 = 0;
      __label__ = 45;
      break;
    }
   case 20:
    var $74 = $_04_ph + 24 | 0;
    if ((HEAP32[$62 >> 2] | 0) == (HEAP32[$74 >> 2] | 0)) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    HEAP32[$bp >> 2] = 0;
    __label__ = 42;
    break;
   case 22:
    var $80 = $74 | 0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor, $62 | 0);
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($vcursor, $80);
    var $_idx2 = $1 | 0;
    __label__ = 23;
    break;
   case 23:
    var $83 = __ZN16JSXMLArrayCursor7getNextEv($cursor);
    var $84 = __ZN16JSXMLArrayCursor7getNextEv($vcursor);
    var $_not = ($83 | 0) == 0;
    var $85 = ($84 | 0) == 0;
    if ($85 | $_not) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    HEAP32[$bp >> 2] = $85 & $_not & 1;
    __label__ = 28;
    break;
   case 25:
    var $90 = $84;
    var $91 = $83;
    var $92 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $91);
    var $93 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $90);
    if (($92 | 0) == 0 | ($93 | 0) == 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    __ZN2JSL11ObjectValueER8JSObject4319($1, $92);
    __ZN2JSL11ObjectValueER8JSObject4319($2, $93);
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    var $97 = __Z18js_TestXMLEqualityP9JSContextRKN2JS5ValueES4_Pi($cx, $_idx2_val$0, $_idx2_val$1, $2, $bp);
    if (($97 | 0) == 0) {
      __label__ = 43;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    if ((HEAP32[$bp >> 2] | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 28:
    __ZN16JSXMLArrayCursorD1Ev($vcursor);
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $102 = HEAP32[$bp >> 2];
    if (($102 | 0) == 0) {
      __label__ = 42;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    if ((HEAP32[$6 >> 2] | 0) == 1) {
      __label__ = 30;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 30:
    var $108 = $_02 + 56 | 0;
    var $109 = HEAPU32[$108 >> 2];
    var $110 = $_04_ph + 56 | 0;
    if (($109 | 0) == (HEAP32[$110 >> 2] | 0)) {
      var $114 = $102;
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    HEAP32[$bp >> 2] = 0;
    var $114 = 0;
    __label__ = 32;
    break;
   case 32:
    var $114;
    var $115 = $_02 + 64 | 0;
    var $116 = $_04_ph + 64 | 0;
    var $117 = $cx;
    var $i_0 = 0;
    var $119 = $114;
    __label__ = 33;
    break;
   case 33:
    var $119;
    var $i_0;
    if (($119 | 0) != 0 & $i_0 >>> 0 < $109 >>> 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 34:
    if ($i_0 >>> 0 < HEAPU32[$108 >> 2] >>> 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 35:
    var $128 = HEAPU32[HEAP32[$115 >> 2] + ($i_0 << 2) >> 2];
    if (($128 | 0) == 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $_idx_val = HEAP32[$110 >> 2];
    var $_idx1_val = HEAP32[$116 >> 2];
    var $131 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx_val, $_idx1_val, $128, 264);
    if (($131 | 0) == -1) {
      __label__ = 37;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 37:
    HEAP32[$bp >> 2] = 0;
    __label__ = 42;
    break;
   case 38:
    if ($131 >>> 0 < HEAPU32[$110 >> 2] >>> 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 39:
    var $140 = HEAPU32[HEAP32[$116 >> 2] + ($131 << 2) >> 2];
    if (($140 | 0) == 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $145 = HEAP32[$128 + 24 >> 2];
    var $148 = HEAP32[$140 + 24 >> 2];
    var $149 = __ZN2js12EqualStringsEP9JSContextP8JSStringS3_Pi($117, $145, $148, $bp);
    if ($149) {
      __label__ = 41;
      break;
    } else {
      var $_1 = 0;
      __label__ = 45;
      break;
    }
   case 41:
    var $i_0 = $i_0 + 1 | 0;
    var $119 = HEAP32[$bp >> 2];
    __label__ = 33;
    break;
   case 42:
    var $_1 = 1;
    __label__ = 45;
    break;
   case 43:
    __ZN16JSXMLArrayCursorD1Ev($vcursor);
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_1 = 0;
    __label__ = 45;
    break;
   case 44:
    __ZN16JSXMLArrayCursorD1Ev($vcursor);
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_1 = 0;
    __label__ = 45;
    break;
   case 45:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9XMLEqualsP9JSContextP5JSXMLS2_Pi["X"] = 1;

function _JSVAL_IS_STRING4320($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_STRING_IMPL4412($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_IS_NUMBER($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_NUMBER_IMPL4446($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_STRING4321($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_STRING_IMPL4397($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _STRING_TO_JSVAL4322($agg_result, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _STRING_TO_JSVAL_IMPL4413($1, $str);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout4416($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function _JSVAL_IS_INT4323($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_INT32_IMPL4445($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_INT4324($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_INT32_IMPL4444($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_DOUBLE4325($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $tmp$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = (tempDoubleI32[0] = HEAP32[$_0 >> 2], tempDoubleI32[1] = $tmp$1, tempDoubleF64[0]);
  STACKTOP = __stackBase__;
  return $2;
}

function __Z17js_ConcatenateXMLP9JSContextP8JSObjectS2_PN2JS5ValueE($cx, $obj, $robj, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 0);
    if (($1 | 0) == 0) {
      var $ok_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    var $_idx2_val = HEAP32[$1 + 24 >> 2];
    var $6 = __ZNK8JSObject10getPrivateEv($_idx2_val);
    var $7 = $6;
    var $_idx1_val = HEAP32[$obj + 24 >> 2];
    var $9 = __ZNK8JSObject10getPrivateEv($_idx1_val);
    var $10 = $9;
    var $11 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $7, $10);
    if (($11 | 0) == 0) {
      var $ok_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$robj + 24 >> 2];
    var $15 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $16 = $15;
    var $17 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $7, $16);
    if (($17 | 0) == 0) {
      var $ok_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value9setObjectER8JSObject($vp, $4);
    var $ok_0 = $17;
    __label__ = 5;
    break;
   case 5:
    var $ok_0;
    return $ok_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, $xml_class) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $root = __stackBase__;
    var $1 = __Z9js_NewXMLP9JSContext10JSXMLClass($cx, $xml_class);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js13AutoXMLRooterC1EP9JSContextP5JSXML($root, $cx, $1);
    var $4 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $1);
    __ZN2js13AutoXMLRooterD1Ev($root);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL6AppendP9JSContextP5JSXMLS2_($cx, $list, $xml) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $list + 24 | 0;
    var $2 = $1 | 0;
    var $3 = $1 | 0;
    var $4 = HEAPU32[$3 >> 2];
    var $5 = $xml + 16 | 0;
    if ((HEAP32[$5 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 2:
    var $9 = $xml + 24 | 0;
    var $_c2 = HEAP32[$xml + 40 >> 2];
    HEAP32[$list + 40 >> 2] = $_c2;
    var $_c3 = HEAP32[$xml + 44 >> 2];
    HEAP32[$list + 44 >> 2] = $_c3;
    if (HEAPU32[$5 >> 2] >>> 0 < 2) {
      __label__ = 3;
      break;
    } else {
      var $24 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $24 = HEAP32[$9 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $24;
    var $25 = $24 + $4 | 0;
    var $26 = __ZN10JSXMLArray11setCapacityEP9JSContextj($2, $cx, $25);
    if ($26) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 5:
    if (($24 | 0) == 0) {
      var $_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $28 = $9 | 0;
    var $29 = $xml + 32 | 0;
    var $30 = $list + 32 | 0;
    var $j_04 = 0;
    __label__ = 7;
    break;
   case 7:
    var $j_04;
    if ($j_04 >>> 0 < HEAPU32[$28 >> 2] >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 8:
    var $36 = HEAPU32[HEAP32[$29 >> 2] + ($j_04 << 2) >> 2];
    if (($36 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $40 = $j_04 + $4 | 0;
    if (HEAPU32[$3 >> 2] >>> 0 > $40 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    HEAP32[$3 >> 2] = $40 + 1 | 0;
    __label__ = 11;
    break;
   case 11:
    var $46 = HEAP32[$30 >> 2] + ($40 << 2) | 0;
    HEAP32[$46 >> 2] = $36;
    __label__ = 12;
    break;
   case 12:
    var $47 = $j_04 + 1 | 0;
    if (($47 | 0) == ($24 | 0)) {
      var $_0 = 1;
      __label__ = 17;
      break;
    } else {
      var $j_04 = $47;
      __label__ = 7;
      break;
    }
   case 13:
    var $_c = HEAP32[$xml + 8 >> 2];
    HEAP32[$list + 40 >> 2] = $_c;
    if ((HEAP32[$5 >> 2] | 0) == 3) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    HEAP32[$list + 44 >> 2] = 0;
    __label__ = 16;
    break;
   case 15:
    var $_c1 = HEAP32[$xml + 12 >> 2];
    HEAP32[$list + 44 >> 2] = $_c1;
    __label__ = 16;
    break;
   case 16:
    var $61 = $xml;
    var $62 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $2, $4, $61);
    var $_0 = ($62 | 0) != 0 & 1;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL6AppendP9JSContextP5JSXMLS2_["X"] = 1;

function __ZL12xml_finalizeP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $2 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    if ((HEAP32[$5 >> 2] | 0) == ($obj | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[$5 >> 2] = 0;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9xml_traceP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $2 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $trc;
    _JS_CallTracer($5, $2, 3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18xml_lookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $id, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $funid = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $3 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $4 = $3;
    var $5 = __Z12js_IdIsIndexiPj($id, $i);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$i >> 2];
    var $9 = __ZL18HasIndexedPropertyP5JSXMLj($4, $8);
    var $found_0 = $9;
    __label__ = 7;
    break;
   case 3:
    __ZN2jsL9IdToJsvalEi4431($1, $id);
    var $_idx1 = $1 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $11 = __ZL9ToXMLNameP9JSContextN2JS5ValueEPi($cx, $_idx1_val$0, $_idx1_val$1, $funid);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = HEAP32[$funid >> 2];
    var $15 = _JSID_IS_VOID4359($14);
    if (($15 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $18 = $cx;
    var $19 = $obj;
    var $20 = $objp;
    var $21 = $propp;
    var $22 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($18, $19, $14, $20, $21);
    var $_0 = $22;
    __label__ = 11;
    break;
   case 6:
    var $24 = __ZL16HasNamedPropertyP5JSXMLP8JSObject($4, $11);
    var $found_0 = $24;
    __label__ = 7;
    break;
   case 7:
    var $found_0;
    if (($found_0 | 0) == 0) {
      var $storemerge = 0;
      var $storemerge1 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $28 = $cx;
    var $29 = $obj;
    var $30 = __Z20js_AddNativePropertyP9JSContextP8JSObjectiPFiS0_S2_iPN2JS5ValueEEPFiS0_S2_iiS5_Ejjji($28, $29, $id);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $storemerge = $30;
    var $storemerge1 = $obj;
    __label__ = 10;
    break;
   case 10:
    var $storemerge1;
    var $storemerge;
    HEAP32[$objp >> 2] = $storemerge1;
    HEAP32[$propp >> 2] = $storemerge;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18xml_lookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty["X"] = 1;

function __ZL17xml_lookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty($cx, $obj, $index, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $2 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $3 = $2;
    var $4 = __ZL18HasIndexedPropertyP5JSXMLj($3, $index);
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$objp >> 2] = 0;
    HEAP32[$propp >> 2] = 0;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $8 = $cx;
    var $9 = __ZN2js9IndexToIdEP9JSContextjPi($8, $index, $id);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $11 = HEAP32[$id >> 2];
    var $12 = $cx;
    var $13 = $obj;
    var $14 = __Z20js_AddNativePropertyP9JSContextP8JSObjectiPFiS0_S2_iPN2JS5ValueEEPFiS0_S2_iiS5_Ejjji($12, $13, $11);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$objp >> 2] = $obj;
    var $17 = $14;
    HEAP32[$propp >> 2] = $17;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17xml_lookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty($cx, $obj, $sid, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE4414($sid_idx_val);
  var $2 = __ZL18xml_lookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $1, $objp, $propp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL18xml_definePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $id, $v, $getter_coerce, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueE4442($v_idx_val$0, $v_idx_val$1);
    if (($getter_coerce | 0) == 0 & ($1 ^ 1) & ($setter | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    if (($attrs & 71 | 0) == 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $cx;
    var $9 = $obj;
    var $10 = $setter;
    var $11 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($8, $9, $id, $v, $getter_coerce, $10, $attrs);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 4:
    var $13 = $tmp | 0;
    HEAP32[$13 >> 2] = $v_idx_val$0;
    HEAP32[$13 + 4 >> 2] = $v_idx_val$1;
    var $14 = __ZL11PutPropertyP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, 0, $tmp);
    var $_0 = $14;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17xml_defineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $index, $v, $getter_coerce, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL18xml_definePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $4, $v, $getter_coerce, $setter, $attrs);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17xml_defineSpecialP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ej($cx, $obj, $sid, $v, $getter_coerce, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE4414($sid_idx_val);
  var $2 = __ZL18xml_definePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $1, $v, $getter_coerce, $setter, $attrs);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL14xml_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_DEFAULT_XML_NAMESPACE4441($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15xml_getPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom4336($1);
  var $3 = __ZL14xml_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $2, $vp);
  return $3;
}

function __ZL14xml_getElementP9JSContextP8JSObjectS2_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL14xml_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $4, $vp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14xml_getSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE4414($sid_idx_val);
  var $2 = __ZL14xml_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL15xml_setPropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var $1 = __ZL14xml_setGenericP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict);
  return $1;
}

function __ZL14xml_setElementP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL14xml_setGenericP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $4, $vp, $strict);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14xml_setSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE4414($sid_idx_val);
  var $2 = __ZL14xml_setGenericP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, $strict);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL17xml_getAttributesP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $found = __stackBase__;
    var $1 = __stackBase__ + 4;
    __ZN2jsL9IdToJsvalEi4431($1, $id);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $2 = __ZL11HasPropertyP9JSContextP8JSObjectN2JS5ValueEPi($cx, $obj, $_idx_val$0, $_idx_val$1, $found);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = (HEAP32[$found >> 2] | 0) != 0 & 1;
    HEAP32[$attrsp >> 2] = $7;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24xml_getElementAttributesP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL17xml_getAttributesP9JSContextP8JSObjectiPj($cx, $obj, $4, $attrsp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24xml_getSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE4414($sid_idx_val);
  var $2 = __ZL17xml_getAttributesP9JSContextP8JSObjectiPj($cx, $obj, $1, $attrsp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL17xml_setAttributesP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $found = __stackBase__;
    var $1 = __stackBase__ + 4;
    __ZN2jsL9IdToJsvalEi4431($1, $id);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $2 = __ZL11HasPropertyP9JSContextP8JSObjectN2JS5ValueEPi($cx, $obj, $_idx_val$0, $_idx_val$1, $found);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$found >> 2] | 0) == 0) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $cx;
    _JS_ReportErrorNumber($8, 4, 189, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24xml_setElementAttributesP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL17xml_setAttributesP9JSContextP8JSObjectiPj($cx, $obj, $4, $attrsp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24xml_setSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE4414($sid_idx_val);
  var $2 = __ZL17xml_setAttributesP9JSContextP8JSObjectiPj($cx, $obj, $1, $attrsp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL10xml_typeOfP9JSContextP8JSObject($cx, $obj) {
  return 7;
}

function __ZL7xml_fixP9JSContextP8JSObjectPbPN2js12AutoIdVectorE($cx, $obj, $success, $props) {
  HEAP8[$success] = 0;
  return 1;
}

function __ZL9xml_clearP9JSContextP8JSObject($cx, $obj) {
  return;
}

function __ZL18xml_deletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $funid = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    __ZN2jsL9IdToJsvalEi4431($1, $id);
    var $_03 = $1 | 0;
    var $tmp$0 = HEAP32[$_03 >> 2];
    var $tmp$1 = HEAP32[$_03 + 4 >> 2];
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $4 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $5 = $4;
    var $6 = __Z12js_IdIsIndexiPj($id, $index);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$4 + 16 >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2jsL9IdToValueEi4432($2, $id);
    var $_idx4 = $2 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    __ZL16ReportBadXMLNameP9JSContextRKN2JS5ValueE($cx, $_idx4_val$0, $_idx4_val$1);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 4:
    var $15 = HEAP32[$index >> 2];
    __ZL17DeleteListElementP9JSContextP5JSXMLj($5, $15);
    __label__ = 9;
    break;
   case 5:
    var $17 = __ZL9ToXMLNameP9JSContextN2JS5ValueEPi($cx, $tmp$0, $tmp$1, $funid);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = HEAP32[$funid >> 2];
    var $21 = _JSID_IS_VOID4359($20);
    if (($21 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $24 = $cx;
    var $25 = $obj;
    var $26 = __Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($24, $25, $20, $rval, 0);
    var $_0 = $26;
    __label__ = 12;
    break;
   case 8:
    var $_idx1_val = HEAP32[$17 + 4 >> 2];
    var $29 = __ZNK8JSObject8getClassEv($_idx1_val);
    var $31 = ($29 | 0) == (__ZN2js18AttributeNameClassE | 0) & 1;
    __ZL19DeleteNamedPropertyP9JSContextP5JSXMLP8JSObjecti($5, $17, $31);
    __label__ = 9;
    break;
   case 9:
    var $_idx2_val = HEAP32[$obj >> 2];
    var $33 = __ZNK8JSObject11nativeEmptyEv($_idx2_val);
    if ($33) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $35 = $cx;
    var $36 = $obj;
    var $37 = __Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($35, $36, $id, $rval, 0);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18xml_deletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi["X"] = 1;

function __ZL17xml_deleteElementP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $3 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if ((HEAP32[$3 + 16 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $index >>> 0;
    __ZN2JSL11DoubleValueEd4439($1, $9);
    var $_idx2 = $1 | 0;
    var $_idx2_val$0 = HEAP32[$_idx2 >> 2];
    var $_idx2_val$1 = HEAP32[$_idx2 + 4 >> 2];
    __ZL16ReportBadXMLNameP9JSContextRKN2JS5ValueE($cx, $_idx2_val$0, $_idx2_val$1);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 3:
    var $11 = $3;
    __ZL17DeleteListElementP9JSContextP5JSXMLj($11, $index);
    var $_idx1_val = HEAP32[$obj >> 2];
    var $12 = __ZNK8JSObject11nativeEmptyEv($_idx1_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $cx;
    var $15 = $obj;
    var $16 = __Z16js_DeleteElementP9JSContextP8JSObjectjPN2JS5ValueEi($14, $15, $index, $rval, 0);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17xml_deleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE4414($sid_idx_val);
  var $2 = __ZL18xml_deletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, $strict);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL13xml_enumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $2 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (HEAPU32[$2 + 16 >> 2] >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      var $12 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $12 = HEAP32[$2 + 24 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $12;
    if (($enum_op | 0) == 3) {
      __label__ = 4;
      break;
    } else if (($enum_op | 0) == 0 || ($enum_op | 0) == 1) {
      __label__ = 5;
      break;
    } else if (($enum_op | 0) == 2) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 21;
      break;
    }
   case 4:
    var $statep_idx3_phi_trans_insert = $statep | 0;
    var $st$1$0 = $statep_idx3_phi_trans_insert | 0;
    var $st$1$1 = $statep_idx3_phi_trans_insert + 4 | 0;
    var $statep_idx3_val$1 = HEAP32[$st$1$1 >> 2];
    var $statep_idx3_val$0 = HEAP32[$st$1$0 >> 2];
    __label__ = 17;
    break;
   case 5:
    if (($12 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2JS5Value8setInt32Ei($statep, 0);
    __label__ = 9;
    break;
   case 7:
    var $18 = $2 + 24 | 0;
    var $19 = __ZN9JSContext4new_I16JSXMLArrayCursorP10JSXMLArrayEEPT_T0_($cx, $18);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = $19;
    __ZN2JS5Value10setPrivateEPv($statep, $22);
    __label__ = 9;
    break;
   case 9:
    if (($idp | 0) == 0) {
      var $_0 = 1;
      __label__ = 21;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $26 = _INT_TO_JSID4434($12);
    HEAP32[$idp >> 2] = $26;
    var $_0 = 1;
    __label__ = 21;
    break;
   case 11:
    var $statep_idx2 = $statep | 0;
    var $st$1$0 = $statep_idx2 | 0;
    var $statep_idx2_val$0 = HEAPU32[$st$1$0 >> 2];
    var $st$1$1 = $statep_idx2 + 4 | 0;
    var $statep_idx2_val$1 = HEAPU32[$st$1$1 >> 2];
    var $28 = __ZNK2JS5Value7isInt32Ei($statep_idx2_val$0, $statep_idx2_val$1);
    if ($28) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    __ZN2JS5Value7setNullEv($statep);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 13:
    var $31 = __ZNK2JS5Value9toPrivateEv($statep_idx2_val$0, $statep_idx2_val$1);
    if (($31 | 0) == 0) {
      var $statep_idx3_val$1 = $statep_idx2_val$1;
      var $statep_idx3_val$0 = $statep_idx2_val$0;
      __label__ = 17;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    if ((HEAP32[$31 >> 2] | 0) == 0) {
      var $statep_idx3_val$1 = $statep_idx2_val$1;
      var $statep_idx3_val$0 = $statep_idx2_val$0;
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $39 = $31 + 4 | 0;
    var $40 = HEAPU32[$39 >> 2];
    if ($40 >>> 0 < $12 >>> 0) {
      __label__ = 16;
      break;
    } else {
      var $statep_idx3_val$1 = $statep_idx2_val$1;
      var $statep_idx3_val$0 = $statep_idx2_val$0;
      __label__ = 17;
      break;
    }
   case 16:
    var $43 = _INT_TO_JSID4434($40);
    HEAP32[$idp >> 2] = $43;
    HEAP32[$39 >> 2] = $40 + 1 | 0;
    var $_0 = 1;
    __label__ = 21;
    break;
   case 17:
    var $statep_idx3_val$0;
    var $statep_idx3_val$1;
    var $46 = __ZNK2JS5Value7isInt32Ei($statep_idx3_val$0, $statep_idx3_val$1);
    if ($46) {
      __label__ = 20;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $48 = __ZNK2JS5Value9toPrivateEv($statep_idx3_val$0, $statep_idx3_val$1);
    if (($48 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $51 = $48;
    __ZN9JSContext7delete_I16JSXMLArrayCursorEEvPT_($51);
    __label__ = 20;
    break;
   case 20:
    __ZN2JS5Value7setNullEv($statep);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13xml_enumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi["X"] = 1;

function __ZL16xml_addNamespaceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$2 + 16 >> 2] | 0) == 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $33 = HEAP32[$obj >> 2];
    var $_pre_phi = $vp | 0;
    __label__ = 10;
    break;
   case 4:
    var $11 = HEAP32[$obj >> 2];
    if ((HEAP32[$2 >> 2] | 0) == ($11 | 0)) {
      var $16 = $2;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $2, $11);
    var $16 = $14;
    __label__ = 6;
    break;
   case 6:
    var $16;
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = ($argc | 0) == 0 ? -1 : 1;
    var $21 = $vp + 16 | 0;
    var $22 = __ZL15NamespaceHelperP9JSContextP8JSObjectiPN2JS5ValueES5_($cx, 0, $20, $21, $vp);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $25 = $vp | 0;
    var $st$1$0 = $25 | 0;
    var $26$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $25 + 4 | 0;
    var $26$1 = HEAP32[$st$1$1 >> 2];
    var $27 = _JSVAL_TO_OBJECT4304($26$0, $26$1);
    var $28 = __ZL19AddInScopeNamespaceP9JSContextP5JSXMLP8JSObject($cx, $16, $27);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $$emscripten$temp$0 = _JSVAL_TRUE | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $31$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $31$1 = HEAP32[$st$1$1 >> 2];
    __ZN8JSObject20setNamespaceDeclaredEN2JS5ValueE($27, $31$0, $31$1);
    var $33 = $11;
    var $_pre_phi = $25;
    __label__ = 10;
    break;
   case 10:
    var $_pre_phi;
    var $33;
    _OBJECT_TO_JSVAL4318($1, $33);
    var $34 = $1 | 0;
    var $35$0 = HEAP32[$34 >> 2];
    var $35$1 = HEAP32[$34 + 4 >> 2];
    HEAP32[$_pre_phi >> 2] = $35$0;
    HEAP32[$_pre_phi + 4 >> 2] = $35$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16xml_addNamespaceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL15xml_appendChildP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $obj = __stackBase__ + 8;
    var $name = __stackBase__ + 12;
    var $1 = __stackBase__ + 16;
    var $2 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$obj >> 2];
    if ((HEAP32[$2 >> 2] | 0) == ($7 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $2, $7);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = __Z13js_GetAnyNameP9JSContextPi($cx, $name);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = HEAP32[$name >> 2];
    var $16 = __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $7, $15, $v);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = $v | 0;
    var $20$0 = HEAP32[$19 >> 2];
    var $20$1 = HEAP32[$19 + 4 >> 2];
    var $21 = _JSVAL_TO_OBJECT4304($20$0, $20$1);
    var $_idx_val = HEAP32[$21 + 24 >> 2];
    var $23 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $26 = HEAP32[$23 + 24 >> 2];
    var $27 = $cx;
    var $28 = __ZN2js9IndexToIdEP9JSContextjPi($27, $26, $name);
    if ($28) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    if (($argc | 0) == 0) {
      var $34 = _JSVAL_VOID;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $34 = $vp + 16 | 0;
    __label__ = 9;
    break;
   case 9:
    var $34;
    var $35 = $34;
    var $st$2$0 = $35 | 0;
    var $36$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $35 + 4 | 0;
    var $36$1 = HEAP32[$st$2$1 >> 2];
    var $37 = $vp | 0;
    HEAP32[$37 >> 2] = $36$0;
    HEAP32[$37 + 4 >> 2] = $36$1;
    var $38$0 = HEAP32[$19 >> 2];
    var $38$1 = HEAP32[$19 + 4 >> 2];
    var $39 = _JSVAL_TO_OBJECT4304($38$0, $38$1);
    var $40 = HEAP32[$name >> 2];
    var $41 = __ZL11PutPropertyP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $39, $40, 0, $vp);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    _OBJECT_TO_JSVAL4318($1, $7);
    var $44 = $1 | 0;
    var $st$2$0 = $44 | 0;
    var $45$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $44 + 4 | 0;
    var $45$1 = HEAP32[$st$2$1 >> 2];
    HEAP32[$37 >> 2] = $45$0;
    HEAP32[$37 + 4 >> 2] = $45$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15xml_appendChildP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL13xml_attributeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $cx;
    __Z19js_ReportMissingArgP9JSContextRKN2JS5ValueEj($4, $vp, 0);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 3:
    var $6 = $vp + 16 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = __ZL15ToAttributeNameP9JSContextN2JS5ValueE($cx, $7$0, $7$1);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _OBJECT_TO_JSVAL4318($1, $8);
    var $11 = $1 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    HEAP32[$6 >> 2] = $12$0;
    HEAP32[$6 + 4 >> 2] = $12$1;
    var $13 = $vp + 8 | 0;
    var $14 = $cx;
    var $15 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($14, $13);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = _OBJECT_TO_JSID4356($8);
    var $19 = $15;
    var $20 = __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $19, $18, $vp);
    var $_0 = $20;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14xml_attributesP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $tvr = __stackBase__ + 8;
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210412 >> 2] | 0;
    _STRING_TO_JSVAL4322($1, $6);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $7 = __ZL15ToAttributeNameP9JSContextN2JS5ValueE($cx, $_idx_val$0, $_idx_val$1);
    if (($7 | 0) == 0) {
      var $_1 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $cx;
    var $11 = $7;
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($tvr, $10, $11);
    var $12 = $vp + 8 | 0;
    var $13 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($10, $12);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = _OBJECT_TO_JSID4356($7);
    var $17 = $13;
    var $18 = __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $17, $16, $vp);
    var $_0 = $18;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js16AutoObjectRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 5;
    break;
   case 5:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9xml_childP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $cursor = __stackBase__ + 8;
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx2_val = HEAP32[$3 + 4 >> 2];
    var $7 = __ZNK8JSObject5isXMLEv($_idx2_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($2, $vp, __ZN2js8XMLClassE);
    var $_1 = 0;
    __label__ = 20;
    break;
   case 4:
    var $_idx1_val = HEAP32[$3 + 24 >> 2];
    var $10 = __ZNK8JSObject10getPrivateEv($_idx1_val);
    var $11 = $10;
    if (($10 | 0) == 0) {
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = ($argc | 0) == 0 ? _JSVAL_VOID : $vp + 16 | 0;
    var $_04 = $16 | 0;
    var $tmp$0 = HEAPU32[$_04 >> 2];
    var $tmp$1 = HEAPU32[$_04 + 4 >> 2];
    if ((HEAP32[$10 + 16 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 6:
    var $22 = __ZL15xml_list_helperP9JSContextP5JSXMLPN2JS5ValueE($cx, $11, $vp);
    if (($22 | 0) == 0) {
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $26 = $10 + 24 | 0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor, $26);
    var $27 = $v | 0;
    __label__ = 8;
    break;
   case 8:
    var $28 = __ZN16JSXMLArrayCursor7getNextEv($cursor);
    var $29 = $28;
    if (($28 | 0) == 0) {
      var $_0 = 1;
      __label__ = 15;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $29);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $35 = __ZL16xml_child_helperP9JSContextP8JSObjectP5JSXMLN2JS5ValueEPS6_($cx, $32, $29, $tmp$0, $tmp$1, $v);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $st$0$0 = $27 | 0;
    var $38$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $27 + 4 | 0;
    var $38$1 = HEAP32[$st$0$1 >> 2];
    var $39 = _JSVAL_IS_VOID4396($38$0, $38$1);
    if (($39 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 12:
    var $st$0$0 = $27 | 0;
    var $42$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $27 + 4 | 0;
    var $42$1 = HEAP32[$st$0$1 >> 2];
    var $43 = _JSVAL_TO_OBJECT4304($42$0, $42$1);
    var $_idx_val = HEAP32[$43 + 24 >> 2];
    var $45 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $46 = $45;
    if (HEAPU32[$45 + 16 >> 2] >>> 0 < 2) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    if ((HEAP32[$45 + 24 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $57 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $22, $46);
    if (($57 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 15:
    var $_0;
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_1 = $_0;
    __label__ = 20;
    break;
   case 16:
    var $61 = __ZL16xml_child_helperP9JSContextP8JSObjectP5JSXMLN2JS5ValueEPS6_($cx, $4, $11, $tmp$0, $tmp$1, $vp);
    if (($61 | 0) == 0) {
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $64 = $vp | 0;
    var $65$0 = HEAP32[$64 >> 2];
    var $65$1 = HEAP32[$64 + 4 >> 2];
    var $66 = _JSVAL_IS_VOID4396($65$0, $65$1);
    if (($66 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $69 = __ZL15xml_list_helperP9JSContextP5JSXMLPN2JS5ValueE($cx, $11, $vp);
    if (($69 | 0) == 0) {
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $_1 = 1;
    __label__ = 20;
    break;
   case 20:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9xml_childP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL14xml_childIndexP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $3 = __stackBase__ + 20;
    var $4 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAPU32[$4 + 8 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$4 + 16 >> 2] | 0) == 2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    _DOUBLE_TO_JSVAL4435($1, $15);
    var $16 = $1 | 0;
    var $st$3$0 = $16 | 0;
    var $17$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $16 + 4 | 0;
    var $17$1 = HEAP32[$st$3$1 >> 2];
    var $18 = $vp | 0;
    var $st$8$0 = $18 | 0;
    HEAP32[$st$8$0 >> 2] = $17$0;
    var $st$8$1 = $18 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $17$1;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 5:
    var $23 = $8 + 24 | 0;
    if (HEAPU32[$8 + 16 >> 2] >>> 0 < 2) {
      __label__ = 6;
      break;
    } else {
      var $26 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $26 = HEAP32[$23 >> 2];
    __label__ = 7;
    break;
   case 7:
    var $26;
    var $27 = $8 + 32 | 0;
    var $i_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $i_0;
    if ($i_0 >>> 0 < $26 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 9:
    if ($i_0 >>> 0 < HEAPU32[$23 >> 2] >>> 0) {
      __label__ = 10;
      break;
    } else {
      var $39 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $39 = HEAP32[HEAP32[$27 >> 2] + ($i_0 << 2) >> 2];
    __label__ = 11;
    break;
   case 11:
    var $39;
    if (($39 | 0) == ($4 | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 8;
    break;
   case 13:
    if (($i_0 | 0) > -1) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    _INT_TO_JSVAL4421($2, $i_0);
    var $46 = $2 | 0;
    var $47$0 = HEAP32[$46 >> 2];
    var $47$1 = HEAP32[$46 + 4 >> 2];
    var $48 = $vp | 0;
    HEAP32[$48 >> 2] = $47$0;
    HEAP32[$48 + 4 >> 2] = $47$1;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 15:
    _DOUBLE_TO_JSVAL4435($3, $i_0 >>> 0);
    var $51 = $3 | 0;
    var $st$3$0 = $51 | 0;
    var $52$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $51 + 4 | 0;
    var $52$1 = HEAP32[$st$3$1 >> 2];
    var $53 = $vp | 0;
    var $st$8$0 = $53 | 0;
    HEAP32[$st$8$0 >> 2] = $52$0;
    var $st$8$1 = $53 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $52$1;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14xml_childIndexP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL12xml_childrenP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $11 = HEAP32[HEAP32[$cx + 52 >> 2] + 210412 >> 2] | 0;
    var $12 = __ZL12ATOM_TO_JSIDP6JSAtom4336($11);
    var $13 = __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $6, $12, $vp);
    var $_0 = $13;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12xml_commentsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$3 + 4 >> 2];
    var $6 = __ZNK8JSObject5isXMLEv($_idx1_val);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($2, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    var $_idx_val = HEAP32[$3 + 24 >> 2];
    var $9 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $9;
    var $13 = __ZL19xml_comments_helperP9JSContextP8JSObjectP5JSXMLPN2JS5ValueE($cx, $12, $vp);
    var $_0 = $13;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12xml_containsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $value = __stackBase__;
    var $eq = __stackBase__ + 8;
    var $cursor = __stackBase__ + 12;
    var $1 = __stackBase__ + 32;
    var $2 = __stackBase__ + 40;
    var $3 = __stackBase__ + 48;
    var $4 = $vp + 8 | 0;
    var $5 = $cx;
    var $6 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($5, $4);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_1 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$6 + 4 >> 2];
    var $10 = __ZNK8JSObject5isXMLEv($_idx1_val);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($5, $vp, __ZN2js8XMLClassE);
    var $_1 = 0;
    __label__ = 18;
    break;
   case 4:
    var $_idx_val = HEAP32[$6 + 24 >> 2];
    var $13 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($13 | 0) == 0) {
      var $_1 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($argc | 0) == 0) {
      var $20 = _JSVAL_VOID;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = $vp + 16 | 0;
    __label__ = 7;
    break;
   case 7:
    var $20;
    var $21 = $20;
    var $st$2$0 = $21 | 0;
    var $22$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $21 + 4 | 0;
    var $22$1 = HEAP32[$st$2$1 >> 2];
    var $23 = $value | 0;
    HEAP32[$23 >> 2] = $22$0;
    HEAP32[$23 + 4 >> 2] = $22$1;
    if ((HEAP32[$13 + 16 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 8:
    HEAP32[$eq >> 2] = 0;
    var $30 = $13 + 24 | 0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor, $30);
    var $_idx3 = $1 | 0;
    __label__ = 9;
    break;
   case 9:
    var $32 = __ZN16JSXMLArrayCursor7getNextEv($cursor);
    if (($32 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $35 = $32;
    var $36 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $35);
    if (($36 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2JSL11ObjectValueER8JSObject4319($1, $36);
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    var $39 = __Z18js_TestXMLEqualityP9JSContextRKN2JS5ValueES4_Pi($cx, $_idx3_val$0, $_idx3_val$1, $value, $eq);
    if (($39 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[$eq >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    __label__ = 15;
    break;
   case 14:
    __ZN2JSL11ObjectValueER8JSObject4319($2, $7);
    var $_idx2 = $2 | 0;
    var $st$2$0 = $_idx2 | 0;
    var $_idx2_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx2 + 4 | 0;
    var $_idx2_val$1 = HEAP32[$st$2$1 >> 2];
    var $46 = __Z18js_TestXMLEqualityP9JSContextRKN2JS5ValueES4_Pi($cx, $_idx2_val$0, $_idx2_val$1, $value, $eq);
    if (($46 | 0) == 0) {
      var $_1 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $49 = HEAP32[$eq >> 2];
    _BOOLEAN_TO_JSVAL4415($3, $49);
    var $50 = $3 | 0;
    var $51$0 = HEAP32[$50 >> 2];
    var $51$1 = HEAP32[$50 + 4 >> 2];
    var $52 = $vp | 0;
    HEAP32[$52 >> 2] = $51$0;
    HEAP32[$52 + 4 >> 2] = $51$1;
    var $_1 = 1;
    __label__ = 18;
    break;
   case 16:
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_1 = 0;
    __label__ = 18;
    break;
   case 17:
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_1 = 0;
    __label__ = 18;
    break;
   case 18:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12xml_containsP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL8xml_copyP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $vp + 8 | 0;
    var $3 = $cx;
    var $4 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($3, $2);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$4 + 4 >> 2];
    var $7 = __ZNK8JSObject5isXMLEv($_idx1_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($3, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 4:
    var $_idx_val = HEAP32[$4 + 24 >> 2];
    var $10 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = $10;
    var $14 = __ZL8DeepCopyP9JSContextP5JSXMLP8JSObjectj($cx, $13, 0);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = HEAP32[$14 >> 2];
    _OBJECT_TO_JSVAL4318($1, $18);
    var $19 = $1 | 0;
    var $20$0 = HEAP32[$19 >> 2];
    var $20$1 = HEAP32[$19 + 4 >> 2];
    var $21 = $vp | 0;
    HEAP32[$21 >> 2] = $20$0;
    HEAP32[$21 + 4 >> 2] = $20$1;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15xml_descendantsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $vp + 8 | 0;
    var $4 = $cx;
    var $5 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($4, $3);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$5 + 4 >> 2];
    var $8 = __ZNK8JSObject5isXMLEv($_idx1_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($4, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 4:
    var $_idx_val = HEAP32[$5 + 24 >> 2];
    var $11 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $12 = $11;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($argc | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $21 = HEAP32[HEAP32[$cx + 52 >> 2] + 210412 >> 2] | 0;
    _STRING_TO_JSVAL4322($1, $21);
    var $_03_phi_trans_insert = $1 | 0;
    var $tmp$1 = HEAP32[$_03_phi_trans_insert + 4 >> 2];
    var $tmp$0 = HEAP32[$_03_phi_trans_insert >> 2];
    __label__ = 8;
    break;
   case 7:
    var $23 = $vp + 16 | 0;
    var $24$0 = HEAP32[$23 >> 2];
    var $24$1 = HEAP32[$23 + 4 >> 2];
    var $25 = $1 | 0;
    HEAP32[$25 >> 2] = $24$0;
    HEAP32[$25 + 4 >> 2] = $24$1;
    var $tmp$1 = $24$1;
    var $tmp$0 = $24$0;
    __label__ = 8;
    break;
   case 8:
    var $tmp$0;
    var $tmp$1;
    var $27 = __ZL11DescendantsP9JSContextP5JSXMLN2JS5ValueE($cx, $12, $tmp$0, $tmp$1);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $31 = HEAP32[$27 >> 2];
    _OBJECT_TO_JSVAL4318($2, $31);
    var $32 = $2 | 0;
    var $33$0 = HEAP32[$32 >> 2];
    var $33$1 = HEAP32[$32 + 4 >> 2];
    var $34 = $vp | 0;
    HEAP32[$34 >> 2] = $33$0;
    HEAP32[$34 + 4 >> 2] = $33$1;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15xml_descendantsP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL12xml_elementsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $funid = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = $vp + 8 | 0;
    var $3 = $cx;
    var $4 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($3, $2);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$4 + 4 >> 2];
    var $7 = __ZNK8JSObject5isXMLEv($_idx1_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($3, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 4:
    var $_idx_val = HEAP32[$4 + 24 >> 2];
    var $10 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $11 = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($argc | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210412 >> 2] | 0;
    _STRING_TO_JSVAL4322($1, $20);
    var $_03_phi_trans_insert = $1 | 0;
    var $tmp$1 = HEAP32[$_03_phi_trans_insert + 4 >> 2];
    var $tmp$0 = HEAP32[$_03_phi_trans_insert >> 2];
    __label__ = 8;
    break;
   case 7:
    var $22 = $vp + 16 | 0;
    var $23$0 = HEAP32[$22 >> 2];
    var $23$1 = HEAP32[$22 + 4 >> 2];
    var $24 = $1 | 0;
    HEAP32[$24 >> 2] = $23$0;
    HEAP32[$24 + 4 >> 2] = $23$1;
    var $tmp$1 = $23$1;
    var $tmp$0 = $23$0;
    __label__ = 8;
    break;
   case 8:
    var $tmp$0;
    var $tmp$1;
    var $26 = __ZL9ToXMLNameP9JSContextN2JS5ValueEPi($cx, $tmp$0, $tmp$1, $funid);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $29 = HEAP32[$funid >> 2];
    var $30 = _JSID_IS_VOID4359($29);
    if (($30 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $33 = __ZL15xml_list_helperP9JSContextP5JSXMLPN2JS5ValueE($cx, $11, $vp);
    var $_0 = ($33 | 0) != 0 & 1;
    __label__ = 12;
    break;
   case 11:
    var $37 = __ZL19xml_elements_helperP9JSContextP8JSObjectP5JSXMLS2_PN2JS5ValueE($cx, $11, $26, $vp);
    var $_0 = $37;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12xml_elementsP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL18xml_hasOwnPropertyP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $found = __stackBase__;
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $7 = __ZNK8JSObject5isXMLEv($_idx_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($2, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 4:
    var $12 = ($argc | 0) == 0 ? _JSVAL_VOID : $vp + 16 | 0;
    var $_03 = $12 | 0;
    var $tmp$0 = HEAP32[$_03 >> 2];
    var $tmp$1 = HEAP32[$_03 + 4 >> 2];
    var $13 = __ZL11HasPropertyP9JSContextP8JSObjectN2JS5ValueEPi($cx, $4, $tmp$0, $tmp$1, $found);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$found >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $$emscripten$temp$0 = _JSVAL_TRUE | 0;
    var $19$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $19$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $20 = $vp | 0;
    HEAP32[$20 >> 2] = $19$0;
    HEAP32[$20 + 4 >> 2] = $19$1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 7:
    var $22 = $cx;
    var $23 = __Z23js_HasOwnPropertyHelperP9JSContextPFiS0_P8JSObjectiPS2_PP10JSPropertyEjPN2JS5ValueE($22, 48, $argc, $vp);
    var $_0 = $23;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21xml_hasComplexContentP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx2_val = HEAP32[$3 + 4 >> 2];
    var $6 = __ZNK8JSObject5isXMLEv($_idx2_val);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($2, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 20;
    break;
   case 4:
    var $_idx1_val = HEAP32[$3 + 24 >> 2];
    var $9 = __ZNK8JSObject10getPrivateEv($_idx1_val);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      var $xml_0_in = $9;
      __label__ = 5;
      break;
    }
   case 5:
    var $xml_0_in;
    var $13 = HEAP32[$xml_0_in + 16 >> 2];
    if (($13 | 0) == 2 || ($13 | 0) == 5 || ($13 | 0) == 3 || ($13 | 0) == 4) {
      __label__ = 7;
      break;
    } else if (($13 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_pre6_pre_phi = $xml_0_in + 24 | 0;
    __label__ = 13;
    break;
   case 7:
    var $$emscripten$temp$0 = _JSVAL_FALSE | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $15$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $15$1 = HEAP32[$st$1$1 >> 2];
    var $16 = $vp | 0;
    var $st$6$0 = $16 | 0;
    HEAP32[$st$6$0 >> 2] = $15$0;
    var $st$6$1 = $16 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $15$1;
    var $_0 = 1;
    __label__ = 20;
    break;
   case 8:
    var $19 = $xml_0_in + 24 | 0;
    var $20 = HEAP32[$19 >> 2];
    if (($20 | 0) == 0) {
      __label__ = 9;
      break;
    } else if (($20 | 0) == 1) {
      __label__ = 10;
      break;
    } else {
      var $_pre6_pre_phi = $19;
      __label__ = 13;
      break;
    }
   case 9:
    var $$emscripten$temp$1 = _JSVAL_TRUE | 0;
    var $st$1$0 = $$emscripten$temp$1 | 0;
    var $22$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$1 + 4 | 0;
    var $22$1 = HEAP32[$st$1$1 >> 2];
    var $23 = $vp | 0;
    var $st$6$0 = $23 | 0;
    HEAP32[$st$6$0 >> 2] = $22$0;
    var $st$6$1 = $23 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $22$1;
    var $_pre_phi = $23;
    var $_pre_phi7 = $19;
    __label__ = 14;
    break;
   case 10:
    var $28 = HEAP32[HEAP32[$xml_0_in + 32 >> 2] >> 2];
    if (($28 | 0) == 0) {
      var $_pre6_pre_phi = $19;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $31 = $28;
    var $32 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $31);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $_idx_val = HEAP32[$32 + 24 >> 2];
    var $36 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $xml_0_in = $36;
    __label__ = 5;
    break;
   case 13:
    var $_pre6_pre_phi;
    var $_pre_phi = $vp | 0;
    var $_pre_phi7 = $_pre6_pre_phi;
    __label__ = 14;
    break;
   case 14:
    var $_pre_phi7;
    var $_pre_phi;
    var $$emscripten$temp$2 = _JSVAL_FALSE | 0;
    var $37$0 = HEAP32[$$emscripten$temp$2 >> 2];
    var $37$1 = HEAP32[$$emscripten$temp$2 + 4 >> 2];
    HEAP32[$_pre_phi >> 2] = $37$0;
    HEAP32[$_pre_phi + 4 >> 2] = $37$1;
    var $38 = HEAPU32[$_pre_phi7 >> 2];
    var $40 = $xml_0_in + 32 | 0;
    var $i_0 = 0;
    __label__ = 15;
    break;
   case 15:
    var $i_0;
    if ($i_0 >>> 0 < $38 >>> 0) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 1;
      __label__ = 20;
      break;
    }
   case 16:
    var $46 = HEAP32[HEAP32[$40 >> 2] + ($i_0 << 2) >> 2];
    if (($46 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    if ((HEAP32[$46 + 16 >> 2] | 0) == 1) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $$emscripten$temp$3 = _JSVAL_TRUE | 0;
    var $st$1$0 = $$emscripten$temp$3 | 0;
    var $54$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$3 + 4 | 0;
    var $54$1 = HEAP32[$st$1$1 >> 2];
    HEAP32[$_pre_phi >> 2] = $54$0;
    HEAP32[$_pre_phi + 4 >> 2] = $54$1;
    var $_0 = 1;
    __label__ = 20;
    break;
   case 19:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 15;
    break;
   case 20:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL21xml_hasComplexContentP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL20xml_hasSimpleContentP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $vp + 8 | 0;
    var $3 = $cx;
    var $4 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($3, $2);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$4 + 4 >> 2];
    var $7 = __ZNK8JSObject5isXMLEv($_idx1_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($3, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    var $_idx_val = HEAP32[$4 + 24 >> 2];
    var $10 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = $10;
    var $14 = __ZL16HasSimpleContentP5JSXML($13);
    _BOOLEAN_TO_JSVAL4415($1, $14);
    var $15 = $1 | 0;
    var $16$0 = HEAP32[$15 >> 2];
    var $16$1 = HEAP32[$15 + 4 >> 2];
    var $17 = $vp | 0;
    HEAP32[$17 >> 2] = $16$0;
    HEAP32[$17 + 4 >> 2] = $16$1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21xml_inScopeNamespacesP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $namespaces = __stackBase__ + 4;
    var $1 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js18AutoNamespaceArrayC1EP9JSContext($namespaces, $cx);
    var $4 = $namespaces + 12 | 0;
    var $5 = __ZL21FindInScopeNamespacesP9JSContextP5JSXMLP10JSXMLArray($cx, $1, $4);
    if (($5 | 0) == 0) {
      var $10 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZL19NamespacesToJSArrayP9JSContextP10JSXMLArrayPN2JS5ValueE($cx, $4, $vp);
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    var $11 = $10 & 1;
    __ZN2js18AutoNamespaceArrayD1Ev($namespaces);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20xml_insertChildAfterP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAPU32[$obj >> 2];
    _OBJECT_TO_JSVAL4318($1, $5);
    var $6 = $1 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $vp | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    if (HEAPU32[$2 + 16 >> 2] >>> 0 > 1 | ($argc | 0) == 0) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_06 = $vp + 16 | 0;
    var $tmp$0 = HEAPU32[$_06 >> 2];
    var $tmp$1 = HEAPU32[$_06 + 4 >> 2];
    var $14 = _JSVAL_IS_NULL4395($tmp$0, $tmp$1);
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $i_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $17 = _JSVAL_IS_PRIMITIVE4303($tmp$0, $tmp$1);
    if (($17 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 14;
      break;
    }
   case 5:
    var $20 = _JSVAL_TO_OBJECT4304($tmp$0, $tmp$1);
    var $_idx1_val = HEAP32[$20 + 4 >> 2];
    var $22 = __ZNK8JSObject5isXMLEv($_idx1_val);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 14;
      break;
    }
   case 6:
    var $24 = _JSVAL_TO_OBJECT4304($tmp$0, $tmp$1);
    var $_idx_val = HEAP32[$24 + 24 >> 2];
    var $26 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $_idx5_val = HEAP32[$2 + 24 >> 2];
    var $_idx6_val = HEAP32[$2 + 32 >> 2];
    var $27 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx5_val, $_idx6_val, $26, 0);
    if (($27 | 0) == -1) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $i_0 = $27 + 1 | 0;
    __label__ = 8;
    break;
   case 8:
    var $i_0;
    if ((HEAP32[$2 >> 2] | 0) == ($5 | 0)) {
      var $38 = $2;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $36 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $2, $5);
    var $38 = $36;
    __label__ = 10;
    break;
   case 10:
    var $38;
    if (($38 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    if ($argc >>> 0 > 1) {
      __label__ = 12;
      break;
    } else {
      var $45 = _JSVAL_VOID;
      __label__ = 13;
      break;
    }
   case 12:
    var $45 = $vp + 24 | 0;
    __label__ = 13;
    break;
   case 13:
    var $45;
    var $46 = $45;
    var $47$0 = HEAP32[$46 >> 2];
    var $47$1 = HEAP32[$46 + 4 >> 2];
    var $48 = __ZL6InsertP9JSContextP5JSXMLjN2JS5ValueE($cx, $38, $i_0, $47$0, $47$1);
    var $_0 = $48;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL20xml_insertChildAfterP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL21xml_insertChildBeforeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAPU32[$obj >> 2];
    _OBJECT_TO_JSVAL4318($1, $5);
    var $6 = $1 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $vp | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    if (HEAPU32[$2 + 16 >> 2] >>> 0 > 1 | ($argc | 0) == 0) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_06 = $vp + 16 | 0;
    var $tmp$0 = HEAPU32[$_06 >> 2];
    var $tmp$1 = HEAPU32[$_06 + 4 >> 2];
    var $14 = _JSVAL_IS_NULL4395($tmp$0, $tmp$1);
    if (($14 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $i_0 = HEAP32[$2 + 24 >> 2];
    __label__ = 8;
    break;
   case 5:
    var $20 = _JSVAL_IS_PRIMITIVE4303($tmp$0, $tmp$1);
    if (($20 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 14;
      break;
    }
   case 6:
    var $23 = _JSVAL_TO_OBJECT4304($tmp$0, $tmp$1);
    var $_idx1_val = HEAP32[$23 + 4 >> 2];
    var $25 = __ZNK8JSObject5isXMLEv($_idx1_val);
    if ($25) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 14;
      break;
    }
   case 7:
    var $27 = _JSVAL_TO_OBJECT4304($tmp$0, $tmp$1);
    var $_idx_val = HEAP32[$27 + 24 >> 2];
    var $29 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $_idx5_val = HEAP32[$2 + 24 >> 2];
    var $_idx6_val = HEAP32[$2 + 32 >> 2];
    var $30 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx5_val, $_idx6_val, $29, 0);
    if (($30 | 0) == -1) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      var $i_0 = $30;
      __label__ = 8;
      break;
    }
   case 8:
    var $i_0;
    if ((HEAP32[$2 >> 2] | 0) == ($5 | 0)) {
      var $39 = $2;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $37 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $2, $5);
    var $39 = $37;
    __label__ = 10;
    break;
   case 10:
    var $39;
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    if ($argc >>> 0 > 1) {
      __label__ = 12;
      break;
    } else {
      var $46 = _JSVAL_VOID;
      __label__ = 13;
      break;
    }
   case 12:
    var $46 = $vp + 24 | 0;
    __label__ = 13;
    break;
   case 13:
    var $46;
    var $47 = $46;
    var $48$0 = HEAP32[$47 >> 2];
    var $48$1 = HEAP32[$47 + 4 >> 2];
    var $49 = __ZL6InsertP9JSContextP5JSXMLjN2JS5ValueE($cx, $39, $i_0, $48$0, $48$1);
    var $_0 = $49;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL21xml_insertChildBeforeP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL10xml_lengthP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $vp + 8 | 0;
    var $4 = $cx;
    var $5 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($4, $3);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$5 + 4 >> 2];
    var $8 = __ZNK8JSObject5isXMLEv($_idx1_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($4, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 4:
    var $_idx_val = HEAP32[$5 + 24 >> 2];
    var $11 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$11 + 16 >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $$emscripten$temp$0 = _JSVAL_ONE | 0;
    var $19$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $19$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $20 = $vp | 0;
    HEAP32[$20 >> 2] = $19$0;
    HEAP32[$20 + 4 >> 2] = $19$1;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 7:
    var $24 = HEAPU32[$11 + 24 >> 2];
    if (($24 | 0) > -1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    _INT_TO_JSVAL4421($1, $24);
    var $27 = $1 | 0;
    var $28$0 = HEAP32[$27 >> 2];
    var $28$1 = HEAP32[$27 + 4 >> 2];
    var $29 = $vp | 0;
    HEAP32[$29 >> 2] = $28$0;
    HEAP32[$29 + 4 >> 2] = $28$1;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 9:
    var $31 = $24 >>> 0;
    _DOUBLE_TO_JSVAL4435($2, $31);
    var $32 = $2 | 0;
    var $33$0 = HEAP32[$32 >> 2];
    var $33$1 = HEAP32[$32 + 4 >> 2];
    var $34 = $vp | 0;
    HEAP32[$34 >> 2] = $33$0;
    HEAP32[$34 + 4 >> 2] = $33$1;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10xml_lengthP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL13xml_localNameP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$2 + 12 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZNK8JSObject20getQNameLocalNameValEv($1, $6);
    var $_phi_trans_insert = $1 | 0;
    var $13$1 = HEAP32[$_phi_trans_insert + 4 >> 2];
    var $13$0 = HEAP32[$_phi_trans_insert >> 2];
    __label__ = 5;
    break;
   case 4:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $10$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $10$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $11 = $1 | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $13$1 = $10$1;
    var $13$0 = $10$0;
    __label__ = 5;
    break;
   case 5:
    var $13$0;
    var $13$1;
    var $14 = $vp | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8xml_nameP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$2 + 12 >> 2];
    _OBJECT_TO_JSVAL4318($1, $6);
    var $7 = $1 | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $vp | 0;
    HEAP32[$9 >> 2] = $8$0;
    HEAP32[$9 + 4 >> 2] = $8$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13xml_namespaceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $inScopeNSes = __stackBase__ + 12;
    var $2 = __stackBase__ + 40;
    var $3 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    if ((HEAP32[$3 + 16 >> 2] - 1 | 0) >>> 0 < 3) {
      var $prefix_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $13$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $13$1 = HEAP32[$st$1$1 >> 2];
    var $14 = $vp | 0;
    var $st$6$0 = $14 | 0;
    HEAP32[$st$6$0 >> 2] = $13$0;
    var $st$6$1 = $14 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $13$1;
    var $_1 = 1;
    __label__ = 21;
    break;
   case 5:
    var $15 = $cx;
    var $_idx = $vp + 16 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $16 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($15, $_idx_val$0, $_idx_val$1);
    if (($16 | 0) == 0) {
      var $_1 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = $cx;
    var $20 = __ZN8JSString12ensureLinearEP9JSContext($16, $19);
    if (($20 | 0) == 0) {
      var $_1 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = $20 | 0;
    _STRING_TO_JSVAL4322($1, $23);
    var $24 = $1 | 0;
    var $st$3$0 = $24 | 0;
    var $25$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $24 + 4 | 0;
    var $25$1 = HEAP32[$st$3$1 >> 2];
    HEAP32[$_idx >> 2] = $25$0;
    HEAP32[$_idx + 4 >> 2] = $25$1;
    var $prefix_0 = $20;
    __label__ = 8;
    break;
   case 8:
    var $prefix_0;
    __ZN2js18AutoNamespaceArrayC1EP9JSContext($inScopeNSes, $cx);
    var $27 = $inScopeNSes + 12 | 0;
    var $28 = __ZL21FindInScopeNamespacesP9JSContextP5JSXMLP10JSXMLArray($cx, $3, $27);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (($prefix_0 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $34 = HEAP32[$3 + 12 >> 2];
    var $35 = __ZL12GetNamespaceP9JSContextP8JSObjectPK10JSXMLArray($cx, $34, $27);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      var $ns_22 = $35;
      __label__ = 18;
      break;
    }
   case 11:
    var $39 = HEAPU32[$27 >> 2];
    var $41 = HEAP32[$inScopeNSes + 20 >> 2];
    var $i_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $i_0;
    if ($i_0 >>> 0 < $39 >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 13:
    var $46 = HEAP32[$41 + ($i_0 << 2) >> 2];
    var $47 = $46;
    if (($46 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $50 = __ZNK8JSObject13getNamePrefixEv($47);
    if (($50 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $53 = __ZN2js12EqualStringsEP14JSLinearStringS1_($50, $prefix_0);
    if ($53) {
      var $ns_22 = $47;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 12;
    break;
   case 17:
    var $$emscripten$temp$1 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$1 | 0;
    var $55$0 = HEAPU32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$1 + 4 | 0;
    var $55$1 = HEAP32[$st$1$1 >> 2];
    var $56 = $2 | 0;
    var $st$6$0 = $56 | 0;
    HEAP32[$st$6$0 >> 2] = $55$0;
    var $st$6$1 = $56 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $55$1;
    var $58$1 = $55$1;
    var $58$0 = $55$0;
    __label__ = 19;
    break;
   case 18:
    var $ns_22;
    _OBJECT_TO_JSVAL4318($2, $ns_22);
    var $_phi_trans_insert = $2 | 0;
    var $st$3$0 = $_phi_trans_insert | 0;
    var $st$3$1 = $_phi_trans_insert + 4 | 0;
    var $58$1 = HEAP32[$st$3$1 >> 2];
    var $58$0 = HEAP32[$st$3$0 >> 2];
    __label__ = 19;
    break;
   case 19:
    var $58$0;
    var $58$1;
    var $59 = $vp | 0;
    var $st$3$0 = $59 | 0;
    HEAP32[$st$3$0 >> 2] = $58$0;
    var $st$3$1 = $59 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $58$1;
    var $_0 = 1;
    __label__ = 20;
    break;
   case 20:
    var $_0;
    __ZN2js18AutoNamespaceArrayD1Ev($inScopeNSes);
    var $_1 = $_0;
    __label__ = 21;
    break;
   case 21:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13xml_namespaceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL25xml_namespaceDeclarationsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $ancestors = __stackBase__ + 4;
    var $declared = __stackBase__ + 32;
    var $1 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($1 | 0) == 0) {
      var $_1 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (HEAPU32[$1 + 16 >> 2] >>> 0 > 1) {
      var $_1 = 1;
      __label__ = 22;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js18AutoNamespaceArrayC1EP9JSContext($ancestors, $cx);
    __ZN2js18AutoNamespaceArrayC1EP9JSContext($declared, $cx);
    var $8 = $ancestors + 12 | 0;
    var $9 = $8 | 0;
    var $_idx3 = $ancestors + 20 | 0;
    var $yml_0 = $1;
    __label__ = 4;
    break;
   case 4:
    var $yml_0;
    var $11 = HEAP32[$yml_0 + 8 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = $11 + 40 | 0;
    var $15 = HEAPU32[$14 >> 2];
    var $16 = $11 + 48 | 0;
    var $i_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $i_0;
    if ($i_0 >>> 0 < $15 >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $yml_0 = $11;
      __label__ = 4;
      break;
    }
   case 7:
    if ($i_0 >>> 0 < HEAPU32[$14 >> 2] >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $25 = HEAPU32[HEAP32[$16 >> 2] + ($i_0 << 2) >> 2];
    if (($25 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_idx2_val = HEAP32[$9 >> 2];
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $28 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx2_val, $_idx3_val, $25, 266);
    if (($28 | 0) == -1) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = HEAP32[$9 >> 2];
    var $32 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $8, $31, $25);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 6;
    break;
   case 12:
    var $36 = $1 + 40 | 0;
    var $37 = HEAPU32[$36 >> 2];
    var $38 = $1 + 48 | 0;
    var $39 = $declared + 12 | 0;
    var $40 = $39 | 0;
    var $_idx = $ancestors + 12 | 0;
    var $i1_0 = 0;
    __label__ = 13;
    break;
   case 13:
    var $i1_0;
    if ($i1_0 >>> 0 < $37 >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 14:
    if ($i1_0 >>> 0 < HEAPU32[$36 >> 2] >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 15:
    var $49 = HEAPU32[HEAP32[$38 >> 2] + ($i1_0 << 2) >> 2];
    if (($49 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $52 = $49;
    var $53 = __ZL10IsDeclaredPK8JSObject($52);
    if (($53 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $_idx_val = HEAP32[$_idx >> 2];
    var $_idx1_val = HEAP32[$_idx3 >> 2];
    var $56 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx_val, $_idx1_val, $49, 266);
    if (($56 | 0) == -1) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $59 = HEAP32[$40 >> 2];
    var $60 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $39, $59, $49);
    if (($60 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 13;
    break;
   case 20:
    var $64 = __ZL19NamespacesToJSArrayP9JSContextP10JSXMLArrayPN2JS5ValueE($cx, $39, $vp);
    var $_0 = $64 & 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    __ZN2js18AutoNamespaceArrayD1Ev($declared);
    __ZN2js18AutoNamespaceArrayD1Ev($ancestors);
    var $_1 = $_0;
    __label__ = 22;
    break;
   case 22:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL25xml_namespaceDeclarationsP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL12xml_nodeKindP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[_js_xml_class_str + (HEAP32[$2 + 16 >> 2] << 2) >> 2];
    var $9 = $cx;
    var $10 = _JS_InternString($9, $8);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _STRING_TO_JSVAL4322($1, $10);
    var $13 = $1 | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $vp | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13xml_normalizeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $vp + 8 | 0;
    var $3 = $cx;
    var $4 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($3, $2);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$4 + 4 >> 2];
    var $8 = __ZNK8JSObject5isXMLEv($_idx1_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($3, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    var $_idx_val = HEAP32[$4 + 24 >> 2];
    var $11 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = $11;
    _OBJECT_TO_JSVAL4318($1, $5);
    var $15 = $1 | 0;
    var $16$0 = HEAP32[$15 >> 2];
    var $16$1 = HEAP32[$15 + 4 >> 2];
    var $17 = $vp | 0;
    HEAP32[$17 >> 2] = $16$0;
    HEAP32[$17 + 4 >> 2] = $16$1;
    var $18 = __ZL20xml_normalize_helperP9JSContextP8JSObjectP5JSXML($cx, $5, $14);
    var $_0 = $18;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10xml_parentP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $vp + 8 | 0;
    var $3 = $cx;
    var $4 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($3, $2);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$4 + 4 >> 2];
    var $7 = __ZNK8JSObject5isXMLEv($_idx1_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($3, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 17;
    break;
   case 4:
    var $_idx_val = HEAP32[$4 + 24 >> 2];
    var $10 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = HEAP32[$10 + 8 >> 2];
    if ((HEAP32[$10 + 16 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $parent_0 = $15;
      __label__ = 13;
      break;
    }
   case 6:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $21$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $21$1 = HEAP32[$st$1$1 >> 2];
    var $22 = $vp | 0;
    var $st$6$0 = $22 | 0;
    HEAP32[$st$6$0 >> 2] = $21$0;
    var $st$6$1 = $22 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $21$1;
    var $25 = HEAPU32[$10 + 24 >> 2];
    if (($25 | 0) == 0) {
      var $_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $30 = HEAPU32[$10 + 32 >> 2];
    var $31 = HEAP32[$30 >> 2];
    if (($31 | 0) == 0) {
      var $_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $36 = HEAP32[$31 + 8 >> 2];
    var $i_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $i_0;
    if ($i_0 >>> 0 < $25 >>> 0) {
      __label__ = 10;
      break;
    } else {
      var $parent_0 = $36;
      __label__ = 13;
      break;
    }
   case 10:
    var $41 = HEAPU32[$30 + ($i_0 << 2) >> 2];
    if (($41 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    if ((HEAP32[$41 + 8 >> 2] | 0) == ($36 | 0)) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 1;
      __label__ = 17;
      break;
    }
   case 12:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 9;
    break;
   case 13:
    var $parent_0;
    if (($parent_0 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $$emscripten$temp$1 = _JSVAL_NULL | 0;
    var $st$1$0 = $$emscripten$temp$1 | 0;
    var $51$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$1 + 4 | 0;
    var $51$1 = HEAP32[$st$1$1 >> 2];
    var $52 = $vp | 0;
    var $st$6$0 = $52 | 0;
    HEAP32[$st$6$0 >> 2] = $51$0;
    var $st$6$1 = $52 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $51$1;
    var $_0 = 1;
    __label__ = 17;
    break;
   case 15:
    var $54 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $parent_0);
    if (($54 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    _OBJECT_TO_JSVAL4318($1, $54);
    var $57 = $1 | 0;
    var $58$0 = HEAP32[$57 >> 2];
    var $58$1 = HEAP32[$57 + 4 >> 2];
    var $59 = $vp | 0;
    HEAP32[$59 >> 2] = $58$0;
    HEAP32[$59 + 4 >> 2] = $58$1;
    var $_0 = 1;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10xml_parentP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL26xml_processingInstructionsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $funid = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $3 = $vp + 8 | 0;
    var $4 = $cx;
    var $5 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($4, $3);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$5 + 4 >> 2];
    var $8 = __ZNK8JSObject5isXMLEv($_idx1_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($4, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 4:
    var $_idx_val = HEAP32[$5 + 24 >> 2];
    var $11 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $12 = $11;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($argc | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $21 = HEAP32[HEAP32[$cx + 52 >> 2] + 210412 >> 2] | 0;
    _STRING_TO_JSVAL4322($1, $21);
    var $_03_phi_trans_insert = $1 | 0;
    var $st$7$0 = $_03_phi_trans_insert | 0;
    var $st$7$1 = $_03_phi_trans_insert + 4 | 0;
    var $tmp$1 = HEAP32[$st$7$1 >> 2];
    var $tmp$0 = HEAP32[$st$7$0 >> 2];
    __label__ = 8;
    break;
   case 7:
    var $23 = $vp + 16 | 0;
    var $24$0 = HEAP32[$23 >> 2];
    var $24$1 = HEAP32[$23 + 4 >> 2];
    var $25 = $1 | 0;
    HEAP32[$25 >> 2] = $24$0;
    HEAP32[$25 + 4 >> 2] = $24$1;
    var $tmp$1 = $24$1;
    var $tmp$0 = $24$0;
    __label__ = 8;
    break;
   case 8:
    var $tmp$0;
    var $tmp$1;
    var $27 = __ZL9ToXMLNameP9JSContextN2JS5ValueEPi($cx, $tmp$0, $tmp$1, $funid);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    _OBJECT_TO_JSVAL4318($2, $27);
    var $30 = $2 | 0;
    var $31$0 = HEAP32[$30 >> 2];
    var $31$1 = HEAP32[$30 + 4 >> 2];
    var $32 = $vp + 16 | 0;
    var $st$7$0 = $32 | 0;
    HEAP32[$st$7$0 >> 2] = $31$0;
    var $st$7$1 = $32 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $31$1;
    var $33 = HEAP32[$funid >> 2];
    var $34 = _JSID_IS_VOID4359($33);
    if (($34 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $37 = __ZL15xml_list_helperP9JSContextP5JSXMLPN2JS5ValueE($cx, $12, $vp);
    var $_0 = ($37 | 0) != 0 & 1;
    __label__ = 12;
    break;
   case 11:
    var $41 = __ZL33xml_processingInstructions_helperP9JSContextP8JSObjectP5JSXMLS2_PN2JS5ValueE($cx, $12, $27, $vp);
    var $_0 = $41;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL26xml_processingInstructionsP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL16xml_prependChildP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$obj >> 2];
    if ((HEAP32[$2 >> 2] | 0) == ($7 | 0)) {
      var $12 = $2;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $2, $7);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      var $12 = $10;
      __label__ = 4;
      break;
    }
   case 4:
    var $12;
    _OBJECT_TO_JSVAL4318($1, $7);
    var $13 = $1 | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $vp | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    if (($argc | 0) == 0) {
      var $20 = _JSVAL_VOID;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = $vp + 16 | 0;
    __label__ = 6;
    break;
   case 6:
    var $20;
    var $21 = $20;
    var $22$0 = HEAP32[$21 >> 2];
    var $22$1 = HEAP32[$21 + 4 >> 2];
    var $23 = __ZL6InsertP9JSContextP5JSXMLjN2JS5ValueE($cx, $12, 0, $22$0, $22$1);
    var $_0 = $23;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24xml_propertyIsEnumerableP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $isIndex = __stackBase__;
    var $index = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = $vp + 8 | 0;
    var $4 = $cx;
    var $5 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($4, $3);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$5 + 4 >> 2];
    var $8 = __ZNK8JSObject5isXMLEv($_idx1_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($4, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 4:
    var $_idx_val = HEAP32[$5 + 24 >> 2];
    var $11 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $$emscripten$temp$0 = _JSVAL_FALSE | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $14$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $14$1 = HEAP32[$st$1$1 >> 2];
    var $15 = $vp | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    if (($argc | 0) == 0) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = $vp + 16 | 0;
    var $st$1$0 = $18 | 0;
    var $19$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $18 + 4 | 0;
    var $19$1 = HEAP32[$st$1$1 >> 2];
    var $20 = __ZL12IdValIsIndexP9JSContextN2JS5ValueEPjPb($cx, $19$0, $19$1, $index, $isIndex);
    if ($20) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    if ((HEAP8[$isIndex] & 1) << 24 >> 24 == 0) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $30 = HEAPU32[$index >> 2];
    if ((HEAP32[$11 + 16 >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $36 = $30 >>> 0 < HEAPU32[$11 + 24 >> 2] >>> 0 & 1;
    _BOOLEAN_TO_JSVAL4415($1, $36);
    var $37 = $1 | 0;
    var $38$0 = HEAP32[$37 >> 2];
    var $38$1 = HEAP32[$37 + 4 >> 2];
    HEAP32[$15 >> 2] = $38$0;
    HEAP32[$15 + 4 >> 2] = $38$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 10:
    var $41 = ($30 | 0) == 0 & 1;
    _BOOLEAN_TO_JSVAL4415($2, $41);
    var $42 = $2 | 0;
    var $43$0 = HEAP32[$42 >> 2];
    var $43$1 = HEAP32[$42 + 4 >> 2];
    HEAP32[$15 >> 2] = $43$0;
    HEAP32[$15 + 4 >> 2] = $43$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL24xml_propertyIsEnumerableP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL19xml_removeNamespaceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$2 + 16 >> 2] | 0) == 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $29 = HEAP32[$obj >> 2];
    var $_pre_phi = $vp | 0;
    __label__ = 9;
    break;
   case 4:
    var $11 = HEAP32[$obj >> 2];
    if ((HEAP32[$2 >> 2] | 0) == ($11 | 0)) {
      var $16 = $2;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $2, $11);
    var $16 = $14;
    __label__ = 6;
    break;
   case 6:
    var $16;
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = ($argc | 0) == 0 ? -1 : 1;
    var $21 = $vp + 16 | 0;
    var $22 = __ZL15NamespaceHelperP9JSContextP8JSObjectiPN2JS5ValueES5_($cx, 0, $20, $21, $vp);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $25 = $vp | 0;
    var $26$0 = HEAP32[$25 >> 2];
    var $26$1 = HEAP32[$25 + 4 >> 2];
    var $27 = _JSVAL_TO_OBJECT4304($26$0, $26$1);
    __ZL26xml_removeNamespace_helperP9JSContextP5JSXMLP8JSObject($cx, $16, $27);
    var $29 = $11;
    var $_pre_phi = $25;
    __label__ = 9;
    break;
   case 9:
    var $_pre_phi;
    var $29;
    _OBJECT_TO_JSVAL4318($1, $29);
    var $30 = $1 | 0;
    var $31$0 = HEAP32[$30 >> 2];
    var $31$1 = HEAP32[$30 + 4 >> 2];
    HEAP32[$_pre_phi >> 2] = $31$0;
    HEAP32[$_pre_phi + 4 >> 2] = $31$1;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19xml_removeNamespaceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL11xml_replaceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $obj = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $haveIndex = __stackBase__ + 24;
    var $3 = __stackBase__ + 28;
    var $4 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$4 + 16 >> 2] | 0) == 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $92 = HEAP32[$obj >> 2];
    __label__ = 31;
    break;
   case 4:
    if ($argc >>> 0 < 2) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $17 = HEAP32[HEAP32[$cx + 52 >> 2] + 209984 >> 2] | 0;
    _STRING_TO_JSVAL4322($1, $17);
    var $value_0_0_0_in = $1 | 0;
    __label__ = 12;
    break;
   case 6:
    var $19 = $vp + 24 | 0;
    var $_011 = $19 | 0;
    var $tmp12$0 = HEAPU32[$_011 >> 2];
    var $tmp12$1 = HEAPU32[$_011 + 4 >> 2];
    var $20 = _JSVAL_IS_PRIMITIVE4303($tmp12$0, $tmp12$1);
    if (($20 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $23 = _JSVAL_TO_OBJECT4304($tmp12$0, $tmp12$1);
    var $_idx1_val = HEAP32[$23 + 4 >> 2];
    var $25 = __ZNK8JSObject5isXMLEv($_idx1_val);
    if ($25) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $27 = _JSVAL_TO_OBJECT4304($tmp12$0, $tmp12$1);
    var $_idx_val = HEAP32[$27 + 24 >> 2];
    var $29 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($29 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $31 = $cx;
    var $32 = _JS_ConvertValue($31, $tmp12$0, $tmp12$1, 3, $19);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      var $value_0_0_0_in = $_011;
      __label__ = 12;
      break;
    }
   case 10:
    var $35 = $29;
    var $36 = __ZL8DeepCopyP9JSContextP5JSXMLP8JSObjectj($cx, $35, 0);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $40 = HEAP32[$36 >> 2];
    _OBJECT_TO_JSVAL4318($2, $40);
    var $41 = $2 | 0;
    var $42$0 = HEAP32[$41 >> 2];
    var $42$1 = HEAP32[$41 + 4 >> 2];
    var $st$8$0 = $_011 | 0;
    HEAP32[$st$8$0 >> 2] = $42$0;
    var $st$8$1 = $_011 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $42$1;
    var $value_0_0_0_in = $_011;
    __label__ = 12;
    break;
   case 12:
    var $value_0_0_0_in;
    var $st$1$0 = $value_0_0_0_in | 0;
    var $value_0_0_0$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $value_0_0_0_in + 4 | 0;
    var $value_0_0_0$1 = HEAP32[$st$1$1 >> 2];
    var $45 = HEAPU32[$obj >> 2];
    if ((HEAP32[$4 >> 2] | 0) == ($45 | 0)) {
      var $50 = $4;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $48 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $4, $45);
    var $50 = $48;
    __label__ = 14;
    break;
   case 14:
    var $50;
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $53 = ($argc | 0) == 0;
    if ($53) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    HEAP8[$haveIndex] = 0;
    __label__ = 20;
    break;
   case 17:
    var $55 = $vp + 16 | 0;
    var $st$1$0 = $55 | 0;
    var $56$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $55 + 4 | 0;
    var $56$1 = HEAP32[$st$1$1 >> 2];
    var $57 = __ZL12IdValIsIndexP9JSContextN2JS5ValueEPjPb($cx, $56$0, $56$1, $index, $haveIndex);
    if ($57) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 32;
      break;
    }
   case 18:
    if ((HEAP8[$haveIndex] & 1) << 24 >> 24 == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $89 = HEAP32[$index >> 2];
    __label__ = 30;
    break;
   case 20:
    var $60 = $53 ? -1 : 1;
    var $61 = $vp + 16 | 0;
    var $62 = __ZL11QNameHelperP9JSContextP8JSObjectiPN2JS5ValueES5_($cx, 0, $60, $61, $vp);
    if (($62 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $65 = $vp | 0;
    var $st$1$0 = $65 | 0;
    var $66$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $65 + 4 | 0;
    var $66$1 = HEAP32[$st$1$1 >> 2];
    var $67 = _JSVAL_TO_OBJECT4304($66$0, $66$1);
    var $68 = $50 + 24 | 0;
    var $69 = HEAP32[$68 >> 2];
    HEAP32[$index >> 2] = -1;
    if (($69 | 0) == 0) {
      var $92 = $45;
      __label__ = 31;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $71 = $50 + 32 | 0;
    var $i_028 = $69;
    var $_pr9 = -1;
    var $73 = $69;
    __label__ = 23;
    break;
   case 23:
    var $73;
    var $_pr9;
    var $i_028;
    var $74 = $i_028 - 1 | 0;
    if ($74 >>> 0 < $73 >>> 0) {
      __label__ = 24;
      break;
    } else {
      var $_pr = $_pr9;
      __label__ = 27;
      break;
    }
   case 24:
    var $79 = HEAP32[HEAP32[$71 >> 2] + ($74 << 2) >> 2];
    if (($79 | 0) == 0) {
      var $_pr = $_pr9;
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $82 = $79;
    var $83 = __ZL13MatchElemNameP8JSObjectP5JSXML($67, $82);
    if (($83 | 0) == 0) {
      var $_pr = $_pr9;
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    __ZL13DeleteByIndexP9JSContextP5JSXMLj($50, $74);
    HEAP32[$index >> 2] = $74;
    var $_pr = $74;
    __label__ = 27;
    break;
   case 27:
    var $_pr;
    if (($74 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $i_028 = $74;
    var $_pr9 = $_pr;
    var $73 = HEAP32[$68 >> 2];
    __label__ = 23;
    break;
   case 29:
    if (($_pr | 0) == -1) {
      var $92 = $45;
      __label__ = 31;
      break;
    } else {
      var $89 = $_pr;
      __label__ = 30;
      break;
    }
   case 30:
    var $89;
    var $90 = __ZL7ReplaceP9JSContextP5JSXMLjN2JS5ValueE($cx, $50, $89, $value_0_0_0$0, $value_0_0_0$1);
    if (($90 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      var $92 = $45;
      __label__ = 31;
      break;
    }
   case 31:
    var $92;
    _OBJECT_TO_JSVAL4318($3, $92);
    var $93 = $3 | 0;
    var $94$0 = HEAP32[$93 >> 2];
    var $94$1 = HEAP32[$93 + 4 >> 2];
    var $95 = $vp | 0;
    var $st$8$0 = $95 | 0;
    HEAP32[$st$8$0 >> 2] = $94$0;
    var $st$8$1 = $95 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $94$1;
    var $_0 = 1;
    __label__ = 32;
    break;
   case 32:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11xml_replaceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL15xml_setChildrenP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($argc | 0) == 0) {
      var $9 = _JSVAL_VOID;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $vp + 16 | 0;
    __label__ = 4;
    break;
   case 4:
    var $9;
    var $10 = $9;
    var $st$2$0 = $10 | 0;
    var $11$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $10 + 4 | 0;
    var $11$1 = HEAP32[$st$2$1 >> 2];
    var $12 = $vp | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    var $13 = HEAP32[$obj >> 2];
    var $18 = HEAP32[HEAP32[$cx + 52 >> 2] + 210412 >> 2] | 0;
    var $19 = __ZL12ATOM_TO_JSIDP6JSAtom4336($18);
    var $20 = __ZL11PutPropertyP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $13, $19, 0, $vp);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _OBJECT_TO_JSVAL4318($1, $13);
    var $23 = $1 | 0;
    var $st$2$0 = $23 | 0;
    var $24$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $23 + 4 | 0;
    var $24$1 = HEAP32[$st$2$1 >> 2];
    HEAP32[$12 >> 2] = $24$0;
    HEAP32[$12 + 4 >> 2] = $24$1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16xml_setLocalNameP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $namestr = __stackBase__ + 4;
    var $1 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$1 + 16 >> 2] - 1 | 0) >>> 0 < 3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $9$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $9$1 = HEAP32[$st$1$1 >> 2];
    var $10 = $vp | 0;
    var $st$6$0 = $10 | 0;
    HEAP32[$st$6$0 >> 2] = $9$0;
    var $st$6$1 = $10 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $9$1;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 4:
    if (($argc | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $18 = HEAP32[HEAP32[$cx + 52 >> 2] + 209984 >> 2] | 0;
    HEAP32[$namestr >> 2] = $18;
    __label__ = 10;
    break;
   case 6:
    var $20 = $vp + 16 | 0;
    var $st$1$0 = $20 | 0;
    var $21$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $20 + 4 | 0;
    var $21$1 = HEAP32[$st$1$1 >> 2];
    var $22 = _JSVAL_IS_PRIMITIVE4303($21$0, $21$1);
    if (($22 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $25 = _JSVAL_TO_OBJECT4304($21$0, $21$1);
    var $_idx_val = HEAP32[$25 + 4 >> 2];
    var $26 = __ZNK8JSObject7isQNameEv($_idx_val);
    if ($26) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $28 = _JSVAL_TO_OBJECT4304($21$0, $21$1);
    var $29 = __ZNK8JSObject17getQNameLocalNameEv($28);
    HEAP32[$namestr >> 2] = $29;
    __label__ = 10;
    break;
   case 9:
    var $31 = $cx;
    var $32 = $namestr;
    var $33 = __Z14js_ValueToAtomP9JSContextRKN2JS5ValueEPP6JSAtom($31, $21$0, $21$1, $32);
    if ($33) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 10:
    var $37 = HEAP32[$obj >> 2];
    if ((HEAP32[$1 >> 2] | 0) == ($37 | 0)) {
      var $42 = $1;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $40 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $1, $37);
    var $42 = $40;
    __label__ = 12;
    break;
   case 12:
    var $42;
    if (($42 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $45 = HEAP32[$namestr >> 2];
    if (($45 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $49 = HEAP32[$42 + 12 >> 2];
    __ZN8JSObject17setQNameLocalNameEP6JSAtom($49, $45);
    __label__ = 15;
    break;
   case 15:
    var $$emscripten$temp$1 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$1 | 0;
    var $51$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$1 + 4 | 0;
    var $51$1 = HEAP32[$st$1$1 >> 2];
    var $52 = $vp | 0;
    var $st$6$0 = $52 | 0;
    HEAP32[$st$6$0 >> 2] = $51$0;
    var $st$6$1 = $52 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $51$1;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16xml_setLocalNameP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL11xml_setNameP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $name = __stackBase__;
    var $obj = __stackBase__ + 8;
    var $1 = __stackBase__ + 12;
    var $2 = __stackBase__ + 20;
    var $3 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + 16 | 0;
    if ((HEAP32[$6 >> 2] - 1 | 0) >>> 0 < 3) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 31;
      break;
    }
   case 3:
    if (($argc | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = HEAP32[HEAP32[$cx + 52 >> 2] + 209984 >> 2] | 0;
    _STRING_TO_JSVAL4322($1, $17);
    var $18 = $1 | 0;
    var $19$0 = HEAP32[$18 >> 2];
    var $19$1 = HEAP32[$18 + 4 >> 2];
    var $20 = $name | 0;
    HEAP32[$20 >> 2] = $19$0;
    HEAP32[$20 + 4 >> 2] = $19$1;
    __label__ = 9;
    break;
   case 5:
    var $22 = $vp + 16 | 0;
    var $st$1$0 = $22 | 0;
    var $23$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $22 + 4 | 0;
    var $23$1 = HEAP32[$st$1$1 >> 2];
    var $24 = $name | 0;
    var $st$6$0 = $24 | 0;
    HEAP32[$st$6$0 >> 2] = $23$0;
    var $st$6$1 = $24 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $23$1;
    var $25 = _JSVAL_IS_PRIMITIVE4303($23$0, $23$1);
    if (($25 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $st$0$0 = $24 | 0;
    var $28$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $24 + 4 | 0;
    var $28$1 = HEAP32[$st$0$1 >> 2];
    var $29 = _JSVAL_TO_OBJECT4304($28$0, $28$1);
    var $_idx_val = HEAP32[$29 + 4 >> 2];
    var $31 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($31 | 0) == (__ZN2js10QNameClassE | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $st$0$0 = $24 | 0;
    var $34$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $24 + 4 | 0;
    var $34$1 = HEAP32[$st$0$1 >> 2];
    var $35 = _JSVAL_TO_OBJECT4304($34$0, $34$1);
    var $36 = __ZNK8JSObject10getNameURIEv($35);
    if (($36 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    __ZNK8JSObject20getQNameLocalNameValEv($2, $35);
    var $39 = $2 | 0;
    var $40$0 = HEAP32[$39 >> 2];
    var $40$1 = HEAP32[$39 + 4 >> 2];
    var $st$6$0 = $22 | 0;
    HEAP32[$st$6$0 >> 2] = $40$0;
    var $st$6$1 = $22 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $40$1;
    HEAP32[$24 >> 2] = $40$0;
    HEAP32[$24 + 4 >> 2] = $40$1;
    __label__ = 9;
    break;
   case 9:
    var $42 = $cx;
    var $43 = __Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE($42, __ZN2js10QNameClassE, 0, 1, $name);
    var $44 = $43;
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ((HEAP32[$6 >> 2] | 0) == 3) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $54 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN8JSObject10setNameURIEP14JSLinearString($44, $54);
    __label__ = 12;
    break;
   case 12:
    var $58 = HEAP32[$obj >> 2];
    if ((HEAP32[$3 >> 2] | 0) == ($58 | 0)) {
      var $63 = $3;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $61 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $3, $58);
    var $63 = $61;
    __label__ = 14;
    break;
   case 14:
    var $63;
    if (($63 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    HEAP32[$63 + 12 >> 2] = $44;
    if ((HEAP32[$63 + 16 >> 2] | 0) == 1) {
      var $nsowner_0 = $63;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $72 = HEAP32[$63 + 8 >> 2];
    if (($72 | 0) == 0) {
      var $_0 = 1;
      __label__ = 31;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    if ((HEAP32[$72 + 16 >> 2] | 0) == 1) {
      var $nsowner_0 = $72;
      __label__ = 18;
      break;
    } else {
      var $_0 = 1;
      __label__ = 31;
      break;
    }
   case 18:
    var $nsowner_0;
    var $79 = __ZNK8JSObject13getNamePrefixEv($44);
    if (($79 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $82 = $nsowner_0 + 40 | 0;
    var $83 = __ZL12GetNamespaceP9JSContextP8JSObjectPK10JSXMLArray($cx, $44, $82);
    if (($83 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $86 = $83;
    var $_idx4_val = HEAP32[$82 >> 2];
    var $_idx5_val = HEAP32[$nsowner_0 + 48 >> 2];
    var $87 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx4_val, $_idx5_val, $86, 0);
    if (($87 | 0) == -1) {
      var $ns_0 = $83;
      __label__ = 29;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $90$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $90$1 = HEAP32[$st$1$1 >> 2];
    var $91 = $vp | 0;
    var $st$6$0 = $91 | 0;
    HEAP32[$st$6$0 >> 2] = $90$0;
    var $st$6$1 = $91 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $90$1;
    var $_0 = 1;
    __label__ = 31;
    break;
   case 22:
    var $94 = HEAPU32[$nsowner_0 + 40 >> 2];
    var $95 = $nsowner_0 + 48 | 0;
    var $i_0 = 0;
    __label__ = 23;
    break;
   case 23:
    var $i_0;
    if ($i_0 >>> 0 < $94 >>> 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 24:
    var $101 = HEAP32[HEAP32[$95 >> 2] + ($i_0 << 2) >> 2];
    var $102 = $101;
    if (($101 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $105 = __ZNK8JSObject10getNameURIEv($102);
    var $106 = __ZNK8JSObject10getNameURIEv($44);
    var $107 = __ZN2js12EqualStringsEP14JSLinearStringS1_($105, $106);
    if ($107) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $109 = __ZNK8JSObject13getNamePrefixEv($102);
    __ZN8JSObject13setNamePrefixEP14JSLinearString($44, $109);
    var $$emscripten$temp$1 = _JSVAL_VOID | 0;
    var $110$0 = HEAP32[$$emscripten$temp$1 >> 2];
    var $110$1 = HEAP32[$$emscripten$temp$1 + 4 >> 2];
    var $111 = $vp | 0;
    HEAP32[$111 >> 2] = $110$0;
    HEAP32[$111 + 4 >> 2] = $110$1;
    var $_0 = 1;
    __label__ = 31;
    break;
   case 27:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 23;
    break;
   case 28:
    var $114 = __ZNK8JSObject10getNameURIEv($44);
    var $115 = __ZL15NewXMLNamespaceP9JSContextP14JSLinearStringS2_i($cx, 0, $114, 1);
    if (($115 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      var $ns_0 = $115;
      __label__ = 29;
      break;
    }
   case 29:
    var $ns_0;
    var $118 = __ZL19AddInScopeNamespaceP9JSContextP5JSXMLP8JSObject($cx, $nsowner_0, $ns_0);
    if (($118 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $$emscripten$temp$2 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$2 | 0;
    var $121$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$2 + 4 | 0;
    var $121$1 = HEAP32[$st$1$1 >> 2];
    var $122 = $vp | 0;
    var $st$6$0 = $122 | 0;
    HEAP32[$st$6$0 >> 2] = $121$0;
    var $st$6$1 = $122 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $121$1;
    var $_0 = 1;
    __label__ = 31;
    break;
   case 31:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11xml_setNameP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN10JSXMLArray4initEv($this) {
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZL16xml_setNamespaceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $qnargv = __stackBase__;
    var $obj = __stackBase__ + 16;
    var $1 = __stackBase__ + 20;
    var $2 = __stackBase__ + 28;
    var $3 = __stackBase__ + 36;
    var $4 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$4 + 16 >> 2] - 1 | 0) >>> 0 < 3) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 13;
      break;
    }
   case 3:
    var $14 = HEAPU32[$obj >> 2];
    if ((HEAP32[$4 >> 2] | 0) == ($14 | 0)) {
      var $19 = $4;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $4, $14);
    var $19 = $17;
    __label__ = 5;
    break;
   case 5:
    var $19;
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = ($argc | 0) != 0 & 1;
    var $23 = $vp + 16 | 0;
    var $24 = $cx;
    var $25 = $14;
    var $26 = __Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE($24, __ZN2js14NamespaceClassE, $25, $22, $23);
    var $27 = $26;
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _OBJECT_TO_JSVAL4318($1, $27);
    var $30 = $1 | 0;
    var $31$0 = HEAP32[$30 >> 2];
    var $31$1 = HEAP32[$30 + 4 >> 2];
    var $32 = $vp | 0;
    HEAP32[$32 >> 2] = $31$0;
    HEAP32[$32 + 4 >> 2] = $31$1;
    var $$emscripten$temp$0 = _JSVAL_TRUE | 0;
    var $33$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $33$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    __ZN8JSObject20setNamespaceDeclaredEN2JS5ValueE($27, $33$0, $33$1);
    var $34 = $qnargv | 0;
    _OBJECT_TO_JSVAL4318($2, $27);
    var $35 = $2 | 0;
    var $36$0 = HEAP32[$35 >> 2];
    var $36$1 = HEAP32[$35 + 4 >> 2];
    var $37 = $qnargv | 0;
    HEAP32[$37 >> 2] = $36$0;
    HEAP32[$37 + 4 >> 2] = $36$1;
    var $38 = $19 + 12 | 0;
    var $39 = HEAP32[$38 >> 2];
    _OBJECT_TO_JSVAL4318($3, $39);
    var $40 = $3 | 0;
    var $41$0 = HEAP32[$40 >> 2];
    var $41$1 = HEAP32[$40 + 4 >> 2];
    var $42 = $qnargv + 8 | 0;
    HEAP32[$42 >> 2] = $41$0;
    HEAP32[$42 + 4 >> 2] = $41$1;
    var $43 = __Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE($24, __ZN2js10QNameClassE, 0, 2, $34);
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP32[$38 >> 2] = $43;
    if ((HEAP32[$19 + 16 >> 2] | 0) == 1) {
      var $nsowner_0 = $19;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $52 = HEAP32[$19 + 8 >> 2];
    if (($52 | 0) == 0) {
      var $_0 = 1;
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ((HEAP32[$52 + 16 >> 2] | 0) == 1) {
      var $nsowner_0 = $52;
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 13;
      break;
    }
   case 11:
    var $nsowner_0;
    var $59 = __ZL19AddInScopeNamespaceP9JSContextP5JSXMLP8JSObject($cx, $nsowner_0, $27);
    if (($59 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $$emscripten$temp$1 = _JSVAL_VOID | 0;
    var $62$0 = HEAP32[$$emscripten$temp$1 >> 2];
    var $62$1 = HEAP32[$$emscripten$temp$1 + 4 >> 2];
    HEAP32[$32 >> 2] = $62$0;
    HEAP32[$32 + 4 >> 2] = $62$1;
    var $_0 = 1;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16xml_setNamespaceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL8xml_textP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$3 + 4 >> 2];
    var $6 = __ZNK8JSObject5isXMLEv($_idx1_val);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($2, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    var $_idx_val = HEAP32[$3 + 24 >> 2];
    var $9 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $9;
    var $13 = __ZL15xml_text_helperP9JSContextP8JSObjectP5JSXMLPN2JS5ValueE($cx, $12, $vp);
    var $_0 = $13;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12xml_toSourceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $vp + 8 | 0;
    var $4 = $cx;
    var $5 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($4, $3);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5;
    _OBJECT_TO_JSVAL4318($1, $8);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $9 = __ZL11ToXMLStringP9JSContextN2JS5ValueEj($cx, $_idx_val$0, $_idx_val$1, -2147483648);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _STRING_TO_JSVAL4322($2, $9);
    var $12 = $2 | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    var $14 = $vp | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12xml_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $vp + 8 | 0;
    var $3 = $cx;
    var $4 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($3, $2);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$4 + 4 >> 2];
    var $7 = __ZNK8JSObject5isXMLEv($_idx1_val);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($3, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 4:
    var $_idx_val = HEAP32[$4 + 24 >> 2];
    var $10 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = $10;
    var $14 = __ZL19xml_toString_helperP9JSContextP5JSXML($cx, $13);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _STRING_TO_JSVAL4322($1, $14);
    var $17 = $1 | 0;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    var $19 = $vp | 0;
    HEAP32[$19 >> 2] = $18$0;
    HEAP32[$19 + 4 >> 2] = $18$1;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15xml_toXMLStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $vp + 8 | 0;
    var $4 = $cx;
    var $5 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($4, $3);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5;
    _OBJECT_TO_JSVAL4318($1, $8);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $9 = __ZL11ToXMLStringP9JSContextN2JS5ValueEj($cx, $_idx_val$0, $_idx_val$1, 0);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _STRING_TO_JSVAL4322($2, $9);
    var $12 = $2 | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    var $14 = $vp | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11xml_valueOfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $vp + 8 | 0;
    var $3 = $cx;
    var $4 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($3, $2);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4;
    _OBJECT_TO_JSVAL4318($1, $7);
    var $8 = $1 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $vp | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12xml_settingsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $cx;
    var $3 = _JS_NewObject($2, 0, 0, 0);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL4318($1, $4);
    var $7 = $1 | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $vp | 0;
    HEAP32[$9 >> 2] = $8$0;
    HEAP32[$9 + 4 >> 2] = $8$1;
    var $10 = $vp + 8 | 0;
    var $11 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = $11;
    var $15 = __ZL15CopyXMLSettingsP9JSContextP8JSObjectS2_($cx, $14, $4);
    var $_0 = $15;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15xml_setSettingsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = ($argc | 0) == 0 ? _JSVAL_VOID : $vp + 16 | 0;
    var $_06 = $9 | 0;
    var $tmp$0 = HEAP32[$_06 >> 2];
    var $tmp$1 = HEAP32[$_06 + 4 >> 2];
    var $10 = _JSVAL_IS_NULL4395($tmp$0, $tmp$1);
    if (($10 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $13 = _JSVAL_IS_VOID4396($tmp$0, $tmp$1);
    if (($13 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = __ZL21SetDefaultXMLSettingsP9JSContextP8JSObject($cx, $4);
    var $ok_0 = $16;
    __label__ = 8;
    break;
   case 5:
    var $18 = _JSVAL_IS_PRIMITIVE4303($tmp$0, $tmp$1);
    if (($18 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $21$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $21$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $22 = $vp | 0;
    HEAP32[$22 >> 2] = $21$0;
    HEAP32[$22 + 4 >> 2] = $21$1;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 7:
    var $24 = _JSVAL_TO_OBJECT4304($tmp$0, $tmp$1);
    var $25 = __ZL15CopyXMLSettingsP9JSContextP8JSObjectS2_($cx, $24, $4);
    var $ok_0 = $25;
    __label__ = 8;
    break;
   case 8:
    var $ok_0;
    var $$emscripten$temp$1 = _JSVAL_VOID | 0;
    var $27$0 = HEAP32[$$emscripten$temp$1 >> 2];
    var $27$1 = HEAP32[$$emscripten$temp$1 + 4 >> 2];
    var $28 = $vp | 0;
    HEAP32[$28 >> 2] = $27$0;
    HEAP32[$28 + 4 >> 2] = $27$1;
    var $_0 = $ok_0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15xml_setSettingsP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL19xml_defaultSettingsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $cx;
    var $3 = _JS_NewObject($2, 0, 0, 0);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL4318($1, $4);
    var $7 = $1 | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $vp | 0;
    HEAP32[$9 >> 2] = $8$0;
    HEAP32[$9 + 4 >> 2] = $8$1;
    var $10 = __ZL21SetDefaultXMLSettingsP9JSContextP8JSObject($cx, $4);
    var $_0 = $10;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z9js_NewXMLP9JSContext10JSXMLClass($cx, $xml_class) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __Z11js_NewGCXMLP9JSContext($1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$2 >> 2] = 0;
    HEAP32[$2 + 4 >> 2] = 0;
    HEAP32[$2 + 8 >> 2] = 0;
    HEAP32[$2 + 12 >> 2] = 0;
    HEAP32[$2 + 16 >> 2] = $xml_class;
    HEAP32[$2 + 20 >> 2] = 0;
    if (($xml_class | 0) > 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $_c = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2];
    HEAP32[$2 + 24 >> 2] = $_c;
    var $_0 = $3;
    __label__ = 7;
    break;
   case 4:
    var $21 = $2 + 24 | 0;
    __ZN10JSXMLArray4initEv($21);
    if (($xml_class | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    HEAP32[$2 + 40 >> 2] = 0;
    HEAP32[$2 + 44 >> 2] = 0;
    var $_0 = $3;
    __label__ = 7;
    break;
   case 6:
    var $28 = $2 + 40 | 0;
    __ZN10JSXMLArray4initEv($28);
    var $30 = $2 + 56 | 0;
    __ZN10JSXMLArray4initEv($30);
    var $_0 = $3;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_TraceXML($trc, $xml) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$xml >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $trc;
    var $6 = $2;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($5, $6);
    __label__ = 3;
    break;
   case 3:
    var $9 = HEAP32[$xml + 12 >> 2];
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $trc;
    var $13 = $9;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($12, $13);
    __label__ = 5;
    break;
   case 5:
    var $16 = HEAP32[$xml + 8 >> 2];
    if (($16 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = $16;
    var $20 = $trc;
    _JS_CallTracer($20, $19, 3);
    __label__ = 7;
    break;
   case 7:
    var $22 = $xml + 16 | 0;
    if (HEAPU32[$22 >> 2] >>> 0 > 1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $28 = HEAPU32[$xml + 24 >> 2];
    if (($28 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $31 = $trc;
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($31, $28);
    __label__ = 16;
    break;
   case 10:
    var $35 = HEAP32[$xml + 32 >> 2];
    var $37 = HEAP32[$xml + 24 >> 2];
    __ZL16xml_trace_vectorP8JSTracerPP5JSXMLj($trc, $35, $37);
    var $39 = HEAP32[$xml + 36 >> 2];
    __ZL19XMLArrayCursorTraceP8JSTracerP16JSXMLArrayCursor($trc, $39);
    if ((HEAP32[$22 >> 2] | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 11:
    var $45 = HEAP32[$xml + 40 >> 2];
    if (($45 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $48 = $45;
    var $49 = $trc;
    _JS_CallTracer($49, $48, 3);
    __label__ = 13;
    break;
   case 13:
    var $53 = HEAP32[$xml + 44 >> 2];
    if (($53 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $56 = $trc;
    var $57 = $53;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($56, $57);
    __label__ = 16;
    break;
   case 15:
    var $60 = HEAP32[$xml + 40 >> 2];
    var $63 = $trc;
    var $64 = HEAP32[$xml + 48 >> 2];
    __ZN2js2gc15MarkObjectRangeEP8JSTracerjPP8JSObjectPKc($63, $60, $64);
    var $66 = HEAP32[$xml + 52 >> 2];
    __ZL19XMLArrayCursorTraceP8JSTracerP16JSXMLArrayCursor($trc, $66);
    var $69 = HEAP32[$xml + 64 >> 2];
    var $71 = HEAP32[$xml + 56 >> 2];
    __ZL16xml_trace_vectorP8JSTracerPP5JSXMLj($trc, $69, $71);
    var $73 = HEAP32[$xml + 68 >> 2];
    __ZL19XMLArrayCursorTraceP8JSTracerP16JSXMLArrayCursor($trc, $73);
    __label__ = 16;
    break;
   case 16:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_TraceXML["X"] = 1;

function __ZL16xml_trace_vectorP8JSTracerPP5JSXMLj($trc, $vec, $len) {
  var $1 = $trc;
  var $2 = $vec;
  __ZN2js2gc12MarkXMLRangeEP8JSTracerjPP5JSXMLPKc($1, $len, $2);
  return;
}

function __ZL19XMLArrayCursorTraceP8JSTracerP16JSXMLArrayCursor($trc, $cursor) {
  __ZN16JSXMLArrayCursor5traceEP8JSTracer($cursor, $trc);
  return;
}

function __ZN2js13AutoXMLRooterC1EP9JSContextP5JSXML($this, $cx, $xml) {
  __ZN2js13AutoXMLRooterC2EP9JSContextP5JSXML($this, $cx, $xml);
  return;
}

function __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $xml) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $xml | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $2;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = __ZL12NewXMLObjectP9JSContextP5JSXML($cx, $xml);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$1 >> 2] = $5;
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13AutoXMLRooterD1Ev($this) {
  __ZN2js13AutoXMLRooterD2Ev($this);
  return;
}

function __ZL12NewXMLObjectP9JSContextP5JSXML($cx, $xml) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL22GetGlobalForScopeChainEP9JSContext4366($cx);
    var $2 = $1 | 0;
    var $3 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_4427($cx, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $xml;
    var $7 = $3;
    __ZN8JSObject10setPrivateEPv($7, $6);
    var $_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z21js_InitNamespaceClassP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZN8JSObject8asGlobalEv($1);
    var $3 = $cx;
    var $4 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($2, $3, __ZN2js14NamespaceClassE);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $cx + 52 | 0;
    var $12 = HEAP32[HEAP32[$8 >> 2] + 144136 >> 2] | 0;
    __ZN8JSObject13setNamePrefixEP14JSLinearString($5, $12);
    __ZN8JSObject10setNameURIEP14JSLinearString($5, $12);
    __ZN8JSObject19syncSpecialEqualityEv($4);
    var $16 = HEAP32[HEAP32[$8 >> 2] + 210068 >> 2];
    var $17 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($2, $3, 268, __ZN2js14NamespaceClassE, $16, 2);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $20 = $17 | 0;
    var $21 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($3, $20, $4);
    if ($21) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $23 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($3, $4, __ZL15namespace_props, __ZL17namespace_methods);
    if ($23) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $25 = $cx;
    var $26 = $2;
    var $27 = $17;
    var $28 = $4;
    var $29 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($25, $26, 12, $27, $28);
    var $_ = $29 ? $5 : 0;
    var $_0 = $_;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject13setNamePrefixEP14JSLinearString($this, $prefix) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($prefix | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $prefix | 0;
    __ZN2JSL11StringValueEP8JSString4311($1, $4);
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv4406($1);
    __label__ = 4;
    break;
   case 4:
    var $7 = $this;
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($7, 0, $_idx_val$0, $_idx_val$1);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject10setNameURIEP14JSLinearString($this, $uri) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($uri | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $uri | 0;
    __ZN2JSL11StringValueEP8JSString4311($1, $4);
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv4406($1);
    __label__ = 4;
    break;
   case 4:
    var $7 = $this;
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($7, 1, $_idx_val$0, $_idx_val$1);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9NamespaceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $thisobj = __stackBase__;
  HEAP32[$thisobj >> 2] = 0;
  __ZN2jsL42IsConstructing_PossiblyWithGivenThisObjectEPKN2JS5ValueEPP8JSObject($vp, $thisobj);
  var $1 = HEAP32[$thisobj >> 2];
  var $2 = $vp + 16 | 0;
  var $3 = __ZL15NamespaceHelperP9JSContextP8JSObjectiPN2JS5ValueES5_($cx, $1, $argc, $2, $vp);
  STACKTOP = __stackBase__;
  return $3;
}

function __Z17js_InitQNameClassP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZN8JSObject8asGlobalEv($1);
    var $3 = $cx;
    var $4 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($2, $3, __ZN2js10QNameClassE);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $cx + 52 | 0;
    var $11 = HEAP32[HEAP32[$8 >> 2] + 144136 >> 2];
    var $12 = $11 | 0;
    var $13 = __ZL12InitXMLQNameP9JSContextP8JSObjectP14JSLinearStringS4_P6JSAtom($cx, $5, $12, $12, $11);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    __ZN8JSObject19syncSpecialEqualityEv($4);
    var $18 = HEAP32[HEAP32[$8 >> 2] + 210072 >> 2];
    var $19 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($2, $3, 270, __ZN2js10QNameClassE, $18, 2);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $19 | 0;
    var $23 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($3, $22, $4);
    if ($23) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $25 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($3, $4, 0, __ZL13qname_methods);
    if ($25) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $27 = $cx;
    var $28 = $2;
    var $29 = $19;
    var $30 = $4;
    var $31 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($27, $28, 13, $29, $30);
    var $_ = $31 ? $5 : 0;
    var $_0 = $_;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12InitXMLQNameP9JSContextP8JSObjectP14JSLinearStringS4_P6JSAtom($cx, $obj, $uri, $prefix, $localName) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = $obj;
    var $3 = _JS_DefineProperties($1, $2, __ZL11qname_props);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($uri | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject10setNameURIEP14JSLinearString($obj, $uri);
    __label__ = 4;
    break;
   case 4:
    if (($prefix | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN8JSObject13setNamePrefixEP14JSLinearString($obj, $prefix);
    __label__ = 6;
    break;
   case 6:
    if (($localName | 0) == 0) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject17setQNameLocalNameEP6JSAtom($obj, $localName);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5QNameP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $thisobj = __stackBase__;
  HEAP32[$thisobj >> 2] = 0;
  __ZN2jsL42IsConstructing_PossiblyWithGivenThisObjectEPKN2JS5ValueEPP8JSObject($vp, $thisobj);
  var $1 = HEAP32[$thisobj >> 2];
  var $2 = $vp + 16 | 0;
  var $3 = __ZL11QNameHelperP9JSContextP8JSObjectiPN2JS5ValueES5_($cx, $1, $argc, $2, $vp);
  STACKTOP = __stackBase__;
  return $3;
}

function __Z15js_InitXMLClassP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $obj;
    var $3 = __ZN8JSObject8asGlobalEv($2);
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js8XMLClassE);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __Z9js_NewXMLP9JSContext10JSXMLClass($cx, 4);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $9;
    var $13 = $5;
    __ZN8JSObject10setPrivateEPv($13, $12);
    HEAP32[$9 >> 2] = $6;
    var $15 = $cx;
    var $16 = __ZNK9JSContext28runningWithTrustedPrincipalsEv($15);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = HEAP32[_sE4XObjectsCreated >> 2] - 1 | 0;
    HEAP32[_sE4XObjectsCreated >> 2] = $19;
    __label__ = 5;
    break;
   case 5:
    var $21 = $cx + 52 | 0;
    var $25 = HEAP32[HEAP32[$21 >> 2] + 210064 >> 2];
    var $26 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 272, __ZN2js8XMLClassE, $25, 1);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $29 = $26;
    var $30 = $26 | 0;
    var $31 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $30, $5);
    if ($31) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 7:
    var $33 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, 0, __ZL11xml_methods);
    if ($33) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 8:
    var $35 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $30, __ZL16xml_static_props, __ZL18xml_static_methods);
    if ($35) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 9:
    var $37 = __ZL21SetDefaultXMLSettingsP9JSContextP8JSObject($cx, $29);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $40 = $3;
    var $41 = _JS_DefineFunction($15, $40, STRING_TABLE.__str983250 | 0, 274, 512);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $47 = HEAP32[HEAP32[$21 >> 2] + 210200 >> 2] | 0;
    var $48 = __ZL12ATOM_TO_JSIDP6JSAtom4336($47);
    __ZN2JSL11ObjectValueER8JSObject4319($1, $6);
    var $49 = $41 | 0;
    var $50 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($49, $15, $48, $1, 10, 12, 6);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $53 = $3;
    var $54 = $26;
    var $55 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($15, $53, 11, $54, $13);
    if ($55) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 13:
    var $57 = $obj;
    var $58 = _JS_DefineFunction($15, $57, STRING_TABLE._js_isXMLName_str | 0, 276, 0);
    var $_ = ($58 | 0) == 0 ? 0 : $6;
    var $_0 = $_;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z15js_InitXMLClassP9JSContextP8JSObject["X"] = 1;

function __ZL3XMLP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $4 = ($argc | 0) == 0 ? _JSVAL_VOID : $vp + 16 | 0;
    var $_08 = $4 | 0;
    var $tmp$0 = HEAP32[$_08 >> 2];
    var $tmp$1 = HEAP32[$_08 + 4 >> 2];
    var $5 = _JSVAL_IS_NULL4395($tmp$0, $tmp$1);
    if (($5 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = _JSVAL_IS_VOID4396($tmp$0, $tmp$1);
    if (($8 | 0) == 0) {
      var $v_0_0_0$1 = $tmp$1;
      var $v_0_0_0$0 = $tmp$0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    _STRING_TO_JSVAL4322($1, $15);
    var $_013 = $1 | 0;
    var $v_0_0_0$1 = HEAP32[$_013 + 4 >> 2];
    var $v_0_0_0$0 = HEAP32[$_013 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $v_0_0_0$0;
    var $v_0_0_0$1;
    var $17 = __ZL5ToXMLP9JSContextN2JS5ValueE($cx, $v_0_0_0$0, $v_0_0_0$1);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = $17;
    var $_idx_val = HEAP32[$17 + 24 >> 2];
    var $22 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $23 = $22;
    var $24 = __ZN2jsL14IsConstructingEPKN2JS5ValueE4419($vp);
    if ($24) {
      __label__ = 6;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 6:
    var $26 = _JSVAL_IS_PRIMITIVE4303($v_0_0_0$0, $v_0_0_0$1);
    if (($26 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 7:
    var $29 = _JSVAL_TO_OBJECT4304($v_0_0_0$0, $v_0_0_0$1);
    var $_idx1_val = HEAP32[$29 + 4 >> 2];
    var $31 = __ZNK8JSObject8getClassEv($_idx1_val);
    if (($31 | 0) == (__ZN2js8XMLClassE | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((HEAP32[$31 + 4 >> 2] & 128 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $39 = __ZL8DeepCopyP9JSContextP5JSXMLP8JSObjectj($cx, $23, 0);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $44 = HEAP32[$39 >> 2];
    __ZN2JS5Value9setObjectER8JSObject($vp, $44);
    var $_0 = 1;
    __label__ = 12;
    break;
   case 11:
    __ZN2JS5Value9setObjectER8JSObject($vp, $20);
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL3XMLP9JSContextjPN2JS5ValueE["X"] = 1;

function _OBJECT_TO_JSID4356($obj) {
  return $obj | 4;
}

function __ZL21SetDefaultXMLSettingsP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = $1 | 0;
    var $3 = $v | 0;
    var $4 = $cx;
    var $5 = $obj;
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    var $7 = __ZL16xml_static_props + ($i_0 << 4) | 0;
    var $8 = HEAP32[$7 >> 2];
    if (($8 | 0) == 0) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = ($8 | 0) == (STRING_TABLE.__ZL19js_prettyIndent_str | 0);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $$emscripten$temp$0 = _JSVAL_TRUE | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $13$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $13$1 = HEAP32[$st$1$1 >> 2];
    HEAP32[$2 >> 2] = $13$0;
    HEAP32[$2 + 4 >> 2] = $13$1;
    var $17$1 = $13$1;
    var $17$0 = $13$0;
    var $16 = $8;
    __label__ = 6;
    break;
   case 5:
    _INT_TO_JSVAL4421($1, 2);
    var $st$1$0 = $2 | 0;
    var $st$1$1 = $2 + 4 | 0;
    var $17$1 = HEAP32[$st$1$1 >> 2];
    var $17$0 = HEAP32[$st$1$0 >> 2];
    var $16 = HEAP32[$7 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $16;
    var $17$0;
    var $17$1;
    HEAP32[$3 >> 2] = $17$0;
    HEAP32[$3 + 4 >> 2] = $17$1;
    var $18 = _JS_SetProperty($4, $5, $16, $v);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL7XMLListP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $6 = ($argc | 0) == 0 ? _JSVAL_VOID : $vp + 16 | 0;
    var $_08 = $6 | 0;
    var $st$7$0 = $_08 | 0;
    var $tmp$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $_08 + 4 | 0;
    var $tmp$1 = HEAP32[$st$7$1 >> 2];
    var $7 = _JSVAL_IS_NULL4395($tmp$0, $tmp$1);
    if (($7 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = _JSVAL_IS_VOID4396($tmp$0, $tmp$1);
    if (($10 | 0) == 0) {
      var $v_0_0_0$1 = $tmp$1;
      var $v_0_0_0$0 = $tmp$0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    _STRING_TO_JSVAL4322($1, $17);
    var $_013 = $1 | 0;
    var $st$7$0 = $_013 | 0;
    var $st$7$1 = $_013 + 4 | 0;
    var $v_0_0_0$1 = HEAP32[$st$7$1 >> 2];
    var $v_0_0_0$0 = HEAP32[$st$7$0 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $v_0_0_0$0;
    var $v_0_0_0$1;
    var $19 = __ZN2jsL14IsConstructingEPKN2JS5ValueE4419($vp);
    if ($19) {
      __label__ = 5;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 5:
    var $21 = _JSVAL_IS_PRIMITIVE4303($v_0_0_0$0, $v_0_0_0$1);
    if (($21 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $24 = _JSVAL_TO_OBJECT4304($v_0_0_0$0, $v_0_0_0$1);
    var $_idx2_val = HEAP32[$24 + 4 >> 2];
    var $26 = __ZNK8JSObject5isXMLEv($_idx2_val);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    var $_idx1_val = HEAP32[$24 + 24 >> 2];
    var $29 = __ZNK8JSObject10getPrivateEv($_idx1_val);
    var $30 = $29;
    if ((HEAP32[$29 + 16 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $36 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 0);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    _OBJECT_TO_JSVAL4318($2, $36);
    var $39 = $2 | 0;
    var $st$2$0 = $39 | 0;
    var $40$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $39 + 4 | 0;
    var $40$1 = HEAP32[$st$2$1 >> 2];
    var $41 = $vp | 0;
    var $st$7$0 = $41 | 0;
    HEAP32[$st$7$0 >> 2] = $40$0;
    var $st$7$1 = $41 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $40$1;
    var $_idx_val = HEAP32[$36 + 24 >> 2];
    var $43 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $44 = $43;
    var $45 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $44, $30);
    var $_0 = ($45 | 0) != 0 & 1;
    __label__ = 12;
    break;
   case 10:
    var $47 = __ZL9ToXMLListP9JSContextN2JS5ValueE($cx, $v_0_0_0$0, $v_0_0_0$1);
    if (($47 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    _OBJECT_TO_JSVAL4318($3, $47);
    var $50 = $3 | 0;
    var $st$2$0 = $50 | 0;
    var $51$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $50 + 4 | 0;
    var $51$1 = HEAP32[$st$2$1 >> 2];
    var $52 = $vp | 0;
    var $st$7$0 = $52 | 0;
    HEAP32[$st$7$0 >> 2] = $51$0;
    var $st$7$1 = $52 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $51$1;
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL7XMLListP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL12ATOM_TO_JSIDP6JSAtom4336($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj4418($1);
  return $2;
}

function __ZL13xml_isXMLNameP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($argc | 0) == 0) {
      var $6 = _JSVAL_VOID;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $vp + 16 | 0;
    __label__ = 3;
    break;
   case 3:
    var $6;
    var $7 = $6;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = __Z12js_IsXMLNameP9JSContextN2JS5ValueE($cx, $8$0, $8$1);
    _BOOLEAN_TO_JSVAL4415($1, $9);
    var $10 = $1 | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = $vp | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_InitXMLClassesP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z21js_InitNamespaceClassP9JSContextP8JSObject($cx, $obj);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z17js_InitQNameClassP9JSContextP8JSObject($cx, $obj);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __Z15js_InitXMLClassP9JSContextP8JSObject($cx, $obj);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12GlobalObject20getFunctionNamespaceEP9JSContextPN2JS5ValueE($this, $cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZN8JSObject10getSlotRefEj($1, 114);
    var $_idx = $2 | 0;
    var $st$3$0 = $_idx | 0;
    var $_idx_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAP32[$st$3$1 >> 2];
    var $3 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $18$1 = $_idx_val$1;
      var $18$0 = $_idx_val$0;
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = HEAP32[$cx + 52 >> 2];
    var $9 = HEAP32[$6 + 209992 >> 2] | 0;
    var $12 = HEAP32[$6 + 210428 >> 2] | 0;
    var $13 = __ZL15NewXMLNamespaceP9JSContextP14JSLinearStringS2_i($cx, $9, $12, 0);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = $13;
    __ZN8JSObject9clearTypeEv($16);
    __ZN2JS5Value9setObjectER8JSObject($2, $16);
    var $st$3$0 = $_idx | 0;
    var $st$3$1 = $_idx + 4 | 0;
    var $18$1 = HEAP32[$st$3$1 >> 2];
    var $18$0 = HEAP32[$st$3$0 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $18$0;
    var $18$1;
    var $19 = $vp | 0;
    var $st$3$0 = $19 | 0;
    HEAP32[$st$3$0 >> 2] = $18$0;
    var $st$3$1 = $19 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $18$1;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15NewXMLNamespaceP9JSContextP14JSLinearStringS2_i($cx, $prefix, $uri, $declared) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL26NewBuiltinClassInstanceXMLP9JSContextPN2js5ClassE($cx, __ZN2js14NamespaceClassE);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $1;
    var $6 = _JS_DefineProperties($4, $5, __ZL15namespace_props);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($prefix | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN8JSObject13setNamePrefixEP14JSLinearString($1, $prefix);
    __label__ = 5;
    break;
   case 5:
    if (($uri | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN8JSObject10setNameURIEP14JSLinearString($1, $uri);
    __label__ = 7;
    break;
   case 7:
    if (($declared | 0) == 0) {
      var $_0 = $1;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $$emscripten$temp$0 = _JSVAL_TRUE | 0;
    var $17$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $17$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    __ZN8JSObject20setNamespaceDeclaredEN2JS5ValueE($1, $17$0, $17$1);
    var $_0 = $1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z25js_GetDefaultXMLNamespaceP9JSContextPN2JS5ValueE($cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 12;
    var $3 = $cx;
    var $4 = __ZN2js13GetScopeChainEP9JSContext($3);
    var $5 = $v | 0;
    var $_02 = $1 | 0;
    var $tmp_0_in = $4;
    var $obj_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $obj_0;
    var $tmp_0_in;
    var $tmp_0 = $tmp_0_in;
    if (($tmp_0_in | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $tmp_0_in_idx1_val = HEAP32[$tmp_0_in + 4 >> 2];
    var $9 = __ZNK8JSObject8getClassEv($tmp_0_in_idx1_val);
    if (($9 | 0) == (__ZN2js10BlockClassE | 0) | ($9 | 0) == (__ZN2js9WithClassE | 0)) {
      var $obj_1 = $obj_0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js9SpecialId19defaultXMLNamespaceEv($1);
    var $_02_val = HEAP32[$_02 >> 2];
    var $13 = __ZN8JSObject10getSpecialEP9JSContextN2js9SpecialIdEPN2JS5ValueE($tmp_0, $cx, $_02_val, $v);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $st$0$0 = $5 | 0;
    var $16$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5 + 4 | 0;
    var $16$1 = HEAP32[$st$0$1 >> 2];
    var $17 = _JSVAL_IS_PRIMITIVE4303($16$0, $16$1);
    if (($17 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $obj_1 = $tmp_0;
      __label__ = 7;
      break;
    }
   case 6:
    var $st$0$0 = $5 | 0;
    var $20$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5 + 4 | 0;
    var $20$1 = HEAP32[$st$0$1 >> 2];
    var $21 = $vp | 0;
    var $st$5$0 = $21 | 0;
    HEAP32[$st$5$0 >> 2] = $20$0;
    var $st$5$1 = $21 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $20$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 7:
    var $obj_1;
    var $tmp_0_in_idx_val = HEAP32[$tmp_0_in + 20 >> 2];
    var $23 = __ZNK8JSObject9getParentEv($tmp_0_in_idx_val);
    var $tmp_0_in = $23;
    var $obj_0 = $obj_1;
    __label__ = 2;
    break;
   case 8:
    var $25 = $cx;
    var $27 = __Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE($25, __ZN2js14NamespaceClassE, $obj_0, 0, 0);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $30 = $27;
    _OBJECT_TO_JSVAL4318($2, $30);
    var $31 = $2 | 0;
    var $32$0 = HEAP32[$31 >> 2];
    var $32$1 = HEAP32[$31 + 4 >> 2];
    HEAP32[$5 >> 2] = $32$0;
    HEAP32[$5 + 4 >> 2] = $32$1;
    var $34 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj_0, $3, 6, $v, 10, 12, 4);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $st$0$0 = $5 | 0;
    var $37$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5 + 4 | 0;
    var $37$1 = HEAP32[$st$0$1 >> 2];
    var $38 = $vp | 0;
    var $st$5$0 = $38 | 0;
    HEAP32[$st$5$0 >> 2] = $37$0;
    var $st$5$1 = $38 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $37$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z25js_GetDefaultXMLNamespaceP9JSContextPN2JS5ValueE["X"] = 1;

function __ZN8JSObject10getSpecialEP9JSContextN2js9SpecialIdEPN2JS5ValueE($this, $cx, $sid_0, $vp) {
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE4414($sid_0);
  var $2 = $this;
  var $3 = $cx;
  var $4 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($2, $3, $1, $vp);
  return $4;
}

function __ZN2js9SpecialId19defaultXMLNamespaceEv($agg_result) {
  __ZN2js9SpecialIdC1Ej($agg_result);
  return;
}

function __Z25js_SetDefaultXMLNamespaceP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $argv = __stackBase__;
    var $1 = __stackBase__ + 16;
    var $2 = $argv | 0;
    var $7 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($2, $7);
    var $8 = $v | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $argv + 8 | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $11 = $cx;
    var $12 = __Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE($11, __ZN2js14NamespaceClassE, 0, 2, $2);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $15 = $12;
    var $16 = $cx;
    var $17 = __ZNK9JSContext2fpEv($16);
    var $18 = __ZN2js10StackFrame6varObjEv($17);
    __ZN2JSL11ObjectValueER8JSObject4319($1, $15);
    var $19 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($18, $16, 6, $1, 10, 12, 4);
    var $_0 = ($19 | 0) != 0 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18js_ToAttributeNameP9JSContextPN2JS5ValueE($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZL15ToAttributeNameP9JSContextN2JS5ValueE($cx, $2$0, $2$1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    __ZN2JS5Value9setObjectER8JSObject($vp, $6);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15ToAttributeNameP9JSContextN2JS5ValueE($cx, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $name = __stackBase__;
    var $1 = _JSVAL_IS_STRING4320($_0_0_0_val$0, $_0_0_0_val$1);
    if (($1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $name;
    var $6 = __Z14js_ValueToAtomP9JSContextRKN2JS5ValueEPP6JSAtom($4, $_0_0_0_val$0, $_0_0_0_val$1, $5);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 3:
    var $12 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    var $uri_0 = $12;
    var $prefix_0 = $12;
    __label__ = 14;
    break;
   case 4:
    var $14 = _JSVAL_IS_PRIMITIVE4303($_0_0_0_val$0, $_0_0_0_val$1);
    if (($14 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = $cx;
    var $18 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($17, 0, 178, 0, $_0_0_0_val$0, $_0_0_0_val$1, 0, 0);
    var $_0 = 0;
    __label__ = 15;
    break;
   case 6:
    var $20 = _JSVAL_TO_OBJECT4304($_0_0_0_val$0, $_0_0_0_val$1);
    var $_idx_val = HEAP32[$20 + 4 >> 2];
    var $22 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($22 | 0) == (__ZN2js18AttributeNameClassE | 0)) {
      var $_0 = $20;
      __label__ = 15;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($22 | 0) == (__ZN2js10QNameClassE | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $27 = __ZNK8JSObject10getNameURIEv($20);
    var $28 = __ZNK8JSObject13getNamePrefixEv($20);
    var $29 = __ZNK8JSObject17getQNameLocalNameEv($20);
    HEAP32[$name >> 2] = $29;
    var $uri_0 = $27;
    var $prefix_0 = $28;
    __label__ = 14;
    break;
   case 9:
    if (($22 | 0) == (__ZN2js12AnyNameClassE | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $34 = HEAP32[$cx + 52 >> 2];
    var $37 = HEAP32[$34 + 210412 >> 2] | 0;
    HEAP32[$name >> 2] = $37;
    var $43 = $34;
    __label__ = 13;
    break;
   case 11:
    var $39 = $cx;
    var $40 = $name;
    var $41 = __Z14js_ValueToAtomP9JSContextRKN2JS5ValueEPP6JSAtom($39, $_0_0_0_val$0, $_0_0_0_val$1, $40);
    if ($41) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 12:
    var $43 = HEAP32[$cx + 52 >> 2];
    __label__ = 13;
    break;
   case 13:
    var $43;
    var $46 = HEAP32[$43 + 144136 >> 2] | 0;
    var $uri_0 = $46;
    var $prefix_0 = $46;
    __label__ = 14;
    break;
   case 14:
    var $prefix_0;
    var $uri_0;
    var $48 = HEAP32[$name >> 2];
    var $49 = __ZL19NewXMLAttributeNameP9JSContextP14JSLinearStringS2_P6JSAtom($cx, $uri_0, $prefix_0, $48);
    var $_0 = $49;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15ToAttributeNameP9JSContextN2JS5ValueE["X"] = 1;

function __Z23js_EscapeAttributeValueP9JSContextP8JSStringi($cx, $str, $quote) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var $sb = __stackBase__;
  var $1 = $sb;
  var $2 = $cx;
  __ZN2js12StringBufferC1EP9JSContext($1, $2);
  var $3 = __ZL20EscapeAttributeValueP9JSContextRN2js12StringBufferEP8JSStringi($cx, $sb, $str, $quote);
  __ZN2js12StringBufferD1Ev($1);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZL20EscapeAttributeValueP9JSContextRN2js12StringBufferEP8JSStringi($cx, $sb, $str, $quote) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str_idx_val = HEAP32[$str >> 2];
    var $1 = __ZNK8JSString6lengthEv($str_idx_val);
    var $2 = $cx;
    var $3 = __ZN8JSString8getCharsEP9JSContext($str, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = ($quote | 0) != 0;
    var $7 = $sb;
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_pre_phi = $7;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = __ZN2js12StringBuffer6appendEt($7, 34);
    if ($9) {
      var $_pre_phi = $7;
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 4:
    var $_pre_phi;
    var $10 = $3 + ($1 << 1) | 0;
    var $11 = $sb;
    var $cp_0 = $3;
    __label__ = 5;
    break;
   case 5:
    var $cp_0;
    if (($cp_0 | 0) == ($10 | 0)) {
      __label__ = 15;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = HEAPU16[$cp_0 >> 1];
    var $16 = $15 & 65535;
    if (($16 | 0) == 34) {
      __label__ = 7;
      break;
    } else if (($16 | 0) == 60) {
      __label__ = 8;
      break;
    } else if (($16 | 0) == 38) {
      __label__ = 9;
      break;
    } else if (($16 | 0) == 10) {
      __label__ = 10;
      break;
    } else if (($16 | 0) == 13) {
      __label__ = 11;
      break;
    } else if (($16 | 0) == 9) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 7:
    var $18 = __ZN2js12StringBuffer6appendILj7EEEbRAT__Kc($sb, STRING_TABLE._js_quot_entity_str);
    if ($18) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 8:
    var $20 = __ZN2js12StringBuffer6appendILj5EEEbRAT__Kc($11, STRING_TABLE._js_lt_entity_str);
    if ($20) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 9:
    var $22 = __ZN2js12StringBuffer6appendILj6EEEbRAT__Kc($11, STRING_TABLE._js_amp_entity_str);
    if ($22) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 10:
    var $24 = __ZN2js12StringBuffer6appendILj6EEEbRAT__Kc($11, STRING_TABLE.__str504296);
    if ($24) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 11:
    var $26 = __ZN2js12StringBuffer6appendILj6EEEbRAT__Kc($11, STRING_TABLE.__str514297);
    if ($26) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 12:
    var $28 = __ZN2js12StringBuffer6appendILj6EEEbRAT__Kc($11, STRING_TABLE.__str524298);
    if ($28) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 13:
    var $30 = __ZN2js12StringBuffer6appendEt($_pre_phi, $15);
    if ($30) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 14:
    var $cp_0 = $cp_0 + 2 | 0;
    __label__ = 5;
    break;
   case 15:
    if ($6) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $35 = __ZN2js12StringBuffer6appendEt($_pre_phi, 34);
    if ($35) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 17:
    var $37 = $sb;
    var $38 = __ZN2js12StringBuffer12finishStringEv($37);
    var $_0 = $38 | 0;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19js_AddAttributePartP9JSContextiP8JSStringS2_($cx, $isName, $str, $str2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str_idx_val = HEAP32[$str >> 2];
    var $1 = __ZNK8JSString6lengthEv($str_idx_val);
    var $2 = $cx;
    var $3 = __ZN8JSString8getCharsEP9JSContext($str, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $str2_idx_val = HEAP32[$str2 >> 2];
    var $6 = __ZNK8JSString6lengthEv($str2_idx_val);
    var $7 = __ZN8JSString8getCharsEP9JSContext($str2, $2);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = ($isName | 0) != 0;
    var $_pn_v = $10 ? 1 : 3;
    var $11 = $1 + $_pn_v + $6 | 0;
    var $13 = ($11 << 1) + 2 | 0;
    var $14 = __ZN9JSContext7malloc_Ej($2, $13);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = $14;
    var $18 = $3;
    var $19 = $1 << 1;
    _memcpy($14, $18, $19, 1);
    var $20 = $17 + ($1 << 1) | 0;
    var $_sum = $1 + 1 | 0;
    var $21 = $17 + ($_sum << 1) | 0;
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    HEAP16[$20 >> 1] = 32;
    var $23 = $21;
    var $24 = $7;
    var $25 = $6 << 1;
    _memcpy($23, $24, $25, 1);
    var $_sum4_pn = $6 + $_sum | 0;
    __label__ = 7;
    break;
   case 6:
    HEAP16[$20 >> 1] = 61;
    var $_sum1 = $1 + 2 | 0;
    var $27 = $17 + ($_sum1 << 1) | 0;
    HEAP16[$21 >> 1] = 34;
    var $28 = $27;
    var $29 = $7;
    var $30 = $6 << 1;
    _memcpy($28, $29, $30, 1);
    var $_sum2 = $6 + $_sum1 | 0;
    var $_sum3 = $_sum2 + 1 | 0;
    HEAP16[$17 + ($_sum2 << 1) >> 1] = 34;
    var $_sum4_pn = $_sum3;
    __label__ = 7;
    break;
   case 7:
    var $_sum4_pn;
    HEAP16[$17 + ($_sum4_pn << 1) >> 1] = 0;
    var $33 = $17 + ($_sum4_pn - $11 << 1) | 0;
    var $34 = $cx;
    var $35 = __Z12js_NewStringP9JSContextPtj($34, $33, $11);
    var $_0 = $35 | 0;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z19js_AddAttributePartP9JSContextiP8JSStringS2_["X"] = 1;

function __Z21js_EscapeElementValueP9JSContextP8JSString($cx, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var $sb = __stackBase__;
  var $1 = $sb;
  var $2 = $cx;
  __ZN2js12StringBufferC1EP9JSContext($1, $2);
  var $3 = __ZL18EscapeElementValueP9JSContextRN2js12StringBufferEP8JSStringj($cx, $sb, $str, 0);
  __ZN2js12StringBufferD1Ev($1);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZL18EscapeElementValueP9JSContextRN2js12StringBufferEP8JSStringj($cx, $sb, $str, $toSourceFlag) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str_idx_val = HEAP32[$str >> 2];
    var $1 = $cx;
    var $2 = __ZN8JSString8getCharsEP9JSContext($str, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSString6lengthEv($str_idx_val);
    var $6 = $2 + ($5 << 1) | 0;
    var $7 = $sb;
    var $8 = $sb;
    var $9 = ($toSourceFlag | 0) == 0;
    var $cp_0 = $2;
    __label__ = 3;
    break;
   case 3:
    var $cp_0;
    if (($cp_0 | 0) == ($6 | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = HEAPU16[$cp_0 >> 1];
    var $14 = $13 & 65535;
    if (($14 | 0) == 60) {
      __label__ = 5;
      break;
    } else if (($14 | 0) == 62) {
      __label__ = 6;
      break;
    } else if (($14 | 0) == 38) {
      __label__ = 7;
      break;
    } else if (($14 | 0) == 123) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 5:
    var $16 = __ZN2js12StringBuffer6appendILj5EEEbRAT__Kc($8, STRING_TABLE._js_lt_entity_str);
    if ($16) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 6:
    var $18 = __ZN2js12StringBuffer6appendILj5EEEbRAT__Kc($8, STRING_TABLE._js_gt_entity_str);
    if ($18) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 7:
    var $20 = __ZN2js12StringBuffer6appendILj6EEEbRAT__Kc($8, STRING_TABLE._js_amp_entity_str);
    if ($20) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 8:
    if ($9) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $23 = __ZN2js12StringBuffer6appendILj7EEEbRAT__Kc($sb, STRING_TABLE.__ZL23js_leftcurly_entity_str);
    if ($23) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 10:
    var $25 = __ZN2js12StringBuffer6appendEt($7, $13);
    if ($25) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 11:
    var $cp_0 = $cp_0 + 2 | 0;
    __label__ = 3;
    break;
   case 12:
    var $29 = $sb;
    var $30 = __ZN2js12StringBuffer12finishStringEv($29);
    var $_0 = $30 | 0;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19js_ValueToXMLStringP9JSContextRKN2JS5ValueE($cx, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  var $1 = __ZL11ToXMLStringP9JSContextN2JS5ValueEj($cx, $v_0_0_0_val$0, $v_0_0_0_val$1, 0);
  return $1;
}

function __ZL11ToXMLStringP9JSContextN2JS5ValueEj($cx, $_0_0_0_val$0, $_0_0_0_val$1, $toSourceFlag) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 172;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $sb = __stackBase__ + 8;
    var $sb1 = __stackBase__ + 88;
    var $anch = __stackBase__ + 168;
    var $1 = $v | 0;
    HEAP32[$1 >> 2] = $_0_0_0_val$0;
    HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
    var $2 = _JSVAL_IS_NULL4395($_0_0_0_val$0, $_0_0_0_val$1);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $st$0$0 = $1 | 0;
    var $5$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $1 + 4 | 0;
    var $5$1 = HEAP32[$st$0$1 >> 2];
    var $6 = _JSVAL_IS_VOID4396($5$0, $5$1);
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $st$0$0 = $1 | 0;
    var $9$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $1 + 4 | 0;
    var $9$1 = HEAP32[$st$0$1 >> 2];
    var $10 = _JSVAL_IS_NULL4395($9$0, $9$1);
    var $_ = ($10 | 0) != 0 ? STRING_TABLE.__str483817 : STRING_TABLE.__str493818;
    var $12 = $_ | 0;
    var $13 = $cx;
    _JS_ReportErrorNumber($13, 4, 180, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $12, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 4:
    var $st$0$0 = $1 | 0;
    var $15$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $1 + 4 | 0;
    var $15$1 = HEAP32[$st$0$1 >> 2];
    var $16 = _JSVAL_IS_BOOLEAN4407($15$0, $15$1);
    if (($16 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $st$0$0 = $1 | 0;
    var $19$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $1 + 4 | 0;
    var $19$1 = HEAP32[$st$0$1 >> 2];
    var $20 = _JSVAL_IS_NUMBER($19$0, $19$1);
    if (($20 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = $cx;
    var $st$1$0 = $1 | 0;
    var $v_idx1_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $1 + 4 | 0;
    var $v_idx1_val$1 = HEAP32[$st$1$1 >> 2];
    var $24 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($23, $v_idx1_val$0, $v_idx1_val$1);
    var $_0 = $24;
    __label__ = 14;
    break;
   case 7:
    var $st$0$0 = $1 | 0;
    var $26$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $1 + 4 | 0;
    var $26$1 = HEAP32[$st$0$1 >> 2];
    var $27 = _JSVAL_IS_STRING4320($26$0, $26$1);
    if (($27 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $30 = $sb;
    var $31 = $cx;
    __ZN2js12StringBufferC1EP9JSContext($30, $31);
    var $32$0 = HEAP32[$1 >> 2];
    var $32$1 = HEAP32[$1 + 4 >> 2];
    var $33 = _JSVAL_TO_STRING4321($32$0, $32$1);
    var $34 = __ZL18EscapeElementValueP9JSContextRN2js12StringBufferEP8JSStringj($cx, $sb, $33, $toSourceFlag);
    var $35 = $34 | 0;
    __ZN2js12StringBufferD1Ev($30);
    var $_0 = $35;
    __label__ = 14;
    break;
   case 9:
    var $st$0$0 = $1 | 0;
    var $37$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $1 + 4 | 0;
    var $37$1 = HEAP32[$st$0$1 >> 2];
    var $38 = _JSVAL_TO_OBJECT4304($37$0, $37$1);
    var $_idx1_val = HEAP32[$38 + 4 >> 2];
    var $40 = __ZNK8JSObject5isXMLEv($_idx1_val);
    if ($40) {
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $42 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE4408($cx, $v);
    if ($42) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 11:
    var $44 = $cx;
    var $st$1$0 = $1 | 0;
    var $v_idx_val$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $1 + 4 | 0;
    var $v_idx_val$1 = HEAP32[$st$1$1 >> 2];
    var $45 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($44, $v_idx_val$0, $v_idx_val$1);
    if (($45 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $48 = $sb1;
    var $49 = $cx;
    __ZN2js12StringBufferC1EP9JSContext($48, $49);
    var $50 = __ZL18EscapeElementValueP9JSContextRN2js12StringBufferEP8JSStringj($cx, $sb1, $45, $toSourceFlag);
    var $51 = $50 | 0;
    __ZN2js12StringBufferD1Ev($48);
    var $_0 = $51;
    __label__ = 14;
    break;
   case 13:
    __ZN2JS6AnchorIP8JSObjectEC1ES2_($anch, $38);
    var $_idx_val = HEAP32[$38 + 24 >> 2];
    var $54 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $55 = $54;
    var $56 = __ZL14XMLToXMLStringP9JSContextP5JSXMLPK10JSXMLArrayj($cx, $55, 0, $toSourceFlag);
    var $_0 = $56;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11ToXMLStringP9JSContextN2JS5ValueEj["X"] = 1;

function __Z13js_GetAnyNameP9JSContextPi($cx, $idp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $cx;
    var $2 = __ZNK9JSContext5hasfpEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK9JSContext2fpEv($1);
    var $5 = __ZNK2js10StackFrame10scopeChainEv($4);
    var $6 = $5;
    var $7 = __ZNK8JSObject9getGlobalEv($6);
    var $13 = $7;
    __label__ = 4;
    break;
   case 3:
    var $13 = HEAP32[$cx + 132 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $13;
    __ZNK8JSObject15getReservedSlotEj($v, $13, 35);
    var $v_idx1 = $v | 0;
    var $v_idx1_val$0 = HEAP32[$v_idx1 >> 2];
    var $v_idx1_val$1 = HEAP32[$v_idx1 + 4 >> 2];
    var $15 = __ZNK2JS5Value11isUndefinedEv($v_idx1_val$0, $v_idx1_val$1);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      var $v_idx_val$1 = $v_idx1_val$1;
      var $v_idx_val$0 = $v_idx1_val$0;
      __label__ = 9;
      break;
    }
   case 5:
    var $17 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_4355($cx, __ZN2js12AnyNameClassE, $13);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = HEAP32[$cx + 52 >> 2];
    var $24 = HEAP32[$21 + 144136 >> 2] | 0;
    var $27 = HEAP32[$21 + 210412 >> 2] | 0;
    var $28 = __ZL12InitXMLQNameP9JSContextP8JSObjectP14JSLinearStringS4_P6JSAtom($cx, $17, $24, $24, $27);
    if ($28) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    var $30 = $17;
    __ZN2JS5Value9setObjectER8JSObject($v, $30);
    var $31 = $cx;
    var $33 = __Z18js_SetReservedSlotP9JSContextP8JSObjectjRKN2JS5ValueE($31, $13, 35, $v);
    if ($33) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $v_idx_val$1 = HEAP32[$v_idx1 + 4 >> 2];
    var $v_idx_val$0 = HEAP32[$v_idx1 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $v_idx_val$0;
    var $v_idx_val$1;
    var $35 = __ZNK2JS5Value8toObjectEv($v_idx_val$0, $v_idx_val$1);
    var $36 = $35;
    var $37 = _OBJECT_TO_JSID4356($36);
    HEAP32[$idp >> 2] = $37;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z13js_GetAnyNameP9JSContextPi["X"] = 1;

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_4355($cx, $clasp, $parent) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb4379($4);
  var $6 = __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE4380($cx, $clasp, $parent, $5);
  return $6;
}

function _JSID_IS_VOID4359($iden) {
  return ($iden | 0) == 2 & 1;
}

function __ZN16JSXMLArrayCursor7getNextEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this >> 2];
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $this + 4 | 0;
    var $6 = HEAPU32[$5 >> 2];
    if ($6 >>> 0 < HEAPU32[$2 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[$5 >> 2] = $6 + 1 | 0;
    var $15 = HEAP32[HEAP32[$2 + 8 >> 2] + ($6 << 2) >> 2];
    HEAP32[$this + 16 >> 2] = $15;
    var $_0 = $15;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18js_FindXMLPropertyP9JSContextRKN2JS5ValueEPP8JSObjectPi($cx, $nameval_0_0_0_val$0, $nameval_0_0_0_val$1, $objp, $idp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $funid = __stackBase__ + 8;
    var $pobj = __stackBase__ + 12;
    var $found = __stackBase__ + 16;
    var $prop = __stackBase__ + 20;
    var $1 = __stackBase__ + 24;
    var $printable = __stackBase__ + 32;
    var $2 = __stackBase__ + 36;
    var $3 = __ZNK2JS5Value8toObjectEv($nameval_0_0_0_val$0, $nameval_0_0_0_val$1);
    var $4 = $3;
    var $_idx3_val = HEAP32[$3 + 4 >> 2];
    var $5 = __ZNK8JSObject8getClassEv($_idx3_val);
    if (($5 | 0) == (__ZN2js12AnyNameClassE | 0)) {
      __label__ = 2;
      break;
    } else {
      var $nameobj_0 = $4;
      __label__ = 3;
      break;
    }
   case 2:
    var $12 = HEAP32[HEAP32[$cx + 52 >> 2] + 210412 >> 2] | 0;
    _STRING_TO_JSVAL4322($1, $12);
    var $13 = $1 | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $v | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    var $16 = $cx;
    var $17 = __Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE($16, __ZN2js10QNameClassE, 0, 1, $v);
    var $18 = $17;
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      var $nameobj_0 = $18;
      __label__ = 3;
      break;
    }
   case 3:
    var $nameobj_0;
    var $21 = __ZL29GetLocalNameFromFunctionQNameP8JSObjectPiP9JSContext($nameobj_0, $funid, $cx);
    if ($21) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$funid >> 2] = 2;
    __label__ = 5;
    break;
   case 5:
    var $25 = $cx + 60 | 0;
    var $26 = __ZNK2js12ContextStack25currentScriptedScopeChainEv($25);
    var $28 = $cx;
    var $29 = $prop;
    var $obj_0 = $26;
    __label__ = 6;
    break;
   case 6:
    var $obj_0;
    var $target_0 = $obj_0;
    __label__ = 7;
    break;
   case 7:
    var $target_0;
    var $_idx2_val = HEAP32[$target_0 + 4 >> 2];
    var $33 = __ZNK8JSObject8getClassEv($_idx2_val);
    if (($33 | 0) == (__ZN2js9WithClassE | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $_idx4_val_idx_val = HEAP32[HEAP32[$target_0 + 36 >> 2] >> 2];
    var $37 = __ZNK8JSObject8getProtoEv($_idx4_val_idx_val);
    if (($37 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $target_0 = $37;
    __label__ = 7;
    break;
   case 10:
    var $41 = $target_0;
    var $42 = __ZNK8JSObject5isXMLEv($_idx2_val);
    var $43 = HEAP32[$funid >> 2];
    var $44 = _JSID_IS_VOID4359($43);
    var $45 = ($44 | 0) != 0;
    if ($42) {
      __label__ = 11;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 11:
    if ($45) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $_idx_val = HEAP32[$target_0 + 24 >> 2];
    var $49 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $50 = $49;
    var $51 = __ZL16HasNamedPropertyP5JSXMLP8JSObject($50, $nameobj_0);
    HEAP32[$found >> 2] = $51;
    var $56 = $51;
    __label__ = 15;
    break;
   case 13:
    var $53 = __ZL19HasFunctionPropertyP9JSContextP8JSObjectiPi($cx, $target_0, $43, $found);
    if (($53 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $56 = HEAP32[$found >> 2];
    __label__ = 15;
    break;
   case 15:
    var $56;
    if (($56 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $59 = _OBJECT_TO_JSID4356($nameobj_0);
    HEAP32[$idp >> 2] = $59;
    HEAP32[$objp >> 2] = $target_0;
    var $_0 = 1;
    __label__ = 26;
    break;
   case 17:
    if ($45) {
      __label__ = 21;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $62 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($41, $28, $43, $pobj, $29);
    if (($62 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    if ((HEAP32[$prop >> 2] | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    HEAP32[$idp >> 2] = $43;
    HEAP32[$objp >> 2] = $target_0;
    var $_0 = 1;
    __label__ = 26;
    break;
   case 21:
    var $_idx1_val = HEAP32[$obj_0 + 20 >> 2];
    var $70 = __ZNK8JSObject9getParentEv($_idx1_val);
    var $71 = $70;
    if (($70 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      var $obj_0 = $71;
      __label__ = 6;
      break;
    }
   case 22:
    __ZN16JSAutoByteStringC1Ev($printable);
    var $74 = __ZL20ConvertQNameToStringP9JSContextP8JSObject($cx, $nameobj_0);
    if (($74 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    __ZN2JSL11StringValueEP8JSString4311($2, $74);
    var $77 = $cx;
    var $78 = $printable;
    var $_idx6 = $2 | 0;
    var $_idx6_val$0 = HEAP32[$_idx6 >> 2];
    var $_idx6_val$1 = HEAP32[$_idx6 + 4 >> 2];
    var $79 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($77, $_idx6_val$0, $_idx6_val$1, $78);
    if (($79 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $printable_idx6_val = HEAP32[$printable >> 2];
    var $82 = __ZNK16JSAutoByteString3ptrEv($printable_idx6_val);
    var $83 = _JS_ReportErrorFlagsAndNumber($28, 0, 197, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $82, tempInt));
    __label__ = 25;
    break;
   case 25:
    var $printable_idx_val = HEAP32[$printable >> 2];
    __ZN16JSAutoByteStringD1Ev($printable_idx_val);
    var $_0 = 0;
    __label__ = 26;
    break;
   case 26:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18js_FindXMLPropertyP9JSContextRKN2JS5ValueEPP8JSObjectPi["X"] = 1;

function __ZL16HasNamedPropertyP5JSXMLP8JSObject($xml, $nameqn) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cursor = __stackBase__;
    var $2 = HEAP32[$xml + 16 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 2:
    var $4 = $xml + 24 | 0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor, $4);
    __label__ = 3;
    break;
   case 3:
    var $6 = __ZN16JSXMLArrayCursor7getNextEv($cursor);
    if (($6 | 0) == 0) {
      var $found_1 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $6;
    var $10 = __ZL16HasNamedPropertyP5JSXMLP8JSObject($9, $nameqn);
    if (($10 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $found_1 = $10;
      __label__ = 5;
      break;
    }
   case 5:
    var $found_1;
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_0 = $found_1;
    __label__ = 12;
    break;
   case 6:
    var $_idx_val = HEAP32[$nameqn + 4 >> 2];
    var $15 = __ZNK8JSObject8getClassEv($_idx_val);
    var $16 = ($15 | 0) == (__ZN2js18AttributeNameClassE | 0);
    var $array_0 = $16 ? $xml + 56 | 0 : $xml + 24 | 0;
    var $matcher_0 = $16 ? 278 : 280;
    var $19 = $array_0 | 0;
    var $20 = HEAPU32[$19 >> 2];
    var $21 = $array_0 + 8 | 0;
    var $i_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $i_0;
    if ($i_0 >>> 0 < $20 >>> 0) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 8:
    if ($i_0 >>> 0 < HEAPU32[$19 >> 2] >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $30 = HEAP32[HEAP32[$21 >> 2] + ($i_0 << 2) >> 2];
    if (($30 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $33 = $30;
    var $34 = FUNCTION_TABLE[$matcher_0]($nameqn, $33);
    if (($34 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 7;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19HasFunctionPropertyP9JSContextP8JSObjectiPi($cx, $obj, $funid, $found) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $tvr = __stackBase__ + 8;
    var $1 = $cx;
    var $2 = $obj;
    var $3 = $prop;
    var $4 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($1, $2, $funid, $pobj, $3);
    if (($4 | 0) == 0) {
      var $_1 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$prop >> 2];
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $30 = $7;
      __label__ = 7;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $11 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $12 = $11;
    var $13 = __ZL16HasSimpleContentP5JSXML($12);
    if (($13 | 0) == 0) {
      var $30 = $7;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = $tvr;
    var $17 = $cx;
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($16, $17, 0);
    var $18 = $tvr;
    var $19 = __ZN2js16AutoObjectRooter4addrEv($18);
    var $20 = $19;
    var $21 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($1, 0, 9, $20, 0);
    if (($21 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_idx1_val = HEAP32[$tvr + 12 >> 2];
    var $25 = __ZNK2js16AutoObjectRooter6objectEv($_idx1_val);
    var $26 = $25;
    var $27 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($1, $26, $funid, $pobj, $3);
    var $28 = ($27 | 0) == 0;
    __ZN2js16AutoObjectRooterD1Ev($16);
    if ($28) {
      var $_1 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $30 = HEAP32[$prop >> 2];
    __label__ = 7;
    break;
   case 7:
    var $30;
    HEAP32[$found >> 2] = ($30 | 0) != 0 & 1;
    var $_1 = 1;
    __label__ = 9;
    break;
   case 8:
    __ZN2js16AutoObjectRooterD1Ev($16);
    var $_1 = 0;
    __label__ = 9;
    break;
   case 9:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20ConvertQNameToStringP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $anchor = __stackBase__;
    var $1 = __ZNK8JSObject10getNameURIEv($obj);
    var $2 = $1 | 0;
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $str_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 210416 >> 2] | 0;
    __label__ = 6;
    break;
   case 3:
    var $_idx2_val = HEAP32[$1 >> 2];
    var $11 = __ZNK8JSString5emptyEv($_idx2_val);
    var $13 = HEAP32[$cx + 52 >> 2];
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $str_0 = HEAP32[$13 + 144136 >> 2] | 0;
    __label__ = 6;
    break;
   case 5:
    var $21 = HEAP32[$13 + 210400 >> 2] | 0;
    var $22 = $cx;
    var $23 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($22, $2, $21);
    if (($23 | 0) == 0) {
      var $_1 = 0;
      __label__ = 13;
      break;
    } else {
      var $str_0 = $23;
      __label__ = 6;
      break;
    }
   case 6:
    var $str_0;
    var $26 = __ZNK8JSObject17getQNameLocalNameEv($obj);
    var $27 = $26 | 0;
    var $28 = $cx;
    var $29 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($28, $str_0, $27);
    if (($29 | 0) == 0) {
      var $_1 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx_val = HEAP32[$obj + 4 >> 2];
    var $33 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($33 | 0) == (__ZN2js18AttributeNameClassE | 0)) {
      __label__ = 8;
      break;
    } else {
      var $_1 = $29;
      __label__ = 13;
      break;
    }
   case 8:
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $29);
    var $_idx1_val = HEAP32[$29 >> 2];
    var $36 = __ZNK8JSString6lengthEv($_idx1_val);
    var $37 = $36 << 1;
    var $38 = $37 + 4 | 0;
    var $39 = __ZN9JSContext7malloc_Ej($28, $38);
    var $40 = $39;
    if (($39 | 0) == 0) {
      var $_1 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    HEAP16[$40 >> 1] = 64;
    var $43 = __ZN8JSString8getCharsEP9JSContext($29, $28);
    if (($43 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    __ZN9JSContext5free_EPv($39);
    var $_1 = 0;
    __label__ = 13;
    break;
   case 11:
    var $47 = $39 + 2 | 0;
    var $48 = $43;
    _memcpy($47, $48, $37, 1);
    var $49 = $36 + 1 | 0;
    HEAP16[$40 + ($49 << 1) >> 1] = 0;
    var $51 = $cx;
    var $52 = __Z12js_NewStringP9JSContextPtj($51, $40, $49);
    var $53 = $52 | 0;
    if (($52 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $_1 = $53;
      __label__ = 13;
      break;
    }
   case 12:
    __ZN9JSContext5free_EPv($39);
    var $_1 = 0;
    __label__ = 13;
    break;
   case 13:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL20ConvertQNameToStringP9JSContextP8JSObject["X"] = 1;

function __Z20js_GetXMLDescendantsP9JSContextP8JSObjectN2JS5ValueEPS4_($cx, $obj, $_0_0_0_val$0, $_0_0_0_val$1, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZL10GetPrivateP9JSContextP8JSObjectPKc($cx, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL11DescendantsP9JSContextP5JSXMLN2JS5ValueE($cx, $2, $_0_0_0_val$0, $_0_0_0_val$1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAP32[$5 >> 2];
    _OBJECT_TO_JSVAL4318($1, $9);
    var $10 = $1 | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = $vp | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10GetPrivateP9JSContextP8JSObjectPKc($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx2_val = HEAP32[$obj + 4 >> 2];
    var $2 = __ZNK8JSObject5isXMLEv($_idx2_val);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject8getClassEv($_idx2_val);
    var $6 = HEAP32[$4 >> 2];
    var $7 = $cx;
    _JS_ReportErrorNumber($7, 4, 188, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE._js_XML_str | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str444290 | 0, HEAP32[tempInt + 8 >> 2] = $6, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $10 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11DescendantsP9JSContextP5JSXMLN2JS5ValueE($cx, $xml, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $funid = __stackBase__;
    var $1 = __ZL9ToXMLNameP9JSContextN2JS5ValueEPi($cx, $_0_0_0_val$0, $_0_0_0_val$1, $funid);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 0);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$4 + 24 >> 2];
    var $8 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $9 = $8;
    var $10 = HEAP32[$funid >> 2];
    var $11 = _JSID_IS_VOID4359($10);
    if (($11 | 0) == 0) {
      var $_0 = $9;
      __label__ = 15;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = $8 + 12 | 0;
    HEAP32[$15 >> 2] = $1;
    if ((HEAP32[$xml + 16 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 5:
    var $20 = $xml + 24 | 0;
    var $21 = HEAPU32[$20 >> 2];
    var $22 = $xml + 32 | 0;
    var $ok_0 = 1;
    var $i_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $i_0;
    var $ok_0;
    if ($i_0 >>> 0 < $21 >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $ok_2 = $ok_0;
      __label__ = 13;
      break;
    }
   case 7:
    if ($i_0 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 8;
      break;
    } else {
      var $ok_1 = $ok_0;
      __label__ = 11;
      break;
    }
   case 8:
    var $31 = HEAPU32[HEAP32[$22 >> 2] + ($i_0 << 2) >> 2];
    var $32 = $31;
    if (($31 | 0) == 0) {
      var $ok_1 = $ok_0;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ((HEAP32[$31 + 16 >> 2] | 0) == 1) {
      __label__ = 10;
      break;
    } else {
      var $ok_1 = $ok_0;
      __label__ = 11;
      break;
    }
   case 10:
    var $40 = __ZL17DescendantsHelperP9JSContextP5JSXMLP8JSObjectS2_($cx, $32, $1, $9);
    if (($40 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      var $ok_1 = $40;
      __label__ = 11;
      break;
    }
   case 11:
    var $ok_1;
    var $ok_0 = $ok_1;
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 6;
    break;
   case 12:
    var $44 = __ZL17DescendantsHelperP9JSContextP5JSXMLP8JSObjectS2_($cx, $xml, $1, $9);
    var $ok_2 = $44;
    __label__ = 13;
    break;
   case 13:
    var $ok_2;
    if (($ok_2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    HEAP32[$15 >> 2] = 0;
    var $_0 = $9;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11DescendantsP9JSContextP5JSXMLN2JS5ValueE["X"] = 1;

function __Z24js_DeleteXMLListElementsP9JSContextP8JSObject($listobj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$listobj + 24 >> 2];
    var $2 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $3 = $2;
    var $6 = HEAP32[$2 + 24 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $n_01 = $6;
      __label__ = 2;
      break;
    }
   case 2:
    var $n_01;
    __ZL17DeleteListElementP9JSContextP5JSXMLj($3, 0);
    var $8 = $n_01 - 1 | 0;
    if (($8 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $n_01 = $8;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17DeleteListElementP9JSContextP5JSXMLj($xml, $index) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $xml + 24 | 0;
    if (HEAPU32[$1 >> 2] >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $9 = HEAPU32[HEAP32[$xml + 32 >> 2] + ($index << 2) >> 2];
    if (($9 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = HEAPU32[$9 + 8 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP32[$9 + 16 >> 2] | 0) == 2) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $24 = HEAP32[$9 + 12 >> 2];
    __ZL19DeleteNamedPropertyP9JSContextP5JSXMLP8JSObjecti($14, $24, 1);
    __label__ = 7;
    break;
   case 6:
    var $_idx_val = HEAP32[$14 + 24 >> 2];
    var $_idx1_val = HEAP32[$14 + 32 >> 2];
    var $26 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx_val, $_idx1_val, $9, 0);
    __ZL13DeleteByIndexP9JSContextP5JSXMLj($14, $26);
    __label__ = 7;
    break;
   case 7:
    __ZL14XMLArrayDeleteP9JSContextP10JSXMLArrayji($1, $index, 1);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18xmlfilter_finalizeP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $2 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN9JSContext7delete_I11JSXMLFilterEEvPT_($5);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15xmlfilter_traceP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $2 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($2 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$2 >> 2];
    var $8 = $trc;
    _JS_CallTracer($8, $7, 3);
    var $11 = HEAP32[$2 + 4 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = $11;
    _JS_CallTracer($8, $14, 3);
    __label__ = 4;
    break;
   case 4:
    var $18 = HEAP32[$2 + 8 >> 2];
    if (($18 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $21 = $18;
    _JS_CallTracer($8, $21, 3);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z20js_StepXMLListFilterP9JSContexti($cx, $initialized) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = $cx;
    var $6 = __ZNK9JSContext4regsEv($5);
    var $8 = HEAP32[$6 >> 2];
    var $10 = $8 - 16 | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    if (($initialized | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    var $13 = _JSVAL_IS_PRIMITIVE4303($11$0, $11$1);
    if (($13 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $st$0$0 = $10 | 0;
    var $16$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $10 + 4 | 0;
    var $16$1 = HEAP32[$st$0$1 >> 2];
    var $17 = _JSVAL_TO_OBJECT4304($16$0, $16$1);
    var $_idx4_val = HEAP32[$17 + 4 >> 2];
    var $19 = __ZNK8JSObject5isXMLEv($_idx4_val);
    if ($19) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $st$0$0 = $10 | 0;
    var $_idx9_val$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $10 + 4 | 0;
    var $_idx9_val$1 = HEAP32[$st$0$1 >> 2];
    var $21 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($5, 0, 217, -2, $_idx9_val$0, $_idx9_val$1, 0, 0);
    var $_0 = 0;
    __label__ = 18;
    break;
   case 5:
    var $st$0$0 = $10 | 0;
    var $23$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $10 + 4 | 0;
    var $23$1 = HEAP32[$st$0$1 >> 2];
    var $24 = _JSVAL_TO_OBJECT4304($23$0, $23$1);
    var $_idx3_val = HEAP32[$24 + 24 >> 2];
    var $26 = __ZNK8JSObject10getPrivateEv($_idx3_val);
    var $27 = $26;
    if ((HEAP32[$26 + 16 >> 2] | 0) == 0) {
      var $list_0 = $27;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $33 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 0);
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _OBJECT_TO_JSVAL4318($1, $33);
    var $36 = $1 | 0;
    var $37$0 = HEAP32[$36 >> 2];
    var $37$1 = HEAP32[$36 + 4 >> 2];
    var $38 = $8 - 8 | 0;
    var $st$7$0 = $38 | 0;
    HEAP32[$st$7$0 >> 2] = $37$0;
    var $st$7$1 = $38 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $37$1;
    var $_idx2_val = HEAP32[$33 + 24 >> 2];
    var $40 = __ZNK8JSObject10getPrivateEv($_idx2_val);
    var $41 = $40;
    var $42 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $41, $27);
    if (($42 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      var $list_0 = $41;
      __label__ = 8;
      break;
    }
   case 8:
    var $list_0;
    var $45 = __ZN2jsL22GetGlobalForScopeChainEP9JSContext4366($cx);
    var $46 = $45 | 0;
    var $47 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_4355($cx, _js_XMLFilterClass, $46);
    if (($47 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $51 = __ZN9JSContext4new_I11JSXMLFilterP5JSXMLP10JSXMLArrayEEPT_T0_T1_($cx, $list_0, $list_0 + 24 | 0);
    if (($51 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $54 = $51;
    var $55 = $47;
    __ZN8JSObject10setPrivateEPv($55, $54);
    _OBJECT_TO_JSVAL4318($2, $47);
    var $56 = $2 | 0;
    var $57$0 = HEAP32[$56 >> 2];
    var $57$1 = HEAP32[$56 + 4 >> 2];
    var $st$9$0 = $10 | 0;
    HEAP32[$st$9$0 >> 2] = $57$0;
    var $st$9$1 = $10 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $57$1;
    var $58 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 0);
    if (($58 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_idx1_val = HEAP32[$58 + 24 >> 2];
    var $62 = __ZNK8JSObject10getPrivateEv($_idx1_val);
    var $63 = $62;
    HEAP32[$51 + 4 >> 2] = $63;
    var $filter_0 = $51;
    __label__ = 14;
    break;
   case 12:
    var $66 = _JSVAL_TO_OBJECT4304($11$0, $11$1);
    var $_idx_val = HEAP32[$66 + 24 >> 2];
    var $68 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $69 = $68;
    var $70 = $8 - 8 | 0;
    var $71 = __Z17js_ValueToBooleanRKN2JS5ValueE($70);
    if (($71 | 0) == 0) {
      var $filter_0 = $69;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $76 = HEAP32[$68 + 4 >> 2];
    var $79 = HEAP32[$68 + 8 >> 2];
    var $80 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $76, $79);
    if (($80 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      var $filter_0 = $69;
      __label__ = 14;
      break;
    }
   case 14:
    var $filter_0;
    var $83 = $filter_0 + 12 | 0;
    var $84 = __ZN16JSXMLArrayCursor7getNextEv($83);
    var $85 = $84;
    HEAP32[$filter_0 + 8 >> 2] = $85;
    if (($84 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    __ZN16JSXMLArrayCursor10disconnectEv($83);
    var $92 = HEAP32[HEAP32[$filter_0 + 4 >> 2] >> 2];
    _OBJECT_TO_JSVAL4318($3, $92);
    var $93 = $3 | 0;
    var $st$7$0 = $93 | 0;
    var $94$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $93 + 4 | 0;
    var $94$1 = HEAP32[$st$7$1 >> 2];
    var $st$11$0 = $10 | 0;
    HEAP32[$st$11$0 >> 2] = $94$0;
    var $st$11$1 = $10 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $94$1;
    var $kidobj_0 = 0;
    __label__ = 17;
    break;
   case 16:
    var $96 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $85);
    if (($96 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      var $kidobj_0 = $96;
      __label__ = 17;
      break;
    }
   case 17:
    var $kidobj_0;
    _OBJECT_TO_JSVAL4318($4, $kidobj_0);
    var $99 = $4 | 0;
    var $100$0 = HEAP32[$99 >> 2];
    var $100$1 = HEAP32[$99 + 4 >> 2];
    var $101 = $8 - 8 | 0;
    var $st$8$0 = $101 | 0;
    HEAP32[$st$8$0 >> 2] = $100$0;
    var $st$8$1 = $101 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $100$1;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z20js_StepXMLListFilterP9JSContexti["X"] = 1;

function __ZN2jsL22GetGlobalForScopeChainEP9JSContext4366($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $scope = __stackBase__;
    var $1 = $cx;
    var $2 = __ZNK9JSContext5hasfpEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK9JSContext2fpEv($1);
    var $5 = __ZNK2js10StackFrame10scopeChainEv($4);
    var $6 = $5;
    var $7 = __ZNK8JSObject9getGlobalEv($6);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 3:
    var $11 = HEAP32[$cx + 132 >> 2];
    HEAP32[$scope >> 2] = $11;
    var $12 = $cx;
    var $13 = $scope;
    var $14 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($12, $13);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = HEAP32[$scope >> 2];
    var $18 = __ZN8JSObject8asGlobalEv($17);
    var $_0 = $18;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext4new_I11JSXMLFilterP5JSXMLP10JSXMLArrayEEPT_T0_T1_($this, $p1, $p2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZN9JSContext7malloc_Ej($1, 32);
    if (($2 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN11JSXMLFilterC1EP5JSXMLP10JSXMLArray($5, $p1, $p2);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19js_ValueToXMLObjectP9JSContextRKN2JS5ValueE($cx, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  var $1 = __ZL5ToXMLP9JSContextN2JS5ValueE($cx, $v_0_0_0_val$0, $v_0_0_0_val$1);
  return $1;
}

function __ZNK8JSString5emptyEv($this_0_0_0_val) {
  return $this_0_0_0_val >>> 0 < 16;
}

function __ZN16JSXMLArrayCursorC2EP10JSXMLArray($this, $array) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this >> 2] = $array;
    HEAP32[$this + 4 >> 2] = 0;
    var $3 = $this + 8 | 0;
    var $4 = $array + 12 | 0;
    var $5 = HEAP32[$4 >> 2];
    HEAP32[$3 >> 2] = $5;
    HEAP32[$this + 12 >> 2] = $4;
    HEAP32[$this + 16 >> 2] = 0;
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $5 + 12 | 0;
    HEAP32[$10 >> 2] = $3;
    __label__ = 3;
    break;
   case 3:
    HEAP32[$4 >> 2] = $this;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JS6AnchorIP8JSObjectEC2ES2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js2gcL15GetGCObjectKindEjb4379($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5ToXMLP9JSContextN2JS5ValueE($cx, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSVAL_IS_PRIMITIVE4303($_0_0_0_val$0, $_0_0_0_val$1);
    if (($1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSVAL_IS_NULL4395($_0_0_0_val$0, $_0_0_0_val$1);
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 3:
    var $7 = _JSVAL_IS_VOID4396($_0_0_0_val$0, $_0_0_0_val$1);
    if (($7 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 4:
    var $10 = _JSVAL_TO_OBJECT4304($_0_0_0_val$0, $_0_0_0_val$1);
    var $_idx2_val = HEAP32[$10 + 4 >> 2];
    var $12 = __ZNK8JSObject5isXMLEv($_idx2_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 5:
    var $_idx_val = HEAP32[$10 + 24 >> 2];
    var $15 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if ((HEAP32[$15 + 16 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $10;
      __label__ = 21;
      break;
    }
   case 6:
    if ((HEAP32[$15 + 24 >> 2] | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 7:
    var $29 = HEAP32[HEAP32[$15 + 32 >> 2] >> 2];
    if (($29 | 0) == 0) {
      var $_0 = $10;
      __label__ = 21;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $32 = $29;
    var $33 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $32);
    var $_0 = $33;
    __label__ = 21;
    break;
   case 9:
    var $35 = __ZNK8JSObject8getClassEv($_idx2_val);
    if (($35 | 0) != (__ZN2js11StringClassE | 0) & ($35 | 0) != (__ZN2js11NumberClassE | 0) & ($35 | 0) != (__ZN2js12BooleanClassE | 0)) {
      __label__ = 20;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $40 = $cx;
    var $41 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($40, $_0_0_0_val$0, $_0_0_0_val$1);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_idx6_val = HEAP32[$41 >> 2];
    var $44 = __ZNK8JSString5emptyEv($_idx6_val);
    if ($44) {
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $46 = __ZL14ParseXMLSourceP9JSContextP8JSString($cx, $41);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if (HEAPU32[$46 + 16 >> 2] >>> 0 < 2) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $54 = HEAP32[$46 + 24 >> 2];
    if (($54 | 0) == 0) {
      __label__ = 15;
      break;
    } else if (($54 | 0) == 1) {
      __label__ = 16;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 15:
    var $55 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 4);
    if (($55 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      var $obj_0 = $55;
      __label__ = 19;
      break;
    }
   case 16:
    var $58 = __ZL14OrphanXMLChildP9JSContextP5JSXMLj($cx, $46, 0);
    if (($58 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $61 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $58);
    if (($61 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      var $obj_0 = $61;
      __label__ = 19;
      break;
    }
   case 18:
    var $64 = $cx;
    _JS_ReportErrorNumber($64, 4, 133, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 21;
    break;
   case 19:
    var $obj_0;
    var $_0 = $obj_0;
    __label__ = 21;
    break;
   case 20:
    var $67 = $cx;
    var $68 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($67, 0, 180, 0, $_0_0_0_val$0, $_0_0_0_val$1, 0, 0);
    var $_0 = 0;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL5ToXMLP9JSContextN2JS5ValueE["X"] = 1;

function __Z23js_ValueToXMLListObjectP9JSContextRKN2JS5ValueE($cx, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  var $1 = __ZL9ToXMLListP9JSContextN2JS5ValueE($cx, $v_0_0_0_val$0, $v_0_0_0_val$1);
  return $1;
}

function __ZL9ToXMLListP9JSContextN2JS5ValueE($cx, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSVAL_IS_PRIMITIVE4303($_0_0_0_val$0, $_0_0_0_val$1);
    if (($1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSVAL_IS_NULL4395($_0_0_0_val$0, $_0_0_0_val$1);
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 3:
    var $7 = _JSVAL_IS_VOID4396($_0_0_0_val$0, $_0_0_0_val$1);
    if (($7 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 4:
    var $10 = _JSVAL_TO_OBJECT4304($_0_0_0_val$0, $_0_0_0_val$1);
    var $_idx4_val = HEAP32[$10 + 4 >> 2];
    var $12 = __ZNK8JSObject5isXMLEv($_idx4_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $_idx2_val = HEAP32[$10 + 24 >> 2];
    var $15 = __ZNK8JSObject10getPrivateEv($_idx2_val);
    var $16 = $15;
    if ((HEAP32[$15 + 16 >> 2] | 0) == 0) {
      var $_0 = $10;
      __label__ = 21;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 0);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx1_val = HEAP32[$22 + 24 >> 2];
    var $26 = __ZNK8JSObject10getPrivateEv($_idx1_val);
    var $27 = $26;
    var $28 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $27, $16);
    var $_ = ($28 | 0) == 0 ? 0 : $22;
    var $_0 = $_;
    __label__ = 21;
    break;
   case 8:
    var $31 = __ZNK8JSObject8getClassEv($_idx4_val);
    if (($31 | 0) != (__ZN2js11StringClassE | 0) & ($31 | 0) != (__ZN2js11NumberClassE | 0) & ($31 | 0) != (__ZN2js12BooleanClassE | 0)) {
      __label__ = 20;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $36 = $cx;
    var $37 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($36, $_0_0_0_val$0, $_0_0_0_val$1);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_idx8_val = HEAP32[$37 >> 2];
    var $40 = __ZNK8JSString5emptyEv($_idx8_val);
    if ($40) {
      var $length_0 = 0;
      var $xml_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $42 = __ZL14ParseXMLSourceP9JSContextP8JSString($cx, $37);
    if (($42 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (HEAPU32[$42 + 16 >> 2] >>> 0 < 2) {
      __label__ = 13;
      break;
    } else {
      var $length_0 = 0;
      var $xml_0 = $42;
      __label__ = 14;
      break;
    }
   case 13:
    var $length_0 = HEAP32[$42 + 24 >> 2];
    var $xml_0 = $42;
    __label__ = 14;
    break;
   case 14:
    var $xml_0;
    var $length_0;
    var $52 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 0);
    if (($52 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $_idx_val = HEAP32[$52 + 24 >> 2];
    var $56 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $57 = $56;
    var $i_0 = 0;
    __label__ = 16;
    break;
   case 16:
    var $i_0;
    if ($i_0 >>> 0 < $length_0 >>> 0) {
      __label__ = 17;
      break;
    } else {
      var $_0 = $52;
      __label__ = 21;
      break;
    }
   case 17:
    var $61 = __ZL14OrphanXMLChildP9JSContextP5JSXMLj($cx, $xml_0, $i_0);
    if (($61 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $64 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $57, $61);
    if (($64 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 16;
    break;
   case 20:
    var $69 = $cx;
    var $70 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($69, 0, 181, 0, $_0_0_0_val$0, $_0_0_0_val$1, 0, 0);
    var $_0 = 0;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9ToXMLListP9JSContextN2JS5ValueE["X"] = 1;

function __Z22js_NewXMLSpecialObjectP9JSContext10JSXMLClassP8JSStringS3_($cx, $xml_class, $name, $value) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $flags = __stackBase__;
    var $1 = __ZL18GetXMLSettingFlagsP9JSContextPj($cx, $flags);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($xml_class | 0) == 5) {
      __label__ = 3;
      break;
    } else if (($xml_class | 0) == 3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    if ((HEAP32[$flags >> 2] & 1 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    if ((HEAP32[$flags >> 2] & 2 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 4);
    var $_0 = $13;
    __label__ = 12;
    break;
   case 6:
    var $15 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, $xml_class);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx_val = HEAP32[$15 + 24 >> 2];
    var $19 = __ZNK8JSObject10getPrivateEv($_idx_val);
    if (($name | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = $cx;
    var $23 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($22, $name);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $26 = $23;
    var $31 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    var $32 = __ZL11NewXMLQNameP9JSContextP14JSLinearStringS2_P6JSAtom($cx, $31, 0, $26);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $36 = $19 + 12 | 0;
    HEAP32[$36 >> 2] = $32;
    __label__ = 11;
    break;
   case 11:
    var $39 = $19 + 24 | 0;
    HEAP32[$39 >> 2] = $value;
    var $_0 = $15;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18GetXMLSettingFlagsP9JSContextPj($cx, $flagsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $flag = __stackBase__;
    var $1 = $flag | 0;
    var $2 = __ZL20GetBooleanXMLSettingP9JSContextPKcPi($cx, STRING_TABLE.__ZL21js_ignoreComments_str | 0, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $flag + 4 | 0;
    var $6 = __ZL20GetBooleanXMLSettingP9JSContextPKcPi($cx, STRING_TABLE.__ZL35js_ignoreProcessingInstructions_str | 0, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $flag + 8 | 0;
    var $10 = __ZL20GetBooleanXMLSettingP9JSContextPKcPi($cx, STRING_TABLE.__ZL23js_ignoreWhitespace_str | 0, $9);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $flag + 12 | 0;
    var $14 = __ZL20GetBooleanXMLSettingP9JSContextPKcPi($cx, STRING_TABLE.__ZL21js_prettyPrinting_str | 0, $13);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$flagsp >> 2] = 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      var $21 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    HEAP32[$flagsp >> 2] = 1;
    var $21 = 1;
    __label__ = 7;
    break;
   case 7:
    var $21;
    if ((HEAP32[$5 >> 2] | 0) == 0) {
      var $27 = $21;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   case 9:
    var $25 = $21 | 2;
    HEAP32[$flagsp >> 2] = $25;
    var $27 = $25;
    __label__ = 10;
    break;
   case 10:
    var $27;
    if ((HEAP32[$9 >> 2] | 0) == 0) {
      var $33 = $27;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $31 = $27 | 4;
    HEAP32[$flagsp >> 2] = $31;
    var $33 = $31;
    __label__ = 12;
    break;
   case 12:
    var $33;
    if ((HEAP32[$13 >> 2] | 0) == 0) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    HEAP32[$flagsp >> 2] = $33 | 8;
    var $_0 = 1;
    __label__ = 8;
    break;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11NewXMLQNameP9JSContextP14JSLinearStringS2_P6JSAtom($cx, $uri, $prefix, $localName) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL26NewBuiltinClassInstanceXMLP9JSContextPN2js5ClassE($cx, __ZN2js10QNameClassE);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZL12InitXMLQNameP9JSContextP8JSObjectP14JSLinearStringS4_P6JSAtom($cx, $1, $uri, $prefix, $localName);
    var $_ = $4 ? $1 : 0;
    var $_0 = $_;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z21js_MakeXMLCDATAStringP9JSContextP8JSString($cx, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var $sb = __stackBase__;
  var $1 = $sb;
  var $2 = $cx;
  __ZN2js12StringBufferC1EP9JSContext($1, $2);
  var $3 = __ZL18MakeXMLCDATAStringP9JSContextRN2js12StringBufferEP8JSString($sb, $str);
  var $4 = $3 | 0;
  __ZN2js12StringBufferD1Ev($1);
  STACKTOP = __stackBase__;
  return $4;
}

function __ZL18MakeXMLCDATAStringP9JSContextRN2js12StringBufferEP8JSString($sb, $str) {
  var $1 = __ZL20MakeXMLSpecialStringP9JSContextRN2js12StringBufferEP8JSStringS5_PKtjS7_j($sb, $str, 0, __ZZL18MakeXMLCDATAStringP9JSContextRN2js12StringBufferEP8JSStringE19cdata_prefix_ucNstr | 0, 9, __ZZL18MakeXMLCDATAStringP9JSContextRN2js12StringBufferEP8JSStringE19cdata_suffix_ucNstr | 0, 3);
  return $1;
}

function __Z23js_MakeXMLCommentStringP9JSContextP8JSString($cx, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var $sb = __stackBase__;
  var $1 = $sb;
  var $2 = $cx;
  __ZN2js12StringBufferC1EP9JSContext($1, $2);
  var $3 = __ZL20MakeXMLCommentStringP9JSContextRN2js12StringBufferEP8JSString($sb, $str);
  var $4 = $3 | 0;
  __ZN2js12StringBufferD1Ev($1);
  STACKTOP = __stackBase__;
  return $4;
}

function __ZL20MakeXMLCommentStringP9JSContextRN2js12StringBufferEP8JSString($sb, $str) {
  var $1 = __ZL20MakeXMLSpecialStringP9JSContextRN2js12StringBufferEP8JSStringS5_PKtjS7_j($sb, $str, 0, __ZZL20MakeXMLCommentStringP9JSContextRN2js12StringBufferEP8JSStringE21comment_prefix_ucNstr | 0, 4, __ZZL20MakeXMLCommentStringP9JSContextRN2js12StringBufferEP8JSStringE21comment_suffix_ucNstr | 0, 3);
  return $1;
}

function __Z18js_MakeXMLPIStringP9JSContextP8JSStringS2_($cx, $name, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var $sb = __stackBase__;
  var $1 = $sb;
  var $2 = $cx;
  __ZN2js12StringBufferC1EP9JSContext($1, $2);
  var $3 = __ZL15MakeXMLPIStringP9JSContextRN2js12StringBufferEP8JSStringS5_($sb, $name, $str);
  var $4 = $3 | 0;
  __ZN2js12StringBufferD1Ev($1);
  STACKTOP = __stackBase__;
  return $4;
}

function __ZL15MakeXMLPIStringP9JSContextRN2js12StringBufferEP8JSStringS5_($sb, $name, $value) {
  var $1 = __ZL20MakeXMLSpecialStringP9JSContextRN2js12StringBufferEP8JSStringS5_PKtjS7_j($sb, $name, $value, __ZZL15MakeXMLPIStringP9JSContextRN2js12StringBufferEP8JSStringS5_E16pi_prefix_ucNstr | 0, 2, __ZZL15MakeXMLPIStringP9JSContextRN2js12StringBufferEP8JSStringS5_E16pi_suffix_ucNstr | 0, 2);
  return $1;
}

function __ZN11JSXMLFilterC1EP5JSXMLP10JSXMLArray($this, $list, $array) {
  __ZN11JSXMLFilterC2EP5JSXMLP10JSXMLArray($this, $list, $array);
  return;
}

function __ZN11JSXMLFilterC2EP5JSXMLP10JSXMLArray($this, $list, $array) {
  HEAP32[$this >> 2] = $list;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  var $4 = $this + 12 | 0;
  __ZN16JSXMLArrayCursorC1EP10JSXMLArray($4, $array);
  return;
}

function __ZN16JSXMLArrayCursorC1EP10JSXMLArray($this, $array) {
  __ZN16JSXMLArrayCursorC2EP10JSXMLArray($this, $array);
  return;
}

function __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE4380($cx, $clasp, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($1, $kind);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $obj_0 = $3;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    var $7 = $clasp;
    var $8 = $parent;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($2, $7, __ZN2js5types15emptyTypeObjectE, $8, 0, $6);
    var $_idx_val = HEAP32[$clasp + 4 >> 2];
    var $10 = __ZNK2js5Class8isNativeEv($_idx_val);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $12 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE4383($cx, $3, $clasp, __ZN2js5types15emptyTypeObjectE, $kind);
    if ($12) {
      var $obj_0 = $3;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $obj_0 = 0;
    __label__ = 6;
    break;
   case 5:
    __ZN8JSObject21setSharedNonNativeMapEv($2);
    var $obj_0 = $3;
    __label__ = 6;
    break;
   case 6:
    var $obj_0;
    return $obj_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE4383($cx, $obj, $clasp, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
    var $5 = $obj;
    var $_idx_val = HEAP32[$obj + 28 >> 2];
    var $7 = __ZNK8JSObject8numSlotsEv($_idx_val);
    if ($4 >>> 0 > $7 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = $obj;
    var $11 = $cx;
    var $12 = __ZN8JSObject10allocSlotsEP9JSContextj($10, $11, $4);
    if ($12) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $14 = $type;
    var $15 = $clasp;
    var $16 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($14, $15);
    var $17 = $cx;
    if ($16) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $19 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($14, $17, $15, $kind);
    var $empty_0_in = $19;
    __label__ = 6;
    break;
   case 5:
    var $21 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($17, $15);
    var $empty_0_in = $21;
    __label__ = 6;
    break;
   case 6:
    var $empty_0_in;
    if (($empty_0_in | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($5, $empty_0_in | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20MakeXMLSpecialStringP9JSContextRN2js12StringBufferEP8JSStringS5_PKtjS7_j($sb, $str, $str2, $prefix, $prefixlength, $suffix, $suffixlength) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $sb;
    var $2 = __ZN2js12StringBuffer6appendEPKtj($1, $prefix, $prefixlength);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    var $4 = __ZN2js12StringBuffer6appendEP8JSString($1, $str);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 3:
    if (($str2 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $str2_idx_val = HEAP32[$str2 >> 2];
    var $8 = __ZNK8JSString5emptyEv($str2_idx_val);
    if ($8) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = __ZN2js12StringBuffer6appendEt($1, 32);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $12 = __ZN2js12StringBuffer6appendEP8JSString($1, $str2);
    if ($12) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $14 = __ZN2js12StringBuffer6appendEPKtj($1, $suffix, $suffixlength);
    if ($14) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $16 = $sb;
    var $17 = __ZN2js12StringBuffer12finishStringEv($16);
    var $_0 = $17 | 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26NewBuiltinClassInstanceXMLP9JSContextPN2js5ClassE($cx, $clasp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __ZNK9JSContext28runningWithTrustedPrincipalsEv($1);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[_sE4XObjectsCreated >> 2] + 1 | 0;
    HEAP32[_sE4XObjectsCreated >> 2] = $5;
    __label__ = 3;
    break;
   case 3:
    var $7 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE4392($cx, $clasp);
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7;
    __ZN8JSObject19syncSpecialEqualityEv($10);
    __label__ = 5;
    break;
   case 5:
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE4392($cx, $clasp) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb4379($4);
  var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE4393($cx, $clasp, $5);
  return $6;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE4393($cx, $clasp, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $4 = HEAPU32[$clasp + 4 >> 2] >>> 24;
    var $5 = $cx;
    var $6 = __ZNK9JSContext5hasfpEv($5);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $9;
    var $10 = $cx;
    var $11 = $global;
    var $12 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($10, $11);
    if ($12) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $20 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $14 = __ZNK9JSContext2fpEv($5);
    var $15 = __ZNK2js10StackFrame10scopeChainEv($14);
    var $16 = $15;
    var $17 = __ZNK8JSObject9getGlobalEv($16);
    var $18 = $17;
    HEAP32[$global >> 2] = $18;
    var $20 = $18;
    __label__ = 5;
    break;
   case 5:
    var $20;
    var $21 = $4 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $20, $21);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $23 = __ZNK2JS5Value8isObjectEv($_idx_val$0, $_idx_val$1);
    if ($23) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $25 = __ZNK2JS5Value8toObjectEv($_idx_val$0, $_idx_val$1);
    var $26 = $25;
    HEAP32[$proto >> 2] = $26;
    var $34 = $26;
    __label__ = 9;
    break;
   case 7:
    var $28 = $cx;
    var $30 = $proto;
    var $31 = $clasp;
    var $32 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($28, $20, $4, $30, $31);
    if ($32) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $34 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $34;
    var $35 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE4394($cx, $clasp, $34, $20, $kind);
    var $_0 = $35;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE4393["X"] = 1;

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE4394($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $proto;
    var $2 = $cx;
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($1, $2, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($2, $kind);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_0 = $7;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    var $11 = $clasp;
    var $12 = $parent;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, $11, $3, $12, 0, $10);
    var $13 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($3, $2, $11, $kind);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = $13 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($6, $16);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20GetBooleanXMLSettingP9JSContextPKcPi($cx, $name, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZL13GetXMLSettingP9JSContextPKcPN2JS5ValueE($cx, $name, $v);
    if (($1 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $v | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    _JS_ValueToBoolean($5$0, $5$1, $bp);
    var $7 = 1;
    __label__ = 3;
    break;
   case 3:
    var $7;
    STACKTOP = __stackBase__;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13GetXMLSettingP9JSContextPKcPN2JS5ValueE($cx, $name, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $cx;
    var $2 = __Z18js_FindClassObjectP9JSContextP8JSObject10JSProtoKeyPN2JS5ValueEPN2js5ClassE($1, 0, 11, $v, 0);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $v | 0;
    var $st$1$0 = $5 | 0;
    var $6$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $5 + 4 | 0;
    var $6$1 = HEAP32[$st$1$1 >> 2];
    var $7 = _JSVAL_IS_PRIMITIVE4303($6$0, $6$1);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = _JSVAL_TO_OBJECT4304($6$0, $6$1);
    var $_idx_val = HEAP32[$10 + 4 >> 2];
    var $12 = __ZNK8JSObject10isFunctionEv($_idx_val);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $14$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $14$1 = HEAP32[$st$1$1 >> 2];
    var $15 = $vp | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $17 = _JSVAL_TO_OBJECT4304($6$0, $6$1);
    var $18 = $cx;
    var $19 = $17;
    var $20 = _JS_GetProperty($18, $19, $name, $vp);
    var $_0 = $20;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSVAL_IS_NULL4395($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_NULL_IMPL4400($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_IS_VOID4396($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_UNDEFINED_IMPL4398($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL14ParseXMLSourceP9JSContextP8JSString($cx, $src) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 1076;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nsval = __stackBase__;
    var $dstlen = __stackBase__ + 8;
    var $i = __stackBase__ + 12;
    var $parser = __stackBase__ + 52;
    var $flags = __stackBase__ + 1044;
    var $namespaces = __stackBase__ + 1048;
    var $1 = __Z25js_GetDefaultXMLNamespaceP9JSContextPN2JS5ValueE($cx, $nsval);
    if (($1 | 0) == 0) {
      var $_1 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $nsval | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = _JSVAL_TO_OBJECT4304($5$0, $5$1);
    var $7 = __ZNK8JSObject10getNameURIEv($6);
    var $8 = $7 | 0;
    var $9 = __Z23js_EscapeAttributeValueP9JSContextP8JSStringi($cx, $8, 0);
    if (($9 | 0) == 0) {
      var $_1 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx_val = HEAP32[$9 >> 2];
    var $12 = __ZNK8JSString6lengthEv($_idx_val);
    var $src_idx_val = HEAP32[$src >> 2];
    var $13 = __ZNK8JSString6lengthEv($src_idx_val);
    var $15 = $13 + ($12 + 17) | 0;
    var $16 = $15 + 9 | 0;
    var $18 = ($15 << 1) + 20 | 0;
    var $19 = $cx;
    var $20 = __ZN9JSContext7malloc_Ej($19, $18);
    var $21 = $20;
    if (($20 | 0) == 0) {
      var $_1 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$dstlen >> 2] = $16;
    var $24 = $cx;
    var $25 = __ZN2js21InflateStringToBufferEP9JSContextPKcjPtPj($24, STRING_TABLE.__ZZL14ParseXMLSourceP9JSContextP8JSStringE6prefix | 0, 15, $21, $dstlen);
    var $26 = HEAP32[$dstlen >> 2];
    var $28 = $21 + ($26 << 1) | 0;
    var $_idx1_val = HEAP32[$9 + 4 >> 2];
    var $29 = __ZNK14JSLinearString5charsEv($_idx1_val);
    var $30 = $29;
    var $31 = $12 << 1;
    _memcpy($28, $30, $31, 1);
    var $32 = $26 + $12 | 0;
    var $33 = $15 + 10 | 0;
    var $34 = $33 - $32 | 0;
    HEAP32[$dstlen >> 2] = $34;
    var $35 = $21 + ($32 << 1) | 0;
    var $36 = __ZN2js21InflateStringToBufferEP9JSContextPKcjPtPj($24, STRING_TABLE.__ZZL14ParseXMLSourceP9JSContextP8JSStringE6middle | 0, 2, $35, $dstlen);
    var $38 = HEAP32[$dstlen >> 2] + $32 | 0;
    var $39 = __ZN8JSString8getCharsEP9JSContext($src, $19);
    if (($39 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN9JSContext5free_EPv($20);
    var $_1 = 0;
    __label__ = 19;
    break;
   case 6:
    var $44 = $21 + ($38 << 1) | 0;
    var $45 = $39;
    var $46 = $13 << 1;
    _memcpy($44, $45, $46, 1);
    var $47 = $38 + $13 | 0;
    var $48 = $33 - $47 | 0;
    HEAP32[$dstlen >> 2] = $48;
    var $49 = $21 + ($47 << 1) | 0;
    var $50 = __ZN2js21InflateStringToBufferEP9JSContextPKcjPtPj($24, STRING_TABLE.__ZZL14ParseXMLSourceP9JSContextP8JSStringE6suffix | 0, 9, $49, $dstlen);
    HEAP16[$21 + (HEAP32[$dstlen >> 2] + $47 << 1) >> 1] = 0;
    __ZN2js13FrameRegsIterC1EP9JSContextNS_9StackIter11SavedOptionE($i, $19);
    var $54 = __ZNK2js13FrameRegsIter4doneEv($i);
    if ($54) {
      var $lineno_2 = 1;
      var $filename_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $56 = __ZNK2js13FrameRegsIter2pcEv($i);
    if ((HEAP8[$56] + 78 & 255 & 255) < 2) {
      __label__ = 8;
      break;
    } else {
      var $lineno_2 = 1;
      var $filename_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $60 = __ZNK2js13FrameRegsIter2fpEv($i);
    var $61 = __ZNK2js10StackFrame6scriptEv($60);
    var $63 = HEAP32[$61 + 52 >> 2];
    var $64 = $cx;
    var $65 = $60;
    var $66 = __Z22js_FramePCToLineNumberP9JSContextPN2js10StackFrameEPh($64, $65, $56);
    var $67 = $39 + ($13 << 1) | 0;
    if (($13 | 0) > 0) {
      var $srcp_05 = $39;
      var $lineno_06 = $66;
      __label__ = 9;
      break;
    } else {
      var $lineno_2 = $66;
      var $filename_0 = $63;
      __label__ = 10;
      break;
    }
   case 9:
    var $lineno_06;
    var $srcp_05;
    var $_lineno_0 = ((HEAP16[$srcp_05 >> 1] << 16 >> 16 == 10) << 31 >> 31) + $lineno_06 | 0;
    var $72 = $srcp_05 + 2 | 0;
    if ($72 >>> 0 < $67 >>> 0) {
      var $srcp_05 = $72;
      var $lineno_06 = $_lineno_0;
      __label__ = 9;
      break;
    } else {
      var $lineno_2 = $_lineno_0;
      var $filename_0 = $63;
      __label__ = 10;
      break;
    }
   case 10:
    var $filename_0;
    var $lineno_2;
    var $74 = $parser;
    __ZN2js6ParserC2EP9JSContextP12JSPrincipalsPNS_10StackFrameEb($74, $19, 0, 0, 1);
    var $75 = __ZNK9JSContext11findVersionEv($19);
    var $76 = __ZN2js6Parser4initEPKtjPKcj9JSVersion($74, $21, $16, $filename_0, $lineno_2, $75);
    if ($76) {
      __label__ = 11;
      break;
    } else {
      var $xml_2_ph = 0;
      __label__ = 18;
      break;
    }
   case 11:
    var $78 = __ZN2js13GetScopeChainEP9JSContext($19);
    if (($78 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $81 = __ZN2js6Parser12parseXMLTextEP8JSObjectb($74, $78);
    if (($81 | 0) == 0) {
      var $xml_2_ph = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $84 = __ZL18GetXMLSettingFlagsP9JSContextPj($cx, $flags);
    if (($84 | 0) == 0) {
      var $xml_2_ph = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZN2js18AutoNamespaceArrayC1EP9JSContext($namespaces, $cx);
    var $87 = $namespaces + 12 | 0;
    var $88 = __ZN10JSXMLArray11setCapacityEP9JSContextj($87, $cx, 1);
    if ($88) {
      __label__ = 15;
      break;
    } else {
      var $xml_0 = 0;
      __label__ = 16;
      break;
    }
   case 15:
    var $90 = HEAP32[$flags >> 2];
    var $91 = __ZL14ParseNodeToXMLPN2js6ParserEP11JSParseNodeP10JSXMLArrayj($parser, $81, $87, $90);
    var $xml_0 = $91;
    __label__ = 16;
    break;
   case 16:
    var $xml_0;
    __ZN2js18AutoNamespaceArrayD1Ev($namespaces);
    var $xml_2_ph = $xml_0;
    __label__ = 18;
    break;
   case 17:
    __ZN9JSContext5free_EPv($20);
    __ZN2js6ParserD2Ev($74);
    var $_1 = 0;
    __label__ = 19;
    break;
   case 18:
    var $xml_2_ph;
    __ZN2js6ParserD2Ev($74);
    __ZN9JSContext5free_EPv($20);
    var $_1 = $xml_2_ph;
    __label__ = 19;
    break;
   case 19:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14ParseXMLSourceP9JSContextP8JSString["X"] = 1;

function __ZL14OrphanXMLChildP9JSContextP5JSXMLj($cx, $xml, $i) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$xml + 40 >> 2] | 0) == 0) {
      var $10 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAP32[HEAP32[$xml + 48 >> 2] >> 2];
    __label__ = 3;
    break;
   case 3:
    var $10;
    if (HEAPU32[$xml + 24 >> 2] >>> 0 > $i >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 4:
    var $18 = HEAPU32[HEAP32[$xml + 32 >> 2] + ($i << 2) >> 2];
    var $19 = $18;
    if (($10 | 0) == 0 | ($18 | 0) == 0) {
      var $_0 = $19;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$18 + 16 >> 2] | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $28 = $18 + 40 | 0;
    var $29 = $28;
    var $31 = HEAP32[$28 >> 2];
    var $33 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $29, $31, $10);
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $36$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $36$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    __ZN8JSObject20setNamespaceDeclaredEN2JS5ValueE($10, $36$0, $36$1);
    __label__ = 8;
    break;
   case 8:
    var $39 = $18 + 8 | 0;
    HEAP32[$39 >> 2] = 0;
    var $_0 = $19;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $array, $index, $elt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $array | 0;
    if (HEAPU32[$1 >> 2] >>> 0 > $index >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $array + 4 | 0;
    if ((HEAP32[$5 >> 2] & 2147483647) >>> 0 > $index >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($index >>> 0 > 255) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $capacity_0 = $index + 32 & -32;
    __label__ = 8;
    break;
   case 5:
    if (($index + 1 | 0) >>> 0 < 2) {
      var $21 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = _llvm_ctlz_i32($index);
    var $21 = 32 - $18 | 0;
    __label__ = 7;
    break;
   case 7:
    var $21;
    var $capacity_0 = 1 << $21;
    __label__ = 8;
    break;
   case 8:
    var $capacity_0;
    if ($capacity_0 >>> 0 > 1073741823) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $_pre_phi = $cx;
    __label__ = 11;
    break;
   case 10:
    var $26 = $array + 8 | 0;
    var $28 = HEAP32[$26 >> 2];
    var $30 = $cx;
    var $31 = __ZN9JSContext8realloc_EPvj($30, $28, $capacity_0 << 2);
    if (($31 | 0) == 0) {
      var $_pre_phi = $30;
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $_pre_phi;
    _JS_ReportOutOfMemory($_pre_phi);
    var $_0 = 0;
    __label__ = 16;
    break;
   case 12:
    var $35 = $31;
    HEAP32[$5 >> 2] = $capacity_0;
    HEAP32[$26 >> 2] = $35;
    var $36 = HEAPU32[$1 >> 2];
    if ($36 >>> 0 < $index >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $scevgep = $31 + ($36 << 2) | 0;
    var $40 = $index - $36 << 2;
    _memset($scevgep, 0, $40, 4);
    __label__ = 14;
    break;
   case 14:
    HEAP32[$1 >> 2] = $index + 1 | 0;
    __label__ = 15;
    break;
   case 15:
    var $44 = HEAP32[$array + 8 >> 2] + ($index << 2) | 0;
    HEAP32[$44 >> 2] = $elt;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv["X"] = 1;

function __ZN8JSObject20setNamespaceDeclaredEN2JS5ValueE($this, $_0_0_0_val$0, $_0_0_0_val$1) {
  var $1 = $this;
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($1, 2, $_0_0_0_val$0, $_0_0_0_val$1);
  return;
}

function __ZNK8JSObject10getNameURIEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK8JSObject7getSlotEj($1, 1);
    var $_idx = $2 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $3 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($3) {
      var $8 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2JS5Value8toStringEv($_idx_val$0, $_idx_val$1);
    var $6 = __ZN8JSString8asLinearEv($5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18AutoNamespaceArrayC1EP9JSContext($this, $cx) {
  __ZN2js18AutoNamespaceArrayC2EP9JSContext($this, $cx);
  return;
}

function __ZL12IS_XML_CHARSPKt($chars) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP16[$chars >> 1];
    if ($1 << 16 >> 16 == 120 || $1 << 16 >> 16 == 88) {
      __label__ = 2;
      break;
    } else {
      var $12 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = HEAP16[$chars + 2 >> 1];
    if ($4 << 16 >> 16 == 109 || $4 << 16 >> 16 == 77) {
      __label__ = 3;
      break;
    } else {
      var $12 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $7 = HEAP16[$chars + 4 >> 1];
    if ($7 << 16 >> 16 == 108) {
      var $12 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $7 << 16 >> 16 == 76;
    __label__ = 5;
    break;
   case 5:
    var $12;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16HAS_NS_AFTER_XMLPKt($chars) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP16[$chars + 6 >> 1];
    if ($2 << 16 >> 16 == 110 || $2 << 16 >> 16 == 78) {
      __label__ = 2;
      break;
    } else {
      var $10 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP16[$chars + 8 >> 1];
    if ($5 << 16 >> 16 == 115) {
      var $10 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $5 << 16 >> 16 == 83;
    __label__ = 4;
    break;
   case 4:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14ParseNodeToXMLPN2js6ParserEP11JSParseNodeP10JSXMLArrayj($parser, $pn, $inScopeNSes, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__ + 4;
    var $bytes = __stackBase__ + 12;
    var $v3 = __stackBase__ + 16;
    var $bytes4 = __stackBase__ + 24;
    var $v6 = __stackBase__ + 28;
    var $bytes7 = __stackBase__ + 36;
    var $2 = HEAPU32[$parser + 12 >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$2 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $parser + 40 | 0;
    var $10 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($9, $pn, 0, 26, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 106;
    break;
   case 3:
    var $12 = __ZNK11JSParseNode7getKindEv($pn);
    if (($12 | 0) == 75) {
      __label__ = 4;
      break;
    } else if (($12 | 0) == 76) {
      __label__ = 23;
      break;
    } else if (($12 | 0) == 59 || ($12 | 0) == 61) {
      __label__ = 37;
      break;
    } else if (($12 | 0) == 65 || ($12 | 0) == 66 || ($12 | 0) == 68 || ($12 | 0) == 67 || ($12 | 0) == 69) {
      __label__ = 86;
      break;
    } else {
      __label__ = 105;
      break;
    }
   case 4:
    var $15 = HEAP32[$inScopeNSes >> 2];
    var $17 = HEAPU32[$pn + 32 >> 2];
    var $18 = __ZL14ParseNodeToXMLPN2js6ParserEP11JSParseNodeP10JSXMLArrayj($parser, $17, $inScopeNSes, $flags);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 106;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $21 = $pn + 40 | 0;
    var $23 = HEAP32[$21 >> 2] - 2 | 0;
    var $24 = $18 + 24 | 0;
    var $25 = __ZN10JSXMLArray11setCapacityEP9JSContextj($24, $2, $23);
    if ($25) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 106;
      break;
    }
   case 6:
    var $27 = ($flags & 4 | 0) != 0;
    var $28 = $24 | 0;
    var $29 = $18 + 32 | 0;
    var $pn2_0_ph = $17;
    var $n_0_ph = $23;
    var $i_0_ph = 0;
    __label__ = 7;
    break;
   case 7:
    var $i_0_ph;
    var $n_0_ph;
    var $pn2_0_ph;
    var $pn2_0 = $pn2_0_ph;
    var $n_0 = $n_0_ph;
    __label__ = 8;
    break;
   case 8:
    var $n_0;
    var $pn2_0;
    var $32 = HEAPU32[$pn2_0 + 24 >> 2];
    if (($32 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ((HEAP32[$32 + 24 >> 2] | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $or_cond = $27 & $n_0 >>> 0 > 1;
    if ($or_cond) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $41 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($32, 65);
    if ($41) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $pn2_0 = $32;
    var $n_0 = $n_0 - 1 | 0;
    __label__ = 8;
    break;
   case 13:
    var $43 = __ZL14ParseNodeToXMLPN2js6ParserEP11JSParseNodeP10JSXMLArrayj($parser, $32, $inScopeNSes, $flags);
    var $magicptr = $43;
    if (($magicptr | 0) == 1) {
      __label__ = 12;
      break;
    } else if (($magicptr | 0) == 0) {
      var $_0 = 0;
      __label__ = 106;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $_pre20 = $i_0_ph + 1 | 0;
    if (HEAPU32[$28 >> 2] >>> 0 > $i_0_ph >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    HEAP32[$28 >> 2] = $_pre20;
    __label__ = 16;
    break;
   case 16:
    var $50 = HEAP32[$29 >> 2] + ($i_0_ph << 2) | 0;
    HEAP32[$50 >> 2] = $43;
    HEAP32[$43 + 8 >> 2] = $18;
    if ($or_cond) {
      __label__ = 17;
      break;
    } else {
      var $pn2_0_ph = $32;
      var $n_0_ph = $n_0;
      var $i_0_ph = $_pre20;
      __label__ = 7;
      break;
    }
   case 17:
    if ((HEAP32[$43 + 16 >> 2] | 0) == 4) {
      __label__ = 18;
      break;
    } else {
      var $pn2_0_ph = $32;
      var $n_0_ph = $n_0;
      var $i_0_ph = $_pre20;
      __label__ = 7;
      break;
    }
   case 18:
    var $57 = $43 + 24 | 0;
    var $59 = HEAP32[$57 >> 2];
    var $60 = __ZL18ChompXMLWhitespaceP9JSContextP8JSString($2, $59);
    if (($60 | 0) == 0) {
      var $_0 = 0;
      __label__ = 106;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $_c4 = $60;
    HEAP32[$57 >> 2] = $_c4;
    var $pn2_0_ph = $32;
    var $n_0_ph = $n_0;
    var $i_0_ph = $_pre20;
    __label__ = 7;
    break;
   case 20:
    if ($n_0 >>> 0 < (HEAP32[$21 >> 2] - 2 | 0) >>> 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    __ZN10JSXMLArray4trimEv($24);
    __label__ = 22;
    break;
   case 22:
    __ZL16XMLArrayTruncateP9JSContextP10JSXMLArrayj($2, $inScopeNSes, $15);
    var $_0 = $18;
    __label__ = 106;
    break;
   case 23:
    var $71 = __Z9js_NewXMLP9JSContext10JSXMLClass($2, 0);
    if (($71 | 0) == 0) {
      var $_0 = 0;
      __label__ = 106;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $74 = $pn + 40 | 0;
    var $75 = HEAP32[$74 >> 2];
    var $76 = $71 + 24 | 0;
    var $77 = __ZN10JSXMLArray11setCapacityEP9JSContextj($76, $2, $75);
    if ($77) {
      __label__ = 25;
      break;
    } else {
      var $_0 = 0;
      __label__ = 106;
      break;
    }
   case 25:
    var $80 = $76 | 0;
    var $81 = $71 + 32 | 0;
    var $pn2_1_in = $pn + 32 | 0;
    var $n_1 = $75;
    var $i_1 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i_1;
    var $n_1;
    var $pn2_1_in;
    var $pn2_1 = HEAPU32[$pn2_1_in >> 2];
    if (($pn2_1 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $85 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_1, 65);
    if ($85) {
      __label__ = 28;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 28:
    var $n_2 = $n_1 - 1 | 0;
    var $i_2 = $i_1;
    __label__ = 34;
    break;
   case 29:
    var $89 = __ZL14ParseNodeToXMLPN2js6ParserEP11JSParseNodeP10JSXMLArrayj($parser, $pn2_1, $inScopeNSes, $flags);
    var $magicptr6 = $89;
    if (($magicptr6 | 0) == 1) {
      __label__ = 30;
      break;
    } else if (($magicptr6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 106;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    var $n_2 = $n_1 - 1 | 0;
    var $i_2 = $i_1;
    __label__ = 34;
    break;
   case 31:
    var $_pre21 = $i_1 + 1 | 0;
    if (HEAPU32[$80 >> 2] >>> 0 > $i_1 >>> 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    HEAP32[$80 >> 2] = $_pre21;
    __label__ = 33;
    break;
   case 33:
    var $98 = HEAP32[$81 >> 2] + ($i_1 << 2) | 0;
    HEAP32[$98 >> 2] = $89;
    var $n_2 = $n_1;
    var $i_2 = $_pre21;
    __label__ = 34;
    break;
   case 34:
    var $i_2;
    var $n_2;
    var $pn2_1_in = $pn2_1 + 24 | 0;
    var $n_1 = $n_2;
    var $i_1 = $i_2;
    __label__ = 26;
    break;
   case 35:
    if ($n_1 >>> 0 < HEAPU32[$74 >> 2] >>> 0) {
      __label__ = 36;
      break;
    } else {
      var $_0 = $71;
      __label__ = 106;
      break;
    }
   case 36:
    __ZN10JSXMLArray4trimEv($76);
    var $_0 = $71;
    __label__ = 106;
    break;
   case 37:
    var $106 = $inScopeNSes | 0;
    var $107 = HEAP32[$106 >> 2];
    var $108 = $pn + 32 | 0;
    var $109 = HEAPU32[$108 >> 2];
    var $110 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($109, 5);
    if ($110) {
      __label__ = 105;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $112 = __Z9js_NewXMLP9JSContext10JSXMLClass($2, 1);
    if (($112 | 0) == 0) {
      var $_0 = 0;
      __label__ = 106;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $118 = $109 + 24 | 0;
    var $119 = HEAPU32[$118 >> 2];
    var $120 = $2 + 52 | 0;
    var $121 = $112 + 40 | 0;
    var $122 = $121 | 0;
    var $123 = $2;
    var $inScopeNSes_idx7 = $inScopeNSes + 8 | 0;
    var $pnp_0_ph = $118;
    var $n_3_ph = HEAP32[$pn + 40 >> 2] - 1 | 0;
    var $124 = $119;
    __label__ = 40;
    break;
   case 40:
    var $124;
    var $n_3_ph;
    var $pnp_0_ph;
    var $pnp_0 = $pnp_0_ph;
    var $126 = $124;
    __label__ = 41;
    break;
   case 41:
    var $126;
    var $pnp_0;
    if (($126 | 0) == 0) {
      __label__ = 66;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $129 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($126, 63);
    if ($129) {
      __label__ = 43;
      break;
    } else {
      __label__ = 105;
      break;
    }
   case 43:
    var $131 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($126, 0);
    if ($131) {
      __label__ = 44;
      break;
    } else {
      __label__ = 105;
      break;
    }
   case 44:
    var $133 = $126 + 32 | 0;
    var $pn3_0 = $119;
    __label__ = 45;
    break;
   case 45:
    var $pn3_0;
    if (($pn3_0 | 0) == ($126 | 0)) {
      __label__ = 52;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $140 = HEAP32[$133 >> 2];
    if ((HEAP32[$pn3_0 + 32 >> 2] | 0) == ($140 | 0)) {
      __label__ = 47;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 47:
    var $143 = $140 | 0;
    __ZN2JSL11StringValueEP8JSString4311($v, $143);
    __ZN16JSAutoByteStringC1Ev($bytes);
    var $144 = $bytes;
    var $v_idx = $v | 0;
    var $st$5$0 = $v_idx | 0;
    var $v_idx_val$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $v_idx + 4 | 0;
    var $v_idx_val$1 = HEAP32[$st$5$1 >> 2];
    var $145 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($123, $v_idx_val$0, $v_idx_val$1, $144);
    if (($145 | 0) == 0) {
      __label__ = 48;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 48:
    var $bytes_idx_val = HEAP32[$bytes >> 2];
    __label__ = 50;
    break;
   case 49:
    var $148 = $parser + 40 | 0;
    var $bytes_idx6_val = HEAP32[$bytes >> 2];
    var $149 = __ZNK16JSAutoByteString3ptrEv($bytes_idx6_val);
    var $150 = $148;
    var $151 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($150, $126, 0, 198, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $149, tempInt));
    var $bytes_idx_val = $bytes_idx6_val;
    __label__ = 50;
    break;
   case 50:
    var $bytes_idx_val;
    __ZN16JSAutoByteStringD1Ev($bytes_idx_val);
    var $_0 = 0;
    __label__ = 106;
    break;
   case 51:
    var $pn3_0 = HEAP32[HEAP32[$pn3_0 + 24 >> 2] + 24 >> 2];
    __label__ = 45;
    break;
   case 52:
    var $159 = HEAP32[$133 >> 2];
    var $161 = HEAPU32[$126 + 24 >> 2];
    var $162 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($161, 64);
    if ($162) {
      __label__ = 53;
      break;
    } else {
      __label__ = 105;
      break;
    }
   case 53:
    var $_idx3_val = HEAP32[$159 + 4 >> 2];
    var $164 = __ZNK14JSLinearString5charsEv($_idx3_val);
    var $_idx1_val = HEAP32[$159 >> 2];
    var $165 = __ZNK8JSString6lengthEv($_idx1_val);
    if ($165 >>> 0 > 4) {
      __label__ = 54;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 54:
    var $168 = __ZL12IS_XML_CHARSPKt($164);
    if ($168) {
      __label__ = 55;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 55:
    var $170 = __ZL16HAS_NS_AFTER_XMLPKt($164);
    if ($170) {
      __label__ = 56;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 56:
    if (($165 | 0) == 5) {
      __label__ = 58;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    if (HEAP16[$164 + 10 >> 1] << 16 >> 16 == 58) {
      __label__ = 59;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 58:
    var $prefix_0 = HEAP32[HEAP32[$120 >> 2] + 144136 >> 2] | 0;
    var $_pn = HEAP32[$161 + 32 >> 2];
    __label__ = 60;
    break;
   case 59:
    var $188 = HEAP32[$161 + 32 >> 2];
    var $189 = $164 + 12 | 0;
    var $190 = $165 - 6 | 0;
    var $191 = __Z17js_NewStringCopyNP9JSContextPKtj($123, $189, $190);
    var $192 = $191 | 0;
    if (($191 | 0) == 0) {
      var $_0 = 0;
      __label__ = 106;
      break;
    } else {
      var $prefix_0 = $192;
      var $_pn = $188;
      __label__ = 60;
      break;
    }
   case 60:
    var $_pn;
    var $prefix_0;
    var $196 = __ZL15NewXMLNamespaceP9JSContextP14JSLinearStringS2_i($2, $prefix_0, $_pn | 0, 1);
    if (($196 | 0) == 0) {
      var $_0 = 0;
      __label__ = 106;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    var $199 = $196;
    var $inScopeNSes_idx_val = HEAP32[$106 >> 2];
    var $inScopeNSes_idx7_val = HEAP32[$inScopeNSes_idx7 >> 2];
    var $200 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($inScopeNSes_idx_val, $inScopeNSes_idx7_val, $199, 282);
    if (($200 | 0) == -1) {
      __label__ = 62;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 62:
    var $203 = HEAP32[$106 >> 2];
    var $204 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($2, $inScopeNSes, $203, $199);
    if (($204 | 0) == 0) {
      var $_0 = 0;
      __label__ = 106;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $207 = HEAP32[$122 >> 2];
    var $208 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($2, $121, $207, $199);
    if (($208 | 0) == 0) {
      var $_0 = 0;
      __label__ = 106;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    var $213 = HEAPU32[$161 + 24 >> 2];
    HEAP32[$pnp_0 >> 2] = $213;
    var $pnp_0_ph = $pnp_0;
    var $n_3_ph = $n_3_ph - 2 | 0;
    var $124 = $213;
    __label__ = 40;
    break;
   case 65:
    var $215 = $161 + 24 | 0;
    var $pnp_0 = $215;
    var $126 = HEAP32[$215 >> 2];
    __label__ = 41;
    break;
   case 66:
    __ZN10JSXMLArray4trimEv($121);
    var $217 = HEAPU32[$108 >> 2];
    var $218 = __ZL16ParseNodeToQNamePN2js6ParserEP11JSParseNodeP10JSXMLArrayi($parser, $217, $inScopeNSes, 0);
    if (($218 | 0) == 0) {
      var $_0 = 0;
      __label__ = 106;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 67:
    HEAP32[$112 + 12 >> 2] = $218;
    var $223 = $112 + 56 | 0;
    var $224 = __ZN10JSXMLArray11setCapacityEP9JSContextj($223, $2, $n_3_ph >>> 1);
    if ($224) {
      __label__ = 68;
      break;
    } else {
      var $_0 = 0;
      __label__ = 106;
      break;
    }
   case 68:
    var $225 = $112 + 64 | 0;
    var $226 = $223 | 0;
    var $pn2_2 = $217;
    var $i_3 = 0;
    __label__ = 69;
    break;
   case 69:
    var $i_3;
    var $pn2_2;
    var $229 = HEAPU32[$pn2_2 + 24 >> 2];
    if (($229 | 0) == 0) {
      __label__ = 84;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    var $232 = __ZL16ParseNodeToQNamePN2js6ParserEP11JSParseNodeP10JSXMLArrayi($parser, $229, $inScopeNSes, 1);
    if (($232 | 0) == 0) {
      __label__ = 71;
      break;
    } else {
      var $j_0 = 0;
      __label__ = 72;
      break;
    }
   case 71:
    HEAP32[$226 >> 2] = $i_3;
    var $_0 = 0;
    __label__ = 106;
    break;
   case 72:
    var $j_0;
    if ($j_0 >>> 0 < $i_3 >>> 0) {
      __label__ = 73;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 73:
    var $242 = HEAP32[HEAP32[HEAP32[$225 >> 2] + ($j_0 << 2) >> 2] + 12 >> 2];
    var $243 = __ZNK8JSObject10getNameURIEv($242);
    var $244 = __ZNK8JSObject10getNameURIEv($232);
    var $245 = __ZN2js12EqualStringsEP14JSLinearStringS1_($243, $244);
    if ($245) {
      __label__ = 74;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 74:
    var $247 = __ZNK8JSObject17getQNameLocalNameEv($242);
    var $248 = $247 | 0;
    var $249 = __ZNK8JSObject17getQNameLocalNameEv($232);
    var $250 = $249 | 0;
    var $251 = __ZN2js12EqualStringsEP14JSLinearStringS1_($248, $250);
    if ($251) {
      __label__ = 75;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 75:
    var $256 = HEAP32[$229 + 32 >> 2] | 0;
    __ZN2JSL11StringValueEP8JSString4311($v3, $256);
    __ZN16JSAutoByteStringC1Ev($bytes4);
    var $257 = $bytes4;
    var $v3_idx = $v3 | 0;
    var $v3_idx_val$0 = HEAP32[$v3_idx >> 2];
    var $v3_idx_val$1 = HEAP32[$v3_idx + 4 >> 2];
    var $258 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($123, $v3_idx_val$0, $v3_idx_val$1, $257);
    if (($258 | 0) == 0) {
      __label__ = 76;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 76:
    var $bytes4_idx_val = HEAP32[$bytes4 >> 2];
    __label__ = 78;
    break;
   case 77:
    var $261 = $parser + 40 | 0;
    var $bytes4_idx5_val = HEAP32[$bytes4 >> 2];
    var $262 = __ZNK16JSAutoByteString3ptrEv($bytes4_idx5_val);
    var $263 = $261;
    var $264 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($263, $229, 0, 198, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $262, tempInt));
    var $bytes4_idx_val = $bytes4_idx5_val;
    __label__ = 78;
    break;
   case 78:
    var $bytes4_idx_val;
    __ZN16JSAutoByteStringD1Ev($bytes4_idx_val);
    var $_0 = 0;
    __label__ = 106;
    break;
   case 79:
    var $j_0 = $j_0 + 1 | 0;
    __label__ = 72;
    break;
   case 80:
    var $270 = HEAPU32[$229 + 24 >> 2];
    var $271 = __Z9js_NewXMLP9JSContext10JSXMLClass($2, 2);
    if (($271 | 0) == 0) {
      var $_0 = 0;
      __label__ = 106;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 81:
    var $_pre23 = $i_3 + 1 | 0;
    if (HEAPU32[$226 >> 2] >>> 0 > $i_3 >>> 0) {
      __label__ = 83;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 82:
    HEAP32[$226 >> 2] = $_pre23;
    __label__ = 83;
    break;
   case 83:
    var $279 = HEAP32[$225 >> 2] + ($i_3 << 2) | 0;
    HEAP32[$279 >> 2] = $271;
    HEAP32[$271 + 8 >> 2] = $112;
    HEAP32[$271 + 12 >> 2] = $232;
    var $_c3 = HEAP32[$270 + 32 >> 2];
    HEAP32[$271 + 24 >> 2] = $_c3;
    var $pn2_2 = $270;
    var $i_3 = $_pre23;
    __label__ = 69;
    break;
   case 84:
    var $287 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 61);
    if ($287) {
      __label__ = 85;
      break;
    } else {
      var $_0 = $112;
      __label__ = 106;
      break;
    }
   case 85:
    __ZL16XMLArrayTruncateP9JSContextP10JSXMLArrayj($2, $inScopeNSes, $107);
    var $_0 = $112;
    __label__ = 106;
    break;
   case 86:
    var $292 = HEAP32[$pn + 32 >> 2];
    var $293 = $292 | 0;
    var $294 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 67);
    if ($294) {
      __label__ = 87;
      break;
    } else {
      __label__ = 88;
      break;
    }
   case 87:
    if (($flags & 1 | 0) == 0) {
      var $xml_class_0 = 5;
      var $qn_0 = 0;
      var $str_0 = $293;
      __label__ = 101;
      break;
    } else {
      var $_0 = 1;
      __label__ = 106;
      break;
    }
   case 88:
    var $299 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 69);
    if ($299) {
      __label__ = 89;
      break;
    } else {
      var $xml_class_0 = 4;
      var $qn_0 = 0;
      var $str_0 = $293;
      __label__ = 101;
      break;
    }
   case 89:
    var $301 = $292 | 0;
    var $_idx_val = HEAP32[$292 >> 2];
    var $302 = __ZNK8JSString6lengthEv($_idx_val);
    if (($302 | 0) == 3) {
      __label__ = 90;
      break;
    } else {
      __label__ = 95;
      break;
    }
   case 90:
    var $_idx2_val = HEAP32[$292 + 4 >> 2];
    var $305 = __ZNK14JSLinearString5charsEv($_idx2_val);
    var $306 = __ZL12IS_XML_CHARSPKt($305);
    if ($306) {
      __label__ = 91;
      break;
    } else {
      __label__ = 95;
      break;
    }
   case 91:
    __ZN2JSL11StringValueEP8JSString4311($v6, $301);
    __ZN16JSAutoByteStringC1Ev($bytes7);
    var $308 = $2;
    var $309 = $bytes7;
    var $v6_idx = $v6 | 0;
    var $st$5$0 = $v6_idx | 0;
    var $v6_idx_val$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $v6_idx + 4 | 0;
    var $v6_idx_val$1 = HEAP32[$st$5$1 >> 2];
    var $310 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($308, $v6_idx_val$0, $v6_idx_val$1, $309);
    if (($310 | 0) == 0) {
      __label__ = 92;
      break;
    } else {
      __label__ = 93;
      break;
    }
   case 92:
    var $bytes7_idx_val = HEAP32[$bytes7 >> 2];
    __label__ = 94;
    break;
   case 93:
    var $313 = $parser + 40 | 0;
    var $bytes7_idx4_val = HEAP32[$bytes7 >> 2];
    var $314 = __ZNK16JSAutoByteString3ptrEv($bytes7_idx4_val);
    var $315 = $313;
    var $316 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($315, $pn, 0, 132, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $314, tempInt));
    var $bytes7_idx_val = $bytes7_idx4_val;
    __label__ = 94;
    break;
   case 94:
    var $bytes7_idx_val;
    __ZN16JSAutoByteStringD1Ev($bytes7_idx_val);
    var $_0 = 0;
    __label__ = 106;
    break;
   case 95:
    if (($flags & 2 | 0) == 0) {
      __label__ = 96;
      break;
    } else {
      var $_0 = 1;
      __label__ = 106;
      break;
    }
   case 96:
    var $322 = __ZL16ParseNodeToQNamePN2js6ParserEP11JSParseNodeP10JSXMLArrayi($parser, $pn, $inScopeNSes, 0);
    if (($322 | 0) == 0) {
      var $_0 = 0;
      __label__ = 106;
      break;
    } else {
      __label__ = 97;
      break;
    }
   case 97:
    var $326 = HEAP32[$pn + 36 >> 2];
    if (($326 | 0) == 0) {
      __label__ = 99;
      break;
    } else {
      __label__ = 98;
      break;
    }
   case 98:
    var $336 = $326;
    __label__ = 100;
    break;
   case 99:
    var $336 = HEAP32[HEAP32[$2 + 52 >> 2] + 144136 >> 2];
    __label__ = 100;
    break;
   case 100:
    var $336;
    var $xml_class_0 = 3;
    var $qn_0 = $322;
    var $str_0 = $336 | 0;
    __label__ = 101;
    break;
   case 101:
    var $str_0;
    var $qn_0;
    var $xml_class_0;
    var $339 = __Z9js_NewXMLP9JSContext10JSXMLClass($2, $xml_class_0);
    if (($339 | 0) == 0) {
      var $_0 = 0;
      __label__ = 106;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 102:
    HEAP32[$339 + 12 >> 2] = $qn_0;
    var $343 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 65);
    if ($343) {
      __label__ = 103;
      break;
    } else {
      __label__ = 104;
      break;
    }
   case 103:
    var $345 = $339 + 20 | 0;
    var $347 = HEAP32[$345 >> 2] | 1;
    HEAP32[$345 >> 2] = $347;
    __label__ = 104;
    break;
   case 104:
    HEAP32[$339 + 24 >> 2] = $str_0;
    var $_0 = $339;
    __label__ = 106;
    break;
   case 105:
    var $351 = $parser + 40 | 0;
    var $352 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($351, $pn, 0, 170, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 106;
    break;
   case 106:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14ParseNodeToXMLPN2js6ParserEP11JSParseNodeP10JSXMLArrayj["X"] = 1;

function __ZN2js18AutoNamespaceArrayD1Ev($this) {
  __ZN2js18AutoNamespaceArrayD2Ev($this);
  return;
}

function __ZN2js18AutoNamespaceArrayD2Ev($this) {
  var $1 = $this + 12 | 0;
  __ZN10JSXMLArray6finishEP9JSContext($1);
  var $_idx_val = HEAP32[$this >> 2];
  var $_idx1_val = HEAP32[$this + 8 >> 2];
  __ZN2js12AutoGCRooterD2Ev($_idx_val, $_idx1_val);
  return;
}

function __ZL18ChompXMLWhitespaceP9JSContextP8JSString($cx, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str_idx_val = HEAP32[$str >> 2];
    var $1 = __ZNK8JSString6lengthEv($str_idx_val);
    var $2 = $cx;
    var $3 = __ZN8JSString8getCharsEP9JSContext($str, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + ($1 << 1) | 0;
    var $cp_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $cp_0;
    if ($cp_0 >>> 0 < $6 >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $end_0 = $6;
      __label__ = 6;
      break;
    }
   case 4:
    var $10 = HEAP16[$cp_0 >> 1];
    var $11 = __ZN2js7unicode10IsXMLSpaceEt($10);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      var $end_0 = $6;
      __label__ = 6;
      break;
    }
   case 5:
    var $cp_0 = $cp_0 + 2 | 0;
    __label__ = 3;
    break;
   case 6:
    var $end_0;
    if ($end_0 >>> 0 > $cp_0 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $16 = $end_0 - 2 | 0;
    var $17 = HEAP16[$16 >> 1];
    var $18 = __ZN2js7unicode10IsXMLSpaceEt($17);
    if ($18) {
      var $end_0 = $16;
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = $cp_0;
    var $23 = $end_0 - $21 >> 1;
    if (($23 | 0) == ($1 | 0)) {
      var $_0 = $str;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $28 = $21 - $3 >> 1;
    var $29 = $cx;
    var $30 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($29, $str, $28, $23);
    var $_0 = $30 | 0;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16XMLArrayTruncateP9JSContextP10JSXMLArrayj($cx, $array, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $array | 0;
    if (HEAPU32[$1 >> 2] >>> 0 > $length >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 2:
    var $6 = $array + 8 | 0;
    var $7 = HEAPU32[$6 >> 2];
    if (($length | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    if (($7 | 0) == 0) {
      var $vector_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $7;
    __ZN9JSContext5free_EPv($11);
    var $vector_0 = 0;
    __label__ = 7;
    break;
   case 5:
    var $13 = $7;
    var $14 = $length << 2;
    var $15 = $cx;
    var $16 = __ZN9JSContext8realloc_EPvj($15, $13, $14);
    if (($16 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $vector_0 = $16;
    __label__ = 7;
    break;
   case 7:
    var $vector_0;
    if (HEAPU32[$1 >> 2] >>> 0 > $length >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    HEAP32[$1 >> 2] = $length;
    __label__ = 9;
    break;
   case 9:
    HEAP32[$array + 4 >> 2] = $length;
    HEAP32[$6 >> 2] = $vector_0;
    __label__ = 10;
    break;
   case 10:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($array_0_0_val, $array_0_2_val, $elt, $identity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($identity | 0) == 0) {
      var $i_1 = 0;
      __label__ = 5;
      break;
    } else {
      var $i_0 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $i_0;
    if ($i_0 >>> 0 < $array_0_0_val >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = -1;
      __label__ = 8;
      break;
    }
   case 3:
    var $5 = HEAP32[$array_0_2_val + ($i_0 << 2) >> 2];
    var $6 = FUNCTION_TABLE[$identity]($5, $elt);
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $i_0;
      __label__ = 8;
      break;
    }
   case 4:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 5:
    var $i_1;
    if ($i_1 >>> 0 < $array_0_0_val >>> 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = -1;
      __label__ = 8;
      break;
    }
   case 6:
    if ((HEAP32[$array_0_2_val + ($i_1 << 2) >> 2] | 0) == ($elt | 0)) {
      var $_0 = $i_1;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $i_1 = $i_1 + 1 | 0;
    __label__ = 5;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18namespace_identityPKvS0_($a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $a;
    var $2 = $b;
    var $3 = __ZNK8JSObject13getNamePrefixEv($1);
    var $4 = __ZNK8JSObject13getNamePrefixEv($2);
    var $_not = ($3 | 0) == 0;
    var $5 = ($4 | 0) == 0;
    if ($_not | $5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZN2js12EqualStringsEP14JSLinearStringS1_($3, $4);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    if ($_not & $5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = __ZNK8JSObject10getNameURIEv($1);
    var $11 = __ZNK8JSObject10getNameURIEv($2);
    var $12 = __ZN2js12EqualStringsEP14JSLinearStringS1_($10, $11);
    var $_0 = $12 & 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSVAL_TO_STRING_IMPL4397($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_IS_UNDEFINED_IMPL4398($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -126) & 1;
}

function _JSVAL_IS_NULL_IMPL4400($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -122) & 1;
}

function _JSID_IS_INT4401($iden) {
  return $iden & 1;
}

function _JSID_TO_INT4402($iden) {
  return $iden >> 1;
}

function _JSID_IS_STRING4403($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_TO_STRING4405($iden) {
  return $iden;
}

function _JS_ASSERT_STRING_IS_FLAT($str) {
  return $str;
}

function __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($agg_result, $_0_0_0_val$0, $_0_0_0_val$1) {
  var $agg_result_0 = $agg_result | 0;
  HEAP32[$agg_result_0 >> 2] = $_0_0_0_val$0;
  HEAP32[$agg_result_0 + 4 >> 2] = $_0_0_0_val$1;
  return;
}

function __ZL14XMLArrayDeleteP9JSContextP10JSXMLArrayji($array, $index, $compress) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $array | 0;
    var $2 = HEAPU32[$1 >> 2];
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 2:
    var $6 = HEAP32[$array + 8 >> 2];
    if (($compress | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $index + 1 | 0;
    if ($8 >>> 0 < $2 >>> 0) {
      var $_011 = $index;
      var $10 = $8;
      __label__ = 4;
      break;
    } else {
      var $_lcssa = $8;
      __label__ = 5;
      break;
    }
   case 4:
    var $10;
    var $_011;
    var $12 = HEAP32[$6 + ($10 << 2) >> 2];
    var $13 = $6 + ($_011 << 2) | 0;
    HEAP32[$13 >> 2] = $12;
    var $14 = $10 + 1 | 0;
    if (($14 | 0) == ($2 | 0)) {
      var $_lcssa = $2;
      __label__ = 5;
      break;
    } else {
      var $_011 = $10;
      var $10 = $14;
      __label__ = 4;
      break;
    }
   case 5:
    var $_lcssa;
    HEAP32[$1 >> 2] = $2 - 1 | 0;
    var $16 = $array + 4 | 0;
    var $18 = HEAP32[$16 >> 2] & 2147483647;
    HEAP32[$16 >> 2] = $18;
    var $_1 = $_lcssa;
    __label__ = 7;
    break;
   case 6:
    var $20 = $6 + ($index << 2) | 0;
    HEAP32[$20 >> 2] = 0;
    var $_1 = $index;
    __label__ = 7;
    break;
   case 7:
    var $_1;
    var $cursor_02 = HEAP32[$array + 12 >> 2];
    if (($cursor_02 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $cursor_03 = $cursor_02;
      __label__ = 8;
      break;
    }
   case 8:
    var $cursor_03;
    var $24 = $cursor_03 + 4 | 0;
    var $25 = HEAPU32[$24 >> 2];
    if ($25 >>> 0 > $_1 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    HEAP32[$24 >> 2] = $25 - 1 | 0;
    __label__ = 10;
    break;
   case 10:
    var $cursor_0 = HEAPU32[$cursor_03 + 8 >> 2];
    if (($cursor_0 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $cursor_03 = $cursor_0;
      __label__ = 8;
      break;
    }
   case 11:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16AutoObjectRooter9setObjectEP8JSObject($this, $obj) {
  HEAP32[$this + 12 >> 2] = $obj;
  return;
}

function __ZL16ParseNodeToQNamePN2js6ParserEP11JSParseNodeP10JSXMLArrayi($parser, $pn, $inScopeNSes, $isAttributeName) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $bytes = __stackBase__ + 8;
    var $1 = $parser + 12 | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $5 = HEAPU32[$pn + 32 >> 2];
    var $_idx1_val = HEAP32[$5 + 4 >> 2];
    var $6 = __ZNK14JSLinearString5charsEv($_idx1_val);
    var $_idx_val = HEAP32[$5 >> 2];
    var $7 = __ZNK8JSString6lengthEv($_idx_val);
    var $11 = HEAPU32[HEAP32[$2 + 52 >> 2] + 144136 >> 2];
    var $12 = $11 | 0;
    var $13 = $6 + ($7 << 1) | 0;
    var $14 = __Z15js_strchr_limitPKttS0_($6, 58, $13);
    if (($14 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $17 = $5 | 0;
    var $21 = $14 - $6 >> 1;
    var $22 = $2;
    var $23 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($22, $17, 0, $21);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($21 >>> 0 > 2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    var $28 = __ZL12IS_XML_CHARSPKt($6);
    if ($28) {
      __label__ = 5;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 5:
    if (($21 | 0) == 3) {
      __label__ = 6;
      break;
    } else if (($21 | 0) == 5) {
      __label__ = 7;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 6:
    var $31 = $2;
    var $32 = _JS_InternString($31, STRING_TABLE.__ZL17xml_namespace_str | 0);
    var $33 = _JS_ASSERT_STRING_IS_FLAT($32);
    var $34 = $33 | 0;
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      var $uri_0 = $34;
      __label__ = 16;
      break;
    }
   case 7:
    var $37 = __ZL16HAS_NS_AFTER_XMLPKt($6);
    if ($37) {
      __label__ = 8;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 8:
    var $39 = $2;
    var $40 = _JS_InternString($39, STRING_TABLE.__ZL19xmlns_namespace_str | 0);
    var $41 = _JS_ASSERT_STRING_IS_FLAT($40);
    var $42 = $41 | 0;
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      var $uri_0 = $42;
      __label__ = 16;
      break;
    }
   case 9:
    var $46 = HEAPU32[$inScopeNSes >> 2];
    var $47 = $inScopeNSes + 8 | 0;
    var $n_0 = $46;
    __label__ = 10;
    break;
   case 10:
    var $n_0;
    if (($n_0 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $50 = $n_0 - 1 | 0;
    if ($50 >>> 0 < $46 >>> 0) {
      __label__ = 12;
      break;
    } else {
      var $58 = 0;
      __label__ = 13;
      break;
    }
   case 12:
    var $58 = HEAP32[HEAP32[$47 >> 2] + ($50 << 2) >> 2];
    __label__ = 13;
    break;
   case 13:
    var $58;
    var $59 = __ZNK8JSObject13getNamePrefixEv($58);
    if (($59 | 0) == 0) {
      var $n_0 = $50;
      __label__ = 10;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $62 = __ZN2js12EqualStringsEP14JSLinearStringS1_($59, $23);
    if ($62) {
      __label__ = 15;
      break;
    } else {
      var $n_0 = $50;
      __label__ = 10;
      break;
    }
   case 15:
    var $64 = __ZNK8JSObject10getNameURIEv($58);
    var $uri_0 = $64;
    __label__ = 16;
    break;
   case 16:
    var $uri_0;
    if (($uri_0 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 17:
    var $67 = $23 | 0;
    __ZN2JSL11StringValueEP8JSString4311($v, $67);
    __ZN16JSAutoByteStringC1Ev($bytes);
    var $69 = HEAP32[$1 >> 2];
    var $70 = $bytes;
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $71 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($69, $v_idx_val$0, $v_idx_val$1, $70);
    if (($71 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $bytes_idx_val = HEAP32[$bytes >> 2];
    __label__ = 20;
    break;
   case 19:
    var $74 = $parser + 40 | 0;
    var $bytes_idx2_val = HEAP32[$bytes >> 2];
    var $75 = __ZNK16JSAutoByteString3ptrEv($bytes_idx2_val);
    var $76 = $74;
    var $77 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($76, $pn, 0, 177, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $75, tempInt));
    var $bytes_idx_val = $bytes_idx2_val;
    __label__ = 20;
    break;
   case 20:
    var $bytes_idx_val;
    __ZN16JSAutoByteStringD1Ev($bytes_idx_val);
    var $_0 = 0;
    __label__ = 33;
    break;
   case 21:
    var $81 = $14 + 2 | 0;
    var $82 = $7 - 1 - $21 | 0;
    var $83 = HEAP32[$1 >> 2];
    var $84 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($83, $81, $82, 0);
    if (($84 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $localName_0 = $84;
    var $prefix_1 = $23;
    var $uri_3 = $uri_0;
    var $115 = HEAP32[$1 >> 2];
    __label__ = 32;
    break;
   case 23:
    if (($isAttributeName | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      var $localName_0 = $5;
      var $prefix_1 = $12;
      var $uri_3 = $12;
      var $115 = $2;
      __label__ = 32;
      break;
    }
   case 24:
    var $91 = HEAPU32[$inScopeNSes >> 2];
    var $92 = $inScopeNSes + 8 | 0;
    var $n_1 = $91;
    __label__ = 25;
    break;
   case 25:
    var $n_1;
    if (($n_1 | 0) == 0) {
      var $uri_1 = $12;
      __label__ = 31;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $96 = $n_1 - 1 | 0;
    if ($96 >>> 0 < $91 >>> 0) {
      __label__ = 27;
      break;
    } else {
      var $104 = 0;
      __label__ = 28;
      break;
    }
   case 27:
    var $104 = HEAP32[HEAP32[$92 >> 2] + ($96 << 2) >> 2];
    __label__ = 28;
    break;
   case 28:
    var $104;
    var $105 = __ZNK8JSObject13getNamePrefixEv($104);
    if (($105 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $_idx4_val = HEAP32[$105 >> 2];
    var $108 = __ZNK8JSString5emptyEv($_idx4_val);
    if ($108) {
      __label__ = 30;
      break;
    } else {
      var $n_1 = $96;
      __label__ = 25;
      break;
    }
   case 30:
    var $110 = __ZNK8JSObject10getNameURIEv($104);
    var $uri_1 = $110;
    __label__ = 31;
    break;
   case 31:
    var $uri_1;
    var $_idx3_val = HEAP32[$uri_1 >> 2];
    var $111 = __ZNK8JSString5emptyEv($_idx3_val);
    var $112 = $111 ? $11 : 0;
    var $localName_0 = $5;
    var $prefix_1 = $112 | 0;
    var $uri_3 = $uri_1;
    var $115 = $2;
    __label__ = 32;
    break;
   case 32:
    var $115;
    var $uri_3;
    var $prefix_1;
    var $localName_0;
    var $116 = __ZL11NewXMLQNameP9JSContextP14JSLinearStringS2_P6JSAtom($115, $uri_3, $prefix_1, $localName_0);
    var $_0 = $116;
    __label__ = 33;
    break;
   case 33:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16ParseNodeToQNamePN2js6ParserEP11JSParseNodeP10JSXMLArrayi["X"] = 1;

function __ZNK8JSObject13getNamePrefixEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK8JSObject7getSlotEj($1, 0);
    var $_idx = $2 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $3 = __ZNK2JS5Value11isUndefinedEv($_idx_val$0, $_idx_val$1);
    if ($3) {
      var $8 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2JS5Value8toStringEv($_idx_val$0, $_idx_val$1);
    var $6 = __ZN8JSString8asLinearEv($5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18AutoNamespaceArrayC2EP9JSContext($this, $cx) {
  var $1 = $this;
  var $2 = $cx;
  __ZN2js12AutoGCRooterC2EP9JSContexti($1, $2, -8);
  var $3 = $this + 12 | 0;
  __ZN10JSXMLArray4initEv($3);
  return;
}

function __ZN9JSContext7delete_I11JSXMLFilterEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN11JSXMLFilterD1Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11JSXMLFilterD1Ev($this) {
  __ZN11JSXMLFilterD2Ev($this);
  return;
}

function __ZN11JSXMLFilterD2Ev($this) {
  var $1 = $this + 12 | 0;
  __ZN16JSXMLArrayCursorD1Ev($1);
  return;
}

function __ZN16JSXMLArrayCursorD1Ev($this) {
  __ZN16JSXMLArrayCursorD2Ev($this);
  return;
}

function __ZN16JSXMLArrayCursorD2Ev($this) {
  __ZN16JSXMLArrayCursor10disconnectEv($this);
  return;
}

function __ZL19DeleteNamedPropertyP9JSContextP5JSXMLP8JSObjecti($xml, $nameqn, $attributes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$xml + 16 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 2:
    var $3 = $xml + 24 | 0;
    var $4 = HEAP32[$3 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = $xml + 32 | 0;
    var $index_06 = 0;
    var $7 = $4;
    __label__ = 4;
    break;
   case 4:
    var $7;
    var $index_06;
    var $10 = HEAP32[HEAP32[$6 >> 2] + ($index_06 << 2) >> 2];
    var $11 = $10;
    if (($10 | 0) == 0) {
      var $20 = $7;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$10 + 16 >> 2] | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      var $20 = $7;
      __label__ = 7;
      break;
    }
   case 6:
    __ZL19DeleteNamedPropertyP9JSContextP5JSXMLP8JSObjecti($11, $nameqn, $attributes);
    var $20 = HEAP32[$3 >> 2];
    __label__ = 7;
    break;
   case 7:
    var $20;
    var $21 = $index_06 + 1 | 0;
    if ($21 >>> 0 < $20 >>> 0) {
      var $index_06 = $21;
      var $7 = $20;
      __label__ = 4;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 8:
    var $24 = ($attributes | 0) == 0;
    var $array_0 = $24 ? $xml + 24 | 0 : $xml + 56 | 0;
    var $matcher_0 = $24 ? 280 : 278;
    var $27 = $array_0 | 0;
    if ((HEAP32[$27 >> 2] | 0) == 0) {
      var $deleteCount_0_lcssa = 0;
      var $_lcssa1 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $30 = $array_0 + 8 | 0;
    var $index_12 = 0;
    var $deleteCount_03 = 0;
    __label__ = 10;
    break;
   case 10:
    var $deleteCount_03;
    var $index_12;
    var $33 = HEAP32[HEAP32[$30 >> 2] + ($index_12 << 2) >> 2];
    if (($33 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $36 = $33;
    var $37 = FUNCTION_TABLE[$matcher_0]($nameqn, $36);
    if (($37 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $41 = $33 + 8 | 0;
    HEAP32[$41 >> 2] = 0;
    __ZL14XMLArrayDeleteP9JSContextP10JSXMLArrayji($array_0, $index_12, 0);
    var $deleteCount_1 = $deleteCount_03 + 1 | 0;
    __label__ = 17;
    break;
   case 13:
    if (($deleteCount_03 | 0) == 0) {
      var $deleteCount_1 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $47 = $index_12 - $deleteCount_03 | 0;
    if (HEAPU32[$27 >> 2] >>> 0 > $47 >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    HEAP32[$27 >> 2] = $47 + 1 | 0;
    __label__ = 16;
    break;
   case 16:
    var $51 = HEAP32[$30 >> 2];
    var $53 = HEAP32[$51 + ($index_12 << 2) >> 2];
    var $54 = $51 + ($47 << 2) | 0;
    HEAP32[$54 >> 2] = $53;
    var $deleteCount_1 = $deleteCount_03;
    __label__ = 17;
    break;
   case 17:
    var $deleteCount_1;
    var $55 = $index_12 + 1 | 0;
    var $56 = HEAPU32[$27 >> 2];
    if ($55 >>> 0 < $56 >>> 0) {
      var $index_12 = $55;
      var $deleteCount_03 = $deleteCount_1;
      __label__ = 10;
      break;
    } else {
      var $deleteCount_0_lcssa = $deleteCount_1;
      var $_lcssa1 = $56;
      __label__ = 18;
      break;
    }
   case 18:
    var $_lcssa1;
    var $deleteCount_0_lcssa;
    HEAP32[$27 >> 2] = $_lcssa1 - $deleteCount_0_lcssa | 0;
    __label__ = 19;
    break;
   case 19:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19DeleteNamedPropertyP9JSContextP5JSXMLP8JSObjecti["X"] = 1;

function __ZL13DeleteByIndexP9JSContextP5JSXMLj($xml, $index) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$xml + 16 >> 2] >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $5 = $xml + 24 | 0;
    if (HEAPU32[$5 >> 2] >>> 0 > $index >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $13 = HEAP32[HEAP32[$xml + 32 >> 2] + ($index << 2) >> 2];
    if (($13 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = $13 + 8 | 0;
    HEAP32[$17 >> 2] = 0;
    __label__ = 5;
    break;
   case 5:
    __ZL14XMLArrayDeleteP9JSContextP10JSXMLArrayji($5, $index, 1);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13MatchAttrNameP8JSObjectP5JSXML($nameqn, $attr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$attr + 12 >> 2];
    var $3 = __ZNK8JSObject17getQNameLocalNameEv($nameqn);
    var $4 = $3 | 0;
    var $_idx_val = HEAP32[$3 >> 2];
    var $5 = __ZNK8JSString6lengthEv($_idx_val);
    if (($5 | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$3 + 4 >> 2];
    var $8 = __ZNK14JSLinearString5charsEv($_idx1_val);
    if (HEAP16[$8 >> 1] << 16 >> 16 == 42) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK8JSObject17getQNameLocalNameEv($2);
    var $13 = $12 | 0;
    var $14 = __ZN2js12EqualStringsEP14JSLinearStringS1_($13, $4);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      var $22 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $16 = __ZNK8JSObject10getNameURIEv($nameqn);
    if (($16 | 0) == 0) {
      var $22 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = __ZNK8JSObject10getNameURIEv($2);
    var $20 = __ZN2js12EqualStringsEP14JSLinearStringS1_($19, $16);
    var $22 = $20;
    __label__ = 6;
    break;
   case 6:
    var $22;
    return $22 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13MatchElemNameP8JSObjectP5JSXML($nameqn, $elem) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject17getQNameLocalNameEv($nameqn);
    var $2 = $1 | 0;
    var $_idx_val = HEAP32[$1 >> 2];
    var $3 = __ZNK8JSString6lengthEv($_idx_val);
    if (($3 | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$1 + 4 >> 2];
    var $6 = __ZNK14JSLinearString5charsEv($_idx1_val);
    if (HEAP16[$6 >> 1] << 16 >> 16 == 42) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$elem + 16 >> 2] | 0) == 1) {
      __label__ = 4;
      break;
    } else {
      var $32 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $15 = HEAP32[$elem + 12 >> 2];
    var $16 = __ZNK8JSObject17getQNameLocalNameEv($15);
    var $17 = $16 | 0;
    var $18 = __ZN2js12EqualStringsEP14JSLinearStringS1_($17, $2);
    if ($18) {
      __label__ = 5;
      break;
    } else {
      var $32 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $20 = __ZNK8JSObject10getNameURIEv($nameqn);
    if (($20 | 0) == 0) {
      var $32 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$elem + 16 >> 2] | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      var $32 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $28 = HEAP32[$elem + 12 >> 2];
    var $29 = __ZNK8JSObject10getNameURIEv($28);
    var $30 = __ZN2js12EqualStringsEP14JSLinearStringS1_($29, $20);
    var $32 = $30;
    __label__ = 8;
    break;
   case 8:
    var $32;
    return $32 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9ToXMLNameP9JSContextN2JS5ValueEPi($cx, $_0_0_0_val$0, $_0_0_0_val$1, $funidp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $index = __stackBase__ + 8;
    var $1 = __stackBase__ + 12;
    var $2 = __stackBase__ + 20;
    var $bytes = __stackBase__ + 28;
    var $3 = __stackBase__ + 32;
    var $4 = $v | 0;
    var $st$7$0 = $4 | 0;
    HEAP32[$st$7$0 >> 2] = $_0_0_0_val$0;
    var $st$7$1 = $4 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $_0_0_0_val$1;
    var $5 = _JSVAL_IS_STRING4320($_0_0_0_val$0, $_0_0_0_val$1);
    var $7$0 = HEAP32[$4 >> 2];
    var $7$1 = HEAP32[$4 + 4 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = _JSVAL_TO_STRING4321($7$0, $7$1);
    var $name_0 = $9;
    __label__ = 9;
    break;
   case 3:
    var $11 = _JSVAL_IS_PRIMITIVE4303($7$0, $7$1);
    var $st$3$0 = $4 | 0;
    var $13$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $4 + 4 | 0;
    var $13$1 = HEAP32[$st$3$1 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZL16ReportBadXMLNameP9JSContextRKN2JS5ValueE($cx, $13$0, $13$1);
    var $_0 = 0;
    __label__ = 20;
    break;
   case 5:
    var $16 = _JSVAL_TO_OBJECT4304($13$0, $13$1);
    var $_idx_val = HEAP32[$16 + 4 >> 2];
    var $18 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($18 | 0) == (__ZN2js18AttributeNameClassE | 0) | ($18 | 0) == (__ZN2js10QNameClassE | 0)) {
      var $obj_0 = $16;
      __label__ = 15;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($18 | 0) == (__ZN2js12AnyNameClassE | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $name_1 = HEAP32[HEAP32[$cx + 52 >> 2] + 210412 >> 2] | 0;
    __label__ = 14;
    break;
   case 8:
    var $30 = $cx;
    var $v_idx_val$0 = HEAP32[$4 >> 2];
    var $v_idx_val$1 = HEAP32[$4 + 4 >> 2];
    var $31 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($30, $v_idx_val$0, $v_idx_val$1);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      var $name_0 = $31;
      __label__ = 9;
      break;
    }
   case 9:
    var $name_0;
    var $34 = $cx;
    var $35 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($34, $name_0);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = $35;
    var $39 = __ZL12ATOM_TO_JSIDP6JSAtom4336($38);
    var $40 = __Z12js_IdIsIndexiPj($39, $index);
    if (($40 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 11:
    var $_idx1_val = HEAP32[$35 + 4 >> 2];
    var $43 = __ZNK14JSLinearString5charsEv($_idx1_val);
    if (HEAP16[$43 >> 1] << 16 >> 16 == 64) {
      __label__ = 12;
      break;
    } else {
      var $name_1 = $name_0;
      __label__ = 14;
      break;
    }
   case 12:
    var $name_0_idx_val = HEAP32[$name_0 >> 2];
    var $47 = __ZNK8JSString6lengthEv($name_0_idx_val);
    var $48 = $47 - 1 | 0;
    var $49 = $cx;
    var $50 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($49, $name_0, 1, $48);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $53 = $50 | 0;
    HEAP32[$funidp >> 2] = 2;
    _STRING_TO_JSVAL4322($1, $53);
    var $_idx4 = $1 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    var $54 = __ZL15ToAttributeNameP9JSContextN2JS5ValueE($cx, $_idx4_val$0, $_idx4_val$1);
    var $_0 = $54;
    __label__ = 20;
    break;
   case 14:
    var $name_1;
    _STRING_TO_JSVAL4322($2, $name_1);
    var $56 = $2 | 0;
    var $st$3$0 = $56 | 0;
    var $57$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $56 + 4 | 0;
    var $57$1 = HEAP32[$st$3$1 >> 2];
    var $st$7$0 = $4 | 0;
    HEAP32[$st$7$0 >> 2] = $57$0;
    var $st$7$1 = $4 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $57$1;
    var $58 = $cx;
    var $59 = __Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE($58, __ZN2js10QNameClassE, 0, 1, $v);
    var $60 = $59;
    if (($59 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      var $obj_0 = $60;
      __label__ = 15;
      break;
    }
   case 15:
    var $obj_0;
    var $63 = __ZL29GetLocalNameFromFunctionQNameP8JSObjectPiP9JSContext($obj_0, $funidp, $cx);
    if ($63) {
      var $_0 = $obj_0;
      __label__ = 20;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    HEAP32[$funidp >> 2] = 2;
    var $_0 = $obj_0;
    __label__ = 20;
    break;
   case 17:
    __ZN16JSAutoByteStringC1Ev($bytes);
    __ZN2JSL11StringValueEP8JSString4311($3, $name_0);
    var $66 = $cx;
    var $67 = $bytes;
    var $_idx7 = $3 | 0;
    var $_idx7_val$0 = HEAP32[$_idx7 >> 2];
    var $_idx7_val$1 = HEAP32[$_idx7 + 4 >> 2];
    var $68 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($66, $_idx7_val$0, $_idx7_val$1, $67);
    var $bytes_idx_val_pre = HEAP32[$bytes >> 2];
    if (($68 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $71 = __ZNK16JSAutoByteString3ptrEv($bytes_idx_val_pre);
    _JS_ReportErrorNumber($34, 4, 179, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $71, tempInt));
    __label__ = 19;
    break;
   case 19:
    __ZN16JSAutoByteStringD1Ev($bytes_idx_val_pre);
    var $_0 = 0;
    __label__ = 20;
    break;
   case 20:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9ToXMLNameP9JSContextN2JS5ValueEPi["X"] = 1;

function __ZL17DescendantsHelperP9JSContextP5JSXMLP8JSObjectS2_($cx, $xml, $nameqn, $list) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx;
    __Z21js_ReportOverRecursedP9JSContext($6);
    var $_0 = 0;
    __label__ = 25;
    break;
   case 3:
    var $8 = $xml + 16 | 0;
    var $9 = HEAPU32[$8 >> 2];
    if (($9 | 0) == 1) {
      __label__ = 4;
      break;
    } else {
      var $37 = $9;
      __label__ = 13;
      break;
    }
   case 4:
    var $_idx1_val = HEAP32[$nameqn + 4 >> 2];
    var $13 = __ZNK8JSObject8getClassEv($_idx1_val);
    if (($13 | 0) == (__ZN2js18AttributeNameClassE | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 5:
    var $16 = $xml + 56 | 0;
    var $17 = HEAPU32[$16 >> 2];
    var $18 = $xml + 64 | 0;
    var $i_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $i_0;
    if ($i_0 >>> 0 < $17 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 7:
    if ($i_0 >>> 0 < HEAPU32[$16 >> 2] >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $27 = HEAP32[HEAP32[$18 >> 2] + ($i_0 << 2) >> 2];
    var $28 = $27;
    if (($27 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $31 = __ZL13MatchAttrNameP8JSObjectP5JSXML($nameqn, $28);
    if (($31 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $34 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $list, $28);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 6;
    break;
   case 12:
    var $37 = HEAP32[$8 >> 2];
    __label__ = 13;
    break;
   case 13:
    var $37;
    if ($37 >>> 0 < 2) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $42 = 0;
    var $_pre_phi = $xml + 24 | 0;
    __label__ = 16;
    break;
   case 15:
    var $39 = $xml + 24 | 0;
    var $42 = HEAP32[$39 >> 2];
    var $_pre_phi = $39;
    __label__ = 16;
    break;
   case 16:
    var $_pre_phi;
    var $42;
    var $43 = $xml + 32 | 0;
    var $_idx = $nameqn + 4 | 0;
    var $i_1 = 0;
    __label__ = 17;
    break;
   case 17:
    var $i_1;
    if ($i_1 >>> 0 < $42 >>> 0) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 1;
      __label__ = 25;
      break;
    }
   case 18:
    if ($i_1 >>> 0 < HEAPU32[$_pre_phi >> 2] >>> 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 19:
    var $52 = HEAP32[HEAP32[$43 >> 2] + ($i_1 << 2) >> 2];
    var $53 = $52;
    if (($52 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $_idx_val = HEAP32[$_idx >> 2];
    var $57 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($57 | 0) == (__ZN2js18AttributeNameClassE | 0)) {
      __label__ = 23;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $60 = __ZL13MatchElemNameP8JSObjectP5JSXML($nameqn, $53);
    if (($60 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $63 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $list, $53);
    if (($63 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $66 = __ZL17DescendantsHelperP9JSContextP5JSXMLP8JSObjectS2_($cx, $53, $nameqn, $list);
    if (($66 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $i_1 = $i_1 + 1 | 0;
    __label__ = 17;
    break;
   case 25:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17DescendantsHelperP9JSContextP5JSXMLP8JSObjectS2_["X"] = 1;

function __ZL16ReportBadXMLNameP9JSContextRKN2JS5ValueE($cx, $idval_0_0_0_val$0, $idval_0_0_0_val$1) {
  var $1 = $cx;
  var $2 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($1, 0, 179, 0, $idval_0_0_0_val$0, $idval_0_0_0_val$1, 0, 0);
  return;
}

function __ZN2JSL14UndefinedValueEv4406($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function _JSVAL_IS_BOOLEAN4407($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_BOOLEAN_IMPL4410($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE4408($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $vp_idx1 = $vp | 0;
    var $vp_idx1_val$0 = HEAP32[$vp_idx1 >> 2];
    var $vp_idx1_val$1 = HEAP32[$vp_idx1 + 4 >> 2];
    var $1 = __ZNK2JS5Value11isPrimitiveEv($vp_idx1_val$0, $vp_idx1_val$1);
    if ($1) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($vp_idx1_val$0, $vp_idx1_val$1);
    var $4 = $3;
    var $5 = $cx;
    var $6 = __ZN8JSObject12defaultValueEP9JSContext6JSTypePN2JS5ValueE($4, $5, 3, $vp);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js18AutoNamespaceArray6lengthEv($this_0_1_0_val) {
  return $this_0_1_0_val;
}

function __ZL14XMLToXMLStringP9JSContextP5JSXMLPK10JSXMLArrayj($cx, $xml, $ancestorNSes, $indentLevel) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 272;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pretty = __stackBase__;
    var $sb = __stackBase__ + 4;
    var $i = __stackBase__ + 84;
    var $empty = __stackBase__ + 88;
    var $decls = __stackBase__ + 116;
    var $ancdecls = __stackBase__ + 144;
    var $cursor = __stackBase__ + 172;
    var $cursor1 = __stackBase__ + 192;
    var $cursor3 = __stackBase__ + 212;
    var $cursor5 = __stackBase__ + 232;
    var $cursor8 = __stackBase__ + 252;
    var $1 = $sb;
    var $2 = $cx;
    __ZN2js12StringBufferC1EP9JSContext($1, $2);
    __ZN2js18AutoNamespaceArrayC1EP9JSContext($empty, $cx);
    __ZN2js18AutoNamespaceArrayC1EP9JSContext($decls, $cx);
    __ZN2js18AutoNamespaceArrayC1EP9JSContext($ancdecls, $cx);
    var $3 = __ZL20GetBooleanXMLSettingP9JSContextPKcPi($cx, STRING_TABLE.__ZL21js_prettyPrinting_str | 0, $pretty);
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 115;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = (HEAP32[$pretty >> 2] | 0) == 0;
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $indentLevel & 2147483647;
    var $10 = $sb;
    var $11 = __ZN2js12StringBuffer7appendNEtj($10, $9);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 4:
    var $14 = HEAP32[$xml + 16 >> 2];
    if (($14 | 0) == 4) {
      __label__ = 5;
      break;
    } else if (($14 | 0) == 2) {
      __label__ = 8;
      break;
    } else if (($14 | 0) == 5) {
      __label__ = 9;
      break;
    } else if (($14 | 0) == 3) {
      __label__ = 10;
      break;
    } else if (($14 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 5:
    var $18 = HEAP32[$xml + 24 >> 2];
    if ($7) {
      var $str_0 = $18;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = __ZL18ChompXMLWhitespaceP9JSContextP8JSString($cx, $18);
    if (($20 | 0) == 0) {
      var $_1 = 0;
      __label__ = 115;
      break;
    } else {
      var $str_0 = $20;
      __label__ = 7;
      break;
    }
   case 7:
    var $str_0;
    var $23 = $indentLevel & -2147483648;
    var $24 = __ZL18EscapeElementValueP9JSContextRN2js12StringBufferEP8JSStringj($cx, $sb, $str_0, $23);
    var $_1 = $24 | 0;
    __label__ = 115;
    break;
   case 8:
    var $29 = HEAP32[$xml + 24 >> 2];
    var $indentLevel_lobit = $indentLevel >>> 31;
    var $30 = __ZL20EscapeAttributeValueP9JSContextRN2js12StringBufferEP8JSStringi($cx, $sb, $29, $indentLevel_lobit);
    var $_1 = $30 | 0;
    __label__ = 115;
    break;
   case 9:
    var $35 = HEAP32[$xml + 24 >> 2];
    var $36 = __ZL20MakeXMLCommentStringP9JSContextRN2js12StringBufferEP8JSString($sb, $35);
    var $_1 = $36 | 0;
    __label__ = 115;
    break;
   case 10:
    var $40 = HEAP32[$xml + 12 >> 2];
    var $41 = __ZNK8JSObject17getQNameLocalNameEv($40);
    var $42 = $41 | 0;
    var $45 = HEAP32[$xml + 24 >> 2];
    var $46 = __ZL15MakeXMLPIStringP9JSContextRN2js12StringBufferEP8JSStringS5_($sb, $42, $45);
    var $_1 = $46 | 0;
    __label__ = 115;
    break;
   case 11:
    var $49 = $xml + 24 | 0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor, $49);
    var $storemerge = 0;
    __label__ = 12;
    break;
   case 12:
    var $storemerge;
    var $51 = __ZN16JSXMLArrayCursor7getNextEv($cursor);
    var $52 = $51;
    if (($51 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if ($7 | ($storemerge | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $57 = __ZN2js12StringBuffer6appendEt($1, 10);
    if ($57) {
      __label__ = 15;
      break;
    } else {
      __label__ = 112;
      break;
    }
   case 15:
    var $59 = __ZL14XMLToXMLStringP9JSContextP5JSXMLPK10JSXMLArrayj($cx, $52, $ancestorNSes, $indentLevel);
    if (($59 | 0) == 0) {
      __label__ = 113;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $62 = __ZN2js12StringBuffer6appendEP8JSString($1, $59);
    if ($62) {
      __label__ = 17;
      break;
    } else {
      __label__ = 114;
      break;
    }
   case 17:
    var $storemerge = $storemerge + 1 | 0;
    __label__ = 12;
    break;
   case 18:
    HEAP32[$i >> 2] = $storemerge;
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $66 = __ZNK2js12StringBuffer5emptyEv($1);
    if ($66) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $_1 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 115;
    break;
   case 20:
    var $74 = $sb;
    var $75 = __ZN2js12StringBuffer12finishStringEv($74);
    var $_1 = $75 | 0;
    __label__ = 115;
    break;
   case 21:
    var $_03 = ($ancestorNSes | 0) == 0 ? $empty + 12 | 0 : $ancestorNSes;
    var $80 = $xml + 40 | 0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor1, $80);
    var $81 = $decls + 12 | 0;
    var $82 = $81 | 0;
    var $_03_idx = $_03 | 0;
    var $_03_idx2 = $_03 + 8 | 0;
    __label__ = 22;
    break;
   case 22:
    var $83 = __ZN16JSXMLArrayCursor7getNextEv($cursor1);
    var $84 = $83;
    if (($83 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $87 = __ZL10IsDeclaredPK8JSObject($84);
    if (($87 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $_03_idx_val = HEAP32[$_03_idx >> 2];
    var $_03_idx2_val = HEAP32[$_03_idx2 >> 2];
    var $90 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_03_idx_val, $_03_idx2_val, $83, 282);
    if (($90 | 0) == -1) {
      __label__ = 25;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 25:
    var $93 = __ZNK8JSObject13getNamePrefixEv($84);
    var $94 = __ZNK8JSObject10getNameURIEv($84);
    var $95 = __ZL15NewXMLNamespaceP9JSContextP14JSLinearStringS2_i($cx, $93, $94, 1);
    if (($95 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $98 = HEAP32[$82 >> 2];
    var $99 = $95;
    var $100 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $81, $98, $99);
    if (($100 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 27:
    __ZN16JSXMLArrayCursorD1Ev($cursor1);
    var $_1 = 0;
    __label__ = 115;
    break;
   case 28:
    __ZN16JSXMLArrayCursorD1Ev($cursor1);
    var $103 = $ancdecls + 12 | 0;
    var $104 = HEAP32[$_03_idx >> 2];
    var $decls_idx8 = $decls + 12 | 0;
    var $decls_idx8_val = HEAP32[$decls_idx8 >> 2];
    var $105 = __ZNK2js18AutoNamespaceArray6lengthEv($decls_idx8_val);
    var $106 = $105 + $104 | 0;
    var $107 = __ZN10JSXMLArray11setCapacityEP9JSContextj($103, $cx, $106);
    if ($107) {
      __label__ = 29;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 29:
    HEAP32[$i >> 2] = 0;
    var $109 = HEAPU32[$_03_idx >> 2];
    var $110 = $103 | 0;
    var $112 = 0;
    __label__ = 30;
    break;
   case 30:
    var $112;
    if ($112 >>> 0 < $109 >>> 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 31:
    if ($112 >>> 0 < HEAPU32[$_03_idx >> 2] >>> 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 32:
    var $120 = HEAPU32[HEAP32[$_03_idx2 >> 2] + ($112 << 2) >> 2];
    if (($120 | 0) == 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $123 = HEAP32[$110 >> 2];
    var $124 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $103, $123, $120);
    if (($124 | 0) == 0) {
      var $_1 = 0;
      __label__ = 115;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $126 = $112 + 1 | 0;
    HEAP32[$i >> 2] = $126;
    var $112 = $126;
    __label__ = 30;
    break;
   case 35:
    HEAP32[$i >> 2] = 0;
    var $decls_idx_val = HEAP32[$decls_idx8 >> 2];
    var $128 = __ZNK2js18AutoNamespaceArray6lengthEv($decls_idx_val);
    var $129 = $decls + 20 | 0;
    var $131 = 0;
    __label__ = 36;
    break;
   case 36:
    var $131;
    if ($131 >>> 0 < $128 >>> 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 37:
    if ($131 >>> 0 < HEAPU32[$decls_idx8 >> 2] >>> 0) {
      __label__ = 38;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 38:
    var $139 = HEAPU32[HEAP32[$129 >> 2] + ($131 << 2) >> 2];
    if (($139 | 0) == 0) {
      __label__ = 40;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $142 = HEAP32[$110 >> 2];
    var $143 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $103, $142, $139);
    if (($143 | 0) == 0) {
      var $_1 = 0;
      __label__ = 115;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $145 = $131 + 1 | 0;
    HEAP32[$i >> 2] = $145;
    var $131 = $145;
    __label__ = 36;
    break;
   case 41:
    var $147 = $xml + 12 | 0;
    var $148 = HEAP32[$147 >> 2];
    var $149 = __ZL12GetNamespaceP9JSContextP8JSObjectPK10JSXMLArray($cx, $148, $103);
    if (($149 | 0) == 0) {
      var $_1 = 0;
      __label__ = 115;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $152 = __ZNK8JSObject13getNamePrefixEv($149);
    if (($152 | 0) == 0) {
      __label__ = 43;
      break;
    } else {
      var $ns_0 = $149;
      var $prefix_1 = $152;
      __label__ = 52;
      break;
    }
   case 43:
    var $155 = __ZNK8JSObject10getNameURIEv($149);
    var $156 = HEAP32[$147 >> 2];
    var $157 = __ZNK8JSObject13getNamePrefixEv($156);
    if (($157 | 0) == 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 44:
    var $prefix_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 46;
    break;
   case 45:
    var $166 = __ZL14GeneratePrefixP9JSContextP14JSLinearStringP10JSXMLArray($cx, $155, $103);
    if (($166 | 0) == 0) {
      var $_1 = 0;
      __label__ = 115;
      break;
    } else {
      var $prefix_0 = $166;
      __label__ = 46;
      break;
    }
   case 46:
    var $prefix_0;
    var $169 = __ZL15NewXMLNamespaceP9JSContextP14JSLinearStringS2_i($cx, $prefix_0, $155, 1);
    if (($169 | 0) == 0) {
      var $_1 = 0;
      __label__ = 115;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $_idx7_val = HEAP32[$prefix_0 >> 2];
    var $172 = __ZNK8JSString5emptyEv($_idx7_val);
    var $173 = $169;
    if ($172) {
      __label__ = 48;
      break;
    } else {
      var $_pre_phi = $173;
      __label__ = 50;
      break;
    }
   case 48:
    var $_idx_val = HEAP32[$82 >> 2];
    var $_idx1_val = HEAP32[$129 >> 2];
    var $175 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx_val, $_idx1_val, $173, 266);
    HEAP32[$i >> 2] = $175;
    if (($175 | 0) == -1) {
      var $_pre_phi = $173;
      __label__ = 50;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    __ZL14XMLArrayDeleteP9JSContextP10JSXMLArrayji($81, $175, 1);
    var $_pre_phi = $173;
    __label__ = 50;
    break;
   case 50:
    var $_pre_phi;
    var $178 = HEAP32[$110 >> 2];
    var $179 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $103, $178, $_pre_phi);
    if (($179 | 0) == 0) {
      var $_1 = 0;
      __label__ = 115;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $182 = HEAP32[$82 >> 2];
    var $183 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $81, $182, $_pre_phi);
    if (($183 | 0) == 0) {
      var $_1 = 0;
      __label__ = 115;
      break;
    } else {
      var $ns_0 = $169;
      var $prefix_1 = $prefix_0;
      __label__ = 52;
      break;
    }
   case 52:
    var $prefix_1;
    var $ns_0;
    var $186 = __ZN2js12StringBuffer6appendEt($1, 60);
    if ($186) {
      __label__ = 53;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 53:
    var $_idx6_val = HEAP32[$prefix_1 >> 2];
    var $188 = __ZNK8JSString5emptyEv($_idx6_val);
    if ($188) {
      __label__ = 56;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    var $191 = __ZN2js12StringBuffer6appendEP8JSString($1, $prefix_1 | 0);
    if ($191) {
      __label__ = 55;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 55:
    var $193 = __ZN2js12StringBuffer6appendEt($1, 58);
    if ($193) {
      __label__ = 56;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 56:
    var $195 = HEAP32[$147 >> 2];
    var $196 = __ZNK8JSObject17getQNameLocalNameEv($195);
    var $197 = $sb;
    var $198 = $196;
    var $199 = __ZN2js12StringBuffer6appendEP6JSAtom($197, $198);
    if ($199) {
      __label__ = 57;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 57:
    var $201 = $xml + 56 | 0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor3, $201);
    __label__ = 58;
    break;
   case 58:
    var $203 = __ZN16JSXMLArrayCursor7getNextEv($cursor3);
    if (($203 | 0) == 0) {
      __label__ = 72;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 59:
    var $206 = __ZN2js12StringBuffer6appendEt($1, 32);
    if ($206) {
      __label__ = 60;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 60:
    var $209 = $203 + 12 | 0;
    var $210 = HEAP32[$209 >> 2];
    var $211 = __ZL12GetNamespaceP9JSContextP8JSObjectPK10JSXMLArray($cx, $210, $103);
    if (($211 | 0) == 0) {
      __label__ = 71;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    var $214 = __ZNK8JSObject13getNamePrefixEv($211);
    if (($214 | 0) == 0) {
      __label__ = 62;
      break;
    } else {
      var $prefix_2 = $214;
      __label__ = 66;
      break;
    }
   case 62:
    var $217 = __ZNK8JSObject10getNameURIEv($211);
    var $218 = __ZL14GeneratePrefixP9JSContextP14JSLinearStringP10JSXMLArray($cx, $217, $103);
    if (($218 | 0) == 0) {
      __label__ = 71;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $221 = __ZNK8JSObject10getNameURIEv($211);
    var $222 = __ZL15NewXMLNamespaceP9JSContextP14JSLinearStringS2_i($cx, $218, $221, 1);
    if (($222 | 0) == 0) {
      __label__ = 71;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    var $225 = HEAP32[$110 >> 2];
    var $226 = $222;
    var $227 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $103, $225, $226);
    if (($227 | 0) == 0) {
      __label__ = 71;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 65:
    var $230 = HEAP32[$82 >> 2];
    var $231 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $81, $230, $226);
    if (($231 | 0) == 0) {
      __label__ = 71;
      break;
    } else {
      var $prefix_2 = $218;
      __label__ = 66;
      break;
    }
   case 66:
    var $prefix_2;
    var $_idx5_val = HEAP32[$prefix_2 >> 2];
    var $234 = __ZNK8JSString5emptyEv($_idx5_val);
    if ($234) {
      __label__ = 69;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 67:
    var $237 = __ZN2js12StringBuffer6appendEP8JSString($1, $prefix_2 | 0);
    if ($237) {
      __label__ = 68;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 68:
    var $239 = __ZN2js12StringBuffer6appendEt($1, 58);
    if ($239) {
      __label__ = 69;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 69:
    var $241 = HEAP32[$209 >> 2];
    var $242 = __ZNK8JSObject17getQNameLocalNameEv($241);
    var $243 = $242;
    var $244 = __ZN2js12StringBuffer6appendEP6JSAtom($197, $243);
    if ($244) {
      __label__ = 70;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 70:
    var $248 = HEAP32[$203 + 24 >> 2];
    var $249 = __ZL20AppendAttributeValueP9JSContextRN2js12StringBufferEP8JSString($cx, $sb, $248);
    if ($249) {
      __label__ = 58;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 71:
    __ZN16JSXMLArrayCursorD1Ev($cursor3);
    var $_1 = 0;
    __label__ = 115;
    break;
   case 72:
    __ZN16JSXMLArrayCursorD1Ev($cursor3);
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor5, $81);
    __label__ = 73;
    break;
   case 73:
    var $252 = __ZN16JSXMLArrayCursor7getNextEv($cursor5);
    var $253 = $252;
    if (($252 | 0) == 0) {
      __label__ = 83;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 74:
    var $256 = __ZN2js12StringBuffer6appendILj7EEEbRAT__Kc($sb, STRING_TABLE.__str464292);
    if ($256) {
      __label__ = 75;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 75:
    var $258 = __ZNK8JSObject13getNamePrefixEv($253);
    if (($258 | 0) == 0) {
      __label__ = 76;
      break;
    } else {
      var $prefix_3 = $258;
      __label__ = 78;
      break;
    }
   case 76:
    var $261 = __ZNK8JSObject10getNameURIEv($253);
    var $262 = __ZL14GeneratePrefixP9JSContextP14JSLinearStringP10JSXMLArray($cx, $261, $103);
    if (($262 | 0) == 0) {
      __label__ = 82;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 77:
    __ZN8JSObject13setNamePrefixEP14JSLinearString($253, $262);
    var $prefix_3 = $262;
    __label__ = 78;
    break;
   case 78:
    var $prefix_3;
    var $266 = $prefix_3 | 0;
    var $_idx4_val = HEAP32[$prefix_3 >> 2];
    var $267 = __ZNK8JSString5emptyEv($_idx4_val);
    if ($267) {
      __label__ = 81;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 79:
    var $269 = __ZN2js12StringBuffer6appendEt($1, 58);
    if ($269) {
      __label__ = 80;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 80:
    var $271 = __ZN2js12StringBuffer6appendEP8JSString($1, $266);
    if ($271) {
      __label__ = 81;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 81:
    var $273 = __ZNK8JSObject10getNameURIEv($253);
    var $274 = $273 | 0;
    var $275 = __ZL20AppendAttributeValueP9JSContextRN2js12StringBufferEP8JSString($cx, $sb, $274);
    if ($275) {
      __label__ = 73;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 82:
    __ZN16JSXMLArrayCursorD1Ev($cursor5);
    var $_1 = 0;
    __label__ = 115;
    break;
   case 83:
    __ZN16JSXMLArrayCursorD1Ev($cursor5);
    var $277 = $xml + 24 | 0;
    var $278 = $277 | 0;
    var $279 = HEAPU32[$278 >> 2];
    if (($279 | 0) == 0) {
      __label__ = 84;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 84:
    var $282 = __ZN2js12StringBuffer6appendILj3EEEbRAT__Kc($1, STRING_TABLE.__str474293);
    if ($282) {
      __label__ = 111;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 85:
    var $284 = __ZN2js12StringBuffer6appendEt($1, 62);
    if ($284) {
      __label__ = 86;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 86:
    if ($279 >>> 0 > 1) {
      var $300 = 0;
      __label__ = 90;
      break;
    } else {
      __label__ = 87;
      break;
    }
   case 87:
    if ((HEAP32[$278 >> 2] | 0) == 0) {
      var $_not22 = 1;
      __label__ = 93;
      break;
    } else {
      __label__ = 88;
      break;
    }
   case 88:
    var $293 = HEAP32[HEAP32[$xml + 32 >> 2] >> 2];
    if (($293 | 0) == 0) {
      var $_not22 = 1;
      __label__ = 93;
      break;
    } else {
      __label__ = 89;
      break;
    }
   case 89:
    var $300 = (HEAP32[$293 + 16 >> 2] | 0) == 4;
    __label__ = 90;
    break;
   case 90:
    var $300;
    if ($7 | $300) {
      var $_not22 = $300;
      __label__ = 93;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 91:
    var $302 = __ZL19GetUint32XMLSettingP9JSContextPKcPj($cx, $i);
    if (($302 | 0) == 0) {
      var $_1 = 0;
      __label__ = 115;
      break;
    } else {
      __label__ = 92;
      break;
    }
   case 92:
    var $nextIndentLevel_0 = HEAP32[$i >> 2] + $indentLevel | 0;
    var $_not21 = $300;
    __label__ = 94;
    break;
   case 93:
    var $_not22;
    var $nextIndentLevel_0 = $indentLevel & -2147483648;
    var $_not21 = $_not22;
    __label__ = 94;
    break;
   case 94:
    var $_not21;
    var $nextIndentLevel_0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor8, $277);
    var $brmerge7 = $7 | $_not21;
    __label__ = 95;
    break;
   case 95:
    var $310 = __ZN16JSXMLArrayCursor7getNextEv($cursor8);
    var $311 = $310;
    if (($310 | 0) == 0) {
      __label__ = 101;
      break;
    } else {
      __label__ = 96;
      break;
    }
   case 96:
    if ($brmerge7) {
      __label__ = 98;
      break;
    } else {
      __label__ = 97;
      break;
    }
   case 97:
    var $315 = __ZN2js12StringBuffer6appendEt($1, 10);
    if ($315) {
      __label__ = 98;
      break;
    } else {
      __label__ = 100;
      break;
    }
   case 98:
    var $317 = __ZL14XMLToXMLStringP9JSContextP5JSXMLPK10JSXMLArrayj($cx, $311, $103, $nextIndentLevel_0);
    if (($317 | 0) == 0) {
      __label__ = 100;
      break;
    } else {
      __label__ = 99;
      break;
    }
   case 99:
    var $320 = __ZN2js12StringBuffer6appendEP8JSString($1, $317);
    if ($320) {
      __label__ = 95;
      break;
    } else {
      __label__ = 100;
      break;
    }
   case 100:
    __ZN16JSXMLArrayCursorD1Ev($cursor8);
    var $_1 = 0;
    __label__ = 115;
    break;
   case 101:
    __ZN16JSXMLArrayCursorD1Ev($cursor8);
    if ($brmerge7) {
      __label__ = 104;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 102:
    var $323 = __ZN2js12StringBuffer6appendEt($1, 10);
    if ($323) {
      __label__ = 103;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 103:
    var $325 = $indentLevel & 2147483647;
    var $326 = $sb;
    var $327 = __ZN2js12StringBuffer7appendNEtj($326, $325);
    if ($327) {
      __label__ = 104;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 104:
    var $329 = __ZN2js12StringBuffer6appendILj3EEEbRAT__Kc($1, STRING_TABLE.__str484294);
    if ($329) {
      __label__ = 105;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 105:
    var $331 = __ZNK8JSObject13getNamePrefixEv($ns_0);
    if (($331 | 0) == 0) {
      __label__ = 109;
      break;
    } else {
      __label__ = 106;
      break;
    }
   case 106:
    var $_idx3_val = HEAP32[$331 >> 2];
    var $334 = __ZNK8JSString5emptyEv($_idx3_val);
    if ($334) {
      __label__ = 109;
      break;
    } else {
      __label__ = 107;
      break;
    }
   case 107:
    var $336 = $331 | 0;
    var $337 = __ZN2js12StringBuffer6appendEP8JSString($1, $336);
    if ($337) {
      __label__ = 108;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 108:
    var $339 = __ZN2js12StringBuffer6appendEt($1, 58);
    if ($339) {
      __label__ = 109;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 109:
    var $341 = HEAP32[$147 >> 2];
    var $342 = __ZNK8JSObject17getQNameLocalNameEv($341);
    var $343 = $342;
    var $344 = __ZN2js12StringBuffer6appendEP6JSAtom($197, $343);
    if ($344) {
      __label__ = 110;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 110:
    var $346 = __ZN2js12StringBuffer6appendEt($1, 62);
    if ($346) {
      __label__ = 111;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 111:
    var $348 = __ZN2js12StringBuffer12finishStringEv($197);
    var $_1 = $348 | 0;
    __label__ = 115;
    break;
   case 112:
    HEAP32[$i >> 2] = $storemerge;
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_1 = 0;
    __label__ = 115;
    break;
   case 113:
    HEAP32[$i >> 2] = $storemerge;
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_1 = 0;
    __label__ = 115;
    break;
   case 114:
    HEAP32[$i >> 2] = $storemerge;
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_1 = 0;
    __label__ = 115;
    break;
   case 115:
    var $_1;
    __ZN2js18AutoNamespaceArrayD1Ev($ancdecls);
    __ZN2js18AutoNamespaceArrayD1Ev($decls);
    __ZN2js18AutoNamespaceArrayD1Ev($empty);
    __ZN2js12StringBufferD1Ev($1);
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14XMLToXMLStringP9JSContextP5JSXMLPK10JSXMLArrayj["X"] = 1;

function __ZL10IsDeclaredPK8JSObject($obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $v = __stackBase__;
  __ZNK8JSObject20getNamespaceDeclaredEv($v, $obj);
  var $v_idx = $v | 0;
  var $v_idx_val$0 = HEAP32[$v_idx >> 2];
  var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
  var $$emscripten$temp$0 = _JSVAL_TRUE | 0;
  var $JSVAL_TRUE_idx_val$0 = HEAP32[$$emscripten$temp$0 >> 2];
  var $JSVAL_TRUE_idx_val$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
  var $1 = __ZNK2JS5ValueeqERKS0_($v_idx_val$0, $v_idx_val$1, $JSVAL_TRUE_idx_val$0, $JSVAL_TRUE_idx_val$1);
  var $2 = $1 & 1;
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL12GetNamespaceP9JSContextP8JSObjectPK10JSXMLArray($cx, $qn, $inScopeNSes) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $argv = __stackBase__;
    var $bytes = __stackBase__ + 16;
    var $1 = __stackBase__ + 20;
    var $2 = __stackBase__ + 28;
    var $3 = __stackBase__ + 36;
    var $4 = __ZNK8JSObject10getNameURIEv($qn);
    var $5 = __ZNK8JSObject13getNamePrefixEv($qn);
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    __ZN16JSAutoByteStringC1Ev($bytes);
    if (($5 | 0) == 0) {
      var $15 = STRING_TABLE.__str493818 | 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $5 | 0;
    __ZN2JSL11StringValueEP8JSString4311($1, $10);
    var $11 = $cx;
    var $12 = $bytes;
    var $_idx1 = $1 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $13 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($11, $_idx1_val$0, $_idx1_val$1, $12);
    if (($13 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $15 = $13;
      __label__ = 4;
      break;
    }
   case 4:
    var $15;
    var $16 = $cx;
    _JS_ReportErrorNumber($16, 4, 177, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $15, tempInt));
    __label__ = 5;
    break;
   case 5:
    var $bytes_idx_val = HEAP32[$bytes >> 2];
    __ZN16JSAutoByteStringD1Ev($bytes_idx_val);
    var $_0 = 0;
    __label__ = 22;
    break;
   case 6:
    if (($inScopeNSes | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = $argv | 0;
    if (($5 | 0) == 0) {
      var $53 = $20;
      __label__ = 19;
      break;
    } else {
      var $50 = $20;
      __label__ = 18;
      break;
    }
   case 8:
    var $23 = HEAPU32[$inScopeNSes >> 2];
    var $24 = $inScopeNSes + 8 | 0;
    var $25 = ($5 | 0) == 0;
    var $i_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $i_0;
    if ($i_0 >>> 0 < $23 >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 10:
    var $31 = HEAP32[HEAP32[$24 >> 2] + ($i_0 << 2) >> 2];
    var $32 = $31;
    if (($31 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $35 = __ZNK8JSObject10getNameURIEv($32);
    var $36 = __ZN2js12EqualStringsEP14JSLinearStringS1_($35, $4);
    if ($36) {
      __label__ = 12;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 12:
    var $38 = __ZNK8JSObject13getNamePrefixEv($32);
    if (($38 | 0) == ($5 | 0)) {
      var $_0 = $32;
      __label__ = 22;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $41 = ($38 | 0) != 0;
    if ($25 | $41 ^ 1) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $43 = __ZN2js12EqualStringsEP14JSLinearStringS1_($38, $5);
    if ($43) {
      var $_0 = $32;
      __label__ = 22;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $45 = $41 ? $38 : $5;
    var $_idx_val = HEAP32[$45 >> 2];
    var $46 = __ZNK8JSString5emptyEv($_idx_val);
    if ($46) {
      var $_0 = $32;
      __label__ = 22;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 9;
    break;
   case 17:
    var $48 = $argv | 0;
    if ($25) {
      var $53 = $48;
      __label__ = 19;
      break;
    } else {
      var $50 = $48;
      __label__ = 18;
      break;
    }
   case 18:
    var $50;
    var $51 = $5 | 0;
    _STRING_TO_JSVAL4322($2, $51);
    var $_phi_trans_insert = $2 | 0;
    var $st$4$0 = $_phi_trans_insert | 0;
    var $st$4$1 = $_phi_trans_insert + 4 | 0;
    var $58$1 = HEAP32[$st$4$1 >> 2];
    var $58$0 = HEAP32[$st$4$0 >> 2];
    var $57 = $50;
    __label__ = 20;
    break;
   case 19:
    var $53;
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $54$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $54$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $55 = $2 | 0;
    HEAP32[$55 >> 2] = $54$0;
    HEAP32[$55 + 4 >> 2] = $54$1;
    var $58$1 = $54$1;
    var $58$0 = $54$0;
    var $57 = $53;
    __label__ = 20;
    break;
   case 20:
    var $57;
    var $58$0;
    var $58$1;
    var $59 = $argv | 0;
    var $st$4$0 = $59 | 0;
    HEAP32[$st$4$0 >> 2] = $58$0;
    var $st$4$1 = $59 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $58$1;
    var $60 = $4 | 0;
    _STRING_TO_JSVAL4322($3, $60);
    var $61 = $3 | 0;
    var $62$0 = HEAP32[$61 >> 2];
    var $62$1 = HEAP32[$61 + 4 >> 2];
    var $63 = $argv + 8 | 0;
    HEAP32[$63 >> 2] = $62$0;
    HEAP32[$63 + 4 >> 2] = $62$1;
    var $64 = $cx;
    var $65 = __Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE($64, __ZN2js14NamespaceClassE, 0, 2, $57);
    if (($65 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $_0 = $65;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12GetNamespaceP9JSContextP8JSObjectPK10JSXMLArray["X"] = 1;

function __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE4414($sid_0_0_val) {
  return $sid_0_0_val;
}

function __ZL14JSID_FROM_BITSj4418($bits) {
  return $bits;
}

function _JSVAL_IS_PRIMITIVE_IMPL4409($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 < 4294967175 & 1;
}

function _JSVAL_IS_BOOLEAN_IMPL4410($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -125) & 1;
}

function _JSVAL_IS_STRING_IMPL4412($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -123) & 1;
}

function _MAGIC_JSVAL_TO_OBJECT_OR_NULL_IMPL($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _STRING_TO_JSVAL_IMPL4413($agg_result, $str) {
  HEAP32[$agg_result + 4 >> 2] = -123;
  HEAP32[$agg_result >> 2] = $str;
  return;
}

function __ZN2js9SpecialIdC2Ej($this) {
  HEAP32[$this >> 2] = 6;
  return;
}

function __ZL13IMPL_TO_JSVAL12jsval_layout4416($agg_result, $l_0$0, $l_0$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $l_0$0;
  HEAP32[$1 + 4 >> 2] = $l_0$1;
  return;
}

function _BOOLEAN_TO_JSVAL_IMPL4417($agg_result, $b) {
  HEAP32[$agg_result + 4 >> 2] = -125;
  HEAP32[$agg_result >> 2] = $b;
  return;
}

function _INT32_TO_JSVAL_IMPL4422($agg_result, $i) {
  HEAP32[$agg_result + 4 >> 2] = -127;
  HEAP32[$agg_result >> 2] = $i;
  return;
}

function __ZL14GeneratePrefixP9JSContextP14JSLinearStringP10JSXMLArray($cx, $uri, $decls) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $decls | 0;
    var $2 = HEAPU32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $cx;
    var $6 = __Z17js_NewStringCopyZP9JSContextPKc($5, STRING_TABLE.__str494295 | 0);
    var $_0 = $6 | 0;
    __label__ = 37;
    break;
   case 3:
    var $uri_idx_val = HEAP32[$uri + 4 >> 2];
    var $9 = __ZNK14JSLinearString5charsEv($uri_idx_val);
    var $10 = $uri | 0;
    var $_idx1_val = HEAP32[$uri >> 2];
    var $11 = __ZNK8JSString6lengthEv($_idx1_val);
    var $end_0_ph = $9 + ($11 << 1) | 0;
    __label__ = 4;
    break;
   case 4:
    var $end_0_ph;
    var $cp_0 = $end_0_ph;
    __label__ = 5;
    break;
   case 5:
    var $cp_0;
    var $14 = $cp_0 - 2 | 0;
    if ($14 >>> 0 > $9 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $17 = HEAP16[$14 >> 1];
    if ($17 << 16 >> 16 == 46 || $17 << 16 >> 16 == 47 || $17 << 16 >> 16 == 58) {
      __label__ = 7;
      break;
    } else {
      var $cp_0 = $14;
      __label__ = 5;
      break;
    }
   case 7:
    var $19 = $end_0_ph;
    var $22 = $19 - $cp_0 >> 1;
    var $23 = __ZL9IsXMLNamePKtj($cp_0, $22);
    if (($23 | 0) == 0) {
      var $end_0_ph = $14;
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($22 >>> 0 > 2) {
      __label__ = 9;
      break;
    } else {
      var $cp_1 = $cp_0;
      var $_pre_phi = $19;
      __label__ = 11;
      break;
    }
   case 9:
    var $28 = __ZL12IS_XML_CHARSPKt($cp_0);
    if ($28) {
      var $end_0_ph = $14;
      __label__ = 4;
      break;
    } else {
      var $cp_1 = $cp_0;
      var $_pre_phi = $19;
      __label__ = 11;
      break;
    }
   case 10:
    var $cp_1 = $14;
    var $_pre_phi = $end_0_ph;
    __label__ = 11;
    break;
   case 11:
    var $_pre_phi;
    var $cp_1;
    var $29 = $cp_1;
    var $30 = $_pre_phi - $29 | 0;
    var $31 = $30 >> 1;
    if ($31 >>> 0 > 2) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $34 = __ZL12IS_XML_CHARSPKt($cp_1);
    if ($34) {
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $36 = __ZL9IsXMLNamePKtj($cp_1, $31);
    if (($36 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $bp_1_ph = $cp_1;
    var $newlength_1_ph = $31;
    var $_pre_phi5 = $31 + 2 | 0;
    var $_pre_phi7 = $cx;
    __label__ = 18;
    break;
   case 15:
    var $39 = $2 >>> 0;
    var $40 = _log10($39);
    var $41 = $40 >= 0 ? Math.floor($40) : Math.ceil($40);
    var $42 = $31 + 2 | 0;
    var $43 = $42 + $41 | 0;
    var $45 = ($43 << 1) + 2 | 0;
    var $46 = $cx;
    var $47 = __ZN9JSContext7malloc_Ej($46, $45);
    var $48 = $47;
    if (($47 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    HEAP16[$48 + ($43 << 1) >> 1] = 0;
    if (($43 | 0) == 0) {
      var $bp_1_ph = $48;
      var $newlength_1_ph = 0;
      var $_pre_phi5 = $42;
      var $_pre_phi7 = $46;
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $54 = $31 + ($41 + 2) | 0;
    var $i_07 = 0;
    __label__ = 19;
    break;
   case 18:
    var $_pre_phi7;
    var $_pre_phi5;
    var $newlength_1_ph;
    var $bp_1_ph;
    var $55 = $decls + 8 | 0;
    var $56 = $cp_1;
    var $bp_1 = $bp_1_ph;
    var $newlength_1 = $newlength_1_ph;
    var $serial_0 = 1;
    __label__ = 20;
    break;
   case 19:
    var $i_07;
    HEAP16[$48 + ($i_07 << 1) >> 1] = 97;
    var $59 = $i_07 + 1 | 0;
    if (($59 | 0) == ($54 | 0)) {
      var $bp_1_ph = $48;
      var $newlength_1_ph = $43;
      var $_pre_phi5 = $42;
      var $_pre_phi7 = $46;
      __label__ = 18;
      break;
    } else {
      var $i_07 = $59;
      __label__ = 19;
      break;
    }
   case 20:
    var $serial_0;
    var $newlength_1;
    var $bp_1;
    var $61 = HEAPU32[$1 >> 2];
    var $62 = $bp_1;
    var $63 = $newlength_1 << 1;
    var $i_1 = 0;
    __label__ = 21;
    break;
   case 21:
    var $i_1;
    if ($i_1 >>> 0 < $61 >>> 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 22:
    var $69 = HEAP32[HEAP32[$55 >> 2] + ($i_1 << 2) >> 2];
    if (($69 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $72 = $69;
    var $73 = __ZNK8JSObject13getNamePrefixEv($72);
    if (($73 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $_idx_val = HEAP32[$73 >> 2];
    var $76 = __ZNK8JSString6lengthEv($_idx_val);
    if (($76 | 0) == ($newlength_1 | 0)) {
      __label__ = 25;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 25:
    var $_idx2_val = HEAP32[$73 + 4 >> 2];
    var $79 = __ZNK14JSLinearString5charsEv($_idx2_val);
    var $80 = $79;
    var $81 = _memcmp($80, $62, $63);
    if (($81 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 26:
    if (($bp_1 | 0) == ($cp_1 | 0)) {
      __label__ = 27;
      break;
    } else {
      var $bp_2 = $bp_1;
      var $newlength_2 = $newlength_1;
      __label__ = 29;
      break;
    }
   case 27:
    var $86 = $61 >>> 0;
    var $87 = _log10($86);
    var $88 = $87 >= 0 ? Math.floor($87) : Math.ceil($87);
    var $89 = $_pre_phi5 + $88 | 0;
    var $91 = ($89 << 1) + 2 | 0;
    var $92 = __ZN9JSContext7malloc_Ej($_pre_phi7, $91);
    if (($92 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $95 = $92;
    _memcpy($92, $56, $30, 1);
    var $bp_2 = $95;
    var $newlength_2 = $89;
    __label__ = 29;
    break;
   case 29:
    var $newlength_2;
    var $bp_2;
    var $98 = _log10($serial_0 >>> 0);
    var $99 = $98 >= 0 ? Math.floor($98) : Math.ceil($98);
    var $100 = $bp_2 + ($_pre_phi5 + $99 << 1) | 0;
    HEAP16[$100 >> 1] = 0;
    if (($serial_0 | 0) == 0) {
      var $dp_0_lcssa = $100;
      __label__ = 31;
      break;
    } else {
      var $m_03 = $serial_0;
      var $dp_04 = $100;
      __label__ = 30;
      break;
    }
   case 30:
    var $dp_04;
    var $m_03;
    var $105 = $dp_04 - 2 | 0;
    HEAP16[$105 >> 1] = (($m_03 >>> 0) % 10 | 48) & 65535;
    var $106 = Math.floor(($m_03 >>> 0) / 10);
    if ($m_03 >>> 0 < 10) {
      var $dp_0_lcssa = $105;
      __label__ = 31;
      break;
    } else {
      var $m_03 = $106;
      var $dp_04 = $105;
      __label__ = 30;
      break;
    }
   case 31:
    var $dp_0_lcssa;
    HEAP16[$dp_0_lcssa - 2 >> 1] = 45;
    var $bp_1 = $bp_2;
    var $newlength_1 = $newlength_2;
    var $serial_0 = $serial_0 + 1 | 0;
    __label__ = 20;
    break;
   case 32:
    var $i_1 = $i_1 + 1 | 0;
    __label__ = 21;
    break;
   case 33:
    if (($bp_1 | 0) == ($cp_1 | 0)) {
      __label__ = 34;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 34:
    var $115 = $29 - $9 >> 1;
    var $116 = $cx;
    var $117 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($116, $10, $115, $31);
    var $_0 = $117;
    __label__ = 37;
    break;
   case 35:
    var $119 = $cx;
    var $120 = __Z12js_NewStringP9JSContextPtj($119, $bp_1, $newlength_1);
    var $121 = $120 | 0;
    if (($120 | 0) == 0) {
      __label__ = 36;
      break;
    } else {
      var $_0 = $121;
      __label__ = 37;
      break;
    }
   case 36:
    __ZN9JSContext5free_EPv($62);
    var $_0 = $121;
    __label__ = 37;
    break;
   case 37:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14GeneratePrefixP9JSContextP14JSLinearStringP10JSXMLArray["X"] = 1;

function __ZL15namespace_matchPKvS0_($a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $a;
    var $2 = $b;
    var $3 = __ZNK8JSObject13getNamePrefixEv($2);
    if (($3 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK8JSObject13getNamePrefixEv($1);
    if (($6 | 0) == 0) {
      var $11 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZN2js12EqualStringsEP14JSLinearStringS1_($6, $3);
    var $11 = $9;
    __label__ = 4;
    break;
   case 4:
    var $11;
    var $_0 = $11 & 1;
    __label__ = 6;
    break;
   case 5:
    var $14 = __ZNK8JSObject10getNameURIEv($1);
    var $15 = __ZNK8JSObject10getNameURIEv($2);
    var $16 = __ZN2js12EqualStringsEP14JSLinearStringS1_($14, $15);
    var $_0 = $16 & 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20AppendAttributeValueP9JSContextRN2js12StringBufferEP8JSString($cx, $sb, $valstr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $sb;
    var $2 = __ZN2js12StringBuffer6appendEt($1, 61);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __Z23js_EscapeAttributeValueP9JSContextP8JSStringi($cx, $valstr, 1);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $4 | 0;
    var $8 = __ZN2js12StringBuffer6appendEP8JSString($1, $7);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19GetUint32XMLSettingP9JSContextPKcPj($cx, $uip) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZL13GetXMLSettingP9JSContextPKcPN2JS5ValueE($cx, STRING_TABLE.__ZL19js_prettyIndent_str | 0, $v);
    if (($1 | 0) == 0) {
      var $10 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $v | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = $cx;
    var $7 = _JS_ValueToECMAUint32($6, $5$0, $5$1, $uip);
    var $10 = ($7 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $10;
    STACKTOP = __stackBase__;
    return $10 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject20getNamespaceDeclaredEv($agg_result, $this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject7getSlotEj($1, 2);
  var $3 = $2 | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  var $5 = $agg_result | 0;
  HEAP32[$5 >> 2] = $4$0;
  HEAP32[$5 + 4 >> 2] = $4$1;
  return;
}

function __ZL19NewXMLAttributeNameP9JSContextP14JSLinearStringS2_P6JSAtom($cx, $uri, $prefix, $localName) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL22GetGlobalForScopeChainEP9JSContext4366($cx);
    var $2 = $1 | 0;
    var $3 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_4355($cx, __ZN2js18AttributeNameClassE, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZL12InitXMLQNameP9JSContextP8JSObjectP14JSLinearStringS4_P6JSAtom($cx, $3, $uri, $prefix, $localName);
    var $_ = $6 ? $3 : 0;
    var $_0 = $_;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9SpecialIdC1Ej($this) {
  __ZN2js9SpecialIdC2Ej($this);
  return;
}

function _BOOLEAN_TO_JSVAL4415($agg_result, $b) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BOOLEAN_TO_JSVAL_IMPL4417($1, $b);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout4416($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2jsL14IsConstructingEPKN2JS5ValueE4419($vp) {
  var $_idx = $vp + 8 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $1 = __ZNK2JS5Value7isMagicEv($_idx_val$0, $_idx_val$1);
  return $1;
}

function _INT_TO_JSVAL4421($agg_result, $i) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _INT32_TO_JSVAL_IMPL4422($1, $i);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout4416($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZL8DeepCopyP9JSContextP5JSXMLP8JSObjectj($cx, $xml, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL13DeepCopyInLRSP9JSContextP5JSXMLj($cx, $xml);
    if (($1 | 0) == 0) {
      var $copy_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($obj | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = $1;
    var $7 = $obj;
    __ZN8JSObject10setPrivateEPv($7, $6);
    HEAP32[$1 >> 2] = $obj;
    var $copy_0 = $1;
    __label__ = 6;
    break;
   case 4:
    var $10 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $1);
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $copy_0 = $1;
      __label__ = 6;
      break;
    }
   case 5:
    var $copy_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $copy_0;
    return $copy_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13DeepCopyInLRSP9JSContextP5JSXMLj($cx, $xml) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx;
    __Z21js_ReportOverRecursedP9JSContext($6);
    var $_0 = 0;
    __label__ = 24;
    break;
   case 3:
    var $8 = $xml + 16 | 0;
    var $9 = HEAP32[$8 >> 2];
    var $10 = __Z9js_NewXMLP9JSContext10JSXMLClass($cx, $9);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = HEAP32[$xml + 12 >> 2];
    if (($14 | 0) == 0) {
      var $qn_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = __ZNK8JSObject10getNameURIEv($14);
    var $18 = __ZNK8JSObject13getNamePrefixEv($14);
    var $19 = __ZNK8JSObject17getQNameLocalNameEv($14);
    var $20 = __ZL11NewXMLQNameP9JSContextP14JSLinearStringS2_P6JSAtom($cx, $17, $18, $19);
    if (($20 | 0) == 0) {
      var $ok_0 = 0;
      __label__ = 23;
      break;
    } else {
      var $qn_0 = $20;
      __label__ = 6;
      break;
    }
   case 6:
    var $qn_0;
    var $23 = $10 + 12 | 0;
    HEAP32[$23 >> 2] = $qn_0;
    var $25 = HEAP32[$xml + 20 >> 2];
    var $26 = $10 + 20 | 0;
    HEAP32[$26 >> 2] = $25;
    if (HEAPU32[$8 >> 2] >>> 0 > 1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $33 = $10 + 24 | 0;
    var $_c2 = HEAP32[$xml + 24 >> 2];
    HEAP32[$33 >> 2] = $_c2;
    var $ok_0 = 1;
    __label__ = 23;
    break;
   case 8:
    var $35 = $xml + 24 | 0;
    var $36 = $10 + 24 | 0;
    var $37 = __ZL16DeepCopySetInLRSP9JSContextP10JSXMLArrayS2_P5JSXMLj($cx, $35, $36, $10);
    if (($37 | 0) == 0) {
      var $ok_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ((HEAP32[$8 >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $46 = $10 + 40 | 0;
    var $_c = HEAP32[$xml + 40 >> 2];
    HEAP32[$46 >> 2] = $_c;
    var $50 = $10 + 44 | 0;
    var $_c1 = HEAP32[$xml + 44 >> 2];
    HEAP32[$50 >> 2] = $_c1;
    var $ok_0 = $37;
    __label__ = 23;
    break;
   case 11:
    var $52 = $xml + 40 | 0;
    var $53 = HEAPU32[$52 >> 2];
    var $54 = $10 + 40 | 0;
    var $55 = __ZN10JSXMLArray11setCapacityEP9JSContextj($54, $cx, $53);
    var $56 = $55 & 1;
    if ($55) {
      __label__ = 12;
      break;
    } else {
      var $ok_0 = $56;
      __label__ = 23;
      break;
    }
   case 12:
    var $57 = $xml + 48 | 0;
    var $58 = $54 | 0;
    var $59 = $10 + 48 | 0;
    var $i_0 = 0;
    __label__ = 13;
    break;
   case 13:
    var $i_0;
    if ($i_0 >>> 0 < $53 >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 14:
    if ($i_0 >>> 0 < HEAPU32[$52 >> 2] >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 15:
    var $68 = HEAP32[HEAP32[$57 >> 2] + ($i_0 << 2) >> 2];
    var $69 = $68;
    if (($68 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $72 = __ZNK8JSObject13getNamePrefixEv($69);
    var $73 = __ZNK8JSObject10getNameURIEv($69);
    var $74 = __ZL10IsDeclaredPK8JSObject($69);
    var $75 = __ZL15NewXMLNamespaceP9JSContextP14JSLinearStringS2_i($cx, $72, $73, $74);
    if (($75 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    HEAP32[$58 >> 2] = $i_0;
    var $ok_0 = 0;
    __label__ = 23;
    break;
   case 18:
    if (HEAPU32[$58 >> 2] >>> 0 > $i_0 >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    HEAP32[$58 >> 2] = $i_0 + 1 | 0;
    __label__ = 20;
    break;
   case 20:
    var $84 = $75;
    var $86 = HEAP32[$59 >> 2] + ($i_0 << 2) | 0;
    HEAP32[$86 >> 2] = $84;
    __label__ = 21;
    break;
   case 21:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 13;
    break;
   case 22:
    var $89 = $xml + 56 | 0;
    var $90 = $10 + 56 | 0;
    var $91 = __ZL16DeepCopySetInLRSP9JSContextP10JSXMLArrayS2_P5JSXMLj($cx, $89, $90, $10);
    var $ok_0 = $91;
    __label__ = 23;
    break;
   case 23:
    var $ok_0;
    var $_ = ($ok_0 | 0) == 0 ? 0 : $10;
    var $_0 = $_;
    __label__ = 24;
    break;
   case 24:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13DeepCopyInLRSP9JSContextP5JSXMLj["X"] = 1;

function __ZL16DeepCopySetInLRSP9JSContextP10JSXMLArrayS2_P5JSXMLj($cx, $from, $to, $parent) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cursor = __stackBase__;
    var $2 = HEAPU32[$from >> 2];
    var $3 = __ZN10JSXMLArray11setCapacityEP9JSContextj($to, $cx, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 13;
      break;
    }
   case 2:
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor, $from);
    var $5 = $to | 0;
    var $6 = $to + 8 | 0;
    var $7 = $parent + 16 | 0;
    var $j_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $j_0;
    var $8 = __ZN16JSXMLArrayCursor7getNextEv($cursor);
    if (($8 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $8;
    var $12 = __ZL13DeepCopyInLRSP9JSContextP5JSXMLj($cx, $11);
    if (($12 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    HEAP32[$5 >> 2] = $j_0;
    var $_0 = 0;
    __label__ = 12;
    break;
   case 6:
    var $_pre = $j_0 + 1 | 0;
    if (HEAPU32[$5 >> 2] >>> 0 > $j_0 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$5 >> 2] = $_pre;
    __label__ = 8;
    break;
   case 8:
    var $21 = HEAP32[$6 >> 2] + ($j_0 << 2) | 0;
    HEAP32[$21 >> 2] = $12;
    if ((HEAP32[$7 >> 2] | 0) == 0) {
      var $j_0 = $_pre;
      __label__ = 3;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    HEAP32[$12 + 8 >> 2] = $parent;
    var $j_0 = $_pre;
    __label__ = 3;
    break;
   case 10:
    if ($j_0 >>> 0 < $2 >>> 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    __ZN10JSXMLArray4trimEv($to);
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_1 = $_0;
    __label__ = 13;
    break;
   case 13:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL42IsConstructing_PossiblyWithGivenThisObjectEPKN2JS5ValueEPP8JSObject($vp, $ctorThis) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx = $vp + 8 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $1 = __ZNK2JS5Value7isMagicEv($_idx_val$0, $_idx_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value27getMagicObjectOrNullPayloadEv($_idx_val$0, $_idx_val$1);
    HEAP32[$ctorThis >> 2] = $3;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11QNameHelperP9JSContextP8JSObjectiPN2JS5ValueES5_($cx, $obj, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nsval = __stackBase__;
    var $name = __stackBase__ + 8;
    var $1 = __stackBase__ + 12;
    var $2 = __stackBase__ + 20;
    var $3 = __stackBase__ + 28;
    if (($argc | 0) < 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $isQName_0 = 0;
    var $nameval_0_0_0$1 = HEAP32[$st$1$1 >> 2];
    var $nameval_0_0_0$0 = HEAP32[$st$1$0 >> 2];
    __label__ = 6;
    break;
   case 3:
    var $10 = $argv + ((($argc | 0) > 1 & 1) << 3) | 0;
    var $st$3$0 = $10 | 0;
    var $11$0 = HEAPU32[$st$3$0 >> 2];
    var $st$3$1 = $10 + 4 | 0;
    var $11$1 = HEAPU32[$st$3$1 >> 2];
    var $12 = _JSVAL_IS_PRIMITIVE4303($11$0, $11$1);
    if (($12 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $20 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = _JSVAL_TO_OBJECT4304($11$0, $11$1);
    var $_idx1_val = HEAP32[$15 + 4 >> 2];
    var $17 = __ZNK8JSObject8getClassEv($_idx1_val);
    var $20 = ($17 | 0) == (__ZN2js10QNameClassE | 0);
    __label__ = 5;
    break;
   case 5:
    var $20;
    var $isQName_0 = $20 & 1;
    var $nameval_0_0_0$1 = $11$1;
    var $nameval_0_0_0$0 = $11$0;
    __label__ = 6;
    break;
   case 6:
    var $nameval_0_0_0$0;
    var $nameval_0_0_0$1;
    var $isQName_0;
    if (($obj | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_01 = $obj;
    var $_pre_phi = ($isQName_0 | 0) == 0;
    __label__ = 11;
    break;
   case 8:
    var $26 = ($isQName_0 | 0) == 0;
    if (($argc | 0) != 1 | $26) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $28 = $rval | 0;
    var $st$1$0 = $28 | 0;
    HEAP32[$st$1$0 >> 2] = $nameval_0_0_0$0;
    var $st$1$1 = $28 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $nameval_0_0_0$1;
    var $_0 = 1;
    __label__ = 41;
    break;
   case 10:
    var $30 = __ZL26NewBuiltinClassInstanceXMLP9JSContextPN2js5ClassE($cx, __ZN2js10QNameClassE);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 41;
      break;
    } else {
      var $_01 = $30;
      var $_pre_phi = $26;
      __label__ = 11;
      break;
    }
   case 11:
    var $_pre_phi;
    var $_01;
    _OBJECT_TO_JSVAL4318($1, $_01);
    var $33 = $1 | 0;
    var $34$0 = HEAP32[$33 >> 2];
    var $34$1 = HEAP32[$33 + 4 >> 2];
    var $35 = $rval | 0;
    HEAP32[$35 >> 2] = $34$0;
    HEAP32[$35 + 4 >> 2] = $34$1;
    if ($_pre_phi) {
      var $nameval_0_0_1$1 = $nameval_0_0_0$1;
      var $nameval_0_0_1$0 = $nameval_0_0_0$0;
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $37 = _JSVAL_TO_OBJECT4304($nameval_0_0_0$0, $nameval_0_0_0$1);
    if (($argc | 0) == 1) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $40 = __ZNK8JSObject10getNameURIEv($37);
    var $41 = __ZNK8JSObject13getNamePrefixEv($37);
    var $42 = __ZNK8JSObject17getQNameLocalNameEv($37);
    HEAP32[$name >> 2] = $42;
    var $prefix_0 = $41;
    var $uri_0 = $40;
    __label__ = 40;
    break;
   case 14:
    __ZNK8JSObject20getQNameLocalNameValEv($2, $37);
    var $44 = $2 | 0;
    var $nameval_0_0_1$1 = HEAP32[$44 + 4 >> 2];
    var $nameval_0_0_1$0 = HEAP32[$44 >> 2];
    __label__ = 15;
    break;
   case 15:
    var $nameval_0_0_1$0;
    var $nameval_0_0_1$1;
    if (($argc | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $51 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2];
    HEAP32[$name >> 2] = $51;
    __label__ = 23;
    break;
   case 17:
    if (($argc | 0) < 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $58 = HEAP32[HEAP32[$cx + 52 >> 2] + 209984 >> 2] | 0;
    HEAP32[$name >> 2] = $58;
    __label__ = 23;
    break;
   case 19:
    var $60 = $cx;
    var $61 = $name;
    var $62 = __Z14js_ValueToAtomP9JSContextRKN2JS5ValueEPP6JSAtom($60, $nameval_0_0_1$0, $nameval_0_0_1$1, $61);
    if ($62) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 41;
      break;
    }
   case 20:
    if (($argc | 0) > 1) {
      __label__ = 21;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 21:
    var $66 = $argv | 0;
    var $st$1$0 = $66 | 0;
    var $67$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $66 + 4 | 0;
    var $67$1 = HEAP32[$st$1$1 >> 2];
    var $68 = _JSVAL_IS_VOID4396($67$0, $67$1);
    if (($68 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    var $71$0 = HEAP32[$66 >> 2];
    var $71$1 = HEAP32[$66 + 4 >> 2];
    var $72 = $nsval | 0;
    HEAP32[$72 >> 2] = $71$0;
    HEAP32[$72 + 4 >> 2] = $71$1;
    var $87$1 = $71$1;
    var $87$0 = $71$0;
    __label__ = 28;
    break;
   case 23:
    var $73 = HEAP32[$name >> 2];
    var $_idx2_val = HEAP32[$73 >> 2];
    var $74 = __ZNK8JSString6lengthEv($_idx2_val);
    if (($74 | 0) == 1) {
      __label__ = 24;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 24:
    var $_idx3_val = HEAP32[$73 + 4 >> 2];
    var $77 = __ZNK14JSLinearString5charsEv($_idx3_val);
    if (HEAP16[$77 >> 1] << 16 >> 16 == 42) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    var $$emscripten$temp$1 = _JSVAL_NULL | 0;
    var $st$1$0 = $$emscripten$temp$1 | 0;
    var $81$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$1 + 4 | 0;
    var $81$1 = HEAP32[$st$1$1 >> 2];
    var $82 = $nsval | 0;
    HEAP32[$82 >> 2] = $81$0;
    HEAP32[$82 + 4 >> 2] = $81$1;
    var $87$1 = $81$1;
    var $87$0 = $81$0;
    __label__ = 28;
    break;
   case 26:
    var $84 = __Z25js_GetDefaultXMLNamespaceP9JSContextPN2JS5ValueE($cx, $nsval);
    if (($84 | 0) == 0) {
      var $_0 = 0;
      __label__ = 41;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $_phi_trans_insert = $nsval | 0;
    var $st$1$0 = $_phi_trans_insert | 0;
    var $st$1$1 = $_phi_trans_insert + 4 | 0;
    var $87$1 = HEAP32[$st$1$1 >> 2];
    var $87$0 = HEAP32[$st$1$0 >> 2];
    __label__ = 28;
    break;
   case 28:
    var $87$0;
    var $87$1;
    var $88 = _JSVAL_IS_NULL4395($87$0, $87$1);
    if (($88 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      var $prefix_0 = 0;
      var $uri_0 = 0;
      __label__ = 40;
      break;
    }
   case 29:
    var $91 = _JSVAL_IS_PRIMITIVE4303($87$0, $87$1);
    if (($91 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 30:
    var $94 = _JSVAL_TO_OBJECT4304($87$0, $87$1);
    var $_idx_val = HEAP32[$94 + 4 >> 2];
    var $96 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($96 | 0) == (__ZN2js14NamespaceClassE | 0)) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    var $99 = __ZNK8JSObject10getNameURIEv($94);
    var $100 = __ZNK8JSObject13getNamePrefixEv($94);
    var $prefix_0 = $100;
    var $uri_0 = $99;
    __label__ = 40;
    break;
   case 32:
    if (($96 | 0) == (__ZN2js10QNameClassE | 0)) {
      __label__ = 33;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 33:
    var $104 = __ZNK8JSObject10getNameURIEv($94);
    if (($104 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $107 = __ZNK8JSObject13getNamePrefixEv($94);
    var $prefix_0 = $107;
    var $uri_0 = $104;
    __label__ = 40;
    break;
   case 35:
    var $108 = $cx;
    var $109 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($108, $87$0, $87$1);
    if (($109 | 0) == 0) {
      var $_0 = 0;
      __label__ = 41;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $112 = $cx;
    var $113 = __ZN8JSString12ensureLinearEP9JSContext($109, $112);
    if (($113 | 0) == 0) {
      var $_0 = 0;
      __label__ = 41;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $116 = $113 | 0;
    _STRING_TO_JSVAL4322($3, $116);
    var $117 = $3 | 0;
    var $st$3$0 = $117 | 0;
    var $118$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $117 + 4 | 0;
    var $118$1 = HEAP32[$st$3$1 >> 2];
    var $119 = $argv | 0;
    HEAP32[$119 >> 2] = $118$0;
    HEAP32[$119 + 4 >> 2] = $118$1;
    var $_idx10_val = HEAP32[$113 >> 2];
    var $120 = __ZNK8JSString5emptyEv($_idx10_val);
    if ($120) {
      __label__ = 38;
      break;
    } else {
      var $127 = 0;
      __label__ = 39;
      break;
    }
   case 38:
    var $127 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2];
    __label__ = 39;
    break;
   case 39:
    var $127;
    var $prefix_0 = $127 | 0;
    var $uri_0 = $113;
    __label__ = 40;
    break;
   case 40:
    var $uri_0;
    var $prefix_0;
    var $129 = HEAP32[$name >> 2];
    var $130 = __ZL12InitXMLQNameP9JSContextP8JSObjectP14JSLinearStringS4_P6JSAtom($cx, $_01, $uri_0, $prefix_0, $129);
    var $_0 = $130 & 1;
    __label__ = 41;
    break;
   case 41:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11QNameHelperP9JSContextP8JSObjectiPN2JS5ValueES5_["X"] = 1;

function __ZNK8JSObject20getQNameLocalNameValEv($agg_result, $this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject7getSlotEj($1, 2);
  var $3 = $2 | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  var $5 = $agg_result | 0;
  HEAP32[$5 >> 2] = $4$0;
  HEAP32[$5 + 4 >> 2] = $4$1;
  return;
}

function __ZNK2JS5Value27getMagicObjectOrNullPayloadEv($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _MAGIC_JSVAL_TO_OBJECT_OR_NULL_IMPL($this_0_0_0_val$0, $this_0_0_0_val$1);
  return $1;
}

function __ZN2jsL16GetClassProtoKeyEPNS_5ClassE4430() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[__ZN2js8XMLClassE + 4 >> 2];
    var $2 = $1 >>> 24;
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $1 >>> 17 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject17setQNameLocalNameEP6JSAtom($this, $name) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($name | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $name | 0;
    __ZN2JSL11StringValueEP8JSString4311($1, $4);
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv4406($1);
    __label__ = 4;
    break;
   case 4:
    var $7 = $this;
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($7, 2, $_idx_val$0, $_idx_val$1);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19QNameNameURI_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $_idx_val = HEAP32[$obj + 4 >> 2];
    var $4 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($4 | 0) == (__ZN2js10QNameClassE | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    __ZNK8JSObject13getNameURIValEv($2, $obj);
    var $_idx1 = $2 | 0;
    var $st$2$0 = $_idx1 | 0;
    var $_idx1_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx1 + 4 | 0;
    var $_idx1_val$1 = HEAP32[$st$2$1 >> 2];
    var $7 = _JSVAL_IS_VOID4396($_idx1_val$0, $_idx1_val$1);
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $10$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $10$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $11 = $1 | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $14$1 = $10$1;
    var $14$0 = $10$0;
    __label__ = 5;
    break;
   case 4:
    __ZNK8JSObject13getNameURIValEv($1, $obj);
    var $_phi_trans_insert = $1 | 0;
    var $st$2$0 = $_phi_trans_insert | 0;
    var $st$2$1 = $_phi_trans_insert + 4 | 0;
    var $14$1 = HEAP32[$st$2$1 >> 2];
    var $14$0 = HEAP32[$st$2$0 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $14$0;
    var $14$1;
    var $15 = $vp | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21QNameLocalName_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $_idx_val = HEAP32[$obj + 4 >> 2];
    var $3 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($3 | 0) == (__ZN2js10QNameClassE | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZNK8JSObject20getQNameLocalNameValEv($1, $obj);
    var $6 = $1 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $vp | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject13getNameURIValEv($agg_result, $this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject7getSlotEj($1, 1);
  var $3 = $2 | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  var $5 = $agg_result | 0;
  HEAP32[$5 >> 2] = $4$0;
  HEAP32[$5 + 4 >> 2] = $4$1;
  return;
}

function __ZL17NamePrefix_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $_idx_val = HEAP32[$obj + 4 >> 2];
    var $3 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($3 | 0) == (__ZN2js14NamespaceClassE | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZNK8JSObject16getNamePrefixValEv($1, $obj);
    var $6 = $1 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $vp | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14NameURI_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $_idx_val = HEAP32[$obj + 4 >> 2];
    var $3 = __ZNK8JSObject8getClassEv($_idx_val);
    if (($3 | 0) == (__ZN2js14NamespaceClassE | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZNK8JSObject13getNameURIValEv($1, $obj);
    var $6 = $1 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $vp | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject16getNamePrefixValEv($agg_result, $this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject7getSlotEj($1, 0);
  var $3 = $2 | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  var $5 = $agg_result | 0;
  HEAP32[$5 >> 2] = $4$0;
  HEAP32[$5 + 4 >> 2] = $4$1;
  return;
}

function __ZL15NamespaceHelperP9JSContextP8JSObjectiPN2JS5ValueES5_($cx, $obj, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $bytes = __stackBase__ + 8;
    var $2 = __stackBase__ + 12;
    if (($argc | 0) < 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $isQName_0 = 0;
    var $isNamespace_0 = 0;
    var $uriobj_0 = 0;
    var $urival_0_0_0$1 = HEAP32[$st$1$1 >> 2];
    var $urival_0_0_0$0 = HEAP32[$st$1$0 >> 2];
    __label__ = 5;
    break;
   case 3:
    var $9 = $argv + ((($argc | 0) > 1 & 1) << 3) | 0;
    var $st$3$0 = $9 | 0;
    var $10$0 = HEAPU32[$st$3$0 >> 2];
    var $st$3$1 = $9 + 4 | 0;
    var $10$1 = HEAPU32[$st$3$1 >> 2];
    var $11 = _JSVAL_IS_PRIMITIVE4303($10$0, $10$1);
    if (($11 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $isQName_0 = 0;
      var $isNamespace_0 = 0;
      var $uriobj_0 = 0;
      var $urival_0_0_0$1 = $10$1;
      var $urival_0_0_0$0 = $10$0;
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = _JSVAL_TO_OBJECT4304($10$0, $10$1);
    var $_idx_val = HEAP32[$14 + 4 >> 2];
    var $16 = __ZNK8JSObject8getClassEv($_idx_val);
    var $isQName_0 = ($16 | 0) == (__ZN2js10QNameClassE | 0) & 1;
    var $isNamespace_0 = ($16 | 0) == (__ZN2js14NamespaceClassE | 0) & 1;
    var $uriobj_0 = $14;
    var $urival_0_0_0$1 = $10$1;
    var $urival_0_0_0$0 = $10$0;
    __label__ = 5;
    break;
   case 5:
    var $urival_0_0_0$0;
    var $urival_0_0_0$1;
    var $uriobj_0;
    var $isNamespace_0;
    var $isQName_0;
    if (($obj | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_02 = $obj;
      __label__ = 9;
      break;
    }
   case 6:
    if (($argc | 0) != 1 | ($isNamespace_0 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $27 = $rval | 0;
    var $st$1$0 = $27 | 0;
    HEAP32[$st$1$0 >> 2] = $urival_0_0_0$0;
    var $st$1$1 = $27 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $urival_0_0_0$1;
    var $_0 = 1;
    __label__ = 37;
    break;
   case 8:
    var $29 = __ZL26NewBuiltinClassInstanceXMLP9JSContextPN2js5ClassE($cx, __ZN2js14NamespaceClassE);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      var $_02 = $29;
      __label__ = 9;
      break;
    }
   case 9:
    var $_02;
    var $32 = $cx;
    var $34 = _JS_DefineProperties($32, $_02, __ZL15namespace_props);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    _OBJECT_TO_JSVAL4318($1, $_02);
    var $37 = $1 | 0;
    var $38$0 = HEAP32[$37 >> 2];
    var $38$1 = HEAP32[$37 + 4 >> 2];
    var $39 = $rval | 0;
    HEAP32[$39 >> 2] = $38$0;
    HEAP32[$39 + 4 >> 2] = $38$1;
    var $44 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN8JSObject13setNamePrefixEP14JSLinearString($_02, $44);
    __ZN8JSObject10setNameURIEP14JSLinearString($_02, $44);
    if (($argc | 0) == -1 || ($argc | 0) == 1) {
      __label__ = 11;
      break;
    } else if (($argc | 0) == 2) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 1;
      __label__ = 37;
      break;
    }
   case 11:
    if (($isNamespace_0 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $48 = __ZNK8JSObject10getNameURIEv($uriobj_0);
    __ZN8JSObject10setNameURIEP14JSLinearString($_02, $48);
    var $49 = __ZNK8JSObject13getNamePrefixEv($uriobj_0);
    __ZN8JSObject13setNamePrefixEP14JSLinearString($_02, $49);
    var $_0 = 1;
    __label__ = 37;
    break;
   case 13:
    if (($isQName_0 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $53 = __ZNK8JSObject10getNameURIEv($uriobj_0);
    if (($53 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    __ZN8JSObject10setNameURIEP14JSLinearString($_02, $53);
    var $56 = __ZNK8JSObject13getNamePrefixEv($uriobj_0);
    __ZN8JSObject13setNamePrefixEP14JSLinearString($_02, $56);
    var $_0 = 1;
    __label__ = 37;
    break;
   case 16:
    var $58 = $cx;
    var $59 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($58, $urival_0_0_0$0, $urival_0_0_0$1);
    if (($59 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $62 = __ZN8JSString12ensureLinearEP9JSContext($59, $32);
    if (($62 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZN8JSObject10setNameURIEP14JSLinearString($_02, $62);
    var $_idx8_val = HEAP32[$62 >> 2];
    var $65 = __ZNK8JSString5emptyEv($_idx8_val);
    if ($65) {
      var $_0 = 1;
      __label__ = 37;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    __ZN8JSObject15clearNamePrefixEv($_02);
    var $_0 = 1;
    __label__ = 37;
    break;
   case 20:
    if (($isQName_0 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $70 = __ZNK8JSObject10getNameURIEv($uriobj_0);
    if (($70 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      var $uri_0 = $70;
      __label__ = 24;
      break;
    }
   case 22:
    var $73 = $cx;
    var $74 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($73, $urival_0_0_0$0, $urival_0_0_0$1);
    if (($74 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $77 = __ZN8JSString12ensureLinearEP9JSContext($74, $32);
    if (($77 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      var $uri_0 = $77;
      __label__ = 24;
      break;
    }
   case 24:
    var $uri_0;
    __ZN8JSObject10setNameURIEP14JSLinearString($_02, $uri_0);
    var $80 = $argv | 0;
    var $st$3$0 = $80 | 0;
    var $81$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $80 + 4 | 0;
    var $81$1 = HEAP32[$st$3$1 >> 2];
    var $_idx7_val = HEAP32[$uri_0 >> 2];
    var $82 = __ZNK8JSString5emptyEv($_idx7_val);
    var $83 = _JSVAL_IS_VOID4396($81$0, $81$1);
    var $84 = ($83 | 0) == 0;
    if ($82) {
      __label__ = 25;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 25:
    if ($84) {
      __label__ = 26;
      break;
    } else {
      var $_0 = 1;
      __label__ = 37;
      break;
    }
   case 26:
    var $87 = $cx;
    var $88 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($87, $81$0, $81$1);
    if (($88 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $_idx6_val = HEAP32[$88 >> 2];
    var $91 = __ZNK8JSString5emptyEv($_idx6_val);
    if ($91) {
      var $_0 = 1;
      __label__ = 37;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    __ZN16JSAutoByteStringC1Ev($bytes);
    __ZN2JSL11StringValueEP8JSString4311($2, $88);
    var $93 = $bytes;
    var $_idx11 = $2 | 0;
    var $_idx11_val$0 = HEAP32[$_idx11 >> 2];
    var $_idx11_val$1 = HEAP32[$_idx11 + 4 >> 2];
    var $94 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($87, $_idx11_val$0, $_idx11_val$1, $93);
    var $bytes_idx_val_pre = HEAP32[$bytes >> 2];
    if (($94 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $97 = __ZNK16JSAutoByteString3ptrEv($bytes_idx_val_pre);
    _JS_ReportErrorNumber($32, 4, 177, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $97, tempInt));
    __label__ = 30;
    break;
   case 30:
    __ZN16JSAutoByteStringD1Ev($bytes_idx_val_pre);
    var $_0 = 0;
    __label__ = 37;
    break;
   case 31:
    if ($84) {
      __label__ = 32;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 32:
    var $100 = __Z12js_IsXMLNameP9JSContextN2JS5ValueE($cx, $81$0, $81$1);
    if (($100 | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 33:
    __ZN8JSObject15clearNamePrefixEv($_02);
    var $_0 = 1;
    __label__ = 37;
    break;
   case 34:
    var $104 = $cx;
    var $105 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($104, $81$0, $81$1);
    if (($105 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $108 = __ZN8JSString12ensureLinearEP9JSContext($105, $32);
    if (($108 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    __ZN8JSObject13setNamePrefixEP14JSLinearString($_02, $108);
    var $_0 = 1;
    __label__ = 37;
    break;
   case 37:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15NamespaceHelperP9JSContextP8JSObjectiPN2JS5ValueES5_["X"] = 1;

function __ZN8JSObject15clearNamePrefixEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL14UndefinedValueEv4406($1);
  var $2 = $this;
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, 0, $_idx_val$0, $_idx_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_4427($cx, $parent) {
  var $3 = HEAPU32[__ZN2js8XMLClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb4379($3);
  var $5 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE4428($cx, $parent, $4);
  return $5;
}

function __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE4428($cx, $parent, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = 0;
    var $2 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_4429($cx, $parent, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 2:
    var $4 = HEAP32[$1 >> 2];
    var $5 = ($4 | 0) == 0;
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = __ZN2js5types15emptyTypeObjectE;
    var $_pre_phi = $cx;
    __label__ = 5;
    break;
   case 4:
    var $7 = $4;
    var $8 = $cx;
    var $9 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($7, $8, 0, 0);
    var $10 = $9;
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      var $12 = $10;
      var $_pre_phi = $8;
      __label__ = 5;
      break;
    }
   case 5:
    var $_pre_phi;
    var $12;
    var $13 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($_pre_phi, $kind);
    var $14 = $13;
    if (($13 | 0) == 0) {
      var $_0 = $14;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_not = ($parent | 0) == 0 ^ 1;
    var $parent_mux = $_not ? $parent : 0;
    if ($_not | $5) {
      var $23 = $parent_mux;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx_val = HEAP32[$4 + 20 >> 2];
    var $20 = __ZNK8JSObject9getParentEv($_idx_val);
    var $23 = $20;
    __label__ = 8;
    break;
   case 8:
    var $23;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($13, __ZN2js8XMLClassE, $12, $23, 0, (__ZN2js8XMLClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $_idx1_val = HEAP32[__ZN2js8XMLClassE + 4 >> 2];
    var $26 = __ZNK2js5Class8isNativeEv($_idx1_val);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $28 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE4383($cx, $14, __ZN2js8XMLClassE, $12, $kind);
    if ($28) {
      var $_0 = $14;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 0;
    __label__ = 12;
    break;
   case 11:
    __ZN8JSObject21setSharedNonNativeMapEv($13);
    var $_0 = $14;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_4429($cx, $parent, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL16GetClassProtoKeyEPNS_5ClassE4430();
    var $2 = $cx;
    var $3 = $parent;
    var $4 = $proto;
    var $5 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, $1, $4, __ZN2js8XMLClassE);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$proto >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, 1, $4, 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13AutoXMLRooterD2Ev($this) {
  var $_idx_val = HEAP32[$this >> 2];
  var $_idx1_val = HEAP32[$this + 8 >> 2];
  __ZN2js12AutoGCRooterD2Ev($_idx_val, $_idx1_val);
  return;
}

function __ZN2js13AutoXMLRooterC2EP9JSContextP5JSXML($this, $cx, $xml) {
  var $1 = $this;
  var $2 = $cx;
  __ZN2js12AutoGCRooterC2EP9JSContexti($1, $2, -9);
  HEAP32[$this + 12 >> 2] = $xml;
  return;
}

function __ZL15CopyXMLSettingsP9JSContextP8JSObjectS2_($cx, $from, $to) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $cx;
    var $2 = $from;
    var $3 = $v | 0;
    var $4 = $to;
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    var $7 = HEAP32[__ZL16xml_static_props + ($i_0 << 4) >> 2];
    if (($7 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = _JS_GetProperty($1, $2, $7, $v);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = ($7 | 0) == (STRING_TABLE.__ZL19js_prettyIndent_str | 0);
    var $14$0 = HEAP32[$3 >> 2];
    var $14$1 = HEAP32[$3 + 4 >> 2];
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = _JSVAL_IS_NUMBER($14$0, $14$1);
    if (($16 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $19 = _JSVAL_IS_BOOLEAN4407($14$0, $14$1);
    if (($19 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = _JS_SetProperty($1, $4, $7, $v);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15xml_text_helperP9JSContextP8JSObjectP5JSXMLPN2JS5ValueE($cx, $xml, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZL15xml_list_helperP9JSContextP5JSXMLPN2JS5ValueE($cx, $xml, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAPU32[$xml + 16 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 3:
    var $8 = $xml + 24 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $10 = $xml + 32 | 0;
    var $11 = $v | 0;
    var $i_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_0;
    if ($i_0 >>> 0 < $9 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 24;
      break;
    }
   case 5:
    if ($i_0 >>> 0 < HEAPU32[$8 >> 2] >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 6:
    var $20 = HEAPU32[HEAP32[$10 >> 2] + ($i_0 << 2) >> 2];
    var $21 = $20;
    if (($20 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ((HEAP32[$20 + 16 >> 2] | 0) == 1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 8:
    var $29 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $21);
    if (($29 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = __ZL15xml_text_helperP9JSContextP8JSObjectP5JSXMLPN2JS5ValueE($cx, $21, $v);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $33$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $33$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    HEAP32[$11 >> 2] = $33$0;
    HEAP32[$11 + 4 >> 2] = $33$1;
    var $_0 = 0;
    __label__ = 24;
    break;
   case 11:
    var $35$0 = HEAP32[$11 >> 2];
    var $35$1 = HEAP32[$11 + 4 >> 2];
    var $36 = _JSVAL_TO_OBJECT4304($35$0, $35$1);
    var $_idx_val = HEAP32[$36 + 24 >> 2];
    var $38 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $39 = $38;
    if (HEAPU32[$38 + 16 >> 2] >>> 0 < 2) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    if ((HEAP32[$38 + 24 >> 2] | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $49 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $1, $39);
    if (($49 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 4;
    break;
   case 15:
    var $54 = $xml + 24 | 0;
    if ($5 >>> 0 < 2) {
      __label__ = 16;
      break;
    } else {
      var $57 = 0;
      __label__ = 17;
      break;
    }
   case 16:
    var $57 = HEAP32[$54 >> 2];
    __label__ = 17;
    break;
   case 17:
    var $57;
    var $58 = $xml + 32 | 0;
    var $i_1 = 0;
    __label__ = 18;
    break;
   case 18:
    var $i_1;
    if ($i_1 >>> 0 < $57 >>> 0) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 1;
      __label__ = 24;
      break;
    }
   case 19:
    if ($i_1 >>> 0 < HEAPU32[$54 >> 2] >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 20:
    var $67 = HEAPU32[HEAP32[$58 >> 2] + ($i_1 << 2) >> 2];
    var $68 = $67;
    if (($67 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    if ((HEAP32[$67 + 16 >> 2] | 0) == 4) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    var $76 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $1, $68);
    if (($76 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $i_1 = $i_1 + 1 | 0;
    __label__ = 18;
    break;
   case 24:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15xml_text_helperP9JSContextP8JSObjectP5JSXMLPN2JS5ValueE["X"] = 1;

function __ZL15xml_list_helperP9JSContextP5JSXMLPN2JS5ValueE($cx, $xml, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 0);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL4318($1, $2);
    var $5 = $1 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $rval | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $_idx_val = HEAP32[$2 + 24 >> 2];
    var $9 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $10 = $9;
    var $12 = $9 + 40 | 0;
    HEAP32[$12 >> 2] = $xml;
    var $_0 = $10;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $numBuf = __stackBase__;
    var $1 = __stackBase__ + 12;
    var $funNameBytes = __stackBase__ + 20;
    var $2 = $vp + 8 | 0;
    var $3 = $cx;
    var $4 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($3, $2);
    HEAP32[$objp >> 2] = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx2_val = HEAP32[$4 + 4 >> 2];
    var $8 = __ZNK8JSObject5isXMLEv($_idx2_val);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($3, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 13;
    break;
   case 4:
    var $_idx_val = HEAP32[$4 + 24 >> 2];
    var $11 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $12 = $11;
    if (($11 | 0) == 0) {
      var $_0 = $12;
      __label__ = 13;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$11 + 16 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $12;
      __label__ = 13;
      break;
    }
   case 6:
    if ((HEAP32[$11 + 24 >> 2] | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      var $xml_0 = $12;
      __label__ = 10;
      break;
    }
   case 7:
    var $28 = HEAP32[HEAP32[$11 + 32 >> 2] >> 2];
    var $29 = $28;
    if (($28 | 0) == 0) {
      var $xml_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $32 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $29);
    HEAP32[$objp >> 2] = $32;
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    _OBJECT_TO_JSVAL4318($1, $32);
    var $35 = $1 | 0;
    var $st$2$0 = $35 | 0;
    var $36$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $35 + 4 | 0;
    var $36$1 = HEAP32[$st$2$1 >> 2];
    var $37 = $2 | 0;
    HEAP32[$37 >> 2] = $36$0;
    HEAP32[$37 + 4 >> 2] = $36$1;
    var $_0 = $29;
    __label__ = 13;
    break;
   case 10:
    var $xml_0;
    var $39 = $vp | 0;
    var $st$2$0 = $39 | 0;
    var $40$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $39 + 4 | 0;
    var $40$1 = HEAP32[$st$2$1 >> 2];
    var $41 = _JSVAL_TO_OBJECT4304($40$0, $40$1);
    var $_idx1_val = HEAP32[$41 + 24 >> 2];
    var $43 = __ZNK8JSObject18getFunctionPrivateEv($_idx1_val);
    var $44 = $numBuf | 0;
    var $46 = HEAP32[$xml_0 + 24 >> 2];
    var $47 = _JS_snprintf($44, 12, STRING_TABLE.__str544300 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $46, tempInt));
    __ZN16JSAutoByteStringC1Ev($funNameBytes);
    var $_idx4_val = HEAP32[$43 + 72 >> 2];
    var $48 = __ZN2js20GetFunctionNameBytesEP9JSContextP10JSFunctionP16JSAutoByteString($3, $_idx4_val, $funNameBytes);
    if (($48 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    _JS_ReportErrorNumber($3, 4, 219, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $48, HEAP32[tempInt + 4 >> 2] = $44, tempInt));
    __label__ = 12;
    break;
   case 12:
    var $funNameBytes_idx_val = HEAP32[$funNameBytes >> 2];
    __ZN16JSAutoByteStringD1Ev($funNameBytes_idx_val);
    var $_0 = 0;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject["X"] = 1;

function __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $xml, $obj) {
  var $1 = __ZL8DeepCopyP9JSContextP5JSXMLP8JSObjectj($cx, $xml, $obj);
  return $1;
}

function __ZL19AddInScopeNamespaceP9JSContextP5JSXMLP8JSObject($cx, $xml, $ns) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$xml + 16 >> 2] | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 22;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject13getNamePrefixEv($ns);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 3:
    var $8 = $xml + 40 | 0;
    var $10 = HEAPU32[$8 >> 2];
    var $11 = $xml + 48 | 0;
    var $i_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_0;
    if ($i_0 >>> 0 < $10 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $17 = HEAP32[HEAP32[$11 >> 2] + ($i_0 << 2) >> 2];
    if (($17 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = $17;
    var $21 = __ZNK8JSObject10getNameURIEv($20);
    var $22 = __ZNK8JSObject10getNameURIEv($ns);
    var $23 = __ZN2js12EqualStringsEP14JSLinearStringS1_($21, $22);
    if ($23) {
      __label__ = 21;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 4;
    break;
   case 8:
    var $26 = $ns;
    var $27 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $8, $10, $26);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 9:
    var $_idx1_val = HEAP32[$5 >> 2];
    var $30 = __ZNK8JSString5emptyEv($_idx1_val);
    if ($30) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $33 = HEAP32[$xml + 12 >> 2];
    var $34 = __ZNK8JSObject10getNameURIEv($33);
    var $_idx_val = HEAP32[$34 >> 2];
    var $35 = __ZNK8JSString5emptyEv($_idx_val);
    if ($35) {
      var $_0 = 1;
      __label__ = 22;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $37 = $xml + 40 | 0;
    var $38 = $37 | 0;
    var $39 = HEAPU32[$38 >> 2];
    var $40 = $xml + 48 | 0;
    var $i_1 = 0;
    __label__ = 12;
    break;
   case 12:
    var $i_1;
    if ($i_1 >>> 0 < $39 >>> 0) {
      __label__ = 13;
      break;
    } else {
      var $62 = $39;
      __label__ = 20;
      break;
    }
   case 13:
    var $46 = HEAP32[HEAP32[$40 >> 2] + ($i_1 << 2) >> 2];
    var $47 = $46;
    if (($46 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $50 = __ZNK8JSObject13getNamePrefixEv($47);
    if (($50 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $53 = __ZN2js12EqualStringsEP14JSLinearStringS1_($50, $5);
    if ($53) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i_1 = $i_1 + 1 | 0;
    __label__ = 12;
    break;
   case 17:
    var $56 = __ZNK8JSObject10getNameURIEv($47);
    var $57 = __ZNK8JSObject10getNameURIEv($ns);
    var $58 = __ZN2js12EqualStringsEP14JSLinearStringS1_($56, $57);
    if ($58) {
      var $62 = $39;
      __label__ = 20;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZL14XMLArrayDeleteP9JSContextP10JSXMLArrayji($37, $i_1, 1);
    __ZN8JSObject15clearNamePrefixEv($47);
    var $60 = __ZL19AddInScopeNamespaceP9JSContextP5JSXMLP8JSObject($cx, $xml, $47);
    if (($60 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $62 = HEAP32[$38 >> 2];
    __label__ = 20;
    break;
   case 20:
    var $62;
    var $63 = $ns;
    var $64 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $37, $62, $63);
    if (($64 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $_0 = 1;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19AddInScopeNamespaceP9JSContextP5JSXMLP8JSObject["X"] = 1;

function __ZL11PutPropertyP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 228;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $rxml = __stackBase__;
    var $index = __stackBase__ + 4;
    var $attrval = __stackBase__ + 8;
    var $nsval = __stackBase__ + 16;
    var $funid = __stackBase__ + 24;
    var $roots = __stackBase__ + 28;
    var $1 = __stackBase__ + 52;
    var $2 = __stackBase__ + 60;
    var $tvr = __stackBase__ + 68;
    var $3 = __stackBase__ + 84;
    var $4 = __stackBase__ + 92;
    var $5 = __stackBase__ + 100;
    var $6 = __stackBase__ + 108;
    var $7 = __stackBase__ + 116;
    var $8 = __stackBase__ + 124;
    var $9 = __stackBase__ + 132;
    var $10 = __stackBase__ + 140;
    var $11 = __stackBase__ + 148;
    var $12 = __stackBase__ + 156;
    var $13 = __stackBase__ + 164;
    var $14 = __stackBase__ + 172;
    var $15 = __stackBase__ + 180;
    var $16 = __stackBase__ + 188;
    var $cursor = __stackBase__ + 196;
    var $bytes = __stackBase__ + 216;
    var $17 = __stackBase__ + 220;
    var $_idx16_val = HEAP32[$obj + 4 >> 2];
    var $19 = __ZNK8JSObject5isXMLEv($_idx16_val);
    if ($19) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 192;
      break;
    }
   case 2:
    var $_idx5_val = HEAP32[$obj + 24 >> 2];
    var $22 = __ZNK8JSObject10getPrivateEv($_idx5_val);
    var $23 = $22;
    if (($22 | 0) == 0) {
      var $_0 = 1;
      __label__ = 192;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$22 >> 2] | 0) == ($obj | 0)) {
      var $32 = $23;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $30 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $23, $obj);
    var $32 = $30;
    __label__ = 5;
    break;
   case 5:
    var $32;
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 192;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $35 = $vp | 0;
    var $st$1$0 = $35 | 0;
    var $36$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $35 + 4 | 0;
    var $36$1 = HEAP32[$st$1$1 >> 2];
    var $37 = _JSVAL_IS_PRIMITIVE4303($36$0, $36$1);
    if (($37 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $vxml_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $st$0$0 = $35 | 0;
    var $40$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $35 + 4 | 0;
    var $40$1 = HEAP32[$st$0$1 >> 2];
    var $41 = _JSVAL_TO_OBJECT4304($40$0, $40$1);
    var $_idx15_val = HEAP32[$41 + 4 >> 2];
    var $43 = __ZNK8JSObject5isXMLEv($_idx15_val);
    if ($43) {
      __label__ = 8;
      break;
    } else {
      var $vxml_0 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $_idx4_val = HEAP32[$41 + 24 >> 2];
    var $46 = __ZNK8JSObject10getPrivateEv($_idx4_val);
    var $vxml_0 = $46;
    __label__ = 9;
    break;
   case 9:
    var $vxml_0;
    var $49 = $roots | 0;
    _OBJECT_TO_JSVAL4318($1, $obj);
    var $50 = $1 | 0;
    var $st$4$0 = $50 | 0;
    var $51$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $50 + 4 | 0;
    var $51$1 = HEAP32[$st$4$1 >> 2];
    var $52 = $roots | 0;
    var $st$9$0 = $52 | 0;
    HEAP32[$st$9$0 >> 2] = $51$0;
    var $st$9$1 = $52 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $51$1;
    __ZN2jsL9IdToJsvalEi4431($2, $id);
    var $53 = $2 | 0;
    var $54$0 = HEAP32[$53 >> 2];
    var $54$1 = HEAP32[$53 + 4 >> 2];
    var $55 = $roots + 8 | 0;
    HEAP32[$55 >> 2] = $54$0;
    HEAP32[$55 + 4 >> 2] = $54$1;
    var $56$0 = HEAP32[$35 >> 2];
    var $56$1 = HEAP32[$35 + 4 >> 2];
    var $57 = $roots + 16 | 0;
    HEAP32[$57 >> 2] = $56$0;
    HEAP32[$57 + 4 >> 2] = $56$1;
    var $58 = $cx;
    __ZN2js15AutoArrayRooterC1EP9JSContextjPN2JS5ValueE($tvr, $58, 3, $49);
    var $59 = __Z12js_IdIsIndexiPj($id, $index);
    if (($59 | 0) == 0) {
      __label__ = 91;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ((HEAP32[$32 + 16 >> 2] | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2jsL9IdToValueEi4432($3, $id);
    var $_idx34 = $3 | 0;
    var $st$2$0 = $_idx34 | 0;
    var $_idx34_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx34 + 4 | 0;
    var $_idx34_val$1 = HEAP32[$st$2$1 >> 2];
    __ZL16ReportBadXMLNameP9JSContextRKN2JS5ValueE($cx, $_idx34_val$0, $_idx34_val$1);
    var $ok_13 = 0;
    __label__ = 188;
    break;
   case 12:
    var $67 = HEAPU32[$index >> 2];
    var $68 = $32 + 24 | 0;
    var $71 = HEAP32[$32 + 40 >> 2];
    if (($71 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $74 = __ZL12ResolveValueP9JSContextP5JSXMLPS2_($cx, $71, $rxml);
    var $76 = HEAP32[$rxml >> 2];
    if (($74 | 0) == 0 | ($76 | 0) == 0) {
      var $ok_13 = $74;
      __label__ = 188;
      break;
    } else {
      var $ok_0 = $74;
      var $80 = $76;
      __label__ = 15;
      break;
    }
   case 14:
    HEAP32[$rxml >> 2] = 0;
    var $ok_0 = 1;
    var $80 = 0;
    __label__ = 15;
    break;
   case 15:
    var $80;
    var $ok_0;
    var $81 = $68 | 0;
    var $82 = $68 | 0;
    if ($67 >>> 0 < HEAPU32[$82 >> 2] >>> 0) {
      var $ok_2 = $ok_0;
      var $i_0 = $67;
      __label__ = 51;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if (($80 | 0) == 0) {
      var $111 = $80;
      __label__ = 23;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $89 = HEAPU32[$80 + 16 >> 2];
    if (($89 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      var $ok_1 = $ok_0;
      var $108 = $80;
      var $107 = $89;
      __label__ = 22;
      break;
    }
   case 18:
    if ((HEAP32[$80 + 24 >> 2] | 0) == 1) {
      __label__ = 19;
      break;
    } else {
      var $ok_13 = $ok_0;
      __label__ = 188;
      break;
    }
   case 19:
    var $98 = HEAPU32[HEAP32[$80 + 32 >> 2] >> 2];
    var $99 = $98;
    HEAP32[$rxml >> 2] = $99;
    if (($98 | 0) == 0) {
      var $ok_13 = $ok_0;
      __label__ = 188;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $102 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $99);
    var $103 = ($102 | 0) != 0;
    var $104 = $103 & 1;
    if ($103) {
      __label__ = 21;
      break;
    } else {
      var $ok_13 = $104;
      __label__ = 188;
      break;
    }
   case 21:
    var $ok_1 = $104;
    var $108 = $99;
    var $107 = HEAP32[$98 + 16 >> 2];
    __label__ = 22;
    break;
   case 22:
    var $107;
    var $108;
    var $ok_1;
    if ($107 >>> 0 < 2) {
      var $111 = $108;
      __label__ = 23;
      break;
    } else {
      var $ok_13 = $ok_1;
      __label__ = 188;
      break;
    }
   case 23:
    var $111;
    var $114 = HEAPU32[$32 + 44 >> 2];
    if (($114 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $117 = __ZNK8JSObject17getQNameLocalNameEv($114);
    var $_idx11_val = HEAP32[$117 >> 2];
    var $118 = __ZNK8JSString6lengthEv($_idx11_val);
    if (($118 | 0) == 1) {
      __label__ = 25;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 25:
    var $_idx14_val = HEAP32[$117 + 4 >> 2];
    var $121 = __ZNK14JSLinearString5charsEv($_idx14_val);
    if (HEAP16[$121 >> 1] << 16 >> 16 == 42) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $125 = __Z9js_NewXMLP9JSContext10JSXMLClass($cx, 4);
    if (($125 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      var $kid_1 = $125;
      __label__ = 36;
      break;
    }
   case 27:
    var $_idx8_val = HEAP32[$114 + 4 >> 2];
    var $129 = __ZNK8JSObject8getClassEv($_idx8_val);
    if (($129 | 0) == (__ZN2js18AttributeNameClassE | 0)) {
      __label__ = 28;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 28:
    var $133 = HEAP32[$111 >> 2];
    var $134 = __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $133, $id, $attrval);
    if (($134 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $137 = $attrval | 0;
    var $st$1$0 = $137 | 0;
    var $138$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $137 + 4 | 0;
    var $138$1 = HEAP32[$st$1$1 >> 2];
    var $139 = _JSVAL_IS_PRIMITIVE4303($138$0, $138$1);
    if (($139 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      var $ok_13 = $134;
      __label__ = 188;
      break;
    }
   case 30:
    var $st$0$0 = $137 | 0;
    var $142$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $137 + 4 | 0;
    var $142$1 = HEAP32[$st$0$1 >> 2];
    var $143 = _JSVAL_TO_OBJECT4304($142$0, $142$1);
    var $_idx3_val = HEAP32[$143 + 24 >> 2];
    var $145 = __ZNK8JSObject10getPrivateEv($_idx3_val);
    if (HEAPU32[$145 + 16 >> 2] >>> 0 < 2) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    if ((HEAP32[$145 + 24 >> 2] | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      var $ok_13 = $134;
      __label__ = 188;
      break;
    }
   case 32:
    var $154 = __Z9js_NewXMLP9JSContext10JSXMLClass($cx, 2);
    var $kid_0 = $154;
    __label__ = 34;
    break;
   case 33:
    var $156 = __Z9js_NewXMLP9JSContext10JSXMLClass($cx, 1);
    var $kid_0 = $156;
    __label__ = 34;
    break;
   case 34:
    var $kid_0;
    if (($kid_0 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    HEAP32[$kid_0 + 12 >> 2] = $114;
    var $kid_1 = $kid_0;
    __label__ = 36;
    break;
   case 36:
    var $kid_1;
    HEAP32[$kid_1 + 8 >> 2] = $111;
    var $163 = HEAPU32[$82 >> 2];
    if ((HEAP32[$kid_1 + 16 >> 2] | 0) == 2) {
      __label__ = 50;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $168 = HEAPU32[$rxml >> 2];
    if (($168 | 0) == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $172 = HEAP32[$168 + 24 >> 2];
    var $173 = $172 - 1 | 0;
    if (($172 | 0) == 0 | ($163 | 0) == 0) {
      var $j_1 = $173;
      __label__ = 43;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $176 = $168 + 32 | 0;
    var $177 = $163 - 1 | 0;
    var $178 = $32 + 32 | 0;
    var $j_0 = 0;
    __label__ = 40;
    break;
   case 40:
    var $j_0;
    if ($j_0 >>> 0 < $173 >>> 0) {
      __label__ = 41;
      break;
    } else {
      var $j_1 = $j_0;
      __label__ = 43;
      break;
    }
   case 41:
    if ((HEAP32[HEAP32[$176 >> 2] + ($j_0 << 2) >> 2] | 0) == (HEAP32[HEAP32[$178 >> 2] + ($177 << 2) >> 2] | 0)) {
      var $j_1 = $j_0;
      __label__ = 43;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $j_0 = $j_0 + 1 | 0;
    __label__ = 40;
    break;
   case 43:
    var $j_1;
    var $191 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $kid_1);
    if (($191 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $194 = $j_1 + 1 | 0;
    _OBJECT_TO_JSVAL4318($4, $191);
    var $_idx39 = $4 | 0;
    var $st$3$0 = $_idx39 | 0;
    var $_idx39_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx39 + 4 | 0;
    var $_idx39_val$1 = HEAP32[$st$3$1 >> 2];
    var $195 = __ZL6InsertP9JSContextP5JSXMLjN2JS5ValueE($cx, $168, $194, $_idx39_val$0, $_idx39_val$1);
    if (($195 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    if (($vxml_0 | 0) == 0) {
      __label__ = 50;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    if ((HEAP32[$vxml_0 + 16 >> 2] | 0) == 0) {
      __label__ = 47;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 47:
    var $_in = $vxml_0 + 44 | 0;
    __label__ = 49;
    break;
   case 48:
    var $_in = $vxml_0 + 12 | 0;
    __label__ = 49;
    break;
   case 49:
    var $_in;
    var $209 = HEAP32[$_in >> 2];
    HEAP32[$kid_1 + 12 >> 2] = $209;
    __label__ = 50;
    break;
   case 50:
    var $212 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $32, $kid_1);
    if (($212 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      var $ok_2 = $212;
      var $i_0 = $163;
      __label__ = 51;
      break;
    }
   case 51:
    var $i_0;
    var $ok_2;
    var $215 = ($vxml_0 | 0) != 0;
    if ($215) {
      __label__ = 52;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 52:
    var $218 = HEAP32[$vxml_0 + 16 >> 2];
    if (($218 | 0) == 4 || ($218 | 0) == 2) {
      __label__ = 53;
      break;
    } else {
      var $ok_3 = $ok_2;
      __label__ = 55;
      break;
    }
   case 53:
    var $st$0$0 = $35 | 0;
    var $220$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $35 + 4 | 0;
    var $220$1 = HEAP32[$st$0$1 >> 2];
    var $221 = _JS_ConvertValue($58, $220$0, $220$1, 3, $vp);
    if (($221 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    var $st$0$0 = $35 | 0;
    var $224$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $35 + 4 | 0;
    var $224$1 = HEAP32[$st$0$1 >> 2];
    var $st$4$0 = $57 | 0;
    HEAP32[$st$4$0 >> 2] = $224$0;
    var $st$4$1 = $57 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $224$1;
    var $ok_3 = $221;
    __label__ = 55;
    break;
   case 55:
    var $ok_3;
    if ($i_0 >>> 0 < HEAPU32[$82 >> 2] >>> 0) {
      __label__ = 56;
      break;
    } else {
      var $ok_13 = $ok_3;
      __label__ = 188;
      break;
    }
   case 56:
    var $228 = $32 + 32 | 0;
    var $231 = HEAPU32[HEAP32[$228 >> 2] + ($i_0 << 2) >> 2];
    var $232 = $231;
    if (($231 | 0) == 0) {
      var $ok_13 = $ok_3;
      __label__ = 188;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    var $237 = HEAPU32[$231 + 8 >> 2];
    var $240 = HEAPU32[$231 + 16 >> 2];
    if (($240 | 0) == 2) {
      __label__ = 58;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 58:
    var $245 = HEAP32[$231 + 12 >> 2];
    var $_idx7_val = HEAP32[$245 + 4 >> 2];
    var $247 = __ZNK8JSObject8getClassEv($_idx7_val);
    if (($247 | 0) == (__ZN2js18AttributeNameClassE | 0)) {
      var $nameobj_0 = $245;
      __label__ = 60;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 59:
    var $250 = __ZNK8JSObject10getNameURIEv($245);
    var $251 = __ZNK8JSObject13getNamePrefixEv($245);
    var $252 = __ZNK8JSObject17getQNameLocalNameEv($245);
    var $253 = __ZL19NewXMLAttributeNameP9JSContextP14JSLinearStringS2_P6JSAtom($cx, $250, $251, $252);
    if (($253 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      var $nameobj_0 = $253;
      __label__ = 60;
      break;
    }
   case 60:
    var $nameobj_0;
    var $256 = _OBJECT_TO_JSID4356($nameobj_0);
    if (($237 | 0) == 0) {
      var $ok_13 = $ok_3;
      __label__ = 188;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    var $259 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $237);
    if (($259 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 62:
    var $262 = __ZL11PutPropertyP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $259, $256, $strict, $vp);
    if (($262 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $265 = __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $259, $256, $vp);
    if (($265 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    var $st$0$0 = $35 | 0;
    var $268$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $35 + 4 | 0;
    var $268$1 = HEAP32[$st$0$1 >> 2];
    var $269 = _JSVAL_TO_OBJECT4304($268$0, $268$1);
    var $_idx2_val = HEAP32[$269 + 24 >> 2];
    var $271 = __ZNK8JSObject10getPrivateEv($_idx2_val);
    if ((HEAP32[$271 + 24 >> 2] | 0) == 0) {
      var $ok_13 = $265;
      __label__ = 188;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 65:
    var $280 = HEAP32[HEAP32[$271 + 32 >> 2] >> 2];
    var $282 = HEAP32[$228 >> 2] + ($i_0 << 2) | 0;
    HEAP32[$282 >> 2] = $280;
    var $ok_13 = $265;
    __label__ = 188;
    break;
   case 66:
    if ($215) {
      __label__ = 67;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 67:
    if ((HEAP32[$vxml_0 + 16 >> 2] | 0) == 0) {
      __label__ = 68;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 68:
    var $289 = __ZL13DeepCopyInLRSP9JSContextP5JSXMLj($cx, $vxml_0);
    if (($289 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 69:
    var $292 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $289);
    if (($292 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    if (($237 | 0) == 0) {
      var $ok_4 = $ok_3;
      __label__ = 72;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 71:
    var $_idx26_val = HEAP32[$237 + 24 >> 2];
    var $_idx27_val = HEAP32[$237 + 32 >> 2];
    var $297 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx26_val, $_idx27_val, $231, 0);
    _OBJECT_TO_JSVAL4318($5, $292);
    var $_idx44 = $5 | 0;
    var $st$7$0 = $_idx44 | 0;
    var $_idx44_val$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $_idx44 + 4 | 0;
    var $_idx44_val$1 = HEAP32[$st$7$1 >> 2];
    var $298 = __ZL7ReplaceP9JSContextP5JSXMLjN2JS5ValueE($cx, $237, $297, $_idx44_val$0, $_idx44_val$1);
    if (($298 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      var $ok_4 = $298;
      __label__ = 72;
      break;
    }
   case 72:
    var $ok_4;
    var $302 = HEAP32[$289 + 24 >> 2];
    if (($302 | 0) == 0) {
      __label__ = 73;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 73:
    __ZL14XMLArrayDeleteP9JSContextP10JSXMLArrayji($81, $i_0, 1);
    var $ok_13 = $ok_4;
    __label__ = 188;
    break;
   case 74:
    var $307 = $302 - 1 | 0;
    var $308 = __ZL14XMLArrayInsertP9JSContextP10JSXMLArrayjj($cx, $81, $i_0 + 1 | 0, $307);
    if (($308 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 75:
    var $310 = $289 + 32 | 0;
    var $j_215 = 0;
    __label__ = 76;
    break;
   case 76:
    var $j_215;
    var $314 = HEAP32[HEAP32[$310 >> 2] + ($j_215 << 2) >> 2];
    var $317 = HEAP32[$228 >> 2] + ($j_215 + $i_0 << 2) | 0;
    HEAP32[$317 >> 2] = $314;
    var $318 = $j_215 + 1 | 0;
    if (($318 | 0) == ($302 | 0)) {
      var $ok_13 = $308;
      __label__ = 188;
      break;
    } else {
      var $j_215 = $318;
      __label__ = 76;
      break;
    }
   case 77:
    if ($240 >>> 0 > 1) {
      __label__ = 78;
      break;
    } else {
      __label__ = 89;
      break;
    }
   case 78:
    if (($237 | 0) == 0) {
      __label__ = 83;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 79:
    var $_idx24 = $237 + 24 | 0;
    var $_idx24_val = HEAP32[$_idx24 >> 2];
    var $_idx25 = $237 + 32 | 0;
    var $_idx25_val = HEAP32[$_idx25 >> 2];
    var $323 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx24_val, $_idx25_val, $231, 0);
    var $st$5$0 = $35 | 0;
    var $324$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $35 + 4 | 0;
    var $324$1 = HEAP32[$st$5$1 >> 2];
    var $325 = __ZL7ReplaceP9JSContextP5JSXMLjN2JS5ValueE($cx, $237, $323, $324$0, $324$1);
    if (($325 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 80:
    if ($323 >>> 0 < HEAPU32[$_idx24 >> 2] >>> 0) {
      __label__ = 81;
      break;
    } else {
      var $ok_13 = $325;
      __label__ = 188;
      break;
    }
   case 81:
    var $333 = HEAPU32[HEAP32[$_idx25 >> 2] + ($323 << 2) >> 2];
    if (($333 | 0) == 0) {
      var $ok_13 = $325;
      __label__ = 188;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 82:
    var $335 = $333;
    var $337 = HEAP32[$333 >> 2];
    _OBJECT_TO_JSVAL4318($6, $337);
    var $338 = $6 | 0;
    var $st$5$0 = $338 | 0;
    var $339$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $338 + 4 | 0;
    var $339$1 = HEAP32[$st$5$1 >> 2];
    var $st$9$0 = $35 | 0;
    HEAP32[$st$9$0 >> 2] = $339$0;
    var $st$9$1 = $35 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $339$1;
    HEAP32[$57 >> 2] = $339$0;
    HEAP32[$57 + 4 >> 2] = $339$1;
    var $vxml_2 = $335;
    var $ok_510 = $325;
    __label__ = 86;
    break;
   case 83:
    if (($vxml_0 | 0) == 0) {
      __label__ = 84;
      break;
    } else {
      var $vxml_2 = $vxml_0;
      var $ok_510 = $ok_3;
      __label__ = 86;
      break;
    }
   case 84:
    var $st$0$0 = $35 | 0;
    var $343$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $35 + 4 | 0;
    var $343$1 = HEAP32[$st$0$1 >> 2];
    var $344 = __ZL5ToXMLP9JSContextN2JS5ValueE($cx, $343$0, $343$1);
    if (($344 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 85:
    _OBJECT_TO_JSVAL4318($7, $344);
    var $347 = $7 | 0;
    var $st$2$0 = $347 | 0;
    var $348$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $347 + 4 | 0;
    var $348$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $35 | 0;
    HEAP32[$st$6$0 >> 2] = $348$0;
    var $st$6$1 = $35 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $348$1;
    var $st$10$0 = $57 | 0;
    HEAP32[$st$10$0 >> 2] = $348$0;
    var $st$10$1 = $57 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $348$1;
    var $_idx1_val = HEAP32[$344 + 24 >> 2];
    var $350 = __ZNK8JSObject10getPrivateEv($_idx1_val);
    var $vxml_2 = $350;
    var $ok_510 = $ok_3;
    __label__ = 86;
    break;
   case 86:
    var $ok_510;
    var $vxml_2;
    if (HEAPU32[$82 >> 2] >>> 0 > $i_0 >>> 0) {
      __label__ = 88;
      break;
    } else {
      __label__ = 87;
      break;
    }
   case 87:
    HEAP32[$82 >> 2] = $i_0 + 1 | 0;
    __label__ = 88;
    break;
   case 88:
    var $359 = HEAP32[$228 >> 2] + ($i_0 << 2) | 0;
    HEAP32[$359 >> 2] = $vxml_2;
    var $ok_13 = $ok_510;
    __label__ = 188;
    break;
   case 89:
    var $361 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $232);
    if (($361 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 90:
    var $368 = HEAP32[HEAP32[$cx + 52 >> 2] + 210412 >> 2] | 0;
    var $369 = __ZL12ATOM_TO_JSIDP6JSAtom4336($368);
    var $370 = __ZL11PutPropertyP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $361, $369, $strict, $vp);
    var $ok_13 = $370;
    __label__ = 188;
    break;
   case 91:
    __ZN2jsL9IdToJsvalEi4431($8, $id);
    var $_idx32 = $8 | 0;
    var $st$2$0 = $_idx32 | 0;
    var $_idx32_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx32 + 4 | 0;
    var $_idx32_val$1 = HEAP32[$st$2$1 >> 2];
    var $372 = __ZL9ToXMLNameP9JSContextN2JS5ValueEPi($cx, $_idx32_val$0, $_idx32_val$1, $funid);
    if (($372 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 92;
      break;
    }
   case 92:
    var $375 = HEAP32[$funid >> 2];
    var $376 = _JSID_IS_VOID4359($375);
    if (($376 | 0) == 0) {
      __label__ = 93;
      break;
    } else {
      __label__ = 94;
      break;
    }
   case 93:
    var $379 = $cx;
    var $380 = $obj;
    var $381 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($379, $380, $375, 0, $vp, 0);
    var $ok_13 = $381;
    __label__ = 188;
    break;
   case 94:
    _OBJECT_TO_JSVAL4318($9, $372);
    var $383 = $9 | 0;
    var $st$2$0 = $383 | 0;
    var $384$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $383 + 4 | 0;
    var $384$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $55 | 0;
    HEAP32[$st$6$0 >> 2] = $384$0;
    var $st$6$1 = $55 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $384$1;
    var $386 = HEAPU32[$32 + 16 >> 2];
    if (($386 | 0) == 0) {
      __label__ = 95;
      break;
    } else {
      var $ok_7 = 1;
      var $xml_0 = $32;
      var $425 = $386;
      __label__ = 106;
      break;
    }
   case 95:
    var $389 = $32 + 24 | 0;
    var $390 = HEAPU32[$389 >> 2];
    if ($390 >>> 0 > 1) {
      __label__ = 189;
      break;
    } else {
      __label__ = 96;
      break;
    }
   case 96:
    if (($390 | 0) == 0) {
      __label__ = 97;
      break;
    } else {
      var $ok_661 = 1;
      __label__ = 103;
      break;
    }
   case 97:
    var $395 = __ZL12ResolveValueP9JSContextP5JSXMLPS2_($cx, $32, $rxml);
    if (($395 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 98;
      break;
    }
   case 98:
    var $398 = HEAPU32[$rxml >> 2];
    if (($398 | 0) == 0) {
      __label__ = 189;
      break;
    } else {
      __label__ = 99;
      break;
    }
   case 99:
    if (HEAPU32[$398 + 16 >> 2] >>> 0 < 2) {
      __label__ = 100;
      break;
    } else {
      __label__ = 189;
      break;
    }
   case 100:
    if ((HEAP32[$398 + 24 >> 2] | 0) == 1) {
      __label__ = 101;
      break;
    } else {
      __label__ = 189;
      break;
    }
   case 101:
    var $408 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $32, $398);
    if (($408 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 102:
    if ((HEAP32[$389 >> 2] | 0) == 0) {
      var $ok_13 = $408;
      __label__ = 188;
      break;
    } else {
      var $ok_661 = $408;
      __label__ = 103;
      break;
    }
   case 103:
    var $ok_661;
    var $414 = HEAPU32[HEAP32[$32 + 32 >> 2] >> 2];
    var $415 = $414;
    if (($414 | 0) == 0) {
      var $ok_13 = $ok_661;
      __label__ = 188;
      break;
    } else {
      __label__ = 104;
      break;
    }
   case 104:
    var $418 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $415);
    if (($418 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 105;
      break;
    }
   case 105:
    _OBJECT_TO_JSVAL4318($10, $418);
    var $421 = $10 | 0;
    var $st$2$0 = $421 | 0;
    var $422$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $421 + 4 | 0;
    var $422$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $52 | 0;
    HEAP32[$st$6$0 >> 2] = $422$0;
    var $st$6$1 = $52 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $422$1;
    var $ok_7 = $ok_661;
    var $xml_0 = $415;
    var $425 = HEAP32[$414 + 16 >> 2];
    __label__ = 106;
    break;
   case 106:
    var $425;
    var $xml_0;
    var $ok_7;
    if ($425 >>> 0 > 1) {
      var $ok_13 = $ok_7;
      __label__ = 188;
      break;
    } else {
      __label__ = 107;
      break;
    }
   case 107:
    if (($vxml_0 | 0) == 0) {
      __label__ = 109;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 108:
    var $431 = HEAP32[$vxml_0 + 16 >> 2];
    if (($431 | 0) == 4 || ($431 | 0) == 2) {
      __label__ = 109;
      break;
    } else {
      __label__ = 111;
      break;
    }
   case 109:
    var $st$0$0 = $35 | 0;
    var $433$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $35 + 4 | 0;
    var $433$1 = HEAP32[$st$0$1 >> 2];
    var $434 = _JS_ConvertValue($58, $433$0, $433$1, 3, $vp);
    if (($434 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 110;
      break;
    }
   case 110:
    var $st$0$0 = $35 | 0;
    var $st$0$1 = $35 + 4 | 0;
    var $vxml_3 = $vxml_0;
    var $448$1 = HEAP32[$st$0$1 >> 2];
    var $448$0 = HEAP32[$st$0$0 >> 2];
    __label__ = 114;
    break;
   case 111:
    var $437 = __ZL13DeepCopyInLRSP9JSContextP5JSXMLj($cx, $vxml_0);
    HEAP32[$rxml >> 2] = $437;
    if (($437 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 112;
      break;
    }
   case 112:
    var $440 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $437);
    if (($440 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 113:
    var $444 = HEAP32[$437 >> 2];
    _OBJECT_TO_JSVAL4318($11, $444);
    var $445 = $11 | 0;
    var $st$4$0 = $445 | 0;
    var $446$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $445 + 4 | 0;
    var $446$1 = HEAP32[$st$4$1 >> 2];
    HEAP32[$35 >> 2] = $446$0;
    HEAP32[$35 + 4 >> 2] = $446$1;
    var $vxml_3 = $437;
    var $448$1 = $446$1;
    var $448$0 = $446$0;
    __label__ = 114;
    break;
   case 114:
    var $448$0;
    var $448$1;
    var $vxml_3;
    var $st$3$0 = $57 | 0;
    HEAP32[$st$3$0 >> 2] = $448$0;
    var $st$3$1 = $57 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $448$1;
    var $449 = __Z25js_GetDefaultXMLNamespaceP9JSContextPN2JS5ValueE($cx, $nsval);
    if (($449 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 115;
      break;
    }
   case 115:
    var $_idx6_val = HEAP32[$372 + 4 >> 2];
    var $453 = __ZNK8JSObject8getClassEv($_idx6_val);
    if (($453 | 0) == (__ZN2js18AttributeNameClassE | 0)) {
      __label__ = 116;
      break;
    } else {
      __label__ = 152;
      break;
    }
   case 116:
    _OBJECT_TO_JSVAL4318($12, $372);
    var $_idx46 = $12 | 0;
    var $st$2$0 = $_idx46 | 0;
    var $_idx46_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx46 + 4 | 0;
    var $_idx46_val$1 = HEAP32[$st$2$1 >> 2];
    var $456 = __Z12js_IsXMLNameP9JSContextN2JS5ValueE($cx, $_idx46_val$0, $_idx46_val$1);
    if (($456 | 0) == 0) {
      var $ok_13 = $449;
      __label__ = 188;
      break;
    } else {
      __label__ = 117;
      break;
    }
   case 117:
    if (($vxml_3 | 0) == 0) {
      __label__ = 129;
      break;
    } else {
      __label__ = 118;
      break;
    }
   case 118:
    if ((HEAP32[$vxml_3 + 16 >> 2] | 0) == 0) {
      __label__ = 119;
      break;
    } else {
      __label__ = 129;
      break;
    }
   case 119:
    var $466 = HEAPU32[$vxml_3 + 24 >> 2];
    if (($466 | 0) == 0) {
      __label__ = 120;
      break;
    } else {
      __label__ = 121;
      break;
    }
   case 120:
    var $473 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    _STRING_TO_JSVAL4322($13, $473);
    var $474 = $13 | 0;
    var $st$7$0 = $474 | 0;
    var $475$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $474 + 4 | 0;
    var $475$1 = HEAP32[$st$7$1 >> 2];
    HEAP32[$35 >> 2] = $475$0;
    HEAP32[$35 + 4 >> 2] = $475$1;
    var $ok_8 = $449;
    __label__ = 131;
    break;
   case 121:
    var $477 = __ZL11KidToStringP9JSContextP5JSXMLj($cx, $vxml_3, 0);
    if (($477 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 122;
      break;
    }
   case 122:
    var $484 = HEAP32[HEAP32[$cx + 52 >> 2] + 210404 >> 2] | 0;
    var $left_0 = $477;
    var $i_1 = 1;
    __label__ = 123;
    break;
   case 123:
    var $i_1;
    var $left_0;
    if ($i_1 >>> 0 < $466 >>> 0) {
      __label__ = 124;
      break;
    } else {
      __label__ = 128;
      break;
    }
   case 124:
    var $488 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($58, $left_0, $484);
    if (($488 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 125;
      break;
    }
   case 125:
    var $491 = __ZL11KidToStringP9JSContextP5JSXMLj($cx, $vxml_3, $i_1);
    if (($491 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 126;
      break;
    }
   case 126:
    var $494 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($58, $488, $491);
    if (($494 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 127:
    var $left_0 = $494;
    var $i_1 = $i_1 + 1 | 0;
    __label__ = 123;
    break;
   case 128:
    _STRING_TO_JSVAL4322($14, $left_0);
    var $499 = $14 | 0;
    var $st$2$0 = $499 | 0;
    var $500$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $499 + 4 | 0;
    var $500$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $35 | 0;
    HEAP32[$st$6$0 >> 2] = $500$0;
    var $st$6$1 = $35 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $500$1;
    var $st$10$0 = $57 | 0;
    HEAP32[$st$10$0 >> 2] = $500$0;
    var $st$10$1 = $57 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $500$1;
    var $ok_8 = $449;
    __label__ = 131;
    break;
   case 129:
    var $st$0$0 = $35 | 0;
    var $502$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $35 + 4 | 0;
    var $502$1 = HEAP32[$st$0$1 >> 2];
    var $503 = _JS_ConvertValue($58, $502$0, $502$1, 3, $vp);
    if (($503 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 130;
      break;
    }
   case 130:
    var $st$0$0 = $35 | 0;
    var $506$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $35 + 4 | 0;
    var $506$1 = HEAP32[$st$0$1 >> 2];
    var $st$4$0 = $57 | 0;
    HEAP32[$st$4$0 >> 2] = $506$0;
    var $st$4$1 = $57 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $506$1;
    var $ok_8 = $503;
    __label__ = 131;
    break;
   case 131:
    var $ok_8;
    var $508 = $xml_0 + 56 | 0;
    var $509 = $508 | 0;
    var $510 = HEAPU32[$509 >> 2];
    if (($510 | 0) == 0) {
      __label__ = 143;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 132:
    var $512 = $xml_0 + 64 | 0;
    var $i_219 = 0;
    var $match_020 = 0;
    var $514 = $510;
    __label__ = 133;
    break;
   case 133:
    var $514;
    var $match_020;
    var $i_219;
    if ($i_219 >>> 0 < $514 >>> 0) {
      __label__ = 134;
      break;
    } else {
      var $match_1 = $match_020;
      var $i_3 = $i_219;
      __label__ = 140;
      break;
    }
   case 134:
    var $519 = HEAPU32[HEAP32[$512 >> 2] + ($i_219 << 2) >> 2];
    var $520 = $519;
    if (($519 | 0) == 0) {
      var $match_1 = $match_020;
      var $i_3 = $i_219;
      __label__ = 140;
      break;
    } else {
      __label__ = 135;
      break;
    }
   case 135:
    var $525 = HEAPU32[$519 + 12 >> 2];
    var $526 = __ZNK8JSObject17getQNameLocalNameEv($525);
    var $527 = $526 | 0;
    var $528 = __ZNK8JSObject17getQNameLocalNameEv($372);
    var $529 = $528 | 0;
    var $530 = __ZN2js12EqualStringsEP14JSLinearStringS1_($527, $529);
    if ($530) {
      __label__ = 136;
      break;
    } else {
      var $match_1 = $match_020;
      var $i_3 = $i_219;
      __label__ = 140;
      break;
    }
   case 136:
    var $532 = __ZNK8JSObject10getNameURIEv($372);
    if (($532 | 0) == 0) {
      __label__ = 138;
      break;
    } else {
      __label__ = 137;
      break;
    }
   case 137:
    var $535 = __ZNK8JSObject10getNameURIEv($525);
    var $536 = __ZN2js12EqualStringsEP14JSLinearStringS1_($535, $532);
    if ($536) {
      __label__ = 138;
      break;
    } else {
      var $match_1 = $match_020;
      var $i_3 = $i_219;
      __label__ = 140;
      break;
    }
   case 138:
    if (($match_020 | 0) == 0) {
      var $match_1 = $520;
      var $i_3 = $i_219;
      __label__ = 140;
      break;
    } else {
      __label__ = 139;
      break;
    }
   case 139:
    __ZL19DeleteNamedPropertyP9JSContextP5JSXMLP8JSObjecti($xml_0, $525, 1);
    var $match_1 = $match_020;
    var $i_3 = $i_219 - 1 | 0;
    __label__ = 140;
    break;
   case 140:
    var $i_3;
    var $match_1;
    var $541 = $i_3 + 1 | 0;
    if ($541 >>> 0 < $510 >>> 0) {
      __label__ = 141;
      break;
    } else {
      __label__ = 142;
      break;
    }
   case 141:
    var $i_219 = $541;
    var $match_020 = $match_1;
    var $514 = HEAP32[$509 >> 2];
    __label__ = 133;
    break;
   case 142:
    if (($match_1 | 0) == 0) {
      __label__ = 143;
      break;
    } else {
      var $ok_9 = $ok_8;
      var $attr_0 = $match_1;
      __label__ = 151;
      break;
    }
   case 143:
    var $544 = __ZNK8JSObject10getNameURIEv($372);
    if (($544 | 0) == 0) {
      __label__ = 144;
      break;
    } else {
      __label__ = 145;
      break;
    }
   case 144:
    var $551 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    var $right3_0 = $551;
    var $left2_0 = $551;
    __label__ = 146;
    break;
   case 145:
    var $553 = __ZNK8JSObject13getNamePrefixEv($372);
    var $right3_0 = $553;
    var $left2_0 = $544;
    __label__ = 146;
    break;
   case 146:
    var $left2_0;
    var $right3_0;
    var $555 = __ZNK8JSObject17getQNameLocalNameEv($372);
    var $556 = __ZL11NewXMLQNameP9JSContextP14JSLinearStringS2_P6JSAtom($cx, $left2_0, $right3_0, $555);
    if (($556 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 147;
      break;
    }
   case 147:
    var $559 = __Z9js_NewXMLP9JSContext10JSXMLClass($cx, 2);
    if (($559 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 148;
      break;
    }
   case 148:
    HEAP32[$559 + 8 >> 2] = $xml_0;
    HEAP32[$559 + 12 >> 2] = $556;
    var $564 = $559;
    var $565 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $508, $510, $564);
    if (($565 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 149;
      break;
    }
   case 149:
    var $568 = __ZL12GetNamespaceP9JSContextP8JSObjectPK10JSXMLArray($cx, $556, 0);
    if (($568 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 150;
      break;
    }
   case 150:
    var $571 = __ZL19AddInScopeNamespaceP9JSContextP5JSXMLP8JSObject($cx, $xml_0, $568);
    if (($571 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      var $ok_9 = $571;
      var $attr_0 = $559;
      __label__ = 151;
      break;
    }
   case 151:
    var $attr_0;
    var $ok_9;
    var $st$2$0 = $35 | 0;
    var $573$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $35 + 4 | 0;
    var $573$1 = HEAP32[$st$2$1 >> 2];
    var $574 = _JSVAL_TO_STRING4321($573$0, $573$1);
    var $_c = $574;
    HEAP32[$attr_0 + 24 >> 2] = $_c;
    var $ok_13 = $ok_9;
    __label__ = 188;
    break;
   case 152:
    _OBJECT_TO_JSVAL4318($15, $372);
    var $_idx45 = $15 | 0;
    var $st$2$0 = $_idx45 | 0;
    var $_idx45_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx45 + 4 | 0;
    var $_idx45_val$1 = HEAP32[$st$2$1 >> 2];
    var $577 = __Z12js_IsXMLNameP9JSContextN2JS5ValueE($cx, $_idx45_val$0, $_idx45_val$1);
    if (($577 | 0) == 0) {
      __label__ = 153;
      break;
    } else {
      __label__ = 155;
      break;
    }
   case 153:
    var $580 = __ZNK8JSObject17getQNameLocalNameEv($372);
    var $_idx10_val = HEAP32[$580 >> 2];
    var $581 = __ZNK8JSString6lengthEv($_idx10_val);
    if (($581 | 0) == 1) {
      __label__ = 154;
      break;
    } else {
      var $ok_13 = $449;
      __label__ = 188;
      break;
    }
   case 154:
    var $_idx13_val = HEAP32[$580 + 4 >> 2];
    var $584 = __ZNK14JSLinearString5charsEv($_idx13_val);
    if (HEAP16[$584 >> 1] << 16 >> 16 == 42) {
      __label__ = 155;
      break;
    } else {
      var $ok_13 = $449;
      __label__ = 188;
      break;
    }
   case 155:
    if (($vxml_3 | 0) == 0) {
      __label__ = 156;
      break;
    } else {
      var $597 = 0;
      __label__ = 158;
      break;
    }
   case 156:
    var $590 = __ZNK8JSObject17getQNameLocalNameEv($372);
    var $_idx9_val = HEAP32[$590 >> 2];
    var $591 = __ZNK8JSString6lengthEv($_idx9_val);
    if (($591 | 0) == 1) {
      __label__ = 157;
      break;
    } else {
      var $597 = 1;
      __label__ = 158;
      break;
    }
   case 157:
    var $_idx12_val = HEAP32[$590 + 4 >> 2];
    var $594 = __ZNK14JSLinearString5charsEv($_idx12_val);
    var $597 = HEAP16[$594 >> 1] << 16 >> 16 != 42;
    __label__ = 158;
    break;
   case 158:
    var $597;
    var $598 = $xml_0 + 24 | 0;
    var $599 = $598 | 0;
    var $600 = HEAPU32[$599 >> 2];
    var $601 = $xml_0 + 32 | 0;
    var $kid2_0_ph = 0;
    var $matchIndex_0_ph = -1;
    var $k_0_ph = $600;
    __label__ = 159;
    break;
   case 159:
    var $k_0_ph;
    var $matchIndex_0_ph;
    var $kid2_0_ph;
    var $k_0 = $k_0_ph;
    __label__ = 160;
    break;
   case 160:
    var $k_0;
    if (($k_0 | 0) == 0) {
      __label__ = 166;
      break;
    } else {
      __label__ = 161;
      break;
    }
   case 161:
    var $604 = $k_0 - 1 | 0;
    if ($604 >>> 0 < HEAPU32[$599 >> 2] >>> 0) {
      __label__ = 162;
      break;
    } else {
      var $k_0 = $604;
      __label__ = 160;
      break;
    }
   case 162:
    var $610 = HEAP32[HEAP32[$601 >> 2] + ($604 << 2) >> 2];
    var $611 = $610;
    if (($610 | 0) == 0) {
      var $k_0 = $604;
      __label__ = 160;
      break;
    } else {
      __label__ = 163;
      break;
    }
   case 163:
    var $614 = __ZL13MatchElemNameP8JSObjectP5JSXML($372, $611);
    if (($614 | 0) == 0) {
      var $k_0 = $604;
      __label__ = 160;
      break;
    } else {
      __label__ = 164;
      break;
    }
   case 164:
    if (($matchIndex_0_ph | 0) == -1) {
      var $kid2_0_ph = $611;
      var $matchIndex_0_ph = $604;
      var $k_0_ph = $604;
      __label__ = 159;
      break;
    } else {
      __label__ = 165;
      break;
    }
   case 165:
    __ZL13DeleteByIndexP9JSContextP5JSXMLj($xml_0, $matchIndex_0_ph);
    var $kid2_0_ph = $611;
    var $matchIndex_0_ph = $604;
    var $k_0_ph = $604;
    __label__ = 159;
    break;
   case 166:
    if (($kid2_0_ph | 0) == 0) {
      __label__ = 169;
      break;
    } else {
      __label__ = 167;
      break;
    }
   case 167:
    var $622 = $kid2_0_ph + 8 | 0;
    if ((HEAP32[$622 >> 2] | 0) == 0) {
      __label__ = 168;
      break;
    } else {
      __label__ = 169;
      break;
    }
   case 168:
    HEAP32[$622 >> 2] = $xml_0;
    __label__ = 169;
    break;
   case 169:
    var $_not = ($matchIndex_0_ph | 0) != -1;
    var $matchIndex_0_mux = $_not ? $matchIndex_0_ph : $600;
    if ($_not | $597 ^ 1) {
      var $ok_10 = $449;
      var $matchIndex_1 = $matchIndex_0_mux;
      __label__ = 178;
      break;
    } else {
      __label__ = 170;
      break;
    }
   case 170:
    var $628 = __ZNK8JSObject10getNameURIEv($372);
    if (($628 | 0) == 0) {
      __label__ = 171;
      break;
    } else {
      __label__ = 172;
      break;
    }
   case 171:
    var $631 = $nsval | 0;
    var $st$1$0 = $631 | 0;
    var $632$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $631 + 4 | 0;
    var $632$1 = HEAP32[$st$1$1 >> 2];
    var $633 = _JSVAL_TO_OBJECT4304($632$0, $632$1);
    var $634 = __ZNK8JSObject10getNameURIEv($633);
    var $635 = __ZNK8JSObject13getNamePrefixEv($633);
    var $right6_0 = $635;
    var $left5_0 = $634;
    __label__ = 173;
    break;
   case 172:
    var $637 = __ZNK8JSObject13getNamePrefixEv($372);
    var $right6_0 = $637;
    var $left5_0 = $628;
    __label__ = 173;
    break;
   case 173:
    var $left5_0;
    var $right6_0;
    var $639 = __ZNK8JSObject17getQNameLocalNameEv($372);
    var $640 = __ZL11NewXMLQNameP9JSContextP14JSLinearStringS2_P6JSAtom($cx, $left5_0, $right6_0, $639);
    if (($640 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 174;
      break;
    }
   case 174:
    var $643 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 1);
    if (($643 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 175;
      break;
    }
   case 175:
    var $_idx_val = HEAP32[$643 + 24 >> 2];
    var $647 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $648 = $647;
    var $650 = $647 + 8 | 0;
    HEAP32[$650 >> 2] = $xml_0;
    var $652 = $647 + 12 | 0;
    HEAP32[$652 >> 2] = $640;
    var $653 = __ZL12GetNamespaceP9JSContextP8JSObjectPK10JSXMLArray($cx, $640, 0);
    if (($653 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 176;
      break;
    }
   case 176:
    _OBJECT_TO_JSVAL4318($16, $643);
    var $_idx42 = $16 | 0;
    var $st$2$0 = $_idx42 | 0;
    var $_idx42_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx42 + 4 | 0;
    var $_idx42_val$1 = HEAP32[$st$2$1 >> 2];
    var $656 = __ZL7ReplaceP9JSContextP5JSXMLjN2JS5ValueE($cx, $xml_0, $600, $_idx42_val$0, $_idx42_val$1);
    if (($656 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 177;
      break;
    }
   case 177:
    var $659 = __ZL19AddInScopeNamespaceP9JSContextP5JSXMLP8JSObject($cx, $648, $653);
    if (($659 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      var $ok_10 = $659;
      var $matchIndex_1 = $600;
      __label__ = 178;
      break;
    }
   case 178:
    var $matchIndex_1;
    var $ok_10;
    if ($597) {
      __label__ = 179;
      break;
    } else {
      __label__ = 187;
      break;
    }
   case 179:
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor, $598);
    HEAP32[$cursor + 4 >> 2] = $matchIndex_1;
    var $664 = __ZN16JSXMLArrayCursor10getCurrentEv($cursor);
    var $665 = $664;
    if (HEAPU32[$664 + 16 >> 2] >>> 0 < 2) {
      __label__ = 180;
      break;
    } else {
      var $ok_11 = $ok_10;
      __label__ = 181;
      break;
    }
   case 180:
    var $672 = $664 + 24 | 0;
    __ZN10JSXMLArray6finishEP9JSContext($672);
    __ZN10JSXMLArray4initEv($672);
    var $673 = __ZN10JSXMLArray11setCapacityEP9JSContextj($672, $cx, 1);
    var $ok_11 = $673 & 1;
    __label__ = 181;
    break;
   case 181:
    var $ok_11;
    if (($ok_11 | 0) == 0) {
      var $ok_12 = 0;
      __label__ = 186;
      break;
    } else {
      __label__ = 182;
      break;
    }
   case 182:
    var $st$0$0 = $35 | 0;
    var $678$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $35 + 4 | 0;
    var $678$1 = HEAP32[$st$0$1 >> 2];
    var $679 = _JS_ConvertValue($58, $678$0, $678$1, 3, $vp);
    if (($679 | 0) == 0) {
      var $ok_12 = 0;
      __label__ = 186;
      break;
    } else {
      __label__ = 183;
      break;
    }
   case 183:
    var $st$0$0 = $35 | 0;
    var $682$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $35 + 4 | 0;
    var $682$1 = HEAP32[$st$0$1 >> 2];
    var $683 = _JSVAL_TO_STRING4321($682$0, $682$1);
    var $_idx30_val = HEAP32[$683 >> 2];
    var $684 = __ZNK8JSString5emptyEv($_idx30_val);
    if ($684) {
      var $ok_12 = $679;
      __label__ = 186;
      break;
    } else {
      __label__ = 184;
      break;
    }
   case 184:
    var $st$0$0 = $35 | 0;
    var $686$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $35 + 4 | 0;
    var $686$1 = HEAP32[$st$0$1 >> 2];
    var $st$4$0 = $57 | 0;
    HEAP32[$st$4$0 >> 2] = $686$0;
    var $st$4$1 = $57 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $686$1;
    var $687 = __ZN16JSXMLArrayCursor10getCurrentEv($cursor);
    if (($687 | 0) == ($664 | 0)) {
      __label__ = 185;
      break;
    } else {
      var $ok_12 = $679;
      __label__ = 186;
      break;
    }
   case 185:
    var $st$0$0 = $35 | 0;
    var $690$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $35 + 4 | 0;
    var $690$1 = HEAP32[$st$0$1 >> 2];
    var $691 = __ZL7ReplaceP9JSContextP5JSXMLjN2JS5ValueE($cx, $665, 0, $690$0, $690$1);
    var $ok_12 = $691;
    __label__ = 186;
    break;
   case 186:
    var $ok_12;
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $ok_13 = $ok_12;
    __label__ = 188;
    break;
   case 187:
    var $st$0$0 = $35 | 0;
    var $694$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $35 + 4 | 0;
    var $694$1 = HEAP32[$st$0$1 >> 2];
    var $695 = __ZL7ReplaceP9JSContextP5JSXMLjN2JS5ValueE($cx, $xml_0, $matchIndex_1, $694$0, $694$1);
    var $ok_13 = $695;
    __label__ = 188;
    break;
   case 188:
    var $ok_13;
    __ZN2js15AutoArrayRooterD1Ev($tvr);
    var $_0 = $ok_13;
    __label__ = 192;
    break;
   case 189:
    __ZN16JSAutoByteStringC1Ev($bytes);
    __ZN2jsL9IdToValueEi4432($17, $id);
    var $696 = $cx;
    var $697 = $bytes;
    var $_idx33 = $17 | 0;
    var $st$5$0 = $_idx33 | 0;
    var $_idx33_val$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $_idx33 + 4 | 0;
    var $_idx33_val$1 = HEAP32[$st$5$1 >> 2];
    var $698 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($696, $_idx33_val$0, $_idx33_val$1, $697);
    var $bytes_idx_val_pre = HEAP32[$bytes >> 2];
    if (($698 | 0) == 0) {
      __label__ = 191;
      break;
    } else {
      __label__ = 190;
      break;
    }
   case 190:
    var $701 = __ZNK16JSAutoByteString3ptrEv($bytes_idx_val_pre);
    _JS_ReportErrorNumber($58, 4, 194, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $701, tempInt));
    __label__ = 191;
    break;
   case 191:
    __ZN16JSAutoByteStringD1Ev($bytes_idx_val_pre);
    var $ok_13 = 0;
    __label__ = 188;
    break;
   case 192:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11PutPropertyP9JSContextP8JSObjectiiPN2JS5ValueE["X"] = 1;

function __ZN16JSXMLArrayCursor10getCurrentEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this >> 2];
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAPU32[$this + 4 >> 2];
    if ($6 >>> 0 < HEAPU32[$2 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $14 = HEAP32[HEAP32[$2 + 8 >> 2] + ($6 << 2) >> 2];
    HEAP32[$this + 16 >> 2] = $14;
    var $_0 = $14;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9IdToJsvalEi4431($agg_result, $id) {
  __ZN2jsL9IdToValueEi4432($agg_result, $id);
  return;
}

function __ZN2jsL9IdToValueEi4432($agg_result, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_STRING4403($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_STRING4405($id);
    __ZN2JSL11StringValueEP8JSString4311($agg_result, $4);
    __label__ = 8;
    break;
   case 3:
    var $6 = _JSID_IS_INT4401($id);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _JSID_TO_INT4402($id);
    __ZN2JSL10Int32ValueEi4433($agg_result, $9);
    __label__ = 8;
    break;
   case 5:
    var $11 = _JSID_IS_OBJECT4314($id);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = _JSID_TO_OBJECT4315($id);
    __ZN2JSL11ObjectValueER8JSObject4319($agg_result, $14);
    __label__ = 8;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv4406($agg_result);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12ResolveValueP9JSContextP5JSXMLPS2_($cx, $list, $result) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $base = __stackBase__;
    var $tv = __stackBase__ + 4;
    var $1 = __stackBase__ + 12;
    if ((HEAP32[$list + 16 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    if ((HEAP32[$list + 24 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $list);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$result >> 2] = $list;
    var $_0 = 1;
    __label__ = 25;
    break;
   case 5:
    var $16 = HEAP32[$list + 40 >> 2];
    var $19 = HEAP32[$list + 44 >> 2];
    if (($16 | 0) == 0 | ($19 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = __ZNK8JSObject17getQNameLocalNameEv($19);
    var $_idx3_val = HEAP32[$23 >> 2];
    var $24 = __ZNK8JSString6lengthEv($_idx3_val);
    if (($24 | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $_idx4_val = HEAP32[$23 + 4 >> 2];
    var $27 = __ZNK14JSLinearString5charsEv($_idx4_val);
    if (HEAP16[$27 >> 1] << 16 >> 16 == 42) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    HEAP32[$result >> 2] = 0;
    var $_0 = 1;
    __label__ = 25;
    break;
   case 9:
    var $_idx2_val = HEAP32[$19 + 4 >> 2];
    var $33 = __ZNK8JSObject8getClassEv($_idx2_val);
    if (($33 | 0) == (__ZN2js18AttributeNameClassE | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    HEAP32[$result >> 2] = 0;
    var $_0 = 1;
    __label__ = 25;
    break;
   case 11:
    var $37 = __ZL12ResolveValueP9JSContextP5JSXMLPS2_($cx, $16, $base);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $40 = HEAPU32[$base >> 2];
    if (($40 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    HEAP32[$result >> 2] = 0;
    var $_0 = 1;
    __label__ = 25;
    break;
   case 14:
    var $44 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $40);
    if (($44 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $47 = _OBJECT_TO_JSID4356($19);
    var $48 = $40 | 0;
    var $49 = HEAP32[$48 >> 2];
    var $50 = __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $49, $47, $tv);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $53 = $tv | 0;
    var $54$0 = HEAP32[$53 >> 2];
    var $54$1 = HEAP32[$53 + 4 >> 2];
    var $55 = _JSVAL_TO_OBJECT4304($54$0, $54$1);
    var $_idx1_val = HEAP32[$55 + 24 >> 2];
    var $57 = __ZNK8JSObject10getPrivateEv($_idx1_val);
    if (HEAPU32[$57 + 16 >> 2] >>> 0 < 2) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    if ((HEAP32[$57 + 24 >> 2] | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      var $target_0_in = $57;
      __label__ = 24;
      break;
    }
   case 18:
    if ((HEAP32[$40 + 16 >> 2] | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 19:
    if (HEAPU32[$40 + 24 >> 2] >>> 0 > 1) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[$result >> 2] = 0;
    var $_0 = 1;
    __label__ = 25;
    break;
   case 21:
    var $77 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    _STRING_TO_JSVAL4322($1, $77);
    var $78 = $1 | 0;
    var $79$0 = HEAP32[$78 >> 2];
    var $79$1 = HEAP32[$78 + 4 >> 2];
    HEAP32[$53 >> 2] = $79$0;
    HEAP32[$53 + 4 >> 2] = $79$1;
    var $80 = HEAP32[$48 >> 2];
    var $81 = __ZL11PutPropertyP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $80, $47, 0, $tv);
    if (($81 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $84 = HEAP32[$48 >> 2];
    var $85 = __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $84, $47, $tv);
    if (($85 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $88$0 = HEAP32[$53 >> 2];
    var $88$1 = HEAP32[$53 + 4 >> 2];
    var $89 = _JSVAL_TO_OBJECT4304($88$0, $88$1);
    var $_idx_val = HEAP32[$89 + 24 >> 2];
    var $91 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $target_0_in = $91;
    __label__ = 24;
    break;
   case 24:
    var $target_0_in;
    HEAP32[$result >> 2] = $target_0_in;
    var $_0 = 1;
    __label__ = 25;
    break;
   case 25:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12ResolveValueP9JSContextP5JSXMLPS2_["X"] = 1;

function __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $funid = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 24;
    var $roots = __stackBase__ + 32;
    var $tvr = __stackBase__ + 48;
    var $4 = __stackBase__ + 64;
    var $5 = __stackBase__ + 72;
    var $_idx2_val = HEAP32[$obj + 4 >> 2];
    var $7 = __ZNK8JSObject5isXMLEv($_idx2_val);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 1;
      __label__ = 22;
      break;
    }
   case 2:
    var $_idx1_val = HEAP32[$obj + 24 >> 2];
    var $10 = __ZNK8JSObject10getPrivateEv($_idx1_val);
    var $11 = $10;
    if (($10 | 0) == 0) {
      var $_1 = 1;
      __label__ = 22;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = __Z12js_IdIsIndexiPj($id, $index);
    if (($14 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $21 = HEAPU32[$index >> 2];
    if (HEAPU32[$10 + 16 >> 2] >>> 0 < 2) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($21 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    _OBJECT_TO_JSVAL4318($1, $obj);
    var $_phi_trans_insert = $1 | 0;
    var $st$2$0 = $_phi_trans_insert | 0;
    var $st$2$1 = $_phi_trans_insert + 4 | 0;
    var $29$1 = HEAP32[$st$2$1 >> 2];
    var $29$0 = HEAP32[$st$2$0 >> 2];
    __label__ = 8;
    break;
   case 7:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $26$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $26$1 = HEAP32[$st$1$1 >> 2];
    var $27 = $1 | 0;
    var $st$6$0 = $27 | 0;
    HEAP32[$st$6$0 >> 2] = $26$0;
    var $st$6$1 = $27 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $26$1;
    var $29$1 = $26$1;
    var $29$0 = $26$0;
    __label__ = 8;
    break;
   case 8:
    var $29$0;
    var $29$1;
    var $30 = $vp | 0;
    var $st$3$0 = $30 | 0;
    HEAP32[$st$3$0 >> 2] = $29$0;
    var $st$3$1 = $30 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $29$1;
    var $_1 = 1;
    __label__ = 22;
    break;
   case 9:
    if ($21 >>> 0 < HEAPU32[$10 + 24 >> 2] >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 10:
    var $41 = HEAPU32[HEAP32[$10 + 32 >> 2] + ($21 << 2) >> 2];
    if (($41 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $$emscripten$temp$1 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$1 | 0;
    var $44$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$1 + 4 | 0;
    var $44$1 = HEAP32[$st$1$1 >> 2];
    var $45 = $vp | 0;
    var $st$6$0 = $45 | 0;
    HEAP32[$st$6$0 >> 2] = $44$0;
    var $st$6$1 = $45 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $44$1;
    var $_1 = 1;
    __label__ = 22;
    break;
   case 12:
    var $47 = $41;
    var $48 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $47);
    if (($48 | 0) == 0) {
      var $_1 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    _OBJECT_TO_JSVAL4318($2, $48);
    var $51 = $2 | 0;
    var $st$2$0 = $51 | 0;
    var $52$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $51 + 4 | 0;
    var $52$1 = HEAP32[$st$2$1 >> 2];
    var $53 = $vp | 0;
    HEAP32[$53 >> 2] = $52$0;
    HEAP32[$53 + 4 >> 2] = $52$1;
    var $_1 = 1;
    __label__ = 22;
    break;
   case 14:
    var $$emscripten$temp$2 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$2 | 0;
    var $55$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$2 + 4 | 0;
    var $55$1 = HEAP32[$st$1$1 >> 2];
    var $56 = $vp | 0;
    var $st$6$0 = $56 | 0;
    HEAP32[$st$6$0 >> 2] = $55$0;
    var $st$6$1 = $56 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $55$1;
    var $_1 = 1;
    __label__ = 22;
    break;
   case 15:
    __ZN2jsL9IdToJsvalEi4431($3, $id);
    var $_idx3 = $3 | 0;
    var $st$2$0 = $_idx3 | 0;
    var $_idx3_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx3 + 4 | 0;
    var $_idx3_val$1 = HEAP32[$st$2$1 >> 2];
    var $58 = __ZL9ToXMLNameP9JSContextN2JS5ValueEPi($cx, $_idx3_val$0, $_idx3_val$1, $funid);
    if (($58 | 0) == 0) {
      var $_1 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $61 = HEAP32[$funid >> 2];
    var $62 = _JSID_IS_VOID4359($61);
    if (($62 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $65 = __ZL14GetXMLFunctionP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $61, $vp);
    var $_1 = $65;
    __label__ = 22;
    break;
   case 18:
    var $67 = $roots | 0;
    _OBJECT_TO_JSVAL4318($67, $58);
    var $$emscripten$temp$3 = _JSVAL_NULL | 0;
    var $st$3$0 = $$emscripten$temp$3 | 0;
    var $68$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $$emscripten$temp$3 + 4 | 0;
    var $68$1 = HEAP32[$st$3$1 >> 2];
    var $69 = $roots + 8 | 0;
    var $st$8$0 = $69 | 0;
    HEAP32[$st$8$0 >> 2] = $68$0;
    var $st$8$1 = $69 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $68$1;
    var $70 = $cx;
    __ZN2js15AutoArrayRooterC1EP9JSContextjPN2JS5ValueE($tvr, $70, 2, $67);
    var $71 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 0);
    if (($71 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    _OBJECT_TO_JSVAL4318($4, $71);
    var $74 = $4 | 0;
    var $st$2$0 = $74 | 0;
    var $75$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $74 + 4 | 0;
    var $75$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $69 | 0;
    HEAP32[$st$6$0 >> 2] = $75$0;
    var $st$6$1 = $69 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $75$1;
    var $_idx_val = HEAP32[$71 + 24 >> 2];
    var $77 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $78 = $77;
    var $79 = __ZL16GetNamedPropertyP9JSContextP5JSXMLP8JSObjectS2_($cx, $11, $58, $78);
    if (($79 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $83 = $77 + 40 | 0;
    HEAP32[$83 >> 2] = $11;
    var $85 = $77 + 44 | 0;
    HEAP32[$85 >> 2] = $58;
    _OBJECT_TO_JSVAL4318($5, $71);
    var $86 = $5 | 0;
    var $st$8$0 = $86 | 0;
    var $87$0 = HEAP32[$st$8$0 >> 2];
    var $st$8$1 = $86 + 4 | 0;
    var $87$1 = HEAP32[$st$8$1 >> 2];
    var $88 = $vp | 0;
    HEAP32[$88 >> 2] = $87$0;
    HEAP32[$88 + 4 >> 2] = $87$1;
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    __ZN2js15AutoArrayRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 22;
    break;
   case 22:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE["X"] = 1;

function __ZL6InsertP9JSContextP5JSXMLjN2JS5ValueE($cx, $xml, $i, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$xml + 16 >> 2] >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 2:
    var $5 = _JSVAL_IS_PRIMITIVE4303($_0_0_0_val$0, $_0_0_0_val$1);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $n_04 = 1;
      __label__ = 14;
      break;
    }
   case 3:
    var $8 = _JSVAL_TO_OBJECT4304($_0_0_0_val$0, $_0_0_0_val$1);
    var $_idx1_val = HEAP32[$8 + 4 >> 2];
    var $10 = __ZNK8JSObject5isXMLEv($_idx1_val);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      var $n_04 = 1;
      __label__ = 14;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$8 + 24 >> 2];
    var $13 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $14 = $13;
    var $17 = HEAP32[$13 + 16 >> 2];
    if (($17 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($17 | 0) == 1) {
      __label__ = 12;
      break;
    } else {
      var $n_0 = 1;
      __label__ = 13;
      break;
    }
   case 5:
    var $20 = $13 + 24 | 0;
    var $21 = HEAPU32[$20 >> 2];
    if (($21 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $24 = $13 + 32 | 0;
    var $j_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $j_0;
    if ($j_0 >>> 0 < $21 >>> 0) {
      __label__ = 8;
      break;
    } else {
      var $n_0 = $21;
      __label__ = 13;
      break;
    }
   case 8:
    if ($j_0 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $33 = HEAP32[HEAP32[$24 >> 2] + ($j_0 << 2) >> 2];
    if (($33 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $36 = $33;
    var $37 = __ZL10CheckCycleP9JSContextP5JSXMLS2_($cx, $xml, $36);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $j_0 = $j_0 + 1 | 0;
    __label__ = 7;
    break;
   case 12:
    var $41 = __ZL10CheckCycleP9JSContextP5JSXMLS2_($cx, $xml, $14);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      var $n_0 = 1;
      __label__ = 13;
      break;
    }
   case 13:
    var $n_0;
    if (($13 | 0) == 0) {
      var $n_04 = $n_0;
      __label__ = 14;
      break;
    } else {
      var $vxml_1 = $14;
      var $n_03 = $n_0;
      __label__ = 17;
      break;
    }
   case 14:
    var $n_04;
    var $44 = $cx;
    var $45 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($44, $_0_0_0_val$0, $_0_0_0_val$1);
    if (($45 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $48 = __Z9js_NewXMLP9JSContext10JSXMLClass($cx, 4);
    if (($48 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    HEAP32[$48 + 24 >> 2] = $45;
    var $vxml_1 = $48;
    var $n_03 = $n_04;
    __label__ = 17;
    break;
   case 17:
    var $n_03;
    var $vxml_1;
    var $53 = $xml + 24 | 0;
    var $54 = $53 | 0;
    var $55 = HEAPU32[$54 >> 2];
    var $_01 = $55 >>> 0 < $i >>> 0 ? $55 : $i;
    var $57 = __ZL14XMLArrayInsertP9JSContextP10JSXMLArrayjj($cx, $53, $_01, $n_03);
    if (($57 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if ((HEAP32[$vxml_1 + 16 >> 2] | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 19:
    if (($n_03 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $64 = $vxml_1 + 24 | 0;
    var $65 = $vxml_1 + 32 | 0;
    var $66 = $xml + 32 | 0;
    var $j_19 = 0;
    __label__ = 21;
    break;
   case 21:
    var $j_19;
    if ($j_19 >>> 0 < HEAPU32[$64 >> 2] >>> 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 22:
    var $72 = HEAPU32[HEAP32[$65 >> 2] + ($j_19 << 2) >> 2];
    if (($72 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $76 = $72 + 8 | 0;
    HEAP32[$76 >> 2] = $xml;
    var $78 = $j_19 + $_01 | 0;
    if (HEAPU32[$54 >> 2] >>> 0 > $78 >>> 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    HEAP32[$54 >> 2] = $78 + 1 | 0;
    __label__ = 25;
    break;
   case 25:
    var $84 = HEAP32[$66 >> 2] + ($78 << 2) | 0;
    HEAP32[$84 >> 2] = $72;
    __label__ = 26;
    break;
   case 26:
    var $85 = $j_19 + 1 | 0;
    if (($85 | 0) == ($n_03 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $j_19 = $85;
      __label__ = 21;
      break;
    }
   case 27:
    HEAP32[$vxml_1 + 8 >> 2] = $xml;
    if (HEAPU32[$54 >> 2] >>> 0 > $_01 >>> 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    HEAP32[$54 >> 2] = $_01 + 1 | 0;
    __label__ = 29;
    break;
   case 29:
    var $96 = HEAP32[$xml + 32 >> 2] + ($_01 << 2) | 0;
    HEAP32[$96 >> 2] = $vxml_1;
    var $_0 = 1;
    __label__ = 30;
    break;
   case 30:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL6InsertP9JSContextP5JSXMLjN2JS5ValueE["X"] = 1;

function __ZL7ReplaceP9JSContextP5JSXMLjN2JS5ValueE($cx, $xml, $i, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$xml + 16 >> 2] >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 19;
      break;
    }
   case 2:
    var $5 = $xml + 24 | 0;
    var $6 = $5 | 0;
    var $7 = HEAPU32[$6 >> 2];
    var $_01 = $7 >>> 0 < $i >>> 0 ? $7 : $i;
    var $9 = _JSVAL_IS_PRIMITIVE4303($_0_0_0_val$0, $_0_0_0_val$1);
    if (($9 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 3:
    var $12 = _JSVAL_TO_OBJECT4304($_0_0_0_val$0, $_0_0_0_val$1);
    var $_idx1_val = HEAP32[$12 + 4 >> 2];
    var $14 = __ZNK8JSObject5isXMLEv($_idx1_val);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$12 + 24 >> 2];
    var $17 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $18 = $17;
    if (($17 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = HEAP32[$17 + 16 >> 2];
    if (($23 | 0) == 1) {
      __label__ = 6;
      break;
    } else if (($23 | 0) == 0) {
      __label__ = 7;
      break;
    } else if (($23 | 0) == 5 || ($23 | 0) == 3 || ($23 | 0) == 4) {
      var $vxml_1 = $18;
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $25 = __ZL10CheckCycleP9JSContextP5JSXMLS2_($cx, $xml, $18);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      var $vxml_1 = $18;
      __label__ = 13;
      break;
    }
   case 7:
    if ($_01 >>> 0 < $7 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    __ZL13DeleteByIndexP9JSContextP5JSXMLj($xml, $_01);
    __label__ = 9;
    break;
   case 9:
    var $31 = __ZL6InsertP9JSContextP5JSXMLjN2JS5ValueE($cx, $xml, $_01, $_0_0_0_val$0, $_0_0_0_val$1);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 10:
    var $33 = $cx;
    var $34 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($33, $_0_0_0_val$0, $_0_0_0_val$1);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $37 = __Z9js_NewXMLP9JSContext10JSXMLClass($cx, 4);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    HEAP32[$37 + 24 >> 2] = $34;
    var $vxml_1 = $37;
    __label__ = 13;
    break;
   case 13:
    var $vxml_1;
    HEAP32[$vxml_1 + 8 >> 2] = $xml;
    if ($_01 >>> 0 < $7 >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 14:
    if ($_01 >>> 0 < HEAPU32[$6 >> 2] >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $51 = HEAP32[HEAP32[$xml + 32 >> 2] + ($_01 << 2) >> 2];
    if (($51 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $55 = $51 + 8 | 0;
    HEAP32[$55 >> 2] = 0;
    __label__ = 17;
    break;
   case 17:
    var $57 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $5, $_01, $vxml_1);
    if (($57 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL7ReplaceP9JSContextP5JSXMLjN2JS5ValueE["X"] = 1;

function __ZL14XMLArrayInsertP9JSContextP10JSXMLArrayjj($cx, $array, $i, $n) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $array | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $2 + $n | 0;
    var $4 = __ZN10JSXMLArray11setCapacityEP9JSContextj($array, $cx, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $3;
    if (($2 | 0) == ($i | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $array + 8 | 0;
    var $j_03 = $2;
    __label__ = 4;
    break;
   case 4:
    var $j_03;
    var $9 = $j_03 - 1 | 0;
    var $10 = HEAP32[$7 >> 2];
    var $12 = HEAP32[$10 + ($9 << 2) >> 2];
    var $14 = $10 + ($9 + $n << 2) | 0;
    HEAP32[$14 >> 2] = $12;
    if (($9 | 0) == ($i | 0)) {
      __label__ = 5;
      break;
    } else {
      var $j_03 = $9;
      __label__ = 4;
      break;
    }
   case 5:
    var $cursor_01 = HEAP32[$array + 12 >> 2];
    if (($cursor_01 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      var $cursor_02 = $cursor_01;
      __label__ = 6;
      break;
    }
   case 6:
    var $cursor_02;
    var $18 = $cursor_02 + 4 | 0;
    var $19 = HEAPU32[$18 >> 2];
    if ($19 >>> 0 > $i >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    HEAP32[$18 >> 2] = $19 + $n | 0;
    __label__ = 8;
    break;
   case 8:
    var $cursor_0 = HEAPU32[$cursor_02 + 8 >> 2];
    if (($cursor_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      var $cursor_02 = $cursor_0;
      __label__ = 6;
      break;
    }
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11KidToStringP9JSContextP5JSXMLj($cx, $xml, $index) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (HEAPU32[$xml + 24 >> 2] >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = HEAPU32[HEAP32[$xml + 32 >> 2] + ($index << 2) >> 2];
    if (($9 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 6;
    break;
   case 4:
    var $17 = $9;
    var $18 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $17);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JSL11ObjectValueER8JSObject4319($1, $18);
    var $21 = $cx;
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $22 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($21, $_idx_val$0, $_idx_val$1);
    var $_0 = $22;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10CheckCycleP9JSContextP5JSXMLS2_($cx, $xml, $kid) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $xml;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    if (($_01 | 0) == ($kid | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $4 = $cx;
    _JS_ReportErrorNumber($4, 4, 36, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_XML_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $7 = HEAP32[$_01 + 8 >> 2];
    if (($7 | 0) == 0) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      var $_01 = $7;
      __label__ = 2;
      break;
    }
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16GetNamedPropertyP9JSContextP5JSXMLP8JSObjectS2_($cx, $xml, $nameqn, $list) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cursor = __stackBase__;
    var $cursor1 = __stackBase__ + 20;
    var $2 = HEAP32[$xml + 16 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      var $_2 = 1;
      __label__ = 18;
      break;
    }
   case 2:
    var $4 = $xml + 24 | 0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor, $4);
    __label__ = 3;
    break;
   case 3:
    var $5 = __ZN16JSXMLArrayCursor7getNextEv($cursor);
    var $6 = $5;
    if (($5 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP32[$5 + 16 >> 2] | 0) == 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 5:
    var $14 = __ZL16GetNamedPropertyP9JSContextP5JSXMLP8JSObjectS2_($cx, $6, $nameqn, $list);
    if (($14 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 6:
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_2 = 1;
    __label__ = 18;
    break;
   case 7:
    var $_idx_val = HEAP32[$nameqn + 4 >> 2];
    var $19 = __ZNK8JSObject8getClassEv($_idx_val);
    var $20 = ($19 | 0) == (__ZN2js18AttributeNameClassE | 0);
    var $array_0 = $20 ? $xml + 56 | 0 : $xml + 24 | 0;
    var $matcher_0 = $20 ? 278 : 280;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor1, $array_0);
    __label__ = 8;
    break;
   case 8:
    var $23 = __ZN16JSXMLArrayCursor7getNextEv($cursor1);
    var $24 = $23;
    if (($23 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $27 = FUNCTION_TABLE[$matcher_0]($nameqn, $24);
    if (($27 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ($20) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    if ((HEAP32[$23 + 16 >> 2] | 0) == 1) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $36 = __ZL21SyncInScopeNamespacesP9JSContextP5JSXML($cx, $24);
    if (($36 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $39 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $list, $24);
    if (($39 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 14:
    __ZN16JSXMLArrayCursorD1Ev($cursor1);
    var $_2 = 1;
    __label__ = 18;
    break;
   case 15:
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_2 = 0;
    __label__ = 18;
    break;
   case 16:
    __ZN16JSXMLArrayCursorD1Ev($cursor1);
    var $_2 = 0;
    __label__ = 18;
    break;
   case 17:
    __ZN16JSXMLArrayCursorD1Ev($cursor1);
    var $_2 = 0;
    __label__ = 18;
    break;
   case 18:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16GetNamedPropertyP9JSContextP5JSXMLP8JSObjectS2_["X"] = 1;

function __ZL21SyncInScopeNamespacesP9JSContextP5JSXML($cx, $xml) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $xml + 40 | 0;
    var $2 = $1 | 0;
    var $_idx1 = $xml + 48 | 0;
    var $_01 = $xml;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $4 = HEAP32[$_01 + 8 >> 2];
    if (($4 | 0) == 0) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $4 + 40 | 0;
    var $8 = HEAPU32[$7 >> 2];
    var $9 = $4 + 48 | 0;
    var $i_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_0;
    if ($i_0 >>> 0 < $8 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $_01 = $4;
      __label__ = 2;
      break;
    }
   case 5:
    if ($i_0 >>> 0 < HEAPU32[$7 >> 2] >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $18 = HEAPU32[HEAP32[$9 >> 2] + ($i_0 << 2) >> 2];
    if (($18 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx_val = HEAP32[$2 >> 2];
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $21 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx_val, $_idx1_val, $18, 282);
    if (($21 | 0) == -1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $24 = HEAP32[$2 >> 2];
    var $25 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $1, $24, $18);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 4;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL10Int32ValueEi4433($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function _INT_TO_JSID4434($i) {
  return $i << 1 | 1;
}

function __ZL18HasIndexedPropertyP5JSXMLj($xml, $i) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$xml + 16 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $_0 = HEAPU32[$xml + 24 >> 2] >>> 0 > $i >>> 0 & 1;
    __label__ = 4;
    break;
   case 3:
    var $_0 = ($i | 0) == 0 & 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12IdValIsIndexP9JSContextN2JS5ValueEPjPb($cx, $_0_0_0_val$0, $_0_0_0_val$1, $indexp, $isIndex) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSVAL_IS_INT4323($_0_0_0_val$0, $_0_0_0_val$1);
    if (($1 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSVAL_TO_INT4324($_0_0_0_val$0, $_0_0_0_val$1);
    if (($4 | 0) < 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP8[$isIndex] = 0;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 4:
    HEAP32[$indexp >> 2] = $4;
    HEAP8[$isIndex] = 1;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 5:
    var $9 = _JSVAL_IS_STRING4320($_0_0_0_val$0, $_0_0_0_val$1);
    if (($9 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP8[$isIndex] = 0;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 7:
    var $13 = _JSVAL_TO_STRING4321($_0_0_0_val$0, $_0_0_0_val$1);
    var $14 = $cx;
    var $15 = __ZN8JSString12ensureLinearEP9JSContext($13, $14);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $18 = __ZN2js18StringIsArrayIndexEP14JSLinearStringPj($15, $indexp);
    HEAP8[$isIndex] = $18 & 1;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26xml_removeNamespace_helperP9JSContextP5JSXMLP8JSObject($cx, $xml, $ns) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$xml + 12 >> 2];
    var $3 = $xml + 40 | 0;
    var $4 = __ZL12GetNamespaceP9JSContextP8JSObjectPK10JSXMLArray($cx, $2, $3);
    if (($4 | 0) == ($ns | 0)) {
      __label__ = 18;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $xml + 56 | 0;
    var $8 = HEAPU32[$7 >> 2];
    var $9 = $xml + 64 | 0;
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    if ($i_0 >>> 0 < $8 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    if ($i_0 >>> 0 < HEAPU32[$7 >> 2] >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $18 = HEAP32[HEAP32[$9 >> 2] + ($i_0 << 2) >> 2];
    if (($18 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = HEAP32[$18 + 12 >> 2];
    var $24 = __ZL12GetNamespaceP9JSContextP8JSObjectPK10JSXMLArray($cx, $23, $3);
    if (($24 | 0) == ($ns | 0)) {
      __label__ = 18;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 3;
    break;
   case 8:
    var $28 = $ns;
    var $_idx_val = HEAP32[$3 >> 2];
    var $_idx1_val = HEAP32[$xml + 48 >> 2];
    var $29 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx_val, $_idx1_val, $28, 284);
    if (($29 | 0) == -1) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZL14XMLArrayDeleteP9JSContextP10JSXMLArrayji($3, $29, 1);
    __label__ = 10;
    break;
   case 10:
    var $33 = $xml + 24 | 0;
    var $34 = HEAPU32[$33 >> 2];
    if (($34 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $36 = $xml + 32 | 0;
    var $i_12 = 0;
    var $38 = $34;
    __label__ = 12;
    break;
   case 12:
    var $38;
    var $i_12;
    if ($i_12 >>> 0 < $38 >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 13:
    var $43 = HEAPU32[HEAP32[$36 >> 2] + ($i_12 << 2) >> 2];
    var $44 = $43;
    if (($43 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    if ((HEAP32[$43 + 16 >> 2] | 0) == 1) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    __ZL26xml_removeNamespace_helperP9JSContextP5JSXMLP8JSObject($cx, $44, $ns);
    __label__ = 16;
    break;
   case 16:
    var $52 = $i_12 + 1 | 0;
    if (($52 | 0) == ($34 | 0)) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $i_12 = $52;
    var $38 = HEAP32[$33 >> 2];
    __label__ = 12;
    break;
   case 18:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL26xml_removeNamespace_helperP9JSContextP5JSXMLP8JSObject["X"] = 1;

function __ZL20namespace_full_matchPKvS0_($a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $a;
    var $2 = $b;
    var $3 = __ZNK8JSObject13getNamePrefixEv($1);
    if (($3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK8JSObject13getNamePrefixEv($2);
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZN2js12EqualStringsEP14JSLinearStringS1_($3, $6);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = __ZNK8JSObject10getNameURIEv($1);
    var $12 = __ZNK8JSObject10getNameURIEv($2);
    var $13 = __ZN2js12EqualStringsEP14JSLinearStringS1_($11, $12);
    var $_0 = $13 & 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL33xml_processingInstructions_helperP9JSContextP8JSObjectP5JSXMLS2_PN2JS5ValueE($cx, $xml, $nameqn, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $cursor = __stackBase__ + 8;
    var $1 = __ZL15xml_list_helperP9JSContextP5JSXMLPN2JS5ValueE($cx, $xml, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 + 44 >> 2] = $nameqn;
    var $6 = HEAPU32[$xml + 16 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 3:
    var $9 = $xml + 24 | 0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor, $9);
    var $10 = $v | 0;
    var $ok_0_ph = 1;
    __label__ = 4;
    break;
   case 4:
    var $ok_0_ph;
    __label__ = 5;
    break;
   case 5:
    var $11 = __ZN16JSXMLArrayCursor7getNextEv($cursor);
    if (($11 | 0) == 0) {
      var $ok_2 = $ok_0_ph;
      __label__ = 13;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$11 + 16 >> 2] | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 7:
    var $19 = $11;
    var $20 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $19);
    if (($20 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $22$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $22$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    HEAP32[$10 >> 2] = $22$0;
    HEAP32[$10 + 4 >> 2] = $22$1;
    var $ok_2 = 0;
    __label__ = 13;
    break;
   case 9:
    var $24 = __ZL33xml_processingInstructions_helperP9JSContextP8JSObjectP5JSXMLS2_PN2JS5ValueE($cx, $19, $nameqn, $v);
    if (($24 | 0) == 0) {
      var $ok_2 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $27$0 = HEAP32[$10 >> 2];
    var $27$1 = HEAP32[$10 + 4 >> 2];
    var $28 = _JSVAL_TO_OBJECT4304($27$0, $27$1);
    var $_idx_val = HEAP32[$28 + 24 >> 2];
    var $30 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $31 = $30;
    if (HEAPU32[$30 + 16 >> 2] >>> 0 < 2) {
      __label__ = 11;
      break;
    } else {
      var $ok_0_ph = $24;
      __label__ = 4;
      break;
    }
   case 11:
    if ((HEAP32[$30 + 24 >> 2] | 0) == 0) {
      var $ok_0_ph = $24;
      __label__ = 4;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $41 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $1, $31);
    if (($41 | 0) == 0) {
      var $ok_2 = 0;
      __label__ = 13;
      break;
    } else {
      var $ok_0_ph = $41;
      __label__ = 4;
      break;
    }
   case 13:
    var $ok_2;
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_0 = $ok_2;
    __label__ = 26;
    break;
   case 14:
    var $45 = $xml + 24 | 0;
    if ($6 >>> 0 < 2) {
      __label__ = 15;
      break;
    } else {
      var $48 = 0;
      __label__ = 16;
      break;
    }
   case 15:
    var $48 = HEAP32[$45 >> 2];
    __label__ = 16;
    break;
   case 16:
    var $48;
    var $49 = $xml + 32 | 0;
    var $i_0 = 0;
    var $ok_3 = 1;
    __label__ = 17;
    break;
   case 17:
    var $ok_3;
    var $i_0;
    if ($i_0 >>> 0 < $48 >>> 0) {
      __label__ = 18;
      break;
    } else {
      var $_0 = $ok_3;
      __label__ = 26;
      break;
    }
   case 18:
    if ($i_0 >>> 0 < HEAPU32[$45 >> 2] >>> 0) {
      __label__ = 19;
      break;
    } else {
      var $ok_4 = $ok_3;
      __label__ = 25;
      break;
    }
   case 19:
    var $58 = HEAPU32[HEAP32[$49 >> 2] + ($i_0 << 2) >> 2];
    var $59 = $58;
    if (($58 | 0) == 0) {
      var $ok_4 = $ok_3;
      __label__ = 25;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    if ((HEAP32[$58 + 16 >> 2] | 0) == 3) {
      __label__ = 21;
      break;
    } else {
      var $ok_4 = $ok_3;
      __label__ = 25;
      break;
    }
   case 21:
    var $67 = __ZNK8JSObject17getQNameLocalNameEv($nameqn);
    var $68 = $67 | 0;
    var $_idx1_val = HEAP32[$67 >> 2];
    var $69 = __ZNK8JSString6lengthEv($_idx1_val);
    if (($69 | 0) == 1) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    var $_idx2_val = HEAP32[$67 + 4 >> 2];
    var $72 = __ZNK14JSLinearString5charsEv($_idx2_val);
    if (HEAP16[$72 >> 1] << 16 >> 16 == 42) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $78 = HEAP32[$58 + 12 >> 2];
    var $79 = __ZNK8JSObject17getQNameLocalNameEv($78);
    var $80 = $79 | 0;
    var $81 = __ZN2js12EqualStringsEP14JSLinearStringS1_($68, $80);
    if ($81) {
      __label__ = 24;
      break;
    } else {
      var $ok_4 = $ok_3;
      __label__ = 25;
      break;
    }
   case 24:
    var $83 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $1, $59);
    if (($83 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      var $ok_4 = $83;
      __label__ = 25;
      break;
    }
   case 25:
    var $ok_4;
    var $i_0 = $i_0 + 1 | 0;
    var $ok_3 = $ok_4;
    __label__ = 17;
    break;
   case 26:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL33xml_processingInstructions_helperP9JSContextP8JSObjectP5JSXMLS2_PN2JS5ValueE["X"] = 1;

function __ZL20xml_normalize_helperP9JSContextP8JSObjectP5JSXML($cx, $obj, $xml) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$xml + 16 >> 2] >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 22;
      break;
    }
   case 2:
    if ((HEAP32[$xml >> 2] | 0) == ($obj | 0)) {
      var $11 = $xml;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $xml, $obj);
    var $11 = $9;
    __label__ = 4;
    break;
   case 4:
    var $11;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = $11 + 24 | 0;
    var $16 = $11 + 32 | 0;
    var $17 = $cx;
    var $n_0 = HEAP32[$14 >> 2];
    var $i_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $i_0;
    var $n_0;
    if ($i_0 >>> 0 < $n_0 >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 22;
      break;
    }
   case 7:
    if ($i_0 >>> 0 < HEAPU32[$14 >> 2] >>> 0) {
      __label__ = 8;
      break;
    } else {
      var $n_2 = $n_0;
      var $i_1 = $i_0;
      __label__ = 21;
      break;
    }
   case 8:
    var $26 = HEAPU32[HEAP32[$16 >> 2] + ($i_0 << 2) >> 2];
    var $27 = $26;
    if (($26 | 0) == 0) {
      var $n_2 = $n_0;
      var $i_1 = $i_0;
      __label__ = 21;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = HEAP32[$26 + 16 >> 2];
    if (($32 | 0) == 4) {
      __label__ = 10;
      break;
    } else if (($32 | 0) == 1) {
      __label__ = 11;
      break;
    } else {
      var $n_2 = $n_0;
      var $i_1 = $i_0;
      __label__ = 21;
      break;
    }
   case 10:
    var $33 = $i_0 + 1 | 0;
    var $34 = $26 + 24 | 0;
    var $35 = $34;
    var $36 = $34;
    var $n_1 = $n_0;
    __label__ = 13;
    break;
   case 11:
    var $38 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $27);
    if (($38 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $41 = __ZL20xml_normalize_helperP9JSContextP8JSObjectP5JSXML($cx, $38, $27);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      var $n_2 = $n_0;
      var $i_1 = $i_0;
      __label__ = 21;
      break;
    }
   case 13:
    var $n_1;
    if ($33 >>> 0 < $n_1 >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 14:
    if ($33 >>> 0 < HEAPU32[$14 >> 2] >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 15:
    var $51 = HEAPU32[HEAP32[$16 >> 2] + ($33 << 2) >> 2];
    if (($51 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if ((HEAP32[$51 + 16 >> 2] | 0) == 4) {
      __label__ = 17;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 17:
    var $59 = HEAP32[$35 >> 2];
    var $62 = HEAP32[$51 + 24 >> 2];
    var $63 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($17, $59, $62);
    if (($63 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZL17NormalizingDeleteP9JSContextP5JSXMLj($11, $33);
    var $66 = HEAP32[$14 >> 2];
    var $_c = $63;
    HEAP32[$36 >> 2] = $_c;
    var $n_1 = $66;
    __label__ = 13;
    break;
   case 19:
    var $_idx_val = HEAP32[HEAP32[$35 >> 2] >> 2];
    var $68 = __ZNK8JSString5emptyEv($_idx_val);
    if ($68) {
      __label__ = 20;
      break;
    } else {
      var $n_2 = $n_1;
      var $i_1 = $i_0;
      __label__ = 21;
      break;
    }
   case 20:
    __ZL17NormalizingDeleteP9JSContextP5JSXMLj($11, $i_0);
    var $n_2 = HEAP32[$14 >> 2];
    var $i_1 = $i_0 - 1 | 0;
    __label__ = 21;
    break;
   case 21:
    var $i_1;
    var $n_2;
    var $n_0 = $n_2;
    var $i_0 = $i_1 + 1 | 0;
    __label__ = 6;
    break;
   case 22:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL20xml_normalize_helperP9JSContextP8JSObjectP5JSXML["X"] = 1;

function __ZL17NormalizingDeleteP9JSContextP5JSXMLj($xml, $index) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$xml + 16 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZL17DeleteListElementP9JSContextP5JSXMLj($xml, $index);
    __label__ = 4;
    break;
   case 3:
    __ZL13DeleteByIndexP9JSContextP5JSXMLj($xml, $index);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19NamespacesToJSArrayP9JSContextP10JSXMLArrayPN2JS5ValueE($cx, $array, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $tvr = __stackBase__ + 8;
    var $2 = __stackBase__ + 32;
    var $3 = $cx;
    var $4 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($3);
    if (($4 | 0) == 0) {
      var $_1 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4;
    _OBJECT_TO_JSVAL4318($1, $7);
    var $8 = $1 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $rval | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $11 = $tvr;
    __ZN2js15AutoValueRooterC1EP9JSContext($11, $3);
    var $12 = $array | 0;
    var $13 = HEAPU32[$12 >> 2];
    var $14 = $array + 8 | 0;
    var $15 = $tvr;
    var $_idx = $2 | 0;
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    if ($i_0 >>> 0 < $13 >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 4:
    if ($i_0 >>> 0 < HEAPU32[$12 >> 2] >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $24 = HEAP32[HEAP32[$14 >> 2] + ($i_0 << 2) >> 2];
    if (($24 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $27 = $24;
    __ZN2JSL11ObjectValueER8JSObject4319($2, $27);
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    __ZN2js15AutoValueRooter3setEN2JS5ValueE($15, $_idx_val$0, $_idx_val$1);
    var $28 = _INT_TO_JSID4434($i_0);
    var $29 = __ZN2js15AutoValueRooter4addrEv($11);
    var $30 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($4, $3, $28, $29, 0);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 3;
    break;
   case 8:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($11);
    var $_1 = $_0;
    __label__ = 9;
    break;
   case 9:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19NamespacesToJSArrayP9JSContextP10JSXMLArrayPN2JS5ValueE["X"] = 1;

function __ZL21FindInScopeNamespacesP9JSContextP5JSXMLP10JSXMLArray($cx, $xml, $nsarray) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $nsarray | 0;
    var $3 = $nsarray + 8 | 0;
    var $_01 = $xml;
    var $length_0 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $length_0;
    var $_01;
    if ((HEAP32[$_01 + 16 >> 2] | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      var $length_3 = $length_0;
      __label__ = 19;
      break;
    }
   case 3:
    var $9 = $_01 + 40 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $11 = $_01 + 48 | 0;
    var $i_0 = 0;
    var $length_1 = $length_0;
    __label__ = 4;
    break;
   case 4:
    var $length_1;
    var $i_0;
    if ($i_0 >>> 0 < $10 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $length_3 = $length_1;
      __label__ = 19;
      break;
    }
   case 5:
    if ($i_0 >>> 0 < HEAPU32[$9 >> 2] >>> 0) {
      __label__ = 6;
      break;
    } else {
      var $length_2 = $length_1;
      __label__ = 18;
      break;
    }
   case 6:
    var $20 = HEAPU32[HEAP32[$11 >> 2] + ($i_0 << 2) >> 2];
    var $21 = $20;
    if (($20 | 0) == 0) {
      var $length_2 = $length_1;
      __label__ = 18;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = __ZNK8JSObject13getNamePrefixEv($21);
    var $25 = ($24 | 0) == 0;
    var $j_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $j_0;
    if ($j_0 >>> 0 < $length_1 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 9:
    if ($j_0 >>> 0 < HEAPU32[$1 >> 2] >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 10:
    var $34 = HEAP32[HEAP32[$3 >> 2] + ($j_0 << 2) >> 2];
    var $35 = $34;
    if (($34 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $38 = __ZNK8JSObject13getNamePrefixEv($35);
    if (($38 | 0) == 0 | $25) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $41 = __ZN2js12EqualStringsEP14JSLinearStringS1_($38, $24);
    if ($41) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $43 = __ZNK8JSObject10getNameURIEv($35);
    var $44 = __ZNK8JSObject10getNameURIEv($21);
    var $45 = __ZN2js12EqualStringsEP14JSLinearStringS1_($43, $44);
    if ($45) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $j_0 = $j_0 + 1 | 0;
    __label__ = 8;
    break;
   case 15:
    if (($j_0 | 0) == ($length_1 | 0)) {
      __label__ = 16;
      break;
    } else {
      var $length_2 = $length_1;
      __label__ = 18;
      break;
    }
   case 16:
    var $50 = HEAP32[$1 >> 2];
    var $51 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $nsarray, $50, $20);
    if (($51 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $length_2 = $length_1 + 1 | 0;
    __label__ = 18;
    break;
   case 18:
    var $length_2;
    var $i_0 = $i_0 + 1 | 0;
    var $length_1 = $length_2;
    __label__ = 4;
    break;
   case 19:
    var $length_3;
    var $57 = HEAPU32[$_01 + 8 >> 2];
    if (($57 | 0) == 0) {
      var $_0 = 1;
      __label__ = 20;
      break;
    } else {
      var $_01 = $57;
      var $length_0 = $length_3;
      __label__ = 2;
      break;
    }
   case 20:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL21FindInScopeNamespacesP9JSContextP5JSXMLP10JSXMLArray["X"] = 1;

function _DOUBLE_TO_JSVAL4435($agg_result, $d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = isNaN($d) || isNaN(0);
    if ($1) {
      var $l_0_0$1 = 2146959360;
      var $l_0_0$0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $l_0_0$1 = tempDoubleI32[1];
    var $l_0_0$0 = tempDoubleI32[0];
    __label__ = 3;
    break;
   case 3:
    var $l_0_0$0;
    var $l_0_0$1;
    __ZL13IMPL_TO_JSVAL12jsval_layout4416($agg_result, $l_0_0$0, $l_0_0$1);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11HasPropertyP9JSContextP8JSObjectN2JS5ValueEPi($cx, $obj, $_0_0_0_val$0, $_0_0_0_val$1, $found) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $isIndex = __stackBase__;
    var $i = __stackBase__ + 4;
    var $funid = __stackBase__ + 8;
    var $_idx_val = HEAP32[$obj + 24 >> 2];
    var $2 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $3 = $2;
    var $4 = __ZL12IdValIsIndexP9JSContextN2JS5ValueEPjPb($cx, $_0_0_0_val$0, $_0_0_0_val$1, $i, $isIndex);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    if ((HEAP8[$isIndex] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = HEAP32[$i >> 2];
    var $11 = __ZL18HasIndexedPropertyP5JSXMLj($3, $10);
    HEAP32[$found >> 2] = $11;
    __label__ = 8;
    break;
   case 4:
    var $13 = __ZL9ToXMLNameP9JSContextN2JS5ValueEPi($cx, $_0_0_0_val$0, $_0_0_0_val$1, $funid);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = HEAP32[$funid >> 2];
    var $17 = _JSID_IS_VOID4359($16);
    if (($17 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $20 = __ZL19HasFunctionPropertyP9JSContextP8JSObjectiPi($cx, $obj, $16, $found);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $23 = __ZL16HasNamedPropertyP5JSXMLP8JSObject($3, $13);
    HEAP32[$found >> 2] = $23;
    __label__ = 8;
    break;
   case 8:
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19xml_elements_helperP9JSContextP8JSObjectP5JSXMLS2_PN2JS5ValueE($cx, $xml, $nameqn, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $cursor = __stackBase__ + 8;
    var $1 = __ZL15xml_list_helperP9JSContextP5JSXMLPN2JS5ValueE($cx, $xml, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 + 44 >> 2] = $nameqn;
    var $6 = HEAPU32[$xml + 16 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 3:
    var $9 = $xml + 24 | 0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor, $9);
    var $10 = $v | 0;
    var $ok_0_ph = 1;
    __label__ = 4;
    break;
   case 4:
    var $ok_0_ph;
    __label__ = 5;
    break;
   case 5:
    var $11 = __ZN16JSXMLArrayCursor7getNextEv($cursor);
    if (($11 | 0) == 0) {
      var $ok_2 = $ok_0_ph;
      __label__ = 13;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$11 + 16 >> 2] | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 7:
    var $19 = $11;
    var $20 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $19);
    if (($20 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $22$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $22$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    HEAP32[$10 >> 2] = $22$0;
    HEAP32[$10 + 4 >> 2] = $22$1;
    var $ok_2 = 0;
    __label__ = 13;
    break;
   case 9:
    var $24 = __ZL19xml_elements_helperP9JSContextP8JSObjectP5JSXMLS2_PN2JS5ValueE($cx, $19, $nameqn, $v);
    if (($24 | 0) == 0) {
      var $ok_2 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $27$0 = HEAP32[$10 >> 2];
    var $27$1 = HEAP32[$10 + 4 >> 2];
    var $28 = _JSVAL_TO_OBJECT4304($27$0, $27$1);
    var $_idx_val = HEAP32[$28 + 24 >> 2];
    var $30 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $31 = $30;
    if (HEAPU32[$30 + 16 >> 2] >>> 0 < 2) {
      __label__ = 11;
      break;
    } else {
      var $ok_0_ph = $24;
      __label__ = 4;
      break;
    }
   case 11:
    if ((HEAP32[$30 + 24 >> 2] | 0) == 0) {
      var $ok_0_ph = $24;
      __label__ = 4;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $41 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $1, $31);
    if (($41 | 0) == 0) {
      var $ok_2 = 0;
      __label__ = 13;
      break;
    } else {
      var $ok_0_ph = $41;
      __label__ = 4;
      break;
    }
   case 13:
    var $ok_2;
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_0 = $ok_2;
    __label__ = 24;
    break;
   case 14:
    var $45 = $xml + 24 | 0;
    if ($6 >>> 0 < 2) {
      __label__ = 15;
      break;
    } else {
      var $48 = 0;
      __label__ = 16;
      break;
    }
   case 15:
    var $48 = HEAP32[$45 >> 2];
    __label__ = 16;
    break;
   case 16:
    var $48;
    var $49 = $xml + 32 | 0;
    var $i_0 = 0;
    var $ok_3 = 1;
    __label__ = 17;
    break;
   case 17:
    var $ok_3;
    var $i_0;
    if ($i_0 >>> 0 < $48 >>> 0) {
      __label__ = 18;
      break;
    } else {
      var $_0 = $ok_3;
      __label__ = 24;
      break;
    }
   case 18:
    if ($i_0 >>> 0 < HEAPU32[$45 >> 2] >>> 0) {
      __label__ = 19;
      break;
    } else {
      var $ok_4 = $ok_3;
      __label__ = 23;
      break;
    }
   case 19:
    var $58 = HEAPU32[HEAP32[$49 >> 2] + ($i_0 << 2) >> 2];
    var $59 = $58;
    if (($58 | 0) == 0) {
      var $ok_4 = $ok_3;
      __label__ = 23;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    if ((HEAP32[$58 + 16 >> 2] | 0) == 1) {
      __label__ = 21;
      break;
    } else {
      var $ok_4 = $ok_3;
      __label__ = 23;
      break;
    }
   case 21:
    var $67 = __ZL13MatchElemNameP8JSObjectP5JSXML($nameqn, $59);
    if (($67 | 0) == 0) {
      var $ok_4 = $ok_3;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $70 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $1, $59);
    if (($70 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      var $ok_4 = $70;
      __label__ = 23;
      break;
    }
   case 23:
    var $ok_4;
    var $i_0 = $i_0 + 1 | 0;
    var $ok_3 = $ok_4;
    __label__ = 17;
    break;
   case 24:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19xml_elements_helperP9JSContextP8JSObjectP5JSXMLS2_PN2JS5ValueE["X"] = 1;

function _JSVAL_TO_INT32_IMPL4444($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _INT_FITS_IN_JSID4436($i) {
  return ($i + 1073741824 | 0) >>> 31 ^ 1;
}

function _JSVAL_IS_SPECIFIC_INT32_IMPL($l_0$0, $l_0$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -127) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = ($l_0$0 | 0) == 0;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSID_IS_DEFAULT_XML_NAMESPACE4441($iden) {
  return ($iden | 0) == 6 & 1;
}

function _JSVAL_IS_INT32_IMPL4445($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -127) & 1;
}

function _JSVAL_IS_NUMBER_IMPL4446($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 < 4294967170 & 1;
}

function _JSVAL_TO_OBJECT_IMPL4449($l_0$0, $l_0$1) {
  return $l_0$0;
}

function __ZNK8JSObject11isNamespaceEv($this_0_1_val) {
  return ($this_0_1_val | 0) == (__ZN2js14NamespaceClassE | 0);
}

function _OBJECT_TO_JSVAL_IMPL4443($agg_result, $obj) {
  HEAP32[$agg_result + 4 >> 2] = -121;
  HEAP32[$agg_result >> 2] = $obj;
  return;
}

function __ZL19xml_comments_helperP9JSContextP8JSObjectP5JSXMLPN2JS5ValueE($cx, $xml, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZL15xml_list_helperP9JSContextP5JSXMLPN2JS5ValueE($cx, $xml, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAPU32[$xml + 16 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 3:
    var $8 = $xml + 24 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $10 = $xml + 32 | 0;
    var $11 = $v | 0;
    var $i_0 = 0;
    var $ok_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $ok_0;
    var $i_0;
    if ($i_0 >>> 0 < $9 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $ok_0;
      __label__ = 24;
      break;
    }
   case 5:
    if ($i_0 >>> 0 < HEAPU32[$8 >> 2] >>> 0) {
      __label__ = 6;
      break;
    } else {
      var $ok_2 = $ok_0;
      __label__ = 14;
      break;
    }
   case 6:
    var $20 = HEAPU32[HEAP32[$10 >> 2] + ($i_0 << 2) >> 2];
    var $21 = $20;
    if (($20 | 0) == 0) {
      var $ok_2 = $ok_0;
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ((HEAP32[$20 + 16 >> 2] | 0) == 1) {
      __label__ = 8;
      break;
    } else {
      var $ok_2 = $ok_0;
      __label__ = 14;
      break;
    }
   case 8:
    var $29 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $21);
    if (($29 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $31$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $31$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    HEAP32[$11 >> 2] = $31$0;
    HEAP32[$11 + 4 >> 2] = $31$1;
    var $_0 = 0;
    __label__ = 24;
    break;
   case 10:
    var $33 = __ZL19xml_comments_helperP9JSContextP8JSObjectP5JSXMLPN2JS5ValueE($cx, $21, $v);
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $36$0 = HEAP32[$11 >> 2];
    var $36$1 = HEAP32[$11 + 4 >> 2];
    var $37 = _JSVAL_TO_OBJECT4304($36$0, $36$1);
    var $_idx_val = HEAP32[$37 + 24 >> 2];
    var $39 = __ZNK8JSObject10getPrivateEv($_idx_val);
    var $40 = $39;
    if (HEAPU32[$39 + 16 >> 2] >>> 0 < 2) {
      __label__ = 12;
      break;
    } else {
      var $ok_2 = $33;
      __label__ = 14;
      break;
    }
   case 12:
    if ((HEAP32[$39 + 24 >> 2] | 0) == 0) {
      var $ok_2 = $33;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $50 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $1, $40);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      var $ok_2 = $50;
      __label__ = 14;
      break;
    }
   case 14:
    var $ok_2;
    var $i_0 = $i_0 + 1 | 0;
    var $ok_0 = $ok_2;
    __label__ = 4;
    break;
   case 15:
    var $55 = $xml + 24 | 0;
    if ($5 >>> 0 < 2) {
      __label__ = 16;
      break;
    } else {
      var $58 = 0;
      __label__ = 17;
      break;
    }
   case 16:
    var $58 = HEAP32[$55 >> 2];
    __label__ = 17;
    break;
   case 17:
    var $58;
    var $59 = $xml + 32 | 0;
    var $i_1 = 0;
    var $ok_3 = 1;
    __label__ = 18;
    break;
   case 18:
    var $ok_3;
    var $i_1;
    if ($i_1 >>> 0 < $58 >>> 0) {
      __label__ = 19;
      break;
    } else {
      var $_0 = $ok_3;
      __label__ = 24;
      break;
    }
   case 19:
    if ($i_1 >>> 0 < HEAPU32[$55 >> 2] >>> 0) {
      __label__ = 20;
      break;
    } else {
      var $ok_4 = $ok_3;
      __label__ = 23;
      break;
    }
   case 20:
    var $68 = HEAPU32[HEAP32[$59 >> 2] + ($i_1 << 2) >> 2];
    var $69 = $68;
    if (($68 | 0) == 0) {
      var $ok_4 = $ok_3;
      __label__ = 23;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    if ((HEAP32[$68 + 16 >> 2] | 0) == 5) {
      __label__ = 22;
      break;
    } else {
      var $ok_4 = $ok_3;
      __label__ = 23;
      break;
    }
   case 22:
    var $77 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $1, $69);
    if (($77 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      var $ok_4 = $77;
      __label__ = 23;
      break;
    }
   case 23:
    var $ok_4;
    var $i_1 = $i_1 + 1 | 0;
    var $ok_3 = $ok_4;
    __label__ = 18;
    break;
   case 24:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19xml_comments_helperP9JSContextP8JSObjectP5JSXMLPN2JS5ValueE["X"] = 1;

function __ZL16xml_child_helperP9JSContextP8JSObjectP5JSXMLN2JS5ValueEPS6_($cx, $obj, $xml, $_0_0_0_val$0, $_0_0_0_val$1, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $isIndex = __stackBase__;
    var $index = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $idr = __stackBase__ + 16;
    var $2 = __ZL12IdValIsIndexP9JSContextN2JS5ValueEPjPb($cx, $_0_0_0_val$0, $_0_0_0_val$1, $index, $isIndex);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 15;
      break;
    }
   case 2:
    if ((HEAP8[$isIndex] & 1) << 24 >> 24 == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = HEAPU32[$index >> 2];
    if (HEAPU32[$xml + 16 >> 2] >>> 0 < 2) {
      __label__ = 4;
      break;
    } else {
      var $16 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = HEAP32[$xml + 24 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $16;
    if ($8 >>> 0 < $16 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $19$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $19$1 = HEAP32[$st$1$1 >> 2];
    var $20 = $rval | 0;
    var $st$6$0 = $20 | 0;
    HEAP32[$st$6$0 >> 2] = $19$0;
    var $st$6$1 = $20 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $19$1;
    var $_1 = 1;
    __label__ = 15;
    break;
   case 7:
    if ($8 >>> 0 < HEAPU32[$xml + 24 >> 2] >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $29 = HEAPU32[HEAP32[$xml + 32 >> 2] + ($8 << 2) >> 2];
    if (($29 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $$emscripten$temp$1 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$1 | 0;
    var $31$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$1 + 4 | 0;
    var $31$1 = HEAP32[$st$1$1 >> 2];
    var $32 = $rval | 0;
    var $st$6$0 = $32 | 0;
    HEAP32[$st$6$0 >> 2] = $31$0;
    var $st$6$1 = $32 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $31$1;
    var $_1 = 1;
    __label__ = 15;
    break;
   case 10:
    var $34 = $29;
    var $35 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $34);
    if (($35 | 0) == 0) {
      var $_1 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    _OBJECT_TO_JSVAL4318($1, $35);
    var $38 = $1 | 0;
    var $39$0 = HEAP32[$38 >> 2];
    var $39$1 = HEAP32[$38 + 4 >> 2];
    var $40 = $rval | 0;
    HEAP32[$40 >> 2] = $39$0;
    HEAP32[$40 + 4 >> 2] = $39$1;
    var $_1 = 1;
    __label__ = 15;
    break;
   case 12:
    var $42 = _INT_TO_JSID4434(0);
    var $43 = $idr;
    var $44 = $cx;
    __ZN2js12AutoIdRooterC1EP9JSContexti($43, $44, $42);
    var $45 = __ZL9ValueToIdP9JSContextN2JS5ValueEPN2js12AutoIdRooterE($cx, $_0_0_0_val$0, $_0_0_0_val$1, $idr);
    if (($45 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $_idx_val = HEAP32[$idr + 12 >> 2];
    var $49 = __ZN2js12AutoIdRooter2idEv($_idx_val);
    var $50 = __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $49, $rval);
    var $_0 = $50;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    __ZN2js12AutoIdRooterD1Ev($43);
    var $_1 = $_0;
    __label__ = 15;
    break;
   case 15:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16xml_child_helperP9JSContextP8JSObjectP5JSXMLN2JS5ValueEPS6_["X"] = 1;

function __ZL9ValueToIdP9JSContextN2JS5ValueEPN2js12AutoIdRooterE($cx, $_0_0_0_val$0, $_0_0_0_val$1, $idr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSVAL_IS_INT4323($_0_0_0_val$0, $_0_0_0_val$1);
    if (($1 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSVAL_TO_INT4324($_0_0_0_val$0, $_0_0_0_val$1);
    var $5 = _INT_FITS_IN_JSID4436($4);
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = _INT_TO_JSID4434($4);
    var $9 = $idr;
    var $10 = __ZN2js12AutoIdRooter4addrEv($9);
    HEAP32[$10 >> 2] = $8;
    __label__ = 11;
    break;
   case 4:
    var $12 = $idr;
    var $13 = __ZN2js12AutoIdRooter4addrEv($12);
    var $14 = $cx;
    var $15 = __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($14, $_0_0_0_val$0, $_0_0_0_val$1, $13);
    if ($15) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 5:
    var $17 = _JSVAL_IS_STRING4320($_0_0_0_val$0, $_0_0_0_val$1);
    if (($17 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = _JSVAL_TO_STRING4321($_0_0_0_val$0, $_0_0_0_val$1);
    var $21 = $cx;
    var $22 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($21, $20);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = $22;
    var $26 = __ZL12ATOM_TO_JSIDP6JSAtom4336($25);
    var $27 = $idr;
    var $28 = __ZN2js12AutoIdRooter4addrEv($27);
    HEAP32[$28 >> 2] = $26;
    __label__ = 11;
    break;
   case 8:
    var $30 = _JSVAL_IS_PRIMITIVE4303($_0_0_0_val$0, $_0_0_0_val$1);
    if (($30 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $33 = _JSVAL_TO_OBJECT4304($_0_0_0_val$0, $_0_0_0_val$1);
    var $34 = _OBJECT_TO_JSID4356($33);
    var $35 = $idr;
    var $36 = __ZN2js12AutoIdRooter4addrEv($35);
    HEAP32[$36 >> 2] = $34;
    __label__ = 11;
    break;
   case 10:
    __ZL16ReportBadXMLNameP9JSContextRKN2JS5ValueE($cx, $_0_0_0_val$0, $_0_0_0_val$1);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 11:
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9ValueToIdP9JSContextN2JS5ValueEPN2js12AutoIdRooterE["X"] = 1;

function __ZN9JSContext4new_I16JSXMLArrayCursorP10JSXMLArrayEEPT_T0_($this, $p1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZN9JSContext7malloc_Ej($1, 20);
    if (($2 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($5, $p1);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value7isInt32Ei($this_0_0_0_val$0, $this_0_0_0_val$1) {
  var $1 = _JSVAL_IS_SPECIFIC_INT32_IMPL($this_0_0_0_val$0, $this_0_0_0_val$1);
  return ($1 | 0) != 0;
}

function __ZN9JSContext7delete_I16JSXMLArrayCursorEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN16JSXMLArrayCursorD1Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11DoubleValueEd4439($agg_result, $dbl) {
  __ZN2JS5Value9setDoubleEd($agg_result, $dbl);
  return;
}

function __ZL14xml_setGenericP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var $1 = __ZL11PutPropertyP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp);
  return $1;
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueE4442($v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v_0_0_0_val$0, $v_0_0_0_val$1);
    var $_idx_val = HEAP32[$3 + 4 >> 2];
    var $4 = __ZNK8JSObject10isFunctionEv($_idx_val);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13attr_identityPKvS0_($a, $b) {
  var $3 = HEAP32[$a + 12 >> 2];
  var $6 = HEAP32[$b + 12 >> 2];
  var $7 = __ZL14qname_identityP8JSObjectS0_($3, $6);
  return $7;
}

function __ZL14qname_identityP8JSObjectS0_($qna, $qnb) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject10getNameURIEv($qna);
    var $2 = __ZNK8JSObject10getNameURIEv($qnb);
    var $3 = ($1 | 0) != 0;
    if (($3 & 1 ^ 1 | 0) == (($2 | 0) == 0 & 1 | 0)) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js12EqualStringsEP14JSLinearStringS1_($1, $2);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = __ZNK8JSObject17getQNameLocalNameEv($qna);
    var $14 = $13 | 0;
    var $15 = __ZNK8JSObject17getQNameLocalNameEv($qnb);
    var $16 = $15 | 0;
    var $17 = __ZN2js12EqualStringsEP14JSLinearStringS1_($14, $16);
    var $_0 = $17 & 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z15jsRegExpCompilePKti24JSRegExpIgnoreCaseOption23JSRegExpMultilineOptionPjPi($pattern, $patternLength, $ignoreCase, $multiline, $numSubpatterns, $error) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cd = __stackBase__;
    var $errorcode = __stackBase__ + 20;
    var $ptr = __stackBase__ + 24;
    var $code = __stackBase__ + 28;
    var $firstByte = __stackBase__ + 32;
    var $reqByte = __stackBase__ + 36;
    var $bracketCount = __stackBase__ + 40;
    if (($error | 0) == 0) {
      var $_0 = 0;
      __label__ = 46;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$error >> 2] = 0;
    __ZN11CompileDataC1Ev($cd);
    HEAP32[$errorcode >> 2] = 0;
    var $3 = __ZL30calculateCompiledPatternLengthPKti24JSRegExpIgnoreCaseOptionR11CompileDataR9ErrorCode($pattern, $patternLength, $ignoreCase, $cd, $errorcode);
    var $4 = __ZL30calculateCompiledPatternLengthPKti24JSRegExpIgnoreCaseOptionR11CompileDataR9ErrorCode($pattern, $patternLength, $ignoreCase, $cd, $errorcode);
    var $5 = HEAP32[$errorcode >> 2];
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZL11returnError9ErrorCodePi($5, $error);
    var $_0 = 0;
    __label__ = 46;
    break;
   case 4:
    if (($4 | 0) > 4194304) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZL11returnError9ErrorCodePi(16, $error);
    var $_0 = 0;
    __label__ = 46;
    break;
   case 6:
    var $12 = $4 + 12 | 0;
    var $13 = __ZN2js11OffTheBooks9array_newIcEEPT_j($12);
    var $14 = $13;
    if (($13 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZL11returnError9ErrorCodePi(13, $error);
    var $_0 = 0;
    __label__ = 46;
    break;
   case 8:
    var $21 = ($multiline | 0) != 0 ? 2 : 0;
    var $23 = $13;
    HEAP32[$23 >> 2] = $21 | ($ignoreCase | 0) != 0 & 1;
    var $24 = $13 + 12 | 0;
    HEAP32[$ptr >> 2] = $pattern;
    var $25 = $pattern + ($patternLength << 1) | 0;
    HEAP32[$code >> 2] = $24;
    HEAP32[$bracketCount >> 2] = 0;
    var $26 = $cd + 12 | 0;
    if ((HEAP8[$26] & 1) << 24 >> 24 == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $31 = HEAP32[$23 >> 2];
    var $32 = __ZL13compileBranchiPiPPhPPKtS3_P9ErrorCodeS_S_R11CompileData($31, $bracketCount, $code, $ptr, $25, $errorcode, $firstByte, $reqByte, $cd);
    __label__ = 11;
    break;
   case 10:
    HEAP8[$24] = 67;
    var $34 = HEAP32[$23 >> 2];
    var $35 = __ZL14compileBracketiPiPPhPPKtS3_P9ErrorCodeiS_S_R11CompileData($34, $bracketCount, $code, $ptr, $25, $errorcode, 2, $firstByte, $reqByte, $cd);
    var $36 = $13 + 16 | 0;
    var $38 = HEAP32[$bracketCount >> 2] & 255;
    __ZL13put2ByteValuePhi($36, $38);
    __label__ = 11;
    break;
   case 11:
    var $43 = $13 + 4 | 0;
    HEAP16[$43 >> 1] = HEAP32[$bracketCount >> 2] & 65535;
    var $48 = $13 + 6 | 0;
    HEAP16[$48 >> 1] = HEAP32[$cd >> 2] & 65535;
    if ((HEAP32[$errorcode >> 2] | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    if (HEAPU32[$ptr >> 2] >>> 0 < $25 >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    HEAP32[$errorcode >> 2] = 10;
    __label__ = 14;
    break;
   case 14:
    var $56 = HEAP32[$code >> 2];
    var $57 = $56 + 1 | 0;
    HEAP32[$code >> 2] = $57;
    HEAP8[$56] = 0;
    if (($57 - $24 | 0) > ($4 | 0)) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    HEAP32[$errorcode >> 2] = 7;
    __label__ = 16;
    break;
   case 16:
    if ((HEAPU16[$48 >> 1] & 65535) > (HEAPU16[$43 >> 1] & 65535)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    HEAP32[$errorcode >> 2] = 15;
    __label__ = 19;
    break;
   case 18:
    if ((HEAP32[$errorcode >> 2] | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    __ZN2js10Foreground12array_deleteIcEEvPT_($13);
    var $70 = HEAP32[$errorcode >> 2];
    __ZL11returnError9ErrorCodePi($70, $error);
    var $_0 = 0;
    __label__ = 46;
    break;
   case 20:
    var $74 = (HEAP8[$26] & 1) << 24 >> 24 == 0;
    if ($74) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $76 = __ZL17bracketIsAnchoredPKh($24);
    if ($76) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 22:
    var $78 = __ZL16branchIsAnchoredPKh($24);
    if ($78) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $81 = HEAP32[$23 >> 2] | 33554432;
    HEAP32[$23 >> 2] = $81;
    __label__ = 37;
    break;
   case 24:
    var $83 = HEAP32[$firstByte >> 2];
    if (($83 | 0) < 0) {
      __label__ = 25;
      break;
    } else {
      var $97 = $83;
      __label__ = 29;
      break;
    }
   case 25:
    if ($74) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $87 = __ZL33bracketFindFirstAssertedCharacterPKhb($24, 0);
    var $91 = $87;
    __label__ = 28;
    break;
   case 27:
    var $89 = __ZL32branchFindFirstAssertedCharacterPKhb($24, 0);
    var $91 = $89;
    __label__ = 28;
    break;
   case 28:
    var $91;
    var $92 = HEAPU32[$23 >> 2];
    var $95 = $92 << 8 & 256 | $91;
    HEAP32[$firstByte >> 2] = $95;
    if (($95 | 0) > -1) {
      var $97 = $95;
      __label__ = 29;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 29:
    var $97;
    var $98 = $97 & 255;
    if ($98 >>> 0 < 127) {
      __label__ = 30;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 30:
    if (($97 & 256 | 0) == 0) {
      var $108 = $97;
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $105 = __ZL8flipCaseh($97 & 255);
    var $phitmp = ($105 & 255 | 0) == ($98 | 0) ? $98 : $97;
    var $108 = $phitmp;
    __label__ = 32;
    break;
   case 32:
    var $108;
    HEAP16[$13 + 8 >> 1] = $108 & 65535;
    var $113 = HEAP32[$23 >> 2] | 1073741824;
    HEAP32[$23 >> 2] = $113;
    __label__ = 37;
    break;
   case 33:
    var $119 = HEAP32[$cd + 4 >> 2];
    if ((HEAP8[$26] & 1) << 24 >> 24 == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $121 = __ZL21bracketNeedsLineStartPKhjj($24, 0, $119);
    if ($121) {
      __label__ = 36;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 35:
    var $123 = __ZL20branchNeedsLineStartPKhjj($24, 0, $119);
    if ($123) {
      __label__ = 36;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 36:
    HEAP32[$23 >> 2] = $92 | 268435456;
    __label__ = 37;
    break;
   case 37:
    var $127 = HEAPU32[$reqByte >> 2];
    if (($127 | 0) > -1) {
      __label__ = 38;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 38:
    var $130 = HEAPU32[$23 >> 2];
    if (($130 & 33554432 | 0) == 0) {
      __label__ = 40;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    if (($127 & 512 | 0) == 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $137 = $127 & 255;
    if ($137 >>> 0 < 127) {
      __label__ = 41;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 41:
    if (($127 & 256 | 0) == 0) {
      var $149 = $127;
      __label__ = 43;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $143 = $127 & 255;
    var $144 = __ZL8flipCaseh($143);
    var $_ = ($144 & 255 | 0) == ($137 | 0) ? $127 & -257 : $127;
    var $149 = $_;
    __label__ = 43;
    break;
   case 43:
    var $149;
    HEAP16[$13 + 10 >> 1] = $149 & 65535;
    HEAP32[$23 >> 2] = $130 | 536870912;
    __label__ = 44;
    break;
   case 44:
    if (($numSubpatterns | 0) == 0) {
      var $_0 = $14;
      __label__ = 46;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    HEAP32[$numSubpatterns >> 2] = HEAPU16[$43 >> 1] & 65535;
    var $_0 = $14;
    __label__ = 46;
    break;
   case 46:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z15jsRegExpCompilePKti24JSRegExpIgnoreCaseOption23JSRegExpMultilineOptionPjPi["X"] = 1;

function __ZN11CompileDataC1Ev($this) {
  __ZN11CompileDataC2Ev($this);
  return;
}

function __ZL11returnError9ErrorCodePi($errorcode, $error) {
  HEAP32[$error >> 2] = $errorcode;
  return;
}

function __ZL30calculateCompiledPatternLengthPKti24JSRegExpIgnoreCaseOptionR11CompileDataR9ErrorCode($pattern, $patternLength, $ignoreCase, $cd, $errorcode) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 1040;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $brastack = __stackBase__;
    var $bralenstack = __stackBase__ + 800;
    var $ptr = __stackBase__ + 1e3;
    var $minRepeats = __stackBase__ + 1004;
    var $maxRepeats = __stackBase__ + 1008;
    var $buffer = __stackBase__ + 1012;
    var $occ = __stackBase__ + 1020;
    var $ocd = __stackBase__ + 1024;
    var $cc = __stackBase__ + 1028;
    var $buffer1 = __stackBase__ + 1032;
    if (($patternLength | 0) > 4194304) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$errorcode >> 2] = 16;
    var $_0 = -1;
    __label__ = 141;
    break;
   case 3:
    var $4 = $pattern - 2 | 0;
    HEAP32[$ptr >> 2] = $4;
    var $5 = $pattern + ($patternLength << 1) | 0;
    var $6 = $cd + 16 | 0;
    var $7 = $cd + 4 | 0;
    var $8 = $cd | 0;
    var $9 = $cd + 12 | 0;
    var $10 = ($ignoreCase | 0) == 0;
    var $11 = $buffer | 0;
    var $12 = ($ignoreCase | 0) != 0;
    var $13 = $12 ? 2 : 1;
    var $14 = $buffer1 | 0;
    var $length_0 = 6;
    var $branch_extra_0 = 0;
    var $lastitemlength_0 = 0;
    var $brastackptr_0 = 0;
    var $bracount_0 = 0;
    var $15 = $4;
    __label__ = 4;
    break;
   case 4:
    var $15;
    var $bracount_0;
    var $brastackptr_0;
    var $lastitemlength_0;
    var $branch_extra_0;
    var $length_0;
    var $16 = $15 + 2 | 0;
    HEAP32[$ptr >> 2] = $16;
    if ($16 >>> 0 < $5 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 140;
      break;
    }
   case 5:
    HEAP32[$minRepeats >> 2] = 0;
    HEAP32[$maxRepeats >> 2] = 0;
    var $20 = HEAPU16[$16 >> 1] & 65535;
    if (($20 | 0) == 92) {
      __label__ = 6;
      break;
    } else if (($20 | 0) == 94 || ($20 | 0) == 46 || ($20 | 0) == 36) {
      __label__ = 28;
      break;
    } else if (($20 | 0) == 42 || ($20 | 0) == 43 || ($20 | 0) == 63) {
      __label__ = 29;
      break;
    } else if (($20 | 0) == 123) {
      __label__ = 30;
      break;
    } else if (($20 | 0) == 124) {
      __label__ = 44;
      break;
    } else if (($20 | 0) == 91) {
      __label__ = 47;
      break;
    } else if (($20 | 0) == 40) {
      __label__ = 98;
      break;
    } else if (($20 | 0) == 41) {
      __label__ = 108;
      break;
    } else {
      var $length_14 = $length_0;
      var $c_6 = $20;
      __label__ = 135;
      break;
    }
   case 6:
    var $22 = HEAP32[$6 >> 2];
    var $23 = __ZL11checkEscapePPKtS0_P9ErrorCodeib($ptr, $5, $errorcode, $22, 0);
    if ((HEAP32[$errorcode >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = -1;
      __label__ = 141;
      break;
    }
   case 7:
    if (($23 | 0) > -1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 8:
    var $29 = $length_0 + 2 | 0;
    if (($23 | 0) > 127) {
      var $i_0 = 0;
      __label__ = 10;
      break;
    } else {
      var $length_0_be = $29;
      var $branch_extra_0_be = $branch_extra_0;
      var $lastitemlength_0_be = 1;
      var $brastackptr_0_be = $brastackptr_0;
      var $bracount_0_be = $bracount_0;
      __label__ = 9;
      break;
    }
   case 9:
    var $bracount_0_be;
    var $brastackptr_0_be;
    var $lastitemlength_0_be;
    var $branch_extra_0_be;
    var $length_0_be;
    var $length_0 = $length_0_be;
    var $branch_extra_0 = $branch_extra_0_be;
    var $lastitemlength_0 = $lastitemlength_0_be;
    var $brastackptr_0 = $brastackptr_0_be;
    var $bracount_0 = $bracount_0_be;
    var $15 = HEAP32[$ptr >> 2];
    __label__ = 4;
    break;
   case 10:
    var $i_0;
    if (($i_0 | 0) < 6) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    if (($23 | 0) > (HEAP32[_jsc_pcre_utf8_table1 + ($i_0 << 2) >> 2] | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 10;
    break;
   case 13:
    var $length_0_be = $i_0 + $29 | 0;
    var $branch_extra_0_be = $branch_extra_0;
    var $lastitemlength_0_be = $i_0 + 1 | 0;
    var $brastackptr_0_be = $brastackptr_0;
    var $bracount_0_be = $bracount_0;
    __label__ = 9;
    break;
   case 14:
    if (($23 | 0) < -8) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $length_0_be = $length_0 + 1 | 0;
    var $branch_extra_0_be = $branch_extra_0;
    var $lastitemlength_0_be = 1;
    var $brastackptr_0_be = $brastackptr_0;
    var $bracount_0_be = $bracount_0;
    __label__ = 9;
    break;
   case 16:
    var $45 = -9 - $23 | 0;
    var $_ = ($45 | 0) < 32 ? 1 << $45 : 1;
    var $49 = HEAP32[$7 >> 2] | $_;
    HEAP32[$7 >> 2] = $49;
    if (($45 | 0) > (HEAP32[$8 >> 2] | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    HEAP32[$8 >> 2] = $45;
    __label__ = 18;
    break;
   case 18:
    var $54 = $length_0 + 3 | 0;
    var $55 = HEAP32[$ptr >> 2];
    var $56 = __ZL19safelyCheckNextCharPKtS0_t($55, $5, 123);
    if ($56) {
      __label__ = 19;
      break;
    } else {
      var $length_0_be = $54;
      var $branch_extra_0_be = $branch_extra_0;
      var $lastitemlength_0_be = 1;
      var $brastackptr_0_be = $brastackptr_0;
      var $bracount_0_be = $bracount_0;
      __label__ = 9;
      break;
    }
   case 19:
    var $58 = $55 + 4 | 0;
    var $59 = __ZL15isCountedRepeatPKtS0_($58, $5);
    if ($59) {
      __label__ = 20;
      break;
    } else {
      var $length_0_be = $54;
      var $branch_extra_0_be = $branch_extra_0;
      var $lastitemlength_0_be = 1;
      var $brastackptr_0_be = $brastackptr_0;
      var $bracount_0_be = $bracount_0;
      __label__ = 9;
      break;
    }
   case 20:
    var $61 = __ZL16readRepeatCountsPKtPiS1_P9ErrorCode($58, $minRepeats, $maxRepeats, $errorcode);
    HEAP32[$ptr >> 2] = $61;
    if ((HEAP32[$errorcode >> 2] | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      var $_0 = -1;
      __label__ = 141;
      break;
    }
   case 21:
    var $65 = HEAP32[$minRepeats >> 2];
    if (($65 | 0) == 0) {
      __label__ = 22;
      break;
    } else if (($65 | 0) == 1) {
      __label__ = 23;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 22:
    var $67 = HEAP32[$maxRepeats >> 2];
    if (($67 | 0) == -1 || ($67 | 0) == 1) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 23:
    if ((HEAP32[$maxRepeats >> 2] | 0) == -1) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $length_1 = $length_0 + 4 | 0;
    __label__ = 26;
    break;
   case 25:
    var $length_1 = $length_0 + 8 | 0;
    __label__ = 26;
    break;
   case 26:
    var $length_1;
    var $75 = __ZL19safelyCheckNextCharPKtS0_t($61, $5, 63);
    if ($75) {
      __label__ = 27;
      break;
    } else {
      var $length_0_be = $length_1;
      var $branch_extra_0_be = $branch_extra_0;
      var $lastitemlength_0_be = 1;
      var $brastackptr_0_be = $brastackptr_0;
      var $bracount_0_be = $bracount_0;
      __label__ = 9;
      break;
    }
   case 27:
    var $77 = $61 + 2 | 0;
    HEAP32[$ptr >> 2] = $77;
    var $length_0_be = $length_1;
    var $branch_extra_0_be = $branch_extra_0;
    var $lastitemlength_0_be = 1;
    var $brastackptr_0_be = $brastackptr_0;
    var $bracount_0_be = $bracount_0;
    __label__ = 9;
    break;
   case 28:
    var $length_0_be = $length_0 + 1 | 0;
    var $branch_extra_0_be = $branch_extra_0;
    var $lastitemlength_0_be = 1;
    var $brastackptr_0_be = $brastackptr_0;
    var $bracount_0_be = $bracount_0;
    __label__ = 9;
    break;
   case 29:
    var $length_4 = $length_0 + 1 | 0;
    var $113 = $16;
    __label__ = 42;
    break;
   case 30:
    var $83 = $15 + 4 | 0;
    var $84 = __ZL15isCountedRepeatPKtS0_($83, $5);
    if ($84) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $length_0_be = $length_0 + 2 | 0;
    var $branch_extra_0_be = $branch_extra_0;
    var $lastitemlength_0_be = 1;
    var $brastackptr_0_be = $brastackptr_0;
    var $bracount_0_be = $bracount_0;
    __label__ = 9;
    break;
   case 32:
    var $87 = __ZL16readRepeatCountsPKtPiS1_P9ErrorCode($83, $minRepeats, $maxRepeats, $errorcode);
    HEAP32[$ptr >> 2] = $87;
    if ((HEAP32[$errorcode >> 2] | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      var $_0 = -1;
      __label__ = 141;
      break;
    }
   case 33:
    var $91 = HEAP32[$minRepeats >> 2];
    if (($91 | 0) == 0) {
      __label__ = 34;
      break;
    } else if (($91 | 0) == 1) {
      __label__ = 35;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 34:
    var $93 = HEAP32[$maxRepeats >> 2];
    if (($93 | 0) == -1 || ($93 | 0) == 1) {
      __label__ = 36;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 35:
    if ((HEAP32[$maxRepeats >> 2] | 0) == -1) {
      __label__ = 36;
      break;
    } else {
      var $length_2 = $length_0;
      __label__ = 39;
      break;
    }
   case 36:
    var $length_3 = $length_0 + 1 | 0;
    __label__ = 40;
    break;
   case 37:
    __label__ = 38;
    break;
   case 38:
    var $_6_p = ($91 | 0) > 0 ? 5 : -$lastitemlength_0 | 0;
    var $length_2 = $_6_p + $length_0 | 0;
    __label__ = 39;
    break;
   case 39:
    var $length_2;
    var $105 = (HEAP32[$maxRepeats >> 2] | 0) > 0 ? 5 : 1;
    var $length_3 = $length_2 + $lastitemlength_0 + $105 | 0;
    __label__ = 40;
    break;
   case 40:
    var $length_3;
    var $109 = __ZL19safelyCheckNextCharPKtS0_t($87, $5, 63);
    if ($109) {
      __label__ = 41;
      break;
    } else {
      var $length_4 = $length_3;
      var $113 = $87;
      __label__ = 42;
      break;
    }
   case 41:
    var $111 = $87 + 2 | 0;
    HEAP32[$ptr >> 2] = $111;
    var $length_4 = $length_3;
    var $113 = $111;
    __label__ = 42;
    break;
   case 42:
    var $113;
    var $length_4;
    var $114 = __ZL19safelyCheckNextCharPKtS0_t($113, $5, 43);
    if ($114) {
      __label__ = 43;
      break;
    } else {
      var $length_0_be = $length_4;
      var $branch_extra_0_be = $branch_extra_0;
      var $lastitemlength_0_be = $lastitemlength_0;
      var $brastackptr_0_be = $brastackptr_0;
      var $bracount_0_be = $bracount_0;
      __label__ = 9;
      break;
    }
   case 43:
    HEAP32[$ptr >> 2] = $113 + 2 | 0;
    var $length_0_be = $length_4 + 8 | 0;
    var $branch_extra_0_be = $branch_extra_0;
    var $lastitemlength_0_be = $lastitemlength_0;
    var $brastackptr_0_be = $brastackptr_0;
    var $bracount_0_be = $bracount_0;
    __label__ = 9;
    break;
   case 44:
    if (($brastackptr_0 | 0) == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 45:
    HEAP8[$9] = 1;
    __label__ = 46;
    break;
   case 46:
    var $length_0_be = $length_0 + ($branch_extra_0 + 4) | 0;
    var $branch_extra_0_be = $branch_extra_0;
    var $lastitemlength_0_be = $lastitemlength_0;
    var $brastackptr_0_be = $brastackptr_0;
    var $bracount_0_be = $bracount_0;
    __label__ = 9;
    break;
   case 47:
    var $125 = $15 + 4 | 0;
    HEAP32[$ptr >> 2] = $125;
    if (HEAP16[$125 >> 1] << 16 >> 16 == 94) {
      __label__ = 48;
      break;
    } else {
      var $length_5 = $length_0;
      var $c_0 = 91;
      var $class_utf8_0 = 0;
      var $class_optcount_1 = 0;
      var $130 = $125;
      __label__ = 49;
      break;
    }
   case 48:
    var $129 = $15 + 6 | 0;
    HEAP32[$ptr >> 2] = $129;
    var $length_5 = $length_0;
    var $c_0 = 91;
    var $class_utf8_0 = 0;
    var $class_optcount_1 = 10;
    var $130 = $129;
    __label__ = 49;
    break;
   case 49:
    var $130;
    var $class_optcount_1;
    var $class_utf8_0;
    var $c_0;
    var $length_5;
    if ($130 >>> 0 < $5 >>> 0) {
      __label__ = 50;
      break;
    } else {
      __label__ = 84;
      break;
    }
   case 50:
    var $133 = HEAPU16[$130 >> 1];
    if ($133 << 16 >> 16 == 92) {
      __label__ = 51;
      break;
    } else if ($133 << 16 >> 16 == 93) {
      __label__ = 85;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 51:
    var $135 = HEAP32[$6 >> 2];
    var $136 = __ZL11checkEscapePPKtS0_P9ErrorCodeib($ptr, $5, $errorcode, $135, 1);
    if ((HEAP32[$errorcode >> 2] | 0) == 0) {
      __label__ = 52;
      break;
    } else {
      var $_0 = -1;
      __label__ = 141;
      break;
    }
   case 52:
    if (($136 | 0) > -1) {
      __label__ = 53;
      break;
    } else {
      var $length_10 = $length_5;
      var $c_4 = $136;
      var $class_utf8_3 = $class_utf8_0;
      var $class_optcount_2 = 10;
      __label__ = 83;
      break;
    }
   case 53:
    var $c_1 = $136;
    var $144 = HEAP32[$ptr >> 2];
    __label__ = 55;
    break;
   case 54:
    var $c_1 = $133 & 65535;
    var $144 = $130;
    __label__ = 55;
    break;
   case 55:
    var $144;
    var $c_1;
    var $145 = $class_optcount_1 + 1 | 0;
    var $146 = __ZL19safelyCheckNextCharPKtS0_t($144, $5, 45);
    if ($146) {
      __label__ = 56;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 56:
    var $148 = $144 + 2 | 0;
    HEAP32[$ptr >> 2] = $148;
    var $149 = __ZL19safelyCheckNextCharPKtS0_t($148, $5, 92);
    var $150 = $144 + 4 | 0;
    if ($149) {
      __label__ = 57;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 57:
    HEAP32[$ptr >> 2] = $150;
    var $152 = HEAP32[$6 >> 2];
    var $153 = __ZL11checkEscapePPKtS0_P9ErrorCodeib($ptr, $5, $errorcode, $152, 1);
    if ((HEAP32[$errorcode >> 2] | 0) == 0) {
      __label__ = 61;
      break;
    } else {
      var $_0 = -1;
      __label__ = 141;
      break;
    }
   case 58:
    if ($150 >>> 0 < $5 >>> 0) {
      __label__ = 59;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 59:
    if (HEAP16[$150 >> 1] << 16 >> 16 == 93) {
      __label__ = 62;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 60:
    HEAP32[$ptr >> 2] = $150;
    var $d_1_ph = HEAPU16[$150 >> 1] & 65535;
    __label__ = 63;
    break;
   case 61:
    if (($153 | 0) < 0) {
      __label__ = 62;
      break;
    } else {
      var $d_1_ph = $153;
      __label__ = 63;
      break;
    }
   case 62:
    HEAP32[$ptr >> 2] = $144;
    __label__ = 81;
    break;
   case 63:
    var $d_1_ph;
    if (($d_1_ph | 0) < ($c_1 | 0)) {
      __label__ = 64;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 64:
    HEAP32[$errorcode >> 2] = 8;
    var $_0 = -1;
    __label__ = 141;
    break;
   case 65:
    if (($d_1_ph | 0) > 255 | $12 & ($d_1_ph | 0) > 127) {
      __label__ = 66;
      break;
    } else {
      var $length_10 = $length_5;
      var $c_4 = $c_1;
      var $class_utf8_3 = $class_utf8_0;
      var $class_optcount_2 = 10;
      __label__ = 83;
      break;
    }
   case 66:
    var $174 = ($class_utf8_0 & 1) << 24 >> 24 == 0;
    var $_length_5 = $174 ? $length_5 + 5 | 0 : $length_5;
    var $class_utf8_1 = $174 ? 1 : $class_utf8_0;
    if ($10) {
      var $length_8 = $_length_5;
      var $d_3 = $d_1_ph;
      var $c_3 = $c_1;
      __label__ = 80;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 67:
    HEAP32[$cc >> 2] = $c_1;
    var $length_7_ph = $_length_5;
    var $d_2_ph = $d_1_ph;
    var $c_2_ph = $c_1;
    __label__ = 68;
    break;
   case 68:
    var $c_2_ph;
    var $d_2_ph;
    var $length_7_ph;
    var $176 = $c_2_ph - 1 | 0;
    var $length_7_ph34 = $length_7_ph;
    var $d_2_ph33 = $d_2_ph;
    __label__ = 69;
    break;
   case 69:
    var $d_2_ph33;
    var $length_7_ph34;
    var $177 = $d_2_ph33 + 1 | 0;
    var $length_7_ph36 = $length_7_ph34;
    __label__ = 70;
    break;
   case 70:
    var $length_7_ph36;
    __label__ = 71;
    break;
   case 71:
    var $179 = __ZL17getOthercaseRangePiiS_S_($cc, $d_1_ph, $occ, $ocd);
    if ($179) {
      __label__ = 72;
      break;
    } else {
      var $length_8 = $length_7_ph36;
      var $d_3 = $d_2_ph33;
      var $c_3 = $c_2_ph;
      __label__ = 80;
      break;
    }
   case 72:
    var $181 = HEAP32[$occ >> 2];
    var $183 = HEAP32[$ocd >> 2];
    if (($181 | 0) < ($c_2_ph | 0)) {
      __label__ = 75;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    if (($183 | 0) > ($d_2_ph33 | 0)) {
      __label__ = 74;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 74:
    var $189 = HEAP32[$ocd >> 2];
    __label__ = 76;
    break;
   case 75:
    if (($183 | 0) < ($176 | 0)) {
      var $189 = $183;
      __label__ = 76;
      break;
    } else {
      var $length_7_ph = $length_7_ph36;
      var $d_2_ph = $d_2_ph33;
      var $c_2_ph = $181;
      __label__ = 68;
      break;
    }
   case 76:
    var $189;
    if (($189 | 0) <= ($d_2_ph33 | 0) | ($181 | 0) > ($177 | 0)) {
      __label__ = 77;
      break;
    } else {
      var $length_7_ph34 = $length_7_ph36;
      var $d_2_ph33 = $189;
      __label__ = 69;
      break;
    }
   case 77:
    var $193 = __ZL10encodeUTF8iPh($181, $11);
    if (($181 | 0) == ($189 | 0)) {
      var $198 = 0;
      __label__ = 79;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 78:
    var $196 = __ZL10encodeUTF8iPh($189, $11);
    var $198 = $196;
    __label__ = 79;
    break;
   case 79:
    var $198;
    var $length_7_ph36 = $198 + ($193 + ($length_7_ph36 + 1)) | 0;
    __label__ = 70;
    break;
   case 80:
    var $c_3;
    var $d_3;
    var $length_8;
    var $202 = __ZL10encodeUTF8iPh($c_3, $11);
    var $203 = __ZL10encodeUTF8iPh($d_3, $11);
    var $length_10 = $203 + ($202 + ($length_8 + 1)) | 0;
    var $c_4 = $c_3;
    var $class_utf8_3 = $class_utf8_1;
    var $class_optcount_2 = 10;
    __label__ = 83;
    break;
   case 81:
    if (($c_1 | 0) > 255 | $12 & ($c_1 | 0) > 127) {
      __label__ = 82;
      break;
    } else {
      var $length_10 = $length_5;
      var $c_4 = $c_1;
      var $class_utf8_3 = $class_utf8_0;
      var $class_optcount_2 = $145;
      __label__ = 83;
      break;
    }
   case 82:
    var $212 = ($class_utf8_0 & 1) << 24 >> 24 == 0;
    var $_length_58 = $212 ? $length_5 + 5 | 0 : $length_5;
    var $class_utf8_2 = $212 ? 1 : $class_utf8_0;
    var $213 = __ZL10encodeUTF8iPh($c_1, $14);
    var $length_10 = ($213 + 1) * $13 + $_length_58 | 0;
    var $c_4 = $c_1;
    var $class_utf8_3 = $class_utf8_2;
    var $class_optcount_2 = 10;
    __label__ = 83;
    break;
   case 83:
    var $class_optcount_2;
    var $class_utf8_3;
    var $c_4;
    var $length_10;
    var $218 = HEAP32[$ptr >> 2] + 2 | 0;
    HEAP32[$ptr >> 2] = $218;
    var $length_5 = $length_10;
    var $c_0 = $c_4;
    var $class_utf8_0 = $class_utf8_3;
    var $class_optcount_1 = $class_optcount_2;
    var $130 = $218;
    __label__ = 49;
    break;
   case 84:
    HEAP32[$errorcode >> 2] = 6;
    var $_0 = -1;
    __label__ = 141;
    break;
   case 85:
    if (($class_optcount_1 | 0) == 1) {
      var $length_14 = $length_5;
      var $c_6 = $c_0;
      __label__ = 135;
      break;
    } else {
      __label__ = 86;
      break;
    }
   case 86:
    var $223 = $length_5 + 33 | 0;
    var $224 = __ZL19safelyCheckNextCharPKtS0_t($130, $5, 123);
    if ($224) {
      __label__ = 87;
      break;
    } else {
      var $length_0_be = $223;
      var $branch_extra_0_be = $branch_extra_0;
      var $lastitemlength_0_be = $lastitemlength_0;
      var $brastackptr_0_be = $brastackptr_0;
      var $bracount_0_be = $bracount_0;
      __label__ = 9;
      break;
    }
   case 87:
    var $226 = $130 + 4 | 0;
    var $227 = __ZL15isCountedRepeatPKtS0_($226, $5);
    if ($227) {
      __label__ = 88;
      break;
    } else {
      var $length_0_be = $223;
      var $branch_extra_0_be = $branch_extra_0;
      var $lastitemlength_0_be = $lastitemlength_0;
      var $brastackptr_0_be = $brastackptr_0;
      var $bracount_0_be = $bracount_0;
      __label__ = 9;
      break;
    }
   case 88:
    var $229 = __ZL16readRepeatCountsPKtPiS1_P9ErrorCode($226, $minRepeats, $maxRepeats, $errorcode);
    HEAP32[$ptr >> 2] = $229;
    if ((HEAP32[$errorcode >> 2] | 0) == 0) {
      __label__ = 89;
      break;
    } else {
      var $_0 = -1;
      __label__ = 141;
      break;
    }
   case 89:
    var $233 = HEAP32[$minRepeats >> 2];
    if (($233 | 0) == 0) {
      __label__ = 90;
      break;
    } else if (($233 | 0) == 1) {
      __label__ = 91;
      break;
    } else {
      __label__ = 93;
      break;
    }
   case 90:
    var $235 = HEAP32[$maxRepeats >> 2];
    if (($235 | 0) == -1 || ($235 | 0) == 1) {
      __label__ = 92;
      break;
    } else {
      __label__ = 93;
      break;
    }
   case 91:
    if ((HEAP32[$maxRepeats >> 2] | 0) == -1) {
      __label__ = 92;
      break;
    } else {
      __label__ = 93;
      break;
    }
   case 92:
    var $length_11 = $length_5 + 34 | 0;
    __label__ = 94;
    break;
   case 93:
    var $length_11 = $length_5 + 38 | 0;
    __label__ = 94;
    break;
   case 94:
    var $length_11;
    var $243 = __ZL19safelyCheckNextCharPKtS0_t($229, $5, 43);
    if ($243) {
      __label__ = 95;
      break;
    } else {
      __label__ = 96;
      break;
    }
   case 95:
    HEAP32[$ptr >> 2] = $229 + 2 | 0;
    var $length_0_be = $length_11 + 8 | 0;
    var $branch_extra_0_be = $branch_extra_0;
    var $lastitemlength_0_be = $lastitemlength_0;
    var $brastackptr_0_be = $brastackptr_0;
    var $bracount_0_be = $bracount_0;
    __label__ = 9;
    break;
   case 96:
    var $248 = __ZL19safelyCheckNextCharPKtS0_t($229, $5, 63);
    if ($248) {
      __label__ = 97;
      break;
    } else {
      var $length_0_be = $length_11;
      var $branch_extra_0_be = $branch_extra_0;
      var $lastitemlength_0_be = $lastitemlength_0;
      var $brastackptr_0_be = $brastackptr_0;
      var $bracount_0_be = $bracount_0;
      __label__ = 9;
      break;
    }
   case 97:
    HEAP32[$ptr >> 2] = $229 + 2 | 0;
    var $length_0_be = $length_11;
    var $branch_extra_0_be = $branch_extra_0;
    var $lastitemlength_0_be = $lastitemlength_0;
    var $brastackptr_0_be = $brastackptr_0;
    var $bracount_0_be = $bracount_0;
    __label__ = 9;
    break;
   case 98:
    var $252 = __ZL19safelyCheckNextCharPKtS0_t($16, $5, 63);
    if ($252) {
      __label__ = 99;
      break;
    } else {
      __label__ = 103;
      break;
    }
   case 99:
    var $254 = $15 + 6 | 0;
    if ($254 >>> 0 < $5 >>> 0) {
      __label__ = 100;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 100:
    var $258 = HEAPU16[$254 >> 1] & 65535;
    if (($258 | 0) == 58 || ($258 | 0) == 61 || ($258 | 0) == 33) {
      __label__ = 101;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 101:
    HEAP32[$ptr >> 2] = $254;
    var $bracket_length_0 = 6;
    var $bracount_1 = $bracount_0;
    __label__ = 105;
    break;
   case 102:
    HEAP32[$errorcode >> 2] = 12;
    var $_0 = -1;
    __label__ = 141;
    break;
   case 103:
    var $260 = $bracount_0 + 1 | 0;
    if (($260 | 0) > 100) {
      __label__ = 104;
      break;
    } else {
      var $bracket_length_0 = 6;
      var $bracount_1 = $260;
      __label__ = 105;
      break;
    }
   case 104:
    var $bracket_length_0 = 9;
    var $bracount_1 = $260;
    __label__ = 105;
    break;
   case 105:
    var $bracount_1;
    var $bracket_length_0;
    if ($brastackptr_0 >>> 0 > 199) {
      __label__ = 106;
      break;
    } else {
      __label__ = 107;
      break;
    }
   case 106:
    HEAP32[$errorcode >> 2] = 17;
    var $_0 = -1;
    __label__ = 141;
    break;
   case 107:
    HEAP8[$bralenstack + $brastackptr_0 | 0] = $branch_extra_0 & 255;
    HEAP32[$brastack + ($brastackptr_0 << 2) >> 2] = $length_0;
    var $length_0_be = $bracket_length_0 + $length_0 | 0;
    var $branch_extra_0_be = 0;
    var $lastitemlength_0_be = $lastitemlength_0;
    var $brastackptr_0_be = $brastackptr_0 + 1 | 0;
    var $bracount_0_be = $bracount_1;
    __label__ = 9;
    break;
   case 108:
    var $273 = $length_0 + 4 | 0;
    if (($brastackptr_0 | 0) == 0) {
      var $duplength_0 = 0;
      var $branch_extra_1 = $branch_extra_0;
      var $brastackptr_1 = 0;
      __label__ = 110;
      break;
    } else {
      __label__ = 109;
      break;
    }
   case 109:
    var $276 = $brastackptr_0 - 1 | 0;
    var $duplength_0 = $273 - HEAP32[$brastack + ($276 << 2) >> 2] | 0;
    var $branch_extra_1 = HEAPU8[$bralenstack + $276 | 0] & 255;
    var $brastackptr_1 = $276;
    __label__ = 110;
    break;
   case 110:
    var $brastackptr_1;
    var $branch_extra_1;
    var $duplength_0;
    var $284 = $15 + 4 | 0;
    if ($284 >>> 0 < $5 >>> 0) {
      __label__ = 111;
      break;
    } else {
      __label__ = 118;
      break;
    }
   case 111:
    var $287 = HEAPU16[$284 >> 1];
    var $288 = $287 & 65535;
    if ($287 << 16 >> 16 == 123) {
      __label__ = 112;
      break;
    } else {
      var $c_5 = $288;
      __label__ = 114;
      break;
    }
   case 112:
    var $291 = $15 + 6 | 0;
    var $292 = __ZL15isCountedRepeatPKtS0_($291, $5);
    if ($292) {
      __label__ = 113;
      break;
    } else {
      var $c_5 = $288;
      __label__ = 114;
      break;
    }
   case 113:
    var $294 = __ZL16readRepeatCountsPKtPiS1_P9ErrorCode($291, $minRepeats, $maxRepeats, $errorcode);
    HEAP32[$ptr >> 2] = $294;
    if ((HEAP32[$errorcode >> 2] | 0) == 0) {
      __label__ = 119;
      break;
    } else {
      var $_0 = -1;
      __label__ = 141;
      break;
    }
   case 114:
    var $c_5;
    if (($c_5 | 0) == 42) {
      __label__ = 115;
      break;
    } else if (($c_5 | 0) == 43) {
      __label__ = 116;
      break;
    } else if (($c_5 | 0) == 63) {
      __label__ = 117;
      break;
    } else {
      __label__ = 118;
      break;
    }
   case 115:
    HEAP32[$minRepeats >> 2] = 0;
    HEAP32[$maxRepeats >> 2] = -1;
    HEAP32[$ptr >> 2] = $284;
    var $length_13 = $length_0 + 5 | 0;
    var $341 = $284;
    __label__ = 133;
    break;
   case 116:
    HEAP32[$minRepeats >> 2] = 1;
    HEAP32[$maxRepeats >> 2] = -1;
    HEAP32[$ptr >> 2] = $284;
    var $319 = 1;
    var $318 = $284;
    __label__ = 125;
    break;
   case 117:
    HEAP32[$minRepeats >> 2] = 0;
    HEAP32[$maxRepeats >> 2] = 1;
    HEAP32[$ptr >> 2] = $284;
    var $308 = 1;
    var $307 = $length_0 + 5 | 0;
    var $306 = $284;
    __label__ = 121;
    break;
   case 118:
    HEAP32[$minRepeats >> 2] = 1;
    HEAP32[$maxRepeats >> 2] = 1;
    var $319 = 1;
    var $318 = $16;
    __label__ = 125;
    break;
   case 119:
    var $_pr24 = HEAP32[$minRepeats >> 2];
    if (($_pr24 | 0) == 0) {
      __label__ = 120;
      break;
    } else {
      var $319 = $_pr24;
      var $318 = $294;
      __label__ = 125;
      break;
    }
   case 120:
    var $_pr30 = HEAP32[$maxRepeats >> 2];
    var $303 = $length_0 + 5 | 0;
    if (($_pr30 | 0) > 0) {
      var $308 = $_pr30;
      var $307 = $303;
      var $306 = $294;
      __label__ = 121;
      break;
    } else {
      var $length_13 = $303;
      var $341 = $294;
      __label__ = 133;
      break;
    }
   case 121:
    var $306;
    var $307;
    var $308;
    var $311 = __ZL25multiplyWithOverflowCheckii($308 - 1 | 0, $duplength_0 + 11 | 0);
    if (($311 | 0) < 0) {
      __label__ = 122;
      break;
    } else {
      __label__ = 123;
      break;
    }
   case 122:
    HEAP32[$errorcode >> 2] = 16;
    var $_0 = -1;
    __label__ = 141;
    break;
   case 123:
    var $315 = $311 + $307 | 0;
    if (($315 | 0) > 4194304) {
      __label__ = 124;
      break;
    } else {
      var $length_13 = $315;
      var $341 = $306;
      __label__ = 133;
      break;
    }
   case 124:
    HEAP32[$errorcode >> 2] = 16;
    var $_0 = -1;
    __label__ = 141;
    break;
   case 125:
    var $318;
    var $319;
    var $321 = __ZL25multiplyWithOverflowCheckii($319 - 1 | 0, $duplength_0);
    if (($321 | 0) < 0) {
      __label__ = 126;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 126:
    HEAP32[$errorcode >> 2] = 16;
    var $_0 = -1;
    __label__ = 141;
    break;
   case 127:
    var $325 = $321 + $273 | 0;
    var $326 = HEAP32[$maxRepeats >> 2];
    if (($326 | 0) > ($319 | 0)) {
      __label__ = 128;
      break;
    } else {
      var $length_12 = $325;
      __label__ = 131;
      break;
    }
   case 128:
    var $329 = $326 - $319 | 0;
    var $331 = __ZL25multiplyWithOverflowCheckii($329, $duplength_0 + 11 | 0);
    if (($331 | 0) < 0) {
      __label__ = 129;
      break;
    } else {
      __label__ = 130;
      break;
    }
   case 129:
    HEAP32[$errorcode >> 2] = 16;
    var $_0 = -1;
    __label__ = 141;
    break;
   case 130:
    var $length_12 = $325 - 8 + $331 | 0;
    __label__ = 131;
    break;
   case 131:
    var $length_12;
    if (($length_12 | 0) > 4194304) {
      __label__ = 132;
      break;
    } else {
      var $length_13 = $length_12;
      var $341 = $318;
      __label__ = 133;
      break;
    }
   case 132:
    HEAP32[$errorcode >> 2] = 16;
    var $_0 = -1;
    __label__ = 141;
    break;
   case 133:
    var $341;
    var $length_13;
    var $342 = __ZL19safelyCheckNextCharPKtS0_t($341, $5, 43);
    if ($342) {
      __label__ = 134;
      break;
    } else {
      var $length_0_be = $length_13;
      var $branch_extra_0_be = $branch_extra_1;
      var $lastitemlength_0_be = $lastitemlength_0;
      var $brastackptr_0_be = $brastackptr_1;
      var $bracount_0_be = $bracount_0;
      __label__ = 9;
      break;
    }
   case 134:
    HEAP32[$ptr >> 2] = $341 + 2 | 0;
    var $length_0_be = $length_13 + 8 | 0;
    var $branch_extra_0_be = $branch_extra_1;
    var $lastitemlength_0_be = $lastitemlength_0;
    var $brastackptr_0_be = $brastackptr_1;
    var $bracount_0_be = $bracount_0;
    __label__ = 9;
    break;
   case 135:
    var $c_6;
    var $length_14;
    var $347 = $length_14 + 2 | 0;
    if (($c_6 | 0) > 127) {
      var $i2_0 = 0;
      __label__ = 136;
      break;
    } else {
      var $length_0_be = $347;
      var $branch_extra_0_be = $branch_extra_0;
      var $lastitemlength_0_be = 1;
      var $brastackptr_0_be = $brastackptr_0;
      var $bracount_0_be = $bracount_0;
      __label__ = 9;
      break;
    }
   case 136:
    var $i2_0;
    if (($i2_0 | 0) < 6) {
      __label__ = 137;
      break;
    } else {
      __label__ = 139;
      break;
    }
   case 137:
    if (($c_6 | 0) > (HEAP32[_jsc_pcre_utf8_table1 + ($i2_0 << 2) >> 2] | 0)) {
      __label__ = 138;
      break;
    } else {
      __label__ = 139;
      break;
    }
   case 138:
    var $i2_0 = $i2_0 + 1 | 0;
    __label__ = 136;
    break;
   case 139:
    var $length_0_be = $i2_0 + $347 | 0;
    var $branch_extra_0_be = $branch_extra_0;
    var $lastitemlength_0_be = $i2_0 + 1 | 0;
    var $brastackptr_0_be = $brastackptr_0;
    var $bracount_0_be = $bracount_0;
    __label__ = 9;
    break;
   case 140:
    HEAP32[$6 >> 2] = $bracount_0;
    var $_0 = $length_0 + 5 | 0;
    __label__ = 141;
    break;
   case 141:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL30calculateCompiledPatternLengthPKti24JSRegExpIgnoreCaseOptionR11CompileDataR9ErrorCode["X"] = 1;

function __ZN2js11OffTheBooks9array_newIcEEPT_j($n) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1$0 = $n;
    var $2$0 = (i64Math.add($1$0, 0, 8, 0), i64Math.result[0]);
    var $2$1 = i64Math.result[1];
    if ($2$0 == ($2$0 & -1) && $2$1 == ($2$1 & 0)) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = $2$0;
    var $7 = _js_malloc4456($6);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$7 >> 2] = $n;
    var $_0 = $7 + 8 | 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13compileBranchiPiPPhPPKtS3_P9ErrorCodeS_S_R11CompileData($options, $brackets, $codePtr, $ptrPtr, $patternEnd, $errorCodePtr, $firstbyteptr, $reqbyteptr, $cd) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 96;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $repeatMin = __stackBase__;
    var $repeat_max = __stackBase__ + 4;
    var $code = __stackBase__ + 8;
    var $tempcode = __stackBase__ + 12;
    var $ptr = __stackBase__ + 16;
    var $previous = __stackBase__ + 20;
    var $classbits = __stackBase__ + 24;
    var $utf8_char = __stackBase__ + 56;
    var $subReqByte = __stackBase__ + 64;
    var $subFirstByte = __stackBase__ + 68;
    var $mcbuffer = __stackBase__ + 72;
    var $occ = __stackBase__ + 80;
    var $ocd = __stackBase__ + 84;
    var $cc = __stackBase__ + 88;
    var $ket = __stackBase__ + 92;
    HEAP32[$repeatMin >> 2] = 0;
    HEAP32[$repeat_max >> 2] = 0;
    var $1 = HEAP32[$codePtr >> 2];
    HEAP32[$code >> 2] = $1;
    var $2 = HEAP32[$ptrPtr >> 2];
    HEAP32[$ptr >> 2] = $2;
    HEAP32[$previous >> 2] = 0;
    var $3 = $options & 1;
    var $4 = ($3 | 0) != 0;
    var $5 = $3 << 8;
    var $6 = $mcbuffer | 0;
    var $8 = ($3 | 14) & 255;
    var $10 = ($options & 2 | 0) == 0;
    var $11 = $classbits | 0;
    var $12 = $cd + 16 | 0;
    var $13 = $cd + 8 | 0;
    var $14 = ($3 | 0) == 0;
    var $15 = $utf8_char | 0;
    var $didGroupSetFirstByte_0 = 0;
    var $firstByte_0 = -2;
    var $reqByte_0 = -2;
    var $zeroReqByte_0 = -2;
    var $zeroFirstByte_0 = -2;
    var $17 = $2;
    __label__ = 2;
    break;
   case 2:
    var $17;
    var $zeroFirstByte_0;
    var $zeroReqByte_0;
    var $reqByte_0;
    var $firstByte_0;
    var $didGroupSetFirstByte_0;
    var $18 = $17 >>> 0 < $patternEnd >>> 0;
    if ($18) {
      __label__ = 3;
      break;
    } else {
      var $23 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $23 = HEAPU16[$17 >> 1] & 65535;
    __label__ = 4;
    break;
   case 4:
    var $23;
    if (($23 - 42 | 0) >>> 0 < 2 | ($23 | 0) == 63) {
      var $31 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($23 | 0) == 123) {
      __label__ = 6;
      break;
    } else {
      var $31 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $28 = $17 + 2 | 0;
    var $29 = __ZL15isCountedRepeatPKtS0_($28, $patternEnd);
    if ($29) {
      var $_pre_phi = $28;
      __label__ = 88;
      break;
    } else {
      __label__ = 213;
      break;
    }
   case 7:
    var $31;
    if (($23 | 0) == 0) {
      __label__ = 8;
      break;
    } else if (($23 | 0) == 124 || ($23 | 0) == 41) {
      __label__ = 9;
      break;
    } else if (($23 | 0) == 94) {
      __label__ = 10;
      break;
    } else if (($23 | 0) == 36) {
      __label__ = 14;
      break;
    } else if (($23 | 0) == 46) {
      __label__ = 17;
      break;
    } else if (($23 | 0) == 91) {
      __label__ = 18;
      break;
    } else if (($23 | 0) == 123) {
      __label__ = 86;
      break;
    } else if (($23 | 0) == 42) {
      __label__ = 89;
      break;
    } else if (($23 | 0) == 43) {
      __label__ = 90;
      break;
    } else if (($23 | 0) == 63) {
      __label__ = 91;
      break;
    } else if (($23 | 0) == 40) {
      __label__ = 177;
      break;
    } else if (($23 | 0) == 92) {
      __label__ = 206;
      break;
    } else {
      var $c_13 = $23;
      __label__ = 214;
      break;
    }
   case 8:
    if ($18) {
      __label__ = 213;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    HEAP32[$firstbyteptr >> 2] = $firstByte_0;
    HEAP32[$reqbyteptr >> 2] = $reqByte_0;
    var $33 = HEAP32[$code >> 2];
    HEAP32[$codePtr >> 2] = $33;
    HEAP32[$ptrPtr >> 2] = $17;
    var $_0 = 1;
    __label__ = 230;
    break;
   case 10:
    if ($10) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $firstByte_1 = ($firstByte_0 | 0) == -2 ? -1 : $firstByte_0;
    var $37 = HEAP32[$code >> 2];
    var $38 = $37 + 1 | 0;
    HEAP32[$code >> 2] = $38;
    HEAP8[$37] = 12;
    var $firstByte_2 = $firstByte_1;
    __label__ = 13;
    break;
   case 12:
    var $40 = HEAP32[$code >> 2];
    var $41 = $40 + 1 | 0;
    HEAP32[$code >> 2] = $41;
    HEAP8[$40] = 10;
    var $firstByte_2 = $firstByte_0;
    __label__ = 13;
    break;
   case 13:
    var $firstByte_2;
    HEAP32[$previous >> 2] = 0;
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $firstByte_2;
    var $reqByte_8 = $reqByte_0;
    var $zeroReqByte_1 = $zeroReqByte_0;
    var $zeroFirstByte_3 = $zeroFirstByte_0;
    __label__ = 228;
    break;
   case 14:
    HEAP32[$previous >> 2] = 0;
    var $44 = HEAP32[$code >> 2];
    var $45 = $44 + 1 | 0;
    HEAP32[$code >> 2] = $45;
    if ($10) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    HEAP8[$44] = 13;
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $firstByte_0;
    var $reqByte_8 = $reqByte_0;
    var $zeroReqByte_1 = $zeroReqByte_0;
    var $zeroFirstByte_3 = $zeroFirstByte_0;
    __label__ = 228;
    break;
   case 16:
    HEAP8[$44] = 11;
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $firstByte_0;
    var $reqByte_8 = $reqByte_0;
    var $zeroReqByte_1 = $zeroReqByte_0;
    var $zeroFirstByte_3 = $zeroFirstByte_0;
    __label__ = 228;
    break;
   case 17:
    var $firstByte_3 = ($firstByte_0 | 0) == -2 ? -1 : $firstByte_0;
    var $50 = HEAP32[$code >> 2];
    HEAP32[$previous >> 2] = $50;
    var $51 = $50 + 1 | 0;
    HEAP32[$code >> 2] = $51;
    HEAP8[$50] = 9;
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $firstByte_3;
    var $reqByte_8 = $reqByte_0;
    var $zeroReqByte_1 = $reqByte_0;
    var $zeroFirstByte_3 = $firstByte_3;
    __label__ = 228;
    break;
   case 18:
    var $53 = HEAPU32[$code >> 2];
    HEAP32[$previous >> 2] = $53;
    var $54 = $17 + 2 | 0;
    if ($54 >>> 0 < $patternEnd >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    HEAP32[$errorCodePtr >> 2] = 6;
    var $_0 = 0;
    __label__ = 230;
    break;
   case 20:
    if (HEAP16[$54 >> 1] << 16 >> 16 == 94) {
      __label__ = 21;
      break;
    } else {
      var $negateClass_0 = 0;
      var $62 = $17;
      __label__ = 22;
      break;
    }
   case 21:
    HEAP32[$ptr >> 2] = $54;
    var $negateClass_0 = 1;
    var $62 = $54;
    __label__ = 22;
    break;
   case 22:
    var $62;
    var $negateClass_0;
    var $63 = $53 + 37 | 0;
    _memset($11, 0, 32, 1);
    var $classLastChar_0 = -1;
    var $classCharCount_0 = 0;
    var $shouldFlipNegation_0 = 0;
    var $class_utf8_0 = 0;
    var $class_utf8data_0 = $63;
    var $64 = $62;
    __label__ = 23;
    break;
   case 23:
    var $64;
    var $class_utf8data_0;
    var $class_utf8_0;
    var $shouldFlipNegation_0;
    var $classCharCount_0;
    var $classLastChar_0;
    var $65 = $64 + 2 | 0;
    HEAP32[$ptr >> 2] = $65;
    if ($65 >>> 0 < $patternEnd >>> 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 72;
      break;
    }
   case 24:
    var $68 = HEAPU16[$65 >> 1];
    if ($68 << 16 >> 16 == 93) {
      __label__ = 72;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $71 = $68 & 65535;
    if ($68 << 16 >> 16 == 92) {
      __label__ = 26;
      break;
    } else {
      var $c_6 = $71;
      var $128 = $65;
      __label__ = 36;
      break;
    }
   case 26:
    var $74 = HEAP32[$12 >> 2];
    var $75 = __ZL11checkEscapePPKtS0_P9ErrorCodeib($ptr, $patternEnd, $errorCodePtr, $74, 1);
    if (($75 | 0) < 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $c_6 = $75;
    var $128 = HEAP32[$ptr >> 2];
    __label__ = 36;
    break;
   case 28:
    var $78 = $classCharCount_0 + 2 | 0;
    var $79 = -$75 | 0;
    if (($79 | 0) == 4) {
      var $c_081 = 0;
      __label__ = 29;
      break;
    } else if (($79 | 0) == 3) {
      var $c_178 = 0;
      __label__ = 30;
      break;
    } else if (($79 | 0) == 8) {
      var $c_275 = 0;
      __label__ = 31;
      break;
    } else if (($79 | 0) == 7) {
      var $c_372 = 0;
      __label__ = 32;
      break;
    } else if (($79 | 0) == 6) {
      var $c_469 = 0;
      __label__ = 33;
      break;
    } else if (($79 | 0) == 5) {
      var $c_566 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 29:
    var $c_081;
    var $82 = __ZL18classBitmapForCharh($c_081 + 32 & 255);
    var $83 = $classbits + $c_081 | 0;
    var $85 = HEAP8[$83] | $82;
    HEAP8[$83] = $85;
    var $86 = $c_081 + 1 | 0;
    if (($86 | 0) == 32) {
      var $classLastChar_0_be = $classLastChar_0;
      var $classCharCount_0_be = $78;
      var $shouldFlipNegation_0_be = $shouldFlipNegation_0;
      var $class_utf8_0_be = $class_utf8_0;
      var $class_utf8data_0_be = $class_utf8data_0;
      __label__ = 45;
      break;
    } else {
      var $c_081 = $86;
      __label__ = 29;
      break;
    }
   case 30:
    var $c_178;
    var $89 = __ZL18classBitmapForCharh($c_178 + 32 & 255);
    var $91 = $classbits + $c_178 | 0;
    var $93 = HEAP8[$91] | $89 ^ -1;
    HEAP8[$91] = $93;
    var $94 = $c_178 + 1 | 0;
    if (($94 | 0) == 32) {
      var $classLastChar_0_be = $classLastChar_0;
      var $classCharCount_0_be = $78;
      var $shouldFlipNegation_0_be = 1;
      var $class_utf8_0_be = $class_utf8_0;
      var $class_utf8data_0_be = $class_utf8data_0;
      __label__ = 45;
      break;
    } else {
      var $c_178 = $94;
      __label__ = 30;
      break;
    }
   case 31:
    var $c_275;
    var $97 = __ZL18classBitmapForCharh($c_275 + 64 & 255);
    var $98 = $classbits + $c_275 | 0;
    var $100 = HEAP8[$98] | $97;
    HEAP8[$98] = $100;
    var $101 = $c_275 + 1 | 0;
    if (($101 | 0) == 32) {
      var $classLastChar_0_be = $classLastChar_0;
      var $classCharCount_0_be = $78;
      var $shouldFlipNegation_0_be = $shouldFlipNegation_0;
      var $class_utf8_0_be = $class_utf8_0;
      var $class_utf8data_0_be = $class_utf8data_0;
      __label__ = 45;
      break;
    } else {
      var $c_275 = $101;
      __label__ = 31;
      break;
    }
   case 32:
    var $c_372;
    var $104 = __ZL18classBitmapForCharh($c_372 + 64 & 255);
    var $106 = $classbits + $c_372 | 0;
    var $108 = HEAP8[$106] | $104 ^ -1;
    HEAP8[$106] = $108;
    var $109 = $c_372 + 1 | 0;
    if (($109 | 0) == 32) {
      var $classLastChar_0_be = $classLastChar_0;
      var $classCharCount_0_be = $78;
      var $shouldFlipNegation_0_be = 1;
      var $class_utf8_0_be = $class_utf8_0;
      var $class_utf8data_0_be = $class_utf8data_0;
      __label__ = 45;
      break;
    } else {
      var $c_372 = $109;
      __label__ = 32;
      break;
    }
   case 33:
    var $c_469;
    var $111 = __ZL18classBitmapForCharh($c_469 & 255);
    var $112 = $classbits + $c_469 | 0;
    var $114 = HEAP8[$112] | $111;
    HEAP8[$112] = $114;
    var $115 = $c_469 + 1 | 0;
    if (($115 | 0) == 32) {
      var $classLastChar_0_be = $classLastChar_0;
      var $classCharCount_0_be = $78;
      var $shouldFlipNegation_0_be = $shouldFlipNegation_0;
      var $class_utf8_0_be = $class_utf8_0;
      var $class_utf8data_0_be = $class_utf8data_0;
      __label__ = 45;
      break;
    } else {
      var $c_469 = $115;
      __label__ = 33;
      break;
    }
   case 34:
    var $c_566;
    var $117 = __ZL18classBitmapForCharh($c_566 & 255);
    var $119 = $classbits + $c_566 | 0;
    var $121 = HEAP8[$119] | $117 ^ -1;
    HEAP8[$119] = $121;
    var $122 = $c_566 + 1 | 0;
    if (($122 | 0) == 32) {
      var $classLastChar_0_be = $classLastChar_0;
      var $classCharCount_0_be = $78;
      var $shouldFlipNegation_0_be = 1;
      var $class_utf8_0_be = $class_utf8_0;
      var $class_utf8data_0_be = $class_utf8data_0;
      __label__ = 45;
      break;
    } else {
      var $c_566 = $122;
      __label__ = 34;
      break;
    }
   case 35:
    var $124 = HEAPU32[$ptr >> 2];
    var $c_6 = HEAPU16[$124 >> 1] & 65535;
    var $128 = $124;
    __label__ = 36;
    break;
   case 36:
    var $128;
    var $c_6;
    var $129 = $128 + 4 | 0;
    if ($129 >>> 0 < $patternEnd >>> 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 37:
    if (HEAP16[$128 + 2 >> 1] << 16 >> 16 == 45) {
      __label__ = 38;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 38:
    if (HEAP16[$129 >> 1] << 16 >> 16 == 93) {
      __label__ = 65;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    HEAP32[$ptr >> 2] = $129;
    var $139 = HEAPU16[$129 >> 1];
    var $140 = $139 & 65535;
    if ($139 << 16 >> 16 == 92) {
      __label__ = 40;
      break;
    } else {
      var $d_0 = $140;
      __label__ = 42;
      break;
    }
   case 40:
    var $143 = HEAP32[$12 >> 2];
    var $144 = __ZL11checkEscapePPKtS0_P9ErrorCodeib($ptr, $patternEnd, $errorCodePtr, $143, 1);
    if (($144 | 0) < 0) {
      __label__ = 41;
      break;
    } else {
      var $d_0 = $144;
      __label__ = 42;
      break;
    }
   case 41:
    HEAP32[$ptr >> 2] = $128;
    __label__ = 65;
    break;
   case 42:
    var $d_0;
    if (($d_0 | 0) == ($c_6 | 0)) {
      __label__ = 65;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    if (($d_0 | 0) > 255 | $4 & ($d_0 | 0) > 127) {
      __label__ = 46;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    if (($c_6 | 0) > ($d_0 | 0)) {
      var $classLastChar_0_be = $classLastChar_0;
      var $classCharCount_0_be = $classCharCount_0;
      var $shouldFlipNegation_0_be = $shouldFlipNegation_0;
      var $class_utf8_0_be = $class_utf8_0;
      var $class_utf8data_0_be = $class_utf8data_0;
      __label__ = 45;
      break;
    } else {
      var $c_959 = $c_6;
      var $classCharCount_260 = $classCharCount_0;
      __label__ = 62;
      break;
    }
   case 45:
    var $class_utf8data_0_be;
    var $class_utf8_0_be;
    var $shouldFlipNegation_0_be;
    var $classCharCount_0_be;
    var $classLastChar_0_be;
    var $classLastChar_0 = $classLastChar_0_be;
    var $classCharCount_0 = $classCharCount_0_be;
    var $shouldFlipNegation_0 = $shouldFlipNegation_0_be;
    var $class_utf8_0 = $class_utf8_0_be;
    var $class_utf8data_0 = $class_utf8data_0_be;
    var $64 = HEAP32[$ptr >> 2];
    __label__ = 23;
    break;
   case 46:
    if ($4) {
      __label__ = 47;
      break;
    } else {
      var $d_2 = $d_0;
      var $c_8 = $c_6;
      var $class_utf8data_3 = $class_utf8data_0;
      __label__ = 61;
      break;
    }
   case 47:
    HEAP32[$cc >> 2] = $c_6;
    var $d_1_ph = $d_0;
    var $c_7_ph = $c_6;
    var $class_utf8data_1_ph = $class_utf8data_0;
    __label__ = 48;
    break;
   case 48:
    var $class_utf8data_1_ph;
    var $c_7_ph;
    var $d_1_ph;
    var $d_1_ph85 = $d_1_ph;
    var $c_7_ph84 = $c_7_ph;
    __label__ = 49;
    break;
   case 49:
    var $c_7_ph84;
    var $d_1_ph85;
    var $155 = $c_7_ph84 - 1 | 0;
    var $d_1_ph87 = $d_1_ph85;
    __label__ = 50;
    break;
   case 50:
    var $d_1_ph87;
    __label__ = 51;
    break;
   case 51:
    var $157 = __ZL17getOthercaseRangePiiS_S_($cc, $d_0, $occ, $ocd);
    if ($157) {
      __label__ = 52;
      break;
    } else {
      var $d_2 = $d_1_ph87;
      var $c_8 = $c_7_ph84;
      var $class_utf8data_3 = $class_utf8data_1_ph;
      __label__ = 61;
      break;
    }
   case 52:
    var $159 = HEAP32[$occ >> 2];
    var $161 = HEAP32[$ocd >> 2];
    if (($159 | 0) < ($c_7_ph84 | 0)) {
      __label__ = 55;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    if (($161 | 0) > ($d_1_ph87 | 0)) {
      __label__ = 54;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 54:
    var $167 = HEAP32[$ocd >> 2];
    __label__ = 56;
    break;
   case 55:
    if (($161 | 0) < ($155 | 0)) {
      var $167 = $161;
      __label__ = 56;
      break;
    } else {
      var $d_1_ph85 = $d_1_ph87;
      var $c_7_ph84 = $159;
      __label__ = 49;
      break;
    }
   case 56:
    var $167;
    if (($167 | 0) <= ($d_1_ph87 | 0) | ($159 | 0) > ($d_1_ph87 + 1 | 0)) {
      __label__ = 57;
      break;
    } else {
      var $d_1_ph87 = $167;
      __label__ = 50;
      break;
    }
   case 57:
    var $173 = $class_utf8data_1_ph + 1 | 0;
    if (($159 | 0) == ($167 | 0)) {
      __label__ = 58;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 58:
    HEAP8[$class_utf8data_1_ph] = 1;
    var $class_utf8data_2 = $173;
    __label__ = 60;
    break;
   case 59:
    HEAP8[$class_utf8data_1_ph] = 2;
    var $176 = HEAP32[$occ >> 2];
    var $177 = __ZL10encodeUTF8iPh($176, $173);
    var $class_utf8data_2 = $177 + ($class_utf8data_1_ph + 1) | 0;
    __label__ = 60;
    break;
   case 60:
    var $class_utf8data_2;
    var $180 = HEAP32[$ocd >> 2];
    var $181 = __ZL10encodeUTF8iPh($180, $class_utf8data_2);
    var $d_1_ph = $d_1_ph87;
    var $c_7_ph = $c_7_ph84;
    var $class_utf8data_1_ph = $class_utf8data_2 + $181 | 0;
    __label__ = 48;
    break;
   case 61:
    var $class_utf8data_3;
    var $c_8;
    var $d_2;
    HEAP8[$class_utf8data_3] = 2;
    var $184 = __ZL10encodeUTF8iPh($c_8, $class_utf8data_3 + 1 | 0);
    var $_sum7 = $184 + 1 | 0;
    var $185 = $class_utf8data_3 + $_sum7 | 0;
    var $186 = __ZL10encodeUTF8iPh($d_2, $185);
    var $classLastChar_0_be = $classLastChar_0;
    var $classCharCount_0_be = $classCharCount_0;
    var $shouldFlipNegation_0_be = $shouldFlipNegation_0;
    var $class_utf8_0_be = 1;
    var $class_utf8data_0_be = $class_utf8data_3 + ($_sum7 + $186) | 0;
    __label__ = 45;
    break;
   case 62:
    var $classCharCount_260;
    var $c_959;
    var $191 = $classbits + (($c_959 | 0) / 8 & -1) | 0;
    HEAP8[$191] = (HEAPU8[$191] & 255 | 1 << ($c_959 & 7)) & 255;
    if ($4) {
      __label__ = 63;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 63:
    var $198 = __ZL8flipCaseh($c_959 & 255);
    var $199 = $198 & 255;
    var $203 = $classbits + ($199 >>> 3) | 0;
    HEAP8[$203] = (1 << ($199 & 7) | HEAPU8[$203] & 255) & 255;
    __label__ = 64;
    break;
   case 64:
    var $209 = $classCharCount_260 + 1 | 0;
    var $210 = $c_959 + 1 | 0;
    if (($210 | 0) > ($d_0 | 0)) {
      var $classLastChar_0_be = $c_959;
      var $classCharCount_0_be = $209;
      var $shouldFlipNegation_0_be = $shouldFlipNegation_0;
      var $class_utf8_0_be = $class_utf8_0;
      var $class_utf8data_0_be = $class_utf8data_0;
      __label__ = 45;
      break;
    } else {
      var $c_959 = $210;
      var $classCharCount_260 = $209;
      __label__ = 62;
      break;
    }
   case 65:
    if (($c_6 | 0) > 255 | $4 & ($c_6 | 0) > 127) {
      __label__ = 66;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 66:
    HEAP8[$class_utf8data_0] = 1;
    var $217 = __ZL10encodeUTF8iPh($c_6, $class_utf8data_0 + 1 | 0);
    var $218 = $217 + ($class_utf8data_0 + 1) | 0;
    if ($4) {
      __label__ = 67;
      break;
    } else {
      var $classLastChar_0_be = $classLastChar_0;
      var $classCharCount_0_be = $classCharCount_0;
      var $shouldFlipNegation_0_be = $shouldFlipNegation_0;
      var $class_utf8_0_be = 1;
      var $class_utf8data_0_be = $218;
      __label__ = 45;
      break;
    }
   case 67:
    var $220 = __Z22jsc_pcre_ucp_othercasej($c_6);
    if (($220 | 0) > -1) {
      __label__ = 68;
      break;
    } else {
      var $classLastChar_0_be = $classLastChar_0;
      var $classCharCount_0_be = $classCharCount_0;
      var $shouldFlipNegation_0_be = $shouldFlipNegation_0;
      var $class_utf8_0_be = 1;
      var $class_utf8data_0_be = $218;
      __label__ = 45;
      break;
    }
   case 68:
    var $_sum5 = $217 + 2 | 0;
    var $223 = $class_utf8data_0 + $_sum5 | 0;
    HEAP8[$218] = 1;
    var $224 = __ZL10encodeUTF8iPh($220, $223);
    var $classLastChar_0_be = $classLastChar_0;
    var $classCharCount_0_be = $classCharCount_0;
    var $shouldFlipNegation_0_be = $shouldFlipNegation_0;
    var $class_utf8_0_be = 1;
    var $class_utf8data_0_be = $class_utf8data_0 + ($224 + $_sum5) | 0;
    __label__ = 45;
    break;
   case 69:
    var $230 = $classbits + (($c_6 | 0) / 8 & -1) | 0;
    HEAP8[$230] = (HEAPU8[$230] & 255 | 1 << ($c_6 & 7)) & 255;
    if ($4) {
      __label__ = 70;
      break;
    } else {
      var $c_10 = $c_6;
      __label__ = 71;
      break;
    }
   case 70:
    var $237 = __ZL8flipCaseh($c_6 & 255);
    var $238 = $237 & 255;
    var $242 = $classbits + ($238 >>> 3) | 0;
    HEAP8[$242] = (1 << ($238 & 7) | HEAPU8[$242] & 255) & 255;
    var $c_10 = $238;
    __label__ = 71;
    break;
   case 71:
    var $c_10;
    var $classLastChar_0_be = $c_10;
    var $classCharCount_0_be = $classCharCount_0 + 1 | 0;
    var $shouldFlipNegation_0_be = $shouldFlipNegation_0;
    var $class_utf8_0_be = $class_utf8_0;
    var $class_utf8data_0_be = $class_utf8data_0;
    __label__ = 45;
    break;
   case 72:
    if (($classCharCount_0 | 0) == 1 & $class_utf8_0 << 24 >> 24 == 0) {
      __label__ = 73;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 73:
    if (($classLastChar_0 | 0) < 128 | $negateClass_0 ^ 1) {
      __label__ = 74;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 74:
    if ($negateClass_0) {
      __label__ = 75;
      break;
    } else {
      var $c_13 = $classLastChar_0;
      __label__ = 214;
      break;
    }
   case 75:
    var $firstByte_4 = ($firstByte_0 | 0) == -2 ? -1 : $firstByte_0;
    var $256 = HEAP32[$code >> 2];
    var $257 = $256 + 1 | 0;
    HEAP32[$code >> 2] = $257;
    HEAP8[$256] = 18;
    var $259 = HEAP32[$code >> 2];
    var $260 = $259 + 1 | 0;
    HEAP32[$code >> 2] = $260;
    HEAP8[$259] = $classLastChar_0 & 255;
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $firstByte_4;
    var $reqByte_8 = $reqByte_0;
    var $zeroReqByte_1 = $reqByte_0;
    var $zeroFirstByte_3 = $firstByte_4;
    __label__ = 228;
    break;
   case 76:
    var $firstByte_5 = ($firstByte_0 | 0) == -2 ? -1 : $firstByte_0;
    if ($class_utf8_0 << 24 >> 24 != 0 & $shouldFlipNegation_0 << 24 >> 24 == 0) {
      __label__ = 77;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 77:
    var $266 = $class_utf8data_0 + 1 | 0;
    HEAP8[$class_utf8data_0] = 0;
    var $267 = HEAP32[$code >> 2];
    var $268 = $267 + 1 | 0;
    HEAP32[$code >> 2] = $268;
    HEAP8[$267] = 56;
    var $270 = HEAP32[$code >> 2] + 3 | 0;
    HEAP32[$code >> 2] = $270;
    HEAP8[$270] = $negateClass_0 & 1;
    var $273 = HEAPU32[$code >> 2];
    if (($classCharCount_0 | 0) > 0) {
      __label__ = 78;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 78:
    HEAP32[$code >> 2] = $273 + 1 | 0;
    var $277 = HEAP8[$273] | 2;
    HEAP8[$273] = $277;
    var $278 = HEAP32[$code >> 2];
    _memcpy($278, $11, 32, 1);
    var $storemerge = $266;
    __label__ = 80;
    break;
   case 79:
    var $280 = $273 + 33 | 0;
    var $283 = $266 - $280 | 0;
    var $284 = $273 + 1 | 0;
    _llvm_memmove_p0i8_p0i8_i32($284, $280, $283, 1, 0);
    var $storemerge = HEAP32[$code >> 2] + ($283 + 1) | 0;
    __label__ = 80;
    break;
   case 80:
    var $storemerge;
    HEAP32[$code >> 2] = $storemerge;
    var $289 = HEAP32[$previous >> 2];
    var $290 = $289 + 1 | 0;
    var $293 = $storemerge - $289 | 0;
    __ZL12putLinkValuePhi($290, $293);
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $firstByte_5;
    var $reqByte_8 = $reqByte_0;
    var $zeroReqByte_1 = $reqByte_0;
    var $zeroFirstByte_3 = $firstByte_5;
    __label__ = 228;
    break;
   case 81:
    var $298 = ($negateClass_0 & 1 | 0) == ($shouldFlipNegation_0 & 255 | 0) ? 54 : 55;
    var $299 = HEAPU32[$code >> 2];
    HEAP32[$code >> 2] = $299 + 1 | 0;
    HEAP8[$299] = $298;
    if ($negateClass_0) {
      var $c_1137 = 0;
      __label__ = 82;
      break;
    } else {
      __label__ = 83;
      break;
    }
   case 82:
    var $c_1137;
    var $303 = HEAP8[$classbits + $c_1137 | 0] ^ -1;
    HEAP8[HEAP32[$code >> 2] + $c_1137 | 0] = $303;
    var $306 = $c_1137 + 1 | 0;
    if (($306 | 0) == 32) {
      __label__ = 84;
      break;
    } else {
      var $c_1137 = $306;
      __label__ = 82;
      break;
    }
   case 83:
    var $308 = HEAP32[$code >> 2];
    _memcpy($308, $11, 32, 1);
    var $309 = $308;
    __label__ = 85;
    break;
   case 84:
    var $309 = HEAP32[$code >> 2];
    __label__ = 85;
    break;
   case 85:
    var $309;
    HEAP32[$code >> 2] = $309 + 32 | 0;
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $firstByte_5;
    var $reqByte_8 = $reqByte_0;
    var $zeroReqByte_1 = $reqByte_0;
    var $zeroFirstByte_3 = $firstByte_5;
    __label__ = 228;
    break;
   case 86:
    if ($31) {
      __label__ = 87;
      break;
    } else {
      __label__ = 213;
      break;
    }
   case 87:
    var $_pre_phi = $17 + 2 | 0;
    __label__ = 88;
    break;
   case 88:
    var $_pre_phi;
    var $313 = __ZL16readRepeatCountsPKtPiS1_P9ErrorCode($_pre_phi, $repeatMin, $repeat_max, $errorCodePtr);
    HEAP32[$ptr >> 2] = $313;
    if ((HEAP32[$errorCodePtr >> 2] | 0) == 0) {
      var $319 = $313;
      __label__ = 92;
      break;
    } else {
      var $762 = $313;
      __label__ = 229;
      break;
    }
   case 89:
    HEAP32[$repeatMin >> 2] = 0;
    HEAP32[$repeat_max >> 2] = -1;
    var $319 = $17;
    __label__ = 92;
    break;
   case 90:
    HEAP32[$repeatMin >> 2] = 1;
    HEAP32[$repeat_max >> 2] = -1;
    var $319 = $17;
    __label__ = 92;
    break;
   case 91:
    HEAP32[$repeatMin >> 2] = 0;
    HEAP32[$repeat_max >> 2] = 1;
    var $319 = $17;
    __label__ = 92;
    break;
   case 92:
    var $319;
    var $320 = HEAPU32[$previous >> 2];
    if (($320 | 0) == 0) {
      __label__ = 93;
      break;
    } else {
      __label__ = 94;
      break;
    }
   case 93:
    HEAP32[$errorCodePtr >> 2] = 9;
    var $762 = $319;
    __label__ = 229;
    break;
   case 94:
    var $324 = HEAPU32[$repeatMin >> 2];
    var $325 = ($324 | 0) == 0;
    var $reqByte_1 = $325 ? $zeroReqByte_0 : $reqByte_0;
    var $firstByte_6 = $325 ? $zeroFirstByte_0 : $firstByte_0;
    var $326 = HEAPU32[$repeat_max >> 2];
    var $328 = ($324 | 0) == ($326 | 0) ? 0 : 512;
    HEAP32[$tempcode >> 2] = $320;
    var $329 = __ZL19safelyCheckNextCharPKtS0_t($319, $patternEnd, 63);
    if ($329) {
      __label__ = 95;
      break;
    } else {
      var $repeatType_0 = 0;
      var $333 = $319;
      __label__ = 96;
      break;
    }
   case 95:
    var $331 = $319 + 2 | 0;
    HEAP32[$ptr >> 2] = $331;
    var $repeatType_0 = 1;
    var $333 = $331;
    __label__ = 96;
    break;
   case 96:
    var $333;
    var $repeatType_0;
    var $334 = HEAPU8[$320];
    if ($334 << 24 >> 24 == 14 || $334 << 24 >> 24 == 15) {
      __label__ = 97;
      break;
    } else if ($334 << 24 >> 24 == 16 || $334 << 24 >> 24 == 17) {
      __label__ = 103;
      break;
    } else if ($334 << 24 >> 24 == 18) {
      __label__ = 105;
      break;
    } else {
      __label__ = 106;
      break;
    }
   case 97:
    var $335 = HEAPU32[$code >> 2];
    var $336 = $335 - 1 | 0;
    var $337 = HEAPU8[$336];
    var $338 = $337 & 255;
    if (($338 & 128 | 0) == 0) {
      __label__ = 101;
      break;
    } else {
      __label__ = 98;
      break;
    }
   case 98:
    if (($337 & -64) << 24 >> 24 == -128) {
      var $lastchar_050 = $336;
      __label__ = 99;
      break;
    } else {
      var $lastchar_0_lcssa = $336;
      __label__ = 100;
      break;
    }
   case 99:
    var $lastchar_050;
    var $343 = $lastchar_050 - 1 | 0;
    if ((HEAP8[$343] & -64) << 24 >> 24 == -128) {
      var $lastchar_050 = $343;
      __label__ = 99;
      break;
    } else {
      var $lastchar_0_lcssa = $343;
      __label__ = 100;
      break;
    }
   case 100:
    var $lastchar_0_lcssa;
    var $349 = $335 - $lastchar_0_lcssa | 0;
    _memcpy($15, $lastchar_0_lcssa, $349, 1);
    var $opType_0 = 0;
    var $c_12 = $349 | 128;
    var $reqByte_2 = $reqByte_1;
    __label__ = 108;
    break;
   case 101:
    if (($324 | 0) > 1) {
      __label__ = 102;
      break;
    } else {
      var $opType_0 = 0;
      var $c_12 = $338;
      var $reqByte_2 = $reqByte_1;
      __label__ = 108;
      break;
    }
   case 102:
    var $opType_0 = 0;
    var $c_12 = $338;
    var $reqByte_2 = $338 | $5 | HEAP32[$13 >> 2];
    __label__ = 108;
    break;
   case 103:
    var $360 = HEAPU8[$320 + 1 | 0] & 255;
    if (($324 | 0) > 1) {
      __label__ = 104;
      break;
    } else {
      var $opType_0 = 0;
      var $c_12 = $360;
      var $reqByte_2 = $reqByte_1;
      __label__ = 108;
      break;
    }
   case 104:
    var $opType_0 = 0;
    var $c_12 = $360;
    var $reqByte_2 = $360 | $5 | HEAP32[$13 >> 2];
    __label__ = 108;
    break;
   case 105:
    var $opType_0 = 9;
    var $c_12 = HEAPU8[$320 + 1 | 0] & 255;
    var $reqByte_2 = $reqByte_1;
    __label__ = 108;
    break;
   case 106:
    if (($334 & 255) < 10) {
      __label__ = 107;
      break;
    } else {
      __label__ = 131;
      break;
    }
   case 107:
    var $opType_0 = 18;
    var $c_12 = $334 & 255;
    var $reqByte_2 = $reqByte_1;
    __label__ = 108;
    break;
   case 108:
    var $reqByte_2;
    var $c_12;
    var $opType_0;
    var $373 = HEAP32[$code >> 2];
    HEAP32[$code >> 2] = $320;
    if (($326 | 0) == 0) {
      var $reqByte_6 = $reqByte_2;
      __label__ = 176;
      break;
    } else {
      __label__ = 109;
      break;
    }
   case 109:
    var $376 = $opType_0 + $repeatType_0 | 0;
    if (($324 | 0) == 0) {
      __label__ = 110;
      break;
    } else if (($324 | 0) == 1) {
      __label__ = 114;
      break;
    } else {
      __label__ = 118;
      break;
    }
   case 110:
    if (($326 | 0) == -1) {
      __label__ = 111;
      break;
    } else if (($326 | 0) == 1) {
      __label__ = 112;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 111:
    HEAP32[$code >> 2] = $320 + 1 | 0;
    HEAP8[$320] = $376 + 19 & 255;
    __label__ = 128;
    break;
   case 112:
    HEAP32[$code >> 2] = $320 + 1 | 0;
    HEAP8[$320] = $376 + 23 & 255;
    __label__ = 128;
    break;
   case 113:
    HEAP32[$code >> 2] = $320 + 1 | 0;
    HEAP8[$320] = $376 + 25 & 255;
    __ZL23put2ByteValueAndAdvanceRPhi($code, $326);
    __label__ = 128;
    break;
   case 114:
    if (($326 | 0) == -1) {
      __label__ = 115;
      break;
    } else {
      __label__ = 116;
      break;
    }
   case 115:
    HEAP32[$code >> 2] = $320 + 1 | 0;
    HEAP8[$320] = $376 + 21 & 255;
    __label__ = 128;
    break;
   case 116:
    HEAP32[$code >> 2] = $373;
    if (($326 | 0) == 1) {
      var $reqByte_6 = $reqByte_2;
      __label__ = 176;
      break;
    } else {
      __label__ = 117;
      break;
    }
   case 117:
    var $401 = $373 + 1 | 0;
    HEAP32[$code >> 2] = $401;
    HEAP8[$373] = $376 + 25 & 255;
    var $402 = $326 - 1 | 0;
    __ZL23put2ByteValueAndAdvanceRPhi($code, $402);
    __label__ = 128;
    break;
   case 118:
    HEAP32[$code >> 2] = $320 + 1 | 0;
    HEAP8[$320] = $opType_0 + 27 & 255;
    __ZL23put2ByteValueAndAdvanceRPhi($code, $324);
    if (($326 | 0) < 0) {
      __label__ = 119;
      break;
    } else {
      __label__ = 123;
      break;
    }
   case 119:
    if (($c_12 | 0) > 127) {
      __label__ = 120;
      break;
    } else {
      __label__ = 121;
      break;
    }
   case 120:
    var $411 = HEAP32[$code >> 2];
    var $412 = $c_12 & 7;
    _memcpy($411, $15, $412, 1);
    var $414 = HEAP32[$code >> 2] + $412 | 0;
    HEAP32[$code >> 2] = $414;
    var $420 = $414;
    __label__ = 122;
    break;
   case 121:
    var $417 = HEAP32[$code >> 2];
    var $418 = $417 + 1 | 0;
    HEAP32[$code >> 2] = $418;
    HEAP8[$417] = $c_12 & 255;
    var $420 = HEAP32[$code >> 2];
    __label__ = 122;
    break;
   case 122:
    var $420;
    HEAP32[$code >> 2] = $420 + 1 | 0;
    HEAP8[$420] = $376 + 19 & 255;
    __label__ = 128;
    break;
   case 123:
    if (($326 | 0) == ($324 | 0)) {
      __label__ = 128;
      break;
    } else {
      __label__ = 124;
      break;
    }
   case 124:
    if (($c_12 | 0) > 127) {
      __label__ = 125;
      break;
    } else {
      __label__ = 126;
      break;
    }
   case 125:
    var $429 = HEAP32[$code >> 2];
    var $430 = $c_12 & 7;
    _memcpy($429, $15, $430, 1);
    var $432 = HEAP32[$code >> 2] + $430 | 0;
    HEAP32[$code >> 2] = $432;
    var $438 = $432;
    __label__ = 127;
    break;
   case 126:
    var $435 = HEAP32[$code >> 2];
    var $436 = $435 + 1 | 0;
    HEAP32[$code >> 2] = $436;
    HEAP8[$435] = $c_12 & 255;
    var $438 = HEAP32[$code >> 2];
    __label__ = 127;
    break;
   case 127:
    var $438;
    var $439 = $326 - $324 | 0;
    HEAP32[$repeat_max >> 2] = $439;
    HEAP32[$code >> 2] = $438 + 1 | 0;
    HEAP8[$438] = $376 + 25 & 255;
    __ZL23put2ByteValueAndAdvanceRPhi($code, $439);
    __label__ = 128;
    break;
   case 128:
    if (($c_12 | 0) > 127) {
      __label__ = 129;
      break;
    } else {
      __label__ = 130;
      break;
    }
   case 129:
    var $446 = HEAP32[$code >> 2];
    var $447 = $c_12 & 7;
    _memcpy($446, $15, $447, 1);
    var $449 = HEAP32[$code >> 2] + $447 | 0;
    HEAP32[$code >> 2] = $449;
    var $reqByte_6 = $reqByte_2;
    __label__ = 176;
    break;
   case 130:
    var $452 = HEAP32[$code >> 2];
    var $453 = $452 + 1 | 0;
    HEAP32[$code >> 2] = $453;
    HEAP8[$452] = $c_12 & 255;
    var $reqByte_6 = $reqByte_2;
    __label__ = 176;
    break;
   case 131:
    if (($334 - 54 & 255 & 255) < 4) {
      __label__ = 132;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 132:
    if (($326 | 0) == 0) {
      __label__ = 133;
      break;
    } else {
      __label__ = 134;
      break;
    }
   case 133:
    HEAP32[$code >> 2] = $320;
    var $reqByte_6 = $reqByte_1;
    __label__ = 176;
    break;
   case 134:
    var $459 = ($326 | 0) == -1;
    if ($325 & $459) {
      __label__ = 135;
      break;
    } else {
      __label__ = 136;
      break;
    }
   case 135:
    var $463 = HEAP32[$code >> 2];
    var $464 = $463 + 1 | 0;
    HEAP32[$code >> 2] = $464;
    HEAP8[$463] = ($repeatType_0 | 46) & 255;
    var $reqByte_6 = $reqByte_1;
    __label__ = 176;
    break;
   case 136:
    if (($324 | 0) != 1 | $459 ^ 1) {
      __label__ = 138;
      break;
    } else {
      __label__ = 137;
      break;
    }
   case 137:
    var $469 = HEAP32[$code >> 2];
    var $470 = $469 + 1 | 0;
    HEAP32[$code >> 2] = $470;
    HEAP8[$469] = ($repeatType_0 | 48) & 255;
    var $reqByte_6 = $reqByte_1;
    __label__ = 176;
    break;
   case 138:
    if ($325 & ($326 | 0) == 1) {
      __label__ = 139;
      break;
    } else {
      __label__ = 140;
      break;
    }
   case 139:
    var $476 = HEAP32[$code >> 2];
    var $477 = $476 + 1 | 0;
    HEAP32[$code >> 2] = $477;
    HEAP8[$476] = ($repeatType_0 | 50) & 255;
    var $reqByte_6 = $reqByte_1;
    __label__ = 176;
    break;
   case 140:
    var $480 = HEAP32[$code >> 2];
    var $481 = $480 + 1 | 0;
    HEAP32[$code >> 2] = $481;
    HEAP8[$480] = ($repeatType_0 | 52) & 255;
    __ZL23put2ByteValueAndAdvanceRPhi($code, $324);
    var $482 = HEAP32[$repeat_max >> 2];
    if (($482 | 0) == -1) {
      __label__ = 141;
      break;
    } else {
      var $486 = $482;
      __label__ = 142;
      break;
    }
   case 141:
    HEAP32[$repeat_max >> 2] = 0;
    var $486 = 0;
    __label__ = 142;
    break;
   case 142:
    var $486;
    __ZL23put2ByteValueAndAdvanceRPhi($code, $486);
    var $reqByte_6 = $reqByte_1;
    __label__ = 176;
    break;
   case 143:
    if (($334 & 255) > 66) {
      __label__ = 144;
      break;
    } else {
      __label__ = 172;
      break;
    }
   case 144:
    var $490 = HEAPU32[$code >> 2];
    var $493 = $490 - $320 | 0;
    var $_val = HEAP8[$320 + 4 | 0];
    var $_idx_val = HEAP8[$320 + 5 | 0];
    var $495 = __ZL13get2ByteValuePKh($_val, $_idx_val);
    if (($326 | 0) == -1) {
      __label__ = 145;
      break;
    } else {
      var $ketoffset_0 = 0;
      var $504 = $490;
      __label__ = 146;
      break;
    }
   case 145:
    HEAP32[$ket >> 2] = $320;
    __ZL21advanceToEndOfBracketRPKh($ket);
    var $498 = HEAP32[$code >> 2];
    var $ketoffset_0 = $498 - HEAP32[$ket >> 2] | 0;
    var $504 = $498;
    __label__ = 146;
    break;
   case 146:
    var $504;
    var $ketoffset_0;
    if ($325) {
      __label__ = 147;
      break;
    } else {
      __label__ = 153;
      break;
    }
   case 147:
    var $506 = HEAP32[$repeat_max >> 2];
    if (($506 | 0) == 0) {
      __label__ = 148;
      break;
    } else {
      __label__ = 149;
      break;
    }
   case 148:
    var $509 = HEAP32[$previous >> 2];
    HEAP32[$code >> 2] = $509;
    var $reqByte_6 = $reqByte_1;
    __label__ = 176;
    break;
   case 149:
    var $511 = ($506 | 0) < 2;
    HEAP8[$504] = 0;
    var $512 = HEAP32[$previous >> 2];
    if ($511) {
      __label__ = 150;
      break;
    } else {
      __label__ = 151;
      break;
    }
   case 150:
    var $514 = $512 + 1 | 0;
    _llvm_memmove_p0i8_p0i8_i32($514, $512, $493, 1, 0);
    var $516 = HEAP32[$code >> 2] + 1 | 0;
    HEAP32[$code >> 2] = $516;
    var $519 = HEAP32[$previous >> 2];
    var $520 = $519 + 1 | 0;
    HEAP32[$previous >> 2] = $520;
    HEAP8[$519] = ($repeatType_0 | 64) & 255;
    var $bralink_0 = 0;
    __label__ = 152;
    break;
   case 151:
    var $522 = $512 + 7 | 0;
    _llvm_memmove_p0i8_p0i8_i32($522, $512, $493, 1, 0);
    var $524 = HEAP32[$code >> 2] + 7 | 0;
    HEAP32[$code >> 2] = $524;
    var $527 = HEAP32[$previous >> 2];
    var $528 = $527 + 1 | 0;
    HEAP32[$previous >> 2] = $528;
    HEAP8[$527] = ($repeatType_0 | 64) & 255;
    var $529 = HEAP32[$previous >> 2];
    var $530 = $529 + 1 | 0;
    HEAP32[$previous >> 2] = $530;
    HEAP8[$529] = 67;
    var $531 = HEAP32[$previous >> 2];
    __ZL31putLinkValueAllowZeroAndAdvanceRPhi($previous, 0);
    __ZL23put2ByteValueAndAdvanceRPhi($previous, $495);
    var $bralink_0 = $531;
    __label__ = 152;
    break;
   case 152:
    var $bralink_0;
    var $534 = HEAP32[$repeat_max >> 2] - 1 | 0;
    HEAP32[$repeat_max >> 2] = $534;
    var $bralink_1 = $bralink_0;
    var $reqByte_5 = $reqByte_1;
    var $552 = $534;
    __label__ = 159;
    break;
   case 153:
    if (($324 | 0) > 1) {
      __label__ = 154;
      break;
    } else {
      var $reqByte_4 = $reqByte_1;
      __label__ = 157;
      break;
    }
   case 154:
    var $reqByte_3 = ($didGroupSetFirstByte_0 & 1) << 24 >> 24 != 0 & ($reqByte_1 | 0) < 0 ? $firstByte_6 : $reqByte_1;
    var $i_047 = 2;
    var $541 = $504;
    __label__ = 155;
    break;
   case 155:
    var $541;
    var $i_047;
    var $542 = HEAP32[$previous >> 2];
    _memcpy($541, $542, $493, 1);
    var $544 = HEAP32[$code >> 2] + $493 | 0;
    HEAP32[$code >> 2] = $544;
    if (($i_047 | 0) < ($324 | 0)) {
      __label__ = 156;
      break;
    } else {
      var $reqByte_4 = $reqByte_3;
      __label__ = 157;
      break;
    }
   case 156:
    var $i_047 = $i_047 + 1 | 0;
    var $541 = $544;
    __label__ = 155;
    break;
   case 157:
    var $reqByte_4;
    var $546 = HEAP32[$repeat_max >> 2];
    if (($546 | 0) > 0) {
      __label__ = 158;
      break;
    } else {
      var $bralink_1 = 0;
      var $reqByte_5 = $reqByte_4;
      var $552 = $546;
      __label__ = 159;
      break;
    }
   case 158:
    var $550 = $546 - HEAP32[$repeatMin >> 2] | 0;
    HEAP32[$repeat_max >> 2] = $550;
    var $bralink_1 = 0;
    var $reqByte_5 = $reqByte_4;
    var $552 = $550;
    __label__ = 159;
    break;
   case 159:
    var $552;
    var $reqByte_5;
    var $bralink_1;
    if (($552 | 0) > -1) {
      __label__ = 160;
      break;
    } else {
      __label__ = 171;
      break;
    }
   case 160:
    if (($552 | 0) > 0) {
      __label__ = 161;
      break;
    } else {
      var $bralink_2_lcssa = $bralink_1;
      __label__ = 167;
      break;
    }
   case 161:
    var $556 = ($repeatType_0 | 64) & 255;
    var $bralink_241 = $bralink_1;
    var $i2_042_in = $552;
    var $558 = HEAP32[$code >> 2];
    __label__ = 162;
    break;
   case 162:
    var $558;
    var $i2_042_in;
    var $bralink_241;
    var $i2_042 = $i2_042_in - 1 | 0;
    HEAP32[$code >> 2] = $558 + 1 | 0;
    HEAP8[$558] = $556;
    if (($i2_042 | 0) == 0) {
      var $bralink_3 = $bralink_241;
      __label__ = 166;
      break;
    } else {
      __label__ = 163;
      break;
    }
   case 163:
    var $562 = HEAP32[$code >> 2];
    var $563 = $562 + 1 | 0;
    HEAP32[$code >> 2] = $563;
    HEAP8[$562] = 67;
    var $_pre48 = HEAP32[$code >> 2];
    if (($bralink_241 | 0) == 0) {
      var $569 = 0;
      __label__ = 165;
      break;
    } else {
      __label__ = 164;
      break;
    }
   case 164:
    var $569 = $_pre48 - $bralink_241 | 0;
    __label__ = 165;
    break;
   case 165:
    var $569;
    __ZL31putLinkValueAllowZeroAndAdvanceRPhi($code, $569);
    __ZL23put2ByteValueAndAdvanceRPhi($code, $495);
    var $bralink_3 = $_pre48;
    __label__ = 166;
    break;
   case 166:
    var $bralink_3;
    var $571 = HEAP32[$code >> 2];
    var $572 = HEAP32[$previous >> 2];
    _memcpy($571, $572, $493, 1);
    var $574 = HEAP32[$code >> 2] + $493 | 0;
    HEAP32[$code >> 2] = $574;
    if (($i2_042 | 0) > 0) {
      var $bralink_241 = $bralink_3;
      var $i2_042_in = $i2_042;
      var $558 = $574;
      __label__ = 162;
      break;
    } else {
      var $bralink_2_lcssa = $bralink_3;
      __label__ = 167;
      break;
    }
   case 167:
    var $bralink_2_lcssa;
    if (($bralink_2_lcssa | 0) == 0) {
      var $reqByte_6 = $reqByte_5;
      __label__ = 176;
      break;
    } else {
      var $bralink_444 = $bralink_2_lcssa;
      __label__ = 168;
      break;
    }
   case 168:
    var $bralink_444;
    var $577 = HEAP32[$code >> 2];
    var $580 = $577 - $bralink_444 | 0;
    var $581 = $580 + 1 | 0;
    var $582 = $577 + -$580 | 0;
    var $_val1 = HEAP8[$582];
    var $_idx2_val = HEAP8[$577 + (1 - $580) | 0];
    var $_idx3_val = HEAP8[$577 + (2 - $580) | 0];
    var $583 = __ZL21getLinkValueAllowZeroPKh($_val1, $_idx2_val, $_idx3_val);
    if (($583 | 0) == 0) {
      var $589 = 0;
      __label__ = 170;
      break;
    } else {
      __label__ = 169;
      break;
    }
   case 169:
    var $589 = $bralink_444 + -$583 | 0;
    __label__ = 170;
    break;
   case 170:
    var $589;
    var $590 = $577 + 1 | 0;
    HEAP32[$code >> 2] = $590;
    HEAP8[$577] = 59;
    __ZL22putLinkValueAndAdvanceRPhi($code, $581);
    __ZL12putLinkValuePhi($582, $581);
    if (($589 | 0) == 0) {
      var $reqByte_6 = $reqByte_5;
      __label__ = 176;
      break;
    } else {
      var $bralink_444 = $589;
      __label__ = 168;
      break;
    }
   case 171:
    HEAP8[HEAP32[$code >> 2] + -$ketoffset_0 | 0] = ($repeatType_0 | 60) & 255;
    var $reqByte_6 = $reqByte_5;
    __label__ = 176;
    break;
   case 172:
    if (($334 - 62 & 255 & 255) < 2) {
      __label__ = 173;
      break;
    } else {
      __label__ = 175;
      break;
    }
   case 173:
    if ($325) {
      __label__ = 174;
      break;
    } else {
      var $reqByte_6 = $reqByte_1;
      __label__ = 176;
      break;
    }
   case 174:
    HEAP32[$code >> 2] = $320;
    var $reqByte_6 = $reqByte_1;
    __label__ = 176;
    break;
   case 175:
    HEAP32[$errorCodePtr >> 2] = 11;
    var $762 = $333;
    __label__ = 229;
    break;
   case 176:
    var $reqByte_6;
    HEAP32[$previous >> 2] = 0;
    var $603 = HEAP32[$13 >> 2] | $328;
    HEAP32[$13 >> 2] = $603;
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $firstByte_6;
    var $reqByte_8 = $reqByte_6;
    var $zeroReqByte_1 = $zeroReqByte_0;
    var $zeroFirstByte_3 = $zeroFirstByte_0;
    __label__ = 228;
    break;
   case 177:
    var $605 = HEAPU32[$brackets >> 2];
    var $606 = $605 + 1 | 0;
    var $607 = $17 + 2 | 0;
    HEAP32[$ptr >> 2] = $607;
    if (HEAP16[$607 >> 1] << 16 >> 16 == 63) {
      __label__ = 178;
      break;
    } else {
      __label__ = 183;
      break;
    }
   case 178:
    var $611 = $17 + 4 | 0;
    HEAP32[$ptr >> 2] = $611;
    var $613 = HEAPU16[$611 >> 1] & 65535;
    if (($613 | 0) == 58) {
      __label__ = 179;
      break;
    } else if (($613 | 0) == 61) {
      __label__ = 180;
      break;
    } else if (($613 | 0) == 33) {
      __label__ = 181;
      break;
    } else {
      __label__ = 182;
      break;
    }
   case 179:
    HEAP32[$ptr >> 2] = $17 + 6 | 0;
    var $skipBytes_0 = 2;
    var $bravalue_0 = 67;
    __label__ = 186;
    break;
   case 180:
    HEAP32[$ptr >> 2] = $17 + 6 | 0;
    var $skipBytes_0 = 2;
    var $bravalue_0 = 62;
    __label__ = 186;
    break;
   case 181:
    HEAP32[$ptr >> 2] = $17 + 6 | 0;
    var $skipBytes_0 = 2;
    var $bravalue_0 = 63;
    __label__ = 186;
    break;
   case 182:
    HEAP32[$errorCodePtr >> 2] = 12;
    var $762 = $611;
    __label__ = 229;
    break;
   case 183:
    HEAP32[$brackets >> 2] = $606;
    if (($606 | 0) > 100) {
      __label__ = 184;
      break;
    } else {
      __label__ = 185;
      break;
    }
   case 184:
    HEAP8[HEAP32[$code >> 2] + 6 | 0] = 66;
    var $627 = HEAP32[$code >> 2] + 7 | 0;
    var $628 = HEAP32[$brackets >> 2];
    __ZL13put2ByteValuePhi($627, $628);
    var $skipBytes_0 = 5;
    var $bravalue_0 = 168;
    __label__ = 186;
    break;
   case 185:
    var $skipBytes_0 = 2;
    var $bravalue_0 = $605 + 68 | 0;
    __label__ = 186;
    break;
   case 186:
    var $bravalue_0;
    var $skipBytes_0;
    var $632 = HEAP32[$code >> 2];
    HEAP32[$previous >> 2] = $632;
    HEAP8[$632] = $bravalue_0 & 255;
    var $634 = HEAP32[$code >> 2];
    HEAP32[$tempcode >> 2] = $634;
    var $635 = HEAP32[$13 >> 2];
    var $636 = HEAP32[$brackets >> 2];
    var $637 = __ZL14compileBracketiPiPPhPPKtS3_P9ErrorCodeiS_S_R11CompileData($options, $brackets, $tempcode, $ptr, $patternEnd, $errorCodePtr, $skipBytes_0, $subFirstByte, $subReqByte, $cd);
    if ($637) {
      __label__ = 188;
      break;
    } else {
      __label__ = 187;
      break;
    }
   case 187:
    var $762 = HEAP32[$ptr >> 2];
    __label__ = 229;
    break;
   case 188:
    var $644 = (($bravalue_0 | 0) > 67 & 1) + $606 - $636 + HEAP32[$brackets >> 2] | 0;
    if (($606 & 511 | 0) == ($606 | 0)) {
      __label__ = 189;
      break;
    } else {
      __label__ = 190;
      break;
    }
   case 189:
    if (($644 & 511 | 0) == ($644 | 0)) {
      __label__ = 191;
      break;
    } else {
      __label__ = 190;
      break;
    }
   case 190:
    HEAP32[$errorCodePtr >> 2] = 17;
    var $_0 = 0;
    __label__ = 230;
    break;
   case 191:
    var $653 = HEAP32[$code >> 2] + 4 | 0;
    var $655 = $644 | $606 << 8;
    __ZL13put2ByteValuePhi($653, $655);
    if (($bravalue_0 | 0) > 66) {
      __label__ = 192;
      break;
    } else {
      __label__ = 200;
      break;
    }
   case 192:
    var $659 = HEAPU32[$subFirstByte >> 2];
    var $660 = ($659 | 0) > -1;
    if (($firstByte_0 | 0) == -2) {
      __label__ = 193;
      break;
    } else {
      __label__ = 194;
      break;
    }
   case 193:
    var $_ = $660 ? $659 : -1;
    var $didGroupSetFirstByte_2_ph = $659 >>> 31 & 255 ^ 1;
    var $firstByte_8_ph = $_;
    var $zeroFirstByte_1_ph = -1;
    __label__ = 197;
    break;
   case 194:
    if ($660) {
      __label__ = 195;
      break;
    } else {
      var $didGroupSetFirstByte_2_ph = 0;
      var $firstByte_8_ph = $firstByte_0;
      var $zeroFirstByte_1_ph = $firstByte_0;
      __label__ = 197;
      break;
    }
   case 195:
    var $665 = HEAPU32[$subReqByte >> 2];
    if (($665 | 0) < 0) {
      __label__ = 196;
      break;
    } else {
      var $672 = $665;
      var $zeroFirstByte_128 = $firstByte_0;
      var $firstByte_829 = $firstByte_0;
      var $didGroupSetFirstByte_230 = 0;
      __label__ = 199;
      break;
    }
   case 196:
    var $668 = $659 | $635;
    HEAP32[$subReqByte >> 2] = $668;
    var $didGroupSetFirstByte_2 = 0;
    var $firstByte_8 = $firstByte_0;
    var $zeroFirstByte_1 = $firstByte_0;
    var $670 = $668;
    __label__ = 198;
    break;
   case 197:
    var $zeroFirstByte_1_ph;
    var $firstByte_8_ph;
    var $didGroupSetFirstByte_2_ph;
    var $didGroupSetFirstByte_2 = $didGroupSetFirstByte_2_ph;
    var $firstByte_8 = $firstByte_8_ph;
    var $zeroFirstByte_1 = $zeroFirstByte_1_ph;
    var $670 = HEAP32[$subReqByte >> 2];
    __label__ = 198;
    break;
   case 198:
    var $670;
    var $zeroFirstByte_1;
    var $firstByte_8;
    var $didGroupSetFirstByte_2;
    if (($670 | 0) > -1) {
      var $672 = $670;
      var $zeroFirstByte_128 = $zeroFirstByte_1;
      var $firstByte_829 = $firstByte_8;
      var $didGroupSetFirstByte_230 = $didGroupSetFirstByte_2;
      __label__ = 199;
      break;
    } else {
      var $didGroupSetFirstByte_3 = $didGroupSetFirstByte_2;
      var $firstByte_9 = $firstByte_8;
      var $reqByte_7 = $reqByte_0;
      var $zeroFirstByte_2 = $zeroFirstByte_1;
      __label__ = 203;
      break;
    }
   case 199:
    var $didGroupSetFirstByte_230;
    var $firstByte_829;
    var $zeroFirstByte_128;
    var $672;
    var $didGroupSetFirstByte_3 = $didGroupSetFirstByte_230;
    var $firstByte_9 = $firstByte_829;
    var $reqByte_7 = $672;
    var $zeroFirstByte_2 = $zeroFirstByte_128;
    __label__ = 203;
    break;
   case 200:
    if (($bravalue_0 | 0) == 62) {
      __label__ = 201;
      break;
    } else {
      var $didGroupSetFirstByte_3 = 0;
      var $firstByte_9 = $firstByte_0;
      var $reqByte_7 = $reqByte_0;
      var $zeroFirstByte_2 = $firstByte_0;
      __label__ = 203;
      break;
    }
   case 201:
    var $676 = HEAP32[$subReqByte >> 2];
    if (($676 | 0) > -1) {
      __label__ = 202;
      break;
    } else {
      var $didGroupSetFirstByte_3 = 0;
      var $firstByte_9 = $firstByte_0;
      var $reqByte_7 = $reqByte_0;
      var $zeroFirstByte_2 = $firstByte_0;
      __label__ = 203;
      break;
    }
   case 202:
    var $didGroupSetFirstByte_3 = 0;
    var $firstByte_9 = $firstByte_0;
    var $reqByte_7 = $676;
    var $zeroFirstByte_2 = $firstByte_0;
    __label__ = 203;
    break;
   case 203:
    var $zeroFirstByte_2;
    var $reqByte_7;
    var $firstByte_9;
    var $didGroupSetFirstByte_3;
    var $680 = HEAP32[$tempcode >> 2];
    HEAP32[$code >> 2] = $680;
    var $681 = HEAPU32[$ptr >> 2];
    if ($681 >>> 0 < $patternEnd >>> 0) {
      __label__ = 204;
      break;
    } else {
      __label__ = 205;
      break;
    }
   case 204:
    if (HEAP16[$681 >> 1] << 16 >> 16 == 41) {
      var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_3;
      var $firstByte_11 = $firstByte_9;
      var $reqByte_8 = $reqByte_7;
      var $zeroReqByte_1 = $reqByte_0;
      var $zeroFirstByte_3 = $zeroFirstByte_2;
      __label__ = 228;
      break;
    } else {
      __label__ = 205;
      break;
    }
   case 205:
    HEAP32[$errorCodePtr >> 2] = 14;
    var $762 = $681;
    __label__ = 229;
    break;
   case 206:
    var $688 = HEAP32[$12 >> 2];
    var $689 = __ZL11checkEscapePPKtS0_P9ErrorCodeib($ptr, $patternEnd, $errorCodePtr, $688, 0);
    if (($689 | 0) < 0) {
      __label__ = 207;
      break;
    } else {
      var $c_13 = $689;
      __label__ = 214;
      break;
    }
   case 207:
    if (($firstByte_0 | 0) == -2) {
      __label__ = 208;
      break;
    } else {
      var $firstByte_10 = $firstByte_0;
      __label__ = 210;
      break;
    }
   case 208:
    if ((-3 - $689 | 0) >>> 0 < 6) {
      __label__ = 209;
      break;
    } else {
      var $firstByte_10 = -2;
      __label__ = 210;
      break;
    }
   case 209:
    var $firstByte_10 = -1;
    __label__ = 210;
    break;
   case 210:
    var $firstByte_10;
    var $697 = -$689 | 0;
    if (($697 | 0) > 8) {
      __label__ = 211;
      break;
    } else {
      __label__ = 212;
      break;
    }
   case 211:
    var $700 = -9 - $689 | 0;
    var $701 = HEAP32[$code >> 2];
    HEAP32[$previous >> 2] = $701;
    var $702 = $701 + 1 | 0;
    HEAP32[$code >> 2] = $702;
    HEAP8[$701] = 57;
    __ZL23put2ByteValueAndAdvanceRPhi($code, $700);
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $firstByte_10;
    var $reqByte_8 = $reqByte_0;
    var $zeroReqByte_1 = $reqByte_0;
    var $zeroFirstByte_3 = $firstByte_10;
    __label__ = 228;
    break;
   case 212:
    var $705 = HEAP32[$code >> 2];
    var $706 = ($697 | 0) > 2 ? $705 : 0;
    HEAP32[$previous >> 2] = $706;
    var $707 = $697 & 255;
    var $708 = $705 + 1 | 0;
    HEAP32[$code >> 2] = $708;
    HEAP8[$705] = $707;
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $firstByte_10;
    var $reqByte_8 = $reqByte_0;
    var $zeroReqByte_1 = $reqByte_0;
    var $zeroFirstByte_3 = $firstByte_10;
    __label__ = 228;
    break;
   case 213:
    var $709 = HEAP32[$code >> 2];
    HEAP32[$previous >> 2] = $709;
    var $c_1332 = $23;
    var $713 = $709;
    __label__ = 215;
    break;
   case 214:
    var $c_13;
    var $710 = HEAP32[$code >> 2];
    HEAP32[$previous >> 2] = $710;
    if (($c_13 | 0) < 128) {
      var $c_1332 = $c_13;
      var $713 = $710;
      __label__ = 215;
      break;
    } else {
      __label__ = 219;
      break;
    }
   case 215:
    var $713;
    var $c_1332;
    var $714 = $c_1332 & 255;
    HEAP8[$6] = $714;
    if ($4) {
      __label__ = 216;
      break;
    } else {
      __label__ = 218;
      break;
    }
   case 216:
    var $716 = $c_1332 | 32;
    if (($716 - 97 | 0) >>> 0 < 26) {
      __label__ = 217;
      break;
    } else {
      __label__ = 218;
      break;
    }
   case 217:
    HEAP32[$code >> 2] = $713 + 1 | 0;
    HEAP8[$713] = 17;
    var $721 = HEAP32[$code >> 2];
    var $722 = $721 + 1 | 0;
    HEAP32[$code >> 2] = $722;
    HEAP8[$721] = $716 & 255;
    var $mcLength_0 = 1;
    __label__ = 222;
    break;
   case 218:
    HEAP32[$code >> 2] = $713 + 1 | 0;
    HEAP8[$713] = 16;
    var $725 = HEAP32[$code >> 2];
    var $726 = $725 + 1 | 0;
    HEAP32[$code >> 2] = $726;
    HEAP8[$725] = $714;
    var $mcLength_0 = 1;
    __label__ = 222;
    break;
   case 219:
    var $728 = __ZL10encodeUTF8iPh($c_13, $6);
    var $729 = HEAP32[$code >> 2];
    var $730 = $729 + 1 | 0;
    HEAP32[$code >> 2] = $730;
    HEAP8[$729] = $8;
    if (($728 | 0) > 0) {
      var $c_1454 = 0;
      __label__ = 220;
      break;
    } else {
      __label__ = 221;
      break;
    }
   case 220:
    var $c_1454;
    var $733 = HEAP8[$mcbuffer + $c_1454 | 0];
    var $734 = HEAP32[$code >> 2];
    var $735 = $734 + 1 | 0;
    HEAP32[$code >> 2] = $735;
    HEAP8[$734] = $733;
    var $736 = $c_1454 + 1 | 0;
    if (($736 | 0) == ($728 | 0)) {
      __label__ = 221;
      break;
    } else {
      var $c_1454 = $736;
      __label__ = 220;
      break;
    }
   case 221:
    var $mcLength_0 = ($728 | 0) == 1;
    __label__ = 222;
    break;
   case 222:
    var $mcLength_0;
    var $or_cond20 = $mcLength_0 | $14;
    if (($firstByte_0 | 0) == -2) {
      __label__ = 223;
      break;
    } else {
      __label__ = 226;
      break;
    }
   case 223:
    if ($or_cond20) {
      __label__ = 224;
      break;
    } else {
      var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
      var $firstByte_11 = -1;
      var $reqByte_8 = -1;
      var $zeroReqByte_1 = $reqByte_0;
      var $zeroFirstByte_3 = -1;
      __label__ = 228;
      break;
    }
   case 224:
    var $743 = HEAPU8[$6] & 255 | $5;
    if ($mcLength_0) {
      var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
      var $firstByte_11 = $743;
      var $reqByte_8 = $reqByte_0;
      var $zeroReqByte_1 = $reqByte_0;
      var $zeroFirstByte_3 = -1;
      __label__ = 228;
      break;
    } else {
      __label__ = 225;
      break;
    }
   case 225:
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $743;
    var $reqByte_8 = HEAPU8[HEAP32[$code >> 2] - 1 | 0] & 255 | HEAP32[$13 >> 2];
    var $zeroReqByte_1 = $reqByte_0;
    var $zeroFirstByte_3 = -1;
    __label__ = 228;
    break;
   case 226:
    if ($or_cond20) {
      __label__ = 227;
      break;
    } else {
      var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
      var $firstByte_11 = $firstByte_0;
      var $reqByte_8 = $reqByte_0;
      var $zeroReqByte_1 = $reqByte_0;
      var $zeroFirstByte_3 = $firstByte_0;
      __label__ = 228;
      break;
    }
   case 227:
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $firstByte_0;
    var $reqByte_8 = HEAP32[$13 >> 2] | $5 | HEAPU8[HEAP32[$code >> 2] - 1 | 0] & 255;
    var $zeroReqByte_1 = $reqByte_0;
    var $zeroFirstByte_3 = $firstByte_0;
    __label__ = 228;
    break;
   case 228:
    var $zeroFirstByte_3;
    var $zeroReqByte_1;
    var $reqByte_8;
    var $firstByte_11;
    var $didGroupSetFirstByte_4;
    var $761 = HEAP32[$ptr >> 2] + 2 | 0;
    HEAP32[$ptr >> 2] = $761;
    var $didGroupSetFirstByte_0 = $didGroupSetFirstByte_4;
    var $firstByte_0 = $firstByte_11;
    var $reqByte_0 = $reqByte_8;
    var $zeroReqByte_0 = $zeroReqByte_1;
    var $zeroFirstByte_0 = $zeroFirstByte_3;
    var $17 = $761;
    __label__ = 2;
    break;
   case 229:
    var $762;
    HEAP32[$ptrPtr >> 2] = $762;
    var $_0 = 0;
    __label__ = 230;
    break;
   case 230:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13compileBranchiPiPPhPPKtS3_P9ErrorCodeS_S_R11CompileData["X"] = 1;

function __ZL13get2ByteValuePKh($opcodePtr_val, $opcodePtr_1_val) {
  return ($opcodePtr_val & 255) << 8 | $opcodePtr_1_val & 255;
}

function __ZL13get3ByteValuePKh($opcodePtr_val, $opcodePtr_1_val, $opcodePtr_2_val) {
  return $opcodePtr_2_val & 255 | ($opcodePtr_val & 255) << 16 | ($opcodePtr_1_val & 255) << 8;
}

function __ZL13put2ByteValuePhi($opcodePtr, $value) {
  HEAP8[$opcodePtr] = $value >>> 8 & 255;
  HEAP8[$opcodePtr + 1 | 0] = $value & 255;
  return;
}

function __ZL8flipCaseh($c) {
  var $2 = STRING_TABLE._jsc_pcre_default_tables + (($c & 255) + 128) | 0;
  return HEAP8[$2];
}

function __ZL22firstSignificantOpcodePKh($code) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAP8[$code] << 24 >> 24 == 66) {
      var $_01 = $code;
      __label__ = 2;
      break;
    } else {
      var $_0_lcssa = $code;
      __label__ = 3;
      break;
    }
   case 2:
    var $_01;
    var $3 = $_01 + 3 | 0;
    if (HEAP8[$3] << 24 >> 24 == 66) {
      var $_01 = $3;
      __label__ = 2;
      break;
    } else {
      var $_0_lcssa = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $_0_lcssa;
    return $_0_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13put3ByteValuePhi($opcodePtr, $value) {
  HEAP8[$opcodePtr] = $value >>> 16 & 255;
  HEAP8[$opcodePtr + 1 | 0] = $value >>> 8 & 255;
  HEAP8[$opcodePtr + 2 | 0] = $value & 255;
  return;
}

function __ZL18classBitmapForCharh($c) {
  var $2 = STRING_TABLE._jsc_pcre_default_tables + ($c & 255 | 256) | 0;
  return HEAP8[$2];
}

function __ZL10encodeUTF8iPh($cvalue, $buffer) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if (($i_0 | 0) < 6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $j_02 = $i_0;
    var $_013 = $buffer + $i_0 | 0;
    var $_04 = $cvalue;
    __label__ = 7;
    break;
   case 4:
    if ((HEAP32[_jsc_pcre_utf8_table1 + ($i_0 << 2) >> 2] | 0) < ($cvalue | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 6:
    var $11 = $buffer + $i_0 | 0;
    if (($i_0 | 0) > 0) {
      var $j_02 = $i_0;
      var $_013 = $11;
      var $_04 = $cvalue;
      __label__ = 7;
      break;
    } else {
      var $_01_lcssa = $11;
      var $_0_lcssa = $cvalue;
      __label__ = 8;
      break;
    }
   case 7:
    var $_04;
    var $_013;
    var $j_02;
    HEAP8[$_013] = ($_04 & 63 | 128) & 255;
    var $17 = $_04 >> 6;
    var $18 = $j_02 - 1 | 0;
    if (($18 | 0) > 0) {
      var $j_02 = $18;
      var $_013 = $_013 - 1 | 0;
      var $_04 = $17;
      __label__ = 7;
      break;
    } else {
      var $_01_lcssa = $buffer;
      var $_0_lcssa = $17;
      __label__ = 8;
      break;
    }
   case 8:
    var $_0_lcssa;
    var $_01_lcssa;
    HEAP8[$_01_lcssa] = (HEAP32[_jsc_pcre_utf8_table2 + ($i_0 << 2) >> 2] | $_0_lcssa) & 255;
    return $i_0 + 1 | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14compileBracketiPiPPhPPKtS3_P9ErrorCodeiS_S_R11CompileData($options, $brackets, $codePtr, $ptrPtr, $patternEnd, $errorCodePtr, $skipBytes, $firstbyteptr, $reqbyteptr, $cd) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ptr = __stackBase__;
    var $code = __stackBase__ + 4;
    var $branchFirstByte = __stackBase__ + 8;
    var $branchReqByte = __stackBase__ + 12;
    var $1 = HEAP32[$ptrPtr >> 2];
    HEAP32[$ptr >> 2] = $1;
    var $2 = HEAPU32[$codePtr >> 2];
    var $3 = $2 + 1 | 0;
    __ZL21putLinkValueAllowZeroPhi($3, 0);
    HEAP32[$code >> 2] = $skipBytes + ($2 + 4) | 0;
    var $reqByte_0 = -2;
    var $firstByte_0 = -2;
    var $lastBranch_0 = $2;
    __label__ = 2;
    break;
   case 2:
    var $lastBranch_0;
    var $firstByte_0;
    var $reqByte_0;
    var $7 = __ZL13compileBranchiPiPPhPPKtS3_P9ErrorCodeS_S_R11CompileData($options, $brackets, $code, $ptr, $patternEnd, $errorCodePtr, $branchFirstByte, $branchReqByte, $cd);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAP32[$ptr >> 2];
    HEAP32[$ptrPtr >> 2] = $9;
    var $_0 = 0;
    __label__ = 19;
    break;
   case 4:
    if (HEAP8[$lastBranch_0] << 24 >> 24 == 58) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $reqByte_3 = HEAP32[$branchReqByte >> 2];
    var $firstByte_2 = HEAP32[$branchFirstByte >> 2];
    __label__ = 13;
    break;
   case 6:
    var $18 = HEAP32[$branchFirstByte >> 2];
    if (($firstByte_0 | 0) > -1) {
      __label__ = 7;
      break;
    } else {
      var $reqByte_2_ph = $reqByte_0;
      var $firstByte_1_ph = $firstByte_0;
      var $23 = $18;
      __label__ = 9;
      break;
    }
   case 7:
    if (($firstByte_0 | 0) == ($18 | 0)) {
      var $firstByte_11 = $firstByte_0;
      var $reqByte_23 = $reqByte_0;
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $reqByte_1 = ($reqByte_0 | 0) < 0 ? $firstByte_0 : $reqByte_0;
    var $reqByte_2_ph = $reqByte_1;
    var $firstByte_1_ph = -1;
    var $23 = $18;
    __label__ = 9;
    break;
   case 9:
    var $23;
    var $firstByte_1_ph;
    var $reqByte_2_ph;
    if (($23 | 0) > -1) {
      __label__ = 10;
      break;
    } else {
      var $firstByte_11 = $firstByte_1_ph;
      var $reqByte_23 = $reqByte_2_ph;
      __label__ = 12;
      break;
    }
   case 10:
    if ((HEAP32[$branchReqByte >> 2] | 0) < 0) {
      __label__ = 11;
      break;
    } else {
      var $firstByte_11 = $firstByte_1_ph;
      var $reqByte_23 = $reqByte_2_ph;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$branchReqByte >> 2] = $23;
    var $firstByte_11 = $firstByte_1_ph;
    var $reqByte_23 = $reqByte_2_ph;
    __label__ = 12;
    break;
   case 12:
    var $reqByte_23;
    var $firstByte_11;
    var $29 = HEAP32[$branchReqByte >> 2];
    var $_ = (($29 ^ $reqByte_23) & -513 | 0) == 0 ? $29 | $reqByte_23 : -1;
    var $reqByte_3 = $_;
    var $firstByte_2 = $firstByte_11;
    __label__ = 13;
    break;
   case 13:
    var $firstByte_2;
    var $reqByte_3;
    var $35 = HEAPU32[$ptr >> 2];
    if ($35 >>> 0 < $patternEnd >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    if (HEAP16[$35 >> 1] << 16 >> 16 == 124) {
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $length_0 = HEAP32[$code >> 2] - $lastBranch_0 | 0;
    var $lastBranch_1 = $lastBranch_0;
    __label__ = 16;
    break;
   case 16:
    var $lastBranch_1;
    var $length_0;
    var $46 = $lastBranch_1 + 1 | 0;
    var $_val = HEAP8[$46];
    var $_idx_val = HEAP8[$lastBranch_1 + 2 | 0];
    var $_idx1_val = HEAP8[$lastBranch_1 + 3 | 0];
    var $47 = __ZL21getLinkValueAllowZeroPKh($_val, $_idx_val, $_idx1_val);
    __ZL12putLinkValuePhi($46, $length_0);
    if (($47 | 0) > 0) {
      var $length_0 = $47;
      var $lastBranch_1 = $lastBranch_1 + -$47 | 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $52 = HEAP32[$code >> 2];
    HEAP8[$52] = 59;
    var $53 = $52 + 1 | 0;
    var $56 = $52 - $2 | 0;
    __ZL12putLinkValuePhi($53, $56);
    var $57 = $52 + 4 | 0;
    HEAP32[$code >> 2] = $57;
    HEAP32[$codePtr >> 2] = $57;
    var $58 = HEAP32[$ptr >> 2];
    HEAP32[$ptrPtr >> 2] = $58;
    HEAP32[$firstbyteptr >> 2] = $firstByte_2;
    HEAP32[$reqbyteptr >> 2] = $reqByte_3;
    var $_0 = 1;
    __label__ = 19;
    break;
   case 18:
    var $60 = HEAPU32[$code >> 2];
    HEAP8[$60] = 58;
    var $61 = $60 + 1 | 0;
    var $64 = $60 - $lastBranch_0 | 0;
    __ZL12putLinkValuePhi($61, $64);
    HEAP32[$code >> 2] = $60 + 4 | 0;
    HEAP32[$ptr >> 2] = $35 + 2 | 0;
    var $reqByte_0 = $reqByte_3;
    var $firstByte_0 = $firstByte_2;
    var $lastBranch_0 = $60;
    __label__ = 2;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14compileBracketiPiPPhPPKtS3_P9ErrorCodeiS_S_R11CompileData["X"] = 1;

function __ZN2js10Foreground12array_deleteIcEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $p - 8 | 0;
    _js_free4455($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17bracketIsAnchoredPKh($code) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $code;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $3 = __ZL16branchIsAnchoredPKh($_01 + 4 | 0);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_val = HEAP8[$_01 + 1 | 0];
    var $_idx_val = HEAP8[$_01 + 2 | 0];
    var $_idx1_val = HEAP8[$_01 + 3 | 0];
    var $6 = __ZL12getLinkValuePKh($_val, $_idx_val, $_idx1_val);
    var $7 = $_01 + $6 | 0;
    if (HEAP8[$7] << 24 >> 24 == 58) {
      var $_01 = $7;
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16branchIsAnchoredPKh($code) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL22firstSignificantOpcodePKh($code);
    var $2 = HEAPU8[$1];
    if (($2 & 255) > 66 | $2 << 24 >> 24 == 62) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZL17bracketIsAnchoredPKh($1);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 3:
    var $_0 = $2 << 24 >> 24 == 10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL33bracketFindFirstAssertedCharacterPKhb($code, $inassert) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $code;
    var $c_0 = -1;
    __label__ = 2;
    break;
   case 2:
    var $c_0;
    var $_01;
    var $2 = $_01 + 1 | 0;
    var $4 = __ZL32branchFindFirstAssertedCharacterPKhb($_01 + 4 | 0, $inassert);
    if (($4 | 0) < 0) {
      var $_0 = -1;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($c_0 | 0) < 0) {
      var $c_1 = $4;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($c_0 | 0) == ($4 | 0)) {
      var $c_1 = $c_0;
      __label__ = 5;
      break;
    } else {
      var $_0 = -1;
      __label__ = 6;
      break;
    }
   case 5:
    var $c_1;
    var $_val = HEAP8[$2];
    var $_idx_val = HEAP8[$_01 + 2 | 0];
    var $_idx1_val = HEAP8[$_01 + 3 | 0];
    var $11 = __ZL12getLinkValuePKh($_val, $_idx_val, $_idx1_val);
    var $12 = $_01 + $11 | 0;
    if (HEAP8[$12] << 24 >> 24 == 58) {
      var $_01 = $12;
      var $c_0 = $c_1;
      __label__ = 2;
      break;
    } else {
      var $_0 = $c_1;
      __label__ = 6;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL32branchFindFirstAssertedCharacterPKhb($code, $inassert) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL40firstSignificantOpcodeSkippingAssertionsPKh($code);
    var $3 = HEAPU8[$1] & 255;
    var $op_0 = $3 >>> 0 < 67 ? $3 : 67;
    if (($op_0 | 0) == 67 || ($op_0 | 0) == 62) {
      __label__ = 2;
      break;
    } else if (($op_0 | 0) == 27) {
      __label__ = 3;
      break;
    } else if (($op_0 | 0) == 14 || ($op_0 | 0) == 15 || ($op_0 | 0) == 16 || ($op_0 | 0) == 17 || ($op_0 | 0) == 21 || ($op_0 | 0) == 22) {
      var $scode_0 = $1;
      __label__ = 4;
      break;
    } else {
      var $_0 = -1;
      __label__ = 6;
      break;
    }
   case 2:
    var $6 = ($op_0 | 0) == 62;
    var $7 = __ZL33bracketFindFirstAssertedCharacterPKhb($1, $6);
    var $_0 = $7;
    __label__ = 6;
    break;
   case 3:
    var $scode_0 = $1 + 2 | 0;
    __label__ = 4;
    break;
   case 4:
    var $scode_0;
    if ($inassert) {
      __label__ = 5;
      break;
    } else {
      var $_0 = -1;
      __label__ = 6;
      break;
    }
   case 5:
    var $_0 = HEAPU8[$scode_0 + 1 | 0] & 255;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21bracketNeedsLineStartPKhjj($code, $captureMap, $backrefMap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $code;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $3 = __ZL20branchNeedsLineStartPKhjj($_01 + 4 | 0, $captureMap, $backrefMap);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_val = HEAP8[$_01 + 1 | 0];
    var $_idx_val = HEAP8[$_01 + 2 | 0];
    var $_idx1_val = HEAP8[$_01 + 3 | 0];
    var $6 = __ZL12getLinkValuePKh($_val, $_idx_val, $_idx1_val);
    var $7 = $_01 + $6 | 0;
    if (HEAP8[$7] << 24 >> 24 == 58) {
      var $_01 = $7;
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20branchNeedsLineStartPKhjj($code, $captureMap, $backrefMap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL22firstSignificantOpcodePKh($code);
    var $2 = HEAPU8[$1];
    if (($2 & 255) > 67) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $6 = ($2 & 255) - 67 | 0;
    if (($6 | 0) > 100) {
      __label__ = 3;
      break;
    } else {
      var $captureNum_0 = $6;
      __label__ = 4;
      break;
    }
   case 3:
    var $_val = HEAP8[$1 + 5 | 0];
    var $_idx_val = HEAP8[$1 + 6 | 0];
    var $10 = __ZL13get2ByteValuePKh($_val, $_idx_val);
    var $captureNum_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $captureNum_0;
    var $_ = ($captureNum_0 | 0) < 32 ? 1 << $captureNum_0 : 1;
    var $14 = $_ | $captureMap;
    var $15 = __ZL21bracketNeedsLineStartPKhjj($1, $14, $backrefMap);
    var $_0 = $15;
    __label__ = 11;
    break;
   case 5:
    if ($2 << 24 >> 24 == 67 || $2 << 24 >> 24 == 62) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $18 = __ZL21bracketNeedsLineStartPKhjj($1, $captureMap, $backrefMap);
    var $_0 = $18;
    __label__ = 11;
    break;
   case 7:
    if (($2 - 37 & 255 & 255) < 2) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    if (HEAP8[$1 + 1 | 0] << 24 >> 24 == 9) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 9:
    var $_0 = ($backrefMap & $captureMap | 0) == 0;
    __label__ = 11;
    break;
   case 10:
    var $_0 = $2 << 24 >> 24 == 10 | $2 << 24 >> 24 == 12;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z12jsRegExpFreeP8JSRegExp($re) {
  var $1 = $re;
  __ZN2js10Foreground12array_deleteIcEEvPT_($1);
  return;
}

function _js_free4455($p) {
  _free($p);
  return;
}

function _js_malloc4456($bytes) {
  var $1 = _malloc($bytes);
  return $1;
}

function __ZL12getLinkValuePKh($opcodePtr_val1, $opcodePtr_1_val, $opcodePtr_2_val) {
  var $1 = __ZL21getLinkValueAllowZeroPKh($opcodePtr_val1, $opcodePtr_1_val, $opcodePtr_2_val);
  return $1;
}

function __ZL21getLinkValueAllowZeroPKh($opcodePtr_val1, $opcodePtr_1_val, $opcodePtr_2_val) {
  var $1 = __ZL13get3ByteValuePKh($opcodePtr_val1, $opcodePtr_1_val, $opcodePtr_2_val);
  return $1;
}

function __ZL40firstSignificantOpcodeSkippingAssertionsPKh($code) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $code;
    var $2 = $code;
    __label__ = 2;
    break;
   case 2:
    var $2;
    var $4 = HEAPU8[$2] & 255;
    if (($4 | 0) == 63) {
      __label__ = 3;
      break;
    } else if (($4 | 0) == 2 || ($4 | 0) == 1) {
      __label__ = 4;
      break;
    } else if (($4 | 0) == 66) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    __ZL21advanceToEndOfBracketRPKh($1);
    var $7 = HEAP32[$1 >> 2] + 4 | 0;
    HEAP32[$1 >> 2] = $7;
    var $2 = $7;
    __label__ = 2;
    break;
   case 4:
    var $9 = $2 + 1 | 0;
    HEAP32[$1 >> 2] = $9;
    var $2 = $9;
    __label__ = 2;
    break;
   case 5:
    var $11 = $2 + 3 | 0;
    HEAP32[$1 >> 2] = $11;
    var $2 = $11;
    __label__ = 2;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21advanceToEndOfBracketRPKh($opcodePtr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$opcodePtr >> 2];
    __label__ = 2;
    break;
   case 2:
    var $2;
    var $_val = HEAP8[$2 + 1 | 0];
    var $_idx_val = HEAP8[$2 + 2 | 0];
    var $_idx1_val = HEAP8[$2 + 3 | 0];
    var $4 = __ZL12getLinkValuePKh($_val, $_idx_val, $_idx1_val);
    var $5 = $2 + $4 | 0;
    HEAP32[$opcodePtr >> 2] = $5;
    if (HEAP8[$5] << 24 >> 24 == 58) {
      var $2 = $5;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21putLinkValueAllowZeroPhi($opcodePtr, $value) {
  __ZL13put3ByteValuePhi($opcodePtr, $value);
  return;
}

function __ZL12putLinkValuePhi($opcodePtr, $value) {
  __ZL21putLinkValueAllowZeroPhi($opcodePtr, $value);
  return;
}

function __ZL15isCountedRepeatPKtS0_($p, $patternEnd) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($p >>> 0 < $patternEnd >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 2:
    var $3 = HEAP16[$p >> 1];
    var $4 = __ZN3WTF12isASCIIDigitEt($3);
    if ($4) {
      var $p_pn = $p;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 3:
    var $p_pn;
    var $_01 = $p_pn + 2 | 0;
    if ($_01 >>> 0 < $patternEnd >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 4:
    var $7 = HEAPU16[$_01 >> 1];
    var $8 = __ZN3WTF12isASCIIDigitEt($7);
    if ($8) {
      var $p_pn = $_01;
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ($7 << 16 >> 16 == 125) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $12 = $p_pn + 4 | 0;
    if ($7 << 16 >> 16 == 44 & $12 >>> 0 < $patternEnd >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 7:
    var $16 = HEAPU16[$12 >> 1];
    if ($16 << 16 >> 16 == 125) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $19 = __ZN3WTF12isASCIIDigitEt($16);
    if ($19) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 9:
    var $_1 = $p_pn + 6 | 0;
    __label__ = 10;
    break;
   case 10:
    var $_1;
    if ($_1 >>> 0 < $patternEnd >>> 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 11:
    var $25 = HEAPU16[$_1 >> 1];
    var $26 = __ZN3WTF12isASCIIDigitEt($25);
    if ($26) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $_1 = $_1 + 2 | 0;
    __label__ = 10;
    break;
   case 13:
    var $_0 = $25 << 16 >> 16 == 125;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11checkEscapePPKtS0_P9ErrorCodeib($ptrPtr, $patternEnd, $errorCodePtr, $bracount, $isClass) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[$ptrPtr >> 2];
    var $2 = $1 + 2 | 0;
    if (($2 | 0) == ($patternEnd | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$errorCodePtr >> 2] = 1;
    HEAP32[$ptrPtr >> 2] = $2;
    var $_0 = 0;
    __label__ = 40;
    break;
   case 3:
    var $6 = HEAPU16[$2 >> 1];
    var $7 = $6 & 65535;
    if (($6 - 48 & 65535 & 65535) > 74) {
      var $ptr_3 = $2;
      var $c_7 = $7;
      __label__ = 39;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 - 48 | 0;
    var $12 = HEAP16[__ZL7escapes + ($10 << 1) >> 1];
    var $13 = $12 << 16 >> 16;
    if ($12 << 16 >> 16 == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ($isClass) {
      __label__ = 6;
      break;
    } else {
      var $ptr_3 = $2;
      var $c_7 = $13;
      __label__ = 39;
      break;
    }
   case 6:
    var $17 = -$13 | 0;
    if (($17 | 0) == 2) {
      var $ptr_3 = $2;
      var $c_7 = 8;
      __label__ = 39;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($17 | 0) == 1) {
      __label__ = 8;
      break;
    } else {
      var $ptr_3 = $2;
      var $c_7 = $13;
      __label__ = 39;
      break;
    }
   case 8:
    var $ptr_3 = $2;
    var $c_7 = 66;
    __label__ = 39;
    break;
   case 9:
    if (($7 | 0) == 49 || ($7 | 0) == 50 || ($7 | 0) == 51 || ($7 | 0) == 52 || ($7 | 0) == 53 || ($7 | 0) == 54 || ($7 | 0) == 55 || ($7 | 0) == 56 || ($7 | 0) == 57) {
      __label__ = 10;
      break;
    } else if (($7 | 0) == 48) {
      var $c_1 = 48;
      __label__ = 17;
      break;
    } else if (($7 | 0) == 120) {
      var $i1_0 = 1;
      var $c_3 = 0;
      __label__ = 23;
      break;
    } else if (($7 | 0) == 117) {
      var $i3_0 = 1;
      var $c_5 = 0;
      __label__ = 28;
      break;
    } else if (($7 | 0) == 99) {
      __label__ = 33;
      break;
    } else {
      var $ptr_3 = $2;
      var $c_7 = $7;
      __label__ = 39;
      break;
    }
   case 10:
    if ($isClass) {
      __label__ = 16;
      break;
    } else {
      var $ptr_0 = $2;
      var $c_0 = $10;
      __label__ = 11;
      break;
    }
   case 11:
    var $c_0;
    var $ptr_0;
    var $24 = $ptr_0 + 2 | 0;
    if ($24 >>> 0 < $patternEnd >>> 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $27 = HEAPU16[$24 >> 1];
    var $28 = __ZN3WTF12isASCIIDigitEt($27);
    if ($28 & ($c_0 | 0) <= ($bracount | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $34 = $c_0 * 10 - 48 + ($27 & 65535) | 0;
    var $ptr_0 = $24;
    var $c_0 = $34;
    __label__ = 11;
    break;
   case 14:
    if (($c_0 | 0) > ($bracount | 0)) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $ptr_3 = $ptr_0;
    var $c_7 = -9 - $c_0 | 0;
    __label__ = 39;
    break;
   case 16:
    if (($6 & 65535) > 55) {
      var $ptr_3 = $1;
      var $c_7 = 92;
      __label__ = 39;
      break;
    } else {
      var $c_1 = $7;
      __label__ = 17;
      break;
    }
   case 17:
    var $c_1;
    var $i_0 = 1;
    var $c_2 = $c_1 - 48 | 0;
    __label__ = 18;
    break;
   case 18:
    var $c_2;
    var $i_0;
    if (($i_0 | 0) < 3) {
      __label__ = 19;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 19:
    var $_sum7 = $i_0 + 1 | 0;
    var $45 = $1 + ($_sum7 << 1) | 0;
    if ($45 >>> 0 < $patternEnd >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 20:
    var $48 = HEAPU16[$45 >> 1];
    if (($48 - 48 & 65535 & 65535) > 7) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $54 = ($c_2 << 3) - 48 + ($48 & 65535) | 0;
    if (($54 | 0) > 255) {
      __label__ = 22;
      break;
    } else {
      var $i_0 = $_sum7;
      var $c_2 = $54;
      __label__ = 18;
      break;
    }
   case 22:
    var $ptr_3 = $1 + ($i_0 << 1) | 0;
    var $c_7 = $c_2;
    __label__ = 39;
    break;
   case 23:
    var $c_3;
    var $i1_0;
    if (($i1_0 | 0) < 3) {
      __label__ = 24;
      break;
    } else {
      var $i1_1 = $i1_0;
      var $c_4 = $c_3;
      __label__ = 27;
      break;
    }
   case 24:
    var $_sum5 = $i1_0 + 1 | 0;
    var $60 = $1 + ($_sum5 << 1) | 0;
    if ($60 >>> 0 < $patternEnd >>> 0) {
      __label__ = 25;
      break;
    } else {
      var $i1_1 = 1;
      var $c_4 = 120;
      __label__ = 27;
      break;
    }
   case 25:
    var $63 = HEAPU16[$60 >> 1];
    var $64 = __ZN3WTF15isASCIIHexDigitEt($63);
    if ($64) {
      __label__ = 26;
      break;
    } else {
      var $i1_1 = 1;
      var $c_4 = 120;
      __label__ = 27;
      break;
    }
   case 26:
    var $66 = $63 & 65535;
    var $cc2_0 = ($63 & 65535) > 96 ? $66 - 32 | 0 : $66;
    var $_neg = ($cc2_0 | 0) < 65 ? -48 : -55;
    var $72 = $cc2_0 + ($c_3 << 4) + $_neg | 0;
    var $i1_0 = $_sum5;
    var $c_3 = $72;
    __label__ = 23;
    break;
   case 27:
    var $c_4;
    var $i1_1;
    var $ptr_3 = $1 + ($i1_1 << 1) | 0;
    var $c_7 = $c_4;
    __label__ = 39;
    break;
   case 28:
    var $c_5;
    var $i3_0;
    if (($i3_0 | 0) < 5) {
      __label__ = 29;
      break;
    } else {
      var $i3_1 = $i3_0;
      var $c_6 = $c_5;
      __label__ = 32;
      break;
    }
   case 29:
    var $_sum = $i3_0 + 1 | 0;
    var $77 = $1 + ($_sum << 1) | 0;
    if ($77 >>> 0 < $patternEnd >>> 0) {
      __label__ = 30;
      break;
    } else {
      var $i3_1 = 1;
      var $c_6 = 117;
      __label__ = 32;
      break;
    }
   case 30:
    var $80 = HEAPU16[$77 >> 1];
    var $81 = __ZN3WTF15isASCIIHexDigitEt($80);
    if ($81) {
      __label__ = 31;
      break;
    } else {
      var $i3_1 = 1;
      var $c_6 = 117;
      __label__ = 32;
      break;
    }
   case 31:
    var $83 = $80 & 65535;
    var $cc4_0 = ($80 & 65535) > 96 ? $83 - 32 | 0 : $83;
    var $_neg11 = ($cc4_0 | 0) < 65 ? -48 : -55;
    var $89 = $cc4_0 + ($c_5 << 4) + $_neg11 | 0;
    var $i3_0 = $_sum;
    var $c_5 = $89;
    __label__ = 28;
    break;
   case 32:
    var $c_6;
    var $i3_1;
    var $ptr_3 = $1 + ($i3_1 << 1) | 0;
    var $c_7 = $c_6;
    __label__ = 39;
    break;
   case 33:
    var $93 = $1 + 4 | 0;
    if (($93 | 0) == ($patternEnd | 0)) {
      __label__ = 34;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 34:
    HEAP32[$errorCodePtr >> 2] = 2;
    var $_0 = 0;
    __label__ = 40;
    break;
   case 35:
    var $97 = HEAPU16[$93 >> 1];
    var $98 = $97 & 65535;
    if ($isClass) {
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $100 = __ZN3WTF12isASCIIAlphaEi($98);
    if ($100) {
      __label__ = 37;
      break;
    } else {
      var $ptr_3 = $1;
      var $c_7 = 92;
      __label__ = 39;
      break;
    }
   case 37:
    var $102 = __ZN3WTF19isASCIIAlphanumericEi($98);
    if ($97 << 16 >> 16 != 95 & ($102 ^ 1)) {
      var $ptr_3 = $1;
      var $c_7 = 92;
      __label__ = 39;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $105 = __ZN3WTF12toASCIIUpperEi($98);
    var $ptr_3 = $93;
    var $c_7 = $105 ^ 64;
    __label__ = 39;
    break;
   case 39:
    var $c_7;
    var $ptr_3;
    HEAP32[$ptrPtr >> 2] = $ptr_3;
    var $_0 = $c_7;
    __label__ = 40;
    break;
   case 40:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11checkEscapePPKtS0_P9ErrorCodeib["X"] = 1;

function __ZL17getOthercaseRangePiiS_S_($cptr, $d, $ocptr, $odptr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $c_0 = HEAP32[$cptr >> 2];
    __label__ = 2;
    break;
   case 2:
    var $c_0;
    if (($c_0 | 0) > ($d | 0)) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __Z22jsc_pcre_ucp_othercasej($c_0);
    if (($5 | 0) > -1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $c_0 = $c_0 + 1 | 0;
    __label__ = 2;
    break;
   case 5:
    HEAP32[$ocptr >> 2] = $5;
    var $next_0_in = $5;
    var $c_1_in = $c_0;
    __label__ = 6;
    break;
   case 6:
    var $c_1_in;
    var $next_0_in;
    var $next_0 = $next_0_in + 1 | 0;
    var $c_1 = $c_1_in + 1 | 0;
    if (($c_1 | 0) > ($d | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $13 = __Z22jsc_pcre_ucp_othercasej($c_1);
    if (($13 | 0) == ($next_0 | 0)) {
      var $next_0_in = $next_0;
      var $c_1_in = $c_1;
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP32[$odptr >> 2] = $next_0_in;
    HEAP32[$cptr >> 2] = $c_1;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN3WTF12isASCIIDigitEt($c) {
  return ($c - 48 & 65535 & 65535) < 10;
}

function __ZN3WTF15isASCIIHexDigitEt($c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($c - 48 & 65535 & 65535) < 10) {
      var $9 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $c & 65535 | 32;
    if ($4 >>> 0 > 96) {
      __label__ = 3;
      break;
    } else {
      var $9 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = $4 >>> 0 < 103;
    __label__ = 4;
    break;
   case 4:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN3WTF12isASCIIAlphaEi($c) {
  return (($c | 32) - 97 | 0) >>> 0 < 26;
}

function __ZN3WTF19isASCIIAlphanumericEi($c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($c - 48 | 0) >>> 0 < 10) {
      var $8 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $c | 32;
    if (($3 | 0) > 96) {
      __label__ = 3;
      break;
    } else {
      var $8 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = ($3 | 0) < 123;
    __label__ = 4;
    break;
   case 4:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN3WTF12toASCIIUpperEi($c) {
  return ((($c - 97 | 0) >>> 0 < 26 & 1) << 5 ^ -1) & $c;
}

function __ZL25multiplyWithOverflowCheckii($a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($a | 0) == 0 | ($b | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((4194304 / ($b | 0) & -1 | 0) < ($a | 0)) {
      var $_0 = -1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_0 = $b * $a | 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19safelyCheckNextCharPKtS0_t($ptr, $patternEnd, $expected) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $ptr + 2 | 0;
    if ($1 >>> 0 < $patternEnd >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = HEAP16[$1 >> 1] << 16 >> 16 == $expected << 16 >> 16;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11CompileDataC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP8[$this + 12 | 0] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  return;
}

function __ZL11toLowerCaseh($c) {
  var $2 = STRING_TABLE._jsc_pcre_default_tables + ($c & 255) | 0;
  return HEAP8[$2];
}

function __ZL8flipCaseh4460($c) {
  var $2 = STRING_TABLE._jsc_pcre_default_tables + (($c & 255) + 128) | 0;
  return HEAP8[$2];
}

function __ZL27tryRequiredByteOptimizationRPKtS0_iibbS1_($subjectPtr_val, $endSubject, $reqByte, $reqByte2, $reqByteIsCaseless, $hasFirstByte, $reqBytePtr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($reqByte | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 2:
    if (($endSubject - $subjectPtr_val | 0) < 2e3) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 3:
    var $9 = $subjectPtr_val + (($hasFirstByte & 1) << 1) | 0;
    if ($9 >>> 0 > HEAPU32[$reqBytePtr >> 2] >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 4:
    if ($reqByteIsCaseless) {
      var $p_0 = $9;
      __label__ = 5;
      break;
    } else {
      var $p_1 = $9;
      __label__ = 8;
      break;
    }
   case 5:
    var $p_0;
    if ($p_0 >>> 0 < $endSubject >>> 0) {
      __label__ = 6;
      break;
    } else {
      var $p_2 = $p_0;
      __label__ = 10;
      break;
    }
   case 6:
    var $16 = HEAPU16[$p_0 >> 1] & 65535;
    if (($16 | 0) == ($reqByte | 0)) {
      var $p_2 = $p_0;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($16 | 0) == ($reqByte2 | 0)) {
      var $p_2 = $p_0;
      __label__ = 10;
      break;
    } else {
      var $p_0 = $p_0 + 2 | 0;
      __label__ = 5;
      break;
    }
   case 8:
    var $p_1;
    if ($p_1 >>> 0 < $endSubject >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $p_2 = $p_1;
      __label__ = 10;
      break;
    }
   case 9:
    if ((HEAPU16[$p_1 >> 1] & 65535 | 0) == ($reqByte | 0)) {
      var $p_2 = $p_1;
      __label__ = 10;
      break;
    } else {
      var $p_1 = $p_1 + 2 | 0;
      __label__ = 8;
      break;
    }
   case 10:
    var $p_2;
    if ($p_2 >>> 0 < $endSubject >>> 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$reqBytePtr >> 2] = $p_2;
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16readRepeatCountsPKtPiS1_P9ErrorCode($p, $minp, $maxp, $errorCodePtr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU16[$p >> 1];
    var $2 = __ZN3WTF12isASCIIDigitEt($1);
    if ($2) {
      var $min_09 = 0;
      var $_0410 = $p;
      var $3 = $1;
      __label__ = 2;
      break;
    } else {
      var $_lcssa22 = $1;
      var $_04_lcssa23 = $p;
      var $min_0_lcssa24 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3;
    var $_0410;
    var $min_09;
    var $5 = $_0410 + 2 | 0;
    var $8 = $min_09 * 10 - 48 + ($3 & 65535) | 0;
    var $9 = HEAPU16[$5 >> 1];
    var $10 = __ZN3WTF12isASCIIDigitEt($9);
    if ($10) {
      var $min_09 = $8;
      var $_0410 = $5;
      var $3 = $9;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($8 >>> 0 > 65535) {
      __label__ = 4;
      break;
    } else {
      var $_lcssa22 = $9;
      var $_04_lcssa23 = $5;
      var $min_0_lcssa24 = $8;
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$errorCodePtr >> 2] = 5;
    var $_0 = $5;
    __label__ = 14;
    break;
   case 5:
    var $min_0_lcssa24;
    var $_04_lcssa23;
    var $_lcssa22;
    if ($_lcssa22 << 16 >> 16 == 125) {
      var $_2 = $_04_lcssa23;
      var $max_1 = $min_0_lcssa24;
      __label__ = 13;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $_04_lcssa23 + 2 | 0;
    var $16 = HEAP16[$15 >> 1];
    if ($16 << 16 >> 16 == 125) {
      var $_2 = $15;
      var $max_1 = -1;
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = __ZN3WTF12isASCIIDigitEt($16);
    if ($18) {
      var $max_05 = 0;
      var $_16 = $15;
      var $19 = $16;
      __label__ = 8;
      break;
    } else {
      var $_1_lcssa26 = $15;
      var $max_0_lcssa27 = 0;
      __label__ = 11;
      break;
    }
   case 8:
    var $19;
    var $_16;
    var $max_05;
    var $21 = $_16 + 2 | 0;
    var $24 = $max_05 * 10 - 48 + ($19 & 65535) | 0;
    var $25 = HEAPU16[$21 >> 1];
    var $26 = __ZN3WTF12isASCIIDigitEt($25);
    if ($26) {
      var $max_05 = $24;
      var $_16 = $21;
      var $19 = $25;
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ($24 >>> 0 > 65535) {
      __label__ = 10;
      break;
    } else {
      var $_1_lcssa26 = $21;
      var $max_0_lcssa27 = $24;
      __label__ = 11;
      break;
    }
   case 10:
    HEAP32[$errorCodePtr >> 2] = 5;
    var $_0 = $21;
    __label__ = 14;
    break;
   case 11:
    var $max_0_lcssa27;
    var $_1_lcssa26;
    if (($max_0_lcssa27 | 0) < ($min_0_lcssa24 | 0)) {
      __label__ = 12;
      break;
    } else {
      var $_2 = $_1_lcssa26;
      var $max_1 = $max_0_lcssa27;
      __label__ = 13;
      break;
    }
   case 12:
    HEAP32[$errorCodePtr >> 2] = 4;
    var $_0 = $_1_lcssa26;
    __label__ = 14;
    break;
   case 13:
    var $max_1;
    var $_2;
    HEAP32[$minp >> 2] = $min_0_lcssa24;
    HEAP32[$maxp >> 2] = $max_1;
    var $_0 = $_2;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16readRepeatCountsPKtPiS1_P9ErrorCode["X"] = 1;

function __ZL23put2ByteValueAndAdvanceRPhi($opcodePtr, $value) {
  var $1 = HEAP32[$opcodePtr >> 2];
  __ZL13put2ByteValuePhi($1, $value);
  var $3 = HEAP32[$opcodePtr >> 2] + 2 | 0;
  HEAP32[$opcodePtr >> 2] = $3;
  return;
}

function __ZL31putLinkValueAllowZeroAndAdvanceRPhi($opcodePtr, $value) {
  var $1 = HEAP32[$opcodePtr >> 2];
  __ZL21putLinkValueAllowZeroPhi($1, $value);
  var $3 = HEAP32[$opcodePtr >> 2] + 3 | 0;
  HEAP32[$opcodePtr >> 2] = $3;
  return;
}

function __ZL22putLinkValueAndAdvanceRPhi($opcodePtr, $value) {
  var $1 = HEAP32[$opcodePtr >> 2];
  __ZL12putLinkValuePhi($1, $value);
  var $3 = HEAP32[$opcodePtr >> 2] + 3 | 0;
  HEAP32[$opcodePtr >> 2] = $3;
  return;
}

function __Z15jsRegExpExecuteP9JSContextPK8JSRegExpPKtiiPii($cx, $re, $subject, $length, $start_offset, $offsets, $offsetCount) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $matchBlock = __stackBase__;
    var $startMatch = __stackBase__ + 36;
    var $reqBytePtr = __stackBase__ + 40;
    var $1 = $matchBlock + 16 | 0;
    HEAP32[$1 >> 2] = $subject;
    var $2 = $subject + ($length << 1) | 0;
    HEAP32[$matchBlock + 20 >> 2] = $2;
    var $4 = $re | 0;
    var $5 = HEAPU32[$4 >> 2];
    HEAP8[$matchBlock + 32 | 0] = $5 >>> 1 & 255 & 1;
    HEAP8[$matchBlock + 33 | 0] = $5 & 255 & 1;
    var $12 = $offsetCount - $offsetCount % 3 | 0;
    var $13 = $matchBlock | 0;
    HEAP32[$13 >> 2] = $offsets;
    HEAP32[$matchBlock + 4 >> 2] = $12;
    HEAP32[$matchBlock + 8 >> 2] = ($12 << 1 | 0) / 3 & -1;
    var $18 = $matchBlock + 12 | 0;
    HEAP8[$18] = 0;
    var $23 = ((HEAPU16[$re + 4 >> 1] & 65535) << 1) + 2 | 0;
    var $resetCount_0 = ($23 | 0) > ($offsetCount | 0) ? $12 : $23;
    if (($offsets | 0) == 0) {
      var $35 = $5;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_sum3 = $12 + 1 + (($resetCount_0 | 0) / -2 & -1) | 0;
    var $28 = $offsets + ($_sum3 << 2) | 0;
    var $_sum7 = $12 - 1 | 0;
    if (($_sum7 | 0) < ($_sum3 | 0)) {
      var $35 = $5;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $32 = $offsets + ($_sum7 << 2) | 0;
    __label__ = 4;
    break;
   case 4:
    var $32;
    HEAP32[$32 >> 2] = -1;
    var $33 = $32 - 4 | 0;
    if ($33 >>> 0 < $28 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $32 = $33;
      __label__ = 4;
      break;
    }
   case 5:
    var $35 = HEAP32[$4 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $35;
    if (($35 & 1073741824 | 0) == 0) {
      var $firstByte_0 = -1;
      var $firstByteIsCaseless_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $40 = HEAPU16[$re + 8 >> 1];
    var $41 = $40 & 65535;
    var $43 = $41 & 256;
    var $45 = $43 >>> 8 & 255;
    if (($43 | 0) == 0) {
      var $firstByte_0 = $41 & 255;
      var $firstByteIsCaseless_0 = $45;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $47 = $40 & 255;
    var $48 = __ZL11toLowerCaseh($47);
    var $firstByte_0 = $48 & 255;
    var $firstByteIsCaseless_0 = $45;
    __label__ = 9;
    break;
   case 9:
    var $firstByteIsCaseless_0;
    var $firstByte_0;
    if (($35 & 536870912 | 0) == 0) {
      var $reqByte2_0 = -1;
      var $reqByte_0 = -1;
      var $reqByteIsCaseless_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $55 = HEAPU16[$re + 10 >> 1];
    var $56 = $55 & 65535;
    var $57 = $56 & 255;
    var $59 = ($56 & 256 | 0) != 0;
    var $60 = $55 & 255;
    var $61 = __ZL8flipCaseh4460($60);
    var $reqByte2_0 = $61 & 255;
    var $reqByte_0 = $57;
    var $reqByteIsCaseless_0 = $59;
    __label__ = 11;
    break;
   case 11:
    var $reqByteIsCaseless_0;
    var $reqByte_0;
    var $reqByte2_0;
    HEAP32[$startMatch >> 2] = $subject + ($start_offset << 1) | 0;
    HEAP32[$reqBytePtr >> 2] = $subject + ($start_offset - 1 << 1) | 0;
    var $67 = ($35 & 268435456 | 0) != 0;
    var $68 = $firstByteIsCaseless_0 << 24 >> 24 != 0;
    var $69 = ($firstByte_0 | 0) > -1;
    var $71 = $re + 12 | 0;
    var $72 = $cx + 104 | 0;
    var $73 = ($resetCount_0 | 0) > 0;
    __label__ = 12;
    break;
   case 12:
    var $74 = HEAP32[$13 >> 2];
    if (($74 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $77 = $74 + ($resetCount_0 << 2) | 0;
    if ($73) {
      var $iptr1_05 = $74;
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $iptr1_05;
    var $78 = $iptr1_05 + 4 | 0;
    HEAP32[$iptr1_05 >> 2] = -1;
    if ($78 >>> 0 < $77 >>> 0) {
      var $iptr1_05 = $78;
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $81 = HEAP32[$1 >> 2] + ($start_offset << 1) | 0;
    __ZL24tryFirstByteOptimizationRPKtS0_ibbS0_($startMatch, $2, $firstByte_0, $68, $67, $81);
    var $startMatch_val = HEAPU32[$startMatch >> 2];
    var $82 = __ZL27tryRequiredByteOptimizationRPKtS0_iibbS1_($startMatch_val, $2, $reqByte_0, $reqByte2_0, $reqByteIsCaseless_0, $69, $reqBytePtr);
    if ($82) {
      var $_0 = -1;
      __label__ = 22;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $84 = __ZL5matchP11JSArenaPoolPKtPKhiR9MatchData($72, $startMatch_val, $71, $matchBlock);
    if (($84 | 0) == 0) {
      __label__ = 17;
      break;
    } else if (($84 | 0) == 1) {
      __label__ = 18;
      break;
    } else {
      var $_0 = $84;
      __label__ = 22;
      break;
    }
   case 17:
    var $86 = $startMatch_val + 2 | 0;
    HEAP32[$startMatch >> 2] = $86;
    if ((HEAP32[$4 >> 2] & 33554432 | 0) != 0 | $86 >>> 0 > $2 >>> 0) {
      var $_0 = -1;
      __label__ = 22;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 18:
    if ((HEAP8[$18] & 1) << 24 >> 24 == 0) {
      __label__ = 19;
      break;
    } else {
      var $100 = 0;
      __label__ = 20;
      break;
    }
   case 19:
    var $100 = (HEAP32[$matchBlock + 28 >> 2] | 0) / 2 & -1;
    __label__ = 20;
    break;
   case 20:
    var $100;
    if (($offsetCount | 0) < 2) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $105 = HEAP32[$1 >> 2];
    var $107 = $startMatch_val - $105 >> 1;
    HEAP32[$offsets >> 2] = $107;
    var $112 = HEAP32[$matchBlock + 24 >> 2] - $105 >> 1;
    HEAP32[$offsets + 4 >> 2] = $112;
    var $_0 = $100;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z15jsRegExpExecuteP9JSContextPK8JSRegExpPKtiiPii["X"] = 1;

function __ZL24tryFirstByteOptimizationRPKtS0_ibbS0_($subjectPtr, $endSubject, $firstByte, $firstByteIsCaseless, $useMultiLineFirstCharOptimization, $originalSubjectStart) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($firstByte | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 2:
    var $3 = $firstByte & 65535;
    var $_pre3 = HEAPU32[$subjectPtr >> 2];
    if ($firstByteIsCaseless) {
      var $4 = $_pre3;
      __label__ = 3;
      break;
    } else {
      var $16 = $_pre3;
      __label__ = 7;
      break;
    }
   case 3:
    var $4;
    if ($4 >>> 0 < $endSubject >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 4:
    var $7 = HEAPU16[$4 >> 1];
    if (($7 & 65535) > 127) {
      __label__ = 15;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = $7 & 255;
    var $11 = __ZL11toLowerCaseh($10);
    if (($11 & 255 | 0) == ($3 | 0)) {
      __label__ = 15;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $4 + 2 | 0;
    HEAP32[$subjectPtr >> 2] = $15;
    var $4 = $15;
    __label__ = 3;
    break;
   case 7:
    var $16;
    if ($16 >>> 0 < $endSubject >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 8:
    if ((HEAPU16[$16 >> 1] & 65535 | 0) == ($3 | 0)) {
      __label__ = 15;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $23 = $16 + 2 | 0;
    HEAP32[$subjectPtr >> 2] = $23;
    var $16 = $23;
    __label__ = 7;
    break;
   case 10:
    if ($useMultiLineFirstCharOptimization) {
      __label__ = 11;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 11:
    var $26 = HEAPU32[$subjectPtr >> 2];
    if ($26 >>> 0 > $originalSubjectStart >>> 0) {
      var $28 = $26;
      __label__ = 12;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 12:
    var $28;
    if ($28 >>> 0 < $endSubject >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $32 = HEAP16[$28 - 2 >> 1];
    var $33 = __ZL9isNewlinet($32);
    if ($33) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $35 = $28 + 2 | 0;
    HEAP32[$subjectPtr >> 2] = $35;
    var $28 = $35;
    __label__ = 12;
    break;
   case 15:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5matchP11JSArenaPoolPKtPKhiR9MatchData($regExpPool, $subjectPtr, $instructionPtr, $md) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 1952;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $min = __stackBase__;
    var $minimize = __stackBase__ + 4;
    var $stack = __stackBase__ + 8;
    var $minSatNextBracket = __stackBase__ + 1948;
    HEAP8[$minimize] = 0;
    __ZN10MatchStackC1EP11JSArenaPool($stack, $regExpPool);
    __ZN10LinearFlagC1Ev($minSatNextBracket);
    var $1 = $stack + 1932 | 0;
    var $3 = HEAP32[$1 >> 2] | 0;
    HEAP32[$3 >> 2] = 0;
    var $5 = HEAP32[$1 >> 2] + 20 | 0;
    HEAP32[$5 >> 2] = $subjectPtr;
    var $7 = HEAP32[$1 >> 2] + 24 | 0;
    HEAP32[$7 >> 2] = $instructionPtr;
    var $9 = HEAP32[$1 >> 2] + 28 | 0;
    HEAP32[$9 >> 2] = 2;
    var $11 = HEAP32[$1 >> 2] + 32 | 0;
    HEAP32[$11 >> 2] = 0;
    var $12 = HEAP32[$1 >> 2];
    __ZN10MatchFrame13startNewGroupEb($12, 0);
    var $13 = $md + 24 | 0;
    var $14 = $md + 28 | 0;
    var $15 = $md + 8 | 0;
    var $16 = $md + 4 | 0;
    var $17 = $md | 0;
    var $18 = $md + 16 | 0;
    var $19 = $md + 12 | 0;
    var $20 = $md + 20 | 0;
    var $21 = $md + 33 | 0;
    var $remainingMatchCount_0 = 999999;
    __label__ = 2;
    break;
   case 2:
    var $remainingMatchCount_0;
    if (($remainingMatchCount_0 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $25 = __ZL10matchErroriR10MatchStack(-2, $stack);
    var $_0 = $25;
    __label__ = 410;
    break;
   case 4:
    var $26 = HEAPU32[$1 >> 2];
    var $27 = $26 + 20 | 0;
    var $28 = $26 + 24 | 0;
    var $29 = HEAPU32[$28 >> 2];
    var $31 = HEAPU8[$29] & 255;
    if (($31 | 0) == 67) {
      var $33 = $26;
      var $32 = $29;
      __label__ = 5;
      break;
    } else if (($31 | 0) == 66) {
      __label__ = 11;
      break;
    } else if (($31 | 0) == 0) {
      __label__ = 12;
      break;
    } else if (($31 | 0) == 62) {
      __label__ = 13;
      break;
    } else if (($31 | 0) == 63) {
      __label__ = 20;
      break;
    } else if (($31 | 0) == 58) {
      __label__ = 24;
      break;
    } else if (($31 | 0) == 64) {
      __label__ = 25;
      break;
    } else if (($31 | 0) == 65) {
      __label__ = 27;
      break;
    } else if (($31 | 0) == 59 || ($31 | 0) == 61 || ($31 | 0) == 60) {
      __label__ = 29;
      break;
    } else if (($31 | 0) == 10) {
      __label__ = 49;
      break;
    } else if (($31 | 0) == 12) {
      __label__ = 51;
      break;
    } else if (($31 | 0) == 11) {
      __label__ = 54;
      break;
    } else if (($31 | 0) == 13) {
      __label__ = 56;
      break;
    } else if (($31 | 0) == 1 || ($31 | 0) == 2) {
      __label__ = 59;
      break;
    } else if (($31 | 0) == 9) {
      __label__ = 66;
      break;
    } else if (($31 | 0) == 3) {
      __label__ = 69;
      break;
    } else if (($31 | 0) == 4) {
      __label__ = 72;
      break;
    } else if (($31 | 0) == 5) {
      __label__ = 75;
      break;
    } else if (($31 | 0) == 6) {
      __label__ = 78;
      break;
    } else if (($31 | 0) == 7) {
      __label__ = 81;
      break;
    } else if (($31 | 0) == 8) {
      __label__ = 84;
      break;
    } else if (($31 | 0) == 57) {
      __label__ = 87;
      break;
    } else if (($31 | 0) == 55 || ($31 | 0) == 54) {
      __label__ = 116;
      break;
    } else if (($31 | 0) == 56) {
      __label__ = 148;
      break;
    } else if (($31 | 0) == 14) {
      __label__ = 173;
      break;
    } else if (($31 | 0) == 15) {
      __label__ = 175;
      break;
    } else if (($31 | 0) == 16) {
      __label__ = 178;
      break;
    } else if (($31 | 0) == 17) {
      __label__ = 181;
      break;
    } else if (($31 | 0) == 27) {
      __label__ = 184;
      break;
    } else if (($31 | 0) == 25 || ($31 | 0) == 26) {
      __label__ = 185;
      break;
    } else if (($31 | 0) == 19 || ($31 | 0) == 20 || ($31 | 0) == 21 || ($31 | 0) == 22 || ($31 | 0) == 23 || ($31 | 0) == 24) {
      __label__ = 186;
      break;
    } else if (($31 | 0) == 18) {
      __label__ = 231;
      break;
    } else if (($31 | 0) == 36) {
      __label__ = 237;
      break;
    } else if (($31 | 0) == 34 || ($31 | 0) == 35) {
      __label__ = 238;
      break;
    } else if (($31 | 0) == 28 || ($31 | 0) == 29 || ($31 | 0) == 30 || ($31 | 0) == 31 || ($31 | 0) == 32 || ($31 | 0) == 33) {
      __label__ = 239;
      break;
    } else if (($31 | 0) == 45) {
      __label__ = 286;
      break;
    } else if (($31 | 0) == 43 || ($31 | 0) == 44) {
      __label__ = 287;
      break;
    } else if (($31 | 0) == 37 || ($31 | 0) == 38 || ($31 | 0) == 39 || ($31 | 0) == 40 || ($31 | 0) == 41 || ($31 | 0) == 42) {
      __label__ = 288;
      break;
    } else if (($31 | 0) == 49 || ($31 | 0) == 51 || ($31 | 0) == 53 || ($31 | 0) == 47 || ($31 | 0) == 48 || ($31 | 0) == 50 || ($31 | 0) == 52 || ($31 | 0) == 46) {
      __label__ = 369;
      break;
    } else {
      __label__ = 370;
      break;
    }
   case 5:
    var $32;
    var $33;
    __ZN10MatchFrame15extractBracketsEPKh($33, $32);
    var $35 = HEAP32[$1 >> 2] + 88 | 0;
    HEAP32[$35 >> 2] = 3;
    var $36 = __ZN10LinearFlag12readAndClearEv($minSatNextBracket);
    HEAP8[HEAP32[$1 >> 2] + 104 | 0] = $36 & 1;
    var $_pre88 = HEAPU32[$1 >> 2];
    var $41 = $_pre88;
    var $40 = HEAP32[$_pre88 + 24 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $40;
    var $41;
    var $45 = (HEAP8[$41 + 104 | 0] & 1) << 24 >> 24 != 0;
    var $48 = $40 + (HEAP32[$41 + 88 >> 2] + 3) | 0;
    var $50 = HEAP32[$41 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $48, $50, 2);
    var $51 = HEAP32[$1 >> 2];
    __ZN10MatchFrame13startNewGroupEb($51, $45);
    __label__ = 7;
    break;
   case 7:
    var $remainingMatchCount_0 = $remainingMatchCount_0 - 1 | 0;
    __label__ = 2;
    break;
   case 8:
    var $54 = HEAP32[$1 >> 2] + 88 | 0;
    HEAP32[$54 >> 2] = 1;
    var $56 = HEAP32[$1 >> 2] + 24 | 0;
    var $57 = HEAP32[$56 >> 2];
    var $_val48 = HEAP8[$57 + 1 | 0];
    var $_idx49_val = HEAP8[$57 + 2 | 0];
    var $_idx50_val = HEAP8[$57 + 3 | 0];
    var $59 = __ZL12getLinkValuePKh4461($_val48, $_idx49_val, $_idx50_val);
    var $60 = $57 + $59 | 0;
    HEAP32[$56 >> 2] = $60;
    var $61 = HEAPU32[$1 >> 2];
    var $63 = HEAPU32[$61 + 24 >> 2];
    if (HEAP8[$63] << 24 >> 24 == 58) {
      var $41 = $61;
      var $40 = $63;
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $68 = HEAPU32[$61 + 92 >> 2];
    if ($68 >>> 0 < HEAPU32[$61 + 96 >> 2] >>> 0) {
      var $i_081 = $68;
      __label__ = 10;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 10:
    var $i_081;
    __ZN9MatchData13setOffsetPairEjii($md, $i_081, -1, -1);
    var $72 = $i_081 + 1 | 0;
    if ($72 >>> 0 < HEAPU32[HEAP32[$1 >> 2] + 96 >> 2] >>> 0) {
      var $i_081 = $72;
      __label__ = 10;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 11:
    HEAP32[$28 >> 2] = $29 + 3 | 0;
    __label__ = 4;
    break;
   case 12:
    var $81 = HEAP32[$27 >> 2];
    HEAP32[$13 >> 2] = $81;
    var $83 = HEAP32[$26 + 28 >> 2];
    HEAP32[$14 >> 2] = $83;
    var $isMatch_0 = 1;
    __label__ = 380;
    break;
   case 13:
    var $_val31 = HEAP8[$29 + 4 | 0];
    var $_idx32_val = HEAP8[$29 + 5 | 0];
    var $86 = __ZL13get2ByteValuePKh4462($_val31, $_idx32_val);
    HEAP32[$26 + 92 >> 2] = $86 >>> 8 & 255;
    var $92 = HEAP32[$1 >> 2] + 96 | 0;
    HEAP32[$92 >> 2] = $86 & 255;
    var $94 = HEAP32[$1 >> 2] + 88 | 0;
    HEAP32[$94 >> 2] = 3;
    var $_pre91 = HEAP32[$1 >> 2];
    var $96 = $_pre91;
    var $95 = HEAP32[$_pre91 + 24 >> 2];
    __label__ = 14;
    break;
   case 14:
    var $95;
    var $96;
    var $99 = $95 + (HEAP32[$96 + 88 >> 2] + 3) | 0;
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $99, 0, 6);
    var $100 = HEAP32[$1 >> 2];
    __ZN10MatchFrame13startNewGroupEb($100, 0);
    __label__ = 7;
    break;
   case 15:
    HEAP32[$2144 + 88 >> 2] = 1;
    var $104 = HEAP32[$1 >> 2] + 24 | 0;
    var $105 = HEAP32[$104 >> 2];
    var $_val45 = HEAP8[$105 + 1 | 0];
    var $_idx46_val = HEAP8[$105 + 2 | 0];
    var $_idx47_val = HEAP8[$105 + 3 | 0];
    var $107 = __ZL12getLinkValuePKh4461($_val45, $_idx46_val, $_idx47_val);
    var $108 = $105 + $107 | 0;
    HEAP32[$104 >> 2] = $108;
    var $109 = HEAPU32[$1 >> 2];
    var $111 = HEAPU32[$109 + 24 >> 2];
    var $112 = HEAP8[$111];
    if ($112 << 24 >> 24 == 58) {
      var $96 = $109;
      var $95 = $111;
      __label__ = 14;
      break;
    } else {
      var $116 = $109;
      var $115 = $112;
      __label__ = 16;
      break;
    }
   case 16:
    var $115;
    var $116;
    if ($115 << 24 >> 24 == 59) {
      __label__ = 17;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 17:
    var $120 = HEAPU32[$116 + 92 >> 2];
    if ($120 >>> 0 < HEAPU32[$116 + 96 >> 2] >>> 0) {
      var $i1_079 = $120;
      __label__ = 18;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 18:
    var $i1_079;
    __ZN9MatchData13setOffsetPairEjii($md, $i1_079, -1, -1);
    var $124 = $i1_079 + 1 | 0;
    if ($124 >>> 0 < HEAPU32[HEAP32[$1 >> 2] + 96 >> 2] >>> 0) {
      var $i1_079 = $124;
      __label__ = 18;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 19:
    __ZL21advanceToEndOfBracketRPKh4463($116 + 24 | 0);
    var $132 = HEAP32[$1 >> 2] + 24 | 0;
    var $134 = HEAP32[$132 >> 2] + 4 | 0;
    HEAP32[$132 >> 2] = $134;
    var $135 = HEAP32[$14 >> 2];
    var $137 = HEAP32[$1 >> 2] + 28 | 0;
    HEAP32[$137 >> 2] = $135;
    __label__ = 4;
    break;
   case 20:
    HEAP32[$26 + 88 >> 2] = 3;
    var $140 = HEAPU32[$1 >> 2];
    var $142 = HEAP32[$140 + 24 >> 2];
    var $_val29 = HEAP8[$142 + 4 | 0];
    var $_idx30_val = HEAP8[$142 + 5 | 0];
    var $144 = __ZL13get2ByteValuePKh4462($_val29, $_idx30_val);
    var $146 = $144 >>> 8 & 255;
    HEAP32[$140 + 92 >> 2] = $146;
    var $148 = $144 & 255;
    var $150 = HEAP32[$1 >> 2] + 96 | 0;
    HEAP32[$150 >> 2] = $148;
    var $_pre94 = HEAP32[$1 >> 2];
    var $152 = $_pre94;
    var $151 = HEAP32[$_pre94 + 24 >> 2];
    __label__ = 21;
    break;
   case 21:
    var $151;
    var $152;
    var $155 = $151 + (HEAP32[$152 + 88 >> 2] + 3) | 0;
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $155, 0, 7);
    var $156 = HEAP32[$1 >> 2];
    __ZN10MatchFrame13startNewGroupEb($156, 0);
    __label__ = 7;
    break;
   case 22:
    var $159 = HEAP32[$1 >> 2] + 88 | 0;
    HEAP32[$159 >> 2] = 1;
    var $161 = HEAP32[$1 >> 2] + 24 | 0;
    var $162 = HEAP32[$161 >> 2];
    var $_val42 = HEAP8[$162 + 1 | 0];
    var $_idx43_val = HEAP8[$162 + 2 | 0];
    var $_idx44_val = HEAP8[$162 + 3 | 0];
    var $164 = __ZL12getLinkValuePKh4461($_val42, $_idx43_val, $_idx44_val);
    var $165 = $162 + $164 | 0;
    HEAP32[$161 >> 2] = $165;
    var $166 = HEAP32[$1 >> 2];
    var $167 = $166 + 24 | 0;
    var $168 = HEAP32[$167 >> 2];
    if (HEAP8[$168] << 24 >> 24 == 58) {
      var $152 = $166;
      var $151 = $168;
      __label__ = 21;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $175 = $168 + (HEAP32[$166 + 88 >> 2] + 3) | 0;
    HEAP32[$167 >> 2] = $175;
    __label__ = 4;
    break;
   case 24:
    __ZL21advanceToEndOfBracketRPKh4463($28);
    __label__ = 4;
    break;
   case 25:
    HEAP32[$26 + 40 >> 2] = $29 + 1 | 0;
    var $180 = HEAP32[$1 >> 2];
    var $183 = HEAP32[$180 + 24 >> 2] + 1 | 0;
    __ZN10MatchFrame15extractBracketsEPKh($180, $183);
    var $184 = HEAP32[$1 >> 2];
    var $186 = HEAP32[$184 + 92 >> 2];
    var $188 = HEAP32[$184 + 96 >> 2];
    var $189 = HEAP32[$17 >> 2];
    var $190 = HEAP32[$16 >> 2];
    __ZN10MatchFrame11saveOffsetsEiiPii($184, $186, $188, $189, $190);
    __ZN10LinearFlag3setEv($minSatNextBracket);
    var $191 = HEAP32[$1 >> 2];
    var $193 = HEAP32[$191 + 40 >> 2];
    var $195 = HEAP32[$191 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $193, $195, 14);
    var $196 = HEAP32[$1 >> 2];
    __ZN10MatchFrame13startNewGroupEb($196, 1);
    __label__ = 7;
    break;
   case 26:
    var $198 = HEAP32[$1 >> 2];
    var $200 = HEAP32[$198 + 92 >> 2];
    var $202 = HEAP32[$198 + 96 >> 2];
    var $203 = HEAP32[$17 >> 2];
    var $204 = HEAP32[$16 >> 2];
    __ZN10MatchFrame14restoreOffsetsEiiPii($198, $200, $202, $203, $204);
    var $206 = HEAP32[$1 >> 2] + 40 | 0;
    __ZL21advanceToEndOfBracketRPKh4463($206);
    var $207 = HEAP32[$1 >> 2];
    var $210 = HEAP32[$207 + 40 >> 2] + 4 | 0;
    var $211 = $207 + 24 | 0;
    HEAP32[$211 >> 2] = $210;
    __label__ = 4;
    break;
   case 27:
    HEAP32[$26 + 40 >> 2] = $29 + 1 | 0;
    var $216 = HEAP32[$1 >> 2] + 40 | 0;
    __ZL21advanceToEndOfBracketRPKh4463($216);
    var $217 = HEAP32[$1 >> 2];
    var $220 = HEAP32[$217 + 40 >> 2] + 4 | 0;
    var $222 = HEAP32[$217 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $220, $222, 15);
    var $223 = HEAP32[$1 >> 2];
    __ZN10MatchFrame13startNewGroupEb($223, 0);
    __label__ = 7;
    break;
   case 28:
    var $226 = HEAP32[$1 >> 2] + 24 | 0;
    var $228 = HEAP32[$226 >> 2] + 1 | 0;
    HEAP32[$226 >> 2] = $228;
    __label__ = 4;
    break;
   case 29:
    var $_val39 = HEAP8[$29 + 1 | 0];
    var $_idx40_val = HEAP8[$29 + 2 | 0];
    var $_idx41_val = HEAP8[$29 + 3 | 0];
    var $231 = __ZL12getLinkValuePKh4461($_val39, $_idx40_val, $_idx41_val);
    HEAP32[$26 + 48 >> 2] = $29 + -$231 | 0;
    var $235 = HEAP32[$1 >> 2];
    var $239 = HEAP32[HEAP32[$235 + 32 >> 2] + 4 >> 2];
    var $240 = $235 + 44 | 0;
    HEAP32[$240 >> 2] = $239;
    var $241 = HEAP32[$1 >> 2];
    var $246 = HEAP8[HEAP32[$241 + 32 >> 2] + 8 | 0] & 1;
    HEAP8[$241 + 104 | 0] = $246;
    var $249 = HEAP32[$1 >> 2] + 32 | 0;
    var $252 = HEAP32[HEAP32[$249 >> 2] >> 2];
    HEAP32[$249 >> 2] = $252;
    var $253 = HEAPU32[$1 >> 2];
    var $256 = HEAPU8[HEAP32[$253 + 48 >> 2]];
    if (($256 - 62 & 255 & 255) < 2) {
      __label__ = 30;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    var $259 = HEAP32[$253 + 28 >> 2];
    HEAP32[$14 >> 2] = $259;
    var $isMatch_0 = 1;
    __label__ = 380;
    break;
   case 31:
    var $262 = ($256 & 255) - 67 | 0;
    HEAP32[$253 + 80 >> 2] = $262;
    var $264 = HEAPU32[$1 >> 2];
    var $265 = $264 + 80 | 0;
    var $266 = HEAPU32[$265 >> 2];
    if (($266 | 0) > 100) {
      __label__ = 32;
      break;
    } else {
      var $275 = $264;
      var $274 = $266;
      __label__ = 33;
      break;
    }
   case 32:
    var $270 = HEAP32[$264 + 48 >> 2];
    var $_val27 = HEAP8[$270 + 7 | 0];
    var $_idx28_val = HEAP8[$270 + 8 | 0];
    var $272 = __ZL13get2ByteValuePKh4462($_val27, $_idx28_val);
    HEAP32[$265 >> 2] = $272;
    var $_pre101 = HEAP32[$1 >> 2];
    var $275 = $_pre101;
    var $274 = HEAP32[$_pre101 + 80 >> 2];
    __label__ = 33;
    break;
   case 33:
    var $274;
    var $275;
    HEAP32[$275 + 84 >> 2] = $274 << 1;
    var $278 = HEAPU32[$1 >> 2];
    var $280 = HEAPU32[$278 + 80 >> 2];
    if (($280 | 0) > 0) {
      __label__ = 34;
      break;
    } else {
      var $317 = $278;
      __label__ = 40;
      break;
    }
   case 34:
    if ((HEAP32[$278 + 84 >> 2] | 0) < (HEAP32[$15 >> 2] | 0)) {
      __label__ = 36;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    HEAP8[$19] = 1;
    var $317 = $278;
    __label__ = 40;
    break;
   case 36:
    var $293 = HEAP32[HEAP32[$17 >> 2] + (HEAP32[$16 >> 2] - $280 << 2) >> 2];
    var $300 = HEAP32[$278 + 20 >> 2] - HEAP32[$18 >> 2] >> 1;
    if (($293 | 0) == ($300 | 0)) {
      __label__ = 37;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 37:
    if ((HEAP8[$278 + 104 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 38;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 38:
    __ZN9MatchData13setOffsetPairEjii($md, $280, $293, $300);
    var $308 = HEAP32[$1 >> 2];
    var $309 = $308 + 28 | 0;
    var $312 = HEAP32[$308 + 84 >> 2];
    if ((HEAP32[$309 >> 2] | 0) > ($312 | 0)) {
      var $317 = $308;
      __label__ = 40;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $315 = $312 + 2 | 0;
    HEAP32[$309 >> 2] = $315;
    var $317 = HEAP32[$1 >> 2];
    __label__ = 40;
    break;
   case 40:
    var $317;
    var $318 = $317 + 24 | 0;
    var $319 = HEAP32[$318 >> 2];
    var $_pre134 = HEAP32[$317 + 20 >> 2];
    var $_pre136 = HEAP32[$317 + 44 >> 2];
    if (HEAP8[$319] << 24 >> 24 == 59 | ($_pre134 | 0) == ($_pre136 | 0)) {
      __label__ = 41;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 41:
    if (($_pre134 | 0) == ($_pre136 | 0)) {
      __label__ = 42;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 42:
    if ((HEAP8[$317 + 104 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 43;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 43:
    var $330 = $319 + 4 | 0;
    HEAP32[$318 >> 2] = $330;
    __label__ = 4;
    break;
   case 44:
    var $333 = HEAP32[$317 + 48 >> 2];
    __ZN10MatchFrame15extractBracketsEPKh($317, $333);
    var $334 = HEAP32[$1 >> 2];
    var $338 = HEAP8[HEAP32[$334 + 24 >> 2]] << 24 >> 24 == 61;
    var $340 = HEAP32[$334 + 92 >> 2];
    var $342 = HEAP32[$334 + 96 >> 2];
    var $343 = HEAP32[$17 >> 2];
    var $344 = HEAP32[$16 >> 2];
    __ZN10MatchFrame11saveOffsetsEiiPii($334, $340, $342, $343, $344);
    var $345 = HEAP32[$1 >> 2];
    if ($338) {
      __label__ = 45;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 45:
    var $349 = HEAP32[$345 + 24 >> 2] + 4 | 0;
    var $351 = HEAP32[$345 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $349, $351, 16);
    __label__ = 7;
    break;
   case 46:
    var $353 = HEAP32[$1 >> 2];
    var $355 = HEAP32[$353 + 92 >> 2];
    var $357 = HEAP32[$353 + 96 >> 2];
    var $358 = HEAP32[$17 >> 2];
    var $359 = HEAP32[$16 >> 2];
    __ZN10MatchFrame14restoreOffsetsEiiPii($353, $355, $357, $358, $359);
    __ZN10LinearFlag3setEv($minSatNextBracket);
    var $360 = HEAP32[$1 >> 2];
    var $362 = HEAP32[$360 + 48 >> 2];
    var $364 = HEAP32[$360 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $362, $364, 17);
    var $365 = HEAP32[$1 >> 2];
    __ZN10MatchFrame13startNewGroupEb($365, 1);
    __label__ = 7;
    break;
   case 47:
    var $368 = HEAP32[$345 + 92 >> 2];
    var $370 = HEAP32[$345 + 96 >> 2];
    var $371 = HEAP32[$17 >> 2];
    __ZN10MatchFrame14clobberOffsetsEiiPii($368, $370, $371);
    __ZN10LinearFlag3setEv($minSatNextBracket);
    var $372 = HEAP32[$1 >> 2];
    var $374 = HEAP32[$372 + 48 >> 2];
    var $376 = HEAP32[$372 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $374, $376, 18);
    var $377 = HEAP32[$1 >> 2];
    __ZN10MatchFrame13startNewGroupEb($377, 1);
    __label__ = 7;
    break;
   case 48:
    var $379 = HEAP32[$1 >> 2];
    var $381 = HEAP32[$379 + 92 >> 2];
    var $383 = HEAP32[$379 + 96 >> 2];
    var $384 = HEAP32[$17 >> 2];
    var $385 = HEAP32[$16 >> 2];
    __ZN10MatchFrame14restoreOffsetsEiiPii($379, $381, $383, $384, $385);
    var $386 = HEAP32[$1 >> 2];
    var $389 = HEAP32[$386 + 24 >> 2] + 4 | 0;
    var $391 = HEAP32[$386 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $389, $391, 19);
    __label__ = 7;
    break;
   case 49:
    if ((HEAP32[$27 >> 2] | 0) == (HEAP32[$18 >> 2] | 0)) {
      __label__ = 50;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 50:
    HEAP32[$28 >> 2] = $29 + 1 | 0;
    __label__ = 4;
    break;
   case 51:
    var $401 = HEAP32[$27 >> 2];
    if (($401 | 0) == (HEAP32[$18 >> 2] | 0)) {
      __label__ = 53;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 52:
    var $406 = HEAP16[$401 - 2 >> 1];
    var $407 = __ZL9isNewlinet($406);
    if ($407) {
      __label__ = 53;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 53:
    HEAP32[$28 >> 2] = $29 + 1 | 0;
    __label__ = 4;
    break;
   case 54:
    if (HEAPU32[$27 >> 2] >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    HEAP32[$28 >> 2] = $29 + 1 | 0;
    __label__ = 4;
    break;
   case 56:
    var $419 = HEAPU32[$27 >> 2];
    if ($419 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 57;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 57:
    var $423 = HEAP16[$419 >> 1];
    var $424 = __ZL9isNewlinet($423);
    if ($424) {
      __label__ = 58;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 58:
    HEAP32[$28 >> 2] = $29 + 1 | 0;
    __label__ = 4;
    break;
   case 59:
    var $429 = HEAPU32[$26 + 20 >> 2];
    if ($429 >>> 0 > HEAPU32[$18 >> 2] >>> 0) {
      __label__ = 60;
      break;
    } else {
      var $previousCharIsWordChar_0 = 0;
      __label__ = 61;
      break;
    }
   case 60:
    var $434 = HEAP16[$429 - 2 >> 1];
    var $435 = __ZL10isWordChart($434);
    var $previousCharIsWordChar_0 = $435;
    __label__ = 61;
    break;
   case 61:
    var $previousCharIsWordChar_0;
    if ($429 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 62;
      break;
    } else {
      var $currentCharIsWordChar_0 = 0;
      __label__ = 63;
      break;
    }
   case 62:
    var $439 = HEAP16[$429 >> 1];
    var $440 = __ZL10isWordChart($439);
    var $currentCharIsWordChar_0 = $440;
    __label__ = 63;
    break;
   case 63:
    var $currentCharIsWordChar_0;
    HEAP32[$28 >> 2] = $29 + 1 | 0;
    var $tmp = $currentCharIsWordChar_0 ^ $previousCharIsWordChar_0;
    if (HEAP8[$29] << 24 >> 24 == 2) {
      __label__ = 64;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 64:
    if ($tmp) {
      __label__ = 4;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 65:
    if ($tmp) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 66:
    var $448 = $27 | 0;
    var $449 = HEAPU32[$448 >> 2];
    if ($449 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 67;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 67:
    HEAP32[$448 >> 2] = $449 + 2 | 0;
    var $454 = HEAP16[$449 >> 1];
    var $455 = __ZL9isNewlinet($454);
    if ($455) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 68:
    var $458 = HEAP32[$1 >> 2] + 24 | 0;
    var $460 = HEAP32[$458 >> 2] + 1 | 0;
    HEAP32[$458 >> 2] = $460;
    __label__ = 4;
    break;
   case 69:
    var $462 = $27 | 0;
    var $463 = HEAPU32[$462 >> 2];
    if ($463 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 70;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 70:
    HEAP32[$462 >> 2] = $463 + 2 | 0;
    var $468 = HEAP16[$463 >> 1];
    var $469 = __ZN3WTF12isASCIIDigitEt($468);
    if ($469) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 71:
    var $472 = HEAP32[$1 >> 2] + 24 | 0;
    var $474 = HEAP32[$472 >> 2] + 1 | 0;
    HEAP32[$472 >> 2] = $474;
    __label__ = 4;
    break;
   case 72:
    var $476 = $27 | 0;
    var $477 = HEAPU32[$476 >> 2];
    if ($477 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 73;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 73:
    HEAP32[$476 >> 2] = $477 + 2 | 0;
    var $482 = HEAP16[$477 >> 1];
    var $483 = __ZN3WTF12isASCIIDigitEt($482);
    if ($483) {
      __label__ = 74;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 74:
    var $486 = HEAP32[$1 >> 2] + 24 | 0;
    var $488 = HEAP32[$486 >> 2] + 1 | 0;
    HEAP32[$486 >> 2] = $488;
    __label__ = 4;
    break;
   case 75:
    var $490 = $27 | 0;
    var $491 = HEAPU32[$490 >> 2];
    if ($491 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 76;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 76:
    HEAP32[$490 >> 2] = $491 + 2 | 0;
    var $496 = HEAP16[$491 >> 1];
    var $497 = __ZL11isSpaceChart($496);
    if ($497) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 77:
    var $500 = HEAP32[$1 >> 2] + 24 | 0;
    var $502 = HEAP32[$500 >> 2] + 1 | 0;
    HEAP32[$500 >> 2] = $502;
    __label__ = 4;
    break;
   case 78:
    var $504 = $27 | 0;
    var $505 = HEAPU32[$504 >> 2];
    if ($505 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 79;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 79:
    HEAP32[$504 >> 2] = $505 + 2 | 0;
    var $510 = HEAP16[$505 >> 1];
    var $511 = __ZL11isSpaceChart($510);
    if ($511) {
      __label__ = 80;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 80:
    var $514 = HEAP32[$1 >> 2] + 24 | 0;
    var $516 = HEAP32[$514 >> 2] + 1 | 0;
    HEAP32[$514 >> 2] = $516;
    __label__ = 4;
    break;
   case 81:
    var $518 = $27 | 0;
    var $519 = HEAPU32[$518 >> 2];
    if ($519 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 82;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 82:
    HEAP32[$518 >> 2] = $519 + 2 | 0;
    var $524 = HEAP16[$519 >> 1];
    var $525 = __ZL10isWordChart($524);
    if ($525) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 83;
      break;
    }
   case 83:
    var $528 = HEAP32[$1 >> 2] + 24 | 0;
    var $530 = HEAP32[$528 >> 2] + 1 | 0;
    HEAP32[$528 >> 2] = $530;
    __label__ = 4;
    break;
   case 84:
    var $532 = $27 | 0;
    var $533 = HEAPU32[$532 >> 2];
    if ($533 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 85;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 85:
    HEAP32[$532 >> 2] = $533 + 2 | 0;
    var $538 = HEAP16[$533 >> 1];
    var $539 = __ZL10isWordChart($538);
    if ($539) {
      __label__ = 86;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 86:
    var $542 = HEAP32[$1 >> 2] + 24 | 0;
    var $544 = HEAP32[$542 >> 2] + 1 | 0;
    HEAP32[$542 >> 2] = $544;
    __label__ = 4;
    break;
   case 87:
    var $_val25 = HEAP8[$29 + 1 | 0];
    var $_idx26_val = HEAP8[$29 + 2 | 0];
    var $547 = __ZL13get2ByteValuePKh4462($_val25, $_idx26_val);
    HEAP32[$26 + 84 >> 2] = $547 << 1;
    var $551 = HEAP32[$1 >> 2] + 24 | 0;
    var $553 = HEAP32[$551 >> 2] + 3 | 0;
    HEAP32[$551 >> 2] = $553;
    var $554 = HEAP32[$1 >> 2];
    var $556 = HEAP32[$554 + 84 >> 2];
    if (($556 | 0) < (HEAP32[$554 + 28 >> 2] | 0)) {
      __label__ = 88;
      break;
    } else {
      __label__ = 89;
      break;
    }
   case 88:
    var $561 = HEAP32[$17 >> 2];
    var $563 = HEAP32[$561 + ($556 << 2) >> 2];
    if (($563 | 0) < 0) {
      __label__ = 89;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 89:
    var $566 = $554 + 72 | 0;
    HEAP32[$566 >> 2] = 0;
    __label__ = 91;
    break;
   case 90:
    var $571 = HEAP32[$561 + ($556 + 1 << 2) >> 2] - $563 | 0;
    var $572 = $554 + 72 | 0;
    HEAP32[$572 >> 2] = $571;
    __label__ = 91;
    break;
   case 91:
    var $574 = HEAPU32[$1 >> 2];
    var $575 = $574 + 24 | 0;
    var $576 = HEAPU32[$575 >> 2];
    var $577 = HEAPU8[$576];
    var $578 = $577 & 255;
    if (($578 | 0) == 46 || ($578 | 0) == 47 || ($578 | 0) == 48 || ($578 | 0) == 49 || ($578 | 0) == 50 || ($578 | 0) == 51) {
      __label__ = 92;
      break;
    } else if (($578 | 0) == 52 || ($578 | 0) == 53) {
      __label__ = 93;
      break;
    } else {
      __label__ = 96;
      break;
    }
   case 92:
    HEAP32[$575 >> 2] = $576 + 1 | 0;
    var $583 = (HEAPU8[$576] & 255) - 46 & 65535;
    var $585 = HEAP32[$1 >> 2] + 76 | 0;
    __ZL38repeatInformationFromInstructionOffsetsRbRiS0_($583, $minimize, $min, $585);
    __label__ = 98;
    break;
   case 93:
    HEAP8[$minimize] = $577 << 24 >> 24 == 53 & 1;
    var $_val23 = HEAP8[$576 + 1 | 0];
    var $_idx24_val = HEAP8[$576 + 2 | 0];
    var $590 = __ZL13get2ByteValuePKh4462($_val23, $_idx24_val);
    HEAP32[$min >> 2] = $590;
    var $591 = HEAP32[$575 >> 2];
    var $_val21 = HEAP8[$591 + 3 | 0];
    var $_idx22_val = HEAP8[$591 + 4 | 0];
    var $593 = __ZL13get2ByteValuePKh4462($_val21, $_idx22_val);
    HEAP32[$574 + 76 >> 2] = $593;
    var $595 = HEAP32[$1 >> 2];
    var $596 = $595 + 76 | 0;
    if ((HEAP32[$596 >> 2] | 0) == 0) {
      __label__ = 94;
      break;
    } else {
      var $601 = $595;
      __label__ = 95;
      break;
    }
   case 94:
    HEAP32[$596 >> 2] = 2147483647;
    var $601 = HEAP32[$1 >> 2];
    __label__ = 95;
    break;
   case 95:
    var $601;
    var $602 = $601 + 24 | 0;
    var $604 = HEAP32[$602 >> 2] + 5 | 0;
    HEAP32[$602 >> 2] = $604;
    __label__ = 98;
    break;
   case 96:
    var $607 = HEAP32[$574 + 84 >> 2];
    var $608 = $574 + 20 | 0;
    var $609 = HEAP32[$608 >> 2];
    var $611 = HEAP32[$574 + 72 >> 2];
    var $612 = __ZL8matchRefiPKtiRK9MatchData($607, $609, $611, $md);
    if ($612) {
      __label__ = 97;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 97:
    var $614 = $609 + ($611 << 1) | 0;
    HEAP32[$608 >> 2] = $614;
    __label__ = 4;
    break;
   case 98:
    var $616 = HEAP32[$1 >> 2];
    if ((HEAP32[$616 + 72 >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $i3_0 = 1;
      var $620 = $616;
      __label__ = 99;
      break;
    }
   case 99:
    var $620;
    var $i3_0;
    var $621 = HEAP32[$min >> 2];
    if (($i3_0 | 0) > ($621 | 0)) {
      __label__ = 102;
      break;
    } else {
      __label__ = 100;
      break;
    }
   case 100:
    var $625 = HEAP32[$620 + 84 >> 2];
    var $626 = $620 + 20 | 0;
    var $627 = HEAP32[$626 >> 2];
    var $629 = HEAP32[$620 + 72 >> 2];
    var $630 = __ZL8matchRefiPKtiRK9MatchData($625, $627, $629, $md);
    if ($630) {
      __label__ = 101;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 101:
    var $632 = $627 + ($629 << 1) | 0;
    HEAP32[$626 >> 2] = $632;
    var $i3_0 = $i3_0 + 1 | 0;
    var $620 = HEAP32[$1 >> 2];
    __label__ = 99;
    break;
   case 102:
    if (($621 | 0) == (HEAP32[$620 + 76 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 103;
      break;
    }
   case 103:
    if ((HEAP8[$minimize] & 1) << 24 >> 24 == 0) {
      __label__ = 109;
      break;
    } else {
      __label__ = 104;
      break;
    }
   case 104:
    HEAP32[$620 + 68 >> 2] = $621;
    __label__ = 105;
    break;
   case 105:
    var $645 = HEAP32[$1 >> 2];
    var $647 = HEAP32[$645 + 24 >> 2];
    var $649 = HEAP32[$645 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $647, $649, 20);
    __label__ = 7;
    break;
   case 106:
    var $651 = HEAP32[$1 >> 2];
    if ((HEAP32[$651 + 68 >> 2] | 0) < (HEAP32[$651 + 76 >> 2] | 0)) {
      __label__ = 107;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 107:
    var $659 = HEAP32[$651 + 84 >> 2];
    var $660 = $651 + 20 | 0;
    var $661 = HEAP32[$660 >> 2];
    var $663 = HEAP32[$651 + 72 >> 2];
    var $664 = __ZL8matchRefiPKtiRK9MatchData($659, $661, $663, $md);
    if ($664) {
      __label__ = 108;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 108:
    var $666 = $661 + ($663 << 1) | 0;
    HEAP32[$660 >> 2] = $666;
    var $668 = HEAP32[$1 >> 2] + 68 | 0;
    var $670 = HEAP32[$668 >> 2] + 1 | 0;
    HEAP32[$668 >> 2] = $670;
    __label__ = 105;
    break;
   case 109:
    var $673 = HEAP32[$620 + 20 >> 2];
    HEAP32[$620 + 44 >> 2] = $673;
    var $i4_0 = HEAP32[$min >> 2];
    __label__ = 110;
    break;
   case 110:
    var $i4_0;
    var $677 = HEAP32[$1 >> 2];
    if (($i4_0 | 0) < (HEAP32[$677 + 76 >> 2] | 0)) {
      __label__ = 111;
      break;
    } else {
      var $692 = $677;
      __label__ = 113;
      break;
    }
   case 111:
    var $683 = HEAP32[$677 + 84 >> 2];
    var $684 = $677 + 20 | 0;
    var $685 = HEAP32[$684 >> 2];
    var $687 = HEAP32[$677 + 72 >> 2];
    var $688 = __ZL8matchRefiPKtiRK9MatchData($683, $685, $687, $md);
    if ($688) {
      __label__ = 112;
      break;
    } else {
      var $692 = $677;
      __label__ = 113;
      break;
    }
   case 112:
    var $690 = $685 + ($687 << 1) | 0;
    HEAP32[$684 >> 2] = $690;
    var $i4_0 = $i4_0 + 1 | 0;
    __label__ = 110;
    break;
   case 113:
    var $692;
    if (HEAPU32[$692 + 20 >> 2] >>> 0 < HEAPU32[$692 + 44 >> 2] >>> 0) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 114;
      break;
    }
   case 114:
    var $700 = HEAP32[$692 + 24 >> 2];
    var $702 = HEAP32[$692 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $700, $702, 21);
    __label__ = 7;
    break;
   case 115:
    var $704 = HEAP32[$1 >> 2];
    var $707 = $704 + 20 | 0;
    var $710 = HEAP32[$707 >> 2] + (-HEAP32[$704 + 72 >> 2] << 1) | 0;
    HEAP32[$707 >> 2] = $710;
    var $692 = HEAP32[$1 >> 2];
    __label__ = 113;
    break;
   case 116:
    HEAP32[$26 + 36 >> 2] = $29 + 1 | 0;
    var $715 = HEAP32[$1 >> 2] + 24 | 0;
    var $717 = HEAP32[$715 >> 2] + 33 | 0;
    HEAP32[$715 >> 2] = $717;
    var $718 = HEAPU32[$1 >> 2];
    var $719 = $718 + 24 | 0;
    var $720 = HEAPU32[$719 >> 2];
    var $721 = HEAPU8[$720];
    var $722 = $721 & 255;
    if (($722 | 0) == 46 || ($722 | 0) == 47 || ($722 | 0) == 48 || ($722 | 0) == 49 || ($722 | 0) == 50 || ($722 | 0) == 51) {
      __label__ = 117;
      break;
    } else if (($722 | 0) == 52 || ($722 | 0) == 53) {
      __label__ = 118;
      break;
    } else {
      __label__ = 121;
      break;
    }
   case 117:
    HEAP32[$719 >> 2] = $720 + 1 | 0;
    var $727 = (HEAPU8[$720] & 255) - 46 & 65535;
    var $729 = HEAP32[$1 >> 2] + 76 | 0;
    __ZL38repeatInformationFromInstructionOffsetsRbRiS0_($727, $minimize, $min, $729);
    __label__ = 122;
    break;
   case 118:
    HEAP8[$minimize] = $721 << 24 >> 24 == 53 & 1;
    var $_val19 = HEAP8[$720 + 1 | 0];
    var $_idx20_val = HEAP8[$720 + 2 | 0];
    var $734 = __ZL13get2ByteValuePKh4462($_val19, $_idx20_val);
    HEAP32[$min >> 2] = $734;
    var $735 = HEAP32[$719 >> 2];
    var $_val17 = HEAP8[$735 + 3 | 0];
    var $_idx18_val = HEAP8[$735 + 4 | 0];
    var $737 = __ZL13get2ByteValuePKh4462($_val17, $_idx18_val);
    HEAP32[$718 + 76 >> 2] = $737;
    var $739 = HEAP32[$1 >> 2];
    var $740 = $739 + 76 | 0;
    if ((HEAP32[$740 >> 2] | 0) == 0) {
      __label__ = 119;
      break;
    } else {
      var $745 = $739;
      __label__ = 120;
      break;
    }
   case 119:
    HEAP32[$740 >> 2] = 2147483647;
    var $745 = HEAP32[$1 >> 2];
    __label__ = 120;
    break;
   case 120:
    var $745;
    var $746 = $745 + 24 | 0;
    var $748 = HEAP32[$746 >> 2] + 5 | 0;
    HEAP32[$746 >> 2] = $748;
    __label__ = 122;
    break;
   case 121:
    HEAP32[$718 + 76 >> 2] = 1;
    HEAP32[$min >> 2] = 1;
    __label__ = 122;
    break;
   case 122:
    var $i5_0 = 1;
    var $751 = HEAP32[$1 >> 2];
    __label__ = 123;
    break;
   case 123:
    var $751;
    var $i5_0;
    var $752 = HEAPU32[$min >> 2];
    if (($i5_0 | 0) > ($752 | 0)) {
      __label__ = 129;
      break;
    } else {
      __label__ = 124;
      break;
    }
   case 124:
    var $755 = $751 + 20 | 0;
    var $756 = HEAPU32[$755 >> 2];
    if ($756 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 125;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 125:
    HEAP32[$755 >> 2] = $756 + 2 | 0;
    var $761 = HEAPU16[$756 >> 1];
    var $762 = $761 & 65535;
    if (($761 & 65535) > 255) {
      __label__ = 126;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 126:
    var $765 = HEAPU32[$1 >> 2];
    if (HEAP8[HEAP32[$765 + 36 >> 2] - 1 | 0] << 24 >> 24 == 54) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      var $784 = $765;
      __label__ = 128;
      break;
    }
   case 127:
    var $773 = HEAPU32[$1 >> 2];
    if ((HEAPU8[HEAP32[$773 + 36 >> 2] + ($762 >>> 3) | 0] & 255 & 1 << ($762 & 7) | 0) == 0) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      var $784 = $773;
      __label__ = 128;
      break;
    }
   case 128:
    var $784;
    var $i5_0 = $i5_0 + 1 | 0;
    var $751 = $784;
    __label__ = 123;
    break;
   case 129:
    if (($752 | 0) == (HEAP32[$751 + 76 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 130;
      break;
    }
   case 130:
    if ((HEAP8[$minimize] & 1) << 24 >> 24 == 0) {
      __label__ = 139;
      break;
    } else {
      __label__ = 131;
      break;
    }
   case 131:
    HEAP32[$751 + 68 >> 2] = $752;
    __label__ = 132;
    break;
   case 132:
    var $797 = HEAP32[$1 >> 2];
    var $799 = HEAP32[$797 + 24 >> 2];
    var $801 = HEAP32[$797 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $799, $801, 22);
    __label__ = 7;
    break;
   case 133:
    var $803 = HEAP32[$1 >> 2];
    if ((HEAP32[$803 + 68 >> 2] | 0) < (HEAP32[$803 + 76 >> 2] | 0)) {
      __label__ = 134;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 134:
    var $810 = $803 + 20 | 0;
    var $811 = HEAPU32[$810 >> 2];
    if ($811 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 135;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 135:
    var $815 = $811 + 2 | 0;
    HEAP32[$810 >> 2] = $815;
    var $816 = HEAPU16[$811 >> 1];
    var $817 = $816 & 65535;
    if (($816 & 65535) > 255) {
      __label__ = 136;
      break;
    } else {
      __label__ = 137;
      break;
    }
   case 136:
    var $820 = HEAPU32[$1 >> 2];
    if (HEAP8[HEAP32[$820 + 36 >> 2] - 1 | 0] << 24 >> 24 == 54) {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    } else {
      var $839 = $820;
      __label__ = 138;
      break;
    }
   case 137:
    var $828 = HEAPU32[$1 >> 2];
    if ((HEAPU8[HEAP32[$828 + 36 >> 2] + ($817 >>> 3) | 0] & 255 & 1 << ($817 & 7) | 0) == 0) {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    } else {
      var $839 = $828;
      __label__ = 138;
      break;
    }
   case 138:
    var $839;
    var $840 = $839 + 68 | 0;
    var $842 = HEAP32[$840 >> 2] + 1 | 0;
    HEAP32[$840 >> 2] = $842;
    __label__ = 132;
    break;
   case 139:
    var $845 = HEAP32[$751 + 20 >> 2];
    HEAP32[$751 + 44 >> 2] = $845;
    var $i7_0 = HEAP32[$min >> 2];
    __label__ = 140;
    break;
   case 140:
    var $i7_0;
    var $849 = HEAPU32[$1 >> 2];
    var $850 = $849 + 36 | 0;
    if (($i7_0 | 0) < (HEAP32[$849 + 76 >> 2] | 0)) {
      __label__ = 141;
      break;
    } else {
      var $883 = $849;
      __label__ = 146;
      break;
    }
   case 141:
    var $855 = $849 + 20 | 0;
    var $856 = HEAPU32[$855 >> 2];
    if ($856 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 142;
      break;
    } else {
      var $883 = $849;
      __label__ = 146;
      break;
    }
   case 142:
    var $860 = HEAPU16[$856 >> 1];
    var $861 = $860 & 65535;
    if (($860 & 65535) > 255) {
      __label__ = 143;
      break;
    } else {
      __label__ = 144;
      break;
    }
   case 143:
    if (HEAP8[HEAP32[$850 >> 2] - 1 | 0] << 24 >> 24 == 54) {
      var $883 = $849;
      __label__ = 146;
      break;
    } else {
      __label__ = 145;
      break;
    }
   case 144:
    if ((HEAPU8[HEAP32[$850 >> 2] + ($861 >>> 3) | 0] & 255 & 1 << ($861 & 7) | 0) == 0) {
      var $883 = $849;
      __label__ = 146;
      break;
    } else {
      __label__ = 145;
      break;
    }
   case 145:
    HEAP32[$855 >> 2] = $856 + 2 | 0;
    var $i7_0 = $i7_0 + 1 | 0;
    __label__ = 140;
    break;
   case 146:
    var $883;
    var $885 = HEAP32[$883 + 24 >> 2];
    var $887 = HEAP32[$883 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $885, $887, 24);
    __label__ = 7;
    break;
   case 147:
    var $890 = HEAP32[$1 >> 2] + 20 | 0;
    var $891 = HEAP32[$890 >> 2];
    var $892 = $891 - 2 | 0;
    HEAP32[$890 >> 2] = $892;
    var $893 = HEAP32[$1 >> 2];
    if (($891 | 0) == (HEAP32[$893 + 44 >> 2] | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      var $883 = $893;
      __label__ = 146;
      break;
    }
   case 148:
    HEAP32[$26 + 36 >> 2] = $29 + 4 | 0;
    var $901 = HEAP32[$1 >> 2] + 24 | 0;
    var $902 = HEAP32[$901 >> 2];
    var $_val36 = HEAP8[$902 + 1 | 0];
    var $_idx37_val = HEAP8[$902 + 2 | 0];
    var $_idx38_val = HEAP8[$902 + 3 | 0];
    var $904 = __ZL12getLinkValuePKh4461($_val36, $_idx37_val, $_idx38_val);
    var $905 = $902 + $904 | 0;
    HEAP32[$901 >> 2] = $905;
    var $906 = HEAPU32[$1 >> 2];
    var $907 = $906 + 24 | 0;
    var $908 = HEAPU32[$907 >> 2];
    var $909 = HEAPU8[$908];
    var $910 = $909 & 255;
    if (($910 | 0) == 46 || ($910 | 0) == 47 || ($910 | 0) == 48 || ($910 | 0) == 49 || ($910 | 0) == 50 || ($910 | 0) == 51) {
      __label__ = 149;
      break;
    } else if (($910 | 0) == 52 || ($910 | 0) == 53) {
      __label__ = 150;
      break;
    } else {
      __label__ = 153;
      break;
    }
   case 149:
    HEAP32[$907 >> 2] = $908 + 1 | 0;
    var $915 = (HEAPU8[$908] & 255) - 46 & 65535;
    var $917 = HEAP32[$1 >> 2] + 76 | 0;
    __ZL38repeatInformationFromInstructionOffsetsRbRiS0_($915, $minimize, $min, $917);
    var $i9_0 = 1;
    __label__ = 154;
    break;
   case 150:
    HEAP8[$minimize] = $909 << 24 >> 24 == 53 & 1;
    var $_val15 = HEAP8[$908 + 1 | 0];
    var $_idx16_val = HEAP8[$908 + 2 | 0];
    var $922 = __ZL13get2ByteValuePKh4462($_val15, $_idx16_val);
    HEAP32[$min >> 2] = $922;
    var $923 = HEAP32[$907 >> 2];
    var $_val13 = HEAP8[$923 + 3 | 0];
    var $_idx14_val = HEAP8[$923 + 4 | 0];
    var $925 = __ZL13get2ByteValuePKh4462($_val13, $_idx14_val);
    HEAP32[$906 + 76 >> 2] = $925;
    var $927 = HEAP32[$1 >> 2];
    var $928 = $927 + 76 | 0;
    if ((HEAP32[$928 >> 2] | 0) == 0) {
      __label__ = 151;
      break;
    } else {
      var $933 = $927;
      __label__ = 152;
      break;
    }
   case 151:
    HEAP32[$928 >> 2] = 2147483647;
    var $933 = HEAP32[$1 >> 2];
    __label__ = 152;
    break;
   case 152:
    var $933;
    var $934 = $933 + 24 | 0;
    var $936 = HEAP32[$934 >> 2] + 5 | 0;
    HEAP32[$934 >> 2] = $936;
    var $i9_0 = 1;
    __label__ = 154;
    break;
   case 153:
    HEAP32[$906 + 76 >> 2] = 1;
    HEAP32[$min >> 2] = 1;
    var $i9_0 = 1;
    __label__ = 154;
    break;
   case 154:
    var $i9_0;
    var $939 = HEAPU32[$min >> 2];
    var $941 = HEAPU32[$1 >> 2];
    if (($i9_0 | 0) > ($939 | 0)) {
      __label__ = 158;
      break;
    } else {
      __label__ = 155;
      break;
    }
   case 155:
    var $943 = $941 + 20 | 0;
    var $944 = HEAPU32[$943 >> 2];
    if ($944 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 156;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 156:
    HEAP32[$943 >> 2] = $944 + 2 | 0;
    var $950 = HEAPU16[$944 >> 1] & 65535;
    var $953 = HEAP32[HEAP32[$1 >> 2] + 36 >> 2];
    var $954 = __Z15jsc_pcre_xclassiPKh($950, $953);
    if ($954) {
      __label__ = 157;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 157:
    var $i9_0 = $i9_0 + 1 | 0;
    __label__ = 154;
    break;
   case 158:
    if (($939 | 0) == (HEAP32[$941 + 76 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 159;
      break;
    }
   case 159:
    if ((HEAP8[$minimize] & 1) << 24 >> 24 == 0) {
      __label__ = 166;
      break;
    } else {
      __label__ = 160;
      break;
    }
   case 160:
    HEAP32[$941 + 68 >> 2] = $939;
    __label__ = 161;
    break;
   case 161:
    var $968 = HEAP32[$1 >> 2];
    var $970 = HEAP32[$968 + 24 >> 2];
    var $972 = HEAP32[$968 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $970, $972, 26);
    __label__ = 7;
    break;
   case 162:
    var $974 = HEAP32[$1 >> 2];
    if ((HEAP32[$974 + 68 >> 2] | 0) < (HEAP32[$974 + 76 >> 2] | 0)) {
      __label__ = 163;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 163:
    var $981 = $974 + 20 | 0;
    var $982 = HEAPU32[$981 >> 2];
    if ($982 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 164;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 164:
    var $986 = $982 + 2 | 0;
    HEAP32[$981 >> 2] = $986;
    var $988 = HEAPU16[$982 >> 1] & 65535;
    var $991 = HEAP32[HEAP32[$1 >> 2] + 36 >> 2];
    var $992 = __Z15jsc_pcre_xclassiPKh($988, $991);
    if ($992) {
      __label__ = 165;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 165:
    var $995 = HEAP32[$1 >> 2] + 68 | 0;
    var $997 = HEAP32[$995 >> 2] + 1 | 0;
    HEAP32[$995 >> 2] = $997;
    __label__ = 161;
    break;
   case 166:
    var $1000 = HEAP32[$941 + 20 >> 2];
    HEAP32[$941 + 44 >> 2] = $1000;
    var $i12_0 = HEAP32[$min >> 2];
    __label__ = 167;
    break;
   case 167:
    var $i12_0;
    var $1004 = HEAPU32[$1 >> 2];
    if (($i12_0 | 0) < (HEAP32[$1004 + 76 >> 2] | 0)) {
      __label__ = 168;
      break;
    } else {
      var $1025 = $1004;
      __label__ = 171;
      break;
    }
   case 168:
    var $1010 = HEAPU32[$1004 + 20 >> 2];
    if ($1010 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 169;
      break;
    } else {
      var $1025 = $1004;
      __label__ = 171;
      break;
    }
   case 169:
    var $1015 = HEAPU16[$1010 >> 1] & 65535;
    var $1017 = HEAP32[$1004 + 36 >> 2];
    var $1018 = __Z15jsc_pcre_xclassiPKh($1015, $1017);
    var $1019 = HEAPU32[$1 >> 2];
    if ($1018) {
      __label__ = 170;
      break;
    } else {
      var $1025 = $1019;
      __label__ = 171;
      break;
    }
   case 170:
    var $1021 = $1019 + 20 | 0;
    var $1023 = HEAP32[$1021 >> 2] + 2 | 0;
    HEAP32[$1021 >> 2] = $1023;
    var $i12_0 = $i12_0 + 1 | 0;
    __label__ = 167;
    break;
   case 171:
    var $1025;
    var $1027 = HEAP32[$1025 + 24 >> 2];
    var $1029 = HEAP32[$1025 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $1027, $1029, 27);
    __label__ = 7;
    break;
   case 172:
    var $1032 = HEAP32[$1 >> 2] + 20 | 0;
    var $1033 = HEAP32[$1032 >> 2];
    var $1034 = $1033 - 2 | 0;
    HEAP32[$1032 >> 2] = $1034;
    var $1035 = HEAP32[$1 >> 2];
    if (($1033 | 0) == (HEAP32[$1035 + 44 >> 2] | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      var $1025 = $1035;
      __label__ = 171;
      break;
    }
   case 173:
    HEAP32[$26 + 72 >> 2] = 1;
    var $1042 = HEAP32[$1 >> 2] + 24 | 0;
    var $1044 = HEAP32[$1042 >> 2] + 1 | 0;
    HEAP32[$1042 >> 2] = $1044;
    var $1045 = HEAP32[$1 >> 2];
    var $1046 = $1045 + 64 | 0;
    var $1048 = HEAP32[$1045 + 24 >> 2];
    var $1049 = $1045 + 72 | 0;
    __ZL29getUTF8CharAndIncrementLengthRiPKhS_($1046, $1048, $1049);
    var $1050 = HEAP32[$1 >> 2];
    var $1053 = $1050 + 24 | 0;
    var $1055 = HEAP32[$1053 >> 2] + HEAP32[$1050 + 72 >> 2] | 0;
    HEAP32[$1053 >> 2] = $1055;
    var $1056 = HEAPU32[$1 >> 2];
    var $1057 = $1056 + 20 | 0;
    var $1058 = HEAPU32[$1057 >> 2];
    if ($1058 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 174;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 174:
    var $1063 = HEAP32[$1056 + 64 >> 2];
    HEAP32[$1057 >> 2] = $1058 + 2 | 0;
    if (($1063 | 0) == (HEAPU16[$1058 >> 1] & 65535 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 175:
    HEAP32[$26 + 72 >> 2] = 1;
    var $1071 = HEAP32[$1 >> 2] + 24 | 0;
    var $1073 = HEAP32[$1071 >> 2] + 1 | 0;
    HEAP32[$1071 >> 2] = $1073;
    var $1074 = HEAP32[$1 >> 2];
    var $1075 = $1074 + 64 | 0;
    var $1077 = HEAP32[$1074 + 24 >> 2];
    var $1078 = $1074 + 72 | 0;
    __ZL29getUTF8CharAndIncrementLengthRiPKhS_($1075, $1077, $1078);
    var $1079 = HEAP32[$1 >> 2];
    var $1082 = $1079 + 24 | 0;
    var $1084 = HEAP32[$1082 >> 2] + HEAP32[$1079 + 72 >> 2] | 0;
    HEAP32[$1082 >> 2] = $1084;
    var $1086 = HEAP32[$1 >> 2] + 20 | 0;
    var $1087 = HEAPU32[$1086 >> 2];
    if ($1087 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 176;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 176:
    var $1091 = $1087 + 2 | 0;
    HEAP32[$1086 >> 2] = $1091;
    var $1093 = HEAPU16[$1087 >> 1] & 65535;
    var $1096 = HEAPU32[HEAP32[$1 >> 2] + 64 >> 2];
    if (($1096 | 0) == ($1093 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 177;
      break;
    }
   case 177:
    var $1099 = __Z22jsc_pcre_ucp_othercasej($1096);
    if (($1099 | 0) == ($1093 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 178:
    var $1103 = $27 | 0;
    var $1104 = HEAPU32[$1103 >> 2];
    if ((HEAP32[$20 >> 2] | 0) == ($1104 | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 179;
      break;
    }
   case 179:
    if ((HEAPU16[$1104 >> 1] & 65535 | 0) == (HEAPU8[$29 + 1 | 0] & 255 | 0)) {
      __label__ = 180;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 180:
    HEAP32[$1103 >> 2] = $1104 + 2 | 0;
    var $1116 = HEAP32[$1 >> 2] + 24 | 0;
    var $1118 = HEAP32[$1116 >> 2] + 2 | 0;
    HEAP32[$1116 >> 2] = $1118;
    __label__ = 4;
    break;
   case 181:
    var $1121 = $27 | 0;
    var $1122 = HEAPU32[$1121 >> 2];
    if ((HEAP32[$20 >> 2] | 0) == ($1122 | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 182;
      break;
    }
   case 182:
    if ((HEAPU16[$1122 >> 1] & 65535 | 32 | 0) == (HEAPU8[$29 + 1 | 0] & 255 | 0)) {
      __label__ = 183;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 183:
    HEAP32[$1121 >> 2] = $1122 + 2 | 0;
    var $1135 = HEAP32[$1 >> 2] + 24 | 0;
    var $1137 = HEAP32[$1135 >> 2] + 2 | 0;
    HEAP32[$1135 >> 2] = $1137;
    __label__ = 4;
    break;
   case 184:
    var $_val11 = HEAP8[$29 + 1 | 0];
    var $_idx12_val = HEAP8[$29 + 2 | 0];
    var $1140 = __ZL13get2ByteValuePKh4462($_val11, $_idx12_val);
    HEAP32[$26 + 76 >> 2] = $1140;
    HEAP32[$min >> 2] = $1140;
    HEAP8[$minimize] = 0;
    var $1143 = HEAP32[$1 >> 2] + 24 | 0;
    var $1145 = HEAP32[$1143 >> 2] + 3 | 0;
    HEAP32[$1143 >> 2] = $1145;
    __label__ = 187;
    break;
   case 185:
    HEAP32[$min >> 2] = 0;
    var $1147 = HEAP32[$28 >> 2];
    var $_val9 = HEAP8[$1147 + 1 | 0];
    var $_idx10_val = HEAP8[$1147 + 2 | 0];
    var $1149 = __ZL13get2ByteValuePKh4462($_val9, $_idx10_val);
    HEAP32[$26 + 76 >> 2] = $1149;
    var $1152 = HEAP32[$1 >> 2] + 24 | 0;
    var $1153 = HEAPU32[$1152 >> 2];
    var $1156 = HEAP8[$1153] << 24 >> 24 == 26 & 1;
    HEAP8[$minimize] = $1156;
    var $1157 = $1153 + 3 | 0;
    HEAP32[$1152 >> 2] = $1157;
    __label__ = 187;
    break;
   case 186:
    HEAP32[$28 >> 2] = $29 + 1 | 0;
    var $1162 = (HEAPU8[$29] & 255) - 19 & 65535;
    var $1164 = HEAP32[$1 >> 2] + 76 | 0;
    __ZL38repeatInformationFromInstructionOffsetsRbRiS0_($1162, $minimize, $min, $1164);
    __label__ = 187;
    break;
   case 187:
    var $1167 = HEAP32[$1 >> 2] + 72 | 0;
    HEAP32[$1167 >> 2] = 1;
    var $1168 = HEAP32[$1 >> 2];
    var $1169 = $1168 + 64 | 0;
    var $1171 = HEAP32[$1168 + 24 >> 2];
    var $1172 = $1168 + 72 | 0;
    __ZL29getUTF8CharAndIncrementLengthRiPKhS_($1169, $1171, $1172);
    var $1174 = HEAPU32[$1 >> 2];
    var $1178 = (HEAP32[$1174 + 64 >> 2] | 0) > 65535 ? 2 : 1;
    if (($1178 * HEAP32[$min >> 2] | 0) > (HEAP32[$20 >> 2] - HEAP32[$1174 + 20 >> 2] >> 1 | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 188;
      break;
    }
   case 188:
    var $1191 = $1174 + 24 | 0;
    var $1193 = HEAP32[$1191 >> 2] + HEAP32[$1174 + 72 >> 2] | 0;
    HEAP32[$1191 >> 2] = $1193;
    var $1194 = HEAPU32[$1 >> 2];
    var $1196 = HEAP32[$1194 + 64 >> 2];
    if (($1196 | 0) < 65536) {
      __label__ = 189;
      break;
    } else {
      var $i16_0 = 1;
      var $1310 = $1194;
      __label__ = 212;
      break;
    }
   case 189:
    if ((HEAP8[$21] & 1) << 24 >> 24 == 0) {
      var $1205 = -1;
      __label__ = 191;
      break;
    } else {
      __label__ = 190;
      break;
    }
   case 190:
    var $1203 = __Z22jsc_pcre_ucp_othercasej($1196);
    var $1205 = $1203;
    __label__ = 191;
    break;
   case 191:
    var $1205;
    var $i14_0 = 1;
    var $1207 = $1194;
    __label__ = 192;
    break;
   case 192:
    var $1207;
    var $i14_0;
    var $1208 = HEAPU32[$min >> 2];
    if (($i14_0 | 0) > ($1208 | 0)) {
      __label__ = 195;
      break;
    } else {
      __label__ = 193;
      break;
    }
   case 193:
    var $1211 = $1207 + 20 | 0;
    var $1212 = HEAPU32[$1211 >> 2];
    var $1214 = HEAPU16[$1212 >> 1] & 65535;
    if (($1214 | 0) == (HEAP32[$1207 + 64 >> 2] | 0) | ($1214 | 0) == ($1205 | 0)) {
      __label__ = 194;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 194:
    HEAP32[$1211 >> 2] = $1212 + 2 | 0;
    var $i14_0 = $i14_0 + 1 | 0;
    var $1207 = HEAP32[$1 >> 2];
    __label__ = 192;
    break;
   case 195:
    if (($1208 | 0) == (HEAP32[$1207 + 76 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 196;
      break;
    }
   case 196:
    if ((HEAP8[$minimize] & 1) << 24 >> 24 == 0) {
      __label__ = 204;
      break;
    } else {
      __label__ = 197;
      break;
    }
   case 197:
    HEAP32[$1207 + 52 >> 2] = $1205;
    var $1232 = HEAP32[$min >> 2];
    var $1234 = HEAP32[$1 >> 2] + 68 | 0;
    HEAP32[$1234 >> 2] = $1232;
    __label__ = 198;
    break;
   case 198:
    var $1236 = HEAP32[$1 >> 2];
    var $1238 = HEAP32[$1236 + 24 >> 2];
    var $1240 = HEAP32[$1236 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $1238, $1240, 28);
    __label__ = 7;
    break;
   case 199:
    var $1242 = HEAPU32[$1 >> 2];
    if ((HEAP32[$1242 + 68 >> 2] | 0) < (HEAP32[$1242 + 76 >> 2] | 0)) {
      __label__ = 200;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 200:
    var $1249 = $1242 + 20 | 0;
    var $1250 = HEAPU32[$1249 >> 2];
    if ($1250 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 201;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 201:
    var $1255 = HEAPU16[$1250 >> 1] & 65535;
    if (($1255 | 0) == (HEAP32[$1242 + 64 >> 2] | 0)) {
      __label__ = 203;
      break;
    } else {
      __label__ = 202;
      break;
    }
   case 202:
    if (($1255 | 0) == (HEAP32[$1242 + 52 >> 2] | 0)) {
      __label__ = 203;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 203:
    HEAP32[$1249 >> 2] = $1250 + 2 | 0;
    var $1266 = HEAP32[$1 >> 2] + 68 | 0;
    var $1268 = HEAP32[$1266 >> 2] + 1 | 0;
    HEAP32[$1266 >> 2] = $1268;
    __label__ = 198;
    break;
   case 204:
    var $1271 = HEAP32[$1207 + 20 >> 2];
    HEAP32[$1207 + 44 >> 2] = $1271;
    var $i15_0 = HEAP32[$min >> 2];
    __label__ = 205;
    break;
   case 205:
    var $i15_0;
    var $1275 = HEAPU32[$1 >> 2];
    if (($i15_0 | 0) < (HEAP32[$1275 + 76 >> 2] | 0)) {
      __label__ = 206;
      break;
    } else {
      var $1294 = $1275;
      __label__ = 209;
      break;
    }
   case 206:
    var $1280 = $1275 + 20 | 0;
    var $1281 = HEAPU32[$1280 >> 2];
    if ($1281 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 207;
      break;
    } else {
      var $1294 = $1275;
      __label__ = 209;
      break;
    }
   case 207:
    var $1286 = HEAPU16[$1281 >> 1] & 65535;
    if (($1286 | 0) == (HEAP32[$1275 + 64 >> 2] | 0) | ($1286 | 0) == ($1205 | 0)) {
      __label__ = 208;
      break;
    } else {
      var $1294 = $1275;
      __label__ = 209;
      break;
    }
   case 208:
    HEAP32[$1280 >> 2] = $1281 + 2 | 0;
    var $i15_0 = $i15_0 + 1 | 0;
    __label__ = 205;
    break;
   case 209:
    var $1294;
    if (HEAPU32[$1294 + 20 >> 2] >>> 0 < HEAPU32[$1294 + 44 >> 2] >>> 0) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 210;
      break;
    }
   case 210:
    var $1302 = HEAP32[$1294 + 24 >> 2];
    var $1304 = HEAP32[$1294 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $1302, $1304, 29);
    __label__ = 7;
    break;
   case 211:
    var $1307 = HEAP32[$1 >> 2] + 20 | 0;
    var $1309 = HEAP32[$1307 >> 2] - 2 | 0;
    HEAP32[$1307 >> 2] = $1309;
    var $1294 = HEAP32[$1 >> 2];
    __label__ = 209;
    break;
   case 212:
    var $1310;
    var $i16_0;
    var $1311 = HEAPU32[$min >> 2];
    if (($i16_0 | 0) > ($1311 | 0)) {
      __label__ = 215;
      break;
    } else {
      __label__ = 213;
      break;
    }
   case 213:
    var $1314 = $1310 + 20 | 0;
    var $1315 = HEAPU32[$1314 >> 2];
    if ((HEAPU16[$1315 >> 1] & 65535 | 0) == (HEAP32[$1310 + 64 >> 2] | 0)) {
      __label__ = 214;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 214:
    HEAP32[$1314 >> 2] = $1315 + 4 | 0;
    var $i16_0 = $i16_0 + 1 | 0;
    var $1310 = HEAP32[$1 >> 2];
    __label__ = 212;
    break;
   case 215:
    if (($1311 | 0) == (HEAP32[$1310 + 76 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 216;
      break;
    }
   case 216:
    if ((HEAP8[$minimize] & 1) << 24 >> 24 == 0) {
      __label__ = 223;
      break;
    } else {
      __label__ = 217;
      break;
    }
   case 217:
    HEAP32[$1310 + 68 >> 2] = $1311;
    __label__ = 218;
    break;
   case 218:
    var $1335 = HEAP32[$1 >> 2];
    var $1337 = HEAP32[$1335 + 24 >> 2];
    var $1339 = HEAP32[$1335 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $1337, $1339, 30);
    __label__ = 7;
    break;
   case 219:
    var $1341 = HEAPU32[$1 >> 2];
    if ((HEAP32[$1341 + 68 >> 2] | 0) < (HEAP32[$1341 + 76 >> 2] | 0)) {
      __label__ = 220;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 220:
    var $1348 = $1341 + 20 | 0;
    var $1349 = HEAPU32[$1348 >> 2];
    if ($1349 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 221;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 221:
    if ((HEAPU16[$1349 >> 1] & 65535 | 0) == (HEAP32[$1341 + 64 >> 2] | 0)) {
      __label__ = 222;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 222:
    HEAP32[$1348 >> 2] = $1349 + 4 | 0;
    var $1361 = HEAP32[$1 >> 2] + 68 | 0;
    var $1363 = HEAP32[$1361 >> 2] + 1 | 0;
    HEAP32[$1361 >> 2] = $1363;
    __label__ = 218;
    break;
   case 223:
    var $1366 = HEAP32[$1310 + 20 >> 2];
    HEAP32[$1310 + 44 >> 2] = $1366;
    var $i17_0 = HEAP32[$min >> 2];
    __label__ = 224;
    break;
   case 224:
    var $i17_0;
    var $1370 = HEAPU32[$1 >> 2];
    if (($i17_0 | 0) < (HEAP32[$1370 + 76 >> 2] | 0)) {
      __label__ = 225;
      break;
    } else {
      var $1389 = $1370;
      __label__ = 228;
      break;
    }
   case 225:
    var $1375 = $1370 + 20 | 0;
    var $1376 = HEAPU32[$1375 >> 2];
    if ($1376 >>> 0 > (HEAP32[$20 >> 2] - 4 | 0) >>> 0) {
      var $1389 = $1370;
      __label__ = 228;
      break;
    } else {
      __label__ = 226;
      break;
    }
   case 226:
    if ((HEAPU16[$1376 >> 1] & 65535 | 0) == (HEAP32[$1370 + 64 >> 2] | 0)) {
      __label__ = 227;
      break;
    } else {
      var $1389 = $1370;
      __label__ = 228;
      break;
    }
   case 227:
    HEAP32[$1375 >> 2] = $1376 + 4 | 0;
    var $i17_0 = $i17_0 + 1 | 0;
    __label__ = 224;
    break;
   case 228:
    var $1389;
    if (HEAPU32[$1389 + 20 >> 2] >>> 0 < HEAPU32[$1389 + 44 >> 2] >>> 0) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 229;
      break;
    }
   case 229:
    var $1397 = HEAP32[$1389 + 24 >> 2];
    var $1399 = HEAP32[$1389 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $1397, $1399, 31);
    __label__ = 7;
    break;
   case 230:
    var $1402 = HEAP32[$1 >> 2] + 20 | 0;
    var $1404 = HEAP32[$1402 >> 2] - 4 | 0;
    HEAP32[$1402 >> 2] = $1404;
    var $1389 = HEAP32[$1 >> 2];
    __label__ = 228;
    break;
   case 231:
    var $1406 = $27 | 0;
    var $1407 = HEAPU32[$1406 >> 2];
    if ($1407 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 232;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 232:
    var $1412 = HEAPU8[$29 + 1 | 0];
    HEAP32[$1406 >> 2] = $1407 + 2 | 0;
    var $1414 = HEAPU16[$1407 >> 1];
    var $1415 = $1414 & 65535;
    var $1417 = HEAP32[$1 >> 2] + 24 | 0;
    var $1419 = HEAP32[$1417 >> 2] + 2 | 0;
    HEAP32[$1417 >> 2] = $1419;
    if ((HEAP8[$21] & 1) << 24 >> 24 == 0) {
      __label__ = 236;
      break;
    } else {
      __label__ = 233;
      break;
    }
   case 233:
    if (($1414 & 65535) < 128) {
      __label__ = 234;
      break;
    } else {
      var $c18_0 = $1415;
      __label__ = 235;
      break;
    }
   case 234:
    var $1426 = $1414 & 255;
    var $1427 = __ZL11toLowerCaseh($1426);
    var $c18_0 = $1427 & 255;
    __label__ = 235;
    break;
   case 235:
    var $c18_0;
    var $1430 = __ZL11toLowerCaseh($1412);
    if (($1430 & 255 | 0) == ($c18_0 | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 236:
    if (($1412 & 255 | 0) == ($1415 | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 237:
    var $_val7 = HEAP8[$29 + 1 | 0];
    var $_idx8_val = HEAP8[$29 + 2 | 0];
    var $1438 = __ZL13get2ByteValuePKh4462($_val7, $_idx8_val);
    HEAP32[$26 + 76 >> 2] = $1438;
    HEAP32[$min >> 2] = $1438;
    HEAP8[$minimize] = 0;
    var $1441 = HEAP32[$1 >> 2] + 24 | 0;
    var $1443 = HEAP32[$1441 >> 2] + 3 | 0;
    HEAP32[$1441 >> 2] = $1443;
    __label__ = 240;
    break;
   case 238:
    HEAP32[$min >> 2] = 0;
    var $1445 = HEAP32[$28 >> 2];
    var $_val5 = HEAP8[$1445 + 1 | 0];
    var $_idx6_val = HEAP8[$1445 + 2 | 0];
    var $1447 = __ZL13get2ByteValuePKh4462($_val5, $_idx6_val);
    HEAP32[$26 + 76 >> 2] = $1447;
    var $1450 = HEAP32[$1 >> 2] + 24 | 0;
    var $1451 = HEAPU32[$1450 >> 2];
    var $1454 = HEAP8[$1451] << 24 >> 24 == 35 & 1;
    HEAP8[$minimize] = $1454;
    var $1455 = $1451 + 3 | 0;
    HEAP32[$1450 >> 2] = $1455;
    __label__ = 240;
    break;
   case 239:
    HEAP32[$28 >> 2] = $29 + 1 | 0;
    var $1460 = (HEAPU8[$29] & 255) - 28 & 65535;
    var $1462 = HEAP32[$1 >> 2] + 76 | 0;
    __ZL38repeatInformationFromInstructionOffsetsRbRiS0_($1460, $minimize, $min, $1462);
    __label__ = 240;
    break;
   case 240:
    var $1466 = HEAPU32[$1 >> 2];
    if ((HEAP32[$min >> 2] | 0) > (HEAP32[$20 >> 2] - HEAP32[$1466 + 20 >> 2] >> 1 | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 241;
      break;
    }
   case 241:
    var $1475 = $1466 + 24 | 0;
    var $1476 = HEAP32[$1475 >> 2];
    var $1477 = $1476 + 1 | 0;
    HEAP32[$1475 >> 2] = $1477;
    var $1479 = HEAPU8[$1476] & 255;
    var $1481 = HEAP32[$1 >> 2] + 64 | 0;
    HEAP32[$1481 >> 2] = $1479;
    var $_pre113 = HEAPU32[$1 >> 2];
    if ((HEAP8[$21] & 1) << 24 >> 24 == 0) {
      var $i23_0 = 1;
      var $1604 = $_pre113;
      __label__ = 268;
      break;
    } else {
      __label__ = 242;
      break;
    }
   case 242:
    var $1486 = $_pre113 + 64 | 0;
    var $1487 = HEAP32[$1486 >> 2];
    if (($1487 | 0) < 128) {
      __label__ = 243;
      break;
    } else {
      var $i19_0 = 1;
      var $1493 = $_pre113;
      __label__ = 244;
      break;
    }
   case 243:
    var $1490 = $1487 & 255;
    var $1491 = __ZL11toLowerCaseh($1490);
    var $1492 = $1491 & 255;
    HEAP32[$1486 >> 2] = $1492;
    var $i19_0 = 1;
    var $1493 = HEAP32[$1 >> 2];
    __label__ = 244;
    break;
   case 244:
    var $1493;
    var $i19_0;
    var $1494 = HEAPU32[$min >> 2];
    if (($i19_0 | 0) > ($1494 | 0)) {
      __label__ = 249;
      break;
    } else {
      __label__ = 245;
      break;
    }
   case 245:
    var $1497 = $1493 + 20 | 0;
    var $1498 = HEAP32[$1497 >> 2];
    var $1499 = $1498 + 2 | 0;
    HEAP32[$1497 >> 2] = $1499;
    var $1500 = HEAPU16[$1498 >> 1];
    var $1501 = $1500 & 65535;
    if (($1500 & 65535) < 128) {
      __label__ = 246;
      break;
    } else {
      var $d_0 = $1501;
      __label__ = 247;
      break;
    }
   case 246:
    var $1504 = $1500 & 255;
    var $1505 = __ZL11toLowerCaseh($1504);
    var $d_0 = $1505 & 255;
    __label__ = 247;
    break;
   case 247:
    var $d_0;
    var $1508 = HEAPU32[$1 >> 2];
    if ((HEAP32[$1508 + 64 >> 2] | 0) == ($d_0 | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 248;
      break;
    }
   case 248:
    var $i19_0 = $i19_0 + 1 | 0;
    var $1493 = $1508;
    __label__ = 244;
    break;
   case 249:
    if (($1494 | 0) == (HEAP32[$1493 + 76 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 250;
      break;
    }
   case 250:
    if ((HEAP8[$minimize] & 1) << 24 >> 24 == 0) {
      __label__ = 259;
      break;
    } else {
      __label__ = 251;
      break;
    }
   case 251:
    HEAP32[$1493 + 68 >> 2] = $1494;
    __label__ = 252;
    break;
   case 252:
    var $1525 = HEAP32[$1 >> 2];
    var $1527 = HEAP32[$1525 + 24 >> 2];
    var $1529 = HEAP32[$1525 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $1527, $1529, 38);
    __label__ = 7;
    break;
   case 253:
    var $1532 = HEAP32[$1 >> 2] + 20 | 0;
    var $1533 = HEAP32[$1532 >> 2];
    var $1534 = $1533 + 2 | 0;
    HEAP32[$1532 >> 2] = $1534;
    var $1535 = HEAPU16[$1533 >> 1];
    var $1536 = $1535 & 65535;
    if (($1535 & 65535) < 128) {
      __label__ = 254;
      break;
    } else {
      var $d20_0 = $1536;
      __label__ = 255;
      break;
    }
   case 254:
    var $1539 = $1535 & 255;
    var $1540 = __ZL11toLowerCaseh($1539);
    var $d20_0 = $1540 & 255;
    __label__ = 255;
    break;
   case 255:
    var $d20_0;
    var $1543 = HEAPU32[$1 >> 2];
    var $1544 = $1543 + 68 | 0;
    var $1545 = HEAPU32[$1544 >> 2];
    if (($1545 | 0) < (HEAP32[$1543 + 76 >> 2] | 0)) {
      __label__ = 256;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 256:
    if (HEAPU32[$1543 + 20 >> 2] >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 257;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 257:
    if ((HEAP32[$1543 + 64 >> 2] | 0) == ($d20_0 | 0)) {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    } else {
      __label__ = 258;
      break;
    }
   case 258:
    HEAP32[$1544 >> 2] = $1545 + 1 | 0;
    __label__ = 252;
    break;
   case 259:
    var $1562 = HEAP32[$1493 + 20 >> 2];
    HEAP32[$1493 + 44 >> 2] = $1562;
    var $i21_0 = HEAP32[$min >> 2];
    __label__ = 260;
    break;
   case 260:
    var $i21_0;
    var $1566 = HEAPU32[$1 >> 2];
    if (($i21_0 | 0) < (HEAP32[$1566 + 76 >> 2] | 0)) {
      __label__ = 261;
      break;
    } else {
      var $1590 = $1566;
      __label__ = 266;
      break;
    }
   case 261:
    var $1571 = $1566 + 20 | 0;
    var $1572 = HEAPU32[$1571 >> 2];
    if ($1572 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 262;
      break;
    } else {
      var $1590 = $1566;
      __label__ = 266;
      break;
    }
   case 262:
    var $1576 = HEAPU16[$1572 >> 1];
    var $1577 = $1576 & 65535;
    if (($1576 & 65535) < 128) {
      __label__ = 263;
      break;
    } else {
      var $d22_0 = $1577;
      __label__ = 264;
      break;
    }
   case 263:
    var $1580 = $1576 & 255;
    var $1581 = __ZL11toLowerCaseh($1580);
    var $d22_0 = $1581 & 255;
    __label__ = 264;
    break;
   case 264:
    var $d22_0;
    if ((HEAP32[$1566 + 64 >> 2] | 0) == ($d22_0 | 0)) {
      var $1590 = $1566;
      __label__ = 266;
      break;
    } else {
      __label__ = 265;
      break;
    }
   case 265:
    HEAP32[$1571 >> 2] = $1572 + 2 | 0;
    var $i21_0 = $i21_0 + 1 | 0;
    __label__ = 260;
    break;
   case 266:
    var $1590;
    var $1592 = HEAP32[$1590 + 24 >> 2];
    var $1594 = HEAP32[$1590 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $1592, $1594, 40);
    __label__ = 7;
    break;
   case 267:
    var $1597 = HEAP32[$1 >> 2] + 20 | 0;
    var $1598 = HEAP32[$1597 >> 2];
    var $1599 = $1598 - 2 | 0;
    HEAP32[$1597 >> 2] = $1599;
    var $1600 = HEAP32[$1 >> 2];
    if (($1598 | 0) == (HEAP32[$1600 + 44 >> 2] | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      var $1590 = $1600;
      __label__ = 266;
      break;
    }
   case 268:
    var $1604;
    var $i23_0;
    var $1605 = HEAPU32[$min >> 2];
    if (($i23_0 | 0) > ($1605 | 0)) {
      __label__ = 271;
      break;
    } else {
      __label__ = 269;
      break;
    }
   case 269:
    var $1608 = $1604 + 20 | 0;
    var $1609 = HEAP32[$1608 >> 2];
    var $1610 = $1609 + 2 | 0;
    HEAP32[$1608 >> 2] = $1610;
    var $1613 = HEAP32[$1 >> 2];
    if ((HEAP32[$1613 + 64 >> 2] | 0) == (HEAPU16[$1609 >> 1] & 65535 | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 270;
      break;
    }
   case 270:
    var $i23_0 = $i23_0 + 1 | 0;
    var $1604 = $1613;
    __label__ = 268;
    break;
   case 271:
    if (($1605 | 0) == (HEAP32[$1604 + 76 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 272;
      break;
    }
   case 272:
    if ((HEAP8[$minimize] & 1) << 24 >> 24 == 0) {
      __label__ = 279;
      break;
    } else {
      __label__ = 273;
      break;
    }
   case 273:
    HEAP32[$1604 + 68 >> 2] = $1605;
    __label__ = 274;
    break;
   case 274:
    var $1630 = HEAP32[$1 >> 2];
    var $1632 = HEAP32[$1630 + 24 >> 2];
    var $1634 = HEAP32[$1630 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $1632, $1634, 42);
    __label__ = 7;
    break;
   case 275:
    var $1637 = HEAP32[$1 >> 2] + 20 | 0;
    var $1638 = HEAP32[$1637 >> 2];
    var $1639 = $1638 + 2 | 0;
    HEAP32[$1637 >> 2] = $1639;
    var $1641 = HEAPU16[$1638 >> 1] & 65535;
    var $1642 = HEAPU32[$1 >> 2];
    var $1643 = $1642 + 68 | 0;
    var $1644 = HEAPU32[$1643 >> 2];
    if (($1644 | 0) < (HEAP32[$1642 + 76 >> 2] | 0)) {
      __label__ = 276;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 276:
    if (HEAPU32[$1642 + 20 >> 2] >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 277;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 277:
    if ((HEAP32[$1642 + 64 >> 2] | 0) == ($1641 | 0)) {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    } else {
      __label__ = 278;
      break;
    }
   case 278:
    HEAP32[$1643 >> 2] = $1644 + 1 | 0;
    __label__ = 274;
    break;
   case 279:
    var $1661 = HEAP32[$1604 + 20 >> 2];
    HEAP32[$1604 + 44 >> 2] = $1661;
    var $i26_0 = HEAP32[$min >> 2];
    __label__ = 280;
    break;
   case 280:
    var $i26_0;
    var $1665 = HEAPU32[$1 >> 2];
    if (($i26_0 | 0) < (HEAP32[$1665 + 76 >> 2] | 0)) {
      __label__ = 281;
      break;
    } else {
      var $1683 = $1665;
      __label__ = 284;
      break;
    }
   case 281:
    var $1670 = $1665 + 20 | 0;
    var $1671 = HEAPU32[$1670 >> 2];
    if ($1671 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 282;
      break;
    } else {
      var $1683 = $1665;
      __label__ = 284;
      break;
    }
   case 282:
    if ((HEAP32[$1665 + 64 >> 2] | 0) == (HEAPU16[$1671 >> 1] & 65535 | 0)) {
      var $1683 = $1665;
      __label__ = 284;
      break;
    } else {
      __label__ = 283;
      break;
    }
   case 283:
    HEAP32[$1670 >> 2] = $1671 + 2 | 0;
    var $i26_0 = $i26_0 + 1 | 0;
    __label__ = 280;
    break;
   case 284:
    var $1683;
    var $1685 = HEAP32[$1683 + 24 >> 2];
    var $1687 = HEAP32[$1683 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $1685, $1687, 44);
    __label__ = 7;
    break;
   case 285:
    var $1690 = HEAP32[$1 >> 2] + 20 | 0;
    var $1691 = HEAP32[$1690 >> 2];
    var $1692 = $1691 - 2 | 0;
    HEAP32[$1690 >> 2] = $1692;
    var $1693 = HEAP32[$1 >> 2];
    if (($1691 | 0) == (HEAP32[$1693 + 44 >> 2] | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      var $1683 = $1693;
      __label__ = 284;
      break;
    }
   case 286:
    var $_val3 = HEAP8[$29 + 1 | 0];
    var $_idx4_val = HEAP8[$29 + 2 | 0];
    var $1699 = __ZL13get2ByteValuePKh4462($_val3, $_idx4_val);
    HEAP32[$26 + 76 >> 2] = $1699;
    HEAP32[$min >> 2] = $1699;
    HEAP8[$minimize] = 1;
    var $1702 = HEAP32[$1 >> 2] + 24 | 0;
    var $1704 = HEAP32[$1702 >> 2] + 3 | 0;
    HEAP32[$1702 >> 2] = $1704;
    __label__ = 289;
    break;
   case 287:
    HEAP32[$min >> 2] = 0;
    var $1706 = HEAP32[$28 >> 2];
    var $_val1 = HEAP8[$1706 + 1 | 0];
    var $_idx2_val = HEAP8[$1706 + 2 | 0];
    var $1708 = __ZL13get2ByteValuePKh4462($_val1, $_idx2_val);
    HEAP32[$26 + 76 >> 2] = $1708;
    var $1711 = HEAP32[$1 >> 2] + 24 | 0;
    var $1712 = HEAPU32[$1711 >> 2];
    var $1715 = HEAP8[$1712] << 24 >> 24 == 44 & 1;
    HEAP8[$minimize] = $1715;
    var $1716 = $1712 + 3 | 0;
    HEAP32[$1711 >> 2] = $1716;
    __label__ = 289;
    break;
   case 288:
    HEAP32[$28 >> 2] = $29 + 1 | 0;
    var $1721 = (HEAPU8[$29] & 255) - 37 & 65535;
    var $1723 = HEAP32[$1 >> 2] + 76 | 0;
    __ZL38repeatInformationFromInstructionOffsetsRbRiS0_($1721, $minimize, $min, $1723);
    __label__ = 289;
    break;
   case 289:
    var $1726 = HEAP32[$1 >> 2] + 24 | 0;
    var $1727 = HEAP32[$1726 >> 2];
    var $1728 = $1727 + 1 | 0;
    HEAP32[$1726 >> 2] = $1728;
    var $1730 = HEAPU8[$1727] & 255;
    var $1732 = HEAP32[$1 >> 2] + 60 | 0;
    HEAP32[$1732 >> 2] = $1730;
    var $1733 = HEAPU32[$min >> 2];
    var $1735 = HEAPU32[$1 >> 2];
    if (($1733 | 0) > (HEAP32[$20 >> 2] - HEAP32[$1735 + 20 >> 2] >> 1 | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 290;
      break;
    }
   case 290:
    if (($1733 | 0) > 0) {
      __label__ = 291;
      break;
    } else {
      var $1827 = $1733;
      __label__ = 314;
      break;
    }
   case 291:
    var $1747 = HEAP32[$1735 + 60 >> 2];
    if (($1747 | 0) == 9) {
      var $i28_0 = 1;
      var $1748 = $1733;
      __label__ = 292;
      break;
    } else if (($1747 | 0) == 3) {
      var $i29_0 = 1;
      var $1759 = $1733;
      __label__ = 295;
      break;
    } else if (($1747 | 0) == 4) {
      var $i30_0 = 1;
      var $1770 = $1733;
      __label__ = 298;
      break;
    } else if (($1747 | 0) == 5) {
      var $i31_0 = 1;
      var $1781 = $1733;
      __label__ = 301;
      break;
    } else if (($1747 | 0) == 6) {
      var $i32_0 = 1;
      var $1792 = $1733;
      __label__ = 304;
      break;
    } else if (($1747 | 0) == 7) {
      var $i33_0 = 1;
      var $1803 = $1733;
      __label__ = 307;
      break;
    } else if (($1747 | 0) == 8) {
      var $i34_0 = 1;
      var $1814 = $1733;
      __label__ = 310;
      break;
    } else {
      __label__ = 313;
      break;
    }
   case 292:
    var $1748;
    var $i28_0;
    if (($i28_0 | 0) > ($1748 | 0)) {
      var $1827 = $1748;
      __label__ = 314;
      break;
    } else {
      __label__ = 293;
      break;
    }
   case 293:
    var $1752 = HEAP32[$1 >> 2] + 20 | 0;
    var $1753 = HEAP32[$1752 >> 2];
    var $1754 = HEAP16[$1753 >> 1];
    var $1755 = __ZL9isNewlinet($1754);
    if ($1755) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 294;
      break;
    }
   case 294:
    var $1757 = $1753 + 2 | 0;
    HEAP32[$1752 >> 2] = $1757;
    var $i28_0 = $i28_0 + 1 | 0;
    var $1748 = HEAP32[$min >> 2];
    __label__ = 292;
    break;
   case 295:
    var $1759;
    var $i29_0;
    if (($i29_0 | 0) > ($1759 | 0)) {
      var $1827 = $1759;
      __label__ = 314;
      break;
    } else {
      __label__ = 296;
      break;
    }
   case 296:
    var $1763 = HEAP32[$1 >> 2] + 20 | 0;
    var $1764 = HEAP32[$1763 >> 2];
    var $1765 = HEAP16[$1764 >> 1];
    var $1766 = __ZN3WTF12isASCIIDigitEt($1765);
    if ($1766) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 297;
      break;
    }
   case 297:
    var $1768 = $1764 + 2 | 0;
    HEAP32[$1763 >> 2] = $1768;
    var $i29_0 = $i29_0 + 1 | 0;
    var $1759 = HEAP32[$min >> 2];
    __label__ = 295;
    break;
   case 298:
    var $1770;
    var $i30_0;
    if (($i30_0 | 0) > ($1770 | 0)) {
      var $1827 = $1770;
      __label__ = 314;
      break;
    } else {
      __label__ = 299;
      break;
    }
   case 299:
    var $1774 = HEAP32[$1 >> 2] + 20 | 0;
    var $1775 = HEAP32[$1774 >> 2];
    var $1776 = HEAP16[$1775 >> 1];
    var $1777 = __ZN3WTF12isASCIIDigitEt($1776);
    if ($1777) {
      __label__ = 300;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 300:
    var $1779 = $1775 + 2 | 0;
    HEAP32[$1774 >> 2] = $1779;
    var $i30_0 = $i30_0 + 1 | 0;
    var $1770 = HEAP32[$min >> 2];
    __label__ = 298;
    break;
   case 301:
    var $1781;
    var $i31_0;
    if (($i31_0 | 0) > ($1781 | 0)) {
      var $1827 = $1781;
      __label__ = 314;
      break;
    } else {
      __label__ = 302;
      break;
    }
   case 302:
    var $1785 = HEAP32[$1 >> 2] + 20 | 0;
    var $1786 = HEAP32[$1785 >> 2];
    var $1787 = HEAP16[$1786 >> 1];
    var $1788 = __ZL11isSpaceChart($1787);
    if ($1788) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 303;
      break;
    }
   case 303:
    var $1790 = $1786 + 2 | 0;
    HEAP32[$1785 >> 2] = $1790;
    var $i31_0 = $i31_0 + 1 | 0;
    var $1781 = HEAP32[$min >> 2];
    __label__ = 301;
    break;
   case 304:
    var $1792;
    var $i32_0;
    if (($i32_0 | 0) > ($1792 | 0)) {
      var $1827 = $1792;
      __label__ = 314;
      break;
    } else {
      __label__ = 305;
      break;
    }
   case 305:
    var $1796 = HEAP32[$1 >> 2] + 20 | 0;
    var $1797 = HEAP32[$1796 >> 2];
    var $1798 = HEAP16[$1797 >> 1];
    var $1799 = __ZL11isSpaceChart($1798);
    if ($1799) {
      __label__ = 306;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 306:
    var $1801 = $1797 + 2 | 0;
    HEAP32[$1796 >> 2] = $1801;
    var $i32_0 = $i32_0 + 1 | 0;
    var $1792 = HEAP32[$min >> 2];
    __label__ = 304;
    break;
   case 307:
    var $1803;
    var $i33_0;
    if (($i33_0 | 0) > ($1803 | 0)) {
      var $1827 = $1803;
      __label__ = 314;
      break;
    } else {
      __label__ = 308;
      break;
    }
   case 308:
    var $1807 = HEAP32[$1 >> 2] + 20 | 0;
    var $1808 = HEAP32[$1807 >> 2];
    var $1809 = HEAP16[$1808 >> 1];
    var $1810 = __ZL10isWordChart($1809);
    if ($1810) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 309;
      break;
    }
   case 309:
    var $1812 = $1808 + 2 | 0;
    HEAP32[$1807 >> 2] = $1812;
    var $i33_0 = $i33_0 + 1 | 0;
    var $1803 = HEAP32[$min >> 2];
    __label__ = 307;
    break;
   case 310:
    var $1814;
    var $i34_0;
    if (($i34_0 | 0) > ($1814 | 0)) {
      var $1827 = $1814;
      __label__ = 314;
      break;
    } else {
      __label__ = 311;
      break;
    }
   case 311:
    var $1818 = HEAP32[$1 >> 2] + 20 | 0;
    var $1819 = HEAP32[$1818 >> 2];
    var $1820 = HEAP16[$1819 >> 1];
    var $1821 = __ZL10isWordChart($1820);
    if ($1821) {
      __label__ = 312;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 312:
    var $1823 = $1819 + 2 | 0;
    HEAP32[$1818 >> 2] = $1823;
    var $i34_0 = $i34_0 + 1 | 0;
    var $1814 = HEAP32[$min >> 2];
    __label__ = 310;
    break;
   case 313:
    var $1826 = __ZL10matchErroriR10MatchStack(-4, $stack);
    var $_0 = $1826;
    __label__ = 410;
    break;
   case 314:
    var $1827;
    var $1828 = HEAPU32[$1 >> 2];
    if (($1827 | 0) == (HEAP32[$1828 + 76 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 315;
      break;
    }
   case 315:
    if ((HEAP8[$minimize] & 1) << 24 >> 24 == 0) {
      __label__ = 330;
      break;
    } else {
      __label__ = 316;
      break;
    }
   case 316:
    HEAP32[$1828 + 68 >> 2] = $1827;
    __label__ = 317;
    break;
   case 317:
    var $1839 = HEAP32[$1 >> 2];
    var $1841 = HEAP32[$1839 + 24 >> 2];
    var $1843 = HEAP32[$1839 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $1841, $1843, 48);
    __label__ = 7;
    break;
   case 318:
    var $1845 = HEAP32[$1 >> 2];
    if ((HEAP32[$1845 + 68 >> 2] | 0) < (HEAP32[$1845 + 76 >> 2] | 0)) {
      __label__ = 319;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 319:
    var $1852 = $1845 + 20 | 0;
    var $1853 = HEAPU32[$1852 >> 2];
    if ($1853 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 320;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 320:
    var $1857 = $1853 + 2 | 0;
    HEAP32[$1852 >> 2] = $1857;
    var $1858 = HEAPU16[$1853 >> 1];
    var $1859 = $1858 & 65535;
    var $1860 = HEAPU32[$1 >> 2];
    var $1862 = HEAP32[$1860 + 60 >> 2];
    if (($1862 | 0) == 9) {
      __label__ = 321;
      break;
    } else if (($1862 | 0) == 3) {
      __label__ = 322;
      break;
    } else if (($1862 | 0) == 4) {
      __label__ = 323;
      break;
    } else if (($1862 | 0) == 5) {
      __label__ = 324;
      break;
    } else if (($1862 | 0) == 6) {
      __label__ = 325;
      break;
    } else if (($1862 | 0) == 7) {
      __label__ = 326;
      break;
    } else if (($1862 | 0) == 8) {
      __label__ = 327;
      break;
    } else {
      __label__ = 328;
      break;
    }
   case 321:
    var $1864 = __ZL9isNewlinet($1858);
    if ($1864) {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    } else {
      __label__ = 329;
      break;
    }
   case 322:
    var $1866 = __ZN3WTF12isASCIIDigitEi($1859);
    if ($1866) {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    } else {
      __label__ = 329;
      break;
    }
   case 323:
    var $1868 = __ZN3WTF12isASCIIDigitEi($1859);
    if ($1868) {
      __label__ = 329;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 324:
    var $1870 = __ZL11isSpaceChart($1858);
    if ($1870) {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    } else {
      __label__ = 329;
      break;
    }
   case 325:
    var $1872 = __ZL11isSpaceChart($1858);
    if ($1872) {
      __label__ = 329;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 326:
    var $1874 = __ZL10isWordChart($1858);
    if ($1874) {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    } else {
      __label__ = 329;
      break;
    }
   case 327:
    var $1876 = __ZL10isWordChart($1858);
    if ($1876) {
      __label__ = 329;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 328:
    var $1878 = __ZL10matchErroriR10MatchStack(-4, $stack);
    var $_0 = $1878;
    __label__ = 410;
    break;
   case 329:
    var $1880 = $1860 + 68 | 0;
    var $1882 = HEAP32[$1880 >> 2] + 1 | 0;
    HEAP32[$1880 >> 2] = $1882;
    __label__ = 317;
    break;
   case 330:
    var $1885 = HEAP32[$1828 + 20 >> 2];
    HEAP32[$1828 + 44 >> 2] = $1885;
    var $1887 = HEAPU32[$1 >> 2];
    var $1889 = HEAP32[$1887 + 60 >> 2];
    if (($1889 | 0) == 9) {
      __label__ = 331;
      break;
    } else if (($1889 | 0) == 3) {
      __label__ = 336;
      break;
    } else if (($1889 | 0) == 4) {
      __label__ = 341;
      break;
    } else if (($1889 | 0) == 5) {
      __label__ = 346;
      break;
    } else if (($1889 | 0) == 6) {
      __label__ = 351;
      break;
    } else if (($1889 | 0) == 7) {
      __label__ = 356;
      break;
    } else if (($1889 | 0) == 8) {
      __label__ = 361;
      break;
    } else {
      __label__ = 366;
      break;
    }
   case 331:
    var $i36_0 = HEAP32[$min >> 2];
    var $1893 = $1887;
    __label__ = 332;
    break;
   case 332:
    var $1893;
    var $i36_0;
    if (($i36_0 | 0) < (HEAP32[$1893 + 76 >> 2] | 0)) {
      __label__ = 333;
      break;
    } else {
      var $2020 = $1893;
      __label__ = 367;
      break;
    }
   case 333:
    var $1898 = $1893 + 20 | 0;
    var $1899 = HEAPU32[$1898 >> 2];
    if ($1899 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 334;
      break;
    } else {
      var $2020 = $1893;
      __label__ = 367;
      break;
    }
   case 334:
    var $1903 = HEAP16[$1899 >> 1];
    var $1904 = __ZL9isNewlinet($1903);
    if ($1904) {
      var $2020 = $1893;
      __label__ = 367;
      break;
    } else {
      __label__ = 335;
      break;
    }
   case 335:
    HEAP32[$1898 >> 2] = $1899 + 2 | 0;
    var $i36_0 = $i36_0 + 1 | 0;
    var $1893 = HEAP32[$1 >> 2];
    __label__ = 332;
    break;
   case 336:
    var $i37_0 = HEAP32[$min >> 2];
    var $1911 = $1887;
    __label__ = 337;
    break;
   case 337:
    var $1911;
    var $i37_0;
    if (($i37_0 | 0) < (HEAP32[$1911 + 76 >> 2] | 0)) {
      __label__ = 338;
      break;
    } else {
      var $2020 = $1911;
      __label__ = 367;
      break;
    }
   case 338:
    var $1916 = $1911 + 20 | 0;
    var $1917 = HEAPU32[$1916 >> 2];
    if ($1917 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 339;
      break;
    } else {
      var $2020 = $1911;
      __label__ = 367;
      break;
    }
   case 339:
    var $1922 = HEAPU16[$1917 >> 1] & 65535;
    var $1923 = __ZN3WTF12isASCIIDigitEi($1922);
    if ($1923) {
      var $2020 = $1911;
      __label__ = 367;
      break;
    } else {
      __label__ = 340;
      break;
    }
   case 340:
    HEAP32[$1916 >> 2] = $1917 + 2 | 0;
    var $i37_0 = $i37_0 + 1 | 0;
    var $1911 = HEAP32[$1 >> 2];
    __label__ = 337;
    break;
   case 341:
    var $i39_0 = HEAP32[$min >> 2];
    var $1930 = $1887;
    __label__ = 342;
    break;
   case 342:
    var $1930;
    var $i39_0;
    if (($i39_0 | 0) < (HEAP32[$1930 + 76 >> 2] | 0)) {
      __label__ = 343;
      break;
    } else {
      var $2020 = $1930;
      __label__ = 367;
      break;
    }
   case 343:
    var $1935 = $1930 + 20 | 0;
    var $1936 = HEAPU32[$1935 >> 2];
    if ($1936 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 344;
      break;
    } else {
      var $2020 = $1930;
      __label__ = 367;
      break;
    }
   case 344:
    var $1941 = HEAPU16[$1936 >> 1] & 65535;
    var $1942 = __ZN3WTF12isASCIIDigitEi($1941);
    if ($1942) {
      __label__ = 345;
      break;
    } else {
      var $2020 = $1930;
      __label__ = 367;
      break;
    }
   case 345:
    HEAP32[$1935 >> 2] = $1936 + 2 | 0;
    var $i39_0 = $i39_0 + 1 | 0;
    var $1930 = HEAP32[$1 >> 2];
    __label__ = 342;
    break;
   case 346:
    var $i41_0 = HEAP32[$min >> 2];
    var $1949 = $1887;
    __label__ = 347;
    break;
   case 347:
    var $1949;
    var $i41_0;
    if (($i41_0 | 0) < (HEAP32[$1949 + 76 >> 2] | 0)) {
      __label__ = 348;
      break;
    } else {
      var $2020 = $1949;
      __label__ = 367;
      break;
    }
   case 348:
    var $1954 = $1949 + 20 | 0;
    var $1955 = HEAPU32[$1954 >> 2];
    if ($1955 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 349;
      break;
    } else {
      var $2020 = $1949;
      __label__ = 367;
      break;
    }
   case 349:
    var $1959 = HEAP16[$1955 >> 1];
    var $1960 = __ZL11isSpaceChart($1959);
    if ($1960) {
      var $2020 = $1949;
      __label__ = 367;
      break;
    } else {
      __label__ = 350;
      break;
    }
   case 350:
    HEAP32[$1954 >> 2] = $1955 + 2 | 0;
    var $i41_0 = $i41_0 + 1 | 0;
    var $1949 = HEAP32[$1 >> 2];
    __label__ = 347;
    break;
   case 351:
    var $i43_0 = HEAP32[$min >> 2];
    var $1967 = $1887;
    __label__ = 352;
    break;
   case 352:
    var $1967;
    var $i43_0;
    if (($i43_0 | 0) < (HEAP32[$1967 + 76 >> 2] | 0)) {
      __label__ = 353;
      break;
    } else {
      var $2020 = $1967;
      __label__ = 367;
      break;
    }
   case 353:
    var $1972 = $1967 + 20 | 0;
    var $1973 = HEAPU32[$1972 >> 2];
    if ($1973 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 354;
      break;
    } else {
      var $2020 = $1967;
      __label__ = 367;
      break;
    }
   case 354:
    var $1977 = HEAP16[$1973 >> 1];
    var $1978 = __ZL11isSpaceChart($1977);
    if ($1978) {
      __label__ = 355;
      break;
    } else {
      var $2020 = $1967;
      __label__ = 367;
      break;
    }
   case 355:
    HEAP32[$1972 >> 2] = $1973 + 2 | 0;
    var $i43_0 = $i43_0 + 1 | 0;
    var $1967 = HEAP32[$1 >> 2];
    __label__ = 352;
    break;
   case 356:
    var $i45_0 = HEAP32[$min >> 2];
    var $1985 = $1887;
    __label__ = 357;
    break;
   case 357:
    var $1985;
    var $i45_0;
    if (($i45_0 | 0) < (HEAP32[$1985 + 76 >> 2] | 0)) {
      __label__ = 358;
      break;
    } else {
      var $2020 = $1985;
      __label__ = 367;
      break;
    }
   case 358:
    var $1990 = $1985 + 20 | 0;
    var $1991 = HEAPU32[$1990 >> 2];
    if ($1991 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 359;
      break;
    } else {
      var $2020 = $1985;
      __label__ = 367;
      break;
    }
   case 359:
    var $1995 = HEAP16[$1991 >> 1];
    var $1996 = __ZL10isWordChart($1995);
    if ($1996) {
      var $2020 = $1985;
      __label__ = 367;
      break;
    } else {
      __label__ = 360;
      break;
    }
   case 360:
    HEAP32[$1990 >> 2] = $1991 + 2 | 0;
    var $i45_0 = $i45_0 + 1 | 0;
    var $1985 = HEAP32[$1 >> 2];
    __label__ = 357;
    break;
   case 361:
    var $i47_0 = HEAP32[$min >> 2];
    var $2003 = $1887;
    __label__ = 362;
    break;
   case 362:
    var $2003;
    var $i47_0;
    if (($i47_0 | 0) < (HEAP32[$2003 + 76 >> 2] | 0)) {
      __label__ = 363;
      break;
    } else {
      var $2020 = $2003;
      __label__ = 367;
      break;
    }
   case 363:
    var $2008 = $2003 + 20 | 0;
    var $2009 = HEAPU32[$2008 >> 2];
    if ($2009 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 364;
      break;
    } else {
      var $2020 = $2003;
      __label__ = 367;
      break;
    }
   case 364:
    var $2013 = HEAP16[$2009 >> 1];
    var $2014 = __ZL10isWordChart($2013);
    if ($2014) {
      __label__ = 365;
      break;
    } else {
      var $2020 = $2003;
      __label__ = 367;
      break;
    }
   case 365:
    HEAP32[$2008 >> 2] = $2009 + 2 | 0;
    var $i47_0 = $i47_0 + 1 | 0;
    var $2003 = HEAP32[$1 >> 2];
    __label__ = 362;
    break;
   case 366:
    var $2019 = __ZL10matchErroriR10MatchStack(-4, $stack);
    var $_0 = $2019;
    __label__ = 410;
    break;
   case 367:
    var $2020;
    var $2022 = HEAP32[$2020 + 24 >> 2];
    var $2024 = HEAP32[$2020 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $2022, $2024, 52);
    __label__ = 7;
    break;
   case 368:
    var $2027 = HEAP32[$1 >> 2] + 20 | 0;
    var $2028 = HEAP32[$2027 >> 2];
    var $2029 = $2028 - 2 | 0;
    HEAP32[$2027 >> 2] = $2029;
    var $2030 = HEAP32[$1 >> 2];
    if (($2028 | 0) == (HEAP32[$2030 + 44 >> 2] | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      var $2020 = $2030;
      __label__ = 367;
      break;
    }
   case 369:
    var $2035 = __ZL10matchErroriR10MatchStack(-4, $stack);
    var $_0 = $2035;
    __label__ = 410;
    break;
   case 370:
    HEAP32[$26 + 80 >> 2] = $31 - 67 | 0;
    var $2039 = HEAP32[$1 >> 2];
    var $2041 = HEAP32[$2039 + 24 >> 2];
    __ZN10MatchFrame15extractBracketsEPKh($2039, $2041);
    var $2042 = HEAP32[$1 >> 2];
    var $2043 = $2042 + 80 | 0;
    var $2044 = HEAP32[$2043 >> 2];
    if (($2044 | 0) > 100) {
      __label__ = 371;
      break;
    } else {
      var $2053 = $2042;
      var $2052 = $2044;
      __label__ = 372;
      break;
    }
   case 371:
    var $2048 = HEAP32[$2042 + 24 >> 2];
    var $_val = HEAP8[$2048 + 7 | 0];
    var $_idx_val = HEAP8[$2048 + 8 | 0];
    var $2050 = __ZL13get2ByteValuePKh4462($_val, $_idx_val);
    HEAP32[$2043 >> 2] = $2050;
    var $_pre = HEAP32[$1 >> 2];
    var $2053 = $_pre;
    var $2052 = HEAP32[$_pre + 80 >> 2];
    __label__ = 372;
    break;
   case 372:
    var $2052;
    var $2053;
    HEAP32[$2053 + 84 >> 2] = $2052 << 1;
    var $2056 = HEAPU32[$1 >> 2];
    if ((HEAP32[$2056 + 84 >> 2] | 0) < (HEAP32[$15 >> 2] | 0)) {
      __label__ = 374;
      break;
    } else {
      __label__ = 373;
      break;
    }
   case 373:
    var $33 = $2056;
    var $32 = HEAP32[$2056 + 24 >> 2];
    __label__ = 5;
    break;
   case 374:
    var $2068 = HEAP32[HEAP32[$17 >> 2] + (HEAP32[$16 >> 2] - HEAP32[$2056 + 80 >> 2] << 2) >> 2];
    HEAP32[$2056 + 56 >> 2] = $2068;
    var $2070 = HEAP32[$1 >> 2];
    var $2077 = HEAP32[$2070 + 20 >> 2] - HEAP32[$18 >> 2] >> 1;
    var $2083 = HEAP32[$17 >> 2] + (HEAP32[$16 >> 2] - HEAP32[$2070 + 80 >> 2] << 2) | 0;
    HEAP32[$2083 >> 2] = $2077;
    var $2085 = HEAP32[$1 >> 2] + 88 | 0;
    HEAP32[$2085 >> 2] = 3;
    var $2086 = __ZN10LinearFlag12readAndClearEv($minSatNextBracket);
    HEAP8[HEAP32[$1 >> 2] + 104 | 0] = $2086 & 1;
    var $_pre85 = HEAPU32[$1 >> 2];
    var $2091 = $_pre85;
    var $2090 = HEAP32[$_pre85 + 24 >> 2];
    __label__ = 375;
    break;
   case 375:
    var $2090;
    var $2091;
    var $2095 = (HEAP8[$2091 + 104 | 0] & 1) << 24 >> 24 != 0;
    var $2098 = $2090 + (HEAP32[$2091 + 88 >> 2] + 3) | 0;
    var $2100 = HEAP32[$2091 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $2098, $2100, 1);
    var $2101 = HEAP32[$1 >> 2];
    __ZN10MatchFrame13startNewGroupEb($2101, $2095);
    __label__ = 7;
    break;
   case 376:
    var $2104 = HEAP32[$1 >> 2] + 88 | 0;
    HEAP32[$2104 >> 2] = 1;
    var $2106 = HEAP32[$1 >> 2] + 24 | 0;
    var $2107 = HEAP32[$2106 >> 2];
    var $_val33 = HEAP8[$2107 + 1 | 0];
    var $_idx34_val = HEAP8[$2107 + 2 | 0];
    var $_idx35_val = HEAP8[$2107 + 3 | 0];
    var $2109 = __ZL12getLinkValuePKh4461($_val33, $_idx34_val, $_idx35_val);
    var $2110 = $2107 + $2109 | 0;
    HEAP32[$2106 >> 2] = $2110;
    var $2111 = HEAPU32[$1 >> 2];
    var $2113 = HEAPU32[$2111 + 24 >> 2];
    if (HEAP8[$2113] << 24 >> 24 == 58) {
      var $2091 = $2111;
      var $2090 = $2113;
      __label__ = 375;
      break;
    } else {
      __label__ = 377;
      break;
    }
   case 377:
    var $2118 = HEAPU32[$2111 + 92 >> 2];
    if ($2118 >>> 0 < HEAPU32[$2111 + 96 >> 2] >>> 0) {
      var $i49_084 = $2118;
      __label__ = 378;
      break;
    } else {
      var $_lcssa83 = $2111;
      __label__ = 379;
      break;
    }
   case 378:
    var $i49_084;
    __ZN9MatchData13setOffsetPairEjii($md, $i49_084, -1, -1);
    var $2122 = $i49_084 + 1 | 0;
    var $2123 = HEAPU32[$1 >> 2];
    if ($2122 >>> 0 < HEAPU32[$2123 + 96 >> 2] >>> 0) {
      var $i49_084 = $2122;
      __label__ = 378;
      break;
    } else {
      var $_lcssa83 = $2123;
      __label__ = 379;
      break;
    }
   case 379:
    var $_lcssa83;
    var $2128 = HEAP32[$_lcssa83 + 56 >> 2];
    var $2134 = HEAP32[$17 >> 2] + (HEAP32[$16 >> 2] - HEAP32[$_lcssa83 + 80 >> 2] << 2) | 0;
    HEAP32[$2134 >> 2] = $2128;
    var $isMatch_0 = $isMatch_0;
    __label__ = 380;
    break;
   case 380:
    var $isMatch_0;
    var $2137 = HEAP32[HEAP32[$1 >> 2] >> 2];
    if (($2137 | 0) == 1) {
      __label__ = 381;
      break;
    } else if (($2137 | 0) == 2) {
      __label__ = 382;
      break;
    } else if (($2137 | 0) == 6) {
      __label__ = 383;
      break;
    } else if (($2137 | 0) == 7) {
      __label__ = 385;
      break;
    } else if (($2137 | 0) == 14) {
      __label__ = 386;
      break;
    } else if (($2137 | 0) == 15) {
      __label__ = 387;
      break;
    } else if (($2137 | 0) == 16) {
      __label__ = 388;
      break;
    } else if (($2137 | 0) == 17) {
      __label__ = 389;
      break;
    } else if (($2137 | 0) == 18) {
      __label__ = 390;
      break;
    } else if (($2137 | 0) == 19) {
      __label__ = 391;
      break;
    } else if (($2137 | 0) == 20) {
      __label__ = 392;
      break;
    } else if (($2137 | 0) == 21) {
      __label__ = 393;
      break;
    } else if (($2137 | 0) == 22) {
      __label__ = 394;
      break;
    } else if (($2137 | 0) == 24) {
      __label__ = 395;
      break;
    } else if (($2137 | 0) == 26) {
      __label__ = 396;
      break;
    } else if (($2137 | 0) == 27) {
      __label__ = 397;
      break;
    } else if (($2137 | 0) == 28) {
      __label__ = 398;
      break;
    } else if (($2137 | 0) == 29) {
      __label__ = 399;
      break;
    } else if (($2137 | 0) == 30) {
      __label__ = 400;
      break;
    } else if (($2137 | 0) == 31) {
      __label__ = 401;
      break;
    } else if (($2137 | 0) == 38) {
      __label__ = 402;
      break;
    } else if (($2137 | 0) == 40) {
      __label__ = 403;
      break;
    } else if (($2137 | 0) == 42) {
      __label__ = 404;
      break;
    } else if (($2137 | 0) == 44) {
      __label__ = 405;
      break;
    } else if (($2137 | 0) == 48) {
      __label__ = 406;
      break;
    } else if (($2137 | 0) == 52) {
      __label__ = 407;
      break;
    } else if (($2137 | 0) == 0) {
      __label__ = 409;
      break;
    } else {
      __label__ = 408;
      break;
    }
   case 381:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 376;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 382:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 8;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 383:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    var $2144 = HEAPU32[$1 >> 2];
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 384;
      break;
    }
   case 384:
    var $116 = $2144;
    var $115 = HEAP8[HEAP32[$2144 + 24 >> 2]];
    __label__ = 16;
    break;
   case 385:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 22;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 386:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 26;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 387:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 28;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 388:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 46;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 389:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    var $isMatch_0 = $isMatch_0;
    __label__ = 380;
    break;
   case 390:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 48;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 391:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    var $isMatch_0 = $isMatch_0;
    __label__ = 380;
    break;
   case 392:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 106;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 393:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 115;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 394:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 133;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 395:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 147;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 396:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 162;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 397:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 172;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 398:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 199;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 399:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 211;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 400:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 219;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 401:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 230;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 402:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 253;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 403:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 267;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 404:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 275;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 405:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 285;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 406:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 318;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 407:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 368;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 408:
    var $2190 = __ZL10matchErroriR10MatchStack(-4, $stack);
    var $_0 = $2190;
    __label__ = 410;
    break;
   case 409:
    var $_0 = $isMatch_0 & 255;
    __label__ = 410;
    break;
   case 410:
    var $_0;
    var $stack_idx_val = HEAP32[$stack >> 2];
    var $stack_idx51_val = HEAP32[$stack + 4 >> 2];
    __ZN10MatchStackD1Ev($stack_idx_val, $stack_idx51_val);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL5matchP11JSArenaPoolPKtPKhiR9MatchData["X"] = 1;

function __ZL9isNewlinet($nl) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($nl << 16 >> 16 == 10 || $nl << 16 >> 16 == 13 || $nl << 16 >> 16 == 8232 || $nl << 16 >> 16 == 8233) {
      var $2 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $2 = 0;
    __label__ = 3;
    break;
   case 3:
    var $2;
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13get2ByteValuePKh4462($opcodePtr_val, $opcodePtr_1_val) {
  return ($opcodePtr_val & 255) << 8 | $opcodePtr_1_val & 255;
}

function __ZN3WTF12isASCIIDigitEi($c) {
  return ($c - 48 | 0) >>> 0 < 10;
}

function __ZL13get3ByteValuePKh4465($opcodePtr_val, $opcodePtr_1_val, $opcodePtr_2_val) {
  return $opcodePtr_2_val & 255 | ($opcodePtr_val & 255) << 16 | ($opcodePtr_1_val & 255) << 8;
}

function __ZN10MatchStack29canUseStackBufferForNextFrameEv($this_0_5_val) {
  return $this_0_5_val >>> 0 < 16;
}

function __ZN10MatchFrame13startNewGroupEb($this, $minSatisfied) {
  var $1 = $this + 32 | 0;
  var $2 = HEAP32[$1 >> 2];
  var $3 = $this + 108 | 0;
  HEAP32[$3 >> 2] = $2;
  var $6 = HEAP32[$this + 20 >> 2];
  HEAP32[$this + 112 >> 2] = $6;
  HEAP8[$this + 116 | 0] = $minSatisfied & 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN10LinearFlag12readAndClearEv($this) {
  var $1 = $this | 0;
  var $4 = (HEAP8[$1] & 1) << 24 >> 24 != 0;
  HEAP8[$1] = 0;
  return $4;
}

function __ZN9MatchData13setOffsetPairEjii($this, $pairNum, $start, $end) {
  var $1 = $pairNum << 1;
  var $2 = $this | 0;
  var $4 = HEAP32[$2 >> 2] + ($1 << 2) | 0;
  HEAP32[$4 >> 2] = $start;
  var $7 = HEAP32[$2 >> 2] + (($1 | 1) << 2) | 0;
  HEAP32[$7 >> 2] = $end;
  return;
}

function __ZN10LinearFlag3setEv($this) {
  HEAP8[$this | 0] = 1;
  return;
}

function __ZN10MatchFrame14restoreOffsetsEiiPii($this, $minBracket, $limitBracket, $offsets, $offsetEnd) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $limitBracket - $minBracket | 0;
    if (($1 | 0) > 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $this + 8 | 0;
    var $i_01 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_01;
    var $5 = $i_01 + $minBracket | 0;
    var $6 = $i_01 * 3 | 0;
    var $7 = HEAP32[$3 >> 2];
    var $9 = HEAP32[$7 + ($6 << 2) >> 2];
    var $12 = HEAP32[$7 + ($6 + 1 << 2) >> 2];
    var $15 = HEAP32[$7 + ($6 + 2 << 2) >> 2];
    var $16 = $5 << 1;
    HEAP32[$offsets + ($16 << 2) >> 2] = $9;
    HEAP32[$offsets + (($16 | 1) << 2) >> 2] = $12;
    HEAP32[$offsets + ($offsetEnd - $5 << 2) >> 2] = $15;
    var $22 = $i_01 + 1 | 0;
    if (($22 | 0) == ($1 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $i_01 = $22;
      __label__ = 3;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10MatchFrame14clobberOffsetsEiiPii($minBracket, $limitBracket, $offsets) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $limitBracket - $minBracket | 0;
    if (($1 | 0) > 0) {
      var $i_01 = 0;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $i_01;
    var $4 = $i_01 + $minBracket << 1;
    HEAP32[$offsets + ($4 << 2) >> 2] = -1;
    HEAP32[$offsets + (($4 | 1) << 2) >> 2] = -1;
    var $8 = $i_01 + 1 | 0;
    if (($8 | 0) == ($1 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $i_01 = $8;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL38repeatInformationFromInstructionOffsetsRbRiS0_($instructionOffset, $minimize, $minimumRepeats, $maximumRepeats) {
  var $1 = $instructionOffset << 16 >> 16;
  HEAP8[$minimize] = $instructionOffset & 255 & 1;
  var $3 = STRING_TABLE.__ZZL38repeatInformationFromInstructionOffsetsRbRiS0_E35minimumRepeatsFromInstructionOffset + $1 | 0;
  HEAP32[$minimumRepeats >> 2] = HEAP8[$3] << 24 >> 24;
  var $7 = HEAP32[__ZZL38repeatInformationFromInstructionOffsetsRbRiS0_E35maximumRepeatsFromInstructionOffset + ($1 << 2) >> 2];
  HEAP32[$maximumRepeats >> 2] = $7;
  return;
}

function __ZL29getUTF8CharAndIncrementLengthRiPKhS_($c, $subjectPtr, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU8[$subjectPtr] & 255;
    HEAP32[$c >> 2] = $2;
    if (($2 & 192 | 0) == 192) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $6 = STRING_TABLE._jsc_pcre_utf8_table4 + ($2 & 63) | 0;
    var $8 = HEAPU8[$6] & 255;
    var $9 = $8 * 6 | 0;
    var $13 = (HEAP32[_jsc_pcre_utf8_table3 + ($8 << 2) >> 2] & $2) << $9;
    HEAP32[$c >> 2] = $13;
    var $gcss_01 = $9;
    var $gcii_02 = 1;
    var $15 = $13;
    __label__ = 3;
    break;
   case 3:
    var $15;
    var $gcii_02;
    var $gcss_01;
    var $16 = $gcss_01 - 6 | 0;
    var $22 = (HEAPU8[$subjectPtr + $gcii_02 | 0] & 255 & 63) << $16 | $15;
    HEAP32[$c >> 2] = $22;
    var $23 = $gcii_02 + 1 | 0;
    if (($23 | 0) > ($8 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $gcss_01 = $16;
      var $gcii_02 = $23;
      var $15 = $22;
      __label__ = 3;
      break;
    }
   case 4:
    var $26 = HEAP32[$len >> 2] + $8 | 0;
    HEAP32[$len >> 2] = $26;
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15charTypeForCharh($c) {
  var $2 = STRING_TABLE._jsc_pcre_default_tables + (($c & 255) + 352) | 0;
  return HEAP8[$2];
}

function __ZN10MatchFrame4initEP11JSArenaPool($this, $regExpPool) {
  HEAP32[$this + 16 >> 2] = $regExpPool;
  return;
}

function __ZN10MatchFrameC2Ev($this) {
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  return;
}

function __ZN10LinearFlagC2Ev($this) {
  HEAP8[$this | 0] = 0;
  return;
}

function __Z22jsc_pcre_ucp_othercasej($c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $bot_0_ph = 0;
    var $top_0_ph = 2963;
    __label__ = 2;
    break;
   case 2:
    var $top_0_ph;
    var $bot_0_ph;
    var $bot_0 = $bot_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $bot_0;
    if (($top_0_ph | 0) > ($bot_0 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $_0 = -1;
      __label__ = 11;
      break;
    }
   case 4:
    var $5 = $bot_0 + $top_0_ph >> 1;
    var $7 = HEAPU32[__ZL9ucp_table + ($5 << 3) >> 2];
    var $8 = $7 & 2097151;
    if (($8 | 0) == ($c | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ($8 >>> 0 > $c >>> 0) {
      var $bot_0_ph = $bot_0;
      var $top_0_ph = $5;
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($7 & 15728640 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (((HEAP32[__ZL9ucp_table + ($5 << 3) + 4 >> 2] & 65535) + $8 | 0) >>> 0 < $c >>> 0) {
      __label__ = 8;
      break;
    } else {
      var $_0 = -1;
      __label__ = 11;
      break;
    }
   case 8:
    var $bot_0 = $5 + 1 | 0;
    __label__ = 3;
    break;
   case 9:
    if (($7 & 15728640 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = -1;
      __label__ = 11;
      break;
    }
   case 10:
    var $26 = HEAP32[__ZL9ucp_table + ($5 << 3) + 4 >> 2];
    var $_ = ($26 & 32768 | 0) == 0 ? $26 & 65535 : $26 | -32768;
    var $33 = ($_ | 0) == 0 ? -1 : $_ + $c | 0;
    var $_0 = $33;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL28getUTF8CharAndAdvancePointerRiRPKh($c, $subjectPtr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$subjectPtr >> 2];
    var $2 = $1 + 1 | 0;
    HEAP32[$subjectPtr >> 2] = $2;
    var $4 = HEAPU8[$1] & 255;
    HEAP32[$c >> 2] = $4;
    if (($4 & 192 | 0) == 192) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = STRING_TABLE._jsc_pcre_utf8_table4 + ($4 & 63) | 0;
    var $10 = HEAPU8[$8] & 255;
    var $11 = $10 * 6 | 0;
    var $15 = (HEAP32[_jsc_pcre_utf8_table3 + ($10 << 2) >> 2] & $4) << $11;
    HEAP32[$c >> 2] = $15;
    var $gcaa_01 = $10;
    var $gcss_02 = $11;
    __label__ = 3;
    break;
   case 3:
    var $gcss_02;
    var $gcaa_01;
    var $17 = $gcaa_01 - 1 | 0;
    var $18 = $gcss_02 - 6 | 0;
    var $19 = HEAP32[$subjectPtr >> 2];
    var $20 = $19 + 1 | 0;
    HEAP32[$subjectPtr >> 2] = $20;
    var $26 = (HEAPU8[$19] & 255 & 63) << $18 | HEAP32[$c >> 2];
    HEAP32[$c >> 2] = $26;
    if (($17 | 0) > 0) {
      var $gcaa_01 = $17;
      var $gcss_02 = $18;
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10MatchStackC1EP11JSArenaPool($this, $regExpPool) {
  __ZN10MatchStackC2EP11JSArenaPool($this, $regExpPool);
  return;
}

function __ZN10LinearFlagC1Ev($this) {
  __ZN10LinearFlagC2Ev($this);
  return;
}

function __ZL10matchErroriR10MatchStack($errorCode, $stack) {
  __ZN10MatchStack12popAllFramesEv($stack);
  return $errorCode;
}

function __ZN10MatchFrame15extractBracketsEPKh($this, $instructionPtr) {
  var $_val = HEAP8[$instructionPtr + 4 | 0];
  var $_idx_val = HEAP8[$instructionPtr + 5 | 0];
  var $2 = __ZL13get2ByteValuePKh4462($_val, $_idx_val);
  HEAP32[$this + 92 >> 2] = $2 >>> 8 & 255;
  HEAP32[$this + 96 >> 2] = $2 & 255;
  return;
}

function __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($this, $instructionPtr, $bracketChain, $returnLocation) {
  var $1 = __ZN10MatchStack17allocateNextFrameEv($this);
  var $2 = $this + 1932 | 0;
  var $3 = HEAP32[$2 >> 2];
  HEAP32[$1 + 4 >> 2] = $3;
  var $7 = HEAP32[HEAP32[$2 >> 2] + 20 >> 2];
  HEAP32[$1 + 20 >> 2] = $7;
  var $11 = HEAP32[HEAP32[$2 >> 2] + 28 >> 2];
  HEAP32[$1 + 28 >> 2] = $11;
  HEAP32[$1 + 24 >> 2] = $instructionPtr;
  HEAP32[$1 + 32 >> 2] = $bracketChain;
  HEAP32[$1 >> 2] = $returnLocation;
  var $16 = $this + 1936 | 0;
  var $18 = HEAP32[$16 >> 2] + 1 | 0;
  HEAP32[$16 >> 2] = $18;
  HEAP32[$2 >> 2] = $1;
  return;
}

function __ZN10MatchStack15popCurrentFrameEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 1932 | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $4 = HEAP32[$2 + 4 >> 2];
    HEAP32[$1 >> 2] = $4;
    var $5 = $this + 1936 | 0;
    var $6 = HEAPU32[$5 >> 2];
    if ($6 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $10 = $6;
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js10Foreground7delete_I10MatchFrameEEvPT_($2);
    var $10 = HEAP32[$5 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $10;
    HEAP32[$5 >> 2] = $10 - 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12getLinkValuePKh4461($opcodePtr_val1, $opcodePtr_1_val, $opcodePtr_2_val) {
  var $1 = __ZL21getLinkValueAllowZeroPKh4464($opcodePtr_val1, $opcodePtr_1_val, $opcodePtr_2_val);
  return $1;
}

function __ZL21advanceToEndOfBracketRPKh4463($opcodePtr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$opcodePtr >> 2];
    __label__ = 2;
    break;
   case 2:
    var $2;
    var $_val = HEAP8[$2 + 1 | 0];
    var $_idx_val = HEAP8[$2 + 2 | 0];
    var $_idx1_val = HEAP8[$2 + 3 | 0];
    var $4 = __ZL12getLinkValuePKh4461($_val, $_idx_val, $_idx1_val);
    var $5 = $2 + $4 | 0;
    HEAP32[$opcodePtr >> 2] = $5;
    if (HEAP8[$5] << 24 >> 24 == 58) {
      var $2 = $5;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10MatchFrame11saveOffsetsEiiPii($this, $minBracket, $limitBracket, $offsets, $offsetEnd) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($minBracket | 0) == ($limitBracket | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $limitBracket - $minBracket | 0;
    var $4 = $3 * 12 | 0;
    var $5 = $this + 12 | 0;
    if (HEAPU32[$5 >> 2] >>> 0 < $4 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    var $10 = HEAPU32[$this + 16 >> 2];
    var $12 = HEAP32[$10 + 16 >> 2];
    var $14 = HEAP32[$10 + 24 >> 2];
    var $17 = $14 + $4 & ($14 ^ -1);
    var $18 = $12 + 12 | 0;
    var $19 = HEAPU32[$18 >> 2];
    var $21 = HEAPU32[$12 + 8 >> 2];
    if ($17 >>> 0 > $21 >>> 0 | $19 >>> 0 > ($21 - $17 | 0) >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $26 = _JS_ArenaAllocate($10, $17);
    var $_p_0 = $26;
    __label__ = 6;
    break;
   case 5:
    var $29 = $17 + $19 | 0;
    HEAP32[$18 >> 2] = $29;
    var $_p_0 = $19;
    __label__ = 6;
    break;
   case 6:
    var $_p_0;
    HEAP32[$this + 8 >> 2] = $_p_0;
    HEAP32[$5 >> 2] = $4;
    __label__ = 7;
    break;
   case 7:
    if (($limitBracket | 0) == ($minBracket | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $34 = $this + 8 | 0;
    var $i_02 = 0;
    __label__ = 9;
    break;
   case 9:
    var $i_02;
    var $35 = $i_02 + $minBracket | 0;
    var $36 = $35 << 1;
    var $38 = HEAP32[$offsets + ($36 << 2) >> 2];
    var $41 = HEAP32[$offsets + (($36 | 1) << 2) >> 2];
    var $44 = HEAP32[$offsets + ($offsetEnd - $35 << 2) >> 2];
    var $45 = $i_02 * 3 | 0;
    var $47 = HEAP32[$34 >> 2] + ($45 << 2) | 0;
    HEAP32[$47 >> 2] = $38;
    var $50 = HEAP32[$34 >> 2] + ($45 + 1 << 2) | 0;
    HEAP32[$50 >> 2] = $41;
    var $53 = HEAP32[$34 >> 2] + ($45 + 2 << 2) | 0;
    HEAP32[$53 >> 2] = $44;
    var $54 = $i_02 + 1 | 0;
    if ($54 >>> 0 < $3 >>> 0) {
      var $i_02 = $54;
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN10MatchFrame11saveOffsetsEiiPii["X"] = 1;

function __ZL10isWordChart($c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($c & 65535) < 128) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $c & 255;
    var $4 = __ZL15charTypeForCharh($3);
    var $8 = ($4 & 16) << 24 >> 24 != 0;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11isSpaceChart($c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($c & 65535) < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $c & 255;
    var $4 = __ZL15charTypeForCharh($3);
    if (($4 & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      var $10 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = $c << 16 >> 16 == 160;
    __label__ = 4;
    break;
   case 4:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8matchRefiPKtiRK9MatchData($offset, $subjectPtr, $length, $md) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $7 = HEAP32[$md + 16 >> 2] + (HEAP32[HEAP32[$md >> 2] + ($offset << 2) >> 2] << 1) | 0;
    if ((HEAP32[$md + 20 >> 2] - $subjectPtr >> 1 | 0) < ($length | 0)) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP8[$md + 33 | 0] & 1) << 24 >> 24 == 0) {
      var $p_1 = $7;
      var $_1 = $subjectPtr;
      var $_13 = $length;
      __label__ = 5;
      break;
    } else {
      var $p_0 = $7;
      var $_01 = $subjectPtr;
      var $_02 = $length;
      __label__ = 3;
      break;
    }
   case 3:
    var $_02;
    var $_01;
    var $p_0;
    if (($_02 | 0) > 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 4:
    var $22 = $_02 - 1 | 0;
    var $23 = $p_0 + 2 | 0;
    var $24 = HEAPU16[$p_0 >> 1];
    var $25 = $24 & 65535;
    var $26 = __Z22jsc_pcre_ucp_othercasej($25);
    var $28 = HEAPU16[$_01 >> 1];
    if ($24 << 16 >> 16 == $28 << 16 >> 16 | ($26 | 0) == ($28 & 65535 | 0)) {
      var $p_0 = $23;
      var $_01 = $_01 + 2 | 0;
      var $_02 = $22;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $_13;
    var $_1;
    var $p_1;
    if (($_13 | 0) > 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 6:
    if (HEAP16[$p_1 >> 1] << 16 >> 16 == HEAP16[$_1 >> 1] << 16 >> 16) {
      var $p_1 = $p_1 + 2 | 0;
      var $_1 = $_1 + 2 | 0;
      var $_13 = $_13 - 1 | 0;
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL8matchRefiPKtiRK9MatchData["X"] = 1;

function __ZN10MatchStackD1Ev($this_0_0_val, $this_0_1_val) {
  __ZN10MatchStackD2Ev($this_0_0_val, $this_0_1_val);
  return;
}

function __ZN10MatchStackD2Ev($this_0_0_val, $this_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this_0_0_val + 16 >> 2];
    if (($2 | 0) == ($this_0_0_val | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $this_0_1_val;
    var $8 = HEAP32[$2 + 4 >> 2];
    var $10 = $2 + 12 | 0;
    if (($6 - $8 | 0) >>> 0 > (HEAP32[$10 >> 2] - $8 | 0) >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = HEAP32[$this_0_0_val + 24 >> 2];
    var $19 = $16 + $6 & ($16 ^ -1);
    HEAP32[$10 >> 2] = $19;
    __label__ = 5;
    break;
   case 4:
    _JS_ArenaRelease($this_0_0_val, $this_0_1_val);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21getLinkValueAllowZeroPKh4464($opcodePtr_val1, $opcodePtr_1_val, $opcodePtr_2_val) {
  var $1 = __ZL13get3ByteValuePKh4465($opcodePtr_val1, $opcodePtr_1_val, $opcodePtr_2_val);
  return $1;
}

function __ZN2js10Foreground7delete_I10MatchFrameEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $p;
    _js_free4466($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_free4466($p) {
  _free($p);
  return;
}

function __ZN10MatchStack17allocateNextFrameEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this + 1936 >> 2];
    var $1 = __ZN10MatchStack29canUseStackBufferForNextFrameEv($this_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = HEAP32[$this + 1932 >> 2] + 120 | 0;
    __label__ = 4;
    break;
   case 3:
    var $7 = __ZN2js11OffTheBooks4new_I10MatchFrameEEPT_v();
    var $9 = HEAP32[$this >> 2];
    __ZN10MatchFrame4initEP11JSArenaPool($7, $9);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11OffTheBooks4new_I10MatchFrameEEPT_v() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_malloc4467();
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN10MatchFrameC1Ev($4);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_malloc4467() {
  var $1 = _malloc(120);
  return $1;
}

function __ZN10MatchFrameC1Ev($this) {
  __ZN10MatchFrameC2Ev($this);
  return;
}

function __ZN10MatchStack12popAllFramesEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 1936 | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN10MatchStack15popCurrentFrameEv($this);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10MatchStackC2EP11JSArenaPool($this, $regExpPool) {
  HEAP32[$this >> 2] = $regExpPool;
  var $7 = HEAP32[HEAP32[$regExpPool + 16 >> 2] + 12 >> 2];
  HEAP32[$this + 4 >> 2] = $7;
  var $8 = $this + 8 | 0;
  var $9 = $this + 1928 | 0;
  __ZN10MatchFrameC1Ev($8);
  var $10 = $this + 128 | 0;
  __ZN10MatchFrameC1Ev($10);
  var $11 = $this + 248 | 0;
  __ZN10MatchFrameC1Ev($11);
  var $12 = $this + 368 | 0;
  __ZN10MatchFrameC1Ev($12);
  var $13 = $this + 488 | 0;
  __ZN10MatchFrameC1Ev($13);
  var $14 = $this + 608 | 0;
  __ZN10MatchFrameC1Ev($14);
  var $15 = $this + 728 | 0;
  __ZN10MatchFrameC1Ev($15);
  var $16 = $this + 848 | 0;
  __ZN10MatchFrameC1Ev($16);
  var $17 = $this + 968 | 0;
  __ZN10MatchFrameC1Ev($17);
  var $18 = $this + 1088 | 0;
  __ZN10MatchFrameC1Ev($18);
  var $19 = $this + 1208 | 0;
  __ZN10MatchFrameC1Ev($19);
  var $20 = $this + 1328 | 0;
  __ZN10MatchFrameC1Ev($20);
  var $21 = $this + 1448 | 0;
  __ZN10MatchFrameC1Ev($21);
  var $22 = $this + 1568 | 0;
  __ZN10MatchFrameC1Ev($22);
  var $23 = $this + 1688 | 0;
  __ZN10MatchFrameC1Ev($23);
  var $24 = $this + 1808 | 0;
  __ZN10MatchFrameC1Ev($24);
  HEAP32[$this + 1928 >> 2] = $9;
  HEAP32[$this + 1932 >> 2] = $8;
  HEAP32[$this + 1936 >> 2] = 1;
  __ZN10MatchFrame4initEP11JSArenaPool($8, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($10, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($11, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($12, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($13, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($14, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($15, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($16, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($17, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($18, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($19, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($20, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($21, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($22, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($23, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($24, $regExpPool);
  return;
}

__ZN10MatchStackC2EP11JSArenaPool["X"] = 1;

function __Z15jsc_pcre_xclassiPKh($c, $data) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $x = __stackBase__ + 4;
    var $x1 = __stackBase__ + 8;
    var $y = __stackBase__ + 12;
    HEAP32[$1 >> 2] = $data;
    var $2 = HEAPU8[$data];
    var $5 = ($2 & 2) << 24 >> 24 == 0;
    if (($c | 0) < 256) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $storemerge = $data + 1 | 0;
    __label__ = 8;
    break;
   case 4:
    if ((HEAPU8[$data + ((($c | 0) / 8 & -1) + 1) | 0] & 255 & 1 << ($c & 7) | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_0 = ($2 & 1) << 24 >> 24 == 0;
    __label__ = 17;
    break;
   case 6:
    if ($5) {
      var $storemerge = $data + 1 | 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $storemerge = $data + 33 | 0;
    __label__ = 8;
    break;
   case 8:
    var $storemerge;
    HEAP32[$1 >> 2] = $storemerge;
    var $24 = $storemerge;
    __label__ = 9;
    break;
   case 9:
    var $24;
    HEAP32[$1 >> 2] = $24 + 1 | 0;
    var $26 = HEAP8[$24];
    if ($26 << 24 >> 24 == 1) {
      __label__ = 11;
      break;
    } else if ($26 << 24 >> 24 == 2) {
      __label__ = 13;
      break;
    } else if ($26 << 24 >> 24 == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $24 = HEAP32[$1 >> 2];
    __label__ = 9;
    break;
   case 11:
    __ZL28getUTF8CharAndAdvancePointerRiRPKh($x, $1);
    if ((HEAP32[$x >> 2] | 0) == ($c | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 12:
    var $_0 = ($2 & 1) << 24 >> 24 == 0;
    __label__ = 17;
    break;
   case 13:
    __ZL28getUTF8CharAndAdvancePointerRiRPKh($x1, $1);
    __ZL28getUTF8CharAndAdvancePointerRiRPKh($y, $1);
    if ((HEAP32[$x1 >> 2] | 0) > ($c | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    if ((HEAP32[$y >> 2] | 0) < ($c | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $_0 = ($2 & 1) << 24 >> 24 == 0;
    __label__ = 17;
    break;
   case 16:
    var $_0 = ($2 & 1) << 24 >> 24 != 0;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z15jsc_pcre_xclassiPKh["X"] = 1;

function __ZN2v88internal7ceilingEd($x) {
  var $1 = _ceil($x);
  return $1;
}

function __ZN2JS15PerfMeasurementC2ENS0_9EventMaskE($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  var $4 = $this + 8 | 0;
  for (var $$dest = $4 >> 2, $$stop = $$dest + 22; $$dest < $$stop; $$dest++) {
    HEAP32[$$dest] = -1;
  }
  return;
}

function __ZN2JS15PerfMeasurement5resetEv($this) {
  var $2 = $this + 8 | 0;
  for (var $$dest = $2 >> 2, $$stop = $$dest + 22; $$dest < $$stop; $$dest++) {
    HEAP32[$$dest] = -1;
  }
  return;
}

function _PRMJ_LocalGMTDifference() {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tm = __stackBase__;
    var $1 = __ZL16ComputeLocalTimelP2tm(0, $tm);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    if ((HEAP32[$tm + 32 >> 2] | 0) > 0) {
      __label__ = 3;
      break;
    } else {
      var $day_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZL16ComputeLocalTimelP2tm(15552e3, $tm);
    if ($7) {
      var $day_0 = 180;
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $day_0;
    var $17 = HEAP32[$tm + 8 >> 2] * -3600 + 86400 - HEAP32[$tm >> 2] + HEAP32[$tm + 4 >> 2] * -60 | 0;
    var $time_0 = (HEAP32[$tm + 28 >> 2] | 0) == ($day_0 | 0) ? $17 - 86400 | 0 : $17;
    var $_0 = $time_0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16ComputeLocalTimelP2tm($local, $ptm) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$1 >> 2] = $local;
  var $2 = _localtime_r($1, $ptm);
  var $3 = ($2 | 0) != 0;
  STACKTOP = __stackBase__;
  return $3;
}

function _PRMJ_Now() {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $tv = __stackBase__;
  var $1 = _gettimeofday($tv, 0);
  var $3 = HEAP32[$tv >> 2];
  var $4$0 = $3;
  var $4$1 = ($3 | 0) < 0 ? -1 : 0;
  var $5$0 = (i64Math.multiply($4$0, $4$1, 1e6, 0), i64Math.result[0]);
  var $5$1 = i64Math.result[1];
  var $7 = HEAP32[$tv + 4 >> 2];
  var $8$0 = $7;
  var $8$1 = ($7 | 0) < 0 ? -1 : 0;
  var $9$0 = (i64Math.add($5$0, $5$1, $8$0, $8$1), i64Math.result[0]);
  var $9$1 = i64Math.result[1];
  STACKTOP = __stackBase__;
  return [ $9$0, $9$1 ];
}

function __ZNK2v88internal6VectorIcE5startEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZL18my_GetErrorMessagePvPKcj($userRef, $locale, $errorNumber) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($errorNumber | 0) != 0 & $errorNumber >>> 0 < 15) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = _jsShell_ErrorFormatString + ($errorNumber << 3) | 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _PRMJ_FormatTime($buf, $fmt, $prtm) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 124;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $a = __stackBase__;
    var $td = __stackBase__ + 44;
    var $t = __stackBase__ + 88;
    var $real_year = __stackBase__ + 92;
    var $fake_year = __stackBase__ + 108;
    var $1 = $a;
    for (var $$dest = $1 >> 2, $$stop = $$dest + 11; $$dest < $$stop; $$dest++) {
      HEAP32[$$dest] = 0;
    }
    var $4 = HEAP8[$prtm + 4 | 0] << 24 >> 24;
    HEAP32[$a >> 2] = $4;
    var $8 = HEAP8[$prtm + 5 | 0] << 24 >> 24;
    HEAP32[$a + 4 >> 2] = $8;
    var $12 = HEAP8[$prtm + 6 | 0] << 24 >> 24;
    HEAP32[$a + 8 >> 2] = $12;
    var $16 = HEAP8[$prtm + 7 | 0] << 24 >> 24;
    HEAP32[$a + 12 >> 2] = $16;
    var $20 = HEAP8[$prtm + 8 | 0] << 24 >> 24;
    HEAP32[$a + 16 >> 2] = $20;
    var $24 = HEAP8[$prtm + 9 | 0] << 24 >> 24;
    HEAP32[$a + 24 >> 2] = $24;
    var $26 = $td;
    for (var $$dest = $26 >> 2, $$stop = $$dest + 11; $$dest < $$stop; $$dest++) {
      HEAP32[$$dest] = 0;
    }
    HEAP32[$td >> 2] = $4;
    HEAP32[$td + 4 >> 2] = $8;
    HEAP32[$td + 8 >> 2] = $12;
    HEAP32[$td + 12 >> 2] = $16;
    HEAP32[$td + 16 >> 2] = $20;
    HEAP32[$td + 24 >> 2] = $24;
    var $33 = $prtm + 12 | 0;
    var $35 = HEAP32[$33 >> 2] - 1900 | 0;
    HEAP32[$td + 20 >> 2] = $35;
    var $37 = $prtm + 16 | 0;
    HEAP32[$td + 28 >> 2] = HEAP16[$37 >> 1] << 16 >> 16;
    var $41 = $prtm + 18 | 0;
    HEAP32[$td + 32 >> 2] = HEAP8[$41] << 24 >> 24;
    var $45 = _mktime($td);
    HEAP32[$t >> 2] = $45;
    var $46 = _localtime_r($t, $td);
    var $48 = HEAP32[$td + 36 >> 2];
    HEAP32[$a + 36 >> 2] = $48;
    var $51 = HEAP32[$td + 40 >> 2];
    HEAP32[$a + 40 >> 2] = $51;
    var $53 = HEAPU32[$33 >> 2];
    var $_off = $53 - 1900 | 0;
    if ($_off >>> 0 > 8099) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $56 = ($53 | 0) % 100;
    var $57 = $56 + 9900 | 0;
    HEAP32[$a + 20 >> 2] = $56 + 8e3 | 0;
    var $fake_tm_year_0 = $57;
    __label__ = 4;
    break;
   case 3:
    HEAP32[$a + 20 >> 2] = $_off;
    var $fake_tm_year_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $fake_tm_year_0;
    HEAP32[$a + 28 >> 2] = HEAP16[$37 >> 1] << 16 >> 16;
    HEAP32[$a + 32 >> 2] = HEAP8[$41] << 24 >> 24;
    var $69 = _strftime($buf, 100, $fmt, $a);
    if (($fake_tm_year_0 | 0) == 0 | ($69 | 0) == 0) {
      var $_0 = $69;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $73 = $real_year | 0;
    var $74 = HEAP32[$33 >> 2];
    var $75 = _sprintf($73, STRING_TABLE.__str4498 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $74, tempInt));
    var $76 = _strlen($73);
    var $77 = $fake_year | 0;
    var $78 = _sprintf($77, STRING_TABLE.__str4498 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $fake_tm_year_0, tempInt));
    var $79 = _strlen($77);
    var $80 = $76 - $79 | 0;
    var $p_0 = $buf;
    var $result_0 = $69;
    __label__ = 6;
    break;
   case 6:
    var $result_0;
    var $p_0;
    var $82 = _strstr($p_0, $77);
    if (($82 | 0) == 0) {
      var $_0 = $result_0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $85 = $80 + $result_0 | 0;
    if (($85 | 0) < 100) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $88 = $82 + $76 | 0;
    var $89 = $82 + $79 | 0;
    var $90 = _strlen($89);
    _llvm_memmove_p0i8_p0i8_i32($88, $89, $90, 1, 0);
    _memcpy($82, $73, $76, 1);
    HEAP8[$buf + $85 | 0] = 0;
    var $p_0 = $88;
    var $result_0 = $85;
    __label__ = 6;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_PRMJ_FormatTime["X"] = 1;

function __ZN14DSTOffsetCache28computeDSTOffsetMillisecondsEx($localTimeSeconds$0, $localTimeSeconds$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tm = __stackBase__;
    var $1 = $localTimeSeconds$0;
    var $2 = __ZL16ComputeLocalTimelP2tm($1, $tm);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0$1 = 0;
      var $_0$0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = _PRMJ_LocalGMTDifference();
    var $5$0 = $4;
    var $5$1 = ($4 | 0) < 0 ? -1 : 0;
    var $6$0 = (i64Math.subtract($localTimeSeconds$0, $localTimeSeconds$1, $5$0, $5$1), i64Math.result[0]);
    var $6$1 = i64Math.result[1];
    var $7$0 = (i64Math.modulo($6$0, $6$1, 86400, 0), i64Math.result[0]);
    var $7$1 = i64Math.result[1];
    var $19 = HEAP32[$tm >> 2] - $7$0 + HEAP32[$tm + 4 >> 2] * 60 + HEAP32[$tm + 8 >> 2] * 3600 | 0;
    var $_ = ($19 | 0) < 0 ? $19 + 86400 | 0 : $19;
    var $22$0 = $_;
    var $22$1 = ($_ | 0) < 0 ? -1 : 0;
    var $23$0 = (i64Math.multiply($22$0, $22$1, 1e3, 0), i64Math.result[0]);
    var $23$1 = i64Math.result[1];
    var $_0$1 = $23$1;
    var $_0$0 = $23$0;
    __label__ = 3;
    break;
   case 3:
    var $_0$0;
    var $_0$1;
    STACKTOP = __stackBase__;
    return [ $_0$0, $_0$1 ];
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN14DSTOffsetCache24getDSTOffsetMillisecondsExP9JSContext($this, $localTimeMilliseconds$0, $localTimeMilliseconds$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $$emscripten$temp$0$1 = 499;
    if (($localTimeMilliseconds$1 | 0) > ($$emscripten$temp$0$1 | 0) || ($localTimeMilliseconds$1 | 0) == ($$emscripten$temp$0$1 | 0) && $localTimeMilliseconds$0 >>> 0 > -1624447001 >>> 0) {
      var $localTimeSeconds_0$1 = 0;
      var $localTimeSeconds_0$0 = 2145859200;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3$0 = (i64Math.divide($localTimeMilliseconds$0, $localTimeMilliseconds$1, 1e3, 0), i64Math.result[0]);
    var $3$1 = i64Math.result[1];
    var $$emscripten$temp$2$1 = -1;
    if (($localTimeMilliseconds$1 | 0) < ($$emscripten$temp$2$1 | 0) || ($localTimeMilliseconds$1 | 0) == ($$emscripten$temp$2$1 | 0) && $localTimeMilliseconds$0 >>> 0 < -999 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $localTimeSeconds_0$1 = $3$1;
      var $localTimeSeconds_0$0 = $3$0;
      __label__ = 4;
      break;
    }
   case 3:
    var $localTimeSeconds_0$1 = 0;
    var $localTimeSeconds_0$0 = 86400;
    __label__ = 4;
    break;
   case 4:
    var $localTimeSeconds_0$0;
    var $localTimeSeconds_0$1;
    var $7 = $this + 8 | 0;
    var $st$3$0 = $7 | 0;
    var $8$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $7 + 4 | 0;
    var $8$1 = HEAP32[$st$3$1 >> 2];
    var $9 = ($8$1 | 0) > ($localTimeSeconds_0$1 | 0) || ($8$1 | 0) == ($localTimeSeconds_0$1 | 0) && $8$0 >>> 0 > $localTimeSeconds_0$0 >>> 0;
    if ($9) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = $this + 16 | 0;
    var $st$1$0 = $11 | 0;
    var $st$1$1 = $11 + 4 | 0;
    var $12$1 = HEAP32[$st$1$1 >> 2];
    if (($localTimeSeconds_0$1 | 0) > ($12$1 | 0) || ($localTimeSeconds_0$1 | 0) == ($12$1 | 0) && $localTimeSeconds_0$0 >>> 0 > HEAP32[$st$1$0 >> 2] >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $this | 0;
    var $st$1$0 = $15 | 0;
    var $st$1$1 = $15 + 4 | 0;
    var $_0$1 = HEAP32[$st$1$1 >> 2];
    var $_0$0 = HEAP32[$st$1$0 >> 2];
    __label__ = 25;
    break;
   case 7:
    var $18 = $this + 32 | 0;
    var $st$1$0 = $18 | 0;
    var $st$1$1 = $18 + 4 | 0;
    var $19$1 = HEAP32[$st$1$1 >> 2];
    var $_pre = $this + 40 | 0;
    if (($19$1 | 0) > ($localTimeSeconds_0$1 | 0) || ($19$1 | 0) == ($localTimeSeconds_0$1 | 0) && HEAP32[$st$1$0 >> 2] >>> 0 > $localTimeSeconds_0$0 >>> 0) {
      var $_pre_phi = $_pre;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $st$0$0 = $_pre | 0;
    var $st$0$1 = $_pre + 4 | 0;
    var $22$1 = HEAP32[$st$0$1 >> 2];
    if (($localTimeSeconds_0$1 | 0) > ($22$1 | 0) || ($localTimeSeconds_0$1 | 0) == ($22$1 | 0) && $localTimeSeconds_0$0 >>> 0 > HEAP32[$st$0$0 >> 2] >>> 0) {
      var $_pre_phi = $_pre;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $25 = $this + 24 | 0;
    var $st$1$0 = $25 | 0;
    var $st$1$1 = $25 + 4 | 0;
    var $_0$1 = HEAP32[$st$1$1 >> 2];
    var $_0$0 = HEAP32[$st$1$0 >> 2];
    __label__ = 25;
    break;
   case 10:
    var $_pre_phi;
    var $27 = $this | 0;
    var $st$2$0 = $27 | 0;
    var $28$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $27 + 4 | 0;
    var $28$1 = HEAP32[$st$2$1 >> 2];
    var $29 = $this + 24 | 0;
    var $st$7$0 = $29 | 0;
    HEAP32[$st$7$0 >> 2] = $28$0;
    var $st$7$1 = $29 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $28$1;
    var $st$11$0 = $18 | 0;
    HEAP32[$st$11$0 >> 2] = $8$0;
    var $st$11$1 = $18 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $8$1;
    var $30 = $this + 16 | 0;
    var $31$0 = HEAP32[$30 >> 2];
    var $31$1 = HEAP32[$30 + 4 >> 2];
    HEAP32[$_pre_phi >> 2] = $31$0;
    HEAP32[$_pre_phi + 4 >> 2] = $31$1;
    if ($9) {
      __label__ = 18;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $33$0 = (i64Math.add($31$0, $31$1, 2592e3, 0), i64Math.result[0]);
    var $33$1 = i64Math.result[1];
    var $$emscripten$temp$4$1 = 0;
    var $34 = ($33$1 | 0) < ($$emscripten$temp$4$1 | 0) || ($33$1 | 0) == ($$emscripten$temp$4$1 | 0) && $33$0 >>> 0 < 2145859200 >>> 0;
    var $35$0 = $34 ? $33$0 : 2145859200;
    var $35$1 = $34 ? $33$1 : 0;
    if (($35$1 | 0) < ($localTimeSeconds_0$1 | 0) || ($35$1 | 0) == ($localTimeSeconds_0$1 | 0) && $35$0 >>> 0 < $localTimeSeconds_0$0 >>> 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $38 = __ZN14DSTOffsetCache28computeDSTOffsetMillisecondsEx($35$0, $35$1);
    var $38$0 = $38[0];
    var $38$1 = $38[1];
    var $st$3$0 = $27 | 0;
    var $39$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $27 + 4 | 0;
    var $39$1 = HEAP32[$st$3$1 >> 2];
    if ($38$0 == $39$0 && $38$1 == $39$1) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $st$0$0 = $30 | 0;
    HEAP32[$st$0$0 >> 2] = $35$0;
    var $st$0$1 = $30 + 4 | 0;
    HEAP32[$st$0$1 >> 2] = $35$1;
    var $_0$1 = $39$1;
    var $_0$0 = $39$0;
    __label__ = 25;
    break;
   case 14:
    var $43 = __ZN14DSTOffsetCache28computeDSTOffsetMillisecondsEx($localTimeSeconds_0$0, $localTimeSeconds_0$1);
    var $43$0 = $43[0];
    var $43$1 = $43[1];
    var $st$3$0 = $27 | 0;
    HEAP32[$st$3$0 >> 2] = $43$0;
    var $st$3$1 = $27 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $43$1;
    if ($43$0 == $38$0 && $43$1 == $38$1) {
      __label__ = 15;
      break;
    } else {
      var $storemerge$1 = $localTimeSeconds_0$1;
      var $storemerge$0 = $localTimeSeconds_0$0;
      __label__ = 16;
      break;
    }
   case 15:
    var $st$0$0 = $7 | 0;
    HEAP32[$st$0$0 >> 2] = $localTimeSeconds_0$0;
    var $st$0$1 = $7 + 4 | 0;
    HEAP32[$st$0$1 >> 2] = $localTimeSeconds_0$1;
    var $storemerge$1 = $35$1;
    var $storemerge$0 = $35$0;
    __label__ = 16;
    break;
   case 16:
    var $storemerge$0;
    var $storemerge$1;
    var $st$2$0 = $30 | 0;
    HEAP32[$st$2$0 >> 2] = $storemerge$0;
    var $st$2$1 = $30 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $storemerge$1;
    var $_0$1 = $43$1;
    var $_0$0 = $43$0;
    __label__ = 25;
    break;
   case 17:
    var $48 = __ZN14DSTOffsetCache28computeDSTOffsetMillisecondsEx($localTimeSeconds_0$0, $localTimeSeconds_0$1);
    var $48$0 = $48[0];
    var $48$1 = $48[1];
    var $st$3$0 = $27 | 0;
    HEAP32[$st$3$0 >> 2] = $48$0;
    var $st$3$1 = $27 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $48$1;
    var $st$7$0 = $30 | 0;
    HEAP32[$st$7$0 >> 2] = $localTimeSeconds_0$0;
    var $st$7$1 = $30 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $localTimeSeconds_0$1;
    var $st$11$0 = $7 | 0;
    HEAP32[$st$11$0 >> 2] = $localTimeSeconds_0$0;
    var $st$11$1 = $7 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $localTimeSeconds_0$1;
    var $_0$1 = $48$1;
    var $_0$0 = $48$0;
    __label__ = 25;
    break;
   case 18:
    var $50$0 = (i64Math.add($8$0, $8$1, -2592e3, -1), i64Math.result[0]);
    var $50$1 = i64Math.result[1];
    var $$emscripten$temp$7$1 = 0;
    var $51 = ($50$1 | 0) > ($$emscripten$temp$7$1 | 0) || ($50$1 | 0) == ($$emscripten$temp$7$1 | 0) && $50$0 >>> 0 > 0 >>> 0;
    var $52$0 = $51 ? $50$0 : 0;
    var $52$1 = $51 ? $50$1 : 0;
    if (($52$1 | 0) > ($localTimeSeconds_0$1 | 0) || ($52$1 | 0) == ($localTimeSeconds_0$1 | 0) && $52$0 >>> 0 > $localTimeSeconds_0$0 >>> 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $55 = __ZN14DSTOffsetCache28computeDSTOffsetMillisecondsEx($52$0, $52$1);
    var $55$0 = $55[0];
    var $55$1 = $55[1];
    var $st$3$0 = $27 | 0;
    var $56$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $27 + 4 | 0;
    var $56$1 = HEAP32[$st$3$1 >> 2];
    if ($55$0 == $56$0 && $55$1 == $56$1) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $st$0$0 = $7 | 0;
    HEAP32[$st$0$0 >> 2] = $52$0;
    var $st$0$1 = $7 + 4 | 0;
    HEAP32[$st$0$1 >> 2] = $52$1;
    var $_0$1 = $56$1;
    var $_0$0 = $56$0;
    __label__ = 25;
    break;
   case 21:
    var $60 = __ZN14DSTOffsetCache28computeDSTOffsetMillisecondsEx($localTimeSeconds_0$0, $localTimeSeconds_0$1);
    var $60$0 = $60[0];
    var $60$1 = $60[1];
    var $st$3$0 = $27 | 0;
    HEAP32[$st$3$0 >> 2] = $60$0;
    var $st$3$1 = $27 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $60$1;
    if ($60$0 == $55$0 && $60$1 == $55$1) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    var $st$0$0 = $7 | 0;
    HEAP32[$st$0$0 >> 2] = $52$0;
    var $st$0$1 = $7 + 4 | 0;
    HEAP32[$st$0$1 >> 2] = $52$1;
    var $st$4$0 = $30 | 0;
    HEAP32[$st$4$0 >> 2] = $localTimeSeconds_0$0;
    var $st$4$1 = $30 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $localTimeSeconds_0$1;
    var $_0$1 = $60$1;
    var $_0$0 = $60$0;
    __label__ = 25;
    break;
   case 23:
    var $st$0$0 = $7 | 0;
    HEAP32[$st$0$0 >> 2] = $localTimeSeconds_0$0;
    var $st$0$1 = $7 + 4 | 0;
    HEAP32[$st$0$1 >> 2] = $localTimeSeconds_0$1;
    var $_0$1 = $60$1;
    var $_0$0 = $60$0;
    __label__ = 25;
    break;
   case 24:
    var $st$0$0 = $30 | 0;
    HEAP32[$st$0$0 >> 2] = $localTimeSeconds_0$0;
    var $st$0$1 = $30 + 4 | 0;
    HEAP32[$st$0$1 >> 2] = $localTimeSeconds_0$1;
    var $st$4$0 = $7 | 0;
    HEAP32[$st$4$0 >> 2] = $localTimeSeconds_0$0;
    var $st$4$1 = $7 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $localTimeSeconds_0$1;
    var $65 = __ZN14DSTOffsetCache28computeDSTOffsetMillisecondsEx($localTimeSeconds_0$0, $localTimeSeconds_0$1);
    var $65$0 = $65[0];
    var $65$1 = $65[1];
    var $st$11$0 = $27 | 0;
    HEAP32[$st$11$0 >> 2] = $65$0;
    var $st$11$1 = $27 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $65$1;
    var $_0$1 = $65$1;
    var $_0$0 = $65$0;
    __label__ = 25;
    break;
   case 25:
    var $_0$0;
    var $_0$1;
    return [ $_0$0, $_0$1 ];
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN14DSTOffsetCache24getDSTOffsetMillisecondsExP9JSContext["X"] = 1;

function __ZN2v88internal13StringBuilder9AddStringEPKc($this, $s) {
  var $1 = __ZN2v88internal9StrLengthEPKc($s);
  __ZN2v88internal13StringBuilder12AddSubstringEPKci($this, $s, $1);
  return;
}

function __ZN2v88internal13StringBuilder12AddSubstringEPKci($this, $s, $n) {
  var $1 = $this + 8 | 0;
  var $2 = HEAP32[$1 >> 2];
  var $_idx_val = HEAP32[$this >> 2];
  var $3 = __ZNK2v88internal6VectorIcEixEi($_idx_val, $2);
  _memcpy($3, $s, $n, 1);
  var $5 = HEAP32[$1 >> 2] + $n | 0;
  HEAP32[$1 >> 2] = $5;
  return;
}

function __ZN2v88internal9StrLengthEPKc($string) {
  var $1 = _strlen($string);
  return $1;
}

function __ZN2v88internal13StringBuilder10AddIntegerEi($this, $n) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ndigits_0 = 0;
    var $n2_0 = $n;
    __label__ = 2;
    break;
   case 2:
    var $n2_0;
    var $ndigits_0;
    var $2 = $ndigits_0 + 1 | 0;
    if (($n2_0 + 9 | 0) >>> 0 > 18) {
      var $ndigits_0 = $2;
      var $n2_0 = ($n2_0 | 0) / 10 & -1;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = $this + 8 | 0;
    var $8 = HEAP32[$6 >> 2] + $2 | 0;
    HEAP32[$6 >> 2] = $8;
    var $_idx = $this | 0;
    var $i_0 = $8;
    var $_0 = $n;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    var $i_0;
    var $12 = $_0 % 10 + 48 & 255;
    var $13 = $i_0 - 1 | 0;
    var $_idx_val = HEAP32[$_idx >> 2];
    var $14 = __ZNK2v88internal6VectorIcEixEi($_idx_val, $13);
    HEAP8[$14] = $12;
    if (($_0 + 9 | 0) >>> 0 > 18) {
      var $i_0 = $13;
      var $_0 = ($_0 | 0) / 10 & -1;
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2v88internal13StringBuilder10AddPaddingEci($this, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($count | 0) > 0) {
      var $i_01 = 0;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $i_01;
    __ZN2v88internal13StringBuilder12AddCharacterEc($this, 48);
    var $2 = $i_01 + 1 | 0;
    if (($2 | 0) == ($count | 0)) {
      __label__ = 3;
      break;
    } else {
      var $i_01 = $2;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2v88internal13StringBuilder8FinalizeEv($this) {
  var $1 = $this + 8 | 0;
  var $2 = HEAP32[$1 >> 2];
  var $_idx = $this | 0;
  var $_idx_val = HEAP32[$_idx >> 2];
  var $3 = __ZNK2v88internal6VectorIcEixEi($_idx_val, $2);
  HEAP8[$3] = 0;
  HEAP32[$1 >> 2] = -1;
  var $_idx1_val = HEAP32[$_idx >> 2];
  var $4 = __ZNK2v88internal6VectorIcE5startEv($_idx1_val);
  return $4;
}

function __ZN2v88internal13DoubleToAsciiEdNS0_8DtoaModeEiNS0_6VectorIcEEPiS4_S4_($v, $buffer_0, $buffer_1, $sign, $length, $point) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    __ZN2v88internal6DoubleC1Ed($1, $v);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $2 = __ZNK2v88internal6Double4SignEv($_idx_val$0, $_idx_val$1);
    if (($2 | 0) < 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$sign >> 2] = 1;
    var $_01 = -$v;
    __label__ = 4;
    break;
   case 3:
    HEAP32[$sign >> 2] = 0;
    var $_01 = $v;
    __label__ = 4;
    break;
   case 4:
    var $_01;
    if ($_01 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $10 = __ZNK2v88internal6VectorIcEixEi($buffer_0, 0);
    HEAP8[$10] = 48;
    var $11 = __ZNK2v88internal6VectorIcEixEi($buffer_0, 1);
    HEAP8[$11] = 0;
    HEAP32[$length >> 2] = 1;
    HEAP32[$point >> 2] = 1;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 6:
    var $13 = __ZN2v88internal8FastDtoaEdNS0_6VectorIcEEPiS3_($_01, $buffer_0, $buffer_1, $length, $point);
    var $_0 = $13;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2v88internal6Double4SignEv($this_0_0_val$0, $this_0_0_val$1) {
  var $1 = __ZNK2v88internal6Double8AsUint64Ev($this_0_0_val$0, $this_0_0_val$1);
  var $1$1 = $1[1];
  var $$emscripten$temp$0$1 = -1;
  var $3 = ($1$1 | 0) > ($$emscripten$temp$0$1 | 0) || ($1$1 | 0) == ($$emscripten$temp$0$1 | 0) && $1[0] >>> 0 > -1 >>> 0 ? 1 : -1;
  return $3;
}

function __Z9DumpStackP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $iter = __stackBase__;
    var $v = __stackBase__ + 40;
    var $1 = __stackBase__ + 48;
    var $2 = __stackBase__ + 56;
    var $3 = __stackBase__ + 64;
    var $4 = __stackBase__ + 72;
    var $5 = _JS_NewArrayObject($cx);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = _JS_NewStringCopyZ($cx, STRING_TABLE.__str293 | 0);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = _JS_NewStringCopyZ($cx, STRING_TABLE.__str1294 | 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $cx;
    __ZN2js9StackIterC2EP9JSContextNS0_11SavedOptionE($iter, $14, 0);
    __ZN2js9StackIterppEv($iter);
    var $15 = $1 | 0;
    var $16 = $v | 0;
    var $17 = $2 | 0;
    var $iter_idx4 = $iter + 8 | 0;
    var $iter_idx1 = $iter + 12 | 0;
    var $_idx3 = $3 | 0;
    var $index_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $index_0;
    var $iter_idx4_val = HEAP32[$iter_idx4 >> 2];
    var $19 = __ZNK2js9StackIter4doneEv($iter_idx4_val);
    if ($19) {
      __label__ = 15;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = __ZNK2js9StackIter8isScriptEv($iter_idx4_val);
    if ($21) {
      __label__ = 7;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 7:
    var $iter_idx1_val = HEAP32[$iter_idx1 >> 2];
    var $23 = __ZNK2js9StackIter2fpEv($iter_idx1_val);
    var $_idx_val = HEAP32[$23 >> 2];
    var $24 = __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($_idx_val);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = $23;
    var $27 = __ZN2js10StackFrame20getValidCalleeObjectEP9JSContextPN2JS5ValueE($26, $cx, $v);
    if ($27) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 9:
    var $29 = __ZNK2js10StackFrame11isEvalFrameEv($_idx_val);
    if ($29) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    __ZN2JSL11StringValueEP8JSString587($1, $8);
    var $st$1$0 = $15 | 0;
    var $31$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $15 + 4 | 0;
    var $31$1 = HEAP32[$st$1$1 >> 2];
    var $st$5$0 = $16 | 0;
    HEAP32[$st$5$0 >> 2] = $31$0;
    var $st$5$1 = $16 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $31$1;
    __label__ = 13;
    break;
   case 11:
    __ZN2JSL11StringValueEP8JSString587($2, $11);
    var $st$1$0 = $17 | 0;
    var $33$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $17 + 4 | 0;
    var $33$1 = HEAP32[$st$1$1 >> 2];
    var $st$5$0 = $16 | 0;
    HEAP32[$st$5$0 >> 2] = $33$0;
    var $st$5$1 = $16 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $33$1;
    __label__ = 13;
    break;
   case 12:
    __ZNK2js9StackIter10nativeArgsEv($3, $iter);
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $35 = __ZNK2js12CallReceiver7calleevEv($_idx3_val);
    var $36 = $35 | 0;
    var $37$0 = HEAP32[$36 >> 2];
    var $37$1 = HEAP32[$36 + 4 >> 2];
    HEAP32[$16 >> 2] = $37$0;
    HEAP32[$16 + 4 >> 2] = $37$1;
    __label__ = 13;
    break;
   case 13:
    var $39 = _JS_SetElement($cx, $5, $index_0, $v);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $42 = $index_0 + 1 | 0;
    __ZN2js9StackIterppEv($iter);
    var $index_0 = $42;
    __label__ = 5;
    break;
   case 15:
    __ZN2JSL11ObjectValueER8JSObject588($4, $5);
    var $44 = $4 | 0;
    var $45$0 = HEAP32[$44 >> 2];
    var $45$1 = HEAP32[$44 + 4 >> 2];
    var $46 = $vp | 0;
    HEAP32[$46 >> 2] = $45$0;
    HEAP32[$46 + 4 >> 2] = $45$1;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z9DumpStackP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2JSL11StringValueEP8JSString587($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2JSL11ObjectValueER8JSObject588($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZL17sandbox_enumerateP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $b = __stackBase__ + 8;
    var $1 = _JS_GetProperty($cx, $obj, STRING_TABLE.__str245538 | 0, $v);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $v | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    _JS_ValueToBoolean($5$0, $5$1, $b);
    if ((HEAP32[$b >> 2] | 0) == 0) {
      var $12 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = _JS_EnumerateStandardClasses($cx, $obj);
    var $12 = ($9 | 0) != 0;
    __label__ = 4;
    break;
   case 4:
    var $12;
    var $_0 = $12 & 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15sandbox_resolveP9JSContextP8JSObjectijPS2_($cx, $obj, $id, $flags, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $b = __stackBase__ + 8;
    var $resolved = __stackBase__ + 12;
    var $1 = _JS_GetProperty($cx, $obj, STRING_TABLE.__str245538 | 0, $v);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $v | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    _JS_ValueToBoolean($5$0, $5$1, $b);
    if ((HEAP32[$b >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($flags & 2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $12 = _JS_ResolveStandardClass($cx, $obj, $id, $resolved);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$resolved >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 7:
    HEAP32[$objp >> 2] = 0;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18resolver_enumerateP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $ida = __stackBase__ + 8;
    var $ignore = __stackBase__ + 24;
    _JS_GetReservedSlot($obj, $1);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $2 = _JSVAL_TO_OBJECT590($_idx_val$0, $_idx_val$1);
    var $3 = _JS_Enumerate($cx, $2);
    __ZN2js11AutoIdArrayC1EP9JSContextP9JSIdArray($ida, $cx, $3);
    var $ida_idx = $ida + 12 | 0;
    var $ida_idx_val = HEAP32[$ida_idx >> 2];
    var $4 = __ZN2js11AutoIdArrayntEv($ida_idx_val);
    var $i_0 = 0;
    var $ok_0 = $4 & 1 ^ 1;
    __label__ = 2;
    break;
   case 2:
    var $ok_0;
    var $i_0;
    var $8 = $ok_0 & 1;
    if ($8 << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $ida_idx1_val = HEAPU32[$ida_idx >> 2];
    var $ida_idx1_val_idx_val = HEAP32[$ida_idx1_val >> 2];
    var $11 = __ZNK2js11AutoIdArray6lengthEv($ida_idx1_val_idx_val);
    if ($i_0 >>> 0 < $11 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = __ZNK2js11AutoIdArrayixEj($ida_idx1_val, $i_0);
    var $15 = __ZL12CopyPropertyP9JSContextP8JSObjectS2_ijPS2_($cx, $obj, $2, $14, 1, $ignore);
    var $17 = ($15 | 0) != 0 & 1;
    var $i_0 = $i_0 + 1 | 0;
    var $ok_0 = $17;
    __label__ = 2;
    break;
   case 5:
    var $19 = $8 & 255;
    __ZN2js11AutoIdArrayD1Ev($ida);
    STACKTOP = __stackBase__;
    return $19;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16resolver_resolveP9JSContextP8JSObjectijPS2_($cx, $obj, $id, $flags, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _JS_GetReservedSlot($obj, $1);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  var $2 = _JSVAL_TO_OBJECT590($_idx_val$0, $_idx_val$1);
  var $3 = __ZL12CopyPropertyP9JSContextP8JSObjectS2_ijPS2_($cx, $obj, $2, $id, $flags, $objp);
  STACKTOP = __stackBase__;
  return $3;
}

function __Z4WrapP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $4 = ($argc | 0) == 0 ? _JSVAL_VOID : $vp + 16 | 0;
    var $_04 = $4 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $5 = _JSVAL_IS_PRIMITIVE589($tmp$0, $tmp$1);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $vp7_0 = $vp | 0;
    HEAP32[$vp7_0 >> 2] = $tmp$0;
    HEAP32[$vp7_0 + 4 >> 2] = $tmp$1;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $9 = _JSVAL_TO_OBJECT590($tmp$0, $tmp$1);
    var $_idx_val_idx_val = HEAP32[HEAP32[$9 + 36 >> 2] >> 2];
    var $10 = __ZNK8JSObject8getProtoEv($_idx_val_idx_val);
    var $11 = $9;
    var $12 = __ZNK8JSObject9getGlobalEv($11);
    var $13 = $12;
    var $14 = __ZN9JSWrapper3NewEP9JSContextP8JSObjectS3_S3_PS_($cx, $9, $10, $13, __ZN9JSWrapper9singletonE);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _OBJECT_TO_JSVAL591($1, $14);
    var $17 = $1 | 0;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    var $19 = $vp | 0;
    HEAP32[$19 >> 2] = $18$0;
    HEAP32[$19 + 4 >> 2] = $18$1;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSVAL_IS_PRIMITIVE589($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE598($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_PRIMITIVE_IMPL650($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_OBJECT590($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE598($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_OBJECT_IMPL642($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _OBJECT_TO_JSVAL591($agg_result, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL_IMPL649($1, $obj);
    var $_0 = $1 | 0;
    var $_0_val$0 = HEAP32[$_0 >> 2];
    var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
    __ZL13IMPL_TO_JSVAL12jsval_layout600($agg_result, $_0_val$0, $_0_val$1);
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $6 = $agg_result | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z9SerializeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $datap = __stackBase__;
    var $nbytes = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $4 = ($argc | 0) == 0 ? _JSVAL_VOID : $vp + 16 | 0;
    var $_03 = $4 | 0;
    var $tmp$0 = HEAP32[$_03 >> 2];
    var $tmp$1 = HEAP32[$_03 + 4 >> 2];
    var $5 = _JS_WriteStructuredClone($cx, $tmp$0, $tmp$1, $datap, $nbytes);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$nbytes >> 2];
    var $9 = __Z19js_CreateTypedArrayP9JSContextij($cx, 1, $8);
    if (($9 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $13 = HEAP32[$datap >> 2];
    _JS_free($13);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $15 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($9);
    var $_idx_val = HEAP32[$15 + 24 >> 2];
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx_val);
    var $18 = HEAP32[$datap >> 2];
    _memcpy($16, $18, $8, 1);
    _JS_free($18);
    _OBJECT_TO_JSVAL591($1, $9);
    var $19 = $1 | 0;
    var $20$0 = HEAP32[$19 >> 2];
    var $20$1 = HEAP32[$19 + 4 >> 2];
    var $21 = $vp | 0;
    HEAP32[$21 >> 2] = $20$0;
    HEAP32[$21 + 4 >> 2] = $20$1;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z11DeserializeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    if (($argc | 0) == 0) {
      var $5 = _JSVAL_VOID;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $vp + 16 | 0;
    __label__ = 3;
    break;
   case 3:
    var $5;
    var $6 = $5;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $v | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    var $9 = _JSVAL_IS_PRIMITIVE589($7$0, $7$1);
    if (($9 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $12 = _JSVAL_TO_OBJECT590($7$0, $7$1);
    var $_idx_val = HEAP32[$12 + 4 >> 2];
    var $13 = __Z15js_IsTypedArrayP8JSObject($_idx_val);
    if (($13 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 286, 12, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str4297 | 0, tempInt));
    var $_0 = 0;
    __label__ = 12;
    break;
   case 6:
    var $17 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($12);
    var $18 = __ZN2js10TypedArray13getByteLengthEP8JSObject($17);
    if (($18 & 7 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 286, 12, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str4297 | 0, tempInt));
    var $_0 = 0;
    __label__ = 12;
    break;
   case 8:
    var $_idx1_val = HEAP32[$17 + 24 >> 2];
    var $23 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx1_val);
    if (($23 & 7 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 286, 14, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 12;
    break;
   case 10:
    var $29 = $23;
    var $30 = _JS_ReadStructuredClone($cx, $29, $18, $v);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $33$0 = HEAP32[$8 >> 2];
    var $33$1 = HEAP32[$8 + 4 >> 2];
    var $34 = $vp | 0;
    HEAP32[$34 >> 2] = $33$0;
    HEAP32[$34 + 4 >> 2] = $33$1;
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z11DeserializeP9JSContextjPN2JS5ValueE["X"] = 1;

function __Z11StringStatsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _INT_TO_JSVAL592($1, 0);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $vp | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return 1;
}

function _INT_TO_JSVAL592($agg_result, $i) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _INT32_TO_JSVAL_IMPL613($1, $i);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout600($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __Z9NewGlobalP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $equalSame = __stackBase__;
    var $equalNew = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    if (($argc | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $vp + 16 | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = _JSVAL_IS_STRING593($5$0, $5$1);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 286, 12, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str5298 | 0, tempInt));
    var $_0 = 0;
    __label__ = 11;
    break;
   case 4:
    var $10$0 = HEAP32[$4 >> 2];
    var $10$1 = HEAP32[$4 + 4 >> 2];
    var $11 = _JSVAL_TO_STRING594($10$0, $10$1);
    HEAP32[$equalSame >> 2] = 0;
    HEAP32[$equalNew >> 2] = 0;
    var $12 = _JS_StringEqualsAscii($cx, $11, STRING_TABLE.__str6299 | 0, $equalSame);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = _JS_StringEqualsAscii($cx, $11, STRING_TABLE.__str7300 | 0, $equalNew);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = (HEAP32[$equalSame >> 2] | 0) == 0;
    if ($19) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    if ((HEAP32[$equalNew >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    _JS_ReportErrorNumber($cx, 286, 12, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str5298 | 0, tempInt));
    var $_0 = 0;
    __label__ = 11;
    break;
   case 9:
    var $25 = $19 & 1;
    var $26 = __ZL15NewGlobalObjectP9JSContext15CompartmentKind($cx, $25);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    _OBJECT_TO_JSVAL591($1, $26);
    var $29 = $1 | 0;
    var $30$0 = HEAP32[$29 >> 2];
    var $30$1 = HEAP32[$29 + 4 >> 2];
    var $31 = $vp | 0;
    HEAP32[$31 >> 2] = $30$0;
    HEAP32[$31 + 4 >> 2] = $30$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z9NewGlobalP9JSContextjPN2JS5ValueE["X"] = 1;

function _JSVAL_IS_STRING593($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE598($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_STRING_IMPL638($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_STRING594($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE598($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_STRING_IMPL648($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL15NewGlobalObjectP9JSContext15CompartmentKind($cx, $compartment) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $glob = __stackBase__;
    var $ac = __stackBase__ + 4;
    var $1 = ($compartment | 0) == 1;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = _JS_NewCompartmentAndGlobalObject($cx, _global_class);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = _JS_NewGlobalObject($cx, _global_class);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    HEAP32[$glob >> 2] = $7;
    if (($7 | 0) == 0) {
      var $_1 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN22JSAutoEnterCompartmentC1Ev($ac);
    var $10 = __ZN22JSAutoEnterCompartment5enterEP9JSContextP8JSObject($ac, $cx, $7);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 6:
    var $12 = _JS_InitReflect($cx, $7);
    if (($12 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $15 = _JS_DefineDebuggerObject($cx, $7);
    if (($15 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $18 = $cx;
    var $20 = __ZN2JS23RegisterPerfMeasurementEP9JSContextP8JSObject($18, $7);
    if (($20 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $23 = _JS_DefineFunctions($cx, $7, __ZL15shell_functions | 0);
    if (($23 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $26 = _JS_DefineObject($cx, $7, STRING_TABLE.__str143436 | 0, __ZL9its_class);
    if (($26 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $29 = _JS_DefineProperties($cx, $26, __ZL9its_props | 0);
    if (($29 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $32$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $32$1 = HEAP32[$st$1$1 >> 2];
    var $$emscripten$temp$1 = STRING_TABLE.__str68361 | 0;
    var $33 = _JS_DefineProperty($cx, $7, $$emscripten$temp$1, $32$0, $32$1, 288, 290, 0);
    if (($33 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $$emscripten$temp$2 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$2 | 0;
    var $36$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$2 + 4 | 0;
    var $36$1 = HEAP32[$st$1$1 >> 2];
    var $$emscripten$temp$3 = STRING_TABLE.__str69362 | 0;
    var $37 = _JS_DefineProperty($cx, $7, $$emscripten$temp$3, $36$0, $36$1, 288, 290, 2);
    var $38 = ($37 | 0) == 0;
    var $ac_idx9_val = HEAP32[$ac >> 2];
    __ZN22JSAutoEnterCompartmentD1Ev($ac_idx9_val);
    var $_mux = $38 ? 0 : $7;
    if ($38 | $1 ^ 1) {
      var $_1 = $_mux;
      __label__ = 24;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $40 = _JS_WrapObject($cx, $glob);
    if (($40 | 0) == 0) {
      var $_1 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $_1 = HEAP32[$glob >> 2];
    __label__ = 24;
    break;
   case 16:
    var $ac_idx8_val = HEAP32[$ac >> 2];
    __ZN22JSAutoEnterCompartmentD1Ev($ac_idx8_val);
    var $_1 = 0;
    __label__ = 24;
    break;
   case 17:
    var $ac_idx7_val = HEAP32[$ac >> 2];
    __ZN22JSAutoEnterCompartmentD1Ev($ac_idx7_val);
    var $_1 = 0;
    __label__ = 24;
    break;
   case 18:
    var $ac_idx6_val = HEAP32[$ac >> 2];
    __ZN22JSAutoEnterCompartmentD1Ev($ac_idx6_val);
    var $_1 = 0;
    __label__ = 24;
    break;
   case 19:
    var $ac_idx5_val = HEAP32[$ac >> 2];
    __ZN22JSAutoEnterCompartmentD1Ev($ac_idx5_val);
    var $_1 = 0;
    __label__ = 24;
    break;
   case 20:
    var $ac_idx4_val = HEAP32[$ac >> 2];
    __ZN22JSAutoEnterCompartmentD1Ev($ac_idx4_val);
    var $_1 = 0;
    __label__ = 24;
    break;
   case 21:
    var $ac_idx3_val = HEAP32[$ac >> 2];
    __ZN22JSAutoEnterCompartmentD1Ev($ac_idx3_val);
    var $_1 = 0;
    __label__ = 24;
    break;
   case 22:
    var $ac_idx2_val = HEAP32[$ac >> 2];
    __ZN22JSAutoEnterCompartmentD1Ev($ac_idx2_val);
    var $_1 = 0;
    __label__ = 24;
    break;
   case 23:
    var $ac_idx_val = HEAP32[$ac >> 2];
    __ZN22JSAutoEnterCompartmentD1Ev($ac_idx_val);
    var $_1 = 0;
    __label__ = 24;
    break;
   case 24:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15NewGlobalObjectP9JSContext15CompartmentKind["X"] = 1;

function __ZL7VersionP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $vp + 16 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = _JSVAL_IS_VOID595($6$0, $6$1);
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = _JS_GetVersion($cx);
    _INT_TO_JSVAL592($1, $10);
    var $11 = $1 | 0;
    var $st$3$0 = $11 | 0;
    var $12$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $11 + 4 | 0;
    var $12$1 = HEAP32[$st$3$1 >> 2];
    var $13 = $vp | 0;
    var $st$8$0 = $13 | 0;
    HEAP32[$st$8$0 >> 2] = $12$0;
    var $st$8$1 = $13 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 4:
    var $st$0$0 = $5 | 0;
    var $15$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5 + 4 | 0;
    var $15$1 = HEAP32[$st$0$1 >> 2];
    var $16 = _JSVAL_IS_INT622($15$0, $15$1);
    var $18$0 = HEAP32[$5 >> 2];
    var $18$1 = HEAP32[$5 + 4 >> 2];
    if (($16 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = _JSVAL_TO_INT623($18$0, $18$1);
    var $v_0 = $20;
    __label__ = 8;
    break;
   case 6:
    var $22 = _JSVAL_IS_DOUBLE645($18$0, $18$1);
    if (($22 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $st$0$0 = $5 | 0;
    var $25$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5 + 4 | 0;
    var $25$1 = HEAP32[$st$0$1 >> 2];
    var $26 = _JSVAL_TO_DOUBLE646($25$0, $25$1);
    var $27 = $26 & -1;
    if (($27 | 0) == $26) {
      var $v_0 = $27;
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $v_0;
    if ($v_0 >>> 0 > 185) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 286, 12, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str8301 | 0, tempInt));
    var $_0 = 0;
    __label__ = 11;
    break;
   case 10:
    var $33 = _JS_SetVersion($cx, $v_0);
    _INT_TO_JSVAL592($2, $33);
    var $34 = $2 | 0;
    var $st$3$0 = $34 | 0;
    var $35$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $34 + 4 | 0;
    var $35$1 = HEAP32[$st$3$1 >> 2];
    var $36 = $vp | 0;
    var $st$8$0 = $36 | 0;
    HEAP32[$st$8$0 >> 2] = $35$0;
    var $st$8$1 = $36 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $35$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL7VersionP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL13RevertVersionP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = $cx;
  _js_RevertVersion($1);
  var $$emscripten$temp$0 = _JSVAL_VOID | 0;
  var $2$0 = HEAP32[$$emscripten$temp$0 >> 2];
  var $2$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
  var $3 = $vp | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  return 1;
}

function __ZL7OptionsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $opt = __stackBase__ + 8;
    var $2 = __stackBase__ + 12;
    var $3 = $1 | 0;
    var $4 = $cx;
    var $opt_idx3 = $opt | 0;
    var $i_0 = 0;
    var $optset_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $optset_0;
    var $i_0;
    if ($i_0 >>> 0 < $argc >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    var $8 = $vp + ($i_0 + 2 << 3) | 0;
    var $st$2$0 = $8 | 0;
    var $9$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $8 + 4 | 0;
    var $9$1 = HEAP32[$st$2$1 >> 2];
    var $10 = _JS_ValueToString($cx, $9$0, $9$1);
    if (($10 | 0) == 0) {
      var $_2 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _STRING_TO_JSVAL599($1, $10);
    var $13$0 = HEAP32[$3 >> 2];
    var $13$1 = HEAP32[$3 + 4 >> 2];
    HEAP32[$8 >> 2] = $13$0;
    HEAP32[$8 + 4 >> 2] = $13$1;
    __ZN16JSAutoByteStringC1EP9JSContextP8JSString($opt, $4, $10);
    var $opt_idx3_val = HEAP32[$opt_idx3 >> 2];
    var $14 = __ZNK16JSAutoByteStringntEv($opt_idx3_val);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = __ZNK16JSAutoByteString3ptrEv($opt_idx3_val);
    var $17 = __ZL26MapContextOptionNameToFlagP9JSContextPKc($cx, $16);
    if (($17 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN16JSAutoByteStringD1Ev($opt_idx3_val);
    var $_2 = 0;
    __label__ = 19;
    break;
   case 7:
    var $20 = $17 | $optset_0;
    __ZN16JSAutoByteStringD1Ev($opt_idx3_val);
    var $i_0 = $i_0 + 1 | 0;
    var $optset_0 = $20;
    __label__ = 2;
    break;
   case 8:
    var $23 = _JS_ToggleOptions($cx, $optset_0);
    var $i1_0 = 0;
    var $found_0 = 0;
    var $names_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $names_0;
    var $found_0;
    var $i1_0;
    if (($i1_0 | 0) == 10) {
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ((HEAP32[__ZL10js_options + ($i1_0 << 3) + 4 >> 2] & $23 | 0) == 0) {
      var $found_1 = $found_0;
      var $names_1 = $names_0;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $33 = ($names_0 | 0) != 0 ? STRING_TABLE.__str288581 | 0 : __str17668 | 0;
    var $35 = HEAP32[__ZL10js_options + ($i1_0 << 3) >> 2];
    var $36 = _JS_sprintf_append($names_0, STRING_TABLE.__str283576 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $33, HEAP32[tempInt + 4 >> 2] = $35, tempInt));
    if (($36 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      var $found_1 = 1;
      var $names_1 = $36;
      __label__ = 12;
      break;
    }
   case 12:
    var $names_1;
    var $found_1;
    var $i1_0 = $i1_0 + 1 | 0;
    var $found_0 = $found_1;
    var $names_0 = $names_1;
    __label__ = 9;
    break;
   case 13:
    if (($found_0 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      var $names_3 = $names_0;
      __label__ = 15;
      break;
    }
   case 14:
    var $43 = _strdup(__str17668 | 0);
    var $names_3 = $43;
    __label__ = 15;
    break;
   case 15:
    var $names_3;
    if (($names_3 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportOutOfMemory($cx);
    var $_2 = 0;
    __label__ = 19;
    break;
   case 17:
    var $47 = _JS_NewStringCopyZ($cx, $names_3);
    _free($names_3);
    if (($47 | 0) == 0) {
      var $_2 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    _STRING_TO_JSVAL599($2, $47);
    var $50 = $2 | 0;
    var $st$2$0 = $50 | 0;
    var $51$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $50 + 4 | 0;
    var $51$1 = HEAP32[$st$2$1 >> 2];
    var $52 = $vp | 0;
    HEAP32[$52 >> 2] = $51$0;
    HEAP32[$52 + 4 >> 2] = $51$1;
    var $_2 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL7OptionsP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL4LoadP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $filename = __stackBase__ + 16;
    _JS_THIS644($1, $cx, $vp);
    var $_idx = $1 | 0;
    var $st$5$0 = $_idx | 0;
    var $_idx_val$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAP32[$st$5$1 >> 2];
    var $3 = _JSVAL_TO_OBJECT590($_idx_val$0, $_idx_val$1);
    if (($3 | 0) == 0) {
      var $_2 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 | 0;
    var $6 = $cx;
    var $filename_idx4 = $filename | 0;
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    if ($i_0 >>> 0 < $argc >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    var $10 = $vp + ($i_0 + 2 << 3) | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = _JS_ValueToString($cx, $11$0, $11$1);
    if (($12 | 0) == 0) {
      var $_2 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _STRING_TO_JSVAL599($2, $12);
    var $st$1$0 = $5 | 0;
    var $15$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $5 + 4 | 0;
    var $15$1 = HEAP32[$st$1$1 >> 2];
    var $st$5$0 = $10 | 0;
    HEAP32[$st$5$0 >> 2] = $15$0;
    var $st$5$1 = $10 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $15$1;
    __ZN16JSAutoByteStringC1EP9JSContextP8JSString($filename, $6, $12);
    var $filename_idx4_val = HEAPU32[$filename_idx4 >> 2];
    var $16 = __ZNK16JSAutoByteStringntEv($filename_idx4_val);
    if ($16) {
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = ___errno();
    HEAP32[$18 >> 2] = 0;
    var $19 = _JS_GetOptions($cx);
    var $20 = $19 | 4112;
    _JS_SetOptions($cx, $20);
    var $21 = __ZNK16JSAutoByteString3ptrEv($filename_idx4_val);
    var $22 = _JS_CompileFile($cx, $3, $21);
    _JS_SetOptions($cx, $19);
    if (($22 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = _JS_ExecuteScript($cx, $3, $22, 0);
    var $26 = ($25 | 0) == 0;
    __ZN16JSAutoByteStringD1Ev($filename_idx4_val);
    if ($26) {
      var $_2 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 3;
    break;
   case 9:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $30$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $30$1 = HEAP32[$st$1$1 >> 2];
    var $31 = $vp | 0;
    HEAP32[$31 >> 2] = $30$0;
    HEAP32[$31 + 4 >> 2] = $30$1;
    var $_2 = 1;
    __label__ = 12;
    break;
   case 10:
    __ZN16JSAutoByteStringD1Ev($filename_idx4_val);
    var $_2 = 0;
    __label__ = 12;
    break;
   case 11:
    __ZN16JSAutoByteStringD1Ev($filename_idx4_val);
    var $_2 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL4LoadP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL8EvaluateP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $codeLength = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = ($argc | 0) != 1;
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $vp + 16 | 0;
    var $st$1$0 = $4 | 0;
    var $5$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $4 + 4 | 0;
    var $5$1 = HEAP32[$st$1$1 >> 2];
    var $6 = _JSVAL_IS_STRING593($5$0, $5$1);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = $2 ? 8 : 12;
    _JS_ReportErrorNumber($cx, 286, $9, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str12305 | 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 4:
    var $11$0 = HEAP32[$4 >> 2];
    var $11$1 = HEAP32[$4 + 4 >> 2];
    var $12 = _JSVAL_TO_STRING594($11$0, $11$1);
    var $13 = _JS_GetStringCharsAndLength($cx, $12, $codeLength);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _JS_THIS644($1, $cx, $vp);
    var $_idx1 = $1 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $16 = _JSVAL_TO_OBJECT590($_idx1_val$0, $_idx1_val$1);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx_val = HEAP32[$16 + 4 >> 2];
    var $19 = _JS_GetClass($_idx_val);
    if ((HEAP32[$19 + 4 >> 2] & 262144 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 4, 222, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = STRING_TABLE.__str285578 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str286579 | 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 8:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $26$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $26$1 = HEAP32[$st$1$1 >> 2];
    var $27 = $vp | 0;
    HEAP32[$27 >> 2] = $26$0;
    HEAP32[$27 + 4 >> 2] = $26$1;
    var $28 = HEAP32[$codeLength >> 2];
    var $29 = _JS_EvaluateUCScript($cx, $16, $13, $28, STRING_TABLE.__str287580 | 0, 0, 0);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL8EvaluateP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL3RunP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $filename = __stackBase__ + 16;
    var $buflen = __stackBase__ + 20;
    var $a_str = __stackBase__ + 24;
    var $3 = __stackBase__ + 28;
    if (($argc | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 286, 12, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str13306 | 0, tempInt));
    var $_2 = 0;
    __label__ = 12;
    break;
   case 3:
    _JS_THIS644($1, $cx, $vp);
    var $_idx = $1 | 0;
    var $st$2$0 = $_idx | 0;
    var $_idx_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAP32[$st$2$1 >> 2];
    var $7 = _JSVAL_TO_OBJECT590($_idx_val$0, $_idx_val$1);
    if (($7 | 0) == 0) {
      var $_2 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $vp + 16 | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = _JS_ValueToString($cx, $11$0, $11$1);
    if (($12 | 0) == 0) {
      var $_2 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _STRING_TO_JSVAL599($2, $12);
    var $15 = $2 | 0;
    var $st$2$0 = $15 | 0;
    var $16$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $15 + 4 | 0;
    var $16$1 = HEAP32[$st$2$1 >> 2];
    HEAP32[$10 >> 2] = $16$0;
    HEAP32[$10 + 4 >> 2] = $16$1;
    var $17 = $cx;
    __ZN16JSAutoByteStringC1EP9JSContextP8JSString($filename, $17, $12);
    var $filename_idx3_val = HEAP32[$filename >> 2];
    var $18 = __ZNK16JSAutoByteStringntEv($filename_idx3_val);
    if ($18) {
      var $_1 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = __ZNK16JSAutoByteString3ptrEv($filename_idx3_val);
    var $21 = __ZL12FileAsStringP9JSContextPKc($cx, $20);
    if (($21 | 0) == 0) {
      var $_1 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = _JS_GetStringCharsAndLength($cx, $21, $buflen);
    if (($24 | 0) == 0) {
      var $_1 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2JS6AnchorIP8JSStringEC1ES2_($a_str, $21);
    var $27 = _JS_GetOptions($cx);
    var $28 = $27 | 4112;
    _JS_SetOptions($cx, $28);
    var $29 = _PRMJ_Now();
    var $29$0 = $29[0];
    var $29$1 = $29[1];
    var $30 = HEAP32[$buflen >> 2];
    var $31 = _JS_CompileUCScript($cx, $7, $24, $30, $20, 1);
    _JS_SetOptions($cx, $27);
    if (($31 | 0) == 0) {
      var $_1 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $34 = _JS_ExecuteScript($cx, $7, $31, 0);
    if (($34 | 0) == 0) {
      var $_1 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $37 = _PRMJ_Now();
    var $37$0 = $37[0];
    var $37$1 = $37[1];
    var $38$0 = (i64Math.subtract($37$0, $37$1, $29$0, $29$1), i64Math.result[0]);
    var $38$1 = i64Math.result[1];
    var $40 = ($38$0 + $38$1 * 4294967296) / 1e3;
    _DOUBLE_TO_JSVAL632($3, $40);
    var $41 = $3 | 0;
    var $42$0 = HEAP32[$41 >> 2];
    var $42$1 = HEAP32[$41 + 4 >> 2];
    var $43 = $vp | 0;
    HEAP32[$43 >> 2] = $42$0;
    HEAP32[$43 + 4 >> 2] = $42$1;
    var $_1 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_1;
    __ZN16JSAutoByteStringD1Ev($filename_idx3_val);
    var $_2 = $_1;
    __label__ = 12;
    break;
   case 12:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL3RunP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL8ReadLineP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = HEAP32[_stdin >> 2];
    var $4 = $3;
    var $5 = _JS_malloc($cx, 256);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      var $buflength_0 = 0;
      var $bufsize_0 = 256;
      var $buf_0 = $5;
      __label__ = 2;
      break;
    }
   case 2:
    var $buf_0;
    var $bufsize_0;
    var $buflength_0;
    var $9 = __Z8js_fgetsPciP7__sFILE($buf_0 + $buflength_0 | 0, $bufsize_0 - $buflength_0 | 0, $3);
    if (($9 | 0) == 0) {
      var $sawNewline_0 = 0;
      var $buflength_1 = $buflength_0;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $9 + $buflength_0 | 0;
    var $14 = $buf_0 + ($12 - 1) | 0;
    if (HEAP8[$14] << 24 >> 24 == 10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP8[$14] = 0;
    var $sawNewline_0 = -1;
    var $buflength_1 = $12;
    __label__ = 10;
    break;
   case 5:
    if ($12 >>> 0 < ($bufsize_0 - 1 | 0) >>> 0) {
      var $sawNewline_0 = 0;
      var $buflength_1 = $12;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = $bufsize_0 << 1;
    if ($22 >>> 0 > $12 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportOutOfMemory($cx);
    __label__ = 9;
    break;
   case 8:
    var $25 = _JS_realloc($cx, $buf_0, $22);
    if (($25 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $buflength_0 = $12;
      var $bufsize_0 = $22;
      var $buf_0 = $25;
      __label__ = 2;
      break;
    }
   case 9:
    _JS_free($buf_0);
    var $_0 = 0;
    __label__ = 19;
    break;
   case 10:
    var $buflength_1;
    var $sawNewline_0;
    if (($buflength_1 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 11:
    var $29 = _feof($4);
    if (($29 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $32$0 = HEAPU32[$$emscripten$temp$0 >> 2];
    var $32$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $33 = $1 | 0;
    var $st$6$0 = $33 | 0;
    HEAP32[$st$6$0 >> 2] = $32$0;
    var $st$6$1 = $33 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $32$1;
    var $36$1 = $32$1;
    var $36$0 = $32$0;
    __label__ = 14;
    break;
   case 13:
    var $cx_idx_val_idx_val = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2];
    _JS_GetEmptyStringValue($1, $cx_idx_val_idx_val);
    var $_phi_trans_insert = $1 | 0;
    var $st$6$0 = $_phi_trans_insert | 0;
    var $st$6$1 = $_phi_trans_insert + 4 | 0;
    var $36$1 = HEAP32[$st$6$1 >> 2];
    var $36$0 = HEAP32[$st$6$0 >> 2];
    __label__ = 14;
    break;
   case 14:
    var $36$0;
    var $36$1;
    var $37 = $vp | 0;
    HEAP32[$37 >> 2] = $36$0;
    HEAP32[$37 + 4 >> 2] = $36$1;
    _JS_free($buf_0);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 15:
    var $39 = _JS_realloc($cx, $buf_0, $buflength_1);
    if (($39 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_free($buf_0);
    var $_0 = 0;
    __label__ = 19;
    break;
   case 17:
    var $44 = _JS_NewStringCopyN($cx, $39, $sawNewline_0 + $buflength_1 | 0);
    _JS_free($39);
    if (($44 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    _STRING_TO_JSVAL599($2, $44);
    var $47 = $2 | 0;
    var $48$0 = HEAP32[$47 >> 2];
    var $48$1 = HEAP32[$47 + 4 >> 2];
    var $49 = $vp | 0;
    HEAP32[$49 >> 2] = $48$0;
    HEAP32[$49 + 4 >> 2] = $48$1;
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL8ReadLineP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL5PrintP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if ($i_0 >>> 0 < $argc >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $4 = $vp + ($i_0 + 2 << 3) | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = _JS_ValueToString($cx, $5$0, $5$1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _JS_EncodeString($cx, $6);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = HEAP32[_gOutFile >> 2];
    var $14 = ($i_0 | 0) != 0 ? STRING_TABLE.__str284577 | 0 : __str17668 | 0;
    var $15 = _fprintf($12, STRING_TABLE.__str283576 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $14, HEAP32[tempInt + 4 >> 2] = $9, tempInt));
    _JS_free($9);
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 6:
    var $19 = HEAP32[_gOutFile >> 2];
    var $20 = _fputc(10, $19);
    var $21 = HEAP32[_gOutFile >> 2];
    var $22 = _fflush($21);
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $23$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $23$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $24 = $vp | 0;
    HEAP32[$24 >> 2] = $23$0;
    HEAP32[$24 + 4 >> 2] = $23$1;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL6PutStrP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($argc | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $vp + 16 | 0;
    var $st$1$0 = $3 | 0;
    var $4$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $3 + 4 | 0;
    var $4$1 = HEAP32[$st$1$1 >> 2];
    var $5 = _JS_ValueToString($cx, $4$0, $4$1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = _JS_EncodeString($cx, $5);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = HEAP32[_gOutFile >> 2];
    var $12 = _fputs($8, $11);
    _JS_free($8);
    var $13 = HEAP32[_gOutFile >> 2];
    var $14 = _fflush($13);
    __label__ = 5;
    break;
   case 5:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $16$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $16$1 = HEAP32[$st$1$1 >> 2];
    var $17 = $vp | 0;
    HEAP32[$17 >> 2] = $16$0;
    HEAP32[$17 + 4 >> 2] = $16$1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL3NowP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = _PRMJ_Now();
  var $4 = ($2[0] + $2[1] * 4294967296) / 1e3;
  _DOUBLE_TO_JSVAL632($1, $4);
  var $5 = $1 | 0;
  var $6$0 = HEAP32[$5 >> 2];
  var $6$1 = HEAP32[$5 + 4 >> 2];
  var $7 = $vp | 0;
  HEAP32[$7 >> 2] = $6$0;
  HEAP32[$7 + 4 >> 2] = $6$1;
  STACKTOP = __stackBase__;
  return 1;
}

function __ZL4HelpP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $funcName = __stackBase__;
    var $1 = HEAP32[_gOutFile >> 2];
    var $2 = _fprintf($1, STRING_TABLE.__str124417 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str21214 | 0, tempInt));
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $funcName_idx4 = $funcName | 0;
    var $i_1 = 0;
    var $did_header_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $6 = HEAP32[_gOutFile >> 2];
    var $7 = _fwrite(STRING_TABLE.__ZL17shell_help_header | 0, 74, 1, $6);
    var $i_011 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_011;
    var $9 = HEAP32[_gOutFile >> 2];
    var $11 = HEAP32[__ZL19shell_help_messages + ($i_011 << 2) >> 2];
    var $12 = _fprintf($9, STRING_TABLE.__str124417 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $11, tempInt));
    var $13 = $i_011 + 1 | 0;
    if (($13 | 0) == 57) {
      __label__ = 24;
      break;
    } else {
      var $i_011 = $13;
      __label__ = 4;
      break;
    }
   case 5:
    var $did_header_0;
    var $i_1;
    if ($i_1 >>> 0 < $argc >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 6:
    var $17 = $vp + ($i_1 + 2 << 3) | 0;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    var $19 = _JS_TypeOfValue($cx, $18$0, $18$1);
    if (($19 | 0) == 2) {
      __label__ = 7;
      break;
    } else if (($19 | 0) == 3) {
      __label__ = 8;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 7:
    var $st$0$0 = $17 | 0;
    var $21$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $17 + 4 | 0;
    var $21$1 = HEAP32[$st$0$1 >> 2];
    var $22 = _JS_ValueToFunction($cx, $21$0, $21$1);
    var $str_0 = HEAP32[$22 + 72 >> 2] | 0;
    __label__ = 9;
    break;
   case 8:
    var $st$0$0 = $17 | 0;
    var $27$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $17 + 4 | 0;
    var $27$1 = HEAP32[$st$0$1 >> 2];
    var $28 = _JSVAL_TO_STRING594($27$0, $27$1);
    var $str_0 = $28;
    __label__ = 9;
    break;
   case 9:
    var $str_0;
    if (($str_0 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN16JSAutoByteStringC1EP9JSContextP8JSString($funcName, $4, $str_0);
    var $funcName_idx4_val = HEAPU32[$funcName_idx4 >> 2];
    var $32 = __ZNK16JSAutoByteStringntEv($funcName_idx4_val);
    if ($32) {
      __label__ = 19;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $str_0_idx = $str_0 | 0;
    var $j_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $j_0;
    if ($j_0 >>> 0 < 57) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    __ZN16JSAutoByteStringD1Ev($funcName_idx4_val);
    __label__ = 21;
    break;
   case 14:
    var $36 = HEAPU32[__ZL19shell_help_messages + ($j_0 << 2) >> 2];
    var $37 = _strchr($36, 40);
    var $40 = $37 - $36 | 0;
    var $str_0_idx_val = HEAP32[$str_0_idx >> 2];
    var $41 = __ZNK8JSString6lengthEv($str_0_idx_val);
    if (($40 | 0) == ($41 | 0)) {
      __label__ = 15;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 15:
    var $44 = __ZNK16JSAutoByteString3ptrEv($funcName_idx4_val);
    var $45 = _strncmp($44, $36, $40);
    if (($45 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 16:
    if (($did_header_0 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $did_header_1 = $did_header_0;
      __label__ = 20;
      break;
    }
   case 17:
    var $50 = HEAP32[_gOutFile >> 2];
    var $51 = _fwrite(STRING_TABLE.__ZL17shell_help_header | 0, 74, 1, $50);
    var $did_header_1 = 1;
    __label__ = 20;
    break;
   case 18:
    var $j_0 = $j_0 + 1 | 0;
    __label__ = 12;
    break;
   case 19:
    __ZN16JSAutoByteStringD1Ev($funcName_idx4_val);
    var $_3 = 0;
    __label__ = 25;
    break;
   case 20:
    var $did_header_1;
    var $56 = HEAP32[_gOutFile >> 2];
    var $57 = _fprintf($56, STRING_TABLE.__str124417 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $36, tempInt));
    __ZN16JSAutoByteStringD1Ev($funcName_idx4_val);
    var $did_header_45 = $did_header_1;
    __label__ = 23;
    break;
   case 21:
    var $st$0$0 = $17 | 0;
    var $58$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $17 + 4 | 0;
    var $58$1 = HEAP32[$st$0$1 >> 2];
    var $59 = _JS_ValueToString($cx, $58$0, $58$1);
    if (($59 | 0) == 0) {
      var $_3 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $62 = HEAP32[_gErrFile >> 2];
    var $63 = _fwrite(STRING_TABLE.__str163456 | 0, 19, 1, $62);
    var $65 = HEAP32[_gErrFile >> 2];
    _JS_FileEscapedString($65, $59);
    var $66 = HEAP32[_gErrFile >> 2];
    var $67 = _putc(10, $66);
    var $did_header_45 = $did_header_0;
    __label__ = 23;
    break;
   case 23:
    var $did_header_45;
    var $i_1 = $i_1 + 1 | 0;
    var $did_header_0 = $did_header_45;
    __label__ = 5;
    break;
   case 24:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $70$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $70$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $71 = $vp | 0;
    HEAP32[$71 >> 2] = $70$0;
    HEAP32[$71 + 4 >> 2] = $70$1;
    var $_3 = 1;
    __label__ = 25;
    break;
   case 25:
    var $_3;
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL4HelpP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL4QuitP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  var $1 = $vp + 16 | 0;
  var $2 = _JS_ConvertArguments($cx, $argc, $1, STRING_TABLE.__str282575 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = _gExitCode, tempInt));
  HEAP8[_gQuitting_b] = 1;
  STACKTOP = __stackBase__;
  return 0;
}

function __ZL9AssertJitP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $$emscripten$temp$0 = _JSVAL_VOID | 0;
  var $1$0 = HEAP32[$$emscripten$temp$0 >> 2];
  var $1$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
  var $2 = $vp | 0;
  HEAP32[$2 >> 2] = $1$0;
  HEAP32[$2 + 4 >> 2] = $1$1;
  return 1;
}

function __ZL8AssertEqP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $same = __stackBase__;
    var $bytes0 = __stackBase__ + 4;
    var $bytes1 = __stackBase__ + 8;
    var $bytes2 = __stackBase__ + 12;
    var $1 = ($argc | 0) == 2;
    if ($1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = ($argc | 0) == 3;
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = $vp + 32 | 0;
    var $st$1$0 = $5 | 0;
    var $6$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $5 + 4 | 0;
    var $6$1 = HEAP32[$st$1$1 >> 2];
    var $7 = _JSVAL_IS_STRING593($6$0, $6$1);
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    if ($argc >>> 0 < 2) {
      var $13 = 8;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = $3 ? 12 : 9;
    var $13 = $11;
    __label__ = 6;
    break;
   case 6:
    var $13;
    _JS_ReportErrorNumber($cx, 286, $13, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str20313 | 0, tempInt));
    var $_2 = 0;
    __label__ = 16;
    break;
   case 7:
    var $15 = $vp + 16 | 0;
    var $16 = $15 | 0;
    var $17$0 = HEAP32[$16 >> 2];
    var $17$1 = HEAP32[$16 + 4 >> 2];
    var $18 = $vp + 24 | 0;
    var $19 = $18 | 0;
    var $20$0 = HEAP32[$19 >> 2];
    var $20$1 = HEAP32[$19 + 4 >> 2];
    var $21 = _JS_SameValue($cx, $17$0, $17$1, $20$0, $20$1, $same);
    if (($21 | 0) == 0) {
      var $_2 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((HEAP32[$same >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 9:
    __ZN16JSAutoByteStringC1Ev($bytes0);
    __ZN16JSAutoByteStringC1Ev($bytes1);
    var $27 = __ZL8ToSourceP9JSContextPN2JS5ValueEP16JSAutoByteString($cx, $15, $bytes0);
    var $28 = __ZL8ToSourceP9JSContextPN2JS5ValueEP16JSAutoByteString($cx, $18, $bytes1);
    if ($1) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    _JS_ReportErrorNumber($cx, 286, 10, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $27, HEAP32[tempInt + 4 >> 2] = $28, tempInt));
    __label__ = 14;
    break;
   case 11:
    var $31 = $vp + 32 | 0;
    var $st$1$0 = $31 | 0;
    var $32$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $31 + 4 | 0;
    var $32$1 = HEAP32[$st$1$1 >> 2];
    var $33 = _JSVAL_TO_STRING594($32$0, $32$1);
    var $34 = $cx;
    __ZN16JSAutoByteStringC1EP9JSContextP8JSString($bytes2, $34, $33);
    var $bytes2_idx3_val = HEAP32[$bytes2 >> 2];
    var $35 = __ZNK16JSAutoByteStringntEv($bytes2_idx3_val);
    if ($35) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $36 = __ZNK16JSAutoByteString3ptrEv($bytes2_idx3_val);
    _JS_ReportErrorNumber($cx, 286, 11, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $27, HEAP32[tempInt + 4 >> 2] = $28, HEAP32[tempInt + 8 >> 2] = $36, tempInt));
    __ZN16JSAutoByteStringD1Ev($bytes2_idx3_val);
    __label__ = 14;
    break;
   case 13:
    __ZN16JSAutoByteStringD1Ev($bytes2_idx3_val);
    __label__ = 14;
    break;
   case 14:
    var $bytes1_idx_val = HEAP32[$bytes1 >> 2];
    __ZN16JSAutoByteStringD1Ev($bytes1_idx_val);
    var $bytes0_idx_val = HEAP32[$bytes0 >> 2];
    __ZN16JSAutoByteStringD1Ev($bytes0_idx_val);
    var $_2 = 0;
    __label__ = 16;
    break;
   case 15:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $40$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $40$1 = HEAP32[$st$1$1 >> 2];
    var $41 = $vp | 0;
    HEAP32[$41 >> 2] = $40$0;
    HEAP32[$41 + 4 >> 2] = $40$1;
    var $_2 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL8AssertEqP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL2GCP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 264;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $buf = __stackBase__;
    var $1 = __stackBase__ + 256;
    if (($argc | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      var $comp_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = $vp + 16 | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = __ZNK2JS5Value8isObjectEv($5$0, $5$1);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $comp_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZNK2JS5Value8toObjectEv($5$0, $5$1);
    var $9 = __ZN8JSObject6unwrapEPj($8, 0);
    var $10 = $9;
    var $11 = __ZNK2js2gc4Cell11compartmentEv($10);
    var $comp_0 = $11;
    __label__ = 4;
    break;
   case 4:
    var $comp_0;
    var $13 = $cx + 52 | 0;
    var $16 = HEAP32[HEAP32[$13 >> 2] + 140 >> 2];
    _JS_CompartmentGC($cx, $comp_0);
    var $17 = $buf | 0;
    var $20 = HEAP32[HEAP32[$13 >> 2] + 140 >> 2];
    var $21 = _sbrk(0);
    var $22 = $21;
    var $23 = _JS_snprintf($17, 256, STRING_TABLE.__str280573 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $16, HEAP32[tempInt + 4 >> 2] = $20, HEAP32[tempInt + 8 >> 2] = $22, tempInt));
    var $24 = _JS_NewStringCopyZ($cx, $17);
    _STRING_TO_JSVAL599($1, $24);
    var $25 = $1 | 0;
    var $26$0 = HEAP32[$25 >> 2];
    var $26$1 = HEAP32[$25 + 4 >> 2];
    var $27 = $vp | 0;
    HEAP32[$27 >> 2] = $26$0;
    HEAP32[$27 + 4 >> 2] = $26$1;
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11GCParameterP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $value1 = __stackBase__ + 8;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $4$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $4$1 = HEAP32[$st$1$1 >> 2];
    var $5 = _JS_ValueToString($cx, $4$0, $4$1);
    var $str_0 = $5;
    __label__ = 5;
    break;
   case 3:
    var $7 = $vp + 16 | 0;
    var $st$1$0 = $7 | 0;
    var $8$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $7 + 4 | 0;
    var $8$1 = HEAP32[$st$1$1 >> 2];
    var $9 = _JS_ValueToString($cx, $8$0, $8$1);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _STRING_TO_JSVAL599($1, $9);
    var $12 = $1 | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    HEAP32[$7 >> 2] = $13$0;
    HEAP32[$7 + 4 >> 2] = $13$1;
    var $str_0 = $9;
    __label__ = 5;
    break;
   case 5:
    var $str_0;
    var $15 = _JS_FlattenString($cx, $str_0);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      var $paramIndex_0 = 0;
      __label__ = 6;
      break;
    }
   case 6:
    var $paramIndex_0;
    if (($paramIndex_0 | 0) == 5) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    _JS_ReportError($cx, STRING_TABLE.__str277570 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 17;
    break;
   case 8:
    var $21 = HEAPU32[__ZZL11GCParameterP9JSContextjPN2JS5ValueEE8paramMap + ($paramIndex_0 << 3) >> 2];
    var $22 = _JS_FlatStringEqualsAscii($15, $21);
    if (($22 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $paramIndex_0 = $paramIndex_0 + 1 | 0;
    __label__ = 6;
    break;
   case 10:
    var $28 = HEAPU32[__ZZL11GCParameterP9JSContextjPN2JS5ValueEE8paramMap + ($paramIndex_0 << 3) + 4 >> 2];
    if (($argc | 0) == 1) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $32 = HEAP32[$cx + 52 >> 2];
    var $33 = _JS_GetGCParameter($32, $28);
    var $34 = $33 >>> 0;
    _JS_NewNumberValue($34, $vp);
    var $_0 = 1;
    __label__ = 17;
    break;
   case 12:
    if (($paramIndex_0 - 3 | 0) >>> 0 < 2) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    _JS_ReportError($cx, STRING_TABLE.__str278571 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $21, tempInt));
    var $_0 = 0;
    __label__ = 17;
    break;
   case 14:
    var $39 = $vp + 24 | 0;
    var $st$1$0 = $39 | 0;
    var $40$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $39 + 4 | 0;
    var $40$1 = HEAP32[$st$1$1 >> 2];
    var $41 = _JS_ValueToECMAUint32($cx, $40$0, $40$1, $value1);
    if (($41 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    _JS_ReportError($cx, STRING_TABLE.__str279572 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 17;
    break;
   case 16:
    var $46 = HEAP32[$cx + 52 >> 2];
    var $47 = HEAP32[$value1 >> 2];
    _JS_SetGCParameter($46, $28, $47);
    var $$emscripten$temp$1 = _JSVAL_VOID | 0;
    var $48$0 = HEAP32[$$emscripten$temp$1 >> 2];
    var $48$1 = HEAP32[$$emscripten$temp$1 + 4 >> 2];
    var $49 = $vp | 0;
    HEAP32[$49 >> 2] = $48$0;
    HEAP32[$49 + 4 >> 2] = $48$1;
    var $_0 = 1;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11GCParameterP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL9CountHeapP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $countTracer = __stackBase__;
    var $bytes = __stackBase__ + 68;
    if (($argc | 0) == 0) {
      var $traceKind_0 = -1;
      var $startTraceKind_015 = 0;
      var $startThing_016 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_06 = $vp + 16 | 0;
    var $st$1$0 = $_06 | 0;
    var $tmp$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_06 + 4 | 0;
    var $tmp$1 = HEAP32[$st$1$1 >> 2];
    var $3 = _JSVAL_IS_TRACEABLE633($tmp$0, $tmp$1);
    if (($3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = _JSVAL_TO_TRACEABLE($tmp$0, $tmp$1);
    var $7 = _JSVAL_TRACE_KIND634($tmp$0, $tmp$1);
    var $startThing_0 = $6;
    var $startTraceKind_0 = $7;
    __label__ = 6;
    break;
   case 4:
    var $9 = _JSVAL_IS_NULL635($tmp$0, $tmp$1);
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $startThing_0 = 0;
      var $startTraceKind_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    _JS_ReportError($cx, STRING_TABLE.__str270563 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 29;
    break;
   case 6:
    var $startTraceKind_0;
    var $startThing_0;
    if ($argc >>> 0 > 1) {
      __label__ = 7;
      break;
    } else {
      var $traceKind_0 = -1;
      var $startTraceKind_015 = $startTraceKind_0;
      var $startThing_016 = $startThing_0;
      __label__ = 14;
      break;
    }
   case 7:
    var $15 = $vp + 24 | 0;
    var $st$1$0 = $15 | 0;
    var $16$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $15 + 4 | 0;
    var $16$1 = HEAP32[$st$1$1 >> 2];
    var $17 = _JS_ValueToString($cx, $16$0, $16$1);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = _JS_FlattenString($cx, $17);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $22 = _JS_FlatStringEqualsAscii($20, STRING_TABLE.__str266559 | 0);
    if (($22 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $i_0_lcssa = 0;
      __label__ = 10;
      break;
    }
   case 10:
    var $i_0_lcssa;
    var $traceKind_0 = HEAP32[__ZZL9CountHeapP9JSContextjPN2JS5ValueEE14traceKindNames + ($i_0_lcssa << 3) + 4 >> 2];
    var $startTraceKind_015 = $startTraceKind_0;
    var $startThing_016 = $startThing_0;
    __label__ = 14;
    break;
   case 11:
    var $28 = _JS_FlatStringEqualsAscii($20, STRING_TABLE.__str267560 | 0);
    if (($28 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      var $i_0_lcssa = 1;
      __label__ = 10;
      break;
    }
   case 12:
    var $31 = __ZNK16JSAutoByteString3ptrEv($bytes_idx2_val);
    _JS_ReportError($cx, STRING_TABLE.__str271564 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $31, tempInt));
    __label__ = 13;
    break;
   case 13:
    __ZN16JSAutoByteStringD1Ev($bytes_idx2_val);
    var $_0 = 0;
    __label__ = 29;
    break;
   case 14:
    var $startThing_016;
    var $startTraceKind_015;
    var $traceKind_0;
    var $33 = $countTracer | 0;
    HEAP32[$countTracer >> 2] = $cx;
    HEAP32[$countTracer + 4 >> 2] = 292;
    HEAP32[$countTracer + 8 >> 2] = 0;
    HEAP32[$countTracer + 12 >> 2] = 0;
    HEAP32[$countTracer + 16 >> 2] = -1;
    HEAP32[$countTracer + 20 >> 2] = 1;
    var $41 = $countTracer + 24 | 0;
    var $42 = _JS_DHashTableInit($41, 8, 134);
    if (($42 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    _JS_ReportOutOfMemory($cx);
    var $_0 = 0;
    __label__ = 29;
    break;
   case 16:
    var $46 = $countTracer + 56 | 0;
    HEAP32[$46 >> 2] = 1;
    var $47 = $countTracer + 60 | 0;
    HEAP32[$47 >> 2] = 0;
    var $48 = $countTracer + 64 | 0;
    HEAP32[$48 >> 2] = 0;
    if (($startThing_016 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    _JS_TraceRuntime($33);
    __label__ = 19;
    break;
   case 18:
    _JS_CallTracer($33, $startThing_016, $startTraceKind_015);
    __label__ = 19;
    break;
   case 19:
    var $52 = HEAP32[$47 >> 2];
    if (($52 | 0) == 0) {
      var $counter_0_lcssa = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $54 = ($traceKind_0 | 0) == -1;
    var $counter_020 = 0;
    var $58 = $52;
    __label__ = 22;
    break;
   case 21:
    var $counter_0_lcssa;
    var $55 = HEAP32[$48 >> 2];
    if (($55 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $72 = $55;
      __label__ = 26;
      break;
    }
   case 22:
    var $58;
    var $counter_020;
    var $_pre_pre = $58 + 4 | 0;
    if ($54) {
      var $_pre_pre_phi = $_pre_pre;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    if ((HEAP32[$_pre_pre >> 2] | 0) == ($traceKind_0 | 0)) {
      var $_pre_pre_phi = $_pre_pre;
      __label__ = 24;
      break;
    } else {
      var $counter_1 = $counter_020;
      var $_pre_phi = $_pre_pre;
      __label__ = 25;
      break;
    }
   case 24:
    var $_pre_pre_phi;
    var $counter_1 = $counter_020 + 1 | 0;
    var $_pre_phi = $_pre_pre_phi;
    __label__ = 25;
    break;
   case 25:
    var $_pre_phi;
    var $counter_1;
    var $64 = $58 + 8 | 0;
    var $65 = HEAP32[$64 >> 2];
    HEAP32[$47 >> 2] = $65;
    var $66 = HEAP32[$48 >> 2];
    HEAP32[$64 >> 2] = $66;
    HEAP32[$48 >> 2] = $58;
    var $68 = HEAP32[$58 >> 2];
    var $69 = HEAP32[$_pre_phi >> 2];
    _JS_TraceChildren($33, $68, $69);
    var $70 = HEAPU32[$47 >> 2];
    if (($70 | 0) == 0) {
      var $counter_0_lcssa = $counter_1;
      __label__ = 21;
      break;
    } else {
      var $counter_020 = $counter_1;
      var $58 = $70;
      __label__ = 22;
      break;
    }
   case 26:
    var $72;
    var $74 = HEAP32[$72 + 8 >> 2];
    HEAP32[$48 >> 2] = $74;
    _JS_free($72);
    var $76 = HEAP32[$48 >> 2];
    if (($76 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $72 = $76;
      __label__ = 26;
      break;
    }
   case 27:
    _JS_DHashTableFinish($41);
    if ((HEAP32[$46 >> 2] | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    _JS_NewNumberValue($counter_0_lcssa >>> 0, $vp);
    var $_0 = 1;
    __label__ = 29;
    break;
   case 29:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   case 30:
    var $84 = _JS_FlatStringEqualsAscii($20, STRING_TABLE.__str268561 | 0);
    if (($84 | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      var $i_0_lcssa = 2;
      __label__ = 10;
      break;
    }
   case 31:
    var $87 = _JS_FlatStringEqualsAscii($20, STRING_TABLE.__str269562 | 0);
    if (($87 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      var $i_0_lcssa = 3;
      __label__ = 10;
      break;
    }
   case 32:
    var $90 = $cx;
    __ZN16JSAutoByteStringC1EP9JSContextP8JSString($bytes, $90, $17);
    var $bytes_idx2_val = HEAPU32[$bytes >> 2];
    var $91 = __ZNK16JSAutoByteStringntEv($bytes_idx2_val);
    if ($91) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9CountHeapP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL20MakeFinalizeObserverP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $cx_idx_val = HEAP32[$cx + 132 >> 2];
    var $2 = _JS_GetGlobalObject($cx_idx_val);
    var $3 = _JS_NewObjectWithGivenProto($cx, __ZL20FinalizeCounterClass, 0, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL591($1, $3);
    var $6 = $1 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $vp | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13FinalizeCountP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = HEAP32[__ZL13finalizeCount >> 2];
  _INT_TO_JSVAL592($1, $2);
  var $3 = $1 | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  var $5 = $vp | 0;
  HEAP32[$5 >> 2] = $4$0;
  HEAP32[$5 + 4 >> 2] = $4$1;
  STACKTOP = __stackBase__;
  return 1;
}

function __ZL13InternalConstP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($argc | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_ReportError($cx, STRING_TABLE.__str262555 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 8;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = _JS_ValueToString($cx, $6$0, $6$1);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = _JS_FlattenString($cx, $7);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = _JS_FlatStringEqualsAscii($10, STRING_TABLE.__str263556 | 0);
    if (($13 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _UINT_TO_JSVAL($1);
    var $16 = $1 | 0;
    var $17$0 = HEAP32[$16 >> 2];
    var $17$1 = HEAP32[$16 + 4 >> 2];
    var $18 = $vp | 0;
    HEAP32[$18 >> 2] = $17$0;
    HEAP32[$18 + 4 >> 2] = $17$1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 7:
    _JS_ReportError($cx, STRING_TABLE.__str264557 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8SetDebugP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $vp + 16 | 0;
    var $st$1$0 = $3 | 0;
    var $4$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $3 + 4 | 0;
    var $4$1 = HEAP32[$st$1$1 >> 2];
    var $5 = _JSVAL_IS_BOOLEAN617($4$0, $4$1);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 286, 8, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str28321 | 0, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    var $9$0 = HEAP32[$3 >> 2];
    var $9$1 = HEAP32[$3 + 4 >> 2];
    var $10 = _JSVAL_TO_BOOLEAN624($9$0, $9$1);
    var $11 = $cx;
    var $12 = _JS_SetDebugMode($11, $10);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $$emscripten$temp$0 = _JSVAL_TRUE | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $15$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $15$1 = HEAP32[$st$1$1 >> 2];
    var $16 = $vp | 0;
    HEAP32[$16 >> 2] = $15$0;
    HEAP32[$16 + 4 >> 2] = $15$1;
    var $_0 = $12;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18SetDebuggerHandlerP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 286, 8, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str29322 | 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $4 = $vp + 16 | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = _JS_ValueToString($cx, $5$0, $5$1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $6;
    var $12 = HEAP32[$cx + 52 >> 2];
    _JS_SetDebuggerHandler($12, $11);
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $13$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $13$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $14 = $vp | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12SetThrowHookP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 286, 8, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str30323 | 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $4 = $vp + 16 | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = _JS_ValueToString($cx, $5$0, $5$1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $6;
    var $12 = HEAP32[$cx + 52 >> 2];
    _JS_SetThrowHook($12, $11);
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $13$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $13$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $14 = $vp | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL4TrapP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $script = __stackBase__;
    var $i = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = $vp + 16 | 0;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 286, 2, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 8;
    break;
   case 3:
    var $7 = $vp + ($argc + 1 << 3) | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = _JS_ValueToString($cx, $8$0, $8$1);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $argc - 1 | 0;
    _STRING_TO_JSVAL599($1, $9);
    var $13 = $1 | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    HEAP32[$7 >> 2] = $14$0;
    HEAP32[$7 + 4 >> 2] = $14$1;
    var $15 = __ZL11GetTrapArgsP9JSContextjPN2JS5ValueEPP8JSScriptPi($cx, $12, $3, $script, $i);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = HEAPU32[$i >> 2];
    var $19 = HEAPU32[$script >> 2];
    if ($18 >>> 0 < HEAPU32[$19 + 8 >> 2] >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 286, 2, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 8;
    break;
   case 7:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $25$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $25$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $26 = $vp | 0;
    HEAP32[$26 >> 2] = $25$0;
    HEAP32[$26 + 4 >> 2] = $25$1;
    var $29 = HEAP32[$19 >> 2] + $18 | 0;
    _STRING_TO_JSVAL599($2, $9);
    var $30 = $cx;
    var $31 = $19;
    var $_idx1 = $2 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    var $32 = _JS_SetTrap($30, $31, $29, $_idx1_val$0, $_idx1_val$1);
    var $_0 = $32;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL4TrapP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL6UntrapP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $script = __stackBase__;
    var $i = __stackBase__ + 4;
    var $1 = $vp + 16 | 0;
    var $2 = __ZL11GetTrapArgsP9JSContextjPN2JS5ValueEPP8JSScriptPi($cx, $argc, $1, $script, $i);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$script >> 2];
    var $9 = HEAP32[$5 >> 2] + HEAP32[$i >> 2] | 0;
    var $10 = $cx;
    var $11 = $5;
    _JS_ClearTrap($10, $11, $9);
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $12$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $12$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $13 = $vp | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8LineToPCP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $script = __stackBase__;
    var $i = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 286, 3, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 8;
    break;
   case 3:
    var $5 = $cx;
    var $6 = _JS_GetScriptedCaller($5);
    var $7 = _JS_GetFrameScript($6);
    HEAP32[$script >> 2] = $7;
    var $9 = $vp + 16 | 0;
    var $10 = __ZL11GetTrapArgsP9JSContextjPN2JS5ValueEPP8JSScriptPi($cx, $argc, $9, $script, $i);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = HEAP32[$i >> 2];
    var $15 = HEAP32[$script >> 2];
    if (($13 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $19 = $13;
      __label__ = 6;
      break;
    }
   case 5:
    var $19 = HEAP32[$15 + 28 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $19;
    var $20 = $15;
    var $21 = _JS_LineNumberToPC($20, $19);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $28 = $21 - HEAP32[$15 >> 2] | 0;
    _INT_TO_JSVAL592($1, $28);
    var $29 = $1 | 0;
    var $30$0 = HEAP32[$29 >> 2];
    var $30$1 = HEAP32[$29 + 4 >> 2];
    var $31 = $vp | 0;
    HEAP32[$31 >> 2] = $30$0;
    HEAP32[$31 + 4 >> 2] = $30$1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8PCToLineP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $script = __stackBase__;
    var $i = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = $vp + 16 | 0;
    var $3 = __ZL11GetTrapArgsP9JSContextjPN2JS5ValueEPP8JSScriptPi($cx, $argc, $2, $script, $i);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$script >> 2];
    var $10 = HEAP32[$6 >> 2] + HEAP32[$i >> 2] | 0;
    var $11 = $cx;
    var $12 = $6;
    var $13 = _JS_PCToLineNumber($11, $12, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _INT_TO_JSVAL592($1, $13);
    var $16 = $1 | 0;
    var $17$0 = HEAP32[$16 >> 2];
    var $17$1 = HEAP32[$16 + 4 >> 2];
    var $18 = $vp | 0;
    HEAP32[$18 >> 2] = $17$0;
    HEAP32[$18 + 4 >> 2] = $17$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14StringsAreUTF8P9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = _JS_CStringsAreUTF8();
  var $2 = ($1 | 0) != 0;
  var $$emscripten$temp$0 = _JSVAL_TRUE | 0;
  var $$emscripten$temp$1 = _JSVAL_FALSE | 0;
  var $3$0 = $2 ? HEAP32[$$emscripten$temp$0 >> 2] : HEAP32[$$emscripten$temp$1 >> 2];
  var $3$1 = $2 ? HEAP32[$$emscripten$temp$0 + 4 >> 2] : HEAP32[$$emscripten$temp$1 + 4 >> 2];
  var $4 = $vp | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  return 1;
}

function __ZL8TestUTF8P9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $mode = __stackBase__;
    var $chars = __stackBase__ + 4;
    var $charsLength = __stackBase__ + 44;
    var $bytes = __stackBase__ + 48;
    var $bytesLength = __stackBase__ + 68;
    HEAP32[$mode >> 2] = 1;
    HEAP32[$charsLength >> 2] = 5;
    HEAP32[$bytesLength >> 2] = 20;
    if (($argc | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $vp + 16 | 0;
    var $st$1$0 = $3 | 0;
    var $4$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $3 + 4 | 0;
    var $4$1 = HEAP32[$st$1$1 >> 2];
    var $5 = _JS_ValueToInt32($cx, $4$0, $4$1, $mode);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_pr = HEAP32[$mode >> 2];
    if (($_pr | 0) == 1) {
      __label__ = 4;
      break;
    } else if (($_pr | 0) == 2) {
      __label__ = 5;
      break;
    } else if (($_pr | 0) == 3) {
      __label__ = 6;
      break;
    } else if (($_pr | 0) == 4) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $8 = _JS_NewStringCopyZ($cx, STRING_TABLE.__str261554 | 0);
    __label__ = 9;
    break;
   case 5:
    var $10 = _JS_NewStringCopyZ($cx, STRING_TABLE.__str260553 | 0);
    __label__ = 9;
    break;
   case 6:
    var $12 = $bytes | 0;
    _JS_EncodeCharacters($cx, $12, $bytesLength);
    __label__ = 9;
    break;
   case 7:
    var $14 = $chars | 0;
    _JS_DecodeBytes($cx, $14, $charsLength);
    __label__ = 9;
    break;
   case 8:
    _JS_ReportError($cx, STRING_TABLE.__str259552 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 10;
    break;
   case 9:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $17$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $17$1 = HEAP32[$st$1$1 >> 2];
    var $18 = $vp | 0;
    HEAP32[$18 >> 2] = $17$0;
    HEAP32[$18 + 4 >> 2] = $17$1;
    var $cx_idx_val = HEAP32[$cx + 20 >> 2];
    var $19 = _JS_IsExceptionPending($cx_idx_val);
    var $_0 = ($19 | 0) == 0 & 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL8TestUTF8P9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL10ThrowErrorP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  _JS_ReportError($cx, STRING_TABLE.__str257550 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
  STACKTOP = __stackBase__;
  return 0;
}

function __ZL9BuildDateP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var $1 = __stackBase__ | 0;
  _memcpy($1, STRING_TABLE.__ZZL9BuildDateP9JSContextjPN2JS5ValueEE7version | 0, 20, 1);
  var $2 = HEAP32[_gOutFile >> 2];
  var $3 = _fprintf($2, STRING_TABLE.__str254547 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str255548 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str256549 | 0, HEAP32[tempInt + 8 >> 2] = $1, tempInt));
  var $$emscripten$temp$0 = _JSVAL_VOID | 0;
  var $4$0 = HEAP32[$$emscripten$temp$0 >> 2];
  var $4$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
  var $5 = $vp | 0;
  HEAP32[$5 >> 2] = $4$0;
  HEAP32[$5 + 4 >> 2] = $4$1;
  STACKTOP = __stackBase__;
  return 1;
}

function __ZL5ClearP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = _JS_GetGlobalForScopeChain($cx);
    HEAP32[$obj >> 2] = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      var $11 = $3;
      __label__ = 5;
      break;
    }
   case 3:
    var $6 = $vp + 16 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = _JS_ValueToObject($cx, $7$0, $7$1, $obj);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = HEAP32[$obj >> 2];
    __label__ = 5;
    break;
   case 5:
    var $11;
    _JS_ClearScope($cx, $11);
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $12$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $12$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $13 = $vp | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL6InternP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $length = __stackBase__;
    if (($argc | 0) == 0) {
      var $5 = _JSVAL_VOID;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $vp + 16 | 0;
    __label__ = 3;
    break;
   case 3:
    var $5;
    var $6 = $5;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = _JS_ValueToString($cx, $7$0, $7$1);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = _JS_GetStringCharsAndLength($cx, $8, $length);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = HEAP32[$length >> 2];
    var $15 = _JS_InternUCStringN($cx, $11, $14);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $18$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $18$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $19 = $vp | 0;
    HEAP32[$19 >> 2] = $18$0;
    HEAP32[$19 + 4 >> 2] = $18$1;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5CloneP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $parent = __stackBase__;
    var $ac = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportError($cx, STRING_TABLE.__str251544 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 23;
    break;
   case 3:
    __ZN22JSAutoEnterCompartmentC1Ev($ac);
    var $6 = $vp + 16 | 0;
    var $st$2$0 = $6 | 0;
    var $7$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $6 + 4 | 0;
    var $7$1 = HEAP32[$st$2$1 >> 2];
    var $8 = _JSVAL_IS_PRIMITIVE589($7$0, $7$1);
    if (($8 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $st$0$0 = $6 | 0;
    var $11$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $6 + 4 | 0;
    var $11$1 = HEAP32[$st$0$1 >> 2];
    var $12 = _JSVAL_TO_OBJECT590($11$0, $11$1);
    var $13 = __ZNK8JSObject25isCrossCompartmentWrapperEv($12);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $st$0$0 = $6 | 0;
    var $15$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $6 + 4 | 0;
    var $15$1 = HEAP32[$st$0$1 >> 2];
    var $16 = _JSVAL_TO_OBJECT590($15$0, $15$1);
    var $17 = __ZN8JSObject6unwrapEPj($16, 0);
    var $18 = __ZN22JSAutoEnterCompartment5enterEP9JSContextP8JSObject($ac, $cx, $17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 6:
    _OBJECT_TO_JSVAL591($1, $17);
    var $20 = $1 | 0;
    var $st$2$0 = $20 | 0;
    var $21$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $20 + 4 | 0;
    var $21$1 = HEAP32[$st$2$1 >> 2];
    HEAP32[$6 >> 2] = $21$0;
    HEAP32[$6 + 4 >> 2] = $21$1;
    __label__ = 7;
    break;
   case 7:
    var $st$0$0 = $6 | 0;
    var $22$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $6 + 4 | 0;
    var $22$1 = HEAP32[$st$0$1 >> 2];
    var $23 = _JSVAL_IS_PRIMITIVE589($22$0, $22$1);
    if (($23 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $st$0$0 = $6 | 0;
    var $26$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $6 + 4 | 0;
    var $26$1 = HEAP32[$st$0$1 >> 2];
    var $27 = _JSVAL_TO_OBJECT590($26$0, $26$1);
    var $_idx_val = HEAP32[$27 + 4 >> 2];
    var $28 = __ZNK8JSObject10isFunctionEv($_idx_val);
    if ($28) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $st$0$0 = $6 | 0;
    var $30$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $6 + 4 | 0;
    var $30$1 = HEAP32[$st$0$1 >> 2];
    var $31 = _JSVAL_TO_OBJECT590($30$0, $30$1);
    var $funobj_1 = $31;
    __label__ = 13;
    break;
   case 10:
    var $st$0$0 = $6 | 0;
    var $33$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $6 + 4 | 0;
    var $33$1 = HEAP32[$st$0$1 >> 2];
    var $34 = _JS_ValueToFunction($cx, $33$0, $33$1);
    if (($34 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $37 = _JS_GetFunctionObject($34);
    var $funobj_1 = $37;
    __label__ = 13;
    break;
   case 12:
    var $ac_idx9_val = HEAP32[$ac >> 2];
    __ZN22JSAutoEnterCompartmentD1Ev($ac_idx9_val);
    var $_1 = 0;
    __label__ = 23;
    break;
   case 13:
    var $funobj_1;
    var $ac_idx_val = HEAP32[$ac >> 2];
    __ZN22JSAutoEnterCompartmentD1Ev($ac_idx_val);
    var $40 = __ZNK2js2gc4Cell11compartmentEv($funobj_1);
    if (($40 | 0) == (HEAP32[$cx + 56 >> 2] | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $funobj_1_idx_val = HEAP32[$funobj_1 + 24 >> 2];
    var $45 = __ZNK8JSObject18getFunctionPrivateEv($funobj_1_idx_val);
    var $_idx1_val = HEAP16[$45 + 58 >> 1];
    var $46 = __ZNK10JSFunction13isInterpretedEv($_idx1_val);
    if ($46) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    if ((HEAP8[HEAP32[$45 + 60 >> 2] + 36 | 0] & 16) << 24 >> 24 == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 4, 222, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = STRING_TABLE.__str252545 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str253546 | 0, tempInt));
    var $_1 = 0;
    __label__ = 23;
    break;
   case 17:
    if ($argc >>> 0 > 1) {
      __label__ = 18;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 18:
    var $59 = $vp + 24 | 0;
    var $st$1$0 = $59 | 0;
    var $60$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $59 + 4 | 0;
    var $60$1 = HEAP32[$st$1$1 >> 2];
    var $61 = _JS_ValueToObject($cx, $60$0, $60$1, $parent);
    if (($61 | 0) == 0) {
      var $_1 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $69 = HEAP32[$parent >> 2];
    __label__ = 21;
    break;
   case 20:
    var $64 = $vp | 0;
    var $st$1$0 = $64 | 0;
    var $65$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $64 + 4 | 0;
    var $65$1 = HEAP32[$st$1$1 >> 2];
    var $66 = _JSVAL_TO_OBJECT590($65$0, $65$1);
    var $_idx12_val = HEAP32[$66 + 20 >> 2];
    var $67 = _JS_GetParent($_idx12_val);
    HEAP32[$parent >> 2] = $67;
    var $69 = $67;
    __label__ = 21;
    break;
   case 21:
    var $69;
    var $70 = _JS_CloneFunctionObject($cx, $funobj_1, $69);
    if (($70 | 0) == 0) {
      var $_1 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    _OBJECT_TO_JSVAL591($2, $70);
    var $73 = $2 | 0;
    var $st$2$0 = $73 | 0;
    var $74$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $73 + 4 | 0;
    var $74$1 = HEAP32[$st$2$1 >> 2];
    var $75 = $vp | 0;
    HEAP32[$75 >> 2] = $74$0;
    HEAP32[$75 + 4 >> 2] = $74$1;
    var $_1 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL5CloneP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL6GetPDAP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $vobj = __stackBase__;
    var $pda = __stackBase__ + 4;
    var $v = __stackBase__ + 12;
    var $1 = __stackBase__ + 20;
    var $2 = __stackBase__ + 28;
    var $3 = __stackBase__ + 36;
    var $4 = __stackBase__ + 44;
    if (($argc | 0) == 0) {
      var $9 = _JSVAL_VOID;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $vp + 16 | 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    var $10 = $9;
    var $st$2$0 = $10 | 0;
    var $11$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $10 + 4 | 0;
    var $11$1 = HEAP32[$st$2$1 >> 2];
    var $12 = _JS_ValueToObject($cx, $11$0, $11$1, $vobj);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = HEAP32[$vobj >> 2];
    if (($15 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $18$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $18$1 = HEAP32[$st$1$1 >> 2];
    var $19 = $vp | 0;
    HEAP32[$19 >> 2] = $18$0;
    HEAP32[$19 + 4 >> 2] = $18$1;
    var $_0 = 1;
    __label__ = 19;
    break;
   case 6:
    var $21 = _JS_NewArrayObject($cx);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _OBJECT_TO_JSVAL591($1, $21);
    var $24 = $1 | 0;
    var $st$2$0 = $24 | 0;
    var $25$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $24 + 4 | 0;
    var $25$1 = HEAP32[$st$2$1 >> 2];
    var $26 = $vp | 0;
    HEAP32[$26 >> 2] = $25$0;
    HEAP32[$26 + 4 >> 2] = $25$1;
    var $27 = $cx;
    var $28 = $15;
    var $29 = $pda;
    var $30 = _JS_GetPropertyDescArray($27, $28, $29);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $36 = $2 | 0;
    var $37 = $v | 0;
    var $38 = $3 | 0;
    var $39 = $4 | 0;
    var $_pre = HEAPU32[$pda >> 2];
    var $i_0 = 0;
    var $pd_0 = HEAP32[$pda + 4 >> 2];
    var $ok_0 = $30;
    __label__ = 9;
    break;
   case 9:
    var $ok_0;
    var $pd_0;
    var $i_0;
    if ($i_0 >>> 0 < $_pre >>> 0) {
      __label__ = 10;
      break;
    } else {
      var $ok_1 = $ok_0;
      __label__ = 18;
      break;
    }
   case 10:
    var $43 = _JS_NewObject($cx, 0, 0, 0);
    if (($43 | 0) == 0) {
      var $ok_1 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    _OBJECT_TO_JSVAL591($2, $43);
    var $st$1$0 = $36 | 0;
    var $46$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $36 + 4 | 0;
    var $46$1 = HEAP32[$st$1$1 >> 2];
    HEAP32[$37 >> 2] = $46$0;
    HEAP32[$37 + 4 >> 2] = $46$1;
    var $47 = _JS_SetElement($cx, $21, $i_0, $v);
    if (($47 | 0) == 0) {
      var $ok_1 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $51 = _JS_SetProperty($cx, $43, STRING_TABLE.__str246539 | 0, $pd_0 | 0);
    if (($51 | 0) == 0) {
      var $ok_1 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $55 = _JS_SetProperty($cx, $43, STRING_TABLE.__str247540 | 0, $pd_0 + 8 | 0);
    if (($55 | 0) == 0) {
      var $ok_1 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $60 = HEAPU8[$pd_0 + 16 | 0] & 255;
    _INT_TO_JSVAL592($3, $60);
    var $st$4$0 = $38 | 0;
    var $61$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $38 + 4 | 0;
    var $61$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $37 | 0;
    HEAP32[$st$8$0 >> 2] = $61$0;
    var $st$8$1 = $37 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $61$1;
    var $62 = _JS_SetProperty($cx, $43, STRING_TABLE.__str248541 | 0, $v);
    if (($62 | 0) == 0) {
      var $ok_1 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $67 = HEAPU16[$pd_0 + 18 >> 1] & 65535;
    _INT_TO_JSVAL592($4, $67);
    var $st$4$0 = $39 | 0;
    var $68$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $39 + 4 | 0;
    var $68$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $37 | 0;
    HEAP32[$st$8$0 >> 2] = $68$0;
    var $st$8$1 = $37 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $68$1;
    var $69 = _JS_SetProperty($cx, $43, STRING_TABLE.__str249542 | 0, $v);
    if (($69 | 0) == 0) {
      var $ok_1 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $73 = _JS_SetProperty($cx, $43, STRING_TABLE.__str250543 | 0, $pd_0 + 24 | 0);
    var $74 = ($73 | 0) != 0;
    var $75 = $74 & 1;
    if ($74) {
      __label__ = 17;
      break;
    } else {
      var $ok_1 = $75;
      __label__ = 18;
      break;
    }
   case 17:
    var $i_0 = $i_0 + 1 | 0;
    var $pd_0 = $pd_0 + 32 | 0;
    var $ok_0 = $75;
    __label__ = 9;
    break;
   case 18:
    var $ok_1;
    _JS_PutPropertyDescArray($27, $29);
    var $_0 = $ok_1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL6GetPDAP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL6GetSLXP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($argc | 0) == 0) {
      var $6 = _JSVAL_VOID;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $vp + 16 | 0;
    __label__ = 3;
    break;
   case 3:
    var $6;
    var $7 = $6;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = __ZL13ValueToScriptP9JSContextN2JS5ValueEPP10JSFunction($cx, $8$0, $8$1);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $9;
    var $13 = __Z22js_GetScriptLineExtentP8JSScript($12);
    _INT_TO_JSVAL592($1, $13);
    var $14 = $1 | 0;
    var $15$0 = HEAP32[$14 >> 2];
    var $15$1 = HEAP32[$14 + 4 >> 2];
    var $16 = $vp | 0;
    HEAP32[$16 >> 2] = $15$0;
    HEAP32[$16 + 4 >> 2] = $15$1;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL7ToInt32P9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    if (($argc | 0) == 0) {
      var $5 = _JSVAL_VOID;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $vp + 16 | 0;
    __label__ = 3;
    break;
   case 3:
    var $5;
    var $6 = $5;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = _JS_ValueToInt32($cx, $7$0, $7$1, $i);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = HEAP32[$i >> 2] | 0;
    _JS_NewNumberValue($12, $vp);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13EvalInContextP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str = __stackBase__;
    var $sobj = __stackBase__ + 4;
    var $srclen = __stackBase__ + 8;
    var $1 = __stackBase__ + 12;
    var $rval = __stackBase__ + 20;
    var $ac = __stackBase__ + 28;
    var $flags = __stackBase__ + 32;
    HEAP32[$sobj >> 2] = 0;
    var $2 = $vp + 16 | 0;
    var $3 = _JS_ConvertArguments($cx, $argc, $2, STRING_TABLE.__str243536 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $str, HEAP32[tempInt + 4 >> 2] = $sobj, tempInt));
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$str >> 2];
    var $7 = _JS_GetStringCharsAndLength($cx, $6, $srclen);
    if (($7 | 0) == 0) {
      var $_1 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = HEAP32[$srclen >> 2];
    if (($10 | 0) == 4) {
      __label__ = 4;
      break;
    } else {
      var $lazy_0 = 0;
      var $29 = $10;
      __label__ = 9;
      break;
    }
   case 4:
    if (HEAP16[$7 >> 1] << 16 >> 16 == 108) {
      __label__ = 5;
      break;
    } else {
      var $lazy_0 = 0;
      var $29 = $10;
      __label__ = 9;
      break;
    }
   case 5:
    if (HEAP16[$7 + 2 >> 1] << 16 >> 16 == 97) {
      __label__ = 6;
      break;
    } else {
      var $lazy_0 = 0;
      var $29 = $10;
      __label__ = 9;
      break;
    }
   case 6:
    if (HEAP16[$7 + 4 >> 1] << 16 >> 16 == 122) {
      __label__ = 7;
      break;
    } else {
      var $lazy_0 = 0;
      var $29 = $10;
      __label__ = 9;
      break;
    }
   case 7:
    if (HEAP16[$7 + 6 >> 1] << 16 >> 16 == 121) {
      __label__ = 8;
      break;
    } else {
      var $lazy_0 = 0;
      var $29 = $10;
      __label__ = 9;
      break;
    }
   case 8:
    HEAP32[$srclen >> 2] = 0;
    var $lazy_0 = 1;
    var $29 = 0;
    __label__ = 9;
    break;
   case 9:
    var $29;
    var $lazy_0;
    var $30 = HEAP32[$sobj >> 2];
    if (($30 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $36 = $30;
      __label__ = 11;
      break;
    }
   case 10:
    var $33 = __ZL10NewSandboxP9JSContextb($cx, $lazy_0);
    HEAP32[$sobj >> 2] = $33;
    if (($33 | 0) == 0) {
      var $_1 = 0;
      __label__ = 23;
      break;
    } else {
      var $36 = $33;
      __label__ = 11;
      break;
    }
   case 11:
    var $36;
    if (($29 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    _OBJECT_TO_JSVAL591($1, $36);
    var $39 = $1 | 0;
    var $40$0 = HEAP32[$39 >> 2];
    var $40$1 = HEAP32[$39 + 4 >> 2];
    var $41 = $vp | 0;
    HEAP32[$41 >> 2] = $40$0;
    HEAP32[$41 + 4 >> 2] = $40$1;
    var $_1 = 1;
    __label__ = 23;
    break;
   case 13:
    var $43 = $cx;
    var $44 = _JS_GetScriptedCaller($43);
    var $45 = _JS_GetFrameScript($44);
    var $46 = _JS_GetFramePC($43, $44);
    __ZN22JSAutoEnterCompartmentC1Ev($ac);
    var $47 = HEAP32[$sobj >> 2];
    var $48 = __ZN8JSObject6unwrapEPj($47, $flags);
    if ((HEAP32[$flags >> 2] & 1 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    HEAP32[$sobj >> 2] = $48;
    var $53 = __ZN22JSAutoEnterCompartment5enterEP9JSContextP8JSObject($ac, $cx, $48);
    if ($53) {
      __label__ = 15;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 15:
    __Z19OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($cx, $sobj);
    var $55 = HEAP32[$sobj >> 2];
    if (($55 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $_idx_val = HEAP32[$55 + 4 >> 2];
    var $58 = __ZNK8JSObject8getClassEv($_idx_val);
    if ((HEAP32[$58 + 4 >> 2] & 262144 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    _JS_ReportError($cx, STRING_TABLE.__str244537 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $ac_idx3_val = HEAP32[$ac >> 2];
    __ZN22JSAutoEnterCompartmentD1Ev($ac_idx3_val);
    var $_1 = 0;
    __label__ = 23;
    break;
   case 18:
    var $65 = HEAP32[$45 + 52 >> 2];
    var $66 = _JS_PCToLineNumber($43, $45, $46);
    var $67 = _JS_EvaluateUCScript($cx, $55, $7, $29, $65, $66, $rval);
    var $68 = ($67 | 0) == 0;
    var $ac_idx2_val = HEAP32[$ac >> 2];
    __ZN22JSAutoEnterCompartmentD1Ev($ac_idx2_val);
    if ($68) {
      var $_1 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $71 = HEAP32[$cx + 56 >> 2];
    var $72 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($71, $cx, $rval);
    if ($72) {
      __label__ = 20;
      break;
    } else {
      var $_1 = 0;
      __label__ = 23;
      break;
    }
   case 20:
    var $74 = $rval | 0;
    var $75$0 = HEAP32[$74 >> 2];
    var $75$1 = HEAP32[$74 + 4 >> 2];
    var $76 = $vp | 0;
    HEAP32[$76 >> 2] = $75$0;
    HEAP32[$76 + 4 >> 2] = $75$1;
    var $_1 = 1;
    __label__ = 23;
    break;
   case 21:
    var $ac_idx1_val = HEAP32[$ac >> 2];
    __ZN22JSAutoEnterCompartmentD1Ev($ac_idx1_val);
    var $_1 = 0;
    __label__ = 23;
    break;
   case 22:
    var $ac_idx_val = HEAP32[$ac >> 2];
    __ZN22JSAutoEnterCompartmentD1Ev($ac_idx_val);
    var $_1 = 0;
    __label__ = 23;
    break;
   case 23:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13EvalInContextP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL11EvalInFrameP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fi = __stackBase__;
    var $length = __stackBase__ + 40;
    if ($argc >>> 0 < 2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $vp + 16 | 0;
    var $st$1$0 = $3 | 0;
    var $4$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $3 + 4 | 0;
    var $4$1 = HEAP32[$st$1$1 >> 2];
    var $5 = _JSVAL_IS_INT622($4$0, $4$1);
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $vp + 24 | 0;
    var $st$1$0 = $8 | 0;
    var $9$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $8 + 4 | 0;
    var $9$1 = HEAP32[$st$1$1 >> 2];
    var $10 = _JSVAL_IS_STRING593($9$0, $9$1);
    if (($10 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    _JS_ReportError($cx, STRING_TABLE.__str241534 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 19;
    break;
   case 5:
    var $st$0$0 = $3 | 0;
    var $14$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $3 + 4 | 0;
    var $14$1 = HEAP32[$st$0$1 >> 2];
    var $15 = _JSVAL_TO_INT623($14$0, $14$1);
    var $16$0 = HEAP32[$8 >> 2];
    var $16$1 = HEAP32[$8 + 4 >> 2];
    var $17 = _JSVAL_TO_STRING594($16$0, $16$1);
    if ($argc >>> 0 > 2) {
      __label__ = 6;
      break;
    } else {
      var $29 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $20 = $vp + 32 | 0;
    var $st$1$0 = $20 | 0;
    var $21$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $20 + 4 | 0;
    var $21$1 = HEAP32[$st$1$1 >> 2];
    var $22 = _JSVAL_IS_BOOLEAN617($21$0, $21$1);
    if (($22 | 0) == 0) {
      var $29 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $st$0$0 = $20 | 0;
    var $25$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $20 + 4 | 0;
    var $25$1 = HEAP32[$st$0$1 >> 2];
    var $26 = _JSVAL_TO_BOOLEAN624($25$0, $25$1);
    var $29 = ($26 | 0) != 0;
    __label__ = 8;
    break;
   case 8:
    var $29;
    __ZN2js13FrameRegsIterC1EP9JSContextNS_9StackIter11SavedOptionE($fi, $cx);
    var $i_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $i_0;
    if ($i_0 >>> 0 < $15 >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $33 = __ZNK2js13FrameRegsIter2fpEv($fi);
    var $_idx_val = HEAP32[$33 + 16 >> 2];
    var $34 = __ZNK2js10StackFrame4prevEv($_idx_val);
    if (($34 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $37 = $i_0 + 1 | 0;
    __ZN2js13FrameRegsIterppEv($fi);
    var $i_0 = $37;
    __label__ = 9;
    break;
   case 12:
    var $39 = __ZNK2js13FrameRegsIter2fpEv($fi);
    var $_idx1_val = HEAP32[$39 >> 2];
    var $40 = __ZNK2js10StackFrame13isScriptFrameEv($_idx1_val);
    if ($40) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    _JS_ReportError($cx, STRING_TABLE.__str242535 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 19;
    break;
   case 14:
    if ($29) {
      __label__ = 15;
      break;
    } else {
      var $saved_0 = 0;
      __label__ = 16;
      break;
    }
   case 15:
    var $44 = _JS_SaveFrameChain($cx);
    var $saved_0 = $44;
    __label__ = 16;
    break;
   case 16:
    var $saved_0;
    var $46 = _JS_GetStringCharsAndLength($cx, $17, $length);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $49 = __ZN2jsL8JsvalifyEPNS_10StackFrameE625($39);
    var $50 = HEAP32[$length >> 2];
    var $51 = __ZNK2js10StackFrame6scriptEv($39);
    var $53 = HEAP32[$51 + 52 >> 2];
    var $54 = __ZNK2js13FrameRegsIter2pcEv($fi);
    var $55 = $cx;
    var $56 = $51;
    var $57 = _JS_PCToLineNumber($55, $56, $54);
    var $58 = $49;
    var $59 = _JS_EvaluateUCInStackFrame($55, $58, $46, $50, $53, $57, $vp);
    if (($saved_0 | 0) == 0) {
      var $_0 = $59;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    _JS_RestoreFrameChain($cx);
    var $_0 = $59;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11EvalInFrameP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL7ShapeOfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_04 = $vp + 16 | 0;
    var $st$1$0 = $_04 | 0;
    var $tmp$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_04 + 4 | 0;
    var $tmp$1 = HEAP32[$st$1$1 >> 2];
    var $4 = _JSVAL_IS_OBJECT620($tmp$0, $tmp$1);
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportError($cx, STRING_TABLE.__str240533 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 4:
    var $8 = _JSVAL_TO_OBJECT590($tmp$0, $tmp$1);
    if (($8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $$emscripten$temp$0 = _JSVAL_ZERO | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $11$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $11$1 = HEAP32[$st$1$1 >> 2];
    var $12 = $vp | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 6:
    var $_idx_val = HEAP32[$8 >> 2];
    var $14 = __ZNK8JSObject8isNativeEv($_idx_val);
    if ($14) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _INT_TO_JSVAL592($1, -1);
    var $16 = $1 | 0;
    var $17$0 = HEAP32[$16 >> 2];
    var $17$1 = HEAP32[$16 + 4 >> 2];
    var $18 = $vp | 0;
    HEAP32[$18 >> 2] = $17$0;
    HEAP32[$18 + 4 >> 2] = $17$1;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 8:
    var $_idx1_val = HEAP32[$8 + 12 >> 2];
    var $20 = __ZNK8JSObject5shapeEv($_idx1_val);
    var $21 = $20 >>> 0;
    _JS_NewNumberValue($21, $vp);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL7ShapeOfP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL8ResolverP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $referent = __stackBase__;
    var $proto = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    HEAP32[$proto >> 2] = 0;
    var $3 = $vp + 16 | 0;
    var $4 = _JS_ConvertArguments($cx, $argc, $3, STRING_TABLE.__str239532 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $referent, HEAP32[tempInt + 4 >> 2] = $proto, tempInt));
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $JS_NewObjectWithGivenProto_JS_NewObject = $argc >>> 0 > 1 ? 294 : 296;
    var $8 = HEAP32[$proto >> 2];
    var $_idx_val = HEAP32[HEAP32[$referent >> 2] + 20 >> 2];
    var $10 = _JS_GetParent($_idx_val);
    var $11 = FUNCTION_TABLE[$JS_NewObjectWithGivenProto_JS_NewObject]($cx, __ZL14resolver_class, $8, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = HEAP32[$referent >> 2];
    _OBJECT_TO_JSVAL591($1, $14);
    var $_idx1 = $1 | 0;
    var $_idx1_val$0 = HEAP32[$_idx1 >> 2];
    var $_idx1_val$1 = HEAP32[$_idx1 + 4 >> 2];
    _JS_SetReservedSlot($cx, $11, $_idx1_val$0, $_idx1_val$1);
    _OBJECT_TO_JSVAL591($2, $11);
    var $15 = $2 | 0;
    var $16$0 = HEAP32[$15 >> 2];
    var $16$1 = HEAP32[$15 + 4 >> 2];
    var $17 = $vp | 0;
    HEAP32[$17 >> 2] = $16$0;
    HEAP32[$17 + 4 >> 2] = $16$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5SnarfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $filename = __stackBase__;
    var $pnGuard = __stackBase__ + 4;
    var $match = __stackBase__ + 12;
    var $1 = __stackBase__ + 16;
    var $2 = __stackBase__ + 24;
    if (($argc | 0) == 0) {
      var $_2 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $vp + 16 | 0;
    var $st$1$0 = $5 | 0;
    var $6$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $5 + 4 | 0;
    var $6$1 = HEAP32[$st$1$1 >> 2];
    var $7 = _JS_ValueToString($cx, $6$0, $6$1);
    if (($7 | 0) == 0) {
      var $_2 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $cx;
    __ZN16JSAutoByteStringC1EP9JSContextP8JSString($filename, $10, $7);
    var $filename_idx2_val = HEAPU32[$filename >> 2];
    var $11 = __ZNK16JSAutoByteStringntEv($filename_idx2_val);
    if ($11) {
      var $_1 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $cx;
    var $14 = _JS_GetScriptedCaller($13);
    var $15 = _JS_GetFrameScript($14);
    var $16 = __ZNK16JSAutoByteString3ptrEv($filename_idx2_val);
    __ZN12FreeOnReturnC1EP9JSContextPKc($pnGuard, $cx);
    if (HEAP8[$16] << 24 >> 24 == 47) {
      var $pathname_0 = $16;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $21 = HEAP32[$15 + 52 >> 2];
    var $22 = __ZL20MakeAbsolutePathnameP9JSContextPKcS2_($cx, $21, $16);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN12FreeOnReturn4initEPKc($pnGuard, $22);
    var $pathname_0 = $22;
    __label__ = 7;
    break;
   case 7:
    var $pathname_0;
    if ($argc >>> 0 > 1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $28 = $vp + 24 | 0;
    var $st$1$0 = $28 | 0;
    var $29$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $28 + 4 | 0;
    var $29$1 = HEAP32[$st$1$1 >> 2];
    var $30 = _JS_ValueToString($cx, $29$0, $29$1);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $33 = _JS_StringEqualsAscii($cx, $30, STRING_TABLE.__str231524 | 0, $match);
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ((HEAP32[$match >> 2] | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $39 = __ZL16FileAsTypedArrayP9JSContextPKc($cx, $pathname_0);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    _OBJECT_TO_JSVAL591($1, $39);
    var $42 = $1 | 0;
    var $st$2$0 = $42 | 0;
    var $43$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $42 + 4 | 0;
    var $43$1 = HEAP32[$st$2$1 >> 2];
    var $44 = $vp | 0;
    var $st$7$0 = $44 | 0;
    HEAP32[$st$7$0 >> 2] = $43$0;
    var $st$7$1 = $44 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $43$1;
    var $_0 = 1;
    __label__ = 15;
    break;
   case 13:
    var $46 = __ZL12FileAsStringP9JSContextPKc($cx, $pathname_0);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    _STRING_TO_JSVAL599($2, $46);
    var $49 = $2 | 0;
    var $st$2$0 = $49 | 0;
    var $50$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $49 + 4 | 0;
    var $50$1 = HEAP32[$st$2$1 >> 2];
    var $51 = $vp | 0;
    var $st$7$0 = $51 | 0;
    HEAP32[$st$7$0 >> 2] = $50$0;
    var $st$7$1 = $51 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $50$1;
    var $_0 = 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    var $pnGuard_idx_val = HEAP32[$pnGuard + 4 >> 2];
    __ZN12FreeOnReturnD1Ev($pnGuard_idx_val);
    var $_1 = $_0;
    __label__ = 16;
    break;
   case 16:
    var $_1;
    __ZN16JSAutoByteStringD1Ev($filename_idx2_val);
    var $_2 = $_1;
    __label__ = 17;
    break;
   case 17:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL5SnarfP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL7CompileP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 4, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str51344 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str225518 | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str226519 | 0, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $_05 = $vp + 16 | 0;
    var $tmp$0 = HEAP32[$_05 >> 2];
    var $tmp$1 = HEAP32[$_05 + 4 >> 2];
    var $4 = _JSVAL_IS_STRING593($tmp$0, $tmp$1);
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = _JS_TypeOfValue($cx, $tmp$0, $tmp$1);
    var $8 = _JS_GetTypeName($7);
    _JS_ReportError($cx, STRING_TABLE.__str229522 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $8, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 5:
    var $10 = _JS_NewGlobalObject($cx, __ZZL7CompileP9JSContextjPN2JS5ValueEE11dummy_class);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $13 = _JSVAL_TO_STRING594($tmp$0, $tmp$1);
    var $14 = _JS_GetOptions($cx);
    var $15 = $14 | 4112;
    _JS_SetOptions($cx, $15);
    var $16 = _JS_GetStringCharsZ($cx, $13);
    var $_idx3_val = HEAP32[$13 >> 2];
    var $17 = _JS_GetStringLength($_idx3_val);
    var $18 = _JS_CompileUCScript($cx, $10, $16, $17, STRING_TABLE.__str228521 | 0, 0);
    var $19 = ($18 | 0) != 0;
    _JS_SetOptions($cx, $14);
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $20$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $20$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $21 = $vp | 0;
    HEAP32[$21 >> 2] = $20$0;
    HEAP32[$21 + 4 >> 2] = $20$1;
    var $_0 = $19 & 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5ParseP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 992;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $parser = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 4, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str51344 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str225518 | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str226519 | 0, tempInt));
    var $_1 = 0;
    __label__ = 8;
    break;
   case 3:
    var $_05 = $vp + 16 | 0;
    var $st$1$0 = $_05 | 0;
    var $tmp$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $_05 + 4 | 0;
    var $tmp$1 = HEAP32[$st$1$1 >> 2];
    var $4 = _JSVAL_IS_STRING593($tmp$0, $tmp$1);
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = _JS_TypeOfValue($cx, $tmp$0, $tmp$1);
    var $8 = _JS_GetTypeName($7);
    _JS_ReportError($cx, STRING_TABLE.__str227520 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $8, tempInt));
    var $_1 = 0;
    __label__ = 8;
    break;
   case 5:
    var $10 = _JSVAL_TO_STRING594($tmp$0, $tmp$1);
    __ZN2js6ParserC2EP9JSContextP12JSPrincipalsPNS_10StackFrameEb($parser, $cx, 0, 0, 1);
    var $11 = _JS_GetStringCharsZ($cx, $10);
    var $_idx3_val = HEAP32[$10 >> 2];
    var $12 = _JS_GetStringLength($_idx3_val);
    var $13 = __ZNK9JSContext11findVersionEv($cx);
    var $14 = __ZN2js6Parser4initEPKtjPKcj9JSVersion($parser, $11, $12, STRING_TABLE.__str228521 | 0, 0, $13);
    var $15 = __ZN2js6Parser5parseEP8JSObject($parser, 0);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $18$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $18$1 = HEAP32[$st$1$1 >> 2];
    var $19 = $vp | 0;
    HEAP32[$19 >> 2] = $18$0;
    HEAP32[$19 + 4 >> 2] = $18$1;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    __ZN2js6ParserD2Ev($parser);
    var $_1 = $_0;
    __label__ = 8;
    break;
   case 8:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL7TimeoutP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $t = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[__ZL16gTimeoutInterval >> 2], tempDoubleI32[1] = HEAP32[__ZL16gTimeoutInterval + 4 >> 2], tempDoubleF64[0]);
    _JS_NewNumberValue($3, $vp);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 3:
    if ($argc >>> 0 > 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    _JS_ReportError($cx, STRING_TABLE.__str221514 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 5:
    var $8 = $vp + 16 | 0;
    var $st$1$0 = $8 | 0;
    var $9$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $8 + 4 | 0;
    var $9$1 = HEAP32[$st$1$1 >> 2];
    var $10 = _JS_ValueToNumber($cx, $9$0, $9$1, $t);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $13$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $13$1 = HEAP32[$st$1$1 >> 2];
    var $14 = $vp | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $15 = (tempDoubleI32[0] = HEAP32[$t >> 2], tempDoubleI32[1] = HEAP32[$t + 4 >> 2], tempDoubleF64[0]);
    var $16 = __ZL15SetTimeoutValueP9JSContextd($cx, $15);
    var $_0 = $16;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL7ElapsedP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $cx_idx_val = HEAP32[$cx + 188 >> 2];
    var $3 = __ZL14GetContextDataP9JSContext($cx_idx_val);
    if (($3 | 0) == 0) {
      var $d_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __Z14js_IntervalNowv();
    var $d_0 = ($6 - HEAP32[$3 >> 2] | 0) >>> 0;
    __label__ = 4;
    break;
   case 4:
    var $d_0;
    _JS_NewNumberValue($d_0, $vp);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    _JS_ReportError($cx, STRING_TABLE.__str221514 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z22ShellPrincipalsSubsumeP12JSPrincipalsS0_($0, $1) {
  return 1;
}

function __Z17CheckObjectAccessP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueE($cx, $obj, $id, $mode, $vp) {
  return 1;
}

function __ZL6ParentP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    if (($argc | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_ReportError($cx, STRING_TABLE.__str221514 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 8;
    break;
   case 3:
    var $_04 = $vp + 16 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $6 = _JSVAL_IS_PRIMITIVE589($tmp$0, $tmp$1);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _JS_ReportError($cx, STRING_TABLE.__str222515 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 8;
    break;
   case 5:
    var $10 = _JSVAL_TO_OBJECT590($tmp$0, $tmp$1);
    var $_idx3_val = HEAP32[$10 + 20 >> 2];
    var $11 = _JS_GetParent($_idx3_val);
    _OBJECT_TO_JSVAL591($1, $11);
    var $12 = $1 | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    var $14 = $vp | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    if (($11 | 0) == 0) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_idx_val = HEAP32[$11 + 4 >> 2];
    var $17 = __ZNK8JSObject8getClassEv($_idx_val);
    var $19 = HEAP32[$17 + 72 >> 2];
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = FUNCTION_TABLE[$19]($cx, $11);
    _OBJECT_TO_JSVAL591($2, $22);
    var $23 = $2 | 0;
    var $24$0 = HEAP32[$23 >> 2];
    var $24$1 = HEAP32[$23 + 4 >> 2];
    HEAP32[$14 >> 2] = $24$0;
    HEAP32[$14 + 4 >> 2] = $24$1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL6ParentP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL15ParseLegacyJSONP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $length = __stackBase__;
    var $1 = __stackBase__ + 4;
    if (($argc | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $vp + 16 | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = _JSVAL_IS_STRING593($5$0, $5$1);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 286, 12, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str59352 | 0, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    var $10$0 = HEAP32[$4 >> 2];
    var $10$1 = HEAP32[$4 + 4 >> 2];
    var $11 = _JSVAL_TO_STRING594($10$0, $10$1);
    var $12 = _JS_GetStringCharsAndLength($cx, $11, $length);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = HEAP32[$length >> 2];
    __ZN2JSL9NullValueEv619($1);
    var $16 = $cx;
    var $17 = __ZN2js20ParseJSONWithReviverEP9JSContextPKtjRKN2JS5ValueEPS5_12DecodingMode($16, $12, $15, $1, $vp, 1);
    var $_0 = $17;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL27EnableStackWalkingAssertionP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $vp + 16 | 0;
    var $st$1$0 = $3 | 0;
    var $4$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $3 + 4 | 0;
    var $4$1 = HEAP32[$st$1$1 >> 2];
    var $5 = _JSVAL_IS_BOOLEAN617($4$0, $4$1);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 286, 12, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str60353 | 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $9$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $9$1 = HEAP32[$st$1$1 >> 2];
    var $10 = $vp | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10GetMaxArgsP9JSContextjPN2JS5ValueE($cx, $arg, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _INT_TO_JSVAL592($1, 491520);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $vp | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return 1;
}

function __ZL10its_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $obj_idx_val = HEAP32[$obj + 24 >> 2];
  var $1 = _JS_GetPrivate($obj_idx_val);
  var $4 = ($1 | 0) != 0 ? $1 : _JSVAL_VOID | 0;
  var $5$0 = HEAP32[$4 >> 2];
  var $5$1 = HEAP32[$4 + 4 >> 2];
  var $6 = $vp | 0;
  HEAP32[$6 >> 2] = $5$0;
  HEAP32[$6 + 4 >> 2] = $5$1;
  return 1;
}

function __ZL10its_setterP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj_idx_val = HEAP32[$obj + 24 >> 2];
    var $1 = _JS_GetPrivate($obj_idx_val);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $vp | 0;
    var $5 = $1;
    var $6$0 = HEAP32[$4 >> 2];
    var $6$1 = HEAP32[$4 + 4 >> 2];
    var $st$6$0 = $5 | 0;
    HEAP32[$st$6$0 >> 2] = $6$0;
    var $st$6$1 = $5 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $6$1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 3:
    var $8 = __Znwj();
    if (($8 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    _JS_ReportOutOfMemory($cx);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 5:
    var $12 = $8;
    var $13 = _JS_AddValueRoot($cx, $12);
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZdlPv($8);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 7:
    _JS_SetPrivate($obj, $8);
    var $17 = $vp | 0;
    var $18 = $8;
    var $19$0 = HEAP32[$17 >> 2];
    var $19$1 = HEAP32[$17 + 4 >> 2];
    HEAP32[$18 >> 2] = $19$0;
    HEAP32[$18 + 4 >> 2] = $19$1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15its_addPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $idString = __stackBase__;
    var $valueString = __stackBase__ + 16;
    if ((HEAP32[__ZL9its_noisy >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN13IdStringifierC1EP9JSContextii($idString, $cx, $id, 0);
    var $4 = HEAP32[_gOutFile >> 2];
    var $5 = $idString | 0;
    var $6 = __ZN8ToString8getBytesEv($5);
    var $7 = _fprintf($4, STRING_TABLE.__str162455 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $6, tempInt));
    var $8 = $vp | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    __ZN8ToStringC1EP9JSContextN2JS5ValueEi($valueString, $cx, $9$0, $9$1, 0);
    var $10 = HEAP32[_gOutFile >> 2];
    var $11 = __ZN8ToString8getBytesEv($valueString);
    var $12 = _fprintf($10, STRING_TABLE.__str160453 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $11, tempInt));
    __ZN8ToStringD1Ev($valueString);
    __ZN13IdStringifierD1Ev($idString);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15its_delPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $idString = __stackBase__;
    var $valueString = __stackBase__ + 16;
    if ((HEAP32[__ZL9its_noisy >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN13IdStringifierC1EP9JSContextii($idString, $cx, $id, 0);
    var $4 = HEAP32[_gOutFile >> 2];
    var $5 = $idString | 0;
    var $6 = __ZN8ToString8getBytesEv($5);
    var $7 = _fprintf($4, STRING_TABLE.__str161454 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $6, tempInt));
    var $8 = $vp | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    __ZN8ToStringC1EP9JSContextN2JS5ValueEi($valueString, $cx, $9$0, $9$1, 0);
    var $10 = HEAP32[_gOutFile >> 2];
    var $11 = __ZN8ToString8getBytesEv($valueString);
    var $12 = _fprintf($10, STRING_TABLE.__str160453 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $11, tempInt));
    __ZN8ToStringD1Ev($valueString);
    __ZN13IdStringifierD1Ev($idString);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15its_getPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $idString = __stackBase__;
    var $valueString = __stackBase__ + 16;
    if ((HEAP32[__ZL9its_noisy >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN13IdStringifierC1EP9JSContextii($idString, $cx, $id, 0);
    var $4 = HEAP32[_gOutFile >> 2];
    var $5 = $idString | 0;
    var $6 = __ZN8ToString8getBytesEv($5);
    var $7 = _fprintf($4, STRING_TABLE.__str159452 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $6, tempInt));
    var $8 = $vp | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    __ZN8ToStringC1EP9JSContextN2JS5ValueEi($valueString, $cx, $9$0, $9$1, 0);
    var $10 = HEAP32[_gOutFile >> 2];
    var $11 = __ZN8ToString8getBytesEv($valueString);
    var $12 = _fprintf($10, STRING_TABLE.__str160453 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $11, tempInt));
    __ZN8ToStringD1Ev($valueString);
    __ZN13IdStringifierD1Ev($idString);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15its_setPropertyP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $idString = __stackBase__;
    var $valueString = __stackBase__ + 16;
    __ZN13IdStringifierC1EP9JSContextii($idString, $cx, $id, 0);
    if ((HEAP32[__ZL9its_noisy >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[_gOutFile >> 2];
    var $5 = $idString | 0;
    var $6 = __ZN8ToString8getBytesEv($5);
    var $7 = _fprintf($4, STRING_TABLE.__str155448 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $6, tempInt));
    var $8 = $vp | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    __ZN8ToStringC1EP9JSContextN2JS5ValueEi($valueString, $cx, $9$0, $9$1, 0);
    var $10 = HEAP32[_gOutFile >> 2];
    var $11 = __ZN8ToString8getBytesEv($valueString);
    var $12 = _fprintf($10, STRING_TABLE.__str156449 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $11, tempInt));
    __ZN8ToStringD1Ev($valueString);
    __label__ = 3;
    break;
   case 3:
    var $14 = __ZL12JSID_IS_ATOMi616($id);
    if (($14 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = $idString | 0;
    var $18 = __ZN8ToString8getBytesEv($17);
    var $19 = _strcmp($18, STRING_TABLE.__str157450 | 0);
    if (($19 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $22 = $vp | 0;
    var $st$1$0 = $22 | 0;
    var $23$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $22 + 4 | 0;
    var $23$1 = HEAP32[$st$1$1 >> 2];
    _JS_ValueToBoolean($23$0, $23$1, __ZL9its_noisy);
    __label__ = 8;
    break;
   case 6:
    var $25 = __ZN8ToString8getBytesEv($17);
    var $26 = _strcmp($25, STRING_TABLE.__str158451 | 0);
    if (($26 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $29 = $vp | 0;
    var $st$1$0 = $29 | 0;
    var $30$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $29 + 4 | 0;
    var $30$1 = HEAP32[$st$1$1 >> 2];
    _JS_ValueToBoolean($30$0, $30$1, __ZL13its_enum_fail);
    __label__ = 8;
    break;
   case 8:
    __ZN13IdStringifierD1Ev($idString);
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13its_enumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($enum_op | 0) == 3) {
      __label__ = 2;
      break;
    } else if (($enum_op | 0) == 0 || ($enum_op | 0) == 1) {
      __label__ = 3;
      break;
    } else if (($enum_op | 0) == 2) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 2:
    var $_pre_phi = $statep | 0;
    __label__ = 11;
    break;
   case 3:
    if ((HEAP32[__ZL9its_noisy >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $6 = HEAP32[_gOutFile >> 2];
    var $7 = _fwrite(STRING_TABLE.__str153446 | 0, 25, 1, $6);
    __label__ = 5;
    break;
   case 5:
    var $9 = _JS_NewPropertyIterator($cx, $obj);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _OBJECT_TO_JSVAL591($1, $9);
    var $12 = $1 | 0;
    var $st$2$0 = $12 | 0;
    var $13$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $12 + 4 | 0;
    var $13$1 = HEAP32[$st$2$1 >> 2];
    var $14 = $statep | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    if (($idp | 0) == 0) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$idp >> 2] = 1;
    var $_0 = 1;
    __label__ = 12;
    break;
   case 8:
    if ((HEAP32[__ZL13its_enum_fail >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    _JS_ReportError($cx, STRING_TABLE.__str154447 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 12;
    break;
   case 10:
    var $22 = $statep | 0;
    var $23$0 = HEAP32[$22 >> 2];
    var $23$1 = HEAP32[$22 + 4 >> 2];
    var $24 = _JSVAL_TO_OBJECT590($23$0, $23$1);
    _JS_NextProperty($24, $idp);
    var $25 = HEAP32[$idp >> 2];
    var $26 = _JSID_IS_VOID615($25);
    if (($26 | 0) == 0) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      var $_pre_phi = $22;
      __label__ = 11;
      break;
    }
   case 11:
    var $_pre_phi;
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $st$2$0 = $$emscripten$temp$0 | 0;
    var $29$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $$emscripten$temp$0 + 4 | 0;
    var $29$1 = HEAP32[$st$2$1 >> 2];
    HEAP32[$_pre_phi >> 2] = $29$0;
    HEAP32[$_pre_phi + 4 >> 2] = $29$1;
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13its_enumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi["X"] = 1;

function __ZL11its_resolveP9JSContextP8JSObjectijPS2_($cx, $obj, $id, $flags, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $idString = __stackBase__;
    if ((HEAP32[__ZL9its_noisy >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN13IdStringifierC1EP9JSContextii($idString, $cx, $id, 0);
    var $4 = HEAP32[_gOutFile >> 2];
    var $5 = $idString | 0;
    var $6 = __ZN8ToString8getBytesEv($5);
    var $9 = ($flags & 1 | 0) != 0 ? STRING_TABLE.__str150443 | 0 : __str17668 | 0;
    var $12 = ($flags & 2 | 0) != 0 ? STRING_TABLE.__str151444 | 0 : __str17668 | 0;
    var $15 = ($flags & 4 | 0) != 0 ? STRING_TABLE.__str152445 | 0 : __str17668 | 0;
    var $16 = _fprintf($4, STRING_TABLE.__str149442 | 0, (tempInt = STACKTOP, STACKTOP += 16, HEAP32[tempInt >> 2] = $6, HEAP32[tempInt + 4 >> 2] = $9, HEAP32[tempInt + 8 >> 2] = $12, HEAP32[tempInt + 12 >> 2] = $15, tempInt));
    __ZN13IdStringifierD1Ev($idString);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11its_convertP9JSContextP8JSObject6JSTypePN2JS5ValueE($cx, $obj, $type, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[__ZL9its_noisy >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[_gOutFile >> 2];
    var $5 = _JS_GetTypeName($type);
    var $6 = _fprintf($4, STRING_TABLE.__str148441 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $5, tempInt));
    __label__ = 3;
    break;
   case 3:
    var $8 = _JS_ConvertStub($cx, $obj, $type, $vp);
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12its_finalizeP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[__ZL9its_noisy >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[_gOutFile >> 2];
    var $5 = _fwrite(STRING_TABLE.__str147440 | 0, 14, 1, $4);
    __label__ = 3;
    break;
   case 3:
    var $obj_idx_val = HEAP32[$obj + 24 >> 2];
    var $7 = _JS_GetPrivate($obj_idx_val);
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7;
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    _JS_RemoveValueRoot($cx_idx_val, $10);
    _JS_SetPrivate($obj, 0);
    __ZdlPv($7);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16global_enumerateP9JSContextP8JSObject($cx, $obj) {
  var $1 = _JS_EnumerateStandardClasses($cx, $obj);
  return $1;
}

function __ZL14global_resolveP9JSContextP8JSObjectijPS2_($cx, $obj, $id, $flags, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $resolved = __stackBase__;
    var $1 = _JS_ResolveStandardClass($cx, $obj, $id, $resolved);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$resolved >> 2] | 0) == 0) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15env_setPropertyP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $idstr = __stackBase__;
    var $valstr = __stackBase__ + 16;
    var $1 = __stackBase__ + 32;
    __ZN13IdStringifierC1EP9JSContextii($idstr, $cx, $id, 1);
    var $2 = $idstr | 0;
    var $_idx1_val = HEAP32[$idstr + 4 >> 2];
    var $3 = __ZN8ToString5threwEv($_idx1_val);
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $6 = $vp | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    __ZN8ToStringC1EP9JSContextN2JS5ValueEi($valstr, $cx, $7$0, $7$1, 1);
    var $valstr_idx = $valstr + 4 | 0;
    var $valstr_idx_val = HEAP32[$valstr_idx >> 2];
    var $8 = __ZN8ToString5threwEv($valstr_idx_val);
    if (($8 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $11 = __ZN8ToString8getBytesEv($2);
    var $12 = __ZN8ToString8getBytesEv($valstr);
    var $13 = _setenv($11, $12, 1);
    if (($13 | 0) < 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = __ZN8ToString8getBytesEv($2);
    var $17 = __ZN8ToString8getBytesEv($valstr);
    _JS_ReportError($cx, STRING_TABLE.__str146439 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $16, HEAP32[tempInt + 4 >> 2] = $17, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 5:
    var $valstr_idx2_val = HEAP32[$valstr_idx >> 2];
    __ZN8ToString8getJSValEv($1, $valstr_idx2_val);
    var $19 = $1 | 0;
    var $20$0 = HEAP32[$19 >> 2];
    var $20$1 = HEAP32[$19 + 4 >> 2];
    HEAP32[$6 >> 2] = $20$0;
    HEAP32[$6 + 4 >> 2] = $20$1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN8ToStringD1Ev($valstr);
    var $_1 = $_0;
    __label__ = 7;
    break;
   case 7:
    var $_1;
    __ZN13IdStringifierD1Ev($idstr);
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13env_enumerateP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (HEAPU8[__ZZL13env_enumerateP9JSContextP8JSObjectE9reflected_b]) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $obj_idx_val = HEAP32[$obj + 24 >> 2];
    var $3 = _JS_GetPrivate($obj_idx_val);
    var $_idx = $1 | 0;
    var $evp_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $evp_0;
    var $6 = HEAP32[$evp_0 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _strchr($6, 61);
    if (($9 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $9 + 1 | 0;
    HEAP8[$9] = 0;
    var $13 = _JS_NewStringCopyZ($cx, $12);
    if (($13 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _STRING_TO_JSVAL599($1, $13);
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $16 = _JS_DefineProperty($cx, $obj, $6, $_idx_val$0, $_idx_val$1, 0, 0, 1);
    var $phitmp = ($16 | 0) == 0;
    HEAP8[$9] = 61;
    if ($phitmp) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    HEAP8[$9] = 61;
    var $_0 = 0;
    __label__ = 10;
    break;
   case 8:
    var $evp_0 = $evp_0 + 4 | 0;
    __label__ = 3;
    break;
   case 9:
    HEAP8[__ZZL13env_enumerateP9JSContextP8JSObjectE9reflected_b] = 1;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11env_resolveP9JSContextP8JSObjectijPS2_($cx, $obj, $id, $flags, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $idstr = __stackBase__;
    var $1 = __stackBase__ + 16;
    if (($flags & 2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 1;
      __label__ = 8;
      break;
    }
   case 2:
    __ZN13IdStringifierC1EP9JSContextii($idstr, $cx, $id, 1);
    var $_idx1_val = HEAP32[$idstr + 4 >> 2];
    var $5 = __ZN8ToString5threwEv($_idx1_val);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    var $8 = $idstr | 0;
    var $9 = __ZN8ToString8getBytesEv($8);
    var $10 = _getenv($9);
    if (($10 | 0) == 0) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = _JS_NewStringCopyZ($cx, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _STRING_TO_JSVAL599($1, $13);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $16 = _JS_DefineProperty($cx, $obj, $9, $_idx_val$0, $_idx_val$1, 0, 0, 1);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    __ZN13IdStringifierD1Ev($idstr);
    var $_1 = $_0;
    __label__ = 8;
    break;
   case 8:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z5ShellP9JSContextPN2js3cli12OptionParserEPPc($cx, $op, $envp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ar = __stackBase__;
    var $ac = __stackBase__ + 8;
    __ZN13JSAutoRequestC1EP9JSContext($ar, $cx);
    var $1 = __ZNK2js3cli12OptionParser13getBoolOptionEc($op, 110);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP8[__ZL19enableTypeInference] & 1 ^ 1;
    HEAP8[__ZL19enableTypeInference] = $5;
    var $6 = _JS_ToggleOptions($cx, 262144);
    __label__ = 3;
    break;
   case 3:
    var $8 = __ZL15NewGlobalObjectP9JSContext15CompartmentKind($cx, 1);
    if (($8 | 0) == 0) {
      var $_1 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN22JSAutoEnterCompartmentC1Ev($ac);
    var $11 = __ZN22JSAutoEnterCompartment5enterEP9JSContextP8JSObject($ac, $cx, $8);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 5:
    _JS_SetGlobalObject($cx, $8);
    var $13 = _JS_DefineObject($cx, $8, STRING_TABLE.__str87380 | 0, __ZL9env_class);
    if (($13 | 0) == 0) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = $envp;
    _JS_SetPrivate($13, $16);
    var $17 = __ZL11ProcessArgsP9JSContextP8JSObjectPN2js3cli12OptionParserE($cx, $8, $op);
    if (HEAPU8[__ZL22enableDisassemblyDumps_b]) {
      __label__ = 7;
      break;
    } else {
      var $_0 = $17;
      __label__ = 8;
      break;
    }
   case 7:
    var $19 = $cx;
    _JS_DumpCompartmentBytecode($19);
    var $_0 = $17;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    var $ac_idx_val = HEAP32[$ac >> 2];
    __ZN22JSAutoEnterCompartmentD1Ev($ac_idx_val);
    var $_1 = $_0;
    __label__ = 9;
    break;
   case 9:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSAutoRequestC1EP9JSContext($this, $cx) {
  __ZN13JSAutoRequestC2EP9JSContext($this, $cx);
  return;
}

function __ZN22JSAutoEnterCompartmentC1Ev($this) {
  __ZN22JSAutoEnterCompartmentC2Ev($this);
  return;
}

function __ZL11ProcessArgsP9JSContextP8JSObjectPN2js3cli12OptionParserE($cx, $obj, $op) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $filePaths = __stackBase__;
    var $codeChunks = __stackBase__ + 8;
    var $rval = __stackBase__ + 16;
    var $1 = __ZNK2js3cli12OptionParser13getBoolOptionEc($op, 97);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = _JS_ToggleOptions($cx, 65536);
    __label__ = 3;
    break;
   case 3:
    var $5 = __ZNK2js3cli12OptionParser13getBoolOptionEc($op, 109);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP8[__ZL15enableMethodJit_b] = 1;
    var $7 = _JS_ToggleOptions($cx, 16384);
    __label__ = 5;
    break;
   case 5:
    var $9 = __ZNK2js3cli12OptionParser13getBoolOptionEc($op, 106);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP8[__ZL14enableTraceJit_b] = 1;
    var $11 = _JS_ToggleOptions($cx, 2048);
    __label__ = 7;
    break;
   case 7:
    var $13 = __ZNK2js3cli12OptionParser13getBoolOptionEc($op, 112);
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $15 = _JS_ToggleOptions($cx, 32768);
    __label__ = 9;
    break;
   case 9:
    var $17 = __ZNK2js3cli12OptionParser13getBoolOptionEc($op, 100);
    if ($17) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    var $19 = _JS_GetRuntime($cx_idx_val);
    var $20 = $19;
    _JS_SetRuntimeDebugMode($20);
    var $21 = $cx;
    var $22 = _JS_SetDebugMode($21, 1);
    __label__ = 11;
    break;
   case 11:
    var $24 = __ZNK2js3cli12OptionParser13getBoolOptionEc($op, 98);
    if ($24) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    HEAP8[__ZL11printTiming_b] = 1;
    __label__ = 13;
    break;
   case 13:
    var $27 = __ZNK2js3cli12OptionParser13getBoolOptionEc($op, 68);
    if ($27) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    HEAP8[__ZL22enableDisassemblyDumps_b] = 1;
    __label__ = 15;
    break;
   case 15:
    var $30 = __ZL14BindScriptArgsP9JSContextP8JSObjectPN2js3cli12OptionParserE($cx, $obj, $op);
    if ($30) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 1;
      __label__ = 37;
      break;
    }
   case 16:
    __ZNK2js3cli12OptionParser20getMultiStringOptionEc($filePaths, $op, 102);
    __ZNK2js3cli12OptionParser20getMultiStringOptionEc($codeChunks, $op, 101);
    var $filePaths_idx9 = $filePaths | 0;
    var $filePaths_idx9_val = HEAP32[$filePaths_idx9 >> 2];
    var $filePaths_idx10 = $filePaths + 4 | 0;
    var $filePaths_idx10_val = HEAP32[$filePaths_idx10 >> 2];
    var $32 = __ZNK2js3cli16MultiStringRange5emptyEv($filePaths_idx9_val, $filePaths_idx10_val);
    var $codeChunks_idx7 = $codeChunks | 0;
    if ($32) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $codeChunks_idx3_pre_phi = $codeChunks_idx7;
    var $codeChunks_idx4_pre_phi = $codeChunks + 4 | 0;
    __label__ = 20;
    break;
   case 18:
    var $codeChunks_idx7_val = HEAP32[$codeChunks_idx7 >> 2];
    var $codeChunks_idx8 = $codeChunks + 4 | 0;
    var $codeChunks_idx8_val = HEAP32[$codeChunks_idx8 >> 2];
    var $34 = __ZNK2js3cli16MultiStringRange5emptyEv($codeChunks_idx7_val, $codeChunks_idx8_val);
    if ($34) {
      __label__ = 19;
      break;
    } else {
      var $codeChunks_idx3_pre_phi = $codeChunks_idx7;
      var $codeChunks_idx4_pre_phi = $codeChunks_idx8;
      __label__ = 20;
      break;
    }
   case 19:
    var $36 = __ZNK2js3cli12OptionParser12getStringArgEPKc($op);
    if (($36 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      var $codeChunks_idx3_pre_phi = $codeChunks_idx7;
      var $codeChunks_idx4_pre_phi = $codeChunks_idx8;
      __label__ = 20;
      break;
    }
   case 20:
    var $codeChunks_idx4_pre_phi;
    var $codeChunks_idx3_pre_phi;
    var $filePaths_idx14_val = $filePaths_idx9_val;
    var $filePaths_idx2_val = $filePaths_idx10_val;
    __label__ = 22;
    break;
   case 21:
    __ZL7ProcessP9JSContextP8JSObjectPKcb($cx, $obj, 0, 1);
    var $_0 = HEAP32[_gExitCode >> 2];
    __label__ = 37;
    break;
   case 22:
    var $filePaths_idx2_val;
    var $filePaths_idx14_val;
    var $40 = __ZNK2js3cli16MultiStringRange5emptyEv($filePaths_idx14_val, $filePaths_idx2_val);
    if ($40) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $codeChunks_idx3_val = HEAP32[$codeChunks_idx3_pre_phi >> 2];
    var $codeChunks_idx4_val = HEAP32[$codeChunks_idx4_pre_phi >> 2];
    var $42 = __ZNK2js3cli16MultiStringRange5emptyEv($codeChunks_idx3_val, $codeChunks_idx4_val);
    if ($42) {
      __label__ = 32;
      break;
    } else {
      var $45 = -1;
      __label__ = 25;
      break;
    }
   case 24:
    var $filePaths_idx14_val_idx_val = HEAP32[$filePaths_idx14_val + 4 >> 2];
    var $44 = __ZNK2js3cli16MultiStringRange5argnoEv($filePaths_idx14_val_idx_val);
    var $45 = $44;
    __label__ = 25;
    break;
   case 25:
    var $45;
    var $codeChunks_idx_val = HEAPU32[$codeChunks_idx3_pre_phi >> 2];
    var $codeChunks_idx1_val = HEAP32[$codeChunks_idx4_pre_phi >> 2];
    var $46 = __ZNK2js3cli16MultiStringRange5emptyEv($codeChunks_idx_val, $codeChunks_idx1_val);
    if ($46) {
      var $50 = -1;
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $codeChunks_idx13_val_idx_val = HEAP32[$codeChunks_idx_val + 4 >> 2];
    var $48 = __ZNK2js3cli16MultiStringRange5argnoEv($codeChunks_idx13_val_idx_val);
    var $50 = $48;
    __label__ = 27;
    break;
   case 27:
    var $50;
    if ($45 >>> 0 < $50 >>> 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 28:
    var $filePaths_idx12_val_idx_val = HEAP32[$filePaths_idx14_val >> 2];
    var $53 = __ZNK2js3cli16MultiStringRange5frontEv($filePaths_idx12_val_idx_val);
    __ZL7ProcessP9JSContextP8JSObjectPKcb($cx, $obj, $53, 0);
    var $54 = HEAPU32[_gExitCode >> 2];
    if (($54 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      var $_0 = $54;
      __label__ = 37;
      break;
    }
   case 29:
    __ZN2js3cli16MultiStringRange8popFrontEv($filePaths);
    var $filePaths_idx14_val = HEAP32[$filePaths_idx9 >> 2];
    var $filePaths_idx2_val = HEAP32[$filePaths_idx10 >> 2];
    __label__ = 22;
    break;
   case 30:
    var $codeChunks_idx11_val_idx_val = HEAP32[$codeChunks_idx_val >> 2];
    var $58 = __ZNK2js3cli16MultiStringRange5frontEv($codeChunks_idx11_val_idx_val);
    var $59 = _strlen($58);
    var $60 = _JS_EvaluateScript($cx, $obj, $58, $59, $rval);
    if (($60 | 0) == 0) {
      var $_0 = 1;
      __label__ = 37;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    __ZN2js3cli16MultiStringRange8popFrontEv($codeChunks);
    var $filePaths_idx14_val = $filePaths_idx14_val;
    var $filePaths_idx2_val = $filePaths_idx2_val;
    __label__ = 22;
    break;
   case 32:
    var $64 = __ZNK2js3cli12OptionParser12getStringArgEPKc($op);
    if (($64 | 0) == 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    __ZL7ProcessP9JSContextP8JSObjectPKcb($cx, $obj, $64, 0);
    var $67 = HEAP32[_gExitCode >> 2];
    if (($67 | 0) == 0) {
      __label__ = 34;
      break;
    } else {
      var $_0 = $67;
      __label__ = 37;
      break;
    }
   case 34:
    var $70 = __ZNK2js3cli12OptionParser13getBoolOptionEc($op, 105);
    if ($70) {
      __label__ = 35;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 35:
    __ZL7ProcessP9JSContextP8JSObjectPKcb($cx, $obj, 0, 1);
    __label__ = 36;
    break;
   case 36:
    var $_0 = HEAP32[_gExitCode >> 2];
    __label__ = 37;
    break;
   case 37:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11ProcessArgsP9JSContextP8JSObjectPN2js3cli12OptionParserE["X"] = 1;

function __ZN22JSAutoEnterCompartmentD1Ev($this_0_0_val) {
  __ZN22JSAutoEnterCompartmentD2Ev($this_0_0_val);
  return;
}

function __ZL12InitWatchdogP9JSRuntime($rt) {
  HEAP32[__ZL8gRuntime >> 2] = $rt;
  return;
}

function __ZN2js3cli6detail10BoolOptionD1Ev($this) {
  return;
}

function __ZNK2js3cli6detail6Option8isValuedEv($this) {
  return 0;
}

function __ZNK2js3cli6detail6Option10isVariadicEv($this) {
  return 0;
}

function __ZNK2js3cli16MultiStringRange5argnoEv($this_0_0_val_0_1_val) {
  return $this_0_0_val_0_1_val;
}

function __ZNK2js3cli16MultiStringRange5frontEv($this_0_0_val_0_0_val) {
  return $this_0_0_val_0_0_val;
}

function __ZNK2js3cli16MultiStringRange5emptyEv($this_0_0_val, $this_0_1_val) {
  return ($this_0_0_val | 0) == ($this_0_1_val | 0);
}

function __ZN2js3cli12OptionParser14setDescriptionEPKc($this) {
  HEAP32[$this + 76 >> 2] = STRING_TABLE.__str93386 | 0;
  return;
}

function __ZN2js3cli12OptionParser19setDescriptionWidthEj($this) {
  HEAP32[$this + 80 >> 2] = 72;
  return;
}

function __ZN2js3cli12OptionParser12setHelpWidthEj($this) {
  HEAP32[$this + 84 >> 2] = 80;
  return;
}

function __ZN2js3cli12OptionParser10setVersionEPKc($this) {
  HEAP32[$this + 72 >> 2] = STRING_TABLE.__str21214 | 0;
  return;
}

function __ZN2js3cli6detail6OptionC2ENS1_10OptionKindEcPKcS5_($this, $kind, $shortflag, $longflag, $help) {
  HEAP32[$this >> 2] = __ZTVN2js3cli6detail6OptionE + 8 | 0;
  HEAP32[$this + 4 >> 2] = $longflag;
  HEAP32[$this + 8 >> 2] = $help;
  HEAP32[$this + 12 >> 2] = $kind;
  HEAP8[$this + 16 | 0] = $shortflag;
  HEAP8[$this + 17 | 0] = 0;
  return;
}

function _main($argc, $argv, $envp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 92;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $op = __stackBase__;
    var $1 = _setlocale(0, __str17668 | 0);
    var $2 = HEAP32[_stderr >> 2];
    __ZL27MaybeOverrideOutFileFromEnvPKcP7__sFILEPS2_(STRING_TABLE.__str90383 | 0, $2, _gErrFile);
    var $3 = HEAP32[_stdout >> 2];
    __ZL27MaybeOverrideOutFileFromEnvPKcP7__sFILEPS2_(STRING_TABLE.__str91384 | 0, $3, _gOutFile);
    __ZN2js3cli12OptionParserC1EPKc($op);
    __ZN2js3cli12OptionParser14setDescriptionEPKc($op);
    __ZN2js3cli12OptionParser19setDescriptionWidthEj($op);
    __ZN2js3cli12OptionParser12setHelpWidthEj($op);
    __ZN2js3cli12OptionParser10setVersionEPKc($op);
    var $4 = __ZN2js3cli12OptionParser20addMultiStringOptionEcPKcS3_S3_($op, 102, STRING_TABLE.__str94387 | 0, STRING_TABLE.__str95388 | 0, STRING_TABLE.__str96389 | 0);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 26;
      break;
    }
   case 2:
    var $6 = __ZN2js3cli12OptionParser20addMultiStringOptionEcPKcS3_S3_($op, 101, STRING_TABLE.__str97390 | 0, STRING_TABLE.__str98391 | 0, STRING_TABLE.__str99392 | 0);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 26;
      break;
    }
   case 3:
    var $8 = __ZN2js3cli12OptionParser13addBoolOptionEcPKcS3_($op, 105, STRING_TABLE.__str100393 | 0, STRING_TABLE.__str101394 | 0);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 26;
      break;
    }
   case 4:
    var $10 = __ZN2js3cli12OptionParser13addBoolOptionEcPKcS3_($op, 109, STRING_TABLE.__str102395 | 0, STRING_TABLE.__str103396 | 0);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 26;
      break;
    }
   case 5:
    var $12 = __ZN2js3cli12OptionParser13addBoolOptionEcPKcS3_($op, 106, STRING_TABLE.__str104397 | 0, STRING_TABLE.__str105398 | 0);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 26;
      break;
    }
   case 6:
    var $14 = __ZN2js3cli12OptionParser13addBoolOptionEcPKcS3_($op, 112, STRING_TABLE.__str106399 | 0, STRING_TABLE.__str107400 | 0);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 26;
      break;
    }
   case 7:
    var $16 = __ZN2js3cli12OptionParser13addBoolOptionEcPKcS3_($op, 110, STRING_TABLE.__str108401 | 0, STRING_TABLE.__str109402 | 0);
    if ($16) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 26;
      break;
    }
   case 8:
    var $18 = __ZN2js3cli12OptionParser13addBoolOptionEcPKcS3_($op, 100, STRING_TABLE.__str110403 | 0, STRING_TABLE.__str111404 | 0);
    if ($18) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 1;
      __label__ = 26;
      break;
    }
   case 9:
    var $20 = __ZN2js3cli12OptionParser13addBoolOptionEcPKcS3_($op, 97, STRING_TABLE.__str112405 | 0, STRING_TABLE.__str113406 | 0);
    if ($20) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 26;
      break;
    }
   case 10:
    var $22 = __ZN2js3cli12OptionParser13addBoolOptionEcPKcS3_($op, 68, STRING_TABLE.__str114407 | 0, STRING_TABLE.__str115408 | 0);
    if ($22) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 26;
      break;
    }
   case 11:
    var $24 = __ZN2js3cli12OptionParser13addBoolOptionEcPKcS3_($op, 98, STRING_TABLE.__str116409 | 0, STRING_TABLE.__str117410 | 0);
    if ($24) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 1;
      __label__ = 26;
      break;
    }
   case 12:
    var $26 = __ZN2js3cli12OptionParser13addBoolOptionEcPKcS3_($op, 85, STRING_TABLE.__str118411 | 0, STRING_TABLE.__str119412 | 0);
    if ($26) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 1;
      __label__ = 26;
      break;
    }
   case 13:
    var $28 = __ZN2js3cli12OptionParser20addOptionalStringArgEPKcS3_($op);
    if ($28) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 1;
      __label__ = 26;
      break;
    }
   case 14:
    var $30 = __ZN2js3cli12OptionParser25addOptionalMultiStringArgEPKcS3_($op);
    if ($30) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 1;
      __label__ = 26;
      break;
    }
   case 15:
    __ZN2js3cli12OptionParser23setArgTerminatesOptionsEPKcb($op);
    var $32 = __ZN2js3cli12OptionParser9parseArgsEiPPc($op, $argc, $argv);
    if (($32 | 0) == 2) {
      __label__ = 16;
      break;
    } else if (($32 | 0) == 1) {
      __label__ = 17;
      break;
    } else if (($32 | 0) == 3) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 16:
    var $34 = HEAP32[$argv >> 2];
    __ZN2js3cli12OptionParser9printHelpEPKc($op, $34);
    var $_0 = 1;
    __label__ = 26;
    break;
   case 17:
    var $_0 = 1;
    __label__ = 26;
    break;
   case 18:
    var $op_idx_val = HEAP8[$op + 64 | 0];
    var $37 = __ZNK2js3cli12OptionParser13getHelpOptionEv($op_idx_val);
    if ($37) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $39 = __ZNK2js3cli12OptionParser13getBoolOptionEc($op, 85);
    if ($39) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    _JS_SetCStringsAreUTF8();
    __label__ = 21;
    break;
   case 21:
    var $42 = _JS_Init();
    if (($42 | 0) == 0) {
      var $_0 = 1;
      __label__ = 26;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    _JS_SetGCParameter($42, 0, -1);
    _JS_SetTrustedPrincipals($42);
    _JS_SetRuntimeSecurityCallbacks($42);
    __ZL12InitWatchdogP9JSRuntime($42);
    var $45 = __ZL10NewContextP9JSRuntime($42);
    if (($45 | 0) == 0) {
      var $_0 = 1;
      __label__ = 26;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    _JS_SetGCParameter($42, 6, 1);
    var $48 = __ZNK2js3cli12OptionParser13getBoolOptionEc($op, 68);
    if ($48) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $50 = _JS_ToggleOptions($45, 131072);
    __label__ = 25;
    break;
   case 25:
    var $52 = __Z5ShellP9JSContextPN2js3cli12OptionParserEPPc($45, $op, $envp);
    __ZL14DestroyContextP9JSContextb($45, 1);
    __ZL12KillWatchdogv();
    _JS_Finish($42);
    var $_0 = $52;
    __label__ = 26;
    break;
   case 26:
    var $_0;
    __ZN2js3cli12OptionParserD2Ev($op);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

Module["_main"] = _main;

_main["X"] = 1;

function __ZL27MaybeOverrideOutFileFromEnvPKcP7__sFILEPS2_($envVar, $defaultOut, $outFile) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _getenv($envVar);
    if (($1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (HEAP8[$1] << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = _fopen($1, STRING_TABLE.__str133426 | 0);
    var $8 = $7;
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $storemerge = $8;
      __label__ = 5;
      break;
    }
   case 4:
    var $storemerge = $defaultOut;
    __label__ = 5;
    break;
   case 5:
    var $storemerge;
    HEAP32[$outFile >> 2] = $storemerge;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js3cli12OptionParserC1EPKc($this) {
  __ZN2js3cli12OptionParserC2EPKc($this);
  return;
}

function __ZL10NewContextP9JSRuntime($rt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __ZL16ScheduleWatchdogP9JSRuntimed(-1);
    var $1 = _JS_NewContext($rt);
    var $2 = (tempDoubleI32[0] = HEAP32[__ZL16gTimeoutInterval >> 2], tempDoubleI32[1] = HEAP32[__ZL16gTimeoutInterval + 4 >> 2], tempDoubleF64[0]);
    __ZL16ScheduleWatchdogP9JSRuntimed($2);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL14NewContextDatav();
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZL14DestroyContextP9JSContextb($1, 0);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 4:
    var $9 = $5;
    _JS_SetContextPrivate($1, $9);
    var $10 = _JS_SetErrorReporter($1, 298);
    var $11 = _JS_SetVersion($1, 185);
    __ZL17SetContextOptionsP9JSContext($1);
    if (HEAPU8[__ZL14enableTraceJit_b]) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $13 = _JS_ToggleOptions($1, 2048);
    __label__ = 6;
    break;
   case 6:
    if (HEAPU8[__ZL15enableMethodJit_b]) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $16 = _JS_ToggleOptions($1, 16384);
    __label__ = 8;
    break;
   case 8:
    if ((HEAP8[__ZL19enableTypeInference] & 1) << 24 >> 24 == 0) {
      var $_0 = $1;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $22 = _JS_ToggleOptions($1, 262144);
    var $_0 = $1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14DestroyContextP9JSContextb($cx, $withGC) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cx_idx_val = HEAP32[$cx + 188 >> 2];
    var $1 = __ZL14GetContextDataP9JSContext($cx_idx_val);
    _JS_SetContextPrivate($cx, 0);
    var $2 = $1;
    _free($2);
    __ZL16ScheduleWatchdogP9JSRuntimed(-1);
    if ($withGC) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_DestroyContext($cx);
    __label__ = 4;
    break;
   case 3:
    _JS_DestroyContextNoGC($cx);
    __label__ = 4;
    break;
   case 4:
    var $6 = (tempDoubleI32[0] = HEAP32[__ZL16gTimeoutInterval >> 2], tempDoubleI32[1] = HEAP32[__ZL16gTimeoutInterval + 4 >> 2], tempDoubleF64[0]);
    __ZL16ScheduleWatchdogP9JSRuntimed($6);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12KillWatchdogv() {
  __ZL16ScheduleWatchdogP9JSRuntimed(-1);
  return;
}

function __ZL16ScheduleWatchdogP9JSRuntimed($t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($t > 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = _alarm(0);
    var $4 = _signal(14, 0);
    __label__ = 4;
    break;
   case 3:
    var $6 = _signal(14, 300);
    var $7 = _ceil($t);
    var $8 = $7 >= 0 ? Math.floor($7) : Math.ceil($7);
    var $9 = _alarm($8);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12AlarmHandleri($sig) {
  var $1 = HEAP32[__ZL8gRuntime >> 2];
  __ZL15CancelExecutionP9JSRuntime($1);
  return;
}

function __ZL15CancelExecutionP9JSRuntime($rt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP8[__ZL9gCanceled] = 1;
    if ((HEAP32[_gExitCode >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[_gExitCode >> 2] = 6;
    __label__ = 3;
    break;
   case 3:
    _JS_TriggerAllOperationCallbacks($rt);
    var $5 = _write(2, STRING_TABLE.__ZZL15CancelExecutionP9JSRuntimeE3msg | 0, 39);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14GetContextDataP9JSContext($cx_0_24_val) {
  var $1 = _JS_GetContextPrivate($cx_0_24_val);
  return $1;
}

function __ZL14NewContextDatav() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[__ZL9gCanceled] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = _calloc(4);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $5;
    var $9 = __Z14js_IntervalNowv();
    HEAP32[$5 >> 2] = $9;
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16my_ErrorReporterP9JSContextPKcP13JSErrorReport($cx, $message, $report) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($report | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[_gErrFile >> 2];
    var $4 = _fprintf($3, STRING_TABLE.__str124417 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $message, tempInt));
    var $5 = HEAP32[_gErrFile >> 2];
    var $6 = _fflush($5);
    __label__ = 33;
    break;
   case 3:
    var $8 = $report + 24 | 0;
    var $10 = HEAP32[$report >> 2];
    if (($10 | 0) == 0) {
      var $prefix_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = _JS_smprintf(STRING_TABLE.__str125418 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $10, tempInt));
    var $prefix_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $prefix_0;
    var $16 = HEAP32[$report + 4 >> 2];
    if (($16 | 0) == 0) {
      var $prefix_1 = $prefix_0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = ($prefix_0 | 0) != 0 ? $prefix_0 : __str17668 | 0;
    var $21 = _JS_smprintf(STRING_TABLE.__str126419 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $20, HEAP32[tempInt + 4 >> 2] = $16, tempInt));
    _JS_free($prefix_0);
    var $prefix_1 = $21;
    __label__ = 7;
    break;
   case 7:
    var $prefix_1;
    var $23 = HEAP32[$8 >> 2];
    if (($23 & 1 | 0) == 0) {
      var $prefix_2_ph = $prefix_1;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $28 = ($prefix_1 | 0) != 0 ? $prefix_1 : __str17668 | 0;
    var $31 = ($23 & 4 | 0) != 0 ? STRING_TABLE.__str128421 | 0 : __str17668 | 0;
    var $32 = _JS_smprintf(STRING_TABLE.__str127420 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $28, HEAP32[tempInt + 4 >> 2] = $31, tempInt));
    _JS_free($prefix_1);
    var $prefix_2_ph = $32;
    __label__ = 9;
    break;
   case 9:
    var $prefix_2_ph;
    var $33 = _strchr($message, 10);
    var $_pre1 = ($prefix_2_ph | 0) == 0;
    if (($33 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_06 = $message;
      var $35 = $33;
      __label__ = 11;
      break;
    }
   case 10:
    if ($_pre1) {
      var $_0_lcssa3 = $message;
      __label__ = 16;
      break;
    } else {
      var $_0_lcssa2 = $message;
      __label__ = 15;
      break;
    }
   case 11:
    var $35;
    var $_06;
    var $36 = $35 + 1 | 0;
    if ($_pre1) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $38 = HEAP32[_gErrFile >> 2];
    var $39 = _fputs($prefix_2_ph, $38);
    __label__ = 13;
    break;
   case 13:
    var $44 = HEAP32[_gErrFile >> 2];
    var $45 = _fwrite($_06, 1, $36 - $_06 | 0, $44);
    var $46 = _strchr($36, 10);
    if (($46 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      var $_06 = $36;
      var $35 = $46;
      __label__ = 11;
      break;
    }
   case 14:
    if ($_pre1) {
      var $_0_lcssa3 = $36;
      __label__ = 16;
      break;
    } else {
      var $_0_lcssa2 = $36;
      __label__ = 15;
      break;
    }
   case 15:
    var $_0_lcssa2;
    var $49 = HEAP32[_gErrFile >> 2];
    var $50 = _fputs($prefix_2_ph, $49);
    var $_0_lcssa3 = $_0_lcssa2;
    __label__ = 16;
    break;
   case 16:
    var $_0_lcssa3;
    var $52 = HEAP32[_gErrFile >> 2];
    var $53 = _fputs($_0_lcssa3, $52);
    var $54 = $report + 8 | 0;
    var $55 = HEAP32[$54 >> 2];
    if (($55 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $59 = HEAP32[_gErrFile >> 2];
    var $60 = _fputc(10, $59);
    __label__ = 28;
    break;
   case 18:
    var $62 = _strlen($55);
    var $63 = HEAP32[_gErrFile >> 2];
    if (($62 | 0) > 0) {
      __label__ = 19;
      break;
    } else {
      var $71 = STRING_TABLE.__str130423 | 0;
      __label__ = 20;
      break;
    }
   case 19:
    var $phitmp = HEAP8[$55 + ($62 - 1) | 0] << 24 >> 24 == 10 ? __str17668 | 0 : STRING_TABLE.__str130423 | 0;
    var $71 = $phitmp;
    __label__ = 20;
    break;
   case 20:
    var $71;
    var $72 = _fprintf($63, STRING_TABLE.__str129422 | 0, (tempInt = STACKTOP, STACKTOP += 16, HEAP32[tempInt >> 2] = $prefix_2_ph, HEAP32[tempInt + 4 >> 2] = $55, HEAP32[tempInt + 8 >> 2] = $71, HEAP32[tempInt + 12 >> 2] = $prefix_2_ph, tempInt));
    var $75 = HEAP32[$54 >> 2];
    var $78 = HEAP32[$report + 12 >> 2] - $75 | 0;
    if (($78 | 0) > 0) {
      var $j_03 = 0;
      var $i_04 = 0;
      var $80 = $75;
      __label__ = 21;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 21:
    var $80;
    var $i_04;
    var $j_03;
    if (HEAP8[$80 + $i_04 | 0] << 24 >> 24 == 9) {
      __label__ = 22;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 22:
    var $86 = $j_03 + 8 & -8;
    if (($j_03 | 0) < ($86 | 0)) {
      var $j_12 = $j_03;
      __label__ = 23;
      break;
    } else {
      var $j_2 = $j_03;
      __label__ = 25;
      break;
    }
   case 23:
    var $j_12;
    var $89 = HEAP32[_gErrFile >> 2];
    var $90 = _fputc(46, $89);
    var $91 = $j_12 + 1 | 0;
    if (($91 | 0) == ($86 | 0)) {
      var $j_2 = $86;
      __label__ = 25;
      break;
    } else {
      var $j_12 = $91;
      __label__ = 23;
      break;
    }
   case 24:
    var $94 = HEAP32[_gErrFile >> 2];
    var $95 = _fputc(46, $94);
    var $j_2 = $j_03 + 1 | 0;
    __label__ = 25;
    break;
   case 25:
    var $j_2;
    var $97 = $i_04 + 1 | 0;
    if (($97 | 0) == ($78 | 0)) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $j_03 = $j_2;
    var $i_04 = $97;
    var $80 = HEAP32[$54 >> 2];
    __label__ = 21;
    break;
   case 27:
    var $98 = HEAP32[_gErrFile >> 2];
    var $99 = _fwrite(STRING_TABLE.__str131424 | 0, 2, 1, $98);
    __label__ = 28;
    break;
   case 28:
    var $101 = HEAP32[_gErrFile >> 2];
    var $102 = _fflush($101);
    if ((HEAP32[$8 >> 2] & 1 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 29:
    if ((HEAP32[$report + 28 >> 2] | 0) == 137) {
      __label__ = 30;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    HEAP32[_gExitCode >> 2] = 5;
    __label__ = 32;
    break;
   case 31:
    HEAP32[_gExitCode >> 2] = 3;
    __label__ = 32;
    break;
   case 32:
    _JS_free($prefix_2_ph);
    __label__ = 33;
    break;
   case 33:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16my_ErrorReporterP9JSContextPKcP13JSErrorReport["X"] = 1;

function __ZL17SetContextOptionsP9JSContext($cx) {
  _JS_SetNativeStackQuota($cx);
  _JS_SetOperationCallback($cx);
  return;
}

function __ZL22ShellOperationCallbackP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[__ZL9gCanceled] & 1) << 24 >> 24 == 0) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_ClearPendingException($cx);
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js3cli12OptionParserC2EPKc($this) {
  var $1 = $this | 0;
  __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEEC1ES5_($1);
  var $2 = $this + 20 | 0;
  __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEEC1ES5_($2);
  var $3 = $this + 40 | 0;
  __ZN2js3cli6detail10BoolOptionC1EcPKcS4_($3, 104, STRING_TABLE.__str18311 | 0, STRING_TABLE.__str132425 | 0);
  HEAP32[$this + 68 >> 2] = STRING_TABLE.__str92385 | 0;
  HEAP32[$this + 72 >> 2] = 0;
  HEAP32[$this + 76 >> 2] = 0;
  HEAP32[$this + 80 >> 2] = 80;
  HEAP32[$this + 84 >> 2] = 80;
  HEAP32[$this + 88 >> 2] = 0;
  return;
}

function __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEEC1ES5_($this) {
  __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEEC2ES5_($this);
  return;
}

function __ZN2js3cli6detail10BoolOptionC1EcPKcS4_($this, $shortflag, $longflag, $help) {
  __ZN2js3cli6detail10BoolOptionC2EcPKcS4_($this, $shortflag, $longflag, $help);
  return;
}

function __ZN2js3cli6detail10BoolOptionC2EcPKcS4_($this, $shortflag, $longflag, $help) {
  var $1 = $this | 0;
  __ZN2js3cli6detail6OptionC2ENS1_10OptionKindEcPKcS5_($1, 0, $shortflag, $longflag, $help);
  HEAP32[$this >> 2] = __ZTVN2js3cli6detail10BoolOptionE + 8 | 0;
  HEAP8[$this + 24 | 0] = 0;
  return;
}

function __ZN2js3cli6detail10BoolOptionD0Ev($this) {
  var $1 = $this;
  __ZdlPv($1);
  return;
}

function __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEEC2ES5_($this) {
  var $1 = $this | 0;
  var $2 = $this + 12 | 0;
  var $3 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($2);
  HEAP32[$1 >> 2] = $3;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN22JSAutoEnterCompartmentD2Ev($this_0_0_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($this_0_0_val >>> 0 < 2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_LeaveCrossCompartmentCall($this_0_0_val);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14BindScriptArgsP9JSContextP8JSObjectPN2js3cli12OptionParserE($cx, $obj, $op) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $msr = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    __ZNK2js3cli12OptionParser17getMultiStringArgEPKc($msr, $op);
    var $3 = _JS_NewArrayObject($cx);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL591($1, $3);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $$emscripten$temp$0 = STRING_TABLE.__str142435 | 0;
    var $6 = _JS_DefineProperty($cx, $obj, $$emscripten$temp$0, $_idx_val$0, $_idx_val$1, 0, 0, 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $msr_idx2 = $msr | 0;
    var $msr_idx1 = $msr + 4 | 0;
    var $_idx3 = $2 | 0;
    var $i_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_0;
    var $msr_idx_val = HEAP32[$msr_idx2 >> 2];
    var $msr_idx1_val = HEAP32[$msr_idx1 >> 2];
    var $8 = __ZNK2js3cli16MultiStringRange5emptyEv($msr_idx_val, $msr_idx1_val);
    if ($8) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $msr_idx2_val_idx_val = HEAP32[$msr_idx_val >> 2];
    var $10 = __ZNK2js3cli16MultiStringRange5frontEv($msr_idx2_val_idx_val);
    var $11 = _JS_NewStringCopyZ($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _STRING_TO_JSVAL599($2, $11);
    var $_idx3_val$0 = HEAP32[$_idx3 >> 2];
    var $_idx3_val$1 = HEAP32[$_idx3 + 4 >> 2];
    var $14 = _JS_DefineElement($cx, $3, $i_0, $_idx3_val$0, $_idx3_val$1);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2js3cli16MultiStringRange8popFrontEv($msr);
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 4;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL7ProcessP9JSContextP8JSObjectPKcb($cx, $obj, $filename, $forceTTY) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $uc_len = __stackBase__ + 8;
    var $suspended = __stackBase__ + 12;
    var $bytes = __stackBase__ + 20;
    if (($filename | 0) == 0 | $forceTTY) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = _strcmp($filename, STRING_TABLE.__str135428 | 0);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $file_0_in = HEAP32[_stdin >> 2];
    __label__ = 6;
    break;
   case 4:
    var $8 = _fopen($filename, STRING_TABLE.__str136429 | 0);
    if (($8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $file_0_in = $8;
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = ___errno();
    var $12 = HEAP32[$11 >> 2];
    var $13 = _strerror($12);
    _JS_ReportErrorNumber($cx, 286, 1, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $filename, HEAP32[tempInt + 4 >> 2] = $13, tempInt));
    HEAP32[_gExitCode >> 2] = 4;
    __label__ = 41;
    break;
   case 6:
    var $file_0_in;
    var $file_0 = $file_0_in;
    __ZL17SetContextOptionsP9JSContext($cx);
    if ($forceTTY) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $15 = $result | 0;
    var $16 = $cx;
    var $bytes_idx3 = $bytes | 0;
    var $hitEOF_0 = 0;
    var $buffer_0 = 0;
    var $size_0 = 0;
    var $lineno_0 = 1;
    __label__ = 14;
    break;
   case 8:
    var $18 = _fileno($file_0_in);
    var $19 = _isatty($18);
    if (($19 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 9:
    __ZL11SkipUTF8BOMP7__sFILE($file_0);
    var $22 = _fgetc($file_0);
    if (($22 | 0) == 35) {
      __label__ = 10;
      break;
    } else {
      var $ch_0 = $22;
      __label__ = 11;
      break;
    }
   case 10:
    var $24 = _fgetc($file_0);
    if (($24 | 0) == -1 || ($24 | 0) == 13 || ($24 | 0) == 10) {
      var $ch_0 = $24;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 11:
    var $ch_0;
    var $25 = _ungetc($ch_0, $file_0_in);
    var $26 = _PRMJ_Now();
    var $26$0 = $26[0];
    var $26$1 = $26[1];
    var $27 = _JS_GetOptions($cx);
    var $28 = $27 | 4112;
    _JS_SetOptions($cx, $28);
    var $29 = _JS_CompileFileHandle($cx, $obj, $filename, $file_0_in);
    _JS_SetOptions($cx, $27);
    if (($29 | 0) == 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $32 = _JS_ExecuteScript($cx, $obj, $29, 0);
    var $33 = _PRMJ_Now();
    var $33$0 = $33[0];
    var $33$1 = $33[1];
    if (HEAPU8[__ZL11printTiming_b]) {
      __label__ = 13;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 13:
    var $35$0 = (i64Math.subtract($33$0, $33$1, $26$0, $26$1), i64Math.result[0]);
    var $35$1 = i64Math.result[1];
    var $37 = ($35$0 + $35$1 * 4294967296) / 1e3;
    var $38 = _printf(STRING_TABLE.__str137430 | 0, (tempInt = STACKTOP, STACKTOP += 8, tempDoubleF64[0] = $37, HEAP32[tempInt >> 2] = tempDoubleI32[0], HEAP32[tempInt + 4 >> 2] = tempDoubleI32[1], tempInt));
    __label__ = 39;
    break;
   case 14:
    var $lineno_0;
    var $size_0;
    var $buffer_0;
    var $hitEOF_0;
    var $len_0 = 0;
    var $buffer_1 = $buffer_0;
    var $size_1 = $size_0;
    var $lineno_1 = $lineno_0;
    __label__ = 15;
    break;
   case 15:
    var $lineno_1;
    var $size_1;
    var $buffer_1;
    var $len_0;
    __ZL16ScheduleWatchdogP9JSRuntimed(-1);
    HEAP8[__ZL9gCanceled] = 0;
    var $41 = ___errno();
    HEAP32[$41 >> 2] = 0;
    __ZN20JSAutoSuspendRequestC1EP9JSContext($suspended, $cx);
    var $42 = ($lineno_0 | 0) == ($lineno_1 | 0);
    var $43 = $42 ? STRING_TABLE.__str138431 | 0 : __str17668 | 0;
    var $44 = __ZL7GetLineP7__sFILEPKc($file_0, $43);
    __ZN20JSAutoSuspendRequestD1Ev($suspended);
    if (($44 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 16:
    var $47 = ___errno();
    if ((HEAP32[$47 >> 2] | 0) == 0) {
      var $len_2 = $len_0;
      var $hitEOF_1 = 1;
      var $buffer_4 = $buffer_1;
      var $size_4 = $size_1;
      var $lineno_2 = $lineno_1;
      __label__ = 27;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $51 = ___errno();
    var $52 = HEAP32[$51 >> 2];
    var $53 = _strerror($52);
    _JS_ReportError($cx, $53, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    _free($buffer_1);
    __label__ = 39;
    break;
   case 18:
    var $55 = ($buffer_1 | 0) == 0;
    var $56 = _strlen($44);
    if ($55) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $len_1 = $56;
    var $buffer_3 = $44;
    var $size_3 = $56 + 1 | 0;
    __label__ = 26;
    break;
   case 20:
    var $60 = $len_0 + 1 | 0;
    var $_ = ($len_0 | 0) == 0 ? 0 : $60;
    var $62 = $56 + $_ | 0;
    var $63 = $62 + 1 | 0;
    if ($63 >>> 0 > $size_1 >>> 0) {
      __label__ = 21;
      break;
    } else {
      var $buffer_2 = $buffer_1;
      var $size_2 = $size_1;
      __label__ = 23;
      break;
    }
   case 21:
    var $66 = $size_1 << 1;
    var $_7 = $63 >>> 0 > $66 >>> 0 ? $63 : $66;
    var $68 = _realloc($buffer_1, $_7);
    if (($68 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      var $buffer_2 = $68;
      var $size_2 = $_7;
      __label__ = 23;
      break;
    }
   case 22:
    _free($buffer_1);
    _free($44);
    _JS_ReportOutOfMemory($cx);
    __label__ = 39;
    break;
   case 23:
    var $size_2;
    var $buffer_2;
    var $72 = $buffer_2 + $len_0 | 0;
    if ($42) {
      var $current_0 = $72;
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    HEAP8[$72] = 10;
    var $current_0 = $buffer_2 + $60 | 0;
    __label__ = 25;
    break;
   case 25:
    var $current_0;
    var $76 = _strcpy($current_0, $44);
    _free($44);
    var $len_1 = $62;
    var $buffer_3 = $buffer_2;
    var $size_3 = $size_2;
    __label__ = 26;
    break;
   case 26:
    var $size_3;
    var $buffer_3;
    var $len_1;
    var $78 = $lineno_1 + 1 | 0;
    var $79 = (tempDoubleI32[0] = HEAP32[__ZL16gTimeoutInterval >> 2], tempDoubleI32[1] = HEAP32[__ZL16gTimeoutInterval + 4 >> 2], tempDoubleF64[0]);
    __ZL16ScheduleWatchdogP9JSRuntimed($79);
    var $80 = _JS_BufferIsCompilableUnit($cx, $obj, $buffer_3, $len_1);
    if (($80 | 0) == 0) {
      var $len_0 = $len_1;
      var $buffer_1 = $buffer_3;
      var $size_1 = $size_3;
      var $lineno_1 = $78;
      __label__ = 15;
      break;
    } else {
      var $len_2 = $len_1;
      var $hitEOF_1 = $hitEOF_0;
      var $buffer_4 = $buffer_3;
      var $size_4 = $size_3;
      var $lineno_2 = $78;
      __label__ = 27;
      break;
    }
   case 27:
    var $lineno_2;
    var $size_4;
    var $buffer_4;
    var $hitEOF_1;
    var $len_2;
    var $82 = ($hitEOF_1 | 0) != 0;
    if ($82 & ($buffer_4 | 0) == 0) {
      __label__ = 38;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $85 = _JS_DecodeUTF8($cx, $buffer_4, $len_2, 0, $uc_len);
    if (($85 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 29:
    _JS_ReportError($cx, STRING_TABLE.__str139432 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[_gExitCode >> 2] = 3;
    __label__ = 41;
    break;
   case 30:
    var $90 = HEAP32[$uc_len >> 2] << 1;
    var $91 = _malloc($90);
    var $92 = $91;
    var $93 = _JS_DecodeUTF8($cx, $buffer_4, $len_2, $92, $uc_len);
    _JS_ClearPendingException($cx);
    var $94 = _JS_GetOptions($cx);
    var $95 = $94 | 16;
    _JS_SetOptions($cx, $95);
    var $96 = HEAP32[$uc_len >> 2];
    var $97 = _JS_CompileUCScript($cx, $obj, $92, $96, STRING_TABLE.__str140433 | 0, $lineno_0);
    _JS_SetOptions($cx, $94);
    if (($97 | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $100 = _JS_ExecuteScript($cx, $obj, $97, $result);
    if (($100 | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $st$0$0 = $15 | 0;
    var $103$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $15 + 4 | 0;
    var $103$1 = HEAP32[$st$0$1 >> 2];
    var $104 = _JSVAL_IS_VOID595($103$0, $103$1);
    if (($104 | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 33:
    var $st$0$0 = $15 | 0;
    var $107$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $15 + 4 | 0;
    var $107$1 = HEAP32[$st$0$1 >> 2];
    var $108 = _JS_ValueToSource($cx, $107$0, $107$1);
    if (($108 | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    __ZN16JSAutoByteStringC1EP9JSContextP8JSString($bytes, $16, $108);
    var $bytes_idx3_val = HEAP32[$bytes_idx3 >> 2];
    var $111 = __ZNK16JSAutoByteStringntEv($bytes_idx3_val);
    if ($111) {
      __label__ = 36;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $113 = HEAP32[_gOutFile >> 2];
    var $114 = __ZNK16JSAutoByteString3ptrEv($bytes_idx3_val);
    var $115 = _fprintf($113, STRING_TABLE.__str124417 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $114, tempInt));
    __label__ = 36;
    break;
   case 36:
    __ZN16JSAutoByteStringD1Ev($bytes_idx3_val);
    __label__ = 37;
    break;
   case 37:
    HEAP8[$buffer_4] = 0;
    _free($91);
    if (HEAPU8[_gQuitting_b] | $82) {
      __label__ = 38;
      break;
    } else {
      var $hitEOF_0 = $hitEOF_1;
      var $buffer_0 = $buffer_4;
      var $size_0 = $size_4;
      var $lineno_0 = $lineno_2;
      __label__ = 14;
      break;
    }
   case 38:
    _free($buffer_4);
    var $119 = HEAP32[_gOutFile >> 2];
    var $fputc = _fputc(10, $119);
    __label__ = 39;
    break;
   case 39:
    if (($file_0_in | 0) == (HEAP32[_stdin >> 2] | 0)) {
      __label__ = 41;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $124 = _fclose($file_0_in);
    __label__ = 41;
    break;
   case 41:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL7ProcessP9JSContextP8JSObjectPKcb["X"] = 1;

function _JSVAL_TO_BOOLEAN_IMPL626($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_TO_INT32_IMPL627($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_IS_UNDEFINED_IMPL597($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -126) & 1;
}

function __ZN8ToString5threwEv($this_0_1_val) {
  return ($this_0_1_val | 0) == 0 & 1;
}

function _JSID_IS_STRING604($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_TO_STRING605($iden) {
  return $iden;
}

function _JSID_IS_INT606($iden) {
  return $iden & 1;
}

function _JSID_TO_INT608($iden) {
  return $iden >> 1;
}

function _JSID_IS_OBJECT609($iden) {
  return ($iden & 7 | 0) == 4 & ($iden | 0) != 4 & 1;
}

function _JSID_TO_OBJECT610($iden) {
  return $iden & -8;
}

function _JSID_IS_VOID615($iden) {
  return ($iden | 0) == 2 & 1;
}

function _JSVAL_IS_BOOLEAN_IMPL618($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -125) & 1;
}

function _JSVAL_IS_OBJECT_OR_NULL_IMPL621($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 > 4294967173 & 1;
}

function _JSVAL_IS_INT32_IMPL628($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -127) & 1;
}

function __ZN2jsL8JsvalifyEPNS_10StackFrameE625($fp) {
  return $fp;
}

function __ZN2jsL8JsvalifyEPNS_5ClassE631($c) {
  return $c;
}

function __ZN2js3cli16MultiStringRange8popFrontEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] + 8 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZL13JSVAL_TO_IMPLN2JS5ValueE598($agg_result, $_0_0_0_val$0, $_0_0_0_val$1) {
  var $agg_result_0 = $agg_result | 0;
  HEAP32[$agg_result_0 >> 2] = $_0_0_0_val$0;
  HEAP32[$agg_result_0 + 4 >> 2] = $_0_0_0_val$1;
  return;
}

function __ZN20JSAutoSuspendRequest6resumeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN20JSAutoSuspendRequestC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZL13IMPL_TO_JSVAL12jsval_layout600($agg_result, $l_0$0, $l_0$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $l_0$0;
  HEAP32[$1 + 4 >> 2] = $l_0$1;
  return;
}

function _STRING_TO_JSVAL_IMPL601($agg_result, $str) {
  HEAP32[$agg_result + 4 >> 2] = -123;
  HEAP32[$agg_result >> 2] = $str;
  return;
}

function __ZN22JSAutoEnterCompartmentC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  return;
}

function __ZN13JSAutoRequestC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function _INT32_TO_JSVAL_IMPL613($agg_result, $i) {
  HEAP32[$agg_result + 4 >> 2] = -127;
  HEAP32[$agg_result >> 2] = $i;
  return;
}

function __ZN12FreeOnReturn4initEPKc($this, $ptr) {
  HEAP32[$this + 4 >> 2] = $ptr;
  return;
}

function __ZN12FreeOnReturnC2EP9JSContextPKc($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js15AutoValueRooter10jsval_addrEv($this) {
  return $this + 16 | 0;
}

function __ZL11SkipUTF8BOMP7__sFILE($file) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU8[_js_CStringsAreUTF8_b]) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    var $2 = _fgetc($file);
    var $3 = _fgetc($file);
    var $4 = _fgetc($file);
    if (($2 | 0) == 239 & ($3 | 0) == 187 & ($4 | 0) == 191) {
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($4 | 0) == -1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $file;
    var $12 = _ungetc($4, $11);
    __label__ = 5;
    break;
   case 5:
    if (($3 | 0) == -1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = $file;
    var $17 = _ungetc($3, $16);
    __label__ = 7;
    break;
   case 7:
    if (($2 | 0) == -1) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = $file;
    var $22 = _ungetc($2, $21);
    __label__ = 9;
    break;
   case 9:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN20JSAutoSuspendRequestC1EP9JSContext($this, $cx) {
  __ZN20JSAutoSuspendRequestC2EP9JSContext($this, $cx);
  return;
}

function __ZL7GetLineP7__sFILEPKc($file, $prompt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[_stdin >> 2] | 0) == ($file | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    var $5 = _readline($prompt);
    var $6 = ___errno();
    if ((HEAP32[$6 >> 2] | 0) == 251) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = ___errno();
    if ((HEAP32[$10 >> 2] | 0) == 25) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = ___errno();
    if ((HEAP32[$14 >> 2] | 0) == 22) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $18 = ___errno();
    HEAP32[$18 >> 2] = 0;
    __label__ = 6;
    break;
   case 6:
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (HEAP8[$5] << 24 >> 24 == 0) {
      var $_0 = $5;
      __label__ = 22;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    _add_history($5);
    var $_0 = $5;
    __label__ = 22;
    break;
   case 9:
    if (HEAP8[$prompt] << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $29 = HEAP32[_gOutFile >> 2];
    var $fputs = _fputs($prompt, $29);
    var $30 = HEAP32[_gOutFile >> 2];
    var $31 = _fflush($30);
    __label__ = 11;
    break;
   case 11:
    var $33 = _malloc(80);
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      var $current_0 = $33;
      var $len_0 = 0;
      var $size_0 = 80;
      var $buffer_0 = $33;
      __label__ = 12;
      break;
    }
   case 12:
    var $buffer_0;
    var $size_0;
    var $len_0;
    var $current_0;
    var $36 = _fgets($current_0, $size_0 - $len_0 | 0, $file);
    if (($36 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $39 = _strlen($current_0);
    var $40 = $39 + $len_0 | 0;
    var $41 = $buffer_0 + ($40 - 1) | 0;
    if (HEAP8[$41] << 24 >> 24 == 10) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    HEAP8[$41] = 0;
    var $_0 = $buffer_0;
    __label__ = 22;
    break;
   case 15:
    if (($40 + 1 | 0) == ($size_0 | 0)) {
      __label__ = 16;
      break;
    } else {
      var $size_1 = $size_0;
      var $buffer_1 = $buffer_0;
      __label__ = 18;
      break;
    }
   case 16:
    var $49 = $size_0 << 1;
    var $50 = _realloc($buffer_0, $49);
    if (($50 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $size_1 = $49;
      var $buffer_1 = $50;
      __label__ = 18;
      break;
    }
   case 17:
    _free($buffer_0);
    var $_0 = 0;
    __label__ = 22;
    break;
   case 18:
    var $buffer_1;
    var $size_1;
    var $current_0 = $buffer_1 + $40 | 0;
    var $len_0 = $40;
    var $size_0 = $size_1;
    var $buffer_0 = $buffer_1;
    __label__ = 12;
    break;
   case 19:
    if (($len_0 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $58 = _ferror($file);
    if (($58 | 0) == 0) {
      var $_0 = $buffer_0;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    _free($buffer_0);
    var $_0 = 0;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL7GetLineP7__sFILEPKc["X"] = 1;

function __ZN20JSAutoSuspendRequestD1Ev($this) {
  __ZN20JSAutoSuspendRequestD2Ev($this);
  return;
}

function _JSVAL_IS_VOID595($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE598($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_UNDEFINED_IMPL597($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN20JSAutoSuspendRequestD2Ev($this) {
  __ZN20JSAutoSuspendRequest6resumeEv($this);
  return;
}

function _STRING_TO_JSVAL599($agg_result, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _STRING_TO_JSVAL_IMPL601($1, $str);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout600($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN13IdStringifierC1EP9JSContextii($this, $cx, $id, $aThrow) {
  __ZN13IdStringifierC2EP9JSContextii($this, $cx, $id, $aThrow);
  return;
}

function __ZN8ToString8getBytesEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    if (($2 | 0) == 0) {
      var $_0 = STRING_TABLE.__str144437 | 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $this + 12 | 0;
    var $_idx1 = $5 | 0;
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $6 = __ZNK16JSAutoByteString3ptrEv($_idx1_val);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_idx_val = $_idx1_val;
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = HEAP32[$this >> 2];
    var $11 = __ZN16JSAutoByteString6encodeEP9JSContextP8JSString($5, $10, $2);
    if (($11 | 0) == 0) {
      var $_0 = STRING_TABLE.__str144437 | 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx_val = HEAP32[$_idx1 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $_idx_val;
    var $14 = __ZNK16JSAutoByteString3ptrEv($_idx_val);
    var $_0 = $14;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13IdStringifierD1Ev($this) {
  __ZN13IdStringifierD2Ev($this);
  return;
}

function __ZN13IdStringifierD2Ev($this) {
  var $1 = $this | 0;
  __ZN8ToStringD2Ev($1);
  return;
}

function __ZN8ToStringD2Ev($this) {
  var $3 = $this + 4 | 0;
  var $_idx1_val = HEAP32[HEAP32[$this >> 2] + 52 >> 2];
  _JS_RemoveStringRoot($_idx1_val, $3);
  var $_idx_val = HEAP32[$this + 12 >> 2];
  __ZN16JSAutoByteStringD1Ev($_idx_val);
  return;
}

function __ZN13IdStringifierC2EP9JSContextii($this, $cx, $id, $aThrow) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2jsL9IdToJsvalEi602($1, $id);
  var $_idx = $1 | 0;
  var $_idx_val$0 = HEAP32[$_idx >> 2];
  var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
  __ZN8ToStringC2EP9JSContextN2JS5ValueEi($2, $cx, $_idx_val$0, $_idx_val$1, $aThrow);
  STACKTOP = __stackBase__;
  return;
}

function __ZN8ToStringC2EP9JSContextN2JS5ValueEi($this, $aCx, $_0_0_0_val$0, $_0_0_0_val$1, $aThrow) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $aCx;
    HEAP32[$this + 8 >> 2] = $aThrow;
    var $3 = $this + 12 | 0;
    __ZN16JSAutoByteStringC1Ev($3);
    var $4 = HEAP32[$1 >> 2];
    var $5 = _JS_ValueToString($4, $_0_0_0_val$0, $_0_0_0_val$1);
    var $6 = $this + 4 | 0;
    HEAP32[$6 >> 2] = $5;
    if (($aThrow | 0) == 0 & ($5 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = HEAP32[$1 >> 2];
    __ZL15ReportExceptionP9JSContext($10);
    __label__ = 3;
    break;
   case 3:
    var $12 = HEAP32[$1 >> 2];
    _JS_AddNamedStringRoot($12, $6);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9IdToJsvalEi602($agg_result, $id) {
  __ZN2jsL9IdToValueEi603($agg_result, $id);
  return;
}

function __ZN2jsL9IdToValueEi603($agg_result, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_STRING604($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_STRING605($id);
    __ZN2JSL11StringValueEP8JSString587($agg_result, $4);
    __label__ = 8;
    break;
   case 3:
    var $6 = _JSID_IS_INT606($id);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _JSID_TO_INT608($id);
    __ZN2JSL10Int32ValueEi607($agg_result, $9);
    __label__ = 8;
    break;
   case 5:
    var $11 = _JSID_IS_OBJECT609($id);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = _JSID_TO_OBJECT610($id);
    __ZN2JSL11ObjectValueER8JSObject588($agg_result, $14);
    __label__ = 8;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv611($agg_result);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL10Int32ValueEi607($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZN2JSL14UndefinedValueEv611($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZL15ReportExceptionP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cx_idx_val = HEAP32[$cx + 20 >> 2];
    var $1 = _JS_IsExceptionPending($cx_idx_val);
    if (($1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JS_ReportPendingException($cx);
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ClearPendingException($cx);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8ToStringC1EP9JSContextN2JS5ValueEi($this, $aCx, $_0_0_0_val$0, $_0_0_0_val$1, $aThrow) {
  __ZN8ToStringC2EP9JSContextN2JS5ValueEi($this, $aCx, $_0_0_0_val$0, $_0_0_0_val$1, $aThrow);
  return;
}

function __ZN8ToString8getJSValEv($agg_result, $this_0_1_val) {
  _STRING_TO_JSVAL599($agg_result, $this_0_1_val);
  return;
}

function __ZN8ToStringD1Ev($this) {
  __ZN8ToStringD2Ev($this);
  return;
}

function __ZL12JSID_IS_ATOMi616($id) {
  var $1 = _JSID_IS_STRING604($id);
  return $1;
}

function _JSVAL_IS_BOOLEAN617($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE598($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_BOOLEAN_IMPL618($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2JSL9NullValueEv619($agg_result) {
  __ZN2JS5Value7setNullEv($agg_result);
  return;
}

function __ZL15SetTimeoutValueP9JSContextd($cx, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($t > 1800) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportError($cx, STRING_TABLE.__str223516 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    tempDoubleF64[0] = $t, HEAP32[__ZL16gTimeoutInterval >> 2] = tempDoubleI32[0], HEAP32[__ZL16gTimeoutInterval + 4 >> 2] = tempDoubleI32[1];
    __ZL16ScheduleWatchdogP9JSRuntimed($t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN12FreeOnReturnC1EP9JSContextPKc($this, $cx) {
  __ZN12FreeOnReturnC2EP9JSContextPKc($this, $cx);
  return;
}

function __ZL20MakeAbsolutePathnameP9JSContextPKcS2_($cx, $from, $leaf) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAP8[$leaf] << 24 >> 24 == 47) {
      __label__ = 2;
      break;
    } else {
      var $cp_0 = $from;
      var $slash_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = _JS_strdup($cx, $leaf);
    var $_0 = $4;
    __label__ = 10;
    break;
   case 3:
    var $slash_0;
    var $cp_0;
    var $5 = HEAP8[$cp_0];
    if ($5 << 24 >> 24 == 47) {
      __label__ = 4;
      break;
    } else if ($5 << 24 >> 24 == 0) {
      __label__ = 6;
      break;
    } else {
      var $slash_1 = $slash_0;
      __label__ = 5;
      break;
    }
   case 4:
    var $slash_1 = $cp_0;
    __label__ = 5;
    break;
   case 5:
    var $slash_1;
    var $cp_0 = $cp_0 + 1 | 0;
    var $slash_0 = $slash_1;
    __label__ = 3;
    break;
   case 6:
    if (($slash_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $12 = _JS_strdup($cx, $leaf);
    var $_0 = $12;
    __label__ = 10;
    break;
   case 8:
    var $16 = $slash_0 - $from | 0;
    var $17 = $16 + 1 | 0;
    var $18 = _strlen($leaf);
    var $20 = $18 + ($16 + 2) | 0;
    var $21 = _JS_malloc($cx, $20);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $24 = _strncpy($21, $from, $17);
    var $25 = $21 + $17 | 0;
    var $26 = _strcpy($25, $leaf);
    var $_0 = $21;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16FileAsTypedArrayP9JSContextPKc($cx, $pathname) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _fopen($pathname, STRING_TABLE.__str232525 | 0);
    var $2 = $1;
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = ___errno();
    var $6 = HEAP32[$5 >> 2];
    var $7 = _strerror($6);
    _JS_ReportError($cx, STRING_TABLE.__str233526 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $pathname, HEAP32[tempInt + 4 >> 2] = $7, tempInt));
    var $_0 = 0;
    __label__ = 13;
    break;
   case 3:
    var $9 = _fseek($2, 0, 2);
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _JS_ReportError($cx, STRING_TABLE.__str234527 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $pathname, tempInt));
    var $obj_0 = 0;
    __label__ = 12;
    break;
   case 5:
    var $13 = _ftell($2);
    var $14 = _fseek($2, 0, 0);
    if (($14 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _JS_ReportError($cx, STRING_TABLE.__str235528 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $pathname, tempInt));
    var $obj_0 = 0;
    __label__ = 12;
    break;
   case 7:
    var $18 = __Z19js_CreateTypedArrayP9JSContextij($cx, 1, $13);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($18);
    var $_idx_val = HEAP32[$21 + 24 >> 2];
    var $22 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($_idx_val);
    var $23 = _fread($22, 1, $13, $2);
    if (($23 | 0) == ($13 | 0)) {
      var $obj_0 = $18;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (($23 | 0) < 0) {
      __label__ = 10;
      break;
    } else {
      var $32 = STRING_TABLE.__str237530 | 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $28 = ___errno();
    var $29 = HEAP32[$28 >> 2];
    var $30 = _strerror($29);
    var $32 = $30;
    __label__ = 11;
    break;
   case 11:
    var $32;
    _JS_ReportError($cx, STRING_TABLE.__str236529 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $pathname, HEAP32[tempInt + 4 >> 2] = $32, tempInt));
    var $obj_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $obj_0;
    var $34 = _fclose($1);
    var $_0 = $obj_0;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12FileAsStringP9JSContextPKc($cx, $pathname) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uclen = __stackBase__;
    var $1 = _fopen($pathname, STRING_TABLE.__str232525 | 0);
    var $2 = $1;
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = ___errno();
    var $6 = HEAP32[$5 >> 2];
    var $7 = _strerror($6);
    _JS_ReportError($cx, STRING_TABLE.__str233526 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $pathname, HEAP32[tempInt + 4 >> 2] = $7, tempInt));
    var $_0 = 0;
    __label__ = 17;
    break;
   case 3:
    var $9 = _fseek($2, 0, 2);
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _JS_ReportError($cx, STRING_TABLE.__str234527 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $pathname, tempInt));
    var $str_1 = 0;
    __label__ = 16;
    break;
   case 5:
    var $13 = _ftell($2);
    var $14 = _fseek($2, 0, 0);
    if (($14 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _JS_ReportError($cx, STRING_TABLE.__str235528 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $pathname, tempInt));
    var $str_1 = 0;
    __label__ = 16;
    break;
   case 7:
    var $18 = $13 + 1 | 0;
    var $19 = _JS_malloc($cx, $18);
    if (($19 | 0) == 0) {
      var $str_1 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = _fread($19, 1, $13, $2);
    if (($22 | 0) == ($13 | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (($22 | 0) < 0) {
      __label__ = 10;
      break;
    } else {
      var $31 = STRING_TABLE.__str237530 | 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $27 = ___errno();
    var $28 = HEAP32[$27 >> 2];
    var $29 = _strerror($28);
    var $31 = $29;
    __label__ = 11;
    break;
   case 11:
    var $31;
    _JS_ReportError($cx, STRING_TABLE.__str236529 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $pathname, HEAP32[tempInt + 4 >> 2] = $31, tempInt));
    var $str_0 = 0;
    __label__ = 15;
    break;
   case 12:
    var $33 = _JS_DecodeUTF8($cx, $19, $22, 0, $uclen);
    if (($33 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    _JS_ReportError($cx, STRING_TABLE.__str238531 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $pathname, tempInt));
    HEAP32[_gExitCode >> 2] = 3;
    var $_0 = 0;
    __label__ = 17;
    break;
   case 14:
    var $38 = HEAP32[$uclen >> 2] << 1;
    var $39 = _malloc($38);
    var $40 = $39;
    var $41 = _JS_DecodeUTF8($cx, $19, $22, $40, $uclen);
    var $42 = HEAP32[$uclen >> 2];
    var $43 = _JS_NewUCStringCopyN($cx, $40, $42);
    _free($39);
    var $str_0 = $43;
    __label__ = 15;
    break;
   case 15:
    var $str_0;
    _JS_free($19);
    var $str_1 = $str_0;
    __label__ = 16;
    break;
   case 16:
    var $str_1;
    var $46 = _fclose($1);
    var $_0 = $str_1;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12FileAsStringP9JSContextPKc["X"] = 1;

function __ZN12FreeOnReturnD1Ev($this_0_1_val) {
  __ZN12FreeOnReturnD2Ev($this_0_1_val);
  return;
}

function __ZN12FreeOnReturnD2Ev($this_0_1_val) {
  _JS_free($this_0_1_val);
  return;
}

function _JSVAL_IS_OBJECT620($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE598($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_OBJECT_OR_NULL_IMPL621($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_IS_INT622($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE598($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_INT32_IMPL628($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_INT623($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE598($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_INT32_IMPL627($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_BOOLEAN624($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE598($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_BOOLEAN_IMPL626($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL10NewSandboxP9JSContextb($cx, $lazy) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ac = __stackBase__;
    var $root = __stackBase__ + 4;
    var $1 = __stackBase__ + 28;
    var $objroot = __stackBase__ + 36;
    var $2 = _JS_NewCompartmentAndGlobalObject($cx, __ZL13sandbox_class);
    if (($2 | 0) == 0) {
      var $_3 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN22JSAutoEnterCompartmentC1Ev($ac);
    var $5 = __ZN22JSAutoEnterCompartment5enterEP9JSContextP8JSObject($ac, $cx, $2);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    if ($lazy) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = _JS_InitStandardClasses($cx, $2);
    if (($8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $ac_idx1_val = HEAP32[$ac >> 2];
    __ZN22JSAutoEnterCompartmentD1Ev($ac_idx1_val);
    var $_3 = 0;
    __label__ = 10;
    break;
   case 6:
    __ZN2JSL12BooleanValueEb629($1, $lazy);
    __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($root, $cx, $1);
    var $11 = __ZN2js15AutoValueRooter10jsval_addrEv($root);
    var $12 = _JS_SetProperty($cx, $2, STRING_TABLE.__str245538 | 0, $11);
    var $13 = ($12 | 0) == 0;
    __ZN2js15AutoValueRooterD1Ev($root);
    var $ac_idx_val = HEAP32[$ac >> 2];
    __ZN22JSAutoEnterCompartmentD1Ev($ac_idx_val);
    if ($13) {
      var $_3 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($objroot, $cx, $2);
    var $16 = HEAP32[$cx + 56 >> 2];
    var $17 = $objroot;
    var $18 = __ZN2js16AutoObjectRooter4addrEv($17);
    var $19 = $18;
    var $20 = __ZN13JSCompartment4wrapEP9JSContextPP8JSObject($16, $cx, $19);
    if ($20) {
      __label__ = 8;
      break;
    } else {
      var $_2 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $_idx_val = HEAP32[$objroot + 12 >> 2];
    var $23 = __ZNK2js16AutoObjectRooter6objectEv($_idx_val);
    var $_2 = $23;
    __label__ = 9;
    break;
   case 9:
    var $_2;
    __ZN2js16AutoObjectRooterD1Ev($objroot);
    var $_3 = $_2;
    __label__ = 10;
    break;
   case 10:
    var $_3;
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL12BooleanValueEb629($agg_result, $boo) {
  __ZN2JS5Value10setBooleanEb($agg_result, $boo);
  return;
}

function __ZL13ValueToScriptP9JSContextN2JS5ValueEPP10JSFunction($cx, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSVAL_IS_PRIMITIVE589($_0_0_0_val$0, $_0_0_0_val$1);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $4 = _JSVAL_TO_OBJECT590($_0_0_0_val$0, $_0_0_0_val$1);
    var $_idx3_val = HEAP32[$4 + 4 >> 2];
    var $5 = _JS_GetClass($_idx3_val);
    var $6 = __ZN2jsL8JsvalifyEPNS_5ClassE631(__ZN2js11ScriptClassE);
    if (($5 | 0) == ($6 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $_idx1_val = HEAP32[$4 + 24 >> 2];
    var $9 = _JS_GetPrivate($_idx1_val);
    var $script_0 = $9;
    __label__ = 6;
    break;
   case 4:
    var $12 = __ZN2jsL8JsvalifyEPNS_5ClassE631(__ZN2js14GeneratorClassE);
    if (($5 | 0) == ($12 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $_idx2_val = HEAP32[$4 + 24 >> 2];
    var $15 = _JS_GetPrivate($_idx2_val);
    var $_idx_val = HEAP32[$15 + 28 >> 2];
    var $17 = __ZN11JSGenerator13floatingFrameEv($_idx_val);
    var $18 = $17;
    var $19 = __ZNK2js10StackFrame3funEv($18);
    var $20 = __ZNK10JSFunction6scriptEv($19);
    var $script_0 = $20;
    __label__ = 6;
    break;
   case 6:
    var $script_0;
    if (($script_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = $script_0;
      __label__ = 10;
      break;
    }
   case 7:
    var $23 = _JS_ValueToFunction($cx, $_0_0_0_val$0, $_0_0_0_val$1);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $26 = $23;
    var $27 = __ZNK10JSFunction11maybeScriptEv($26);
    var $28 = $27;
    if (($27 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $_0 = $28;
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 286, 7, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = $28;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js11AutoIdArray6lengthEv($this_0_1_val_0_0_val) {
  return $this_0_1_val_0_0_val;
}

function __ZL25finalize_counter_finalizeP9JSContextP8JSObject($cx, $obj) {
  var $2 = HEAP32[__ZL13finalizeCount >> 2] + 1 | 0;
  HEAP32[__ZL13finalizeCount >> 2] = $2;
  return;
}

function _JSVAL_IS_NULL_IMPL636($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -122) & 1;
}

function _JSVAL_IS_STRING_IMPL638($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -123) & 1;
}

function _JSVAL_TO_GCTHING_IMPL640($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_IS_TRACEABLE_IMPL641($l_0$0, $l_0$1) {
  var $2 = $l_0$1;
  return (($2 | 0) == -123 | ($2 | 0) == -121) & 1;
}

function _JSVAL_TO_OBJECT_IMPL642($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_IS_DOUBLE_IMPL647($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 < 4294967169 & 1;
}

function _JSVAL_TO_STRING_IMPL648($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_IS_PRIMITIVE_IMPL650($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 < 4294967175 & 1;
}

function __ZN2js11AutoIdArrayntEv($this_0_1_val) {
  return ($this_0_1_val | 0) == 0;
}

function __ZN2js3cli6detail6Option8asValuedEv($this) {
  return $this;
}

function __ZN2js3cli6detail6Option12asBoolOptionEv($this) {
  return $this;
}

function __ZN2js3cli6detail6Option14asStringOptionEv($this) {
  return $this;
}

function __ZN2js3cli6detail6Option11asIntOptionEv($this) {
  return $this;
}

function __ZN2js3cli6detail6Option19asMultiStringOptionEv($this) {
  return $this;
}

function _OBJECT_TO_JSVAL_IMPL649($agg_result, $obj) {
  HEAP32[$agg_result + 4 >> 2] = -121;
  HEAP32[$agg_result >> 2] = $obj;
  return;
}

function __ZNK2js11AutoIdArrayixEj($this_0_1_val, $i) {
  return HEAP32[$this_0_1_val + 4 + ($i << 2) >> 2];
}

function __ZN2js3cli6detail6Option20setTerminatesOptionsEb($this) {
  HEAP8[$this + 17 | 0] = 1;
  return;
}

function __ZL11GetTrapArgsP9JSContextjPN2JS5ValueEPP8JSScriptPi($cx, $argc, $argv, $scriptp, $ip) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = _JS_GetScriptedCaller($1);
    var $3 = _JS_GetFrameScript($2);
    HEAP32[$scriptp >> 2] = $3;
    HEAP32[$ip >> 2] = 0;
    if (($argc | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $argv5_0 = $argv | 0;
    var $st$1$0 = $argv5_0 | 0;
    var $tmp$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $argv5_0 + 4 | 0;
    var $tmp$1 = HEAP32[$st$1$1 >> 2];
    var $7 = _JSVAL_IS_PRIMITIVE589($tmp$0, $tmp$1);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $intarg_0 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    var $10 = _JSVAL_TO_OBJECT590($tmp$0, $tmp$1);
    var $_idx2_val = HEAP32[$10 + 4 >> 2];
    var $11 = _JS_GetClass($_idx2_val);
    var $12 = __ZN2jsL8JsvalifyEPNS_5ClassE631(__ZN2js13FunctionClassE);
    if (($11 | 0) == ($12 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = _JSVAL_TO_OBJECT590($tmp$0, $tmp$1);
    var $_idx1_val = HEAP32[$15 + 4 >> 2];
    var $16 = _JS_GetClass($_idx1_val);
    var $17 = __ZN2jsL8JsvalifyEPNS_5ClassE631(__ZN2js11ScriptClassE);
    if (($16 | 0) == ($17 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $intarg_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $20 = __ZL13ValueToScriptP9JSContextN2JS5ValueEPP10JSFunction($cx, $tmp$0, $tmp$1);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    HEAP32[$scriptp >> 2] = $20;
    var $intarg_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $intarg_0;
    if ($intarg_0 >>> 0 < $argc >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = $argv + ($intarg_0 << 3) | 0;
    var $st$1$0 = $26 | 0;
    var $27$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $26 + 4 | 0;
    var $27$1 = HEAP32[$st$1$1 >> 2];
    var $28 = _JS_ValueToInt32($cx, $27$0, $27$1, $ip);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11GetTrapArgsP9JSContextjPN2JS5ValueEPP8JSScriptPi["X"] = 1;

function __ZL11TrapHandlerP9JSContextP8JSScriptPhPN2JS5ValueES5_($cx, $0, $pc, $rval, $1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $length = __stackBase__;
    var $_03 = $1 | 0;
    var $tmp$0 = HEAP32[$_03 >> 2];
    var $tmp$1 = HEAP32[$_03 + 4 >> 2];
    var $3 = _JSVAL_TO_STRING594($tmp$0, $tmp$1);
    var $4 = $cx;
    var $5 = _JS_GetScriptedCaller($4);
    var $6 = _JS_GetFrameScript($5);
    var $7 = _JS_GetStringCharsAndLength($cx, $3, $length);
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAP32[$length >> 2];
    var $12 = HEAP32[$6 + 52 >> 2];
    var $14 = HEAP32[$6 + 28 >> 2];
    var $15 = _JS_EvaluateUCInStackFrame($4, $5, $7, $10, $12, $14, $rval);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $18 = $rval | 0;
    var $19$0 = HEAP32[$18 >> 2];
    var $19$1 = HEAP32[$18 + 4 >> 2];
    var $20 = _JSVAL_IS_VOID595($19$0, $19$1);
    var $_ = ($20 | 0) == 0 ? 2 : 1;
    var $_0 = $_;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23DebuggerAndThrowHandlerP9JSContextP8JSScriptPhPN2JS5ValueEPv($cx, $script, $pc, $rval, $closure) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $closure;
  _STRING_TO_JSVAL599($1, $2);
  var $3 = __ZL11TrapHandlerP9JSContextP8JSScriptPhPN2JS5ValueES5_($cx, $script, $pc, $rval, $1);
  STACKTOP = __stackBase__;
  return $3;
}

function _UINT_TO_JSVAL($agg_result) {
  _INT_TO_JSVAL592($agg_result, 32768);
  return;
}

function _DOUBLE_TO_JSVAL632($agg_result, $d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = isNaN($d) || isNaN(0);
    if ($1) {
      var $l_0_0$1 = 2146959360;
      var $l_0_0$0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $l_0_0$1 = tempDoubleI32[1];
    var $l_0_0$0 = tempDoubleI32[0];
    __label__ = 3;
    break;
   case 3:
    var $l_0_0$0;
    var $l_0_0$1;
    __ZL13IMPL_TO_JSVAL12jsval_layout600($agg_result, $l_0_0$0, $l_0_0$1);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSVAL_IS_TRACEABLE633($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE598($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_TRACEABLE_IMPL641($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_TRACEABLE($_0_0_0_val$0, $_0_0_0_val$1) {
  var $1 = _JSVAL_TO_GCTHING639($_0_0_0_val$0, $_0_0_0_val$1);
  return $1;
}

function _JSVAL_TRACE_KIND634($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE598($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TRACE_KIND_IMPL637($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_IS_NULL635($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE598($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_NULL_IMPL636($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL15CountHeapNotifyP8JSTracerPv13JSGCTraceKind($trc, $thing, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $trc + 56 | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $trc + 24 | 0;
    var $8 = _JS_DHashTableOperate($7, $thing, 1);
    if (($8 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = HEAP32[$trc >> 2];
    _JS_ReportOutOfMemory($12);
    HEAP32[$1 >> 2] = 0;
    __label__ = 10;
    break;
   case 4:
    var $14 = $8 + 4 | 0;
    if ((HEAP32[$14 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 5:
    HEAP32[$14 >> 2] = $thing;
    var $20 = $trc + 64 | 0;
    var $22 = HEAP32[$20 >> 2];
    if (($22 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_c = HEAP32[$22 + 8 >> 2];
    HEAP32[$20 >> 2] = $_c;
    var $node_0 = $22;
    __label__ = 9;
    break;
   case 7:
    var $29 = HEAP32[$trc >> 2];
    var $30 = _JS_malloc($29, 12);
    var $31 = $30;
    if (($30 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $node_0 = $31;
      __label__ = 9;
      break;
    }
   case 8:
    HEAP32[$1 >> 2] = 0;
    __label__ = 10;
    break;
   case 9:
    var $node_0;
    HEAP32[$node_0 >> 2] = $thing;
    HEAP32[$node_0 + 4 >> 2] = $kind;
    var $37 = $trc + 60 | 0;
    var $39 = HEAP32[$37 >> 2];
    HEAP32[$node_0 + 8 >> 2] = $39;
    HEAP32[$37 >> 2] = $node_0;
    __label__ = 10;
    break;
   case 10:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15CountHeapNotifyP8JSTracerPv13JSGCTraceKind["X"] = 1;

function _JSVAL_TRACE_KIND_IMPL637($l_0$0, $l_0$1) {
  var $1 = _JSVAL_IS_STRING_IMPL638($l_0$0, $l_0$1);
  return $1;
}

function _JSVAL_TO_GCTHING639($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE598($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_GCTHING_IMPL640($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL8ToSourceP9JSContextPN2JS5ValueEP16JSAutoByteString($cx, $vp, $bytes) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $vp | 0;
    var $st$2$0 = $2 | 0;
    var $3$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $2 + 4 | 0;
    var $3$1 = HEAP32[$st$2$1 >> 2];
    var $4 = _JS_ValueToSource($cx, $3$0, $3$1);
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _STRING_TO_JSVAL599($1, $4);
    var $7 = $1 | 0;
    var $st$2$0 = $7 | 0;
    var $8$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $7 + 4 | 0;
    var $8$1 = HEAP32[$st$2$1 >> 2];
    HEAP32[$2 >> 2] = $8$0;
    HEAP32[$2 + 4 >> 2] = $8$1;
    var $9 = __ZN16JSAutoByteString6encodeEP9JSContextP8JSString($bytes, $cx, $4);
    if (($9 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $bytes_idx_val = HEAP32[$bytes >> 2];
    var $12 = __ZNK16JSAutoByteString3ptrEv($bytes_idx_val);
    var $_0 = $12;
    __label__ = 5;
    break;
   case 4:
    _JS_ClearPendingException($cx);
    var $_0 = STRING_TABLE.__str281574 | 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_THIS644($agg_result, $cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = _JSVAL_IS_PRIMITIVE589($2$0, $2$1);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_ComputeThis($agg_result, $cx, $vp);
    __label__ = 4;
    break;
   case 3:
    var $7$0 = HEAP32[$1 >> 2];
    var $7$1 = HEAP32[$1 + 4 >> 2];
    var $8 = $agg_result | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26MapContextOptionNameToFlagP9JSContextPKc($cx, $name) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if (($i_0 | 0) == 10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = HEAP32[__ZL10js_options + ($i_0 << 3) >> 2];
    var $6 = _strcmp($name, $5);
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = HEAP32[__ZL10js_options + ($i_0 << 3) + 4 >> 2];
    __label__ = 13;
    break;
   case 5:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 6:
    var $14 = _JS_sprintf_append(0, STRING_TABLE.__str295 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $name, tempInt));
    if (($14 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $msg_01 = $14;
      var $i1_02 = 0;
      __label__ = 7;
      break;
    }
   case 7:
    var $i1_02;
    var $msg_01;
    var $17 = HEAP32[__ZL10js_options + ($i1_02 << 3) >> 2];
    var $18 = $i1_02 + 2 | 0;
    if ($18 >>> 0 < 10) {
      var $24 = STRING_TABLE.__str296 | 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = ($18 | 0) == 10 ? STRING_TABLE.__str297 | 0 : STRING_TABLE.__str298 | 0;
    var $24 = $22;
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $25 = _JS_sprintf_append($msg_01, STRING_TABLE.__str283576 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $17, HEAP32[tempInt + 4 >> 2] = $24, tempInt));
    var $26 = $i1_02 + 1 | 0;
    var $28 = ($25 | 0) == 0;
    if (($26 | 0) == 10 | $28) {
      __label__ = 10;
      break;
    } else {
      var $msg_01 = $25;
      var $i1_02 = $26;
      __label__ = 7;
      break;
    }
   case 10:
    if ($28) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    _JS_ReportOutOfMemory($cx);
    var $_0 = 0;
    __label__ = 13;
    break;
   case 12:
    _JS_ReportError($cx, $25, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    _free($25);
    var $_0 = 0;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSVAL_IS_DOUBLE645($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE598($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_DOUBLE_IMPL647($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_DOUBLE646($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE598($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $tmp$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = (tempDoubleI32[0] = HEAP32[$_0 >> 2], tempDoubleI32[1] = $tmp$1, tempDoubleF64[0]);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL12CopyPropertyP9JSContextP8JSObjectS2_ijPS2_($cx, $obj, $referent, $id, $lookupFlags, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $prop = __stackBase__;
    var $desc = __stackBase__ + 4;
    var $obj2 = __stackBase__ + 36;
    var $desc1 = __stackBase__ + 40;
    HEAP32[$objp >> 2] = 0;
    var $referent_idx_val = HEAP32[$referent >> 2];
    var $1 = __ZNK8JSObject8isNativeEv($referent_idx_val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 2:
    var $3 = $cx;
    var $4 = $referent;
    var $5 = $obj2;
    var $6 = $prop;
    var $7 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($3, $4, $id, $lookupFlags, $5, $6);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 26;
      break;
    }
   case 3:
    if ((HEAP32[$obj2 >> 2] | 0) == ($referent | 0)) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 26;
      break;
    }
   case 4:
    var $13 = HEAP32[$prop >> 2];
    var $_idx_val = HEAP8[$13 + 29 | 0];
    var $14 = __ZNK2js5Shape8isMethodEv($_idx_val);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = $desc + 16 | 0;
    var $17 = __ZN8JSObject17methodReadBarrierEP9JSContextRKN2js5ShapeEPN2JS5ValueE($referent, $cx, $13, $16);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      var $shape_0 = $17;
      __label__ = 9;
      break;
    }
   case 6:
    var $_idx2_val = HEAP8[$13 + 28 | 0];
    var $20 = __ZNK2js5Shape7hasSlotEv($_idx2_val);
    var $21 = $desc + 16 | 0;
    if ($20) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $24 = HEAP32[$13 + 24 >> 2];
    var $25 = __ZNK8JSObject13nativeGetSlotEj($referent, $24);
    var $26 = $25 | 0;
    var $27$0 = HEAP32[$26 >> 2];
    var $27$1 = HEAP32[$26 + 4 >> 2];
    var $28 = $21 | 0;
    HEAP32[$28 >> 2] = $27$0;
    HEAP32[$28 + 4 >> 2] = $27$1;
    var $shape_0 = $13;
    __label__ = 9;
    break;
   case 8:
    __ZN2JS5Value12setUndefinedEv($21);
    var $shape_0 = $13;
    __label__ = 9;
    break;
   case 9:
    var $shape_0;
    var $shape_0_idx5_val = HEAP8[$shape_0 + 28 | 0];
    var $31 = __ZNK2js5Shape10attributesEv($shape_0_idx5_val);
    var $32 = $31 & 255;
    HEAP32[$desc + 4 >> 2] = $32;
    var $shape_0_idx_val = HEAP32[$shape_0 + 16 >> 2];
    var $34 = __ZNK2js5Shape6getterEv($shape_0_idx_val);
    var $35 = $desc + 8 | 0;
    HEAP32[$35 >> 2] = $34;
    if (($34 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $42 = $34;
      __label__ = 12;
      break;
    }
   case 10:
    if (($32 & 16 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $42 = $34;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$35 >> 2] = 10;
    var $42 = 10;
    __label__ = 12;
    break;
   case 12:
    var $42;
    var $shape_0_idx1_val = HEAP32[$shape_0 + 20 >> 2];
    var $43 = __ZNK2js5Shape6setterEv($shape_0_idx1_val);
    var $44 = $desc + 12 | 0;
    HEAP32[$44 >> 2] = $43;
    if (($43 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $51 = $43;
      __label__ = 15;
      break;
    }
   case 13:
    if (($32 & 32 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      var $51 = $43;
      __label__ = 15;
      break;
    }
   case 14:
    HEAP32[$44 >> 2] = 12;
    var $51 = 12;
    __label__ = 15;
    break;
   case 15:
    var $51;
    var $54 = HEAP16[$shape_0 + 30 >> 1] << 16 >> 16;
    HEAP32[$desc + 24 >> 2] = $54;
    var $shape_0_idx4_val = HEAP8[$shape_0 + 29 | 0];
    var $56 = __ZNK2js5Shape8getFlagsEv($shape_0_idx4_val);
    var $propFlags_0 = $56;
    var $89 = $42;
    var $88 = $51;
    var $87 = $32;
    var $86 = $54;
    __label__ = 25;
    break;
   case 16:
    var $referent_idx3_val = HEAP32[$referent + 4 >> 2];
    var $58 = __ZNK8JSObject7isProxyEv($referent_idx3_val);
    if ($58) {
      __label__ = 17;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 17:
    var $60 = __ZN2js7JSProxy24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($cx, $referent, $id, 0, $desc1);
    if ($60) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 26;
      break;
    }
   case 18:
    if ((HEAP32[$desc1 >> 2] | 0) == 0) {
      var $_0 = 1;
      __label__ = 26;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $propFlags_0 = 0;
    var $89 = HEAP32[$desc + 8 >> 2];
    var $88 = HEAP32[$desc + 12 >> 2];
    var $87 = HEAP32[$desc + 4 >> 2];
    var $86 = HEAP32[$desc + 24 >> 2];
    __label__ = 25;
    break;
   case 20:
    var $66 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($referent, $cx, $id, $objp, $prop);
    if (($66 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    if ((HEAP32[$objp >> 2] | 0) == ($referent | 0)) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 1;
      __label__ = 26;
      break;
    }
   case 22:
    var $72 = $desc + 16 | 0;
    var $73 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($referent, $cx, $id, $72);
    if (($73 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $76 = $desc + 4 | 0;
    var $77 = __ZN8JSObject13getAttributesEP9JSContextiPj($referent, $cx, $id, $76);
    if (($77 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $81 = HEAP32[$76 >> 2] & 7;
    HEAP32[$76 >> 2] = $81;
    HEAP32[$desc + 8 >> 2] = 10;
    HEAP32[$desc + 12 >> 2] = 12;
    HEAP32[$desc + 24 >> 2] = 0;
    var $propFlags_0 = 0;
    var $89 = 10;
    var $88 = 12;
    var $87 = $81;
    var $86 = 0;
    __label__ = 25;
    break;
   case 25:
    var $86;
    var $87;
    var $88;
    var $89;
    var $propFlags_0;
    HEAP32[$objp >> 2] = $obj;
    var $90 = $desc + 16 | 0;
    var $91 = $cx;
    var $92 = $obj;
    var $95 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($91, $92, $id, $90, $89, $88, $87, $propFlags_0, $86, 0);
    var $_0 = ($95 | 0) != 0 & 1;
    __label__ = 26;
    break;
   case 26:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12CopyPropertyP9JSContextP8JSObjectS2_ijPS2_["X"] = 1;

function __ZN2js11AutoIdArrayC1EP9JSContextP9JSIdArray($this, $cx, $ida) {
  __ZN2js11AutoIdArrayC2EP9JSContextP9JSIdArray($this, $cx, $ida);
  return;
}

function __ZN2js11AutoIdArrayD1Ev($this) {
  __ZN2js11AutoIdArrayD2Ev($this);
  return;
}

function __ZN2js11AutoIdArrayD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 12 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_DestroyIdArray($2);
    __label__ = 3;
    break;
   case 3:
    var $_idx_val = HEAP32[$this >> 2];
    var $_idx1_val = HEAP32[$this + 8 >> 2];
    __ZN2js12AutoGCRooterD2Ev($_idx_val, $_idx1_val);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11AutoIdArrayC2EP9JSContextP9JSIdArray($this, $cx, $ida) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($1, $cx, -6);
  HEAP32[$this + 12 >> 2] = $ida;
  return;
}

function __ZNK2js3cli6detail6Option12asBoolOptionEv($this) {
  var $1 = __ZN2js3cli6detail6Option12asBoolOptionEv($this);
  return $1;
}

function __ZNK2js3cli6detail6Option14asStringOptionEv($this) {
  var $1 = __ZN2js3cli6detail6Option14asStringOptionEv($this);
  return $1;
}

function __ZNK2js3cli6detail6Option19asMultiStringOptionEv($this) {
  var $1 = __ZN2js3cli6detail6Option19asMultiStringOptionEv($this);
  return $1;
}

function __ZN2js3cli12OptionParser23setArgTerminatesOptionsEPKcb($this) {
  var $1 = __ZN2js3cli12OptionParser12findArgumentEPKc($this, STRING_TABLE.__str120413 | 0);
  __ZN2js3cli6detail6Option20setTerminatesOptionsEb($1);
  return;
}

function __ZN2js3cli12OptionParser12findArgumentEPKc($this, $name) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this + 20 >> 2];
    var $1 = __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE5beginEv($_idx_val);
    var $_idx2_val = HEAP32[$this + 24 >> 2];
    var $2 = __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE3endEv($_idx_val, $_idx2_val);
    var $it_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $it_0;
    if (($it_0 | 0) == ($2 | 0)) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = HEAP32[$it_0 >> 2];
    var $8 = HEAP32[$6 + 4 >> 2];
    var $9 = _strcmp($8, $name);
    if (($9 | 0) == 0) {
      var $_0 = $6;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $it_0 = $it_0 + 4 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js3cli12OptionParser5errorEPKcz($fmt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $args = __stackBase__;
  HEAP32[$args >> 2] = arguments[__ZN2js3cli12OptionParser5errorEPKcz.length];
  var $2 = HEAP32[_stderr >> 2];
  var $3 = _fwrite(STRING_TABLE.__str651 | 0, 7, 1, $2);
  var $4 = HEAP32[_stderr >> 2];
  var $5 = HEAP32[$args >> 2];
  var $6 = _vfprintf($4, $fmt, $5);
  var $7 = HEAP32[_stderr >> 2];
  var $8 = _fwrite(STRING_TABLE.__str1652 | 0, 2, 1, $7);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE5beginEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE6lengthEv($this_0_1_val) {
  return $this_0_1_val;
}

function __ZNK2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE5beginEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE5emptyEv($this_0_1_val) {
  return ($this_0_1_val | 0) == 0;
}

function __ZNK2js3cli6detail6Option20getTerminatesOptionsEv($this_0_5_val) {
  return ($this_0_5_val & 1) << 24 >> 24 != 0;
}

function __ZNK2js3cli12OptionParser13getHelpOptionEv($this_0_2_2_val) {
  return ($this_0_2_2_val & 1) << 24 >> 24 != 0;
}

function __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE3endEv($this_0_0_val, $this_0_1_val) {
  return $this_0_0_val + ($this_0_1_val << 2) | 0;
}

function __ZL23OptionFlagsToFormatInfocbPj($shortflag, $isValued, $length) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $lengths = __stackBase__;
  HEAP32[$lengths >> 2] = 8;
  HEAP32[$lengths + 4 >> 2] = 4;
  HEAP32[$lengths + 8 >> 2] = 9;
  HEAP32[$lengths + 12 >> 2] = 5;
  var $5 = $isValued ? 2 : 0;
  var $index_0 = $5 | $shortflag << 24 >> 24 == 0 & 1;
  var $9 = HEAP32[$lengths + ($index_0 << 2) >> 2];
  HEAP32[$length >> 2] = $9;
  var $11 = HEAP32[__ZZL23OptionFlagsToFormatInfocbPjE3fmt + ($index_0 << 2) >> 2];
  STACKTOP = __stackBase__;
  return $11;
}

function __ZNK2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE3endEv($this_0_0_val, $this_0_1_val) {
  return $this_0_0_val + ($this_0_1_val << 3) | 0;
}

function __ZN2js3cli12OptionParser9printHelpEPKc($this, $progname) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fmtLen = __stackBase__;
    var $fmtLen9 = __stackBase__ + 4;
    var $2 = HEAP32[$this + 68 >> 2];
    var $3 = _strstr($2, STRING_TABLE.__ZN2js3cli12OptionParser12prognameMetaE | 0);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $3 - $2 | 0;
    var $9 = $3 + 10 | 0;
    var $10 = _printf(STRING_TABLE.__str2653 | 0, (tempInt = STACKTOP, STACKTOP += 16, HEAP32[tempInt >> 2] = $8, HEAP32[tempInt + 4 >> 2] = $2, HEAP32[tempInt + 8 >> 2] = $progname, HEAP32[tempInt + 12 >> 2] = $9, tempInt));
    __label__ = 4;
    break;
   case 3:
    var $12 = _puts($2);
    __label__ = 4;
    break;
   case 4:
    var $14 = $this + 76 | 0;
    if ((HEAP32[$14 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = HEAP32[_stdout >> 2];
    var $19 = _putc(10, $18);
    var $20 = HEAP32[$14 >> 2];
    var $22 = HEAP32[$this + 80 >> 2];
    __ZL14PrintParagraphPKcjjb($20, 2, $22, 1);
    var $23 = HEAP32[_stdout >> 2];
    var $24 = _putc(10, $23);
    __label__ = 6;
    break;
   case 6:
    var $27 = HEAP32[$this + 72 >> 2];
    if (($27 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $30 = _printf(STRING_TABLE.__str3654 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $27, tempInt));
    __label__ = 8;
    break;
   case 8:
    var $_idx13 = $this + 24 | 0;
    var $_idx13_val = HEAP32[$_idx13 >> 2];
    var $32 = __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE5emptyEv($_idx13_val);
    if ($32) {
      __label__ = 17;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $puts = _puts(STRING_TABLE._str2 | 0);
    var $_idx3_val = HEAP32[$this + 20 >> 2];
    var $34 = __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE5beginEv($_idx3_val);
    var $_idx11_val = HEAP32[$_idx13 >> 2];
    var $35 = __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE3endEv($_idx3_val, $_idx11_val);
    var $36 = ($34 | 0) == ($35 | 0);
    if ($36) {
      __label__ = 16;
      break;
    } else {
      var $it_07 = $34;
      var $lhsLen_08 = 0;
      __label__ = 10;
      break;
    }
   case 10:
    var $lhsLen_08;
    var $it_07;
    var $39 = HEAP32[HEAP32[$it_07 >> 2] + 4 >> 2];
    var $40 = _strlen($39);
    var $41 = $40 + 4 | 0;
    var $43 = $lhsLen_08 >>> 0 > $41 >>> 0 ? $lhsLen_08 : $41;
    var $44 = $it_07 + 4 | 0;
    if (($44 | 0) == ($35 | 0)) {
      var $lhsLen_0_lcssa = $43;
      __label__ = 11;
      break;
    } else {
      var $it_07 = $44;
      var $lhsLen_08 = $43;
      __label__ = 10;
      break;
    }
   case 11:
    var $lhsLen_0_lcssa;
    if ($36) {
      __label__ = 16;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $46 = $this + 84 | 0;
    var $it1_03 = $34;
    __label__ = 13;
    break;
   case 13:
    var $it1_03;
    var $48 = HEAPU32[$it1_03 >> 2];
    var $50 = HEAP32[$48 + 4 >> 2];
    var $51 = _printf(STRING_TABLE.__ZZN2js3cli12OptionParser9printHelpEPKcE3fmt | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $50, tempInt));
    if ($51 >>> 0 < $lhsLen_0_lcssa >>> 0) {
      var $chars_02 = $51;
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $chars_02;
    var $53 = HEAP32[_stdout >> 2];
    var $54 = _putc(32, $53);
    var $55 = $chars_02 + 1 | 0;
    if (($55 | 0) == ($lhsLen_0_lcssa | 0)) {
      __label__ = 15;
      break;
    } else {
      var $chars_02 = $55;
      __label__ = 14;
      break;
    }
   case 15:
    var $57 = HEAP32[$48 + 8 >> 2];
    var $58 = HEAP32[$46 >> 2];
    __ZL14PrintParagraphPKcjjb($57, $lhsLen_0_lcssa, $58, 0);
    var $59 = HEAP32[_stdout >> 2];
    var $60 = _putc(10, $59);
    var $61 = $it1_03 + 4 | 0;
    if (($61 | 0) == ($35 | 0)) {
      __label__ = 16;
      break;
    } else {
      var $it1_03 = $61;
      __label__ = 13;
      break;
    }
   case 16:
    var $63 = HEAP32[_stdout >> 2];
    var $64 = _putc(10, $63);
    __label__ = 17;
    break;
   case 17:
    var $_idx12 = $this + 4 | 0;
    var $_idx12_val = HEAP32[$_idx12 >> 2];
    var $66 = __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE5emptyEv($_idx12_val);
    if ($66) {
      __label__ = 35;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $puts1 = _puts(STRING_TABLE._str3 | 0);
    var $_idx1 = $this | 0;
    var $_idx1_val = HEAPU32[$_idx1 >> 2];
    var $68 = __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE5beginEv($_idx1_val);
    var $_idx7_val = HEAPU32[$_idx12 >> 2];
    var $69 = __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE3endEv($_idx1_val, $_idx7_val);
    if (($68 | 0) == ($69 | 0)) {
      var $lhsLen3_0_lcssa = 0;
      var $_idx_val = $_idx1_val;
      var $_idx5_val = $_idx7_val;
      __label__ = 23;
      break;
    } else {
      var $lhsLen3_018 = 0;
      var $it4_019 = $68;
      __label__ = 19;
      break;
    }
   case 19:
    var $it4_019;
    var $lhsLen3_018;
    var $71 = HEAP32[$it4_019 >> 2];
    var $73 = HEAP32[$71 + 4 >> 2];
    var $74 = _strlen($73);
    var $76 = HEAP8[$71 + 16 | 0];
    var $77 = $71;
    var $80 = HEAP32[HEAP32[$77 >> 2] + 8 >> 2];
    var $81 = FUNCTION_TABLE[$80]($71);
    var $82 = __ZL23OptionFlagsToFormatInfocbPj($76, $81, $fmtLen);
    var $84 = HEAP32[$fmtLen >> 2] + $74 | 0;
    var $87 = HEAP32[HEAP32[$77 >> 2] + 8 >> 2];
    var $88 = FUNCTION_TABLE[$87]($71);
    if ($88) {
      __label__ = 20;
      break;
    } else {
      var $len_0 = $84;
      __label__ = 21;
      break;
    }
   case 20:
    var $90 = __ZN2js3cli6detail6Option8asValuedEv($71);
    var $92 = HEAP32[$90 + 20 >> 2];
    var $93 = _strlen($92);
    var $len_0 = $93 + $84 | 0;
    __label__ = 21;
    break;
   case 21:
    var $len_0;
    var $97 = $lhsLen3_018 >>> 0 > $len_0 >>> 0 ? $lhsLen3_018 : $len_0;
    var $98 = $it4_019 + 4 | 0;
    if (($98 | 0) == ($69 | 0)) {
      __label__ = 22;
      break;
    } else {
      var $lhsLen3_018 = $97;
      var $it4_019 = $98;
      __label__ = 19;
      break;
    }
   case 22:
    var $lhsLen3_0_lcssa = $97;
    var $_idx_val = HEAP32[$_idx1 >> 2];
    var $_idx5_val = HEAP32[$_idx12 >> 2];
    __label__ = 23;
    break;
   case 23:
    var $_idx5_val;
    var $_idx_val;
    var $lhsLen3_0_lcssa;
    var $100 = __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE5beginEv($_idx_val);
    var $101 = __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE3endEv($_idx_val, $_idx5_val);
    if (($100 | 0) == ($101 | 0)) {
      __label__ = 35;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $103 = $this + 84 | 0;
    var $it6_015 = $100;
    __label__ = 25;
    break;
   case 25:
    var $it6_015;
    var $105 = HEAPU32[$it6_015 >> 2];
    var $106 = $105 + 16 | 0;
    var $107 = HEAP8[$106];
    var $108 = $105;
    var $111 = HEAP32[HEAP32[$108 >> 2] + 8 >> 2];
    var $112 = FUNCTION_TABLE[$111]($105);
    var $113 = __ZL23OptionFlagsToFormatInfocbPj($107, $112, $fmtLen9);
    var $116 = HEAP32[HEAP32[$108 >> 2] + 8 >> 2];
    var $117 = FUNCTION_TABLE[$116]($105);
    var $118 = HEAP8[$106];
    var $119 = $118 << 24 >> 24 != 0;
    if ($117) {
      __label__ = 26;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 26:
    if ($119) {
      __label__ = 27;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 27:
    var $122 = $118 << 24 >> 24;
    var $124 = HEAP32[$105 + 4 >> 2];
    var $125 = __ZN2js3cli6detail6Option8asValuedEv($105);
    var $127 = HEAP32[$125 + 20 >> 2];
    var $128 = _printf($113, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $122, HEAP32[tempInt + 4 >> 2] = $124, HEAP32[tempInt + 8 >> 2] = $127, tempInt));
    var $chars10_0_ph = $128;
    __label__ = 32;
    break;
   case 28:
    var $131 = HEAP32[$105 + 4 >> 2];
    var $132 = __ZN2js3cli6detail6Option8asValuedEv($105);
    var $134 = HEAP32[$132 + 20 >> 2];
    var $135 = _printf($113, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $131, HEAP32[tempInt + 4 >> 2] = $134, tempInt));
    var $chars10_0_ph = $135;
    __label__ = 32;
    break;
   case 29:
    if ($119) {
      __label__ = 30;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    var $138 = $118 << 24 >> 24;
    var $140 = HEAP32[$105 + 4 >> 2];
    var $141 = _printf($113, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $138, HEAP32[tempInt + 4 >> 2] = $140, tempInt));
    var $chars10_0_ph = $141;
    __label__ = 32;
    break;
   case 31:
    var $144 = HEAP32[$105 + 4 >> 2];
    var $145 = _printf($113, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $144, tempInt));
    var $chars10_0_ph = $145;
    __label__ = 32;
    break;
   case 32:
    var $chars10_0_ph;
    if ($chars10_0_ph >>> 0 < $lhsLen3_0_lcssa >>> 0) {
      var $chars10_012 = $chars10_0_ph;
      __label__ = 33;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 33:
    var $chars10_012;
    var $147 = HEAP32[_stdout >> 2];
    var $148 = _putc(32, $147);
    var $149 = $chars10_012 + 1 | 0;
    if (($149 | 0) == ($lhsLen3_0_lcssa | 0)) {
      __label__ = 34;
      break;
    } else {
      var $chars10_012 = $149;
      __label__ = 33;
      break;
    }
   case 34:
    var $151 = HEAP32[$105 + 8 >> 2];
    var $152 = HEAP32[$103 >> 2];
    __ZL14PrintParagraphPKcjjb($151, $lhsLen3_0_lcssa, $152, 0);
    var $153 = HEAP32[_stdout >> 2];
    var $154 = _putc(10, $153);
    var $155 = $it6_015 + 4 | 0;
    if (($155 | 0) == ($101 | 0)) {
      __label__ = 35;
      break;
    } else {
      var $it6_015 = $155;
      __label__ = 25;
      break;
    }
   case 35:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js3cli12OptionParser9printHelpEPKc["X"] = 1;

function __ZL14PrintParagraphPKcjjb($text, $startColno, $limitColno, $padFirstLine) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($padFirstLine) {
      __label__ = 2;
      break;
    } else {
      var $it_0_ph = $text;
      var $colno_0_ph = $startColno;
      __label__ = 3;
      break;
    }
   case 2:
    var $2 = _printf(STRING_TABLE.__str16667 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $startColno, HEAP32[tempInt + 4 >> 2] = __str17668 | 0, tempInt));
    var $it_0_ph = $text;
    var $colno_0_ph = $startColno;
    __label__ = 3;
    break;
   case 3:
    var $colno_0_ph;
    var $it_0_ph;
    var $3 = $it_0_ph;
    var $colno_0 = $colno_0_ph;
    __label__ = 4;
    break;
   case 4:
    var $colno_0;
    var $4 = HEAP8[$it_0_ph];
    if ($4 << 24 >> 24 == 0) {
      __label__ = 16;
      break;
    } else {
      var $limit_0 = $it_0_ph;
      var $6 = $4;
      __label__ = 5;
      break;
    }
   case 5:
    var $6;
    var $limit_0;
    var $8 = _isspace($6 << 24 >> 24);
    if (($8 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (HEAP8[$limit_0] << 24 >> 24 == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $14 = $limit_0 + 1 | 0;
    var $_pre = HEAP8[$14];
    var $limit_0 = $14;
    var $6 = $_pre;
    __label__ = 5;
    break;
   case 8:
    var $16 = $limit_0 - $3 | 0;
    if (($16 + $colno_0 | 0) >>> 0 < $limitColno >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $20 = _printf(STRING_TABLE.__str18669 | 0, (tempInt = STACKTOP, STACKTOP += 16, HEAP32[tempInt >> 2] = $startColno, HEAP32[tempInt + 4 >> 2] = __str17668 | 0, HEAP32[tempInt + 8 >> 2] = $16, HEAP32[tempInt + 12 >> 2] = $it_0_ph, tempInt));
    var $startColno_pn = $startColno;
    __label__ = 11;
    break;
   case 10:
    var $22 = _printf(STRING_TABLE.__str19670 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $16, HEAP32[tempInt + 4 >> 2] = $it_0_ph, tempInt));
    var $startColno_pn = $colno_0;
    __label__ = 11;
    break;
   case 11:
    var $startColno_pn;
    var $colno_1 = $startColno_pn + $16 | 0;
    var $25 = HEAP8[$limit_0] << 24 >> 24;
    if (($25 | 0) == 32) {
      __label__ = 12;
      break;
    } else if (($25 | 0) == 10) {
      __label__ = 14;
      break;
    } else if (($25 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      var $colno_0 = $colno_1;
      __label__ = 4;
      break;
    }
   case 12:
    var $27 = HEAP32[_stdout >> 2];
    var $28 = _putc(32, $27);
    var $29 = $colno_1 + 1 | 0;
    if (HEAP8[$limit_0] << 24 >> 24 == 32) {
      var $it_11 = $limit_0;
      __label__ = 13;
      break;
    } else {
      var $it_0_ph = $limit_0;
      var $colno_0_ph = $29;
      __label__ = 3;
      break;
    }
   case 13:
    var $it_11;
    var $32 = $it_11 + 1 | 0;
    if (HEAP8[$32] << 24 >> 24 == 32) {
      var $it_11 = $32;
      __label__ = 13;
      break;
    } else {
      var $it_0_ph = $32;
      var $colno_0_ph = $29;
      __label__ = 3;
      break;
    }
   case 14:
    var $36 = _printf(STRING_TABLE.__str20671 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $startColno, HEAP32[tempInt + 4 >> 2] = __str17668 | 0, tempInt));
    var $it_23 = $limit_0 + 1 | 0;
    if (HEAP8[$it_23] << 24 >> 24 == 32) {
      var $colno_24 = $startColno;
      var $it_25 = $it_23;
      __label__ = 15;
      break;
    } else {
      var $it_0_ph = $it_23;
      var $colno_0_ph = $startColno;
      __label__ = 3;
      break;
    }
   case 15:
    var $it_25;
    var $colno_24;
    var $39 = HEAP32[_stdout >> 2];
    var $40 = _putc(32, $39);
    var $41 = $colno_24 + 1 | 0;
    var $it_2 = $it_25 + 1 | 0;
    if (HEAP8[$it_2] << 24 >> 24 == 32) {
      var $colno_24 = $41;
      var $it_25 = $it_2;
      __label__ = 15;
      break;
    } else {
      var $it_0_ph = $it_2;
      var $colno_0_ph = $41;
      __label__ = 3;
      break;
    }
   case 16:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14PrintParagraphPKcjjb["X"] = 1;

function __ZN2js3cli12OptionParser12extractValueEjPPcPjS3_($argc, $argv, $i, $value) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$i >> 2];
    var $3 = HEAP32[$argv + ($1 << 2) >> 2];
    var $4 = _strchr($3, 61);
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4 + 1 | 0;
    HEAP32[$value >> 2] = $7;
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    var $12 = HEAP32[$argv + (HEAP32[$i >> 2] << 2) >> 2];
    var $15 = $4 - $12 | 0;
    __ZN2js3cli12OptionParser5errorEPKcz(STRING_TABLE.__str6657 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $15, HEAP32[tempInt + 4 >> 2] = $12, tempInt));
    var $_0 = 2;
    __label__ = 7;
    break;
   case 4:
    var $17 = $1 + 1 | 0;
    if (($17 | 0) == ($argc | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js3cli12OptionParser5errorEPKcz(STRING_TABLE.__str7658 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $3, tempInt));
    var $_0 = 2;
    __label__ = 7;
    break;
   case 6:
    HEAP32[$i >> 2] = $17;
    var $22 = HEAP32[$argv + ($17 << 2) >> 2];
    HEAP32[$value >> 2] = $22;
    var $_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js3cli12OptionParser12handleOptionEPNS0_6detail6OptionEjPPcPjPb($this, $opt, $argc, $argv, $i, $optionsAllowed) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $value = __stackBase__;
    var $value1 = __stackBase__ + 4;
    var $value3 = __stackBase__ + 8;
    var $1 = __stackBase__ + 12;
    var $opt_idx_val = HEAP8[$opt + 17 | 0];
    var $2 = __ZNK2js3cli6detail6Option20getTerminatesOptionsEv($opt_idx_val);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP8[$optionsAllowed] = 0;
    __label__ = 3;
    break;
   case 3:
    var $6 = HEAP32[$opt + 12 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($6 | 0) == 1) {
      __label__ = 7;
      break;
    } else if (($6 | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($6 | 0) == 3) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 13;
      break;
    }
   case 4:
    if (($this + 40 | 0) == ($opt | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = HEAP32[$argv >> 2];
    __ZN2js3cli12OptionParser9printHelpEPKc($this, $11);
    var $_0 = 3;
    __label__ = 13;
    break;
   case 6:
    var $13 = __ZN2js3cli6detail6Option12asBoolOptionEv($opt);
    HEAP8[$13 + 24 | 0] = 1;
    var $_0 = 0;
    __label__ = 13;
    break;
   case 7:
    HEAP32[$value >> 2] = 0;
    var $16 = __ZN2js3cli12OptionParser12extractValueEjPPcPjS3_($argc, $argv, $i, $value);
    if (($16 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $_0 = $16;
      __label__ = 13;
      break;
    }
   case 8:
    var $19 = HEAP32[$value >> 2];
    var $20 = __ZN2js3cli6detail6Option14asStringOptionEv($opt);
    HEAP32[$20 + 24 >> 2] = $19;
    var $_0 = 0;
    __label__ = 13;
    break;
   case 9:
    HEAP32[$value1 >> 2] = 0;
    var $23 = __ZN2js3cli12OptionParser12extractValueEjPPcPjS3_($argc, $argv, $i, $value1);
    if (($23 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = $23;
      __label__ = 13;
      break;
    }
   case 10:
    var $26 = HEAP32[$value1 >> 2];
    var $27 = _atoi($26);
    var $28 = __ZN2js3cli6detail6Option11asIntOptionEv($opt);
    HEAP32[$28 + 24 >> 2] = $27;
    var $_0 = 0;
    __label__ = 13;
    break;
   case 11:
    HEAP32[$value3 >> 2] = 0;
    var $31 = __ZN2js3cli12OptionParser12extractValueEjPPcPjS3_($argc, $argv, $i, $value3);
    if (($31 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $_0 = $31;
      __label__ = 13;
      break;
    }
   case 12:
    var $34 = HEAP32[$value3 >> 2];
    var $35 = HEAP32[$i >> 2];
    __ZN2js3cli6detail9StringArgC1EPcj($1, $34, $35);
    var $36 = __ZN2js3cli6detail6Option19asMultiStringOptionEv($opt);
    var $37 = $36 + 24 | 0;
    var $_01_val = HEAP32[$1 >> 2];
    var $_1_val = HEAP32[$1 + 4 >> 2];
    var $38 = __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE6appendIS3_EEbT_($37, $_01_val, $_1_val);
    var $_0 = $38 & 1 ^ 1;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js3cli12OptionParser12handleOptionEPNS0_6detail6OptionEjPPcPjPb["X"] = 1;

function __ZN2js3cli6detail9StringArgC1EPcj($this, $value, $argno) {
  __ZN2js3cli6detail9StringArgC2EPcj($this, $value, $argno);
  return;
}

function __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE6appendIS3_EEbT_($this, $t_0, $t_1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 4 >> 2] | 0) == (HEAP32[$this + 8 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE13growStorageByEj($this);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE14internalAppendIS3_EEvT_($this, $t_0, $t_1);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js3cli12OptionParser9handleArgEjPPcPjPb($this, $argv, $i, $optionsAllowed) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 88 | 0;
    var $3 = HEAPU32[$2 >> 2];
    var $_idx_val = HEAP32[$this + 24 >> 2];
    var $4 = __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE6lengthEv($_idx_val);
    if ($3 >>> 0 < $4 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js3cli12OptionParser5errorEPKcz(STRING_TABLE.__str8659 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 2;
    __label__ = 8;
    break;
   case 3:
    var $_idx3_val = HEAP32[$this + 20 >> 2];
    var $8 = __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEEixEj($_idx3_val, $3);
    var $9 = HEAPU32[$8 >> 2];
    var $_idx1_val = HEAP8[$9 + 17 | 0];
    var $10 = __ZNK2js3cli6detail6Option20getTerminatesOptionsEv($_idx1_val);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP8[$optionsAllowed] = 0;
    __label__ = 5;
    break;
   case 5:
    var $14 = HEAP32[$9 + 12 >> 2];
    if (($14 | 0) == 1) {
      __label__ = 6;
      break;
    } else if (($14 | 0) == 3) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = HEAP32[$argv + (HEAP32[$i >> 2] << 2) >> 2];
    var $19 = __ZN2js3cli6detail6Option14asStringOptionEv($9);
    var $20 = $19 + 24 | 0;
    HEAP32[$20 >> 2] = $18;
    var $22 = HEAP32[$2 >> 2] + 1 | 0;
    HEAP32[$2 >> 2] = $22;
    var $_0 = 0;
    __label__ = 8;
    break;
   case 7:
    var $24 = HEAP32[$i >> 2];
    var $26 = HEAP32[$argv + ($24 << 2) >> 2];
    __ZN2js3cli6detail9StringArgC1EPcj($1, $26, $24);
    var $27 = __ZN2js3cli6detail6Option19asMultiStringOptionEv($9);
    var $28 = $27 + 24 | 0;
    var $_02_val = HEAP32[$1 >> 2];
    var $_1_val = HEAP32[$1 + 4 >> 2];
    var $29 = __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE6appendIS3_EEbT_($28, $_02_val, $_1_val);
    var $_0 = $29 & 1 ^ 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEEixEj($this_0_0_val, $i) {
  var $1 = __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE5beginEv($this_0_0_val);
  return $1 + ($i << 2) | 0;
}

function __ZN2js3cli12OptionParser9parseArgsEiPPc($this, $inputArgc, $argv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $optionsAllowed = __stackBase__;
    var $i = __stackBase__ + 4;
    HEAP8[$optionsAllowed] = 1;
    var $storemerge = 1;
    __label__ = 2;
    break;
   case 2:
    var $storemerge;
    HEAP32[$i >> 2] = $storemerge;
    if ($storemerge >>> 0 < $inputArgc >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 3:
    var $5 = HEAPU32[$argv + ($storemerge << 2) >> 2];
    if (HEAP8[$5] << 24 >> 24 == 45) {
      __label__ = 4;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 4:
    var $10 = HEAPU8[$5 + 1 | 0];
    if ($10 << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP8[$optionsAllowed] & 1) << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = $5 + 2 | 0;
    if ($10 << 24 >> 24 == 45) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $20 = __ZN2js3cli12OptionParser10findOptionEPKc($this, $18);
    if (($20 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $opt_0 = $20;
      __label__ = 13;
      break;
    }
   case 8:
    __ZN2js3cli12OptionParser5errorEPKcz(STRING_TABLE.__str9660 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $5, tempInt));
    var $_0 = 2;
    __label__ = 17;
    break;
   case 9:
    if (HEAP8[$18] << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2js3cli12OptionParser5errorEPKcz(STRING_TABLE.__str10661 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $5, tempInt));
    var $_0 = 2;
    __label__ = 17;
    break;
   case 11:
    var $28 = __ZN2js3cli12OptionParser10findOptionEc($this, $10);
    if (($28 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $opt_0 = $28;
      __label__ = 13;
      break;
    }
   case 12:
    __ZN2js3cli12OptionParser5errorEPKcz(STRING_TABLE.__str11662 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $5, tempInt));
    var $_0 = 2;
    __label__ = 17;
    break;
   case 13:
    var $opt_0;
    var $32 = __ZN2js3cli12OptionParser12handleOptionEPNS0_6detail6OptionEjPPcPjPb($this, $opt_0, $inputArgc, $argv, $i, $optionsAllowed);
    var $r_0 = $32;
    __label__ = 15;
    break;
   case 14:
    var $34 = __ZN2js3cli12OptionParser9handleArgEjPPcPjPb($this, $argv, $i, $optionsAllowed);
    var $r_0 = $34;
    __label__ = 15;
    break;
   case 15:
    var $r_0;
    if (($r_0 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      var $_0 = $r_0;
      __label__ = 17;
      break;
    }
   case 16:
    var $storemerge = HEAP32[$i >> 2] + 1 | 0;
    __label__ = 2;
    break;
   case 17:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js3cli12OptionParser9parseArgsEiPPc["X"] = 1;

function __ZN2js3cli12OptionParser10findOptionEPKc($this, $longflag) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE5beginEv($_idx_val);
    var $_idx2_val = HEAP32[$this + 4 >> 2];
    var $2 = __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE3endEv($_idx_val, $_idx2_val);
    var $it_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $it_0;
    if (($it_0 | 0) == ($2 | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = HEAP32[$it_0 >> 2];
    var $8 = HEAPU32[$6 + 4 >> 2];
    var $12 = HEAP32[HEAP32[$6 >> 2] + 8 >> 2];
    var $13 = FUNCTION_TABLE[$12]($6);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 4:
    var $15 = _strlen($8);
    var $i_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_0;
    if ($i_0 >>> 0 < $15 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $20 = HEAPU8[$longflag + $i_0 | 0];
    if ($20 << 24 >> 24 == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ($20 << 24 >> 24 == HEAP8[$8 + $i_0 | 0] << 24 >> 24) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 5;
    break;
   case 9:
    var $30 = HEAP8[$longflag + $15 | 0];
    if ($30 << 24 >> 24 == 0 || $30 << 24 >> 24 == 61) {
      __label__ = 10;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 10:
    var $_0 = HEAP32[$it_0 >> 2];
    __label__ = 15;
    break;
   case 11:
    var $34 = _strcmp($8, $longflag);
    if (($34 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $_0 = HEAP32[$it_0 >> 2];
    __label__ = 15;
    break;
   case 13:
    var $it_0 = $it_0 + 4 | 0;
    __label__ = 2;
    break;
   case 14:
    var $40 = $this + 40 | 0;
    var $42 = HEAP32[$this + 44 >> 2];
    var $43 = _strcmp($42, $longflag);
    var $45 = ($43 | 0) != 0 ? 0 : $40;
    var $_0 = $45 | 0;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js3cli12OptionParser10findOptionEPKc["X"] = 1;

function __ZN2js3cli12OptionParser10findOptionEc($this, $shortflag) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_idx_val = HEAP32[$this >> 2];
    var $1 = __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE5beginEv($_idx_val);
    var $_idx2_val = HEAP32[$this + 4 >> 2];
    var $2 = __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE3endEv($_idx_val, $_idx2_val);
    var $it_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $it_0;
    if (($it_0 | 0) == ($2 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = HEAP32[$it_0 >> 2];
    if (HEAP8[$6 + 16 | 0] << 24 >> 24 == $shortflag << 24 >> 24) {
      var $_0 = $6;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $it_0 = $it_0 + 4 | 0;
    __label__ = 2;
    break;
   case 5:
    var $17 = HEAP8[$this + 56 | 0] << 24 >> 24 == $shortflag << 24 >> 24 ? $this + 40 | 0 : 0;
    var $_0 = $17 | 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js3cli12OptionParser13getBoolOptionEc($this, $shortflag) {
  var $1 = __ZNK2js3cli12OptionParser10findOptionEc($this, $shortflag);
  var $2 = __ZNK2js3cli6detail6Option12asBoolOptionEv($1);
  return (HEAP8[$2 + 24 | 0] & 1) << 24 >> 24 != 0;
}

function __ZNK2js3cli12OptionParser10findOptionEc($this, $shortflag) {
  var $1 = __ZN2js3cli12OptionParser10findOptionEc($this, $shortflag);
  return $1;
}

function __ZNK2js3cli12OptionParser20getMultiStringOptionEc($agg_result, $this, $shortflag) {
  var $1 = __ZNK2js3cli12OptionParser10findOptionEc($this, $shortflag);
  var $2 = __ZNK2js3cli6detail6Option19asMultiStringOptionEv($1);
  var $_idx_val = HEAP32[$2 + 24 >> 2];
  var $3 = __ZNK2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE5beginEv($_idx_val);
  var $_idx2_val = HEAP32[$2 + 28 >> 2];
  var $4 = __ZNK2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE3endEv($_idx_val, $_idx2_val);
  __ZN2js3cli16MultiStringRangeC1EPKNS0_6detail9StringArgES5_($agg_result, $3, $4);
  return;
}

function __ZN2js3cli16MultiStringRangeC1EPKNS0_6detail9StringArgES5_($this, $cur, $end) {
  __ZN2js3cli16MultiStringRangeC2EPKNS0_6detail9StringArgES5_($this, $cur, $end);
  return;
}

function __ZN2js3cli12OptionParserD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_idx1_val = HEAP32[$this >> 2];
    var $2 = __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE5beginEv($_idx1_val);
    var $_idx5_val = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE3endEv($_idx1_val, $_idx5_val);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $it_02 = $2;
      __label__ = 2;
      break;
    }
   case 2:
    var $it_02;
    var $5 = HEAP32[$it_02 >> 2];
    __ZN2js10Foreground7delete_INS_3cli6detail6OptionEEEvPT_($5);
    var $6 = $it_02 + 4 | 0;
    if (($6 | 0) == ($3 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $it_02 = $6;
      __label__ = 2;
      break;
    }
   case 3:
    var $8 = $this + 20 | 0;
    var $_idx_val = HEAP32[$8 >> 2];
    var $9 = __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE5beginEv($_idx_val);
    var $_idx3_val = HEAP32[$this + 24 >> 2];
    var $10 = __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE3endEv($_idx_val, $_idx3_val);
    if (($9 | 0) == ($10 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $it1_01 = $9;
      __label__ = 4;
      break;
    }
   case 4:
    var $it1_01;
    var $12 = HEAP32[$it1_01 >> 2];
    __ZN2js10Foreground7delete_INS_3cli6detail6OptionEEEvPT_($12);
    var $13 = $it1_01 + 4 | 0;
    if (($13 | 0) == ($10 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $it1_01 = $13;
      __label__ = 4;
      break;
    }
   case 5:
    __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEED1Ev($8);
    __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEED1Ev($1);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Foreground7delete_INS_3cli6detail6OptionEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[HEAP32[$p >> 2] >> 2];
    FUNCTION_TABLE[$5]($p);
    var $6 = $p;
    _js_free697($6);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZNK2js3cli12OptionParser12findArgumentEPKc($this, $name) {
  var $1 = __ZN2js3cli12OptionParser12findArgumentEPKc($this, $name);
  return $1;
}

function __ZNK2js3cli12OptionParser12getStringArgEPKc($this) {
  var $1 = __ZNK2js3cli12OptionParser12findArgumentEPKc($this, STRING_TABLE.__str120413 | 0);
  var $2 = __ZNK2js3cli6detail6Option14asStringOptionEv($1);
  return HEAP32[$2 + 24 >> 2];
}

function __ZNK2js3cli12OptionParser17getMultiStringArgEPKc($agg_result, $this) {
  var $1 = __ZNK2js3cli12OptionParser12findArgumentEPKc($this, STRING_TABLE.__str122415 | 0);
  var $2 = __ZNK2js3cli6detail6Option19asMultiStringOptionEv($1);
  var $_idx_val = HEAP32[$2 + 24 >> 2];
  var $3 = __ZNK2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE5beginEv($_idx_val);
  var $_idx2_val = HEAP32[$2 + 28 >> 2];
  var $4 = __ZNK2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE3endEv($_idx_val, $_idx2_val);
  __ZN2js3cli16MultiStringRangeC1EPKNS0_6detail9StringArgES5_($agg_result, $3, $4);
  return;
}

function __ZNK2js3cli6detail12ValuedOption8isValuedEv($this) {
  return 1;
}

function __ZNK2js3cli6detail17MultiStringOption10isVariadicEv($this) {
  return 1;
}

function __ZNK2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js3cli6detail12StringOptionD1Ev($this) {
  return;
}

function __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_0_0_val) {
  return $this_0_0_val;
}

function __ZNK2js7MoveRefINS_3cli6detail9StringArgEEcvRS3_Ev($this_0_0_val) {
  return $this_0_0_val;
}

function __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE10endNoCheckEv($this_0_0_val, $this_0_1_val) {
  return $this_0_0_val + ($this_0_1_val << 3) | 0;
}

function __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE10endNoCheckEv($this_0_0_val, $this_0_1_val) {
  return $this_0_0_val + ($this_0_1_val << 2) | 0;
}

function __ZN2js10VectorImplIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyELb1EE13copyConstructIS4_EEvPS4_PKT_SB_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7MoveRefINS_3cli6detail9StringArgEEC2ERS3_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js3cli16MultiStringRangeC2EPKNS0_6detail9StringArgES5_($this, $cur, $end) {
  HEAP32[$this >> 2] = $cur;
  HEAP32[$this + 4 >> 2] = $end;
  return;
}

function __ZN2js3cli6detail9StringArgC2EPcj($this, $value, $argno) {
  HEAP32[$this >> 2] = $value;
  HEAP32[$this + 4 >> 2] = $argno;
  return;
}

function __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE7reserveEj($this, $request) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$this + 8 >> 2] >>> 0 < $request >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $request - HEAP32[$this + 4 >> 2] | 0;
    var $8 = __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE13growStorageByEj($this, $7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE16infallibleAppendERKS4_($this, $t_val) {
  __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE14internalAppendIS4_EEvT_($this, $t_val);
  return;
}

function __ZN2js3cli12OptionParser13addBoolOptionEcPKcS3_($this, $shortflag, $longflag, $help) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_idx_val = HEAP32[$this + 4 >> 2];
    var $2 = __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE6lengthEv($_idx_val);
    var $3 = $2 + 1 | 0;
    var $4 = __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE7reserveEj($1, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = __ZN2js11OffTheBooks4new_INS_3cli6detail10BoolOptionEcPKcS6_EEPT_T0_T1_T2_($shortflag, $longflag, $help);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $6 | 0;
    __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE16infallibleAppendERKS4_($1, $9);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11OffTheBooks4new_INS_3cli6detail10BoolOptionEcPKcS6_EEPT_T0_T1_T2_($p1, $p2, $p3) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_malloc696(28);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js3cli6detail10BoolOptionC1EcPKcS4_($4, $p1, $p2, $p3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js3cli12OptionParser20addMultiStringOptionEcPKcS3_S3_($this, $shortflag, $longflag, $metavar, $help) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_idx_val = HEAP32[$this + 4 >> 2];
    var $2 = __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE6lengthEv($_idx_val);
    var $3 = $2 + 1 | 0;
    var $4 = __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE7reserveEj($1, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = __ZN2js11OffTheBooks4new_INS_3cli6detail17MultiStringOptionEcPKcS6_S6_EEPT_T0_T1_T2_T3_($shortflag, $longflag, $help, $metavar);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $6 | 0;
    __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE16infallibleAppendERKS4_($1, $9);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11OffTheBooks4new_INS_3cli6detail17MultiStringOptionEcPKcS6_S6_EEPT_T0_T1_T2_T3_($p1, $p2, $p3, $p4) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_malloc696(44);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js3cli6detail17MultiStringOptionC1EcPKcS4_S4_($4, $p1, $p2, $p3, $p4);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js3cli12OptionParser20addOptionalStringArgEPKcS3_($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 20 | 0;
    var $_idx_val = HEAP32[$this + 24 >> 2];
    var $2 = __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE6lengthEv($_idx_val);
    var $3 = $2 + 1 | 0;
    var $4 = __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE7reserveEj($1, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = __ZN2js11OffTheBooks4new_INS_3cli6detail12StringOptionEiPKcS6_S6_EEPT_T0_T1_T2_T3_();
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $6 | 0;
    __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE16infallibleAppendERKS4_($1, $9);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11OffTheBooks4new_INS_3cli6detail12StringOptionEiPKcS6_S6_EEPT_T0_T1_T2_T3_() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_malloc696(28);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js3cli6detail12StringOptionC1EcPKcS4_S4_($4);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js3cli12OptionParser25addOptionalMultiStringArgEPKcS3_($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 20 | 0;
    var $_idx_val = HEAP32[$this + 24 >> 2];
    var $2 = __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE6lengthEv($_idx_val);
    var $3 = $2 + 1 | 0;
    var $4 = __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE7reserveEj($1, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = __ZN2js11OffTheBooks4new_INS_3cli6detail17MultiStringOptionEiPKcS6_S6_EEPT_T0_T1_T2_T3_();
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $6 | 0;
    __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE16infallibleAppendERKS4_($1, $9);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11OffTheBooks4new_INS_3cli6detail17MultiStringOptionEiPKcS6_S6_EEPT_T0_T1_T2_T3_() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_malloc696(44);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js3cli6detail17MultiStringOptionC1EcPKcS4_S4_($4, 1, STRING_TABLE.__str122415 | 0, STRING_TABLE.__str123416 | 0, 0);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_malloc696($bytes) {
  var $1 = _malloc($bytes);
  return $1;
}

function __ZN2js3cli6detail17MultiStringOptionC1EcPKcS4_S4_($this, $shortflag, $longflag, $help, $metavar) {
  __ZN2js3cli6detail17MultiStringOptionC2EcPKcS4_S4_($this, $shortflag, $longflag, $help, $metavar);
  return;
}

function __ZN2js3cli6detail17MultiStringOptionC2EcPKcS4_S4_($this, $shortflag, $longflag, $help, $metavar) {
  var $1 = $this | 0;
  __ZN2js3cli6detail12ValuedOptionC2ENS1_10OptionKindEcPKcS5_S5_($1, 3, $shortflag, $longflag, $help, $metavar);
  HEAP32[$this >> 2] = __ZTVN2js3cli6detail17MultiStringOptionE + 8 | 0;
  var $3 = $this + 24 | 0;
  __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEEC1ES4_($3);
  return;
}

function __ZN2js3cli6detail12ValuedOptionC2ENS1_10OptionKindEcPKcS5_S5_($this, $kind, $shortflag, $longflag, $help, $metavar) {
  var $1 = $this | 0;
  __ZN2js3cli6detail6OptionC2ENS1_10OptionKindEcPKcS5_($1, $kind, $shortflag, $longflag, $help);
  HEAP32[$this >> 2] = __ZTVN2js3cli6detail12ValuedOptionE + 8 | 0;
  HEAP32[$this + 20 >> 2] = $metavar;
  return;
}

function __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEEC1ES4_($this) {
  __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEEC2ES4_($this);
  return;
}

function __ZN2js3cli6detail17MultiStringOptionD1Ev($this) {
  __ZN2js3cli6detail17MultiStringOptionD2Ev($this);
  return;
}

function __ZN2js3cli6detail17MultiStringOptionD0Ev($this) {
  __ZN2js3cli6detail17MultiStringOptionD1Ev($this);
  var $1 = $this;
  __ZdlPv($1);
  return;
}

function __ZN2js3cli6detail17MultiStringOptionD2Ev($this) {
  HEAP32[$this >> 2] = __ZTVN2js3cli6detail17MultiStringOptionE + 8 | 0;
  var $2 = $this + 24 | 0;
  __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEED1Ev($2);
  return;
}

function __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this >> 2];
    var $3 = __ZNK2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js17SystemAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = $this + 12 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function _js_free697($p) {
  _free($p);
  return;
}

function __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEEC2ES4_($this) {
  var $1 = $this | 0;
  var $2 = $this + 12 | 0;
  var $3 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($2);
  HEAP32[$1 >> 2] = $3;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN2js3cli6detail12StringOptionC1EcPKcS4_S4_($this) {
  __ZN2js3cli6detail12StringOptionC2EcPKcS4_S4_($this);
  return;
}

function __ZN2js3cli6detail12StringOptionC2EcPKcS4_S4_($this) {
  var $1 = $this | 0;
  __ZN2js3cli6detail12ValuedOptionC2ENS1_10OptionKindEcPKcS5_S5_($1, 1, 1, STRING_TABLE.__str120413 | 0, STRING_TABLE.__str121414 | 0, 0);
  HEAP32[$this >> 2] = __ZTVN2js3cli6detail12StringOptionE + 8 | 0;
  HEAP32[$this + 24 >> 2] = 0;
  return;
}

function __ZN2js3cli6detail12StringOptionD0Ev($this) {
  var $1 = $this;
  __ZdlPv($1);
  return;
}

function __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE14internalAppendIS4_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this >> 2];
    var $this_idx1 = $this + 4 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $5 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    var $5 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    HEAP32[$this_idx1 >> 2] = $5 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = $this + 12 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 2;
    var $7 = __ZN2js17SystemAllocPolicy7malloc_Ej($6);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $11 = __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $12 = __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyELb1EE13moveConstructIS4_EEvPS4_PKT_SB_($8, $11, $12);
    HEAP32[$this_idx >> 2] = $8;
    HEAP32[$this + 8 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS4_Lj0ES5_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $5;
    if ($5 >>> 0 > 536870911) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS4_Lj0ES5_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = __ZN2js17SystemAllocPolicy8realloc_EPvjj($4, $1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5;
    var $9 = $v + 8 | 0;
    HEAP32[$2 >> 2] = $8;
    HEAP32[$9 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyELb1EE13moveConstructIS4_EEvPS4_PKT_SB_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyELb1EE13copyConstructIS4_EEvPS4_PKT_SB_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE13growStorageByEj($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE14internalAppendIS3_EEvT_($this, $t_0, $t_1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_idx_val = HEAP32[$this >> 2];
    var $this_idx1 = $this + 4 | 0;
    var $this_idx1_val = HEAP32[$this_idx1 >> 2];
    var $1 = __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx1_val);
    if (($1 | 0) == 0) {
      var $11 = $this_idx1_val;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $1;
    var $9$1 = $t_1 | 0;
    var $st$10$0 = $5 | 0;
    HEAP32[$st$10$0 >> 2] = 0 | $t_0;
    var $st$10$1 = $5 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $9$1;
    var $11 = HEAP32[$this_idx1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $11;
    HEAP32[$this_idx1 >> 2] = $11 + 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 3;
    var $7 = __ZN2js17SystemAllocPolicy7malloc_Ej($6);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $this_idx = $this | 0;
    var $this_idx_val = HEAP32[$this_idx >> 2];
    var $11 = __ZNK2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $this_idx2_val = HEAP32[$1 >> 2];
    var $12 = __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE10endNoCheckEv($this_idx_val, $this_idx2_val);
    __ZN2js10VectorImplINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyELb0EE13moveConstructIS3_EEvPS3_PKT_SA_($8, $11, $12);
    HEAP32[$this_idx >> 2] = $8;
    HEAP32[$this + 8 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($2, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyELb0EE6growToERNS_6VectorIS3_Lj0ES4_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($curLength, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, 1);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 268435455) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $5;
    if ($5 >>> 0 > 268435455) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyELb0EE6growToERNS_6VectorIS3_Lj0ES4_EEj($v, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $newcap << 3;
    var $3 = __ZN2js17SystemAllocPolicy7malloc_Ej($2);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $v_idx = $v | 0;
    var $v_idx_val = HEAP32[$v_idx >> 2];
    var $7 = __ZNK2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE12beginNoCheckEv($v_idx_val);
    var $v_idx4 = $v + 4 | 0;
    var $v_idx4_val = HEAP32[$v_idx4 >> 2];
    var $8 = __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE10endNoCheckEv($v_idx_val, $v_idx4_val);
    if (($7 | 0) == ($8 | 0)) {
      var $21 = $v_idx_val;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_idx = $1 | 0;
    var $dst_01 = $4;
    var $src_02 = $7;
    var $v_idx1_val5 = $v_idx_val;
    var $v_idx2_val7 = $v_idx4_val;
    __label__ = 4;
    break;
   case 4:
    var $v_idx2_val7;
    var $v_idx1_val5;
    var $src_02;
    var $dst_01;
    if (($dst_01 | 0) == 0) {
      var $v_idx1_val = $v_idx1_val5;
      var $v_idx2_val = $v_idx2_val7;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js4MoveINS_3cli6detail9StringArgEEENS_7MoveRefIT_EERS5_($1, $src_02);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $12 = __ZNK2js7MoveRefINS_3cli6detail9StringArgEEcvRS3_Ev($_idx_val);
    var $13 = $12;
    var $14 = $dst_01;
    var $15$0 = HEAP32[$13 >> 2];
    var $15$1 = HEAP32[$13 + 4 >> 2];
    HEAP32[$14 >> 2] = $15$0;
    HEAP32[$14 + 4 >> 2] = $15$1;
    var $v_idx1_val = HEAP32[$v_idx >> 2];
    var $v_idx2_val = HEAP32[$v_idx4 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $v_idx2_val;
    var $v_idx1_val;
    var $17 = $dst_01 + 8 | 0;
    var $18 = $src_02 + 8 | 0;
    var $19 = __ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE10endNoCheckEv($v_idx1_val, $v_idx2_val);
    if (($18 | 0) == ($19 | 0)) {
      var $21 = $v_idx1_val;
      __label__ = 7;
      break;
    } else {
      var $dst_01 = $17;
      var $src_02 = $18;
      var $v_idx1_val5 = $v_idx1_val;
      var $v_idx2_val7 = $v_idx2_val;
      __label__ = 4;
      break;
    }
   case 7:
    var $21;
    __ZN2js17SystemAllocPolicy5free_EPv($21);
    HEAP32[$v_idx >> 2] = $4;
    HEAP32[$v + 8 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js10VectorImplINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyELb0EE6growToERNS_6VectorIS3_Lj0ES4_EEj["X"] = 1;

function __ZN2js4MoveINS_3cli6detail9StringArgEEENS_7MoveRefIT_EERS5_($agg_result, $t) {
  __ZN2js7MoveRefINS_3cli6detail9StringArgEEC1ERS3_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_3cli6detail9StringArgEEC1ERS3_($this, $t) {
  __ZN2js7MoveRefINS_3cli6detail9StringArgEEC2ERS3_($this, $t);
  return;
}

function __ZN2js10VectorImplINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyELb0EE13moveConstructIS3_EEvPS3_PKT_SA_($dst, $srcbeg, $srcend) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_idx = $1 | 0;
    var $p_01 = $srcbeg;
    var $_02 = $dst;
    __label__ = 3;
    break;
   case 3:
    var $_02;
    var $p_01;
    if (($_02 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js4MoveINS_3cli6detail9StringArgEEENS_7MoveRefIT_EERKS5_($1, $p_01);
    var $_idx_val = HEAP32[$_idx >> 2];
    var $5 = __ZNK2js7MoveRefINS_3cli6detail9StringArgEEcvRS3_Ev($_idx_val);
    var $6 = $5;
    var $7 = $_02;
    var $8$0 = HEAP32[$6 >> 2];
    var $8$1 = HEAP32[$6 + 4 >> 2];
    HEAP32[$7 >> 2] = $8$0;
    HEAP32[$7 + 4 >> 2] = $8$1;
    __label__ = 5;
    break;
   case 5:
    var $10 = $p_01 + 8 | 0;
    if (($10 | 0) == ($srcend | 0)) {
      __label__ = 6;
      break;
    } else {
      var $p_01 = $10;
      var $_02 = $_02 + 8 | 0;
      __label__ = 3;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_3cli6detail9StringArgEEENS_7MoveRefIT_EERKS5_($agg_result, $t) {
  __ZN2js7MoveRefINS_3cli6detail9StringArgEEC1ERS3_($agg_result, $t);
  return;
}

function __ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $this_idx_val = HEAP32[$this >> 2];
    var $3 = __ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE12beginNoCheckEv($this_idx_val);
    var $4 = $3;
    __ZN2js17SystemAllocPolicy5free_EPv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _malloc($bytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($bytes >>> 0 < 245) {
      __label__ = 2;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 2:
    if ($bytes >>> 0 < 11) {
      var $8 = 16;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $bytes + 11 & -8;
    __label__ = 4;
    break;
   case 4:
    var $8;
    var $9 = $8 >>> 3;
    var $10 = HEAPU32[__gm_ >> 2];
    var $11 = $10 >>> ($9 >>> 0);
    if (($11 & 3 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = ($11 & 1 ^ 1) + $9 | 0;
    var $18 = $17 << 1;
    var $20 = __gm_ + 40 + ($18 << 2) | 0;
    var $21 = __gm_ + 40 + ($18 + 2 << 2) | 0;
    var $22 = HEAPU32[$21 >> 2];
    var $23 = $22 + 8 | 0;
    var $24 = HEAPU32[$23 >> 2];
    if (($20 | 0) == ($24 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[__gm_ >> 2] = $10 & (1 << $17 ^ -1);
    __label__ = 10;
    break;
   case 7:
    if ($24 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP32[$21 >> 2] = $24;
    HEAP32[$24 + 12 >> 2] = $20;
    __label__ = 10;
    break;
   case 9:
    _abort();
    throw "Reached an unreachable!";
   case 10:
    var $38 = $17 << 3;
    HEAP32[$22 + 4 >> 2] = $38 | 3;
    var $43 = $22 + ($38 | 4) | 0;
    var $45 = HEAP32[$43 >> 2] | 1;
    HEAP32[$43 >> 2] = $45;
    var $mem_0 = $23;
    __label__ = 38;
    break;
   case 11:
    if ($8 >>> 0 > HEAPU32[__gm_ + 8 >> 2] >>> 0) {
      __label__ = 12;
      break;
    } else {
      var $nb_0 = $8;
      __label__ = 30;
      break;
    }
   case 12:
    if (($11 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $54 = 2 << $9;
    var $57 = $11 << $9 & ($54 | -$54);
    var $60 = ($57 & -$57) - 1 | 0;
    var $62 = $60 >>> 12 & 16;
    var $63 = $60 >>> ($62 >>> 0);
    var $65 = $63 >>> 5 & 8;
    var $66 = $63 >>> ($65 >>> 0);
    var $68 = $66 >>> 2 & 4;
    var $69 = $66 >>> ($68 >>> 0);
    var $71 = $69 >>> 1 & 2;
    var $72 = $69 >>> ($71 >>> 0);
    var $74 = $72 >>> 1 & 1;
    var $80 = ($65 | $62 | $68 | $71 | $74) + ($72 >>> ($74 >>> 0)) | 0;
    var $81 = $80 << 1;
    var $83 = __gm_ + 40 + ($81 << 2) | 0;
    var $84 = __gm_ + 40 + ($81 + 2 << 2) | 0;
    var $85 = HEAPU32[$84 >> 2];
    var $86 = $85 + 8 | 0;
    var $87 = HEAPU32[$86 >> 2];
    if (($83 | 0) == ($87 | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    HEAP32[__gm_ >> 2] = $10 & (1 << $80 ^ -1);
    __label__ = 18;
    break;
   case 15:
    if ($87 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    HEAP32[$84 >> 2] = $87;
    HEAP32[$87 + 12 >> 2] = $83;
    __label__ = 18;
    break;
   case 17:
    _abort();
    throw "Reached an unreachable!";
   case 18:
    var $101 = $80 << 3;
    var $102 = $101 - $8 | 0;
    HEAP32[$85 + 4 >> 2] = $8 | 3;
    var $105 = $85;
    var $107 = $105 + $8 | 0;
    HEAP32[$105 + ($8 | 4) >> 2] = $102 | 1;
    HEAP32[$105 + $101 >> 2] = $102;
    var $113 = HEAPU32[__gm_ + 8 >> 2];
    if (($113 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $116 = HEAP32[__gm_ + 20 >> 2];
    var $119 = $113 >>> 2 & 1073741822;
    var $121 = __gm_ + 40 + ($119 << 2) | 0;
    var $122 = HEAPU32[__gm_ >> 2];
    var $123 = 1 << ($113 >>> 3);
    if (($122 & $123 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[__gm_ >> 2] = $122 | $123;
    var $F4_0 = $121;
    var $_pre_phi = __gm_ + 40 + ($119 + 2 << 2) | 0;
    __label__ = 23;
    break;
   case 21:
    var $129 = __gm_ + 40 + ($119 + 2 << 2) | 0;
    var $130 = HEAPU32[$129 >> 2];
    if ($130 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 22;
      break;
    } else {
      var $F4_0 = $130;
      var $_pre_phi = $129;
      __label__ = 23;
      break;
    }
   case 22:
    _abort();
    throw "Reached an unreachable!";
   case 23:
    var $_pre_phi;
    var $F4_0;
    HEAP32[$_pre_phi >> 2] = $116;
    HEAP32[$F4_0 + 12 >> 2] = $116;
    var $137 = $116 + 8 | 0;
    HEAP32[$137 >> 2] = $F4_0;
    var $138 = $116 + 12 | 0;
    HEAP32[$138 >> 2] = $121;
    __label__ = 24;
    break;
   case 24:
    HEAP32[__gm_ + 8 >> 2] = $102;
    HEAP32[__gm_ + 20 >> 2] = $107;
    var $mem_0 = $86;
    __label__ = 38;
    break;
   case 25:
    if ((HEAP32[__gm_ + 4 >> 2] | 0) == 0) {
      var $nb_0 = $8;
      __label__ = 30;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $145 = _tmalloc_small($8);
    if (($145 | 0) == 0) {
      var $nb_0 = $8;
      __label__ = 30;
      break;
    } else {
      var $mem_0 = $145;
      __label__ = 38;
      break;
    }
   case 27:
    if ($bytes >>> 0 > 4294967231) {
      var $nb_0 = -1;
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $151 = $bytes + 11 & -8;
    if ((HEAP32[__gm_ + 4 >> 2] | 0) == 0) {
      var $nb_0 = $151;
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $155 = _tmalloc_large($151);
    if (($155 | 0) == 0) {
      var $nb_0 = $151;
      __label__ = 30;
      break;
    } else {
      var $mem_0 = $155;
      __label__ = 38;
      break;
    }
   case 30:
    var $nb_0;
    var $157 = HEAPU32[__gm_ + 8 >> 2];
    if ($nb_0 >>> 0 > $157 >>> 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $160 = $157 - $nb_0 | 0;
    var $161 = HEAPU32[__gm_ + 20 >> 2];
    if ($160 >>> 0 > 15) {
      __label__ = 32;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 32:
    var $164 = $161;
    HEAP32[__gm_ + 20 >> 2] = $164 + $nb_0 | 0;
    HEAP32[__gm_ + 8 >> 2] = $160;
    HEAP32[$nb_0 + ($164 + 4) >> 2] = $160 | 1;
    HEAP32[$164 + $157 >> 2] = $160;
    HEAP32[$161 + 4 >> 2] = $nb_0 | 3;
    __label__ = 34;
    break;
   case 33:
    HEAP32[__gm_ + 8 >> 2] = 0;
    HEAP32[__gm_ + 20 >> 2] = 0;
    HEAP32[$161 + 4 >> 2] = $157 | 3;
    var $179 = $157 + ($161 + 4) | 0;
    var $181 = HEAP32[$179 >> 2] | 1;
    HEAP32[$179 >> 2] = $181;
    __label__ = 34;
    break;
   case 34:
    var $mem_0 = $161 + 8 | 0;
    __label__ = 38;
    break;
   case 35:
    var $186 = HEAPU32[__gm_ + 12 >> 2];
    if ($nb_0 >>> 0 < $186 >>> 0) {
      __label__ = 36;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 36:
    var $189 = $186 - $nb_0 | 0;
    HEAP32[__gm_ + 12 >> 2] = $189;
    var $190 = HEAPU32[__gm_ + 24 >> 2];
    var $191 = $190;
    HEAP32[__gm_ + 24 >> 2] = $191 + $nb_0 | 0;
    HEAP32[$nb_0 + ($191 + 4) >> 2] = $189 | 1;
    HEAP32[$190 + 4 >> 2] = $nb_0 | 3;
    var $mem_0 = $190 + 8 | 0;
    __label__ = 38;
    break;
   case 37:
    var $202 = _sys_alloc($nb_0);
    var $mem_0 = $202;
    __label__ = 38;
    break;
   case 38:
    var $mem_0;
    return $mem_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

Module["_malloc"] = _malloc;

_malloc["X"] = 1;

function _tmalloc_small($nb) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[__gm_ + 4 >> 2];
    var $4 = ($1 & -$1) - 1 | 0;
    var $6 = $4 >>> 12 & 16;
    var $7 = $4 >>> ($6 >>> 0);
    var $9 = $7 >>> 5 & 8;
    var $10 = $7 >>> ($9 >>> 0);
    var $12 = $10 >>> 2 & 4;
    var $13 = $10 >>> ($12 >>> 0);
    var $15 = $13 >>> 1 & 2;
    var $16 = $13 >>> ($15 >>> 0);
    var $18 = $16 >>> 1 & 1;
    var $26 = HEAPU32[__gm_ + 304 + (($9 | $6 | $12 | $15 | $18) + ($16 >>> ($18 >>> 0)) << 2) >> 2];
    var $v_0_ph = $26;
    var $rsize_0_ph = (HEAP32[$26 + 4 >> 2] & -8) - $nb | 0;
    __label__ = 2;
    break;
   case 2:
    var $rsize_0_ph;
    var $v_0_ph;
    var $t_0 = $v_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $t_0;
    var $33 = HEAP32[$t_0 + 16 >> 2];
    if (($33 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $39 = $33;
      __label__ = 5;
      break;
    }
   case 4:
    var $37 = HEAP32[$t_0 + 20 >> 2];
    if (($37 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $39 = $37;
      __label__ = 5;
      break;
    }
   case 5:
    var $39;
    var $43 = (HEAP32[$39 + 4 >> 2] & -8) - $nb | 0;
    if ($43 >>> 0 < $rsize_0_ph >>> 0) {
      var $v_0_ph = $39;
      var $rsize_0_ph = $43;
      __label__ = 2;
      break;
    } else {
      var $t_0 = $39;
      __label__ = 3;
      break;
    }
   case 6:
    var $46 = $v_0_ph;
    var $47 = HEAPU32[__gm_ + 16 >> 2];
    if ($46 >>> 0 < $47 >>> 0) {
      __label__ = 49;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $50 = $46 + $nb | 0;
    var $51 = $50;
    if ($46 >>> 0 < $50 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 8:
    var $55 = HEAPU32[$v_0_ph + 24 >> 2];
    var $57 = HEAPU32[$v_0_ph + 12 >> 2];
    if (($57 | 0) == ($v_0_ph | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $61 = HEAPU32[$v_0_ph + 8 >> 2];
    if ($61 >>> 0 < $47 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    HEAP32[$61 + 12 >> 2] = $57;
    HEAP32[$57 + 8 >> 2] = $61;
    var $R_1 = $57;
    __label__ = 19;
    break;
   case 11:
    _abort();
    throw "Reached an unreachable!";
   case 12:
    var $69 = $v_0_ph + 20 | 0;
    var $70 = HEAP32[$69 >> 2];
    if (($70 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $RP_0 = $69;
      var $R_0 = $70;
      __label__ = 14;
      break;
    }
   case 13:
    var $73 = $v_0_ph + 16 | 0;
    var $74 = HEAP32[$73 >> 2];
    if (($74 | 0) == 0) {
      var $R_1 = 0;
      __label__ = 19;
      break;
    } else {
      var $RP_0 = $73;
      var $R_0 = $74;
      __label__ = 14;
      break;
    }
   case 14:
    var $R_0;
    var $RP_0;
    var $76 = $R_0 + 20 | 0;
    var $77 = HEAP32[$76 >> 2];
    if (($77 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      var $RP_0 = $76;
      var $R_0 = $77;
      __label__ = 14;
      break;
    }
   case 15:
    var $80 = $R_0 + 16 | 0;
    var $81 = HEAPU32[$80 >> 2];
    if (($81 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      var $RP_0 = $80;
      var $R_0 = $81;
      __label__ = 14;
      break;
    }
   case 16:
    if ($RP_0 >>> 0 < $47 >>> 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    HEAP32[$RP_0 >> 2] = 0;
    var $R_1 = $R_0;
    __label__ = 19;
    break;
   case 18:
    _abort();
    throw "Reached an unreachable!";
   case 19:
    var $R_1;
    if (($55 | 0) == 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $91 = $v_0_ph + 28 | 0;
    var $93 = __gm_ + 304 + (HEAP32[$91 >> 2] << 2) | 0;
    if (($v_0_ph | 0) == (HEAP32[$93 >> 2] | 0)) {
      __label__ = 21;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 21:
    HEAP32[$93 >> 2] = $R_1;
    if (($R_1 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 22:
    var $101 = HEAP32[__gm_ + 4 >> 2] & (1 << HEAP32[$91 >> 2] ^ -1);
    HEAP32[__gm_ + 4 >> 2] = $101;
    __label__ = 39;
    break;
   case 23:
    if ($55 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $107 = $55 + 16 | 0;
    if ((HEAP32[$107 >> 2] | 0) == ($v_0_ph | 0)) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    HEAP32[$107 >> 2] = $R_1;
    __label__ = 28;
    break;
   case 26:
    HEAP32[$55 + 20 >> 2] = $R_1;
    __label__ = 28;
    break;
   case 27:
    _abort();
    throw "Reached an unreachable!";
   case 28:
    if (($R_1 | 0) == 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    if ($R_1 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 38;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    HEAP32[$R_1 + 24 >> 2] = $55;
    var $123 = HEAPU32[$v_0_ph + 16 >> 2];
    if (($123 | 0) == 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    if ($123 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    HEAP32[$R_1 + 16 >> 2] = $123;
    HEAP32[$123 + 24 >> 2] = $R_1;
    __label__ = 34;
    break;
   case 33:
    _abort();
    throw "Reached an unreachable!";
   case 34:
    var $135 = HEAPU32[$v_0_ph + 20 >> 2];
    if (($135 | 0) == 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    if ($135 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    HEAP32[$R_1 + 20 >> 2] = $135;
    HEAP32[$135 + 24 >> 2] = $R_1;
    __label__ = 39;
    break;
   case 37:
    _abort();
    throw "Reached an unreachable!";
   case 38:
    _abort();
    throw "Reached an unreachable!";
   case 39:
    if ($rsize_0_ph >>> 0 < 16) {
      __label__ = 40;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 40:
    var $149 = $rsize_0_ph + $nb | 0;
    HEAP32[$v_0_ph + 4 >> 2] = $149 | 3;
    var $153 = $149 + ($46 + 4) | 0;
    var $155 = HEAP32[$153 >> 2] | 1;
    HEAP32[$153 >> 2] = $155;
    __label__ = 48;
    break;
   case 41:
    HEAP32[$v_0_ph + 4 >> 2] = $nb | 3;
    HEAP32[$nb + ($46 + 4) >> 2] = $rsize_0_ph | 1;
    HEAP32[$46 + ($rsize_0_ph + $nb) >> 2] = $rsize_0_ph;
    var $164 = HEAPU32[__gm_ + 8 >> 2];
    if (($164 | 0) == 0) {
      __label__ = 47;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $167 = HEAPU32[__gm_ + 20 >> 2];
    var $170 = $164 >>> 2 & 1073741822;
    var $172 = __gm_ + 40 + ($170 << 2) | 0;
    var $173 = HEAPU32[__gm_ >> 2];
    var $174 = 1 << ($164 >>> 3);
    if (($173 & $174 | 0) == 0) {
      __label__ = 43;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 43:
    HEAP32[__gm_ >> 2] = $173 | $174;
    var $F1_0 = $172;
    var $_pre_phi = __gm_ + 40 + ($170 + 2 << 2) | 0;
    __label__ = 46;
    break;
   case 44:
    var $180 = __gm_ + 40 + ($170 + 2 << 2) | 0;
    var $181 = HEAPU32[$180 >> 2];
    if ($181 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 45;
      break;
    } else {
      var $F1_0 = $181;
      var $_pre_phi = $180;
      __label__ = 46;
      break;
    }
   case 45:
    _abort();
    throw "Reached an unreachable!";
   case 46:
    var $_pre_phi;
    var $F1_0;
    HEAP32[$_pre_phi >> 2] = $167;
    HEAP32[$F1_0 + 12 >> 2] = $167;
    HEAP32[$167 + 8 >> 2] = $F1_0;
    HEAP32[$167 + 12 >> 2] = $172;
    __label__ = 47;
    break;
   case 47:
    HEAP32[__gm_ + 8 >> 2] = $rsize_0_ph;
    HEAP32[__gm_ + 20 >> 2] = $51;
    __label__ = 48;
    break;
   case 48:
    return $v_0_ph + 8 | 0;
   case 49:
    _abort();
    throw "Reached an unreachable!";
   default:
    assert(0, "bad label: " + __label__);
  }
}

_tmalloc_small["X"] = 1;

function _sys_alloc($nb) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[_mparams >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _init_mparams();
    __label__ = 3;
    break;
   case 3:
    if ((HEAP32[__gm_ + 440 >> 2] & 4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 4:
    var $9 = HEAP32[__gm_ + 24 >> 2];
    if (($9 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $9;
    var $13 = _segment_holding($12);
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 6:
    var $15 = _sbrk(0);
    if (($15 | 0) == -1) {
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = HEAP32[_mparams + 8 >> 2];
    var $22 = $18 + ($nb + 47) & -$18;
    var $23 = $15;
    var $24 = HEAP32[_mparams + 4 >> 2];
    var $25 = $24 - 1 | 0;
    if (($25 & $23 | 0) == 0) {
      var $asize_0 = $22;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $asize_0 = $22 - $23 + ($25 + $23 & -$24) | 0;
    __label__ = 9;
    break;
   case 9:
    var $asize_0;
    if ($asize_0 >>> 0 < 2147483647) {
      __label__ = 10;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 10:
    var $37 = _sbrk($asize_0);
    if (($37 | 0) == ($15 | 0)) {
      var $tbase_0 = $15;
      var $asize_1 = $asize_0;
      var $br_0 = $37;
      __label__ = 13;
      break;
    } else {
      var $br_08 = $37;
      var $asize_19 = $asize_0;
      __label__ = 15;
      break;
    }
   case 11:
    var $41 = HEAP32[_mparams + 8 >> 2];
    var $46 = $nb + 47 - HEAP32[__gm_ + 12 >> 2] + $41 & -$41;
    if ($46 >>> 0 < 2147483647) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $49 = _sbrk($46);
    if (($49 | 0) == (HEAP32[$13 >> 2] + HEAP32[$13 + 4 >> 2] | 0)) {
      var $tbase_0 = $49;
      var $asize_1 = $46;
      var $br_0 = $49;
      __label__ = 13;
      break;
    } else {
      var $br_08 = $49;
      var $asize_19 = $46;
      __label__ = 15;
      break;
    }
   case 13:
    var $br_0;
    var $asize_1;
    var $tbase_0;
    if (($tbase_0 | 0) == -1) {
      var $br_08 = $br_0;
      var $asize_19 = $asize_1;
      __label__ = 15;
      break;
    } else {
      var $tsize_220 = $asize_1;
      var $tbase_221 = $tbase_0;
      __label__ = 26;
      break;
    }
   case 14:
    var $59 = HEAP32[__gm_ + 440 >> 2] | 4;
    HEAP32[__gm_ + 440 >> 2] = $59;
    __label__ = 23;
    break;
   case 15:
    var $asize_19;
    var $br_08;
    var $60 = -$asize_19 | 0;
    if (($br_08 | 0) != -1 & $asize_19 >>> 0 < 2147483647) {
      __label__ = 16;
      break;
    } else {
      var $asize_2 = $asize_19;
      __label__ = 21;
      break;
    }
   case 16:
    if ($asize_19 >>> 0 < ($nb + 48 | 0) >>> 0) {
      __label__ = 17;
      break;
    } else {
      var $asize_2 = $asize_19;
      __label__ = 21;
      break;
    }
   case 17:
    var $67 = HEAP32[_mparams + 8 >> 2];
    var $72 = $nb + 47 - $asize_19 + $67 & -$67;
    if ($72 >>> 0 < 2147483647) {
      __label__ = 18;
      break;
    } else {
      var $asize_2 = $asize_19;
      __label__ = 21;
      break;
    }
   case 18:
    var $75 = _sbrk($72);
    if (($75 | 0) == -1) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $asize_2 = $72 + $asize_19 | 0;
    __label__ = 21;
    break;
   case 20:
    var $79 = _sbrk($60);
    __label__ = 22;
    break;
   case 21:
    var $asize_2;
    if (($br_08 | 0) == -1) {
      __label__ = 22;
      break;
    } else {
      var $tsize_220 = $asize_2;
      var $tbase_221 = $br_08;
      __label__ = 26;
      break;
    }
   case 22:
    var $84 = HEAP32[__gm_ + 440 >> 2] | 4;
    HEAP32[__gm_ + 440 >> 2] = $84;
    __label__ = 23;
    break;
   case 23:
    var $85 = HEAP32[_mparams + 8 >> 2];
    var $89 = $85 + ($nb + 47) & -$85;
    if ($89 >>> 0 < 2147483647) {
      __label__ = 24;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 24:
    var $92 = _sbrk($89);
    var $93 = _sbrk(0);
    if (($93 | 0) != -1 & ($92 | 0) != -1 & $92 >>> 0 < $93 >>> 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 25:
    var $98 = $93 - $92 | 0;
    if ($98 >>> 0 <= ($nb + 40 | 0) >>> 0 | ($92 | 0) == -1) {
      __label__ = 49;
      break;
    } else {
      var $tsize_220 = $98;
      var $tbase_221 = $92;
      __label__ = 26;
      break;
    }
   case 26:
    var $tbase_221;
    var $tsize_220;
    var $103 = HEAP32[__gm_ + 432 >> 2] + $tsize_220 | 0;
    HEAP32[__gm_ + 432 >> 2] = $103;
    if ($103 >>> 0 > HEAPU32[__gm_ + 436 >> 2] >>> 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 27:
    HEAP32[__gm_ + 436 >> 2] = $103;
    __label__ = 28;
    break;
   case 28:
    var $108 = HEAPU32[__gm_ + 24 >> 2];
    if (($108 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      var $sp_0 = __gm_ + 444 | 0;
      __label__ = 32;
      break;
    }
   case 29:
    var $111 = HEAPU32[__gm_ + 16 >> 2];
    if (($111 | 0) == 0 | $tbase_221 >>> 0 < $111 >>> 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    HEAP32[__gm_ + 16 >> 2] = $tbase_221;
    __label__ = 31;
    break;
   case 31:
    HEAP32[__gm_ + 444 >> 2] = $tbase_221;
    HEAP32[__gm_ + 448 >> 2] = $tsize_220;
    HEAP32[__gm_ + 456 >> 2] = 0;
    var $116 = HEAP32[_mparams >> 2];
    HEAP32[__gm_ + 36 >> 2] = $116;
    HEAP32[__gm_ + 32 >> 2] = -1;
    _init_bins();
    _init_top($tbase_221, $tsize_220 - 40 | 0);
    __label__ = 47;
    break;
   case 32:
    var $sp_0;
    if (($sp_0 | 0) == 0) {
      __label__ = 38;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $122 = HEAPU32[$sp_0 >> 2];
    var $123 = $sp_0 + 4 | 0;
    var $124 = HEAPU32[$123 >> 2];
    var $125 = $122 + $124 | 0;
    if (($tbase_221 | 0) == ($125 | 0)) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $sp_0 = HEAP32[$sp_0 + 8 >> 2];
    __label__ = 32;
    break;
   case 35:
    if ((HEAP32[$sp_0 + 12 >> 2] & 8 | 0) == 0) {
      __label__ = 36;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 36:
    var $135 = $108;
    if ($135 >>> 0 >= $122 >>> 0 & $135 >>> 0 < $125 >>> 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 37:
    HEAP32[$123 >> 2] = $124 + $tsize_220 | 0;
    var $140 = HEAP32[__gm_ + 24 >> 2];
    var $142 = HEAP32[__gm_ + 12 >> 2] + $tsize_220 | 0;
    _init_top($140, $142);
    __label__ = 47;
    break;
   case 38:
    if ($tbase_221 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 39:
    HEAP32[__gm_ + 16 >> 2] = $tbase_221;
    __label__ = 40;
    break;
   case 40:
    var $146 = $tbase_221 + $tsize_220 | 0;
    var $sp_1 = __gm_ + 444 | 0;
    __label__ = 41;
    break;
   case 41:
    var $sp_1;
    if (($sp_1 | 0) == 0) {
      __label__ = 46;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $150 = $sp_1 | 0;
    var $151 = HEAPU32[$150 >> 2];
    if (($151 | 0) == ($146 | 0)) {
      __label__ = 44;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    var $sp_1 = HEAP32[$sp_1 + 8 >> 2];
    __label__ = 41;
    break;
   case 44:
    if ((HEAP32[$sp_1 + 12 >> 2] & 8 | 0) == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 45:
    HEAP32[$150 >> 2] = $tbase_221;
    var $161 = $sp_1 + 4 | 0;
    var $163 = HEAP32[$161 >> 2] + $tsize_220 | 0;
    HEAP32[$161 >> 2] = $163;
    var $164 = _prepend_alloc($tbase_221, $151, $nb);
    var $_0 = $164;
    __label__ = 50;
    break;
   case 46:
    _add_segment($tbase_221, $tsize_220);
    __label__ = 47;
    break;
   case 47:
    var $166 = HEAPU32[__gm_ + 12 >> 2];
    if ($166 >>> 0 > $nb >>> 0) {
      __label__ = 48;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 48:
    var $169 = $166 - $nb | 0;
    HEAP32[__gm_ + 12 >> 2] = $169;
    var $170 = HEAPU32[__gm_ + 24 >> 2];
    var $171 = $170;
    HEAP32[__gm_ + 24 >> 2] = $171 + $nb | 0;
    HEAP32[$nb + ($171 + 4) >> 2] = $169 | 1;
    HEAP32[$170 + 4 >> 2] = $nb | 3;
    var $_0 = $170 + 8 | 0;
    __label__ = 50;
    break;
   case 49:
    var $181 = ___errno();
    HEAP32[$181 >> 2] = 12;
    var $_0 = 0;
    __label__ = 50;
    break;
   case 50:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_sys_alloc["X"] = 1;

function _tmalloc_large($nb) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = -$nb | 0;
    var $2 = $nb >>> 8;
    if (($2 | 0) == 0) {
      var $idx_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($nb >>> 0 > 16777215) {
      var $idx_0 = 31;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = ($2 + 1048320 | 0) >>> 16 & 8;
    var $10 = $2 << $9;
    var $13 = ($10 + 520192 | 0) >>> 16 & 4;
    var $14 = $10 << $13;
    var $17 = ($14 + 245760 | 0) >>> 16 & 2;
    var $23 = 14 - ($13 | $9 | $17) + ($14 << $17 >>> 15) | 0;
    var $idx_0 = $nb >>> (($23 + 7 | 0) >>> 0) & 1 | $23 << 1;
    __label__ = 4;
    break;
   case 4:
    var $idx_0;
    var $31 = HEAPU32[__gm_ + 304 + ($idx_0 << 2) >> 2];
    if (($31 | 0) == 0) {
      var $v_2 = 0;
      var $rsize_2 = $1;
      var $t_1 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($idx_0 | 0) == 31) {
      var $39 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $39 = 25 - ($idx_0 >>> 1) | 0;
    __label__ = 7;
    break;
   case 7:
    var $39;
    var $v_0 = 0;
    var $rsize_0 = $1;
    var $t_0 = $31;
    var $sizebits_0 = $nb << $39;
    var $rst_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $rst_0;
    var $sizebits_0;
    var $t_0;
    var $rsize_0;
    var $v_0;
    var $44 = HEAP32[$t_0 + 4 >> 2] & -8;
    var $45 = $44 - $nb | 0;
    if ($45 >>> 0 < $rsize_0 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $v_1 = $v_0;
      var $rsize_1 = $rsize_0;
      __label__ = 10;
      break;
    }
   case 9:
    if (($44 | 0) == ($nb | 0)) {
      var $v_2 = $t_0;
      var $rsize_2 = $45;
      var $t_1 = $t_0;
      __label__ = 12;
      break;
    } else {
      var $v_1 = $t_0;
      var $rsize_1 = $45;
      __label__ = 10;
      break;
    }
   case 10:
    var $rsize_1;
    var $v_1;
    var $51 = HEAPU32[$t_0 + 20 >> 2];
    var $54 = HEAPU32[$t_0 + 16 + ($sizebits_0 >>> 31 << 2) >> 2];
    var $rst_1 = ($51 | 0) == 0 | ($51 | 0) == ($54 | 0) ? $rst_0 : $51;
    if (($54 | 0) == 0) {
      var $v_2 = $v_1;
      var $rsize_2 = $rsize_1;
      var $t_1 = $rst_1;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $v_0 = $v_1;
    var $rsize_0 = $rsize_1;
    var $t_0 = $54;
    var $sizebits_0 = $sizebits_0 << 1;
    var $rst_0 = $rst_1;
    __label__ = 8;
    break;
   case 12:
    var $t_1;
    var $rsize_2;
    var $v_2;
    if (($t_1 | 0) == 0 & ($v_2 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $t_2_ph = $t_1;
      __label__ = 15;
      break;
    }
   case 13:
    var $63 = 2 << $idx_0;
    var $67 = HEAP32[__gm_ + 4 >> 2] & ($63 | -$63);
    if (($67 | 0) == 0) {
      var $t_2_ph = $t_1;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $72 = ($67 & -$67) - 1 | 0;
    var $74 = $72 >>> 12 & 16;
    var $75 = $72 >>> ($74 >>> 0);
    var $77 = $75 >>> 5 & 8;
    var $78 = $75 >>> ($77 >>> 0);
    var $80 = $78 >>> 2 & 4;
    var $81 = $78 >>> ($80 >>> 0);
    var $83 = $81 >>> 1 & 2;
    var $84 = $81 >>> ($83 >>> 0);
    var $86 = $84 >>> 1 & 1;
    var $t_2_ph = HEAP32[__gm_ + 304 + (($77 | $74 | $80 | $83 | $86) + ($84 >>> ($86 >>> 0)) << 2) >> 2];
    __label__ = 15;
    break;
   case 15:
    var $t_2_ph;
    if (($t_2_ph | 0) == 0) {
      var $rsize_3_lcssa = $rsize_2;
      var $v_3_lcssa = $v_2;
      __label__ = 18;
      break;
    } else {
      var $t_224 = $t_2_ph;
      var $rsize_325 = $rsize_2;
      var $v_326 = $v_2;
      __label__ = 16;
      break;
    }
   case 16:
    var $v_326;
    var $rsize_325;
    var $t_224;
    var $99 = (HEAP32[$t_224 + 4 >> 2] & -8) - $nb | 0;
    var $100 = $99 >>> 0 < $rsize_325 >>> 0;
    var $rsize_4 = $100 ? $99 : $rsize_325;
    var $v_4 = $100 ? $t_224 : $v_326;
    var $102 = HEAPU32[$t_224 + 16 >> 2];
    if (($102 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $t_224 = $102;
      var $rsize_325 = $rsize_4;
      var $v_326 = $v_4;
      __label__ = 16;
      break;
    }
   case 17:
    var $105 = HEAPU32[$t_224 + 20 >> 2];
    if (($105 | 0) == 0) {
      var $rsize_3_lcssa = $rsize_4;
      var $v_3_lcssa = $v_4;
      __label__ = 18;
      break;
    } else {
      var $t_224 = $105;
      var $rsize_325 = $rsize_4;
      var $v_326 = $v_4;
      __label__ = 16;
      break;
    }
   case 18:
    var $v_3_lcssa;
    var $rsize_3_lcssa;
    if (($v_3_lcssa | 0) == 0) {
      var $_0 = 0;
      __label__ = 81;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    if ($rsize_3_lcssa >>> 0 < (HEAP32[__gm_ + 8 >> 2] - $nb | 0) >>> 0) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 81;
      break;
    }
   case 20:
    var $113 = $v_3_lcssa;
    var $114 = HEAPU32[__gm_ + 16 >> 2];
    if ($113 >>> 0 < $114 >>> 0) {
      __label__ = 80;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $117 = $113 + $nb | 0;
    var $118 = $117;
    if ($113 >>> 0 < $117 >>> 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 22:
    var $122 = HEAPU32[$v_3_lcssa + 24 >> 2];
    var $124 = HEAPU32[$v_3_lcssa + 12 >> 2];
    if (($124 | 0) == ($v_3_lcssa | 0)) {
      __label__ = 26;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $128 = HEAPU32[$v_3_lcssa + 8 >> 2];
    if ($128 >>> 0 < $114 >>> 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    HEAP32[$128 + 12 >> 2] = $124;
    HEAP32[$124 + 8 >> 2] = $128;
    var $R_1 = $124;
    __label__ = 33;
    break;
   case 25:
    _abort();
    throw "Reached an unreachable!";
   case 26:
    var $136 = $v_3_lcssa + 20 | 0;
    var $137 = HEAP32[$136 >> 2];
    if (($137 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $RP_0 = $136;
      var $R_0 = $137;
      __label__ = 28;
      break;
    }
   case 27:
    var $140 = $v_3_lcssa + 16 | 0;
    var $141 = HEAP32[$140 >> 2];
    if (($141 | 0) == 0) {
      var $R_1 = 0;
      __label__ = 33;
      break;
    } else {
      var $RP_0 = $140;
      var $R_0 = $141;
      __label__ = 28;
      break;
    }
   case 28:
    var $R_0;
    var $RP_0;
    var $143 = $R_0 + 20 | 0;
    var $144 = HEAP32[$143 >> 2];
    if (($144 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      var $RP_0 = $143;
      var $R_0 = $144;
      __label__ = 28;
      break;
    }
   case 29:
    var $147 = $R_0 + 16 | 0;
    var $148 = HEAPU32[$147 >> 2];
    if (($148 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      var $RP_0 = $147;
      var $R_0 = $148;
      __label__ = 28;
      break;
    }
   case 30:
    if ($RP_0 >>> 0 < $114 >>> 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    HEAP32[$RP_0 >> 2] = 0;
    var $R_1 = $R_0;
    __label__ = 33;
    break;
   case 32:
    _abort();
    throw "Reached an unreachable!";
   case 33:
    var $R_1;
    if (($122 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $158 = $v_3_lcssa + 28 | 0;
    var $160 = __gm_ + 304 + (HEAP32[$158 >> 2] << 2) | 0;
    if (($v_3_lcssa | 0) == (HEAP32[$160 >> 2] | 0)) {
      __label__ = 35;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 35:
    HEAP32[$160 >> 2] = $R_1;
    if (($R_1 | 0) == 0) {
      __label__ = 36;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 36:
    var $168 = HEAP32[__gm_ + 4 >> 2] & (1 << HEAP32[$158 >> 2] ^ -1);
    HEAP32[__gm_ + 4 >> 2] = $168;
    __label__ = 53;
    break;
   case 37:
    if ($122 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $174 = $122 + 16 | 0;
    if ((HEAP32[$174 >> 2] | 0) == ($v_3_lcssa | 0)) {
      __label__ = 39;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 39:
    HEAP32[$174 >> 2] = $R_1;
    __label__ = 42;
    break;
   case 40:
    HEAP32[$122 + 20 >> 2] = $R_1;
    __label__ = 42;
    break;
   case 41:
    _abort();
    throw "Reached an unreachable!";
   case 42:
    if (($R_1 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    if ($R_1 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 52;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    HEAP32[$R_1 + 24 >> 2] = $122;
    var $190 = HEAPU32[$v_3_lcssa + 16 >> 2];
    if (($190 | 0) == 0) {
      __label__ = 48;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    if ($190 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 47;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    HEAP32[$R_1 + 16 >> 2] = $190;
    HEAP32[$190 + 24 >> 2] = $R_1;
    __label__ = 48;
    break;
   case 47:
    _abort();
    throw "Reached an unreachable!";
   case 48:
    var $202 = HEAPU32[$v_3_lcssa + 20 >> 2];
    if (($202 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    if ($202 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    HEAP32[$R_1 + 20 >> 2] = $202;
    HEAP32[$202 + 24 >> 2] = $R_1;
    __label__ = 53;
    break;
   case 51:
    _abort();
    throw "Reached an unreachable!";
   case 52:
    _abort();
    throw "Reached an unreachable!";
   case 53:
    if ($rsize_3_lcssa >>> 0 < 16) {
      __label__ = 54;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 54:
    var $216 = $rsize_3_lcssa + $nb | 0;
    HEAP32[$v_3_lcssa + 4 >> 2] = $216 | 3;
    var $220 = $216 + ($113 + 4) | 0;
    var $222 = HEAP32[$220 >> 2] | 1;
    HEAP32[$220 >> 2] = $222;
    __label__ = 79;
    break;
   case 55:
    HEAP32[$v_3_lcssa + 4 >> 2] = $nb | 3;
    HEAP32[$nb + ($113 + 4) >> 2] = $rsize_3_lcssa | 1;
    HEAP32[$113 + ($rsize_3_lcssa + $nb) >> 2] = $rsize_3_lcssa;
    if ($rsize_3_lcssa >>> 0 < 256) {
      __label__ = 56;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 56:
    var $235 = $rsize_3_lcssa >>> 2 & 1073741822;
    var $237 = __gm_ + 40 + ($235 << 2) | 0;
    var $238 = HEAPU32[__gm_ >> 2];
    var $239 = 1 << ($rsize_3_lcssa >>> 3);
    if (($238 & $239 | 0) == 0) {
      __label__ = 57;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 57:
    HEAP32[__gm_ >> 2] = $238 | $239;
    var $F5_0 = $237;
    var $_pre_phi = __gm_ + 40 + ($235 + 2 << 2) | 0;
    __label__ = 60;
    break;
   case 58:
    var $245 = __gm_ + 40 + ($235 + 2 << 2) | 0;
    var $246 = HEAPU32[$245 >> 2];
    if ($246 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 59;
      break;
    } else {
      var $F5_0 = $246;
      var $_pre_phi = $245;
      __label__ = 60;
      break;
    }
   case 59:
    _abort();
    throw "Reached an unreachable!";
   case 60:
    var $_pre_phi;
    var $F5_0;
    HEAP32[$_pre_phi >> 2] = $118;
    HEAP32[$F5_0 + 12 >> 2] = $118;
    HEAP32[$nb + ($113 + 8) >> 2] = $F5_0;
    HEAP32[$nb + ($113 + 12) >> 2] = $237;
    __label__ = 79;
    break;
   case 61:
    var $258 = $117;
    var $259 = $rsize_3_lcssa >>> 8;
    if (($259 | 0) == 0) {
      var $I7_0 = 0;
      __label__ = 64;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 62:
    if ($rsize_3_lcssa >>> 0 > 16777215) {
      var $I7_0 = 31;
      __label__ = 64;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $266 = ($259 + 1048320 | 0) >>> 16 & 8;
    var $267 = $259 << $266;
    var $270 = ($267 + 520192 | 0) >>> 16 & 4;
    var $271 = $267 << $270;
    var $274 = ($271 + 245760 | 0) >>> 16 & 2;
    var $280 = 14 - ($270 | $266 | $274) + ($271 << $274 >>> 15) | 0;
    var $I7_0 = $rsize_3_lcssa >>> (($280 + 7 | 0) >>> 0) & 1 | $280 << 1;
    __label__ = 64;
    break;
   case 64:
    var $I7_0;
    var $287 = __gm_ + 304 + ($I7_0 << 2) | 0;
    HEAP32[$nb + ($113 + 28) >> 2] = $I7_0;
    var $290 = $nb + ($113 + 16) | 0;
    HEAP32[$nb + ($113 + 20) >> 2] = 0;
    HEAP32[$290 >> 2] = 0;
    var $294 = HEAP32[__gm_ + 4 >> 2];
    var $295 = 1 << $I7_0;
    if (($294 & $295 | 0) == 0) {
      __label__ = 65;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 65:
    var $299 = $294 | $295;
    HEAP32[__gm_ + 4 >> 2] = $299;
    HEAP32[$287 >> 2] = $258;
    HEAP32[$nb + ($113 + 24) >> 2] = $287;
    HEAP32[$nb + ($113 + 12) >> 2] = $258;
    HEAP32[$nb + ($113 + 8) >> 2] = $258;
    __label__ = 79;
    break;
   case 66:
    var $308 = HEAP32[$287 >> 2];
    if (($I7_0 | 0) == 31) {
      var $314 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 67:
    var $314 = 25 - ($I7_0 >>> 1) | 0;
    __label__ = 68;
    break;
   case 68:
    var $314;
    var $K12_0 = $rsize_3_lcssa << $314;
    var $T_0 = $308;
    __label__ = 69;
    break;
   case 69:
    var $T_0;
    var $K12_0;
    if ((HEAP32[$T_0 + 4 >> 2] & -8 | 0) == ($rsize_3_lcssa | 0)) {
      __label__ = 75;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    var $323 = $T_0 + 16 + ($K12_0 >>> 31 << 2) | 0;
    var $324 = HEAPU32[$323 >> 2];
    if (($324 | 0) == 0) {
      __label__ = 72;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 71:
    var $K12_0 = $K12_0 << 1;
    var $T_0 = $324;
    __label__ = 69;
    break;
   case 72:
    if ($323 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 74;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    HEAP32[$323 >> 2] = $258;
    HEAP32[$nb + ($113 + 24) >> 2] = $T_0;
    HEAP32[$nb + ($113 + 12) >> 2] = $258;
    HEAP32[$nb + ($113 + 8) >> 2] = $258;
    __label__ = 79;
    break;
   case 74:
    _abort();
    throw "Reached an unreachable!";
   case 75:
    var $341 = $T_0 + 8 | 0;
    var $342 = HEAPU32[$341 >> 2];
    var $344 = HEAPU32[__gm_ + 16 >> 2];
    if ($T_0 >>> 0 < $344 >>> 0) {
      __label__ = 78;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 76:
    if ($342 >>> 0 < $344 >>> 0) {
      __label__ = 78;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 77:
    HEAP32[$342 + 12 >> 2] = $258;
    HEAP32[$341 >> 2] = $258;
    HEAP32[$nb + ($113 + 8) >> 2] = $342;
    HEAP32[$nb + ($113 + 12) >> 2] = $T_0;
    HEAP32[$nb + ($113 + 24) >> 2] = 0;
    __label__ = 79;
    break;
   case 78:
    _abort();
    throw "Reached an unreachable!";
   case 79:
    var $_0 = $v_3_lcssa + 8 | 0;
    __label__ = 81;
    break;
   case 80:
    _abort();
    throw "Reached an unreachable!";
   case 81:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_tmalloc_large["X"] = 1;

function _release_unused_segments() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sp_01 = HEAP32[__gm_ + 452 >> 2];
    if (($sp_01 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $sp_02 = $sp_01;
      __label__ = 2;
      break;
    }
   case 2:
    var $sp_02;
    var $sp_0 = HEAP32[$sp_02 + 8 >> 2];
    if (($sp_0 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $sp_02 = $sp_0;
      __label__ = 2;
      break;
    }
   case 3:
    HEAP32[__gm_ + 32 >> 2] = -1;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _sys_trim() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[_mparams >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _init_mparams();
    __label__ = 3;
    break;
   case 3:
    var $5 = HEAPU32[__gm_ + 24 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = HEAPU32[__gm_ + 12 >> 2];
    if ($8 >>> 0 > 40) {
      __label__ = 5;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 5:
    var $11 = HEAPU32[_mparams + 8 >> 2];
    var $13 = $8 - 41 + $11 | 0;
    var $14 = Math.floor(($13 >>> 0) / ($11 >>> 0));
    var $16 = ($14 - 1) * $11 | 0;
    var $17 = $5;
    var $18 = _segment_holding($17);
    if ((HEAP32[$18 + 12 >> 2] & 8 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $24 = _sbrk(0);
    var $27 = $18 + 4 | 0;
    if (($24 | 0) == (HEAP32[$18 >> 2] + HEAP32[$27 >> 2] | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    var $_ = $16 >>> 0 > 2147483646 ? -2147483648 - $11 | 0 : $16;
    var $34 = -$_ | 0;
    var $35 = _sbrk($34);
    var $36 = _sbrk(0);
    if (($35 | 0) != -1 & $36 >>> 0 < $24 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $42 = $24 - $36 | 0;
    if (($24 | 0) == ($36 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $46 = HEAP32[$27 >> 2] - $42 | 0;
    HEAP32[$27 >> 2] = $46;
    var $48 = HEAP32[__gm_ + 432 >> 2] - $42 | 0;
    HEAP32[__gm_ + 432 >> 2] = $48;
    var $49 = HEAP32[__gm_ + 24 >> 2];
    var $51 = HEAP32[__gm_ + 12 >> 2] - $42 | 0;
    _init_top($49, $51);
    __label__ = 12;
    break;
   case 10:
    if (HEAPU32[__gm_ + 12 >> 2] >>> 0 > HEAPU32[__gm_ + 28 >> 2] >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[__gm_ + 28 >> 2] = -1;
    __label__ = 12;
    break;
   case 12:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_sys_trim["X"] = 1;

function _free($mem) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($mem | 0) == 0) {
      __label__ = 128;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $mem - 8 | 0;
    var $4 = $3;
    var $5 = HEAPU32[__gm_ + 16 >> 2];
    if ($3 >>> 0 < $5 >>> 0) {
      __label__ = 127;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = HEAPU32[$mem - 4 >> 2];
    var $11 = $10 & 3;
    if (($11 | 0) == 1) {
      __label__ = 127;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $10 & -8;
    var $15 = $mem + ($14 - 8) | 0;
    var $16 = $15;
    if (($10 & 1 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $p_0 = $4;
      var $psize_0 = $14;
      __label__ = 48;
      break;
    }
   case 5:
    var $21 = HEAPU32[$3 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 128;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_sum2 = -8 - $21 | 0;
    var $24 = $mem + $_sum2 | 0;
    var $25 = $24;
    var $26 = $21 + $14 | 0;
    if ($24 >>> 0 < $5 >>> 0) {
      __label__ = 127;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($25 | 0) == (HEAP32[__gm_ + 20 >> 2] | 0)) {
      __label__ = 46;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $32 = $21 >>> 3;
    if ($21 >>> 0 < 256) {
      __label__ = 9;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 9:
    var $37 = HEAPU32[$_sum2 + ($mem + 8) >> 2];
    var $40 = HEAPU32[$_sum2 + ($mem + 12) >> 2];
    if (($37 | 0) == ($40 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $46 = HEAP32[__gm_ >> 2] & (1 << $32 ^ -1);
    HEAP32[__gm_ >> 2] = $46;
    var $p_0 = $25;
    var $psize_0 = $26;
    __label__ = 48;
    break;
   case 11:
    var $51 = __gm_ + 40 + (($21 >>> 2 & 1073741822) << 2) | 0;
    if (($37 | 0) != ($51 | 0) & $37 >>> 0 < $5 >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (($40 | 0) == ($51 | 0) | $40 >>> 0 >= $5 >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    HEAP32[$37 + 12 >> 2] = $40;
    HEAP32[$40 + 8 >> 2] = $37;
    var $p_0 = $25;
    var $psize_0 = $26;
    __label__ = 48;
    break;
   case 14:
    _abort();
    throw "Reached an unreachable!";
   case 15:
    var $62 = $24;
    var $65 = HEAPU32[$_sum2 + ($mem + 24) >> 2];
    var $68 = HEAPU32[$_sum2 + ($mem + 12) >> 2];
    if (($68 | 0) == ($62 | 0)) {
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $73 = HEAPU32[$_sum2 + ($mem + 8) >> 2];
    if ($73 >>> 0 < $5 >>> 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    HEAP32[$73 + 12 >> 2] = $68;
    HEAP32[$68 + 8 >> 2] = $73;
    var $R_1 = $68;
    __label__ = 26;
    break;
   case 18:
    _abort();
    throw "Reached an unreachable!";
   case 19:
    var $82 = $_sum2 + ($mem + 20) | 0;
    var $83 = HEAP32[$82 >> 2];
    if (($83 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      var $RP_0 = $82;
      var $R_0 = $83;
      __label__ = 21;
      break;
    }
   case 20:
    var $87 = $_sum2 + ($mem + 16) | 0;
    var $88 = HEAP32[$87 >> 2];
    if (($88 | 0) == 0) {
      var $R_1 = 0;
      __label__ = 26;
      break;
    } else {
      var $RP_0 = $87;
      var $R_0 = $88;
      __label__ = 21;
      break;
    }
   case 21:
    var $R_0;
    var $RP_0;
    var $90 = $R_0 + 20 | 0;
    var $91 = HEAP32[$90 >> 2];
    if (($91 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      var $RP_0 = $90;
      var $R_0 = $91;
      __label__ = 21;
      break;
    }
   case 22:
    var $94 = $R_0 + 16 | 0;
    var $95 = HEAPU32[$94 >> 2];
    if (($95 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      var $RP_0 = $94;
      var $R_0 = $95;
      __label__ = 21;
      break;
    }
   case 23:
    if ($RP_0 >>> 0 < $5 >>> 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    HEAP32[$RP_0 >> 2] = 0;
    var $R_1 = $R_0;
    __label__ = 26;
    break;
   case 25:
    _abort();
    throw "Reached an unreachable!";
   case 26:
    var $R_1;
    if (($65 | 0) == 0) {
      var $p_0 = $25;
      var $psize_0 = $26;
      __label__ = 48;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $106 = $_sum2 + ($mem + 28) | 0;
    var $108 = __gm_ + 304 + (HEAP32[$106 >> 2] << 2) | 0;
    if (($62 | 0) == (HEAP32[$108 >> 2] | 0)) {
      __label__ = 28;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 28:
    HEAP32[$108 >> 2] = $R_1;
    if (($R_1 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 29:
    var $116 = HEAP32[__gm_ + 4 >> 2] & (1 << HEAP32[$106 >> 2] ^ -1);
    HEAP32[__gm_ + 4 >> 2] = $116;
    var $p_0 = $25;
    var $psize_0 = $26;
    __label__ = 48;
    break;
   case 30:
    if ($65 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $122 = $65 + 16 | 0;
    if ((HEAP32[$122 >> 2] | 0) == ($62 | 0)) {
      __label__ = 32;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 32:
    HEAP32[$122 >> 2] = $R_1;
    __label__ = 35;
    break;
   case 33:
    HEAP32[$65 + 20 >> 2] = $R_1;
    __label__ = 35;
    break;
   case 34:
    _abort();
    throw "Reached an unreachable!";
   case 35:
    if (($R_1 | 0) == 0) {
      var $p_0 = $25;
      var $psize_0 = $26;
      __label__ = 48;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    if ($R_1 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    HEAP32[$R_1 + 24 >> 2] = $65;
    var $139 = HEAPU32[$_sum2 + ($mem + 16) >> 2];
    if (($139 | 0) == 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    if ($139 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 40;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    HEAP32[$R_1 + 16 >> 2] = $139;
    HEAP32[$139 + 24 >> 2] = $R_1;
    __label__ = 41;
    break;
   case 40:
    _abort();
    throw "Reached an unreachable!";
   case 41:
    var $152 = HEAPU32[$_sum2 + ($mem + 20) >> 2];
    if (($152 | 0) == 0) {
      var $p_0 = $25;
      var $psize_0 = $26;
      __label__ = 48;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    if ($152 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    HEAP32[$R_1 + 20 >> 2] = $152;
    HEAP32[$152 + 24 >> 2] = $R_1;
    var $p_0 = $25;
    var $psize_0 = $26;
    __label__ = 48;
    break;
   case 44:
    _abort();
    throw "Reached an unreachable!";
   case 45:
    _abort();
    throw "Reached an unreachable!";
   case 46:
    var $165 = $mem + ($14 - 4) | 0;
    if ((HEAP32[$165 >> 2] & 3 | 0) == 3) {
      __label__ = 47;
      break;
    } else {
      var $p_0 = $25;
      var $psize_0 = $26;
      __label__ = 48;
      break;
    }
   case 47:
    HEAP32[__gm_ + 8 >> 2] = $26;
    var $171 = HEAP32[$165 >> 2] & -2;
    HEAP32[$165 >> 2] = $171;
    HEAP32[$_sum2 + ($mem + 4) >> 2] = $26 | 1;
    HEAP32[$15 >> 2] = $26;
    __label__ = 128;
    break;
   case 48:
    var $psize_0;
    var $p_0;
    var $177 = $p_0;
    if ($177 >>> 0 < $15 >>> 0) {
      __label__ = 49;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 49:
    var $181 = $mem + ($14 - 4) | 0;
    var $182 = HEAPU32[$181 >> 2];
    if (($182 & 1 | 0) == 0) {
      __label__ = 127;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    if (($182 & 2 | 0) == 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 100;
      break;
    }
   case 51:
    if (($16 | 0) == (HEAP32[__gm_ + 24 >> 2] | 0)) {
      __label__ = 52;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 52:
    var $193 = HEAP32[__gm_ + 12 >> 2] + $psize_0 | 0;
    HEAP32[__gm_ + 12 >> 2] = $193;
    HEAP32[__gm_ + 24 >> 2] = $p_0;
    var $194 = $193 | 1;
    HEAP32[$p_0 + 4 >> 2] = $194;
    if (($p_0 | 0) == (HEAP32[__gm_ + 20 >> 2] | 0)) {
      __label__ = 53;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 53:
    HEAP32[__gm_ + 20 >> 2] = 0;
    HEAP32[__gm_ + 8 >> 2] = 0;
    __label__ = 54;
    break;
   case 54:
    if ($193 >>> 0 > HEAPU32[__gm_ + 28 >> 2] >>> 0) {
      __label__ = 55;
      break;
    } else {
      __label__ = 128;
      break;
    }
   case 55:
    _sys_trim();
    __label__ = 128;
    break;
   case 56:
    if (($16 | 0) == (HEAP32[__gm_ + 20 >> 2] | 0)) {
      __label__ = 57;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 57:
    var $208 = HEAP32[__gm_ + 8 >> 2] + $psize_0 | 0;
    HEAP32[__gm_ + 8 >> 2] = $208;
    HEAP32[__gm_ + 20 >> 2] = $p_0;
    var $209 = $208 | 1;
    HEAP32[$p_0 + 4 >> 2] = $209;
    var $212 = $177 + $208 | 0;
    HEAP32[$212 >> 2] = $208;
    __label__ = 128;
    break;
   case 58:
    var $215 = ($182 & -8) + $psize_0 | 0;
    var $216 = $182 >>> 3;
    if ($182 >>> 0 < 256) {
      __label__ = 59;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 59:
    var $221 = HEAPU32[$mem + $14 >> 2];
    var $224 = HEAPU32[$mem + ($14 | 4) >> 2];
    if (($221 | 0) == ($224 | 0)) {
      __label__ = 60;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 60:
    var $230 = HEAP32[__gm_ >> 2] & (1 << $216 ^ -1);
    HEAP32[__gm_ >> 2] = $230;
    __label__ = 98;
    break;
   case 61:
    var $235 = __gm_ + 40 + (($182 >>> 2 & 1073741822) << 2) | 0;
    if (($221 | 0) == ($235 | 0)) {
      __label__ = 63;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 62:
    if ($221 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 66;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    if (($224 | 0) == ($235 | 0)) {
      __label__ = 65;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    if ($224 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 66;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 65:
    HEAP32[$221 + 12 >> 2] = $224;
    HEAP32[$224 + 8 >> 2] = $221;
    __label__ = 98;
    break;
   case 66:
    _abort();
    throw "Reached an unreachable!";
   case 67:
    var $250 = $15;
    var $253 = HEAPU32[$14 + ($mem + 16) >> 2];
    var $256 = HEAPU32[$mem + ($14 | 4) >> 2];
    if (($256 | 0) == ($250 | 0)) {
      __label__ = 71;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 68:
    var $261 = HEAPU32[$mem + $14 >> 2];
    if ($261 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 70;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 69:
    HEAP32[$261 + 12 >> 2] = $256;
    HEAP32[$256 + 8 >> 2] = $261;
    var $R7_1 = $256;
    __label__ = 78;
    break;
   case 70:
    _abort();
    throw "Reached an unreachable!";
   case 71:
    var $271 = $14 + ($mem + 12) | 0;
    var $272 = HEAP32[$271 >> 2];
    if (($272 | 0) == 0) {
      __label__ = 72;
      break;
    } else {
      var $RP9_0 = $271;
      var $R7_0 = $272;
      __label__ = 73;
      break;
    }
   case 72:
    var $276 = $14 + ($mem + 8) | 0;
    var $277 = HEAP32[$276 >> 2];
    if (($277 | 0) == 0) {
      var $R7_1 = 0;
      __label__ = 78;
      break;
    } else {
      var $RP9_0 = $276;
      var $R7_0 = $277;
      __label__ = 73;
      break;
    }
   case 73:
    var $R7_0;
    var $RP9_0;
    var $279 = $R7_0 + 20 | 0;
    var $280 = HEAP32[$279 >> 2];
    if (($280 | 0) == 0) {
      __label__ = 74;
      break;
    } else {
      var $RP9_0 = $279;
      var $R7_0 = $280;
      __label__ = 73;
      break;
    }
   case 74:
    var $283 = $R7_0 + 16 | 0;
    var $284 = HEAPU32[$283 >> 2];
    if (($284 | 0) == 0) {
      __label__ = 75;
      break;
    } else {
      var $RP9_0 = $283;
      var $R7_0 = $284;
      __label__ = 73;
      break;
    }
   case 75:
    if ($RP9_0 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 77;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 76:
    HEAP32[$RP9_0 >> 2] = 0;
    var $R7_1 = $R7_0;
    __label__ = 78;
    break;
   case 77:
    _abort();
    throw "Reached an unreachable!";
   case 78:
    var $R7_1;
    if (($253 | 0) == 0) {
      __label__ = 98;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 79:
    var $296 = $14 + ($mem + 20) | 0;
    var $298 = __gm_ + 304 + (HEAP32[$296 >> 2] << 2) | 0;
    if (($250 | 0) == (HEAP32[$298 >> 2] | 0)) {
      __label__ = 80;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 80:
    HEAP32[$298 >> 2] = $R7_1;
    if (($R7_1 | 0) == 0) {
      __label__ = 81;
      break;
    } else {
      __label__ = 88;
      break;
    }
   case 81:
    var $306 = HEAP32[__gm_ + 4 >> 2] & (1 << HEAP32[$296 >> 2] ^ -1);
    HEAP32[__gm_ + 4 >> 2] = $306;
    __label__ = 98;
    break;
   case 82:
    if ($253 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 86;
      break;
    } else {
      __label__ = 83;
      break;
    }
   case 83:
    var $312 = $253 + 16 | 0;
    if ((HEAP32[$312 >> 2] | 0) == ($250 | 0)) {
      __label__ = 84;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 84:
    HEAP32[$312 >> 2] = $R7_1;
    __label__ = 87;
    break;
   case 85:
    HEAP32[$253 + 20 >> 2] = $R7_1;
    __label__ = 87;
    break;
   case 86:
    _abort();
    throw "Reached an unreachable!";
   case 87:
    if (($R7_1 | 0) == 0) {
      __label__ = 98;
      break;
    } else {
      __label__ = 88;
      break;
    }
   case 88:
    if ($R7_1 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 97;
      break;
    } else {
      __label__ = 89;
      break;
    }
   case 89:
    HEAP32[$R7_1 + 24 >> 2] = $253;
    var $329 = HEAPU32[$14 + ($mem + 8) >> 2];
    if (($329 | 0) == 0) {
      __label__ = 93;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 90:
    if ($329 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 92;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 91:
    HEAP32[$R7_1 + 16 >> 2] = $329;
    HEAP32[$329 + 24 >> 2] = $R7_1;
    __label__ = 93;
    break;
   case 92:
    _abort();
    throw "Reached an unreachable!";
   case 93:
    var $342 = HEAPU32[$14 + ($mem + 12) >> 2];
    if (($342 | 0) == 0) {
      __label__ = 98;
      break;
    } else {
      __label__ = 94;
      break;
    }
   case 94:
    if ($342 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 96;
      break;
    } else {
      __label__ = 95;
      break;
    }
   case 95:
    HEAP32[$R7_1 + 20 >> 2] = $342;
    HEAP32[$342 + 24 >> 2] = $R7_1;
    __label__ = 98;
    break;
   case 96:
    _abort();
    throw "Reached an unreachable!";
   case 97:
    _abort();
    throw "Reached an unreachable!";
   case 98:
    HEAP32[$p_0 + 4 >> 2] = $215 | 1;
    HEAP32[$177 + $215 >> 2] = $215;
    if (($p_0 | 0) == (HEAP32[__gm_ + 20 >> 2] | 0)) {
      __label__ = 99;
      break;
    } else {
      var $psize_1 = $215;
      __label__ = 101;
      break;
    }
   case 99:
    HEAP32[__gm_ + 8 >> 2] = $215;
    __label__ = 128;
    break;
   case 100:
    HEAP32[$181 >> 2] = $182 & -2;
    HEAP32[$p_0 + 4 >> 2] = $psize_0 | 1;
    HEAP32[$177 + $psize_0 >> 2] = $psize_0;
    var $psize_1 = $psize_0;
    __label__ = 101;
    break;
   case 101:
    var $psize_1;
    if ($psize_1 >>> 0 < 256) {
      __label__ = 102;
      break;
    } else {
      __label__ = 107;
      break;
    }
   case 102:
    var $372 = $psize_1 >>> 2 & 1073741822;
    var $374 = __gm_ + 40 + ($372 << 2) | 0;
    var $375 = HEAPU32[__gm_ >> 2];
    var $376 = 1 << ($psize_1 >>> 3);
    if (($375 & $376 | 0) == 0) {
      __label__ = 103;
      break;
    } else {
      __label__ = 104;
      break;
    }
   case 103:
    HEAP32[__gm_ >> 2] = $375 | $376;
    var $F16_0 = $374;
    var $_pre_phi = __gm_ + 40 + ($372 + 2 << 2) | 0;
    __label__ = 106;
    break;
   case 104:
    var $382 = __gm_ + 40 + ($372 + 2 << 2) | 0;
    var $383 = HEAPU32[$382 >> 2];
    if ($383 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 105;
      break;
    } else {
      var $F16_0 = $383;
      var $_pre_phi = $382;
      __label__ = 106;
      break;
    }
   case 105:
    _abort();
    throw "Reached an unreachable!";
   case 106:
    var $_pre_phi;
    var $F16_0;
    HEAP32[$_pre_phi >> 2] = $p_0;
    HEAP32[$F16_0 + 12 >> 2] = $p_0;
    HEAP32[$p_0 + 8 >> 2] = $F16_0;
    HEAP32[$p_0 + 12 >> 2] = $374;
    __label__ = 128;
    break;
   case 107:
    var $393 = $p_0;
    var $394 = $psize_1 >>> 8;
    if (($394 | 0) == 0) {
      var $I18_0 = 0;
      __label__ = 110;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 108:
    if ($psize_1 >>> 0 > 16777215) {
      var $I18_0 = 31;
      __label__ = 110;
      break;
    } else {
      __label__ = 109;
      break;
    }
   case 109:
    var $401 = ($394 + 1048320 | 0) >>> 16 & 8;
    var $402 = $394 << $401;
    var $405 = ($402 + 520192 | 0) >>> 16 & 4;
    var $406 = $402 << $405;
    var $409 = ($406 + 245760 | 0) >>> 16 & 2;
    var $415 = 14 - ($405 | $401 | $409) + ($406 << $409 >>> 15) | 0;
    var $I18_0 = $psize_1 >>> (($415 + 7 | 0) >>> 0) & 1 | $415 << 1;
    __label__ = 110;
    break;
   case 110:
    var $I18_0;
    var $422 = __gm_ + 304 + ($I18_0 << 2) | 0;
    HEAP32[$p_0 + 28 >> 2] = $I18_0;
    HEAP32[$p_0 + 20 >> 2] = 0;
    HEAP32[$p_0 + 16 >> 2] = 0;
    var $426 = HEAP32[__gm_ + 4 >> 2];
    var $427 = 1 << $I18_0;
    if (($426 & $427 | 0) == 0) {
      __label__ = 111;
      break;
    } else {
      __label__ = 112;
      break;
    }
   case 111:
    var $431 = $426 | $427;
    HEAP32[__gm_ + 4 >> 2] = $431;
    HEAP32[$422 >> 2] = $393;
    HEAP32[$p_0 + 24 >> 2] = $422;
    HEAP32[$p_0 + 12 >> 2] = $p_0;
    HEAP32[$p_0 + 8 >> 2] = $p_0;
    __label__ = 125;
    break;
   case 112:
    var $436 = HEAP32[$422 >> 2];
    if (($I18_0 | 0) == 31) {
      var $442 = 0;
      __label__ = 114;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 113:
    var $442 = 25 - ($I18_0 >>> 1) | 0;
    __label__ = 114;
    break;
   case 114:
    var $442;
    var $K19_0 = $psize_1 << $442;
    var $T_0 = $436;
    __label__ = 115;
    break;
   case 115:
    var $T_0;
    var $K19_0;
    if ((HEAP32[$T_0 + 4 >> 2] & -8 | 0) == ($psize_1 | 0)) {
      __label__ = 121;
      break;
    } else {
      __label__ = 116;
      break;
    }
   case 116:
    var $451 = $T_0 + 16 + ($K19_0 >>> 31 << 2) | 0;
    var $452 = HEAPU32[$451 >> 2];
    if (($452 | 0) == 0) {
      __label__ = 118;
      break;
    } else {
      __label__ = 117;
      break;
    }
   case 117:
    var $K19_0 = $K19_0 << 1;
    var $T_0 = $452;
    __label__ = 115;
    break;
   case 118:
    if ($451 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 120;
      break;
    } else {
      __label__ = 119;
      break;
    }
   case 119:
    HEAP32[$451 >> 2] = $393;
    HEAP32[$p_0 + 24 >> 2] = $T_0;
    HEAP32[$p_0 + 12 >> 2] = $p_0;
    HEAP32[$p_0 + 8 >> 2] = $p_0;
    __label__ = 125;
    break;
   case 120:
    _abort();
    throw "Reached an unreachable!";
   case 121:
    var $466 = $T_0 + 8 | 0;
    var $467 = HEAPU32[$466 >> 2];
    var $469 = HEAPU32[__gm_ + 16 >> 2];
    if ($T_0 >>> 0 < $469 >>> 0) {
      __label__ = 124;
      break;
    } else {
      __label__ = 122;
      break;
    }
   case 122:
    if ($467 >>> 0 < $469 >>> 0) {
      __label__ = 124;
      break;
    } else {
      __label__ = 123;
      break;
    }
   case 123:
    HEAP32[$467 + 12 >> 2] = $393;
    HEAP32[$466 >> 2] = $393;
    HEAP32[$p_0 + 8 >> 2] = $467;
    HEAP32[$p_0 + 12 >> 2] = $T_0;
    HEAP32[$p_0 + 24 >> 2] = 0;
    __label__ = 125;
    break;
   case 124:
    _abort();
    throw "Reached an unreachable!";
   case 125:
    var $481 = HEAP32[__gm_ + 32 >> 2] - 1 | 0;
    HEAP32[__gm_ + 32 >> 2] = $481;
    if (($481 | 0) == 0) {
      __label__ = 126;
      break;
    } else {
      __label__ = 128;
      break;
    }
   case 126:
    _release_unused_segments();
    __label__ = 128;
    break;
   case 127:
    _abort();
    throw "Reached an unreachable!";
   case 128:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

Module["_free"] = _free;

_free["X"] = 1;

function _mmap_resize($oldp, $nb) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$oldp + 4 >> 2] & -8;
    if ($nb >>> 0 < 256) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($3 >>> 0 < ($nb + 4 | 0) >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($3 - $nb | 0) >>> 0 > HEAP32[_mparams + 8 >> 2] << 1 >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $oldp;
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _segment_holding($addr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sp_0 = __gm_ + 444 | 0;
    __label__ = 2;
    break;
   case 2:
    var $sp_0;
    var $3 = HEAPU32[$sp_0 >> 2];
    if ($3 >>> 0 > $addr >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($3 + HEAP32[$sp_0 + 4 >> 2] | 0) >>> 0 > $addr >>> 0) {
      var $_0 = $sp_0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = HEAPU32[$sp_0 + 8 >> 2];
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      var $sp_0 = $12;
      __label__ = 2;
      break;
    }
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _init_top($p, $psize) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p;
    var $3 = $p + 8 | 0;
    if (($3 & 7 | 0) == 0) {
      var $10 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = -$3 & 7;
    __label__ = 3;
    break;
   case 3:
    var $10;
    var $13 = $psize - $10 | 0;
    HEAP32[__gm_ + 24 >> 2] = $1 + $10 | 0;
    HEAP32[__gm_ + 12 >> 2] = $13;
    HEAP32[$10 + ($1 + 4) >> 2] = $13 | 1;
    HEAP32[$psize + ($1 + 4) >> 2] = 40;
    var $19 = HEAP32[_mparams + 16 >> 2];
    HEAP32[__gm_ + 28 >> 2] = $19;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _init_bins() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i_02 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_02;
    var $2 = $i_02 << 1;
    var $4 = __gm_ + 40 + ($2 << 2) | 0;
    HEAP32[__gm_ + 40 + ($2 + 3 << 2) >> 2] = $4;
    HEAP32[__gm_ + 40 + ($2 + 2 << 2) >> 2] = $4;
    var $7 = $i_02 + 1 | 0;
    if (($7 | 0) == 32) {
      __label__ = 3;
      break;
    } else {
      var $i_02 = $7;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _calloc($n_elements) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $req_0 = ($n_elements | 0) == 0 ? 0 : $n_elements;
    var $2 = _malloc($req_0);
    if (($2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$2 - 4 >> 2] & 3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _memset($2, 0, $req_0, 1);
    __label__ = 4;
    break;
   case 4:
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _realloc($oldmem, $bytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($oldmem | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = _malloc($bytes);
    var $_0 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = _internal_realloc($oldmem, $bytes);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _internal_realloc($oldmem, $bytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($bytes >>> 0 > 4294967231) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = ___errno();
    HEAP32[$3 >> 2] = 12;
    var $_0 = 0;
    __label__ = 23;
    break;
   case 3:
    var $5 = $oldmem - 8 | 0;
    var $6 = $5;
    var $8 = $oldmem - 4 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $10 = $9 & -8;
    var $_sum = $10 - 8 | 0;
    var $12 = $oldmem + $_sum | 0;
    if ($5 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = $9 & 3;
    if (($16 | 0) != 1 & ($_sum | 0) > -8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 5:
    var $21 = $oldmem + ($10 - 4) | 0;
    if ((HEAP32[$21 >> 2] & 1 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ($bytes >>> 0 < 11) {
      var $31 = 16;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $31 = $bytes + 11 & -8;
    __label__ = 8;
    break;
   case 8:
    var $31;
    if (($16 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = _mmap_resize($6, $31);
    var $extra_0 = 0;
    var $newp_0 = $34;
    __label__ = 17;
    break;
   case 10:
    if ($10 >>> 0 < $31 >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $38 = $10 - $31 | 0;
    if ($38 >>> 0 > 15) {
      __label__ = 12;
      break;
    } else {
      var $extra_0 = 0;
      var $newp_0 = $6;
      __label__ = 17;
      break;
    }
   case 12:
    HEAP32[$8 >> 2] = $31 | $9 & 1 | 2;
    HEAP32[$oldmem + ($31 - 4) >> 2] = $38 | 3;
    var $48 = HEAP32[$21 >> 2] | 1;
    HEAP32[$21 >> 2] = $48;
    var $extra_0 = $oldmem + $31 | 0;
    var $newp_0 = $6;
    __label__ = 17;
    break;
   case 13:
    if (($12 | 0) == (HEAP32[__gm_ + 24 >> 2] | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 14:
    var $55 = HEAP32[__gm_ + 12 >> 2] + $10 | 0;
    if ($55 >>> 0 > $31 >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 15:
    var $58 = $55 - $31 | 0;
    var $60 = $oldmem + ($31 - 8) | 0;
    HEAP32[$8 >> 2] = $31 | $9 & 1 | 2;
    var $66 = $58 | 1;
    HEAP32[$oldmem + ($31 - 4) >> 2] = $66;
    HEAP32[__gm_ + 24 >> 2] = $60;
    HEAP32[__gm_ + 12 >> 2] = $58;
    var $extra_0 = 0;
    var $newp_0 = $6;
    __label__ = 17;
    break;
   case 16:
    _abort();
    throw "Reached an unreachable!";
   case 17:
    var $newp_0;
    var $extra_0;
    if (($newp_0 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if (($extra_0 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    _free($extra_0);
    __label__ = 20;
    break;
   case 20:
    var $_0 = $newp_0 + 8 | 0;
    __label__ = 23;
    break;
   case 21:
    var $75 = _malloc($bytes);
    if (($75 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $81 = (HEAP32[$8 >> 2] & 3 | 0) == 0 ? 8 : 4;
    var $82 = $10 - $81 | 0;
    var $84 = $82 >>> 0 < $bytes >>> 0 ? $82 : $bytes;
    _memcpy($75, $oldmem, $84, 1);
    _free($oldmem);
    var $_0 = $75;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_internal_realloc["X"] = 1;

function _init_mparams() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[_mparams >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = _sysconf(8);
    if (($4 - 1 & $4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _abort();
    throw "Reached an unreachable!";
   case 4:
    HEAP32[_mparams + 8 >> 2] = $4;
    HEAP32[_mparams + 4 >> 2] = $4;
    HEAP32[_mparams + 12 >> 2] = -1;
    HEAP32[_mparams + 16 >> 2] = 2097152;
    HEAP32[_mparams + 20 >> 2] = 0;
    HEAP32[__gm_ + 440 >> 2] = 0;
    var $10 = _time(0);
    HEAP32[_mparams >> 2] = $10 & -16 ^ 1431655768;
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _prepend_alloc($newbase, $oldbase, $nb) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $newbase + 8 | 0;
    if (($2 & 7 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = -$2 & 7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    var $10 = $newbase + $9 | 0;
    var $12 = $oldbase + 8 | 0;
    if (($12 & 7 | 0) == 0) {
      var $19 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = -$12 & 7;
    __label__ = 5;
    break;
   case 5:
    var $19;
    var $20 = $oldbase + $19 | 0;
    var $21 = $20;
    var $_sum = $9 + $nb | 0;
    var $25 = $newbase + $_sum | 0;
    var $26 = $25;
    var $27 = $20 - $10 - $nb | 0;
    HEAP32[$9 + ($newbase + 4) >> 2] = $nb | 3;
    if (($21 | 0) == (HEAP32[__gm_ + 24 >> 2] | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $35 = HEAP32[__gm_ + 12 >> 2] + $27 | 0;
    HEAP32[__gm_ + 12 >> 2] = $35;
    HEAP32[__gm_ + 24 >> 2] = $26;
    var $36 = $35 | 1;
    HEAP32[$_sum + ($newbase + 4) >> 2] = $36;
    __label__ = 75;
    break;
   case 7:
    if (($21 | 0) == (HEAP32[__gm_ + 20 >> 2] | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $44 = HEAP32[__gm_ + 8 >> 2] + $27 | 0;
    HEAP32[__gm_ + 8 >> 2] = $44;
    HEAP32[__gm_ + 20 >> 2] = $26;
    var $45 = $44 | 1;
    HEAP32[$_sum + ($newbase + 4) >> 2] = $45;
    var $49 = $newbase + ($44 + $_sum) | 0;
    HEAP32[$49 >> 2] = $44;
    __label__ = 75;
    break;
   case 9:
    var $53 = HEAPU32[$19 + ($oldbase + 4) >> 2];
    if (($53 & 3 | 0) == 1) {
      __label__ = 10;
      break;
    } else {
      var $oldfirst_0 = $21;
      var $qsize_0 = $27;
      __label__ = 51;
      break;
    }
   case 10:
    var $57 = $53 & -8;
    var $58 = $53 >>> 3;
    if ($53 >>> 0 < 256) {
      __label__ = 11;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 11:
    var $63 = HEAPU32[$oldbase + ($19 | 8) >> 2];
    var $66 = HEAPU32[$19 + ($oldbase + 12) >> 2];
    if (($63 | 0) == ($66 | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $72 = HEAP32[__gm_ >> 2] & (1 << $58 ^ -1);
    HEAP32[__gm_ >> 2] = $72;
    __label__ = 50;
    break;
   case 13:
    var $77 = __gm_ + 40 + (($53 >>> 2 & 1073741822) << 2) | 0;
    if (($63 | 0) == ($77 | 0)) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    if ($63 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    if (($66 | 0) == ($77 | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if ($66 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    HEAP32[$63 + 12 >> 2] = $66;
    HEAP32[$66 + 8 >> 2] = $63;
    __label__ = 50;
    break;
   case 18:
    _abort();
    throw "Reached an unreachable!";
   case 19:
    var $92 = $20;
    var $95 = HEAPU32[$oldbase + ($19 | 24) >> 2];
    var $98 = HEAPU32[$19 + ($oldbase + 12) >> 2];
    if (($98 | 0) == ($92 | 0)) {
      __label__ = 23;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $103 = HEAPU32[$oldbase + ($19 | 8) >> 2];
    if ($103 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    HEAP32[$103 + 12 >> 2] = $98;
    HEAP32[$98 + 8 >> 2] = $103;
    var $R_1 = $98;
    __label__ = 30;
    break;
   case 22:
    _abort();
    throw "Reached an unreachable!";
   case 23:
    var $_sum67 = $19 | 16;
    var $113 = $_sum67 + ($oldbase + 4) | 0;
    var $114 = HEAP32[$113 >> 2];
    if (($114 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      var $RP_0 = $113;
      var $R_0 = $114;
      __label__ = 25;
      break;
    }
   case 24:
    var $118 = $oldbase + $_sum67 | 0;
    var $119 = HEAP32[$118 >> 2];
    if (($119 | 0) == 0) {
      var $R_1 = 0;
      __label__ = 30;
      break;
    } else {
      var $RP_0 = $118;
      var $R_0 = $119;
      __label__ = 25;
      break;
    }
   case 25:
    var $R_0;
    var $RP_0;
    var $121 = $R_0 + 20 | 0;
    var $122 = HEAP32[$121 >> 2];
    if (($122 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      var $RP_0 = $121;
      var $R_0 = $122;
      __label__ = 25;
      break;
    }
   case 26:
    var $125 = $R_0 + 16 | 0;
    var $126 = HEAPU32[$125 >> 2];
    if (($126 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $RP_0 = $125;
      var $R_0 = $126;
      __label__ = 25;
      break;
    }
   case 27:
    if ($RP_0 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    HEAP32[$RP_0 >> 2] = 0;
    var $R_1 = $R_0;
    __label__ = 30;
    break;
   case 29:
    _abort();
    throw "Reached an unreachable!";
   case 30:
    var $R_1;
    if (($95 | 0) == 0) {
      __label__ = 50;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $138 = $19 + ($oldbase + 28) | 0;
    var $140 = __gm_ + 304 + (HEAP32[$138 >> 2] << 2) | 0;
    if (($92 | 0) == (HEAP32[$140 >> 2] | 0)) {
      __label__ = 32;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 32:
    HEAP32[$140 >> 2] = $R_1;
    if (($R_1 | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 33:
    var $148 = HEAP32[__gm_ + 4 >> 2] & (1 << HEAP32[$138 >> 2] ^ -1);
    HEAP32[__gm_ + 4 >> 2] = $148;
    __label__ = 50;
    break;
   case 34:
    if ($95 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 38;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $154 = $95 + 16 | 0;
    if ((HEAP32[$154 >> 2] | 0) == ($92 | 0)) {
      __label__ = 36;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 36:
    HEAP32[$154 >> 2] = $R_1;
    __label__ = 39;
    break;
   case 37:
    HEAP32[$95 + 20 >> 2] = $R_1;
    __label__ = 39;
    break;
   case 38:
    _abort();
    throw "Reached an unreachable!";
   case 39:
    if (($R_1 | 0) == 0) {
      __label__ = 50;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    if ($R_1 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 49;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    HEAP32[$R_1 + 24 >> 2] = $95;
    var $_sum3132 = $19 | 16;
    var $171 = HEAPU32[$oldbase + $_sum3132 >> 2];
    if (($171 | 0) == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    if ($171 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    HEAP32[$R_1 + 16 >> 2] = $171;
    HEAP32[$171 + 24 >> 2] = $R_1;
    __label__ = 45;
    break;
   case 44:
    _abort();
    throw "Reached an unreachable!";
   case 45:
    var $184 = HEAPU32[$_sum3132 + ($oldbase + 4) >> 2];
    if (($184 | 0) == 0) {
      __label__ = 50;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    if ($184 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 48;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    HEAP32[$R_1 + 20 >> 2] = $184;
    HEAP32[$184 + 24 >> 2] = $R_1;
    __label__ = 50;
    break;
   case 48:
    _abort();
    throw "Reached an unreachable!";
   case 49:
    _abort();
    throw "Reached an unreachable!";
   case 50:
    var $oldfirst_0 = $oldbase + ($57 | $19) | 0;
    var $qsize_0 = $57 + $27 | 0;
    __label__ = 51;
    break;
   case 51:
    var $qsize_0;
    var $oldfirst_0;
    var $200 = $oldfirst_0 + 4 | 0;
    var $202 = HEAP32[$200 >> 2] & -2;
    HEAP32[$200 >> 2] = $202;
    HEAP32[$_sum + ($newbase + 4) >> 2] = $qsize_0 | 1;
    HEAP32[$newbase + ($qsize_0 + $_sum) >> 2] = $qsize_0;
    if ($qsize_0 >>> 0 < 256) {
      __label__ = 52;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 52:
    var $212 = $qsize_0 >>> 2 & 1073741822;
    var $214 = __gm_ + 40 + ($212 << 2) | 0;
    var $215 = HEAPU32[__gm_ >> 2];
    var $216 = 1 << ($qsize_0 >>> 3);
    if (($215 & $216 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 53:
    HEAP32[__gm_ >> 2] = $215 | $216;
    var $F4_0 = $214;
    var $_pre_phi = __gm_ + 40 + ($212 + 2 << 2) | 0;
    __label__ = 56;
    break;
   case 54:
    var $222 = __gm_ + 40 + ($212 + 2 << 2) | 0;
    var $223 = HEAPU32[$222 >> 2];
    if ($223 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 55;
      break;
    } else {
      var $F4_0 = $223;
      var $_pre_phi = $222;
      __label__ = 56;
      break;
    }
   case 55:
    _abort();
    throw "Reached an unreachable!";
   case 56:
    var $_pre_phi;
    var $F4_0;
    HEAP32[$_pre_phi >> 2] = $26;
    HEAP32[$F4_0 + 12 >> 2] = $26;
    HEAP32[$_sum + ($newbase + 8) >> 2] = $F4_0;
    HEAP32[$_sum + ($newbase + 12) >> 2] = $214;
    __label__ = 75;
    break;
   case 57:
    var $235 = $25;
    var $236 = $qsize_0 >>> 8;
    if (($236 | 0) == 0) {
      var $I7_0 = 0;
      __label__ = 60;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 58:
    if ($qsize_0 >>> 0 > 16777215) {
      var $I7_0 = 31;
      __label__ = 60;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 59:
    var $243 = ($236 + 1048320 | 0) >>> 16 & 8;
    var $244 = $236 << $243;
    var $247 = ($244 + 520192 | 0) >>> 16 & 4;
    var $248 = $244 << $247;
    var $251 = ($248 + 245760 | 0) >>> 16 & 2;
    var $257 = 14 - ($247 | $243 | $251) + ($248 << $251 >>> 15) | 0;
    var $I7_0 = $qsize_0 >>> (($257 + 7 | 0) >>> 0) & 1 | $257 << 1;
    __label__ = 60;
    break;
   case 60:
    var $I7_0;
    var $264 = __gm_ + 304 + ($I7_0 << 2) | 0;
    HEAP32[$_sum + ($newbase + 28) >> 2] = $I7_0;
    var $267 = $_sum + ($newbase + 16) | 0;
    HEAP32[$_sum + ($newbase + 20) >> 2] = 0;
    HEAP32[$267 >> 2] = 0;
    var $271 = HEAP32[__gm_ + 4 >> 2];
    var $272 = 1 << $I7_0;
    if (($271 & $272 | 0) == 0) {
      __label__ = 61;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 61:
    var $276 = $271 | $272;
    HEAP32[__gm_ + 4 >> 2] = $276;
    HEAP32[$264 >> 2] = $235;
    HEAP32[$_sum + ($newbase + 24) >> 2] = $264;
    HEAP32[$_sum + ($newbase + 12) >> 2] = $235;
    HEAP32[$_sum + ($newbase + 8) >> 2] = $235;
    __label__ = 75;
    break;
   case 62:
    var $285 = HEAP32[$264 >> 2];
    if (($I7_0 | 0) == 31) {
      var $291 = 0;
      __label__ = 64;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $291 = 25 - ($I7_0 >>> 1) | 0;
    __label__ = 64;
    break;
   case 64:
    var $291;
    var $K8_0 = $qsize_0 << $291;
    var $T_0 = $285;
    __label__ = 65;
    break;
   case 65:
    var $T_0;
    var $K8_0;
    if ((HEAP32[$T_0 + 4 >> 2] & -8 | 0) == ($qsize_0 | 0)) {
      __label__ = 71;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 66:
    var $300 = $T_0 + 16 + ($K8_0 >>> 31 << 2) | 0;
    var $301 = HEAPU32[$300 >> 2];
    if (($301 | 0) == 0) {
      __label__ = 68;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 67:
    var $K8_0 = $K8_0 << 1;
    var $T_0 = $301;
    __label__ = 65;
    break;
   case 68:
    if ($300 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 70;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 69:
    HEAP32[$300 >> 2] = $235;
    HEAP32[$_sum + ($newbase + 24) >> 2] = $T_0;
    HEAP32[$_sum + ($newbase + 12) >> 2] = $235;
    HEAP32[$_sum + ($newbase + 8) >> 2] = $235;
    __label__ = 75;
    break;
   case 70:
    _abort();
    throw "Reached an unreachable!";
   case 71:
    var $318 = $T_0 + 8 | 0;
    var $319 = HEAPU32[$318 >> 2];
    var $321 = HEAPU32[__gm_ + 16 >> 2];
    if ($T_0 >>> 0 < $321 >>> 0) {
      __label__ = 74;
      break;
    } else {
      __label__ = 72;
      break;
    }
   case 72:
    if ($319 >>> 0 < $321 >>> 0) {
      __label__ = 74;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    HEAP32[$319 + 12 >> 2] = $235;
    HEAP32[$318 >> 2] = $235;
    HEAP32[$_sum + ($newbase + 8) >> 2] = $319;
    HEAP32[$_sum + ($newbase + 12) >> 2] = $T_0;
    HEAP32[$_sum + ($newbase + 24) >> 2] = 0;
    __label__ = 75;
    break;
   case 74:
    _abort();
    throw "Reached an unreachable!";
   case 75:
    return $newbase + ($9 | 8) | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_prepend_alloc["X"] = 1;

function __ZNKSt9bad_alloc4whatEv($this) {
  return STRING_TABLE.__str3302 | 0;
}

function __ZSt15get_new_handlerv() {
  var $1 = (tempValue = HEAP32[__ZL13__new_handler >> 2], HEAP32[__ZL13__new_handler >> 2] = tempValue + 0, tempValue);
  return $1;
}

function __ZNSt9bad_allocC2Ev($this) {
  HEAP32[$this >> 2] = __ZTVSt9bad_alloc + 8 | 0;
  return;
}

function __ZdlPv($ptr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($ptr | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _free($ptr);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNSt9bad_allocD0Ev($this) {
  __ZNSt9bad_allocD2Ev($this);
  var $1 = $this;
  __ZdlPv($1);
  return;
}

function __ZNSt9bad_allocD2Ev($this) {
  var $1 = $this | 0;
  __ZNSt9exceptionD2Ev($1);
  return;
}

function _add_segment($tbase, $tsize) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[__gm_ + 24 >> 2];
    var $2 = $1;
    var $3 = _segment_holding($2);
    var $5 = HEAP32[$3 >> 2];
    var $7 = HEAP32[$3 + 4 >> 2];
    var $8 = $5 + $7 | 0;
    var $10 = $5 + ($7 - 39) | 0;
    if (($10 & 7 | 0) == 0) {
      var $17 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $17 = -$10 & 7;
    __label__ = 3;
    break;
   case 3:
    var $17;
    var $18 = $5 + ($7 - 47 + $17) | 0;
    var $22 = $18 >>> 0 < ($1 + 16 | 0) >>> 0 ? $2 : $18;
    var $23 = $22 + 8 | 0;
    var $24 = $23;
    var $25 = $tbase;
    var $26 = $tsize - 40 | 0;
    _init_top($25, $26);
    var $28 = $22 + 4 | 0;
    HEAP32[$28 >> 2] = 27;
    HEAP32[$23 >> 2] = HEAP32[__gm_ + 444 >> 2];
    HEAP32[$23 + 4 >> 2] = HEAP32[__gm_ + 448 >> 2];
    HEAP32[$23 + 8 >> 2] = HEAP32[__gm_ + 452 >> 2];
    HEAP32[$23 + 12 >> 2] = HEAP32[__gm_ + 456 >> 2];
    HEAP32[__gm_ + 444 >> 2] = $tbase;
    HEAP32[__gm_ + 448 >> 2] = $tsize;
    HEAP32[__gm_ + 456 >> 2] = 0;
    HEAP32[__gm_ + 452 >> 2] = $24;
    var $30 = $22 + 28 | 0;
    HEAP32[$30 >> 2] = 7;
    if (($22 + 32 | 0) >>> 0 < $8 >>> 0) {
      var $33 = $30;
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $33;
    var $34 = $33 + 4 | 0;
    HEAP32[$34 >> 2] = 7;
    if (($33 + 8 | 0) >>> 0 < $8 >>> 0) {
      var $33 = $34;
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($22 | 0) == ($2 | 0)) {
      __label__ = 30;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $42 = $22 - $1 | 0;
    var $43 = $2 + $42 | 0;
    var $45 = $42 + ($2 + 4) | 0;
    var $47 = HEAP32[$45 >> 2] & -2;
    HEAP32[$45 >> 2] = $47;
    var $48 = $42 | 1;
    HEAP32[$1 + 4 >> 2] = $48;
    var $50 = $43;
    HEAP32[$50 >> 2] = $42;
    if ($42 >>> 0 < 256) {
      __label__ = 7;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 7:
    var $55 = $42 >>> 2 & 1073741822;
    var $57 = __gm_ + 40 + ($55 << 2) | 0;
    var $58 = HEAPU32[__gm_ >> 2];
    var $59 = 1 << ($42 >>> 3);
    if (($58 & $59 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $63 = $58 | $59;
    HEAP32[__gm_ >> 2] = $63;
    var $F_0 = $57;
    var $_pre_phi = __gm_ + 40 + ($55 + 2 << 2) | 0;
    __label__ = 11;
    break;
   case 9:
    var $65 = __gm_ + 40 + ($55 + 2 << 2) | 0;
    var $66 = HEAPU32[$65 >> 2];
    if ($66 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 10;
      break;
    } else {
      var $F_0 = $66;
      var $_pre_phi = $65;
      __label__ = 11;
      break;
    }
   case 10:
    _abort();
    throw "Reached an unreachable!";
   case 11:
    var $_pre_phi;
    var $F_0;
    HEAP32[$_pre_phi >> 2] = $1;
    HEAP32[$F_0 + 12 >> 2] = $1;
    HEAP32[$1 + 8 >> 2] = $F_0;
    HEAP32[$1 + 12 >> 2] = $57;
    __label__ = 30;
    break;
   case 12:
    var $76 = $1;
    var $77 = $42 >>> 8;
    if (($77 | 0) == 0) {
      var $I1_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if ($42 >>> 0 > 16777215) {
      var $I1_0 = 31;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $84 = ($77 + 1048320 | 0) >>> 16 & 8;
    var $85 = $77 << $84;
    var $88 = ($85 + 520192 | 0) >>> 16 & 4;
    var $89 = $85 << $88;
    var $92 = ($89 + 245760 | 0) >>> 16 & 2;
    var $98 = 14 - ($88 | $84 | $92) + ($89 << $92 >>> 15) | 0;
    var $I1_0 = $42 >>> (($98 + 7 | 0) >>> 0) & 1 | $98 << 1;
    __label__ = 15;
    break;
   case 15:
    var $I1_0;
    var $105 = __gm_ + 304 + ($I1_0 << 2) | 0;
    HEAP32[$1 + 28 >> 2] = $I1_0;
    HEAP32[$1 + 20 >> 2] = 0;
    HEAP32[$1 + 16 >> 2] = 0;
    var $109 = HEAP32[__gm_ + 4 >> 2];
    var $110 = 1 << $I1_0;
    if (($109 & $110 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $114 = $109 | $110;
    HEAP32[__gm_ + 4 >> 2] = $114;
    HEAP32[$105 >> 2] = $76;
    HEAP32[$1 + 24 >> 2] = $105;
    HEAP32[$1 + 12 >> 2] = $1;
    HEAP32[$1 + 8 >> 2] = $1;
    __label__ = 30;
    break;
   case 17:
    var $119 = HEAP32[$105 >> 2];
    if (($I1_0 | 0) == 31) {
      var $125 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $125 = 25 - ($I1_0 >>> 1) | 0;
    __label__ = 19;
    break;
   case 19:
    var $125;
    var $K2_0 = $42 << $125;
    var $T_0 = $119;
    __label__ = 20;
    break;
   case 20:
    var $T_0;
    var $K2_0;
    if ((HEAP32[$T_0 + 4 >> 2] & -8 | 0) == ($42 | 0)) {
      __label__ = 26;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $134 = $T_0 + 16 + ($K2_0 >>> 31 << 2) | 0;
    var $135 = HEAPU32[$134 >> 2];
    if (($135 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $K2_0 = $K2_0 << 1;
    var $T_0 = $135;
    __label__ = 20;
    break;
   case 23:
    if ($134 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    HEAP32[$134 >> 2] = $76;
    HEAP32[$1 + 24 >> 2] = $T_0;
    HEAP32[$1 + 12 >> 2] = $1;
    HEAP32[$1 + 8 >> 2] = $1;
    __label__ = 30;
    break;
   case 25:
    _abort();
    throw "Reached an unreachable!";
   case 26:
    var $149 = $T_0 + 8 | 0;
    var $150 = HEAPU32[$149 >> 2];
    var $152 = HEAPU32[__gm_ + 16 >> 2];
    if ($T_0 >>> 0 < $152 >>> 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    if ($150 >>> 0 < $152 >>> 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    HEAP32[$150 + 12 >> 2] = $76;
    HEAP32[$149 >> 2] = $76;
    HEAP32[$1 + 8 >> 2] = $150;
    HEAP32[$1 + 12 >> 2] = $T_0;
    HEAP32[$1 + 24 >> 2] = 0;
    __label__ = 30;
    break;
   case 29:
    _abort();
    throw "Reached an unreachable!";
   case 30:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_add_segment["X"] = 1;

function __Znwj() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __label__ = 2;
    break;
   case 2:
    var $1 = _malloc(8);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 3:
    var $4 = __ZSt15get_new_handlerv();
    if (($4 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    ((function() {
      try {
        __THREW__ = false;
        return FUNCTION_TABLE[$4]();
      } catch (e) {
        if (typeof e != "number") throw e;
        if (ABORT) throw e;
        __THREW__ = true;
        Module.print("Exception: " + e + ", currently at: " + (new Error).stack);
        return null;
      }
    }))();
    if (!__THREW__) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $lpad_loopexit = ___cxa_find_matching_catch(HEAP32[_llvm_eh_exception.buf >> 2], HEAP32[_llvm_eh_exception.buf + 4 >> 2], []);
    var $lpad_phi = $lpad_loopexit;
    __label__ = 7;
    break;
   case 6:
    var $lpad_nonloopexit = ___cxa_find_matching_catch(HEAP32[_llvm_eh_exception.buf >> 2], HEAP32[_llvm_eh_exception.buf + 4 >> 2], []);
    var $lpad_phi = $lpad_nonloopexit;
    __label__ = 7;
    break;
   case 7:
    var $lpad_phi;
    var $8 = $lpad_phi.f1;
    if (($8 | 0) < 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $11 = $lpad_phi.f0;
    ___cxa_call_unexpected($11);
    throw "Reached an unreachable!";
   case 9:
    var $13 = ___cxa_allocate_exception(4);
    var $14 = $13;
    __ZNSt9bad_allocC2Ev($14);
    ((function() {
      try {
        __THREW__ = false;
        return ___cxa_throw($13, __ZTISt9bad_alloc, 302);
      } catch (e) {
        if (typeof e != "number") throw e;
        if (ABORT) throw e;
        __THREW__ = true;
        Module.print("Exception: " + e + ", currently at: " + (new Error).stack);
        return null;
      }
    }))();
    if (!__THREW__) {
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 10:
    return $1;
   case 11:
    Module.print("Resuming exception");
    throw HEAP32[_llvm_eh_exception.buf >> 2];
   case 12:
    throw "Reached an unreachable!";
   default:
    assert(0, "bad label: " + __label__);
  }
}

var i64Math = (function() {
  var goog = {
    math: {}
  };
  goog.math.Long = (function(low, high) {
    this.low_ = low | 0;
    this.high_ = high | 0;
  });
  goog.math.Long.IntCache_ = {};
  goog.math.Long.fromInt = (function(value) {
    if (-128 <= value && value < 128) {
      var cachedObj = goog.math.Long.IntCache_[value];
      if (cachedObj) {
        return cachedObj;
      }
    }
    var obj = new goog.math.Long(value | 0, value < 0 ? -1 : 0);
    if (-128 <= value && value < 128) {
      goog.math.Long.IntCache_[value] = obj;
    }
    return obj;
  });
  goog.math.Long.fromNumber = (function(value) {
    if (isNaN(value) || !isFinite(value)) {
      return goog.math.Long.ZERO;
    } else if (value <= -goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MIN_VALUE;
    } else if (value + 1 >= goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MAX_VALUE;
    } else if (value < 0) {
      return goog.math.Long.fromNumber(-value).negate();
    } else {
      return new goog.math.Long(value % goog.math.Long.TWO_PWR_32_DBL_ | 0, value / goog.math.Long.TWO_PWR_32_DBL_ | 0);
    }
  });
  goog.math.Long.fromBits = (function(lowBits, highBits) {
    return new goog.math.Long(lowBits, highBits);
  });
  goog.math.Long.fromString = (function(str, opt_radix) {
    if (str.length == 0) {
      throw Error("number format error: empty string");
    }
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error("radix out of range: " + radix);
    }
    if (str.charAt(0) == "-") {
      return goog.math.Long.fromString(str.substring(1), radix).negate();
    } else if (str.indexOf("-") >= 0) {
      throw Error('number format error: interior "-" character: ' + str);
    }
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 8));
    var result = goog.math.Long.ZERO;
    for (var i = 0; i < str.length; i += 8) {
      var size = Math.min(8, str.length - i);
      var value = parseInt(str.substring(i, i + size), radix);
      if (size < 8) {
        var power = goog.math.Long.fromNumber(Math.pow(radix, size));
        result = result.multiply(power).add(goog.math.Long.fromNumber(value));
      } else {
        result = result.multiply(radixToPower);
        result = result.add(goog.math.Long.fromNumber(value));
      }
    }
    return result;
  });
  goog.math.Long.TWO_PWR_16_DBL_ = 1 << 16;
  goog.math.Long.TWO_PWR_24_DBL_ = 1 << 24;
  goog.math.Long.TWO_PWR_32_DBL_ = goog.math.Long.TWO_PWR_16_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  goog.math.Long.TWO_PWR_31_DBL_ = goog.math.Long.TWO_PWR_32_DBL_ / 2;
  goog.math.Long.TWO_PWR_48_DBL_ = goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  goog.math.Long.TWO_PWR_64_DBL_ = goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_32_DBL_;
  goog.math.Long.TWO_PWR_63_DBL_ = goog.math.Long.TWO_PWR_64_DBL_ / 2;
  goog.math.Long.ZERO = goog.math.Long.fromInt(0);
  goog.math.Long.ONE = goog.math.Long.fromInt(1);
  goog.math.Long.NEG_ONE = goog.math.Long.fromInt(-1);
  goog.math.Long.MAX_VALUE = goog.math.Long.fromBits(4294967295 | 0, 2147483647 | 0);
  goog.math.Long.MIN_VALUE = goog.math.Long.fromBits(0, 2147483648 | 0);
  goog.math.Long.TWO_PWR_24_ = goog.math.Long.fromInt(1 << 24);
  goog.math.Long.prototype.toInt = (function() {
    return this.low_;
  });
  goog.math.Long.prototype.toNumber = (function() {
    return this.high_ * goog.math.Long.TWO_PWR_32_DBL_ + this.getLowBitsUnsigned();
  });
  goog.math.Long.prototype.toString = (function(opt_radix) {
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error("radix out of range: " + radix);
    }
    if (this.isZero()) {
      return "0";
    }
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        var radixLong = goog.math.Long.fromNumber(radix);
        var div = this.div(radixLong);
        var rem = div.multiply(radixLong).subtract(this);
        return div.toString(radix) + rem.toInt().toString(radix);
      } else {
        return "-" + this.negate().toString(radix);
      }
    }
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 6));
    var rem = this;
    var result = "";
    while (true) {
      var remDiv = rem.div(radixToPower);
      var intval = rem.subtract(remDiv.multiply(radixToPower)).toInt();
      var digits = intval.toString(radix);
      rem = remDiv;
      if (rem.isZero()) {
        return digits + result;
      } else {
        while (digits.length < 6) {
          digits = "0" + digits;
        }
        result = "" + digits + result;
      }
    }
  });
  goog.math.Long.prototype.getHighBits = (function() {
    return this.high_;
  });
  goog.math.Long.prototype.getLowBits = (function() {
    return this.low_;
  });
  goog.math.Long.prototype.getLowBitsUnsigned = (function() {
    return this.low_ >= 0 ? this.low_ : goog.math.Long.TWO_PWR_32_DBL_ + this.low_;
  });
  goog.math.Long.prototype.getNumBitsAbs = (function() {
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        return 64;
      } else {
        return this.negate().getNumBitsAbs();
      }
    } else {
      var val = this.high_ != 0 ? this.high_ : this.low_;
      for (var bit = 31; bit > 0; bit--) {
        if ((val & 1 << bit) != 0) {
          break;
        }
      }
      return this.high_ != 0 ? bit + 33 : bit + 1;
    }
  });
  goog.math.Long.prototype.isZero = (function() {
    return this.high_ == 0 && this.low_ == 0;
  });
  goog.math.Long.prototype.isNegative = (function() {
    return this.high_ < 0;
  });
  goog.math.Long.prototype.isOdd = (function() {
    return (this.low_ & 1) == 1;
  });
  goog.math.Long.prototype.equals = (function(other) {
    return this.high_ == other.high_ && this.low_ == other.low_;
  });
  goog.math.Long.prototype.notEquals = (function(other) {
    return this.high_ != other.high_ || this.low_ != other.low_;
  });
  goog.math.Long.prototype.lessThan = (function(other) {
    return this.compare(other) < 0;
  });
  goog.math.Long.prototype.lessThanOrEqual = (function(other) {
    return this.compare(other) <= 0;
  });
  goog.math.Long.prototype.greaterThan = (function(other) {
    return this.compare(other) > 0;
  });
  goog.math.Long.prototype.greaterThanOrEqual = (function(other) {
    return this.compare(other) >= 0;
  });
  goog.math.Long.prototype.compare = (function(other) {
    if (this.equals(other)) {
      return 0;
    }
    var thisNeg = this.isNegative();
    var otherNeg = other.isNegative();
    if (thisNeg && !otherNeg) {
      return -1;
    }
    if (!thisNeg && otherNeg) {
      return 1;
    }
    if (this.subtract(other).isNegative()) {
      return -1;
    } else {
      return 1;
    }
  });
  goog.math.Long.prototype.negate = (function() {
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.MIN_VALUE;
    } else {
      return this.not().add(goog.math.Long.ONE);
    }
  });
  goog.math.Long.prototype.add = (function(other) {
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 65535;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 65535;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 65535;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 65535;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 + b00;
    c16 += c00 >>> 16;
    c00 &= 65535;
    c16 += a16 + b16;
    c32 += c16 >>> 16;
    c16 &= 65535;
    c32 += a32 + b32;
    c48 += c32 >>> 16;
    c32 &= 65535;
    c48 += a48 + b48;
    c48 &= 65535;
    return goog.math.Long.fromBits(c16 << 16 | c00, c48 << 16 | c32);
  });
  goog.math.Long.prototype.subtract = (function(other) {
    return this.add(other.negate());
  });
  goog.math.Long.prototype.multiply = (function(other) {
    if (this.isZero()) {
      return goog.math.Long.ZERO;
    } else if (other.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return other.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return this.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().multiply(other.negate());
      } else {
        return this.negate().multiply(other).negate();
      }
    } else if (other.isNegative()) {
      return this.multiply(other.negate()).negate();
    }
    if (this.lessThan(goog.math.Long.TWO_PWR_24_) && other.lessThan(goog.math.Long.TWO_PWR_24_)) {
      return goog.math.Long.fromNumber(this.toNumber() * other.toNumber());
    }
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 65535;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 65535;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 65535;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 65535;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 * b00;
    c16 += c00 >>> 16;
    c00 &= 65535;
    c16 += a16 * b00;
    c32 += c16 >>> 16;
    c16 &= 65535;
    c16 += a00 * b16;
    c32 += c16 >>> 16;
    c16 &= 65535;
    c32 += a32 * b00;
    c48 += c32 >>> 16;
    c32 &= 65535;
    c32 += a16 * b16;
    c48 += c32 >>> 16;
    c32 &= 65535;
    c32 += a00 * b32;
    c48 += c32 >>> 16;
    c32 &= 65535;
    c48 += a48 * b00 + a32 * b16 + a16 * b32 + a00 * b48;
    c48 &= 65535;
    return goog.math.Long.fromBits(c16 << 16 | c00, c48 << 16 | c32);
  });
  goog.math.Long.prototype.div = (function(other) {
    if (other.isZero()) {
      throw Error("division by zero");
    } else if (this.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      if (other.equals(goog.math.Long.ONE) || other.equals(goog.math.Long.NEG_ONE)) {
        return goog.math.Long.MIN_VALUE;
      } else if (other.equals(goog.math.Long.MIN_VALUE)) {
        return goog.math.Long.ONE;
      } else {
        var halfThis = this.shiftRight(1);
        var approx = halfThis.div(other).shiftLeft(1);
        if (approx.equals(goog.math.Long.ZERO)) {
          return other.isNegative() ? goog.math.Long.ONE : goog.math.Long.NEG_ONE;
        } else {
          var rem = this.subtract(other.multiply(approx));
          var result = approx.add(rem.div(other));
          return result;
        }
      }
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().div(other.negate());
      } else {
        return this.negate().div(other).negate();
      }
    } else if (other.isNegative()) {
      return this.div(other.negate()).negate();
    }
    var res = goog.math.Long.ZERO;
    var rem = this;
    while (rem.greaterThanOrEqual(other)) {
      var approx = Math.max(1, Math.floor(rem.toNumber() / other.toNumber()));
      var log2 = Math.ceil(Math.log(approx) / Math.LN2);
      var delta = log2 <= 48 ? 1 : Math.pow(2, log2 - 48);
      var approxRes = goog.math.Long.fromNumber(approx);
      var approxRem = approxRes.multiply(other);
      while (approxRem.isNegative() || approxRem.greaterThan(rem)) {
        approx -= delta;
        approxRes = goog.math.Long.fromNumber(approx);
        approxRem = approxRes.multiply(other);
      }
      if (approxRes.isZero()) {
        approxRes = goog.math.Long.ONE;
      }
      res = res.add(approxRes);
      rem = rem.subtract(approxRem);
    }
    return res;
  });
  goog.math.Long.prototype.modulo = (function(other) {
    return this.subtract(this.div(other).multiply(other));
  });
  goog.math.Long.prototype.not = (function() {
    return goog.math.Long.fromBits(~this.low_, ~this.high_);
  });
  goog.math.Long.prototype.and = (function(other) {
    return goog.math.Long.fromBits(this.low_ & other.low_, this.high_ & other.high_);
  });
  goog.math.Long.prototype.or = (function(other) {
    return goog.math.Long.fromBits(this.low_ | other.low_, this.high_ | other.high_);
  });
  goog.math.Long.prototype.xor = (function(other) {
    return goog.math.Long.fromBits(this.low_ ^ other.low_, this.high_ ^ other.high_);
  });
  goog.math.Long.prototype.shiftLeft = (function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var low = this.low_;
      if (numBits < 32) {
        var high = this.high_;
        return goog.math.Long.fromBits(low << numBits, high << numBits | low >>> 32 - numBits);
      } else {
        return goog.math.Long.fromBits(0, low << numBits - 32);
      }
    }
  });
  goog.math.Long.prototype.shiftRight = (function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(low >>> numBits | high << 32 - numBits, high >> numBits);
      } else {
        return goog.math.Long.fromBits(high >> numBits - 32, high >= 0 ? 0 : -1);
      }
    }
  });
  goog.math.Long.prototype.shiftRightUnsigned = (function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(low >>> numBits | high << 32 - numBits, high >>> numBits);
      } else if (numBits == 32) {
        return goog.math.Long.fromBits(high, 0);
      } else {
        return goog.math.Long.fromBits(high >>> numBits - 32, 0);
      }
    }
  });
  var navigator = {
    appName: "Modern Browser"
  };
  var dbits;
  var canary = 0xdeadbeefcafe;
  var j_lm = (canary & 16777215) == 15715070;
  function BigInteger(a, b, c) {
    if (a != null) if ("number" == typeof a) this.fromNumber(a, b, c); else if (b == null && "string" != typeof a) this.fromString(a, 256); else this.fromString(a, b);
  }
  function nbi() {
    return new BigInteger(null);
  }
  function am1(i, x, w, j, c, n) {
    while (--n >= 0) {
      var v = x * this[i++] + w[j] + c;
      c = Math.floor(v / 67108864);
      w[j++] = v & 67108863;
    }
    return c;
  }
  function am2(i, x, w, j, c, n) {
    var xl = x & 32767, xh = x >> 15;
    while (--n >= 0) {
      var l = this[i] & 32767;
      var h = this[i++] >> 15;
      var m = xh * l + h * xl;
      l = xl * l + ((m & 32767) << 15) + w[j] + (c & 1073741823);
      c = (l >>> 30) + (m >>> 15) + xh * h + (c >>> 30);
      w[j++] = l & 1073741823;
    }
    return c;
  }
  function am3(i, x, w, j, c, n) {
    var xl = x & 16383, xh = x >> 14;
    while (--n >= 0) {
      var l = this[i] & 16383;
      var h = this[i++] >> 14;
      var m = xh * l + h * xl;
      l = xl * l + ((m & 16383) << 14) + w[j] + c;
      c = (l >> 28) + (m >> 14) + xh * h;
      w[j++] = l & 268435455;
    }
    return c;
  }
  if (j_lm && navigator.appName == "Microsoft Internet Explorer") {
    BigInteger.prototype.am = am2;
    dbits = 30;
  } else if (j_lm && navigator.appName != "Netscape") {
    BigInteger.prototype.am = am1;
    dbits = 26;
  } else {
    BigInteger.prototype.am = am3;
    dbits = 28;
  }
  BigInteger.prototype.DB = dbits;
  BigInteger.prototype.DM = (1 << dbits) - 1;
  BigInteger.prototype.DV = 1 << dbits;
  var BI_FP = 52;
  BigInteger.prototype.FV = Math.pow(2, BI_FP);
  BigInteger.prototype.F1 = BI_FP - dbits;
  BigInteger.prototype.F2 = 2 * dbits - BI_FP;
  var BI_RM = "0123456789abcdefghijklmnopqrstuvwxyz";
  var BI_RC = new Array;
  var rr, vv;
  rr = "0".charCodeAt(0);
  for (vv = 0; vv <= 9; ++vv) BI_RC[rr++] = vv;
  rr = "a".charCodeAt(0);
  for (vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  rr = "A".charCodeAt(0);
  for (vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  function int2char(n) {
    return BI_RM.charAt(n);
  }
  function intAt(s, i) {
    var c = BI_RC[s.charCodeAt(i)];
    return c == null ? -1 : c;
  }
  function bnpCopyTo(r) {
    for (var i = this.t - 1; i >= 0; --i) r[i] = this[i];
    r.t = this.t;
    r.s = this.s;
  }
  function bnpFromInt(x) {
    this.t = 1;
    this.s = x < 0 ? -1 : 0;
    if (x > 0) this[0] = x; else if (x < -1) this[0] = x + DV; else this.t = 0;
  }
  function nbv(i) {
    var r = nbi();
    r.fromInt(i);
    return r;
  }
  function bnpFromString(s, b) {
    var k;
    if (b == 16) k = 4; else if (b == 8) k = 3; else if (b == 256) k = 8; else if (b == 2) k = 1; else if (b == 32) k = 5; else if (b == 4) k = 2; else {
      this.fromRadix(s, b);
      return;
    }
    this.t = 0;
    this.s = 0;
    var i = s.length, mi = false, sh = 0;
    while (--i >= 0) {
      var x = k == 8 ? s[i] & 255 : intAt(s, i);
      if (x < 0) {
        if (s.charAt(i) == "-") mi = true;
        continue;
      }
      mi = false;
      if (sh == 0) this[this.t++] = x; else if (sh + k > this.DB) {
        this[this.t - 1] |= (x & (1 << this.DB - sh) - 1) << sh;
        this[this.t++] = x >> this.DB - sh;
      } else this[this.t - 1] |= x << sh;
      sh += k;
      if (sh >= this.DB) sh -= this.DB;
    }
    if (k == 8 && (s[0] & 128) != 0) {
      this.s = -1;
      if (sh > 0) this[this.t - 1] |= (1 << this.DB - sh) - 1 << sh;
    }
    this.clamp();
    if (mi) BigInteger.ZERO.subTo(this, this);
  }
  function bnpClamp() {
    var c = this.s & this.DM;
    while (this.t > 0 && this[this.t - 1] == c) --this.t;
  }
  function bnToString(b) {
    if (this.s < 0) return "-" + this.negate().toString(b);
    var k;
    if (b == 16) k = 4; else if (b == 8) k = 3; else if (b == 2) k = 1; else if (b == 32) k = 5; else if (b == 4) k = 2; else return this.toRadix(b);
    var km = (1 << k) - 1, d, m = false, r = "", i = this.t;
    var p = this.DB - i * this.DB % k;
    if (i-- > 0) {
      if (p < this.DB && (d = this[i] >> p) > 0) {
        m = true;
        r = int2char(d);
      }
      while (i >= 0) {
        if (p < k) {
          d = (this[i] & (1 << p) - 1) << k - p;
          d |= this[--i] >> (p += this.DB - k);
        } else {
          d = this[i] >> (p -= k) & km;
          if (p <= 0) {
            p += this.DB;
            --i;
          }
        }
        if (d > 0) m = true;
        if (m) r += int2char(d);
      }
    }
    return m ? r : "0";
  }
  function bnNegate() {
    var r = nbi();
    BigInteger.ZERO.subTo(this, r);
    return r;
  }
  function bnAbs() {
    return this.s < 0 ? this.negate() : this;
  }
  function bnCompareTo(a) {
    var r = this.s - a.s;
    if (r != 0) return r;
    var i = this.t;
    r = i - a.t;
    if (r != 0) return r;
    while (--i >= 0) if ((r = this[i] - a[i]) != 0) return r;
    return 0;
  }
  function nbits(x) {
    var r = 1, t;
    if ((t = x >>> 16) != 0) {
      x = t;
      r += 16;
    }
    if ((t = x >> 8) != 0) {
      x = t;
      r += 8;
    }
    if ((t = x >> 4) != 0) {
      x = t;
      r += 4;
    }
    if ((t = x >> 2) != 0) {
      x = t;
      r += 2;
    }
    if ((t = x >> 1) != 0) {
      x = t;
      r += 1;
    }
    return r;
  }
  function bnBitLength() {
    if (this.t <= 0) return 0;
    return this.DB * (this.t - 1) + nbits(this[this.t - 1] ^ this.s & this.DM);
  }
  function bnpDLShiftTo(n, r) {
    var i;
    for (i = this.t - 1; i >= 0; --i) r[i + n] = this[i];
    for (i = n - 1; i >= 0; --i) r[i] = 0;
    r.t = this.t + n;
    r.s = this.s;
  }
  function bnpDRShiftTo(n, r) {
    for (var i = n; i < this.t; ++i) r[i - n] = this[i];
    r.t = Math.max(this.t - n, 0);
    r.s = this.s;
  }
  function bnpLShiftTo(n, r) {
    var bs = n % this.DB;
    var cbs = this.DB - bs;
    var bm = (1 << cbs) - 1;
    var ds = Math.floor(n / this.DB), c = this.s << bs & this.DM, i;
    for (i = this.t - 1; i >= 0; --i) {
      r[i + ds + 1] = this[i] >> cbs | c;
      c = (this[i] & bm) << bs;
    }
    for (i = ds - 1; i >= 0; --i) r[i] = 0;
    r[ds] = c;
    r.t = this.t + ds + 1;
    r.s = this.s;
    r.clamp();
  }
  function bnpRShiftTo(n, r) {
    r.s = this.s;
    var ds = Math.floor(n / this.DB);
    if (ds >= this.t) {
      r.t = 0;
      return;
    }
    var bs = n % this.DB;
    var cbs = this.DB - bs;
    var bm = (1 << bs) - 1;
    r[0] = this[ds] >> bs;
    for (var i = ds + 1; i < this.t; ++i) {
      r[i - ds - 1] |= (this[i] & bm) << cbs;
      r[i - ds] = this[i] >> bs;
    }
    if (bs > 0) r[this.t - ds - 1] |= (this.s & bm) << cbs;
    r.t = this.t - ds;
    r.clamp();
  }
  function bnpSubTo(a, r) {
    var i = 0, c = 0, m = Math.min(a.t, this.t);
    while (i < m) {
      c += this[i] - a[i];
      r[i++] = c & this.DM;
      c >>= this.DB;
    }
    if (a.t < this.t) {
      c -= a.s;
      while (i < this.t) {
        c += this[i];
        r[i++] = c & this.DM;
        c >>= this.DB;
      }
      c += this.s;
    } else {
      c += this.s;
      while (i < a.t) {
        c -= a[i];
        r[i++] = c & this.DM;
        c >>= this.DB;
      }
      c -= a.s;
    }
    r.s = c < 0 ? -1 : 0;
    if (c < -1) r[i++] = this.DV + c; else if (c > 0) r[i++] = c;
    r.t = i;
    r.clamp();
  }
  function bnpMultiplyTo(a, r) {
    var x = this.abs(), y = a.abs();
    var i = x.t;
    r.t = i + y.t;
    while (--i >= 0) r[i] = 0;
    for (i = 0; i < y.t; ++i) r[i + x.t] = x.am(0, y[i], r, i, 0, x.t);
    r.s = 0;
    r.clamp();
    if (this.s != a.s) BigInteger.ZERO.subTo(r, r);
  }
  function bnpSquareTo(r) {
    var x = this.abs();
    var i = r.t = 2 * x.t;
    while (--i >= 0) r[i] = 0;
    for (i = 0; i < x.t - 1; ++i) {
      var c = x.am(i, x[i], r, 2 * i, 0, 1);
      if ((r[i + x.t] += x.am(i + 1, 2 * x[i], r, 2 * i + 1, c, x.t - i - 1)) >= x.DV) {
        r[i + x.t] -= x.DV;
        r[i + x.t + 1] = 1;
      }
    }
    if (r.t > 0) r[r.t - 1] += x.am(i, x[i], r, 2 * i, 0, 1);
    r.s = 0;
    r.clamp();
  }
  function bnpDivRemTo(m, q, r) {
    var pm = m.abs();
    if (pm.t <= 0) return;
    var pt = this.abs();
    if (pt.t < pm.t) {
      if (q != null) q.fromInt(0);
      if (r != null) this.copyTo(r);
      return;
    }
    if (r == null) r = nbi();
    var y = nbi(), ts = this.s, ms = m.s;
    var nsh = this.DB - nbits(pm[pm.t - 1]);
    if (nsh > 0) {
      pm.lShiftTo(nsh, y);
      pt.lShiftTo(nsh, r);
    } else {
      pm.copyTo(y);
      pt.copyTo(r);
    }
    var ys = y.t;
    var y0 = y[ys - 1];
    if (y0 == 0) return;
    var yt = y0 * (1 << this.F1) + (ys > 1 ? y[ys - 2] >> this.F2 : 0);
    var d1 = this.FV / yt, d2 = (1 << this.F1) / yt, e = 1 << this.F2;
    var i = r.t, j = i - ys, t = q == null ? nbi() : q;
    y.dlShiftTo(j, t);
    if (r.compareTo(t) >= 0) {
      r[r.t++] = 1;
      r.subTo(t, r);
    }
    BigInteger.ONE.dlShiftTo(ys, t);
    t.subTo(y, y);
    while (y.t < ys) y[y.t++] = 0;
    while (--j >= 0) {
      var qd = r[--i] == y0 ? this.DM : Math.floor(r[i] * d1 + (r[i - 1] + e) * d2);
      if ((r[i] += y.am(0, qd, r, j, 0, ys)) < qd) {
        y.dlShiftTo(j, t);
        r.subTo(t, r);
        while (r[i] < --qd) r.subTo(t, r);
      }
    }
    if (q != null) {
      r.drShiftTo(ys, q);
      if (ts != ms) BigInteger.ZERO.subTo(q, q);
    }
    r.t = ys;
    r.clamp();
    if (nsh > 0) r.rShiftTo(nsh, r);
    if (ts < 0) BigInteger.ZERO.subTo(r, r);
  }
  function bnMod(a) {
    var r = nbi();
    this.abs().divRemTo(a, null, r);
    if (this.s < 0 && r.compareTo(BigInteger.ZERO) > 0) a.subTo(r, r);
    return r;
  }
  function Classic(m) {
    this.m = m;
  }
  function cConvert(x) {
    if (x.s < 0 || x.compareTo(this.m) >= 0) return x.mod(this.m); else return x;
  }
  function cRevert(x) {
    return x;
  }
  function cReduce(x) {
    x.divRemTo(this.m, null, x);
  }
  function cMulTo(x, y, r) {
    x.multiplyTo(y, r);
    this.reduce(r);
  }
  function cSqrTo(x, r) {
    x.squareTo(r);
    this.reduce(r);
  }
  Classic.prototype.convert = cConvert;
  Classic.prototype.revert = cRevert;
  Classic.prototype.reduce = cReduce;
  Classic.prototype.mulTo = cMulTo;
  Classic.prototype.sqrTo = cSqrTo;
  function bnpInvDigit() {
    if (this.t < 1) return 0;
    var x = this[0];
    if ((x & 1) == 0) return 0;
    var y = x & 3;
    y = y * (2 - (x & 15) * y) & 15;
    y = y * (2 - (x & 255) * y) & 255;
    y = y * (2 - ((x & 65535) * y & 65535)) & 65535;
    y = y * (2 - x * y % this.DV) % this.DV;
    return y > 0 ? this.DV - y : -y;
  }
  function Montgomery(m) {
    this.m = m;
    this.mp = m.invDigit();
    this.mpl = this.mp & 32767;
    this.mph = this.mp >> 15;
    this.um = (1 << m.DB - 15) - 1;
    this.mt2 = 2 * m.t;
  }
  function montConvert(x) {
    var r = nbi();
    x.abs().dlShiftTo(this.m.t, r);
    r.divRemTo(this.m, null, r);
    if (x.s < 0 && r.compareTo(BigInteger.ZERO) > 0) this.m.subTo(r, r);
    return r;
  }
  function montRevert(x) {
    var r = nbi();
    x.copyTo(r);
    this.reduce(r);
    return r;
  }
  function montReduce(x) {
    while (x.t <= this.mt2) x[x.t++] = 0;
    for (var i = 0; i < this.m.t; ++i) {
      var j = x[i] & 32767;
      var u0 = j * this.mpl + ((j * this.mph + (x[i] >> 15) * this.mpl & this.um) << 15) & x.DM;
      j = i + this.m.t;
      x[j] += this.m.am(0, u0, x, i, 0, this.m.t);
      while (x[j] >= x.DV) {
        x[j] -= x.DV;
        x[++j]++;
      }
    }
    x.clamp();
    x.drShiftTo(this.m.t, x);
    if (x.compareTo(this.m) >= 0) x.subTo(this.m, x);
  }
  function montSqrTo(x, r) {
    x.squareTo(r);
    this.reduce(r);
  }
  function montMulTo(x, y, r) {
    x.multiplyTo(y, r);
    this.reduce(r);
  }
  Montgomery.prototype.convert = montConvert;
  Montgomery.prototype.revert = montRevert;
  Montgomery.prototype.reduce = montReduce;
  Montgomery.prototype.mulTo = montMulTo;
  Montgomery.prototype.sqrTo = montSqrTo;
  function bnpIsEven() {
    return (this.t > 0 ? this[0] & 1 : this.s) == 0;
  }
  function bnpExp(e, z) {
    if (e > 4294967295 || e < 1) return BigInteger.ONE;
    var r = nbi(), r2 = nbi(), g = z.convert(this), i = nbits(e) - 1;
    g.copyTo(r);
    while (--i >= 0) {
      z.sqrTo(r, r2);
      if ((e & 1 << i) > 0) z.mulTo(r2, g, r); else {
        var t = r;
        r = r2;
        r2 = t;
      }
    }
    return z.revert(r);
  }
  function bnModPowInt(e, m) {
    var z;
    if (e < 256 || m.isEven()) z = new Classic(m); else z = new Montgomery(m);
    return this.exp(e, z);
  }
  BigInteger.prototype.copyTo = bnpCopyTo;
  BigInteger.prototype.fromInt = bnpFromInt;
  BigInteger.prototype.fromString = bnpFromString;
  BigInteger.prototype.clamp = bnpClamp;
  BigInteger.prototype.dlShiftTo = bnpDLShiftTo;
  BigInteger.prototype.drShiftTo = bnpDRShiftTo;
  BigInteger.prototype.lShiftTo = bnpLShiftTo;
  BigInteger.prototype.rShiftTo = bnpRShiftTo;
  BigInteger.prototype.subTo = bnpSubTo;
  BigInteger.prototype.multiplyTo = bnpMultiplyTo;
  BigInteger.prototype.squareTo = bnpSquareTo;
  BigInteger.prototype.divRemTo = bnpDivRemTo;
  BigInteger.prototype.invDigit = bnpInvDigit;
  BigInteger.prototype.isEven = bnpIsEven;
  BigInteger.prototype.exp = bnpExp;
  BigInteger.prototype.toString = bnToString;
  BigInteger.prototype.negate = bnNegate;
  BigInteger.prototype.abs = bnAbs;
  BigInteger.prototype.compareTo = bnCompareTo;
  BigInteger.prototype.bitLength = bnBitLength;
  BigInteger.prototype.mod = bnMod;
  BigInteger.prototype.modPowInt = bnModPowInt;
  BigInteger.ZERO = nbv(0);
  BigInteger.ONE = nbv(1);
  function bnpFromRadix(s, b) {
    this.fromInt(0);
    if (b == null) b = 10;
    var cs = this.chunkSize(b);
    var d = Math.pow(b, cs), mi = false, j = 0, w = 0;
    for (var i = 0; i < s.length; ++i) {
      var x = intAt(s, i);
      if (x < 0) {
        if (s.charAt(i) == "-" && this.signum() == 0) mi = true;
        continue;
      }
      w = b * w + x;
      if (++j >= cs) {
        this.dMultiply(d);
        this.dAddOffset(w, 0);
        j = 0;
        w = 0;
      }
    }
    if (j > 0) {
      this.dMultiply(Math.pow(b, j));
      this.dAddOffset(w, 0);
    }
    if (mi) BigInteger.ZERO.subTo(this, this);
  }
  function bnpChunkSize(r) {
    return Math.floor(Math.LN2 * this.DB / Math.log(r));
  }
  function bnSigNum() {
    if (this.s < 0) return -1; else if (this.t <= 0 || this.t == 1 && this[0] <= 0) return 0; else return 1;
  }
  function bnpDMultiply(n) {
    this[this.t] = this.am(0, n - 1, this, 0, 0, this.t);
    ++this.t;
    this.clamp();
  }
  function bnpDAddOffset(n, w) {
    if (n == 0) return;
    while (this.t <= w) this[this.t++] = 0;
    this[w] += n;
    while (this[w] >= this.DV) {
      this[w] -= this.DV;
      if (++w >= this.t) this[this.t++] = 0;
      ++this[w];
    }
  }
  function bnpToRadix(b) {
    if (b == null) b = 10;
    if (this.signum() == 0 || b < 2 || b > 36) return "0";
    var cs = this.chunkSize(b);
    var a = Math.pow(b, cs);
    var d = nbv(a), y = nbi(), z = nbi(), r = "";
    this.divRemTo(d, y, z);
    while (y.signum() > 0) {
      r = (a + z.intValue()).toString(b).substr(1) + r;
      y.divRemTo(d, y, z);
    }
    return z.intValue().toString(b) + r;
  }
  function bnIntValue() {
    if (this.s < 0) {
      if (this.t == 1) return this[0] - this.DV; else if (this.t == 0) return -1;
    } else if (this.t == 1) return this[0]; else if (this.t == 0) return 0;
    return (this[1] & (1 << 32 - this.DB) - 1) << this.DB | this[0];
  }
  function bnpAddTo(a, r) {
    var i = 0, c = 0, m = Math.min(a.t, this.t);
    while (i < m) {
      c += this[i] + a[i];
      r[i++] = c & this.DM;
      c >>= this.DB;
    }
    if (a.t < this.t) {
      c += a.s;
      while (i < this.t) {
        c += this[i];
        r[i++] = c & this.DM;
        c >>= this.DB;
      }
      c += this.s;
    } else {
      c += this.s;
      while (i < a.t) {
        c += a[i];
        r[i++] = c & this.DM;
        c >>= this.DB;
      }
      c += a.s;
    }
    r.s = c < 0 ? -1 : 0;
    if (c > 0) r[i++] = c; else if (c < -1) r[i++] = this.DV + c;
    r.t = i;
    r.clamp();
  }
  BigInteger.prototype.fromRadix = bnpFromRadix;
  BigInteger.prototype.chunkSize = bnpChunkSize;
  BigInteger.prototype.signum = bnSigNum;
  BigInteger.prototype.dMultiply = bnpDMultiply;
  BigInteger.prototype.dAddOffset = bnpDAddOffset;
  BigInteger.prototype.toRadix = bnpToRadix;
  BigInteger.prototype.intValue = bnIntValue;
  BigInteger.prototype.addTo = bnpAddTo;
  var Wrapper = {
    result: [ 0, 0 ],
    add: (function(xl, xh, yl, yh) {
      var x = new goog.math.Long(xl, xh);
      var y = new goog.math.Long(yl, yh);
      var ret = x.add(y);
      Wrapper.result[0] = ret.low_;
      Wrapper.result[1] = ret.high_;
    }),
    subtract: (function(xl, xh, yl, yh) {
      var x = new goog.math.Long(xl, xh);
      var y = new goog.math.Long(yl, yh);
      var ret = x.subtract(y);
      Wrapper.result[0] = ret.low_;
      Wrapper.result[1] = ret.high_;
    }),
    multiply: (function(xl, xh, yl, yh) {
      var x = new goog.math.Long(xl, xh);
      var y = new goog.math.Long(yl, yh);
      var ret = x.multiply(y);
      Wrapper.result[0] = ret.low_;
      Wrapper.result[1] = ret.high_;
    }),
    makeTwo32: (function() {
      Wrapper.two32 = new BigInteger;
      Wrapper.two32.fromString("4294967296", 10);
    }),
    lh2bignum: (function(l, h) {
      var a = new BigInteger;
      a.fromString(h.toString(), 10);
      var b = new BigInteger;
      a.multiplyTo(Wrapper.two32, b);
      var c = new BigInteger;
      c.fromString(l.toString(), 10);
      var d = new BigInteger;
      c.addTo(b, d);
      return d;
    }),
    divide: (function(xl, xh, yl, yh, unsigned) {
      if (!Wrapper.two32) Wrapper.makeTwo32();
      if (!unsigned) {
        var x = new goog.math.Long(xl, xh);
        var y = new goog.math.Long(yl, yh);
        var ret = x.div(y);
        Wrapper.result[0] = ret.low_;
        Wrapper.result[1] = ret.high_;
      } else {
        var x = Wrapper.lh2bignum(xl >>> 0, xh >>> 0);
        var y = Wrapper.lh2bignum(yl >>> 0, yh >>> 0);
        var z = new BigInteger;
        x.divRemTo(y, z, null);
        var l = new BigInteger;
        var h = new BigInteger;
        z.divRemTo(Wrapper.two32, h, l);
        Wrapper.result[0] = parseInt(l.toString()) | 0;
        Wrapper.result[1] = parseInt(h.toString()) | 0;
      }
    }),
    modulo: (function(xl, xh, yl, yh, unsigned) {
      if (!Wrapper.two32) Wrapper.makeTwo32();
      if (!unsigned) {
        var x = new goog.math.Long(xl, xh);
        var y = new goog.math.Long(yl, yh);
        var ret = x.modulo(y);
        Wrapper.result[0] = ret.low_;
        Wrapper.result[1] = ret.high_;
      } else {
        var x = Wrapper.lh2bignum(xl >>> 0, xh >>> 0);
        var y = Wrapper.lh2bignum(yl >>> 0, yh >>> 0);
        var z = new BigInteger;
        x.divRemTo(y, null, z);
        var l = new BigInteger;
        var h = new BigInteger;
        z.divRemTo(Wrapper.two32, h, l);
        Wrapper.result[0] = parseInt(l.toString()) | 0;
        Wrapper.result[1] = parseInt(h.toString()) | 0;
      }
    }),
    stringify: (function(l, h, unsigned) {
      var ret = (new goog.math.Long(l, h)).toString();
      if (unsigned && ret[0] == "-") {
        if (!Wrapper.two64) {
          Wrapper.two64 = new BigInteger;
          Wrapper.two64.fromString("18446744073709551616", 10);
        }
        var bignum = new BigInteger;
        bignum.fromString(ret, 10);
        ret = new BigInteger;
        Wrapper.two64.addTo(bignum, ret);
        ret = ret.toString(10);
      }
      return ret;
    })
  };
  return Wrapper;
})();

var _llvm_dbg_declare;

function _memcpy(dest, src, num, align) {
  if (num >= 20 && src % 2 == dest % 2) {
    if (src % 4 == dest % 4) {
      var stop = src + num;
      while (src % 4) {
        HEAP8[dest++] = HEAP8[src++];
      }
      var src4 = src >> 2, dest4 = dest >> 2, stop4 = stop >> 2;
      while (src4 < stop4) {
        HEAP32[dest4++] = HEAP32[src4++];
      }
      src = src4 << 2;
      dest = dest4 << 2;
      while (src < stop) {
        HEAP8[dest++] = HEAP8[src++];
      }
    } else {
      var stop = src + num;
      if (src % 2) {
        HEAP8[dest++] = HEAP8[src++];
      }
      var src2 = src >> 1, dest2 = dest >> 1, stop2 = stop >> 1;
      while (src2 < stop2) {
        HEAP16[dest2++] = HEAP16[src2++];
      }
      src = src2 << 1;
      dest = dest2 << 1;
      if (src < stop) {
        HEAP8[dest++] = HEAP8[src++];
      }
    }
  } else {
    while (num--) {
      HEAP8[dest++] = HEAP8[src++];
    }
  }
}

var _llvm_memcpy_p0i8_p0i8_i32 = _memcpy;

function _strlen(ptr) {
  return String_len(ptr);
}

function _llvm_ctlz_i32(x) {
  for (var i = 0; i < 32; i++) {
    if ((x & 1 << 31 - i) != 0) {
      return i;
    }
  }
  return 32;
}

function _memset(ptr, value, num, align) {
  if (num >= 20) {
    var stop = ptr + num;
    while (ptr % 4) {
      HEAP8[ptr++] = value;
    }
    if (value < 0) value += 256;
    var ptr4 = ptr >> 2, stop4 = stop >> 2, value4 = value | value << 8 | value << 16 | value << 24;
    while (ptr4 < stop4) {
      HEAP32[ptr4++] = value4;
    }
    ptr = ptr4 << 2;
    while (ptr < stop) {
      HEAP8[ptr++] = value;
    }
  } else {
    while (num--) {
      HEAP8[ptr++] = value;
    }
  }
}

var _llvm_memset_p0i8_i32 = _memset;

function ___cxa_pure_virtual() {
  ABORT = true;
  throw "Pure virtual function called!";
}

var ERRNO_CODES = {
  E2BIG: 7,
  EACCES: 13,
  EADDRINUSE: 98,
  EADDRNOTAVAIL: 99,
  EAFNOSUPPORT: 97,
  EAGAIN: 11,
  EALREADY: 114,
  EBADF: 9,
  EBADMSG: 74,
  EBUSY: 16,
  ECANCELED: 125,
  ECHILD: 10,
  ECONNABORTED: 103,
  ECONNREFUSED: 111,
  ECONNRESET: 104,
  EDEADLK: 35,
  EDESTADDRREQ: 89,
  EDOM: 33,
  EDQUOT: 122,
  EEXIST: 17,
  EFAULT: 14,
  EFBIG: 27,
  EHOSTUNREACH: 113,
  EIDRM: 43,
  EILSEQ: 84,
  EINPROGRESS: 115,
  EINTR: 4,
  EINVAL: 22,
  EIO: 5,
  EISCONN: 106,
  EISDIR: 21,
  ELOOP: 40,
  EMFILE: 24,
  EMLINK: 31,
  EMSGSIZE: 90,
  EMULTIHOP: 72,
  ENAMETOOLONG: 36,
  ENETDOWN: 100,
  ENETRESET: 102,
  ENETUNREACH: 101,
  ENFILE: 23,
  ENOBUFS: 105,
  ENODATA: 61,
  ENODEV: 19,
  ENOENT: 2,
  ENOEXEC: 8,
  ENOLCK: 37,
  ENOLINK: 67,
  ENOMEM: 12,
  ENOMSG: 42,
  ENOPROTOOPT: 92,
  ENOSPC: 28,
  ENOSR: 63,
  ENOSTR: 60,
  ENOSYS: 38,
  ENOTCONN: 107,
  ENOTDIR: 20,
  ENOTEMPTY: 39,
  ENOTRECOVERABLE: 131,
  ENOTSOCK: 88,
  ENOTSUP: 95,
  ENOTTY: 25,
  ENXIO: 6,
  EOVERFLOW: 75,
  EOWNERDEAD: 130,
  EPERM: 1,
  EPIPE: 32,
  EPROTO: 71,
  EPROTONOSUPPORT: 93,
  EPROTOTYPE: 91,
  ERANGE: 34,
  EROFS: 30,
  ESPIPE: 29,
  ESRCH: 3,
  ESTALE: 116,
  ETIME: 62,
  ETIMEDOUT: 110,
  ETXTBSY: 26,
  EWOULDBLOCK: 11,
  EXDEV: 18
};

function ___setErrNo(value) {
  if (!___setErrNo.ret) ___setErrNo.ret = allocate([ 0 ], "i32", ALLOC_STATIC);
  HEAP32[___setErrNo.ret >> 2] = value;
  return value;
}

var _stdin = 0;

var _stdout = 0;

var _stderr = 0;

var __impure_ptr = 0;

var FS = {
  currentPath: "/",
  nextInode: 2,
  streams: [ null ],
  ignorePermissions: true,
  absolutePath: (function(relative, base) {
    if (typeof relative !== "string") return null;
    if (base === undefined) base = FS.currentPath;
    if (relative && relative[0] == "/") base = "";
    var full = base + "/" + relative;
    var parts = full.split("/").reverse();
    var absolute = [ "" ];
    while (parts.length) {
      var part = parts.pop();
      if (part == "" || part == ".") {} else if (part == "..") {
        if (absolute.length > 1) absolute.pop();
      } else {
        absolute.push(part);
      }
    }
    return absolute.length == 1 ? "/" : absolute.join("/");
  }),
  analyzePath: (function(path, dontResolveLastLink, linksVisited) {
    var ret = {
      isRoot: false,
      exists: false,
      error: 0,
      name: null,
      path: null,
      object: null,
      parentExists: false,
      parentPath: null,
      parentObject: null
    };
    path = FS.absolutePath(path);
    if (path == "/") {
      ret.isRoot = true;
      ret.exists = ret.parentExists = true;
      ret.name = "/";
      ret.path = ret.parentPath = "/";
      ret.object = ret.parentObject = FS.root;
    } else if (path !== null) {
      linksVisited = linksVisited || 0;
      path = path.slice(1).split("/");
      var current = FS.root;
      var traversed = [ "" ];
      while (path.length) {
        if (path.length == 1 && current.isFolder) {
          ret.parentExists = true;
          ret.parentPath = traversed.length == 1 ? "/" : traversed.join("/");
          ret.parentObject = current;
          ret.name = path[0];
        }
        var target = path.shift();
        if (!current.isFolder) {
          ret.error = ERRNO_CODES.ENOTDIR;
          break;
        } else if (!current.read) {
          ret.error = ERRNO_CODES.EACCES;
          break;
        } else if (!current.contents.hasOwnProperty(target)) {
          ret.error = ERRNO_CODES.ENOENT;
          break;
        }
        current = current.contents[target];
        if (current.link && !(dontResolveLastLink && path.length == 0)) {
          if (linksVisited > 40) {
            ret.error = ERRNO_CODES.ELOOP;
            break;
          }
          var link = FS.absolutePath(current.link, traversed.join("/"));
          ret = FS.analyzePath([ link ].concat(path).join("/"), dontResolveLastLink, linksVisited + 1);
          return ret;
        }
        traversed.push(target);
        if (path.length == 0) {
          ret.exists = true;
          ret.path = traversed.join("/");
          ret.object = current;
        }
      }
    }
    return ret;
  }),
  findObject: (function(path, dontResolveLastLink) {
    FS.ensureRoot();
    var ret = FS.analyzePath(path, dontResolveLastLink);
    if (ret.exists) {
      return ret.object;
    } else {
      ___setErrNo(ret.error);
      return null;
    }
  }),
  createObject: (function(parent, name, properties, canRead, canWrite) {
    if (!parent) parent = "/";
    if (typeof parent === "string") parent = FS.findObject(parent);
    if (!parent) {
      ___setErrNo(ERRNO_CODES.EACCES);
      throw new Error("Parent path must exist.");
    }
    if (!parent.isFolder) {
      ___setErrNo(ERRNO_CODES.ENOTDIR);
      throw new Error("Parent must be a folder.");
    }
    if (!parent.write && !FS.ignorePermissions) {
      ___setErrNo(ERRNO_CODES.EACCES);
      throw new Error("Parent folder must be writeable.");
    }
    if (!name || name == "." || name == "..") {
      ___setErrNo(ERRNO_CODES.ENOENT);
      throw new Error("Name must not be empty.");
    }
    if (parent.contents.hasOwnProperty(name)) {
      ___setErrNo(ERRNO_CODES.EEXIST);
      throw new Error("Can't overwrite object.");
    }
    parent.contents[name] = {
      read: canRead === undefined ? true : canRead,
      write: canWrite === undefined ? false : canWrite,
      timestamp: Date.now(),
      inodeNumber: FS.nextInode++
    };
    for (var key in properties) {
      if (properties.hasOwnProperty(key)) {
        parent.contents[name][key] = properties[key];
      }
    }
    return parent.contents[name];
  }),
  createFolder: (function(parent, name, canRead, canWrite) {
    var properties = {
      isFolder: true,
      isDevice: false,
      contents: {}
    };
    return FS.createObject(parent, name, properties, canRead, canWrite);
  }),
  createPath: (function(parent, path, canRead, canWrite) {
    var current = FS.findObject(parent);
    if (current === null) throw new Error("Invalid parent.");
    path = path.split("/").reverse();
    while (path.length) {
      var part = path.pop();
      if (!part) continue;
      if (!current.contents.hasOwnProperty(part)) {
        FS.createFolder(current, part, canRead, canWrite);
      }
      current = current.contents[part];
    }
    return current;
  }),
  createFile: (function(parent, name, properties, canRead, canWrite) {
    properties.isFolder = false;
    return FS.createObject(parent, name, properties, canRead, canWrite);
  }),
  createDataFile: (function(parent, name, data, canRead, canWrite) {
    if (typeof data === "string") {
      var dataArray = new Array(data.length);
      for (var i = 0, len = data.length; i < len; ++i) dataArray[i] = data.charCodeAt(i);
      data = dataArray;
    }
    var properties = {
      isDevice: false,
      contents: data
    };
    return FS.createFile(parent, name, properties, canRead, canWrite);
  }),
  createLazyFile: (function(parent, name, url, canRead, canWrite) {
    var properties = {
      isDevice: false,
      url: url
    };
    return FS.createFile(parent, name, properties, canRead, canWrite);
  }),
  createLink: (function(parent, name, target, canRead, canWrite) {
    var properties = {
      isDevice: false,
      link: target
    };
    return FS.createFile(parent, name, properties, canRead, canWrite);
  }),
  createDevice: (function(parent, name, input, output) {
    if (!(input || output)) {
      throw new Error("A device must have at least one callback defined.");
    }
    var ops = {
      isDevice: true,
      input: input,
      output: output
    };
    return FS.createFile(parent, name, ops, Boolean(input), Boolean(output));
  }),
  forceLoadFile: (function(obj) {
    if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
    var success = true;
    if (typeof XMLHttpRequest !== "undefined") {
      assert("Cannot do synchronous binary XHRs in modern browsers. Use --embed-file or --preload-file in emcc");
    } else if (Module["read"]) {
      try {
        obj.contents = intArrayFromString(Module["read"](obj.url), true);
      } catch (e) {
        success = false;
      }
    } else {
      throw new Error("Cannot load without read() or XMLHttpRequest.");
    }
    if (!success) ___setErrNo(ERRNO_CODES.EIO);
    return success;
  }),
  ensureRoot: (function() {
    if (FS.root) return;
    FS.root = {
      read: true,
      write: true,
      isFolder: true,
      isDevice: false,
      timestamp: Date.now(),
      inodeNumber: 1,
      contents: {}
    };
  }),
  init: (function(input, output, error) {
    assert(!FS.init.initialized, "FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)");
    FS.init.initialized = true;
    FS.ensureRoot();
    input = input || Module["stdin"];
    output = output || Module["stdout"];
    error = error || Module["stderr"];
    var stdinOverridden = true, stdoutOverridden = true, stderrOverridden = true;
    if (!input) {
      stdinOverridden = false;
      input = (function() {
        if (!input.cache || !input.cache.length) {
          var result;
          if (typeof window != "undefined" && typeof window.prompt == "function") {
            result = window.prompt("Input: ");
          } else if (typeof readline == "function") {
            result = readline();
          }
          if (!result) result = "";
          input.cache = intArrayFromString(result + "\n", true);
        }
        return input.cache.shift();
      });
    }
    function simpleOutput(val) {
      if (val === null || val === "\n".charCodeAt(0)) {
        output.printer(output.buffer.join(""));
        output.buffer = [];
      } else {
        output.buffer.push(String.fromCharCode(val));
      }
    }
    if (!output) {
      stdoutOverridden = false;
      output = simpleOutput;
    }
    if (!output.printer) output.printer = Module["print"];
    if (!output.buffer) output.buffer = [];
    if (!error) {
      stderrOverridden = false;
      error = simpleOutput;
    }
    if (!error.printer) error.printer = Module["print"];
    if (!error.buffer) error.buffer = [];
    FS.createFolder("/", "tmp", true, true);
    var devFolder = FS.createFolder("/", "dev", true, true);
    var stdin = FS.createDevice(devFolder, "stdin", input);
    var stdout = FS.createDevice(devFolder, "stdout", null, output);
    var stderr = FS.createDevice(devFolder, "stderr", null, error);
    FS.createDevice(devFolder, "tty", input, output);
    FS.streams[1] = {
      path: "/dev/stdin",
      object: stdin,
      position: 0,
      isRead: true,
      isWrite: false,
      isAppend: false,
      isTerminal: !stdinOverridden,
      error: false,
      eof: false,
      ungotten: []
    };
    FS.streams[2] = {
      path: "/dev/stdout",
      object: stdout,
      position: 0,
      isRead: false,
      isWrite: true,
      isAppend: false,
      isTerminal: !stdoutOverridden,
      error: false,
      eof: false,
      ungotten: []
    };
    FS.streams[3] = {
      path: "/dev/stderr",
      object: stderr,
      position: 0,
      isRead: false,
      isWrite: true,
      isAppend: false,
      isTerminal: !stderrOverridden,
      error: false,
      eof: false,
      ungotten: []
    };
    _stdin = allocate([ 1 ], "void*", ALLOC_STATIC);
    _stdout = allocate([ 2 ], "void*", ALLOC_STATIC);
    _stderr = allocate([ 3 ], "void*", ALLOC_STATIC);
    FS.createPath("/", "dev/shm/tmp", true, true);
    FS.streams[_stdin] = FS.streams[1];
    FS.streams[_stdout] = FS.streams[2];
    FS.streams[_stderr] = FS.streams[3];
    __impure_ptr = allocate([ allocate([ 0, 0, 0, 0, _stdin, 0, 0, 0, _stdout, 0, 0, 0, _stderr, 0, 0, 0 ], "void*", ALLOC_STATIC) ], "void*", ALLOC_STATIC);
  }),
  quit: (function() {
    if (!FS.init.initialized) return;
    if (FS.streams[2] && FS.streams[2].object.output.buffer.length > 0) FS.streams[2].object.output("\n".charCodeAt(0));
    if (FS.streams[3] && FS.streams[3].object.output.buffer.length > 0) FS.streams[3].object.output("\n".charCodeAt(0));
  }),
  standardizePath: (function(path) {
    if (path.substr(0, 2) == "./") path = path.substr(2);
    return path;
  }),
  deleteFile: (function(path) {
    var path = FS.analyzePath(path);
    if (!path.parentExists || !path.exists) {
      throw "Invalid path " + path;
    }
    delete path.parentObject.contents[path.name];
  })
};

function _mmap(start, num, prot, flags, stream, offset) {
  if (stream == -1) {
    var ptr = _malloc(num);
    _memset(ptr, 0, num);
    return ptr;
  }
  var info = FS.streams[stream];
  if (!info) return -1;
  var contents = info.object.contents;
  contents = Array.prototype.slice.call(contents, offset, offset + num);
  return allocate(contents, "i8", ALLOC_NORMAL);
}

function _munmap(start, num) {
  _free(start);
  return 0;
}

function _fflush(stream) {
  var flush = (function(filedes) {
    if (filedes in FS.streams && FS.streams[filedes].object.output) {
      if (!FS.streams[filedes].isTerminal) {
        FS.streams[filedes].object.output(null);
      }
    }
  });
  try {
    if (stream === 0) {
      for (var i in FS.streams) flush(i);
    } else {
      flush(stream);
    }
    return 0;
  } catch (e) {
    ___setErrNo(ERRNO_CODES.EIO);
    return -1;
  }
}

function _pwrite(fildes, buf, nbyte, offset) {
  var stream = FS.streams[fildes];
  if (!stream || stream.object.isDevice) {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  } else if (!stream.isWrite) {
    ___setErrNo(ERRNO_CODES.EACCES);
    return -1;
  } else if (stream.object.isFolder) {
    ___setErrNo(ERRNO_CODES.EISDIR);
    return -1;
  } else if (nbyte < 0 || offset < 0) {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
  } else {
    var contents = stream.object.contents;
    while (contents.length < offset) contents.push(0);
    for (var i = 0; i < nbyte; i++) {
      contents[offset + i] = HEAPU8[buf + i];
    }
    stream.object.timestamp = Date.now();
    return i;
  }
}

function _write(fildes, buf, nbyte) {
  var stream = FS.streams[fildes];
  if (!stream) {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  } else if (!stream.isWrite) {
    ___setErrNo(ERRNO_CODES.EACCES);
    return -1;
  } else if (nbyte < 0) {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
  } else {
    if (stream.object.isDevice) {
      if (stream.object.output) {
        for (var i = 0; i < nbyte; i++) {
          try {
            stream.object.output(HEAP8[buf + i]);
          } catch (e) {
            ___setErrNo(ERRNO_CODES.EIO);
            return -1;
          }
        }
        stream.object.timestamp = Date.now();
        return i;
      } else {
        ___setErrNo(ERRNO_CODES.ENXIO);
        return -1;
      }
    } else {
      var bytesWritten = _pwrite(fildes, buf, nbyte, stream.position);
      if (bytesWritten != -1) stream.position += bytesWritten;
      return bytesWritten;
    }
  }
}

function _fwrite(ptr, size, nitems, stream) {
  var bytesToWrite = nitems * size;
  if (bytesToWrite == 0) return 0;
  var bytesWritten = _write(stream, ptr, bytesToWrite);
  if (bytesWritten == -1) {
    if (FS.streams[stream]) FS.streams[stream].error = true;
    return -1;
  } else {
    return Math.floor(bytesWritten / size);
  }
}

function __formatString(format, varargs) {
  var textIndex = format;
  var argIndex = 0;
  function getNextArg(type) {
    var ret;
    if (type === "double") {
      ret = (tempDoubleI32[0] = HEAP32[varargs + argIndex >> 2], tempDoubleI32[1] = HEAP32[varargs + argIndex + 4 >> 2], tempDoubleF64[0]);
    } else if (type == "i64") {
      ret = [ HEAP32[varargs + argIndex >> 2], HEAP32[varargs + argIndex + 4 >> 2] ];
    } else {
      type = "i32";
      ret = HEAP32[varargs + argIndex >> 2];
    }
    argIndex += Runtime.getNativeFieldSize(type);
    return ret;
  }
  var ret = [];
  var curr, next, currArg;
  while (1) {
    var startTextIndex = textIndex;
    curr = HEAP8[textIndex];
    if (curr === 0) break;
    next = HEAP8[textIndex + 1];
    if (curr == "%".charCodeAt(0)) {
      var flagAlwaysSigned = false;
      var flagLeftAlign = false;
      var flagAlternative = false;
      var flagZeroPad = false;
      flagsLoop : while (1) {
        switch (next) {
         case "+".charCodeAt(0):
          flagAlwaysSigned = true;
          break;
         case "-".charCodeAt(0):
          flagLeftAlign = true;
          break;
         case "#".charCodeAt(0):
          flagAlternative = true;
          break;
         case "0".charCodeAt(0):
          if (flagZeroPad) {
            break flagsLoop;
          } else {
            flagZeroPad = true;
            break;
          }
         default:
          break flagsLoop;
        }
        textIndex++;
        next = HEAP8[textIndex + 1];
      }
      var width = 0;
      if (next == "*".charCodeAt(0)) {
        width = getNextArg("i32");
        textIndex++;
        next = HEAP8[textIndex + 1];
      } else {
        while (next >= "0".charCodeAt(0) && next <= "9".charCodeAt(0)) {
          width = width * 10 + (next - "0".charCodeAt(0));
          textIndex++;
          next = HEAP8[textIndex + 1];
        }
      }
      var precisionSet = false;
      if (next == ".".charCodeAt(0)) {
        var precision = 0;
        precisionSet = true;
        textIndex++;
        next = HEAP8[textIndex + 1];
        if (next == "*".charCodeAt(0)) {
          precision = getNextArg("i32");
          textIndex++;
        } else {
          while (1) {
            var precisionChr = HEAP8[textIndex + 1];
            if (precisionChr < "0".charCodeAt(0) || precisionChr > "9".charCodeAt(0)) break;
            precision = precision * 10 + (precisionChr - "0".charCodeAt(0));
            textIndex++;
          }
        }
        next = HEAP8[textIndex + 1];
      } else {
        var precision = 6;
      }
      var argSize;
      switch (String.fromCharCode(next)) {
       case "h":
        var nextNext = HEAP8[textIndex + 2];
        if (nextNext == "h".charCodeAt(0)) {
          textIndex++;
          argSize = 1;
        } else {
          argSize = 2;
        }
        break;
       case "l":
        var nextNext = HEAP8[textIndex + 2];
        if (nextNext == "l".charCodeAt(0)) {
          textIndex++;
          argSize = 8;
        } else {
          argSize = 4;
        }
        break;
       case "L":
       case "q":
       case "j":
        argSize = 8;
        break;
       case "z":
       case "t":
       case "I":
        argSize = 4;
        break;
       default:
        argSize = null;
      }
      if (argSize) textIndex++;
      next = HEAP8[textIndex + 1];
      if ([ "d", "i", "u", "o", "x", "X", "p" ].indexOf(String.fromCharCode(next)) != -1) {
        var signed = next == "d".charCodeAt(0) || next == "i".charCodeAt(0);
        argSize = argSize || 4;
        var currArg = getNextArg("i" + argSize * 8);
        var origArg = currArg;
        var argText;
        if (argSize == 8) {
          currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == "u".charCodeAt(0));
        }
        if (argSize <= 4) {
          var limit = Math.pow(256, argSize) - 1;
          currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
        }
        var currAbsArg = Math.abs(currArg);
        var prefix = "";
        if (next == "d".charCodeAt(0) || next == "i".charCodeAt(0)) {
          if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1]); else argText = reSign(currArg, 8 * argSize, 1).toString(10);
        } else if (next == "u".charCodeAt(0)) {
          if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], true); else argText = unSign(currArg, 8 * argSize, 1).toString(10);
          currArg = Math.abs(currArg);
        } else if (next == "o".charCodeAt(0)) {
          argText = (flagAlternative ? "0" : "") + currAbsArg.toString(8);
        } else if (next == "x".charCodeAt(0) || next == "X".charCodeAt(0)) {
          prefix = flagAlternative ? "0x" : "";
          if (currArg < 0) {
            currArg = -currArg;
            argText = (currAbsArg - 1).toString(16);
            var buffer = [];
            for (var i = 0; i < argText.length; i++) {
              buffer.push((15 - parseInt(argText[i], 16)).toString(16));
            }
            argText = buffer.join("");
            while (argText.length < argSize * 2) argText = "f" + argText;
          } else {
            argText = currAbsArg.toString(16);
          }
          if (next == "X".charCodeAt(0)) {
            prefix = prefix.toUpperCase();
            argText = argText.toUpperCase();
          }
        } else if (next == "p".charCodeAt(0)) {
          if (currAbsArg === 0) {
            argText = "(nil)";
          } else {
            prefix = "0x";
            argText = currAbsArg.toString(16);
          }
        }
        if (precisionSet) {
          while (argText.length < precision) {
            argText = "0" + argText;
          }
        }
        if (flagAlwaysSigned) {
          if (currArg < 0) {
            prefix = "-" + prefix;
          } else {
            prefix = "+" + prefix;
          }
        }
        while (prefix.length + argText.length < width) {
          if (flagLeftAlign) {
            argText += " ";
          } else {
            if (flagZeroPad) {
              argText = "0" + argText;
            } else {
              prefix = " " + prefix;
            }
          }
        }
        argText = prefix + argText;
        argText.split("").forEach((function(chr) {
          ret.push(chr.charCodeAt(0));
        }));
      } else if ([ "f", "F", "e", "E", "g", "G" ].indexOf(String.fromCharCode(next)) != -1) {
        var currArg = getNextArg("double");
        var argText;
        if (isNaN(currArg)) {
          argText = "nan";
          flagZeroPad = false;
        } else if (!isFinite(currArg)) {
          argText = (currArg < 0 ? "-" : "") + "inf";
          flagZeroPad = false;
        } else {
          var isGeneral = false;
          var effectivePrecision = Math.min(precision, 20);
          if (next == "g".charCodeAt(0) || next == "G".charCodeAt(0)) {
            isGeneral = true;
            precision = precision || 1;
            var exponent = parseInt(currArg.toExponential(effectivePrecision).split("e")[1], 10);
            if (precision > exponent && exponent >= -4) {
              next = (next == "g".charCodeAt(0) ? "f" : "F").charCodeAt(0);
              precision -= exponent + 1;
            } else {
              next = (next == "g".charCodeAt(0) ? "e" : "E").charCodeAt(0);
              precision--;
            }
            effectivePrecision = Math.min(precision, 20);
          }
          if (next == "e".charCodeAt(0) || next == "E".charCodeAt(0)) {
            argText = currArg.toExponential(effectivePrecision);
            if (/[eE][-+]\d$/.test(argText)) {
              argText = argText.slice(0, -1) + "0" + argText.slice(-1);
            }
          } else if (next == "f".charCodeAt(0) || next == "F".charCodeAt(0)) {
            argText = currArg.toFixed(effectivePrecision);
          }
          var parts = argText.split("e");
          if (isGeneral && !flagAlternative) {
            while (parts[0].length > 1 && parts[0].indexOf(".") != -1 && (parts[0].slice(-1) == "0" || parts[0].slice(-1) == ".")) {
              parts[0] = parts[0].slice(0, -1);
            }
          } else {
            if (flagAlternative && argText.indexOf(".") == -1) parts[0] += ".";
            while (precision > effectivePrecision++) parts[0] += "0";
          }
          argText = parts[0] + (parts.length > 1 ? "e" + parts[1] : "");
          if (next == "E".charCodeAt(0)) argText = argText.toUpperCase();
          if (flagAlwaysSigned && currArg >= 0) {
            argText = "+" + argText;
          }
        }
        while (argText.length < width) {
          if (flagLeftAlign) {
            argText += " ";
          } else {
            if (flagZeroPad && (argText[0] == "-" || argText[0] == "+")) {
              argText = argText[0] + "0" + argText.slice(1);
            } else {
              argText = (flagZeroPad ? "0" : " ") + argText;
            }
          }
        }
        if (next < "a".charCodeAt(0)) argText = argText.toUpperCase();
        argText.split("").forEach((function(chr) {
          ret.push(chr.charCodeAt(0));
        }));
      } else if (next == "s".charCodeAt(0)) {
        var arg = getNextArg("i8*");
        var copiedString;
        if (arg) {
          copiedString = String_copy(arg);
          if (precisionSet && copiedString.length > precision) {
            copiedString = copiedString.slice(0, precision);
          }
        } else {
          copiedString = intArrayFromString("(null)", true);
        }
        if (!flagLeftAlign) {
          while (copiedString.length < width--) {
            ret.push(" ".charCodeAt(0));
          }
        }
        ret = ret.concat(copiedString);
        if (flagLeftAlign) {
          while (copiedString.length < width--) {
            ret.push(" ".charCodeAt(0));
          }
        }
      } else if (next == "c".charCodeAt(0)) {
        if (flagLeftAlign) ret.push(getNextArg("i8"));
        while (--width > 0) {
          ret.push(" ".charCodeAt(0));
        }
        if (!flagLeftAlign) ret.push(getNextArg("i8"));
      } else if (next == "n".charCodeAt(0)) {
        var ptr = getNextArg("i32*");
        HEAP32[ptr >> 2] = ret.length;
      } else if (next == "%".charCodeAt(0)) {
        ret.push(curr);
      } else {
        for (var i = startTextIndex; i < textIndex + 2; i++) {
          ret.push(HEAP8[i]);
        }
      }
      textIndex += 2;
    } else {
      ret.push(curr);
      textIndex += 1;
    }
  }
  return ret;
}

function _fprintf(stream, format, varargs) {
  var result = __formatString(format, varargs);
  var stack = Runtime.stackSave();
  var ret = _fwrite(allocate(result, "i8", ALLOC_STACK), 1, result.length, stream);
  Runtime.stackRestore(stack);
  return ret;
}

var _llvm_va_start;

var _vfprintf = _fprintf;

function _llvm_va_end() {}

function ___fpclassifyf(x) {
  if (isNaN(x)) return 0;
  if (!isFinite(x)) return 1;
  if (x == 0) return 2;
  return 4;
}

var ___fpclassifyd = ___fpclassifyf;

function _memcmp(p1, p2, num) {
  for (var i = 0; i < num; i++) {
    var v1 = HEAP8[p1 + i];
    var v2 = HEAP8[p2 + i];
    if (v1 != v2) return v1 > v2 ? 1 : -1;
  }
  return 0;
}

function _isspace(chr) {
  return chr in {
    32: 0,
    9: 0,
    10: 0,
    11: 0,
    12: 0,
    13: 0
  };
}

function _strncmp(px, py, n) {
  var i = 0;
  while (i < n) {
    var x = HEAP8[px + i];
    var y = HEAP8[py + i];
    if (x == y && x == 0) return 0;
    if (x == 0) return -1;
    if (y == 0) return 1;
    if (x == y) {
      i++;
      continue;
    } else {
      return x > y ? 1 : -1;
    }
  }
  return 0;
}

function _strcmp(px, py) {
  return _strncmp(px, py, TOTAL_MEMORY);
}

var ___dirent_struct_layout = null;

function _open(path, oflag, varargs) {
  var mode = HEAP32[varargs >> 2];
  var accessMode = oflag & 3;
  var isWrite = accessMode != 0;
  var isRead = accessMode != 1;
  var isCreate = Boolean(oflag & 512);
  var isExistCheck = Boolean(oflag & 2048);
  var isTruncate = Boolean(oflag & 1024);
  var isAppend = Boolean(oflag & 8);
  var origPath = path;
  path = FS.analyzePath(Pointer_stringify(path));
  if (!path.parentExists) {
    ___setErrNo(path.error);
    return -1;
  }
  var target = path.object || null;
  var finalPath;
  if (target) {
    if (isCreate && isExistCheck) {
      ___setErrNo(ERRNO_CODES.EEXIST);
      return -1;
    }
    if ((isWrite || isCreate || isTruncate) && target.isFolder) {
      ___setErrNo(ERRNO_CODES.EISDIR);
      return -1;
    }
    if (isRead && !target.read || isWrite && !target.write) {
      ___setErrNo(ERRNO_CODES.EACCES);
      return -1;
    }
    if (isTruncate && !target.isDevice) {
      target.contents = [];
    } else {
      if (!FS.forceLoadFile(target)) {
        ___setErrNo(ERRNO_CODES.EIO);
        return -1;
      }
    }
    finalPath = path.path;
  } else {
    if (!isCreate) {
      ___setErrNo(ERRNO_CODES.ENOENT);
      return -1;
    }
    if (!path.parentObject.write) {
      ___setErrNo(ERRNO_CODES.EACCES);
      return -1;
    }
    target = FS.createDataFile(path.parentObject, path.name, [], mode & 256, mode & 128);
    finalPath = path.parentPath + "/" + path.name;
  }
  var id = FS.streams.length;
  if (target.isFolder) {
    var entryBuffer = 0;
    if (___dirent_struct_layout) {
      entryBuffer = _malloc(___dirent_struct_layout.__size__);
    }
    var contents = [];
    for (var key in target.contents) contents.push(key);
    FS.streams[id] = {
      path: finalPath,
      object: target,
      position: -2,
      isRead: true,
      isWrite: false,
      isAppend: false,
      error: false,
      eof: false,
      ungotten: [],
      contents: contents,
      currentEntry: entryBuffer
    };
  } else {
    FS.streams[id] = {
      path: finalPath,
      object: target,
      position: 0,
      isRead: isRead,
      isWrite: isWrite,
      isAppend: isAppend,
      error: false,
      eof: false,
      ungotten: []
    };
  }
  return id;
}

function _fopen(filename, mode) {
  var flags;
  mode = Pointer_stringify(mode);
  if (mode[0] == "r") {
    if (mode.indexOf("+") != -1) {
      flags = 2;
    } else {
      flags = 0;
    }
  } else if (mode[0] == "w") {
    if (mode.indexOf("+") != -1) {
      flags = 2;
    } else {
      flags = 1;
    }
    flags |= 512;
    flags |= 1024;
  } else if (mode[0] == "a") {
    if (mode.indexOf("+") != -1) {
      flags = 2;
    } else {
      flags = 1;
    }
    flags |= 512;
    flags |= 8;
  } else {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return 0;
  }
  var ret = _open(filename, flags, allocate([ 511, 0, 0, 0 ], "i32", ALLOC_STACK));
  return ret == -1 ? 0 : ret;
}

function _close(fildes) {
  if (FS.streams[fildes]) {
    if (FS.streams[fildes].currentEntry) {
      _free(FS.streams[fildes].currentEntry);
    }
    delete FS.streams[fildes];
    return 0;
  } else {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  }
}

function _fsync(fildes) {
  if (FS.streams[fildes]) {
    return 0;
  } else {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  }
}

function _fclose(stream) {
  _fsync(stream);
  return _close(stream);
}

var ___stat_struct_layout = {
  __size__: 72,
  st_dev: 0,
  st_ino: 4,
  st_mode: 8,
  st_nlink: 12,
  st_uid: 16,
  st_gid: 20,
  st_rdev: 24,
  st_size: 28,
  st_atime: 32,
  st_spare1: 36,
  st_mtime: 40,
  st_spare2: 44,
  st_ctime: 48,
  st_spare3: 52,
  st_blksize: 56,
  st_blocks: 60,
  st_spare4: 64
};

function _stat(path, buf, dontResolveLastLink) {
  var obj = FS.findObject(Pointer_stringify(path), dontResolveLastLink);
  if (obj === null || !FS.forceLoadFile(obj)) return -1;
  var offsets = ___stat_struct_layout;
  HEAP32[buf + offsets.st_nlink >> 2] = 1;
  HEAP32[buf + offsets.st_uid >> 2] = 0;
  HEAP32[buf + offsets.st_gid >> 2] = 0;
  HEAP32[buf + offsets.st_blksize >> 2] = 4096;
  HEAP32[buf + offsets.st_ino >> 2] = obj.inodeNumber;
  var time = Math.floor(obj.timestamp / 1e3);
  if (offsets.st_atime === undefined) {
    offsets.st_atime = offsets.st_atim.tv_sec;
    offsets.st_mtime = offsets.st_mtim.tv_sec;
    offsets.st_ctime = offsets.st_ctim.tv_sec;
    var nanosec = obj.timestamp % 1e3 * 1e3;
    HEAP32[buf + offsets.st_atim.tv_nsec >> 2] = nanosec;
    HEAP32[buf + offsets.st_mtim.tv_nsec >> 2] = nanosec;
    HEAP32[buf + offsets.st_ctim.tv_nsec >> 2] = nanosec;
  }
  HEAP32[buf + offsets.st_atime >> 2] = time;
  HEAP32[buf + offsets.st_mtime >> 2] = time;
  HEAP32[buf + offsets.st_ctime >> 2] = time;
  var mode = 0;
  var size = 0;
  var blocks = 0;
  var dev = 0;
  var rdev = 0;
  if (obj.isDevice) {
    dev = rdev = obj.inodeNumber;
    size = blocks = 0;
    mode = 8192;
  } else {
    dev = 1;
    rdev = 0;
    if (obj.isFolder) {
      size = 4096;
      blocks = 1;
      mode = 16384;
    } else {
      var data = obj.contents || obj.link;
      size = data.length;
      blocks = Math.ceil(data.length / 4096);
      mode = obj.link === undefined ? 32768 : 40960;
    }
  }
  HEAP32[buf + offsets.st_dev >> 2] = dev;
  HEAP32[buf + offsets.st_rdev >> 2] = rdev;
  HEAP32[buf + offsets.st_size >> 2] = size;
  HEAP32[buf + offsets.st_blocks >> 2] = blocks;
  if (obj.read) mode |= 365;
  if (obj.write) mode |= 146;
  HEAP32[buf + offsets.st_mode >> 2] = mode;
  return 0;
}

function _fstat(fildes, buf) {
  if (!FS.streams[fildes]) {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  } else {
    var pathArray = intArrayFromString(FS.streams[fildes].path);
    return _stat(allocate(pathArray, "i8", ALLOC_STACK), buf);
  }
}

function _fileno(stream) {
  return stream;
}

function _pread(fildes, buf, nbyte, offset) {
  var stream = FS.streams[fildes];
  if (!stream || stream.object.isDevice) {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  } else if (!stream.isRead) {
    ___setErrNo(ERRNO_CODES.EACCES);
    return -1;
  } else if (stream.object.isFolder) {
    ___setErrNo(ERRNO_CODES.EISDIR);
    return -1;
  } else if (nbyte < 0 || offset < 0) {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
  } else {
    var bytesRead = 0;
    while (stream.ungotten.length && nbyte > 0) {
      HEAP8[buf++] = stream.ungotten.pop();
      nbyte--;
      bytesRead++;
    }
    var contents = stream.object.contents;
    var size = Math.min(contents.length - offset, nbyte);
    for (var i = 0; i < size; i++) {
      HEAP8[buf + i] = contents[offset + i];
      bytesRead++;
    }
    return bytesRead;
  }
}

function _read(fildes, buf, nbyte) {
  var stream = FS.streams[fildes];
  if (!stream) {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  } else if (!stream.isRead) {
    ___setErrNo(ERRNO_CODES.EACCES);
    return -1;
  } else if (nbyte < 0) {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
  } else {
    var bytesRead;
    if (stream.object.isDevice) {
      if (stream.object.input) {
        bytesRead = 0;
        while (stream.ungotten.length && nbyte > 0) {
          HEAP8[buf++] = stream.ungotten.pop();
          nbyte--;
          bytesRead++;
        }
        for (var i = 0; i < nbyte; i++) {
          try {
            var result = stream.object.input();
          } catch (e) {
            ___setErrNo(ERRNO_CODES.EIO);
            return -1;
          }
          if (result === null || result === undefined) break;
          bytesRead++;
          HEAP8[buf + i] = result;
        }
        return bytesRead;
      } else {
        ___setErrNo(ERRNO_CODES.ENXIO);
        return -1;
      }
    } else {
      var ungotSize = stream.ungotten.length;
      bytesRead = _pread(fildes, buf, nbyte, stream.position);
      if (bytesRead != -1) {
        stream.position += stream.ungotten.length - ungotSize + bytesRead;
      }
      return bytesRead;
    }
  }
}

function _fgetc(stream) {
  if (!(stream in FS.streams)) return -1;
  var streamObj = FS.streams[stream];
  if (streamObj.eof || streamObj.error) return -1;
  var ret = _read(stream, _fgetc.ret, 1);
  if (ret == 0) {
    streamObj.eof = true;
    return -1;
  } else if (ret == -1) {
    streamObj.error = true;
    return -1;
  } else {
    return HEAP8[_fgetc.ret];
  }
}

var _getc_unlocked = _fgetc;

function _memmove(dest, src, num, align) {
  if (src < dest && dest < src + num) {
    src += num;
    dest += num;
    while (num--) {
      dest--;
      src--;
      HEAP8[dest] = HEAP8[src];
    }
  } else {
    _memcpy(dest, src, num, align);
  }
}

var _llvm_memmove_p0i8_p0i8_i32 = _memmove;

function _fmod(x, y) {
  return x % y;
}

var _floor = Math.floor;

var _ceil = Math.ceil;

function _time(ptr) {
  var ret = Math.floor(Date.now() / 1e3);
  if (ptr) {
    HEAP32[ptr >> 2] = ret;
  }
  return ret;
}

function _isalpha(chr) {
  return chr >= "a".charCodeAt(0) && chr <= "z".charCodeAt(0) || chr >= "A".charCodeAt(0) && chr <= "Z".charCodeAt(0);
}

function _strcpy(pdest, psrc) {
  var i = 0;
  do {
    HEAP8[pdest + i] = HEAP8[psrc + i];
    i++;
  } while (HEAP8[psrc + i - 1] != 0);
  return pdest;
}

function ___errno_location() {
  return ___setErrNo.ret;
}

var ___errno = ___errno_location;

var _setjmp;

function _printf(format, varargs) {
  var stdout = HEAP32[_stdout >> 2];
  return _fprintf(stdout, format, varargs);
}

var _environ = null;

var ___environ = null;

function ___buildEnvironment(env) {
  var MAX_ENV_VALUES = 64;
  var TOTAL_ENV_SIZE = 1024;
  var poolPtr;
  var envPtr;
  if (_environ === null) {
    ENV["USER"] = "root";
    ENV["PATH"] = "/";
    ENV["PWD"] = "/";
    ENV["HOME"] = "/home/emscripten";
    ENV["LANG"] = "en_US.UTF-8";
    ENV["_"] = "./this.program";
    poolPtr = allocate(TOTAL_ENV_SIZE, "i8", ALLOC_STATIC);
    envPtr = allocate(MAX_ENV_VALUES * 4, "i8*", ALLOC_STATIC);
    HEAP32[envPtr >> 2] = poolPtr;
    _environ = allocate([ envPtr ], "i8**", ALLOC_STATIC);
    ___environ = _environ;
  } else {
    envPtr = HEAP32[_environ >> 2];
    poolPtr = HEAP32[envPtr >> 2];
  }
  var strings = [];
  var totalSize = 0;
  for (var key in env) {
    if (typeof env[key] === "string") {
      var line = key + "=" + env[key];
      strings.push(line);
      totalSize += line.length;
    }
  }
  if (totalSize > TOTAL_ENV_SIZE) {
    throw new Error("Environment size exceeded TOTAL_ENV_SIZE!");
  }
  var ptrSize = 4;
  for (var i = 0; i < strings.length; i++) {
    var line = strings[i];
    for (var j = 0; j < line.length; j++) {
      HEAP8[poolPtr + j] = line.charCodeAt(j);
    }
    HEAP8[poolPtr + j] = 0;
    HEAP32[envPtr + i * ptrSize >> 2] = poolPtr;
    poolPtr += line.length + 1;
  }
  HEAP32[envPtr + strings.length * ptrSize >> 2] = 0;
}

var ENV = {};

function _getenv(name) {
  if (name === 0) return 0;
  name = Pointer_stringify(name);
  if (!ENV.hasOwnProperty(name)) return 0;
  if (_getenv.ret) _free(_getenv.ret);
  _getenv.ret = allocate(intArrayFromString(ENV[name]), "i8", ALLOC_NORMAL);
  return _getenv.ret;
}

function _strstr(ptr1, ptr2) {
  var str1 = Pointer_stringify(ptr1);
  var str2 = Pointer_stringify(ptr2);
  var ret = str1.search(str2);
  return ret >= 0 ? ptr1 + ret : 0;
}

var _fabs = Math.abs;

function _copysign(a, b) {
  if (a < 0 === b < 0) return a;
  return -a;
}

var _sqrt = Math.sqrt;

var _llvm_pow_f64 = Math.pow;

var _tan = Math.tan;

var _sin = Math.sin;

var _log = Math.log;

var _exp = Math.exp;

var _cos = Math.cos;

var _atan2 = Math.atan2;

var _atan = Math.atan;

var _asin = Math.asin;

var _acos = Math.acos;

function _pthread_self() {
  return 0;
}

function _pthread_attr_init(attr) {
  return 0;
}

function _pthread_getattr_np(thread, attr) {
  return 0;
}

function _pthread_attr_getstack(attr, stackaddr, stacksize) {
  HEAP32[stackaddr >> 2] = STACK_ROOT;
  HEAP32[stacksize >> 2] = TOTAL_STACK;
  return 0;
}

function _pthread_attr_destroy(attr) {
  return 0;
}

function _localeconv() {
  var me = _localeconv;
  if (!me.ret) {
    me.ret = allocate([ allocate(intArrayFromString("."), "i8", ALLOC_NORMAL) ], "i8*", ALLOC_NORMAL);
  }
  return me.ret;
}

function _isxdigit(chr) {
  return chr >= "0".charCodeAt(0) && chr <= "9".charCodeAt(0) || chr >= "a".charCodeAt(0) && chr <= "f".charCodeAt(0) || chr >= "A".charCodeAt(0) && chr <= "F".charCodeAt(0);
}

function _tolower(chr) {
  if (chr >= "A".charCodeAt(0) && chr <= "Z".charCodeAt(0)) {
    return chr - "A".charCodeAt(0) + "a".charCodeAt(0);
  } else {
    return chr;
  }
}

function _isprint(chr) {
  return 31 < chr && chr < 127;
}

function _strchr(ptr, chr) {
  ptr--;
  do {
    ptr++;
    var val = HEAP8[ptr];
    if (val == chr) return ptr;
  } while (val);
  return 0;
}

function _snprintf(s, n, format, varargs) {
  var result = __formatString(format, varargs);
  var limit = n === undefined ? result.length : Math.min(result.length, n - 1);
  for (var i = 0; i < limit; i++) {
    HEAP8[s + i] = result[i];
  }
  HEAP8[s + i] = 0;
  return result.length;
}

function _sprintf(s, format, varargs) {
  return _snprintf(s, undefined, format, varargs);
}

function _llvm_va_copy(ppdest, ppsrc) {
  HEAP8[ppdest] = HEAP8[ppsrc];
  HEAP8[ppdest + 1] = HEAP8[ppsrc + 1];
  HEAP8[ppdest + 2] = HEAP8[ppsrc + 2];
  HEAP8[ppdest + 3] = HEAP8[ppsrc + 3];
}

var _llvm_memset_p0i8_i64 = _memset;

function _ungetc(c, stream) {
  if (stream in FS.streams) {
    c = unSign(c & 255);
    FS.streams[stream].ungotten.push(c);
    return c;
  } else {
    return -1;
  }
}

function _fputc(c, stream) {
  var chr = unSign(c & 255);
  HEAP8[_fputc.ret] = chr;
  var ret = _write(stream, _fputc.ret, 1);
  if (ret == -1) {
    if (stream in FS.streams) FS.streams[stream].error = true;
    return -1;
  } else {
    return chr;
  }
}

var _raise;

function _log10(x) {
  return Math.log(x) / Math.LN10;
}

function _gettimeofday(ptr) {
  var indexes = Runtime.calculateStructAlignment({
    fields: [ "i32", "i32" ]
  });
  var now = Date.now();
  HEAP32[ptr + indexes[0] >> 2] = Math.floor(now / 1e3);
  HEAP32[ptr + indexes[1] >> 2] = Math.floor((now - 1e3 * Math.floor(now / 1e3)) * 1e3);
  return 0;
}

var ___tm_struct_layout = {
  __size__: 44,
  tm_sec: 0,
  tm_min: 4,
  tm_hour: 8,
  tm_mday: 12,
  tm_mon: 16,
  tm_year: 20,
  tm_wday: 24,
  tm_yday: 28,
  tm_isdst: 32,
  tm_gmtoff: 36,
  tm_zone: 40
};

var __tzname = null;

var __daylight = null;

var __timezone = null;

function _tzset() {
  if (__tzname) return;
  __timezone = _malloc(4);
  HEAP32[__timezone >> 2] = -(new Date).getTimezoneOffset() * 60;
  __daylight = _malloc(4);
  var winter = new Date(2e3, 0, 1);
  var summer = new Date(2e3, 6, 1);
  HEAP32[__daylight >> 2] = Number(winter.getTimezoneOffset() != summer.getTimezoneOffset());
  var winterName = "GMT";
  var summerName = "GMT";
  var winterNamePtr = allocate(intArrayFromString(winterName), "i8", ALLOC_NORMAL);
  var summerNamePtr = allocate(intArrayFromString(summerName), "i8", ALLOC_NORMAL);
  __tzname = _malloc(2 * 4);
  HEAP32[__tzname >> 2] = winterNamePtr;
  HEAP32[__tzname + 4 >> 2] = summerNamePtr;
}

function _mktime(tmPtr) {
  _tzset();
  var offsets = ___tm_struct_layout;
  var year = HEAP32[tmPtr + offsets.tm_year >> 2];
  var timestamp = (new Date(year >= 1900 ? year : year + 1900, HEAP32[tmPtr + offsets.tm_mon >> 2], HEAP32[tmPtr + offsets.tm_mday >> 2], HEAP32[tmPtr + offsets.tm_hour >> 2], HEAP32[tmPtr + offsets.tm_min >> 2], HEAP32[tmPtr + offsets.tm_sec >> 2], 0)).getTime() / 1e3;
  HEAP32[tmPtr + offsets.tm_wday >> 2] = (new Date(timestamp)).getDay();
  var yday = Math.round((timestamp - (new Date(year, 0, 1)).getTime()) / (1e3 * 60 * 60 * 24));
  HEAP32[tmPtr + offsets.tm_yday >> 2] = yday;
  return timestamp;
}

var ___tm_timezones = {};

function _localtime_r(time, tmPtr) {
  _tzset();
  var offsets = ___tm_struct_layout;
  var date = new Date(HEAP32[time >> 2] * 1e3);
  HEAP32[tmPtr + offsets.tm_sec >> 2] = date.getSeconds();
  HEAP32[tmPtr + offsets.tm_min >> 2] = date.getMinutes();
  HEAP32[tmPtr + offsets.tm_hour >> 2] = date.getHours();
  HEAP32[tmPtr + offsets.tm_mday >> 2] = date.getDate();
  HEAP32[tmPtr + offsets.tm_mon >> 2] = date.getMonth();
  HEAP32[tmPtr + offsets.tm_year >> 2] = date.getFullYear() - 1900;
  HEAP32[tmPtr + offsets.tm_wday >> 2] = date.getDay();
  var start = new Date(date.getFullYear(), 0, 1);
  var yday = Math.floor((date.getTime() - start.getTime()) / (1e3 * 60 * 60 * 24));
  HEAP32[tmPtr + offsets.tm_yday >> 2] = yday;
  HEAP32[tmPtr + offsets.tm_gmtoff >> 2] = start.getTimezoneOffset() * 60;
  var dst = Number(start.getTimezoneOffset() != date.getTimezoneOffset());
  HEAP32[tmPtr + offsets.tm_isdst >> 2] = dst;
  var timezone = "GMT";
  if (!(timezone in ___tm_timezones)) {
    ___tm_timezones[timezone] = allocate(intArrayFromString(timezone), "i8", ALLOC_NORMAL);
  }
  HEAP32[tmPtr + offsets.tm_zone >> 2] = ___tm_timezones[timezone];
  return tmPtr;
}

function _strftime(s, maxsize, format, timeptr) {
  return 0;
}

function _setlocale(category, locale) {
  if (!_setlocale.ret) _setlocale.ret = allocate([ 0 ], "i8", ALLOC_NORMAL);
  return _setlocale.ret;
}

function _alarm(seconds) {
  return 0;
}

function _signal(sig, func) {
  return 0;
}

function _fputs(s, stream) {
  return _write(stream, s, _strlen(s));
}

var ERRNO_MESSAGES = {
  1: "Operation not permitted",
  2: "No such file or directory",
  3: "No such process",
  4: "Interrupted system call",
  5: "Input/output error",
  6: "No such device or address",
  8: "Exec format error",
  9: "Bad file descriptor",
  10: "No child processes",
  11: "Resource temporarily unavailable",
  12: "Cannot allocate memory",
  13: "Permission denied",
  14: "Bad address",
  16: "Device or resource busy",
  17: "File exists",
  18: "Invalid cross-device link",
  19: "No such device",
  20: "Not a directory",
  21: "Is a directory",
  22: "Invalid argument",
  23: "Too many open files in system",
  24: "Too many open files",
  25: "Inappropriate ioctl for device",
  26: "Text file busy",
  27: "File too large",
  28: "No space left on device",
  29: "Illegal seek",
  30: "Read-only file system",
  31: "Too many links",
  32: "Broken pipe",
  33: "Numerical argument out of domain",
  34: "Numerical result out of range",
  35: "Resource deadlock avoided",
  36: "File name too long",
  37: "No locks available",
  38: "Function not implemented",
  39: "Directory not empty",
  40: "Too many levels of symbolic links",
  42: "No message of desired type",
  43: "Identifier removed",
  60: "Device not a stream",
  61: "No data available",
  62: "Timer expired",
  63: "Out of streams resources",
  67: "Link has been severed",
  71: "Protocol error",
  72: "Multihop attempted",
  74: "Bad message",
  75: "Value too large for defined data type",
  84: "Invalid or incomplete multibyte or wide character",
  88: "Socket operation on non-socket",
  89: "Destination address required",
  90: "Message too long",
  91: "Protocol wrong type for socket",
  92: "Protocol not available",
  93: "Protocol not supported",
  95: "Operation not supported",
  97: "Address family not supported by protocol",
  98: "Address already in use",
  99: "Cannot assign requested address",
  100: "Network is down",
  101: "Network is unreachable",
  102: "Network dropped connection on reset",
  103: "Software caused connection abort",
  104: "Connection reset by peer",
  105: "No buffer space available",
  106: "Transport endpoint is already connected",
  107: "Transport endpoint is not connected",
  110: "Connection timed out",
  111: "Connection refused",
  113: "No route to host",
  114: "Operation already in progress",
  115: "Operation now in progress",
  116: "Stale NFS file handle",
  122: "Disk quota exceeded",
  125: "Operation canceled",
  130: "Owner died",
  131: "State not recoverable"
};

function _strerror_r(errnum, strerrbuf, buflen) {
  if (errnum in ERRNO_MESSAGES) {
    if (ERRNO_MESSAGES[errnum].length > buflen - 1) {
      return ___setErrNo(ERRNO_CODES.ERANGE);
    } else {
      var msg = ERRNO_MESSAGES[errnum];
      for (var i = 0; i < msg.length; i++) {
        HEAP8[strerrbuf + i] = msg.charCodeAt(i);
      }
      HEAP8[strerrbuf + i] = 0;
      return 0;
    }
  } else {
    return ___setErrNo(ERRNO_CODES.EINVAL);
  }
}

function _strerror(errnum) {
  if (!_strerror.buffer) _strerror.buffer = _malloc(256);
  _strerror_r(errnum, _strerror.buffer, 256);
  return _strerror.buffer;
}

function _isatty(fildes) {
  if (!FS.streams[fildes]) {
    ___setErrNo(ERRNO_CODES.EBADF);
    return 0;
  }
  if (FS.streams[fildes].isTerminal) return 1;
  ___setErrNo(ERRNO_CODES.ENOTTY);
  return 0;
}

var _readline;

var _add_history;

function _fgets(s, n, stream) {
  if (!(stream in FS.streams)) return 0;
  var streamObj = FS.streams[stream];
  if (streamObj.error || streamObj.eof) return 0;
  var byte_;
  for (var i = 0; i < n - 1 && byte_ != "\n".charCodeAt(0); i++) {
    byte_ = _fgetc(stream);
    if (byte_ == -1) {
      if (streamObj.error) return 0; else if (streamObj.eof) break;
    }
    HEAP8[s + i] = byte_;
  }
  HEAP8[s + i] = 0;
  return s;
}

function _ferror(stream) {
  return Number(stream in FS.streams && FS.streams[stream].error);
}

function _setenv(envname, envval, overwrite) {
  if (envname === 0) {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
  }
  var name = Pointer_stringify(envname);
  var val = Pointer_stringify(envval);
  if (name === "" || name.indexOf("=") !== -1) {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
  }
  if (ENV.hasOwnProperty(name) && !overwrite) return 0;
  ENV[name] = val;
  ___buildEnvironment(ENV);
  return 0;
}

var _putc = _fputc;

function _lseek(fildes, offset, whence) {
  if (FS.streams[fildes] && !FS.streams[fildes].isDevice) {
    var stream = FS.streams[fildes];
    var position = offset;
    if (whence === 1) {
      position += stream.position;
    } else if (whence === 2) {
      position += stream.object.contents.length;
    }
    if (position < 0) {
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    } else {
      stream.ungotten = [];
      stream.position = position;
      return position;
    }
  } else {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  }
}

function _fseek(stream, offset, whence) {
  var ret = _lseek(stream, offset, whence);
  if (ret == -1) {
    return -1;
  } else {
    FS.streams[stream].eof = false;
    return 0;
  }
}

function _ftell(stream) {
  if (stream in FS.streams) {
    stream = FS.streams[stream];
    if (stream.object.isDevice) {
      ___setErrNo(ERRNO_CODES.ESPIPE);
      return -1;
    } else {
      return stream.position;
    }
  } else {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  }
}

function _fread(ptr, size, nitems, stream) {
  var bytesToRead = nitems * size;
  if (bytesToRead == 0) return 0;
  var bytesRead = _read(stream, ptr, bytesToRead);
  var streamObj = FS.streams[stream];
  if (bytesRead == -1) {
    if (streamObj) streamObj.error = true;
    return -1;
  } else {
    if (bytesRead < bytesToRead) streamObj.eof = true;
    return Math.floor(bytesRead / size);
  }
}

function _strncpy(pdest, psrc, num) {
  var padding = false, curr;
  for (var i = 0; i < num; i++) {
    curr = padding ? 0 : HEAP8[psrc + i];
    HEAP8[pdest + i] = curr;
    padding = padding || HEAP8[psrc + i] == 0;
  }
  return pdest;
}

function _sbrk(bytes) {
  var self = _sbrk;
  if (!self.called) {
    STATICTOP = alignMemoryPage(STATICTOP);
    self.called = true;
  }
  var ret = STATICTOP;
  if (bytes != 0) Runtime.staticAlloc(bytes);
  return ret;
}

function _feof(stream) {
  return Number(stream in FS.streams && FS.streams[stream].eof);
}

function _strdup(ptr) {
  var len = String_len(ptr);
  var newStr = _malloc(len + 1);
  _memcpy(newStr, ptr, len, 1);
  HEAP8[newStr + len] = 0;
  return newStr;
}

function _puts(s) {
  var stdout = HEAP32[_stdout >> 2];
  var ret = _fputs(s, stdout);
  if (ret < 0) {
    return ret;
  } else {
    var newlineRet = _fputc("\n".charCodeAt(0), stdout);
    return newlineRet < 0 ? -1 : ret + 1;
  }
}

function _isdigit(chr) {
  return chr >= "0".charCodeAt(0) && chr <= "9".charCodeAt(0);
}

function _atoi(s) {
  var c;
  while ((c = HEAP8[s]) && _isspace(c)) s++;
  if (!c || !_isdigit(c)) return 0;
  var e = s;
  while ((c = HEAP8[e]) && _isdigit(c)) e++;
  return Math.floor(Number(Pointer_stringify(s).substr(0, e - s)));
}

function _abort() {
  ABORT = true;
  throw "abort() at " + (new Error).stack;
}

function _sysconf(name) {
  switch (name) {
   case 8:
    return PAGE_SIZE;
   case 54:
   case 56:
   case 21:
   case 61:
   case 63:
   case 22:
   case 67:
   case 23:
   case 24:
   case 25:
   case 26:
   case 27:
   case 69:
   case 28:
   case 101:
   case 70:
   case 71:
   case 29:
   case 30:
   case 199:
   case 75:
   case 76:
   case 32:
   case 43:
   case 44:
   case 80:
   case 46:
   case 47:
   case 45:
   case 48:
   case 49:
   case 42:
   case 82:
   case 33:
   case 7:
   case 108:
   case 109:
   case 107:
   case 112:
   case 119:
   case 121:
    return 200809;
   case 13:
   case 104:
   case 94:
   case 95:
   case 34:
   case 35:
   case 77:
   case 81:
   case 83:
   case 84:
   case 85:
   case 86:
   case 87:
   case 88:
   case 89:
   case 90:
   case 91:
   case 94:
   case 95:
   case 110:
   case 111:
   case 113:
   case 114:
   case 115:
   case 116:
   case 117:
   case 118:
   case 120:
   case 40:
   case 16:
   case 79:
   case 19:
    return -1;
   case 92:
   case 93:
   case 5:
   case 72:
   case 6:
   case 74:
   case 92:
   case 93:
   case 96:
   case 97:
   case 98:
   case 99:
   case 102:
   case 103:
   case 105:
    return 1;
   case 38:
   case 66:
   case 50:
   case 51:
   case 4:
    return 1024;
   case 15:
   case 64:
   case 41:
    return 32;
   case 55:
   case 37:
   case 17:
    return 2147483647;
   case 18:
   case 1:
    return 47839;
   case 59:
   case 57:
    return 99;
   case 68:
   case 58:
    return 2048;
   case 0:
    return 2097152;
   case 3:
    return 65536;
   case 14:
    return 32768;
   case 73:
    return 32767;
   case 39:
    return 16384;
   case 60:
    return 1e3;
   case 106:
    return 700;
   case 52:
    return 256;
   case 62:
    return 255;
   case 2:
    return 100;
   case 65:
    return 64;
   case 36:
    return 20;
   case 100:
    return 16;
   case 20:
    return 6;
   case 53:
    return 4;
  }
  ___setErrNo(ERRNO_CODES.EINVAL);
  return -1;
}

function ___gxx_personality_v0() {}

function ___cxa_allocate_exception(size) {
  return _malloc(size);
}

function _llvm_eh_exception() {
  return HEAP32[_llvm_eh_exception.buf >> 2];
}

function __ZSt18uncaught_exceptionv() {
  return !!__ZSt18uncaught_exceptionv.uncaught_exception;
}

function ___cxa_is_number_type(type) {
  var isNumber = false;
  try {
    if (type == __ZTIi) isNumber = true;
  } catch (e) {}
  try {
    if (type == __ZTIl) isNumber = true;
  } catch (e) {}
  try {
    if (type == __ZTIx) isNumber = true;
  } catch (e) {}
  try {
    if (type == __ZTIf) isNumber = true;
  } catch (e) {}
  try {
    if (type == __ZTId) isNumber = true;
  } catch (e) {}
  return isNumber;
}

function ___cxa_does_inherit(definiteType, possibilityType, possibility) {
  if (possibility == 0) return false;
  if (possibilityType == 0 || possibilityType == definiteType) return true;
  var possibility_type_info;
  if (___cxa_is_number_type(possibilityType)) {
    possibility_type_info = possibilityType;
  } else {
    var possibility_type_infoAddr = HEAP32[possibilityType >> 2] - 8;
    possibility_type_info = HEAP32[possibility_type_infoAddr >> 2];
  }
  switch (possibility_type_info) {
   case 0:
    var definite_type_infoAddr = HEAP32[definiteType >> 2] - 8;
    var definite_type_info = HEAP32[definite_type_infoAddr >> 2];
    if (definite_type_info == 0) {
      var defPointerBaseAddr = definiteType + 8;
      var defPointerBaseType = HEAP32[defPointerBaseAddr >> 2];
      var possPointerBaseAddr = possibilityType + 8;
      var possPointerBaseType = HEAP32[possPointerBaseAddr >> 2];
      return ___cxa_does_inherit(defPointerBaseType, possPointerBaseType, possibility);
    } else return false;
   case 1:
    return false;
   case 2:
    var parentTypeAddr = possibilityType + 8;
    var parentType = HEAP32[parentTypeAddr >> 2];
    return ___cxa_does_inherit(definiteType, parentType, possibility);
   default:
    return false;
  }
}

function ___cxa_find_matching_catch(thrown, throwntype, typeArray) {
  if (throwntype != 0 && !___cxa_is_number_type(throwntype)) {
    var throwntypeInfoAddr = HEAP32[throwntype >> 2] - 8;
    var throwntypeInfo = HEAP32[throwntypeInfoAddr >> 2];
    if (throwntypeInfo == 0) thrown = HEAP32[thrown >> 2];
  }
  for (var i = 0; i < typeArray.length; i++) {
    if (___cxa_does_inherit(typeArray[i], throwntype, thrown)) return {
      f0: thrown,
      f1: typeArray[i]
    };
  }
  return {
    f0: thrown,
    f1: throwntype
  };
}

function ___cxa_throw(ptr, type, destructor) {
  if (!___cxa_throw.initialized) {
    try {
      HEAP32[__ZTVN10__cxxabiv119__pointer_type_infoE >> 2] = 0;
    } catch (e) {}
    try {
      HEAP32[__ZTVN10__cxxabiv117__class_type_infoE >> 2] = 1;
    } catch (e) {}
    try {
      HEAP32[__ZTVN10__cxxabiv120__si_class_type_infoE >> 2] = 2;
    } catch (e) {}
    ___cxa_throw.initialized = true;
  }
  Module.printErr("Compiled code throwing an exception, " + [ ptr, type, destructor ] + ", at " + (new Error).stack);
  HEAP32[_llvm_eh_exception.buf >> 2] = ptr;
  HEAP32[_llvm_eh_exception.buf + 4 >> 2] = type;
  HEAP32[_llvm_eh_exception.buf + 8 >> 2] = destructor;
  if (!("uncaught_exception" in __ZSt18uncaught_exceptionv)) {
    __ZSt18uncaught_exceptionv.uncaught_exception = 1;
  } else {
    __ZSt18uncaught_exceptionv.uncaught_exception++;
  }
  throw ptr;
}

function ___cxa_call_unexpected(exception) {
  ABORT = true;
  throw exception;
}

var __ZNSt9exceptionD2Ev;

function _llvm_uadd_with_overflow_i32(x, y) {
  x = x >>> 0;
  y = y >>> 0;
  return {
    f0: x + y >>> 0,
    f1: x + y > 4294967295
  };
}

function _putchar(c) {
  return _fputc(c, HEAP32[_stdout >> 2]);
}

function _memchr(ptr, chr, num) {
  chr = unSign(chr);
  for (var i = 0; i < num; i++) {
    if (HEAP8[ptr] == chr) return ptr;
    ptr++;
  }
  return 0;
}

__ATINIT__.unshift({
  func: (function() {
    if (!Module["noFSInit"] && !FS.init.initialized) FS.init();
  })
});

__ATMAIN__.push({
  func: (function() {
    FS.ignorePermissions = false;
  })
});

__ATEXIT__.push({
  func: (function() {
    FS.quit();
  })
});

___setErrNo(0);

_fgetc.ret = allocate([ 0 ], "i8", ALLOC_STATIC);

___buildEnvironment(ENV);

_fputc.ret = allocate([ 0 ], "i8", ALLOC_STATIC);

_llvm_eh_exception.buf = allocate(12, "void*", ALLOC_STATIC);

Module.callMain = function callMain(args) {
  var argc = args.length + 1;
  function pad() {
    for (var i = 0; i < 4 - 1; i++) {
      argv.push(0);
    }
  }
  var argv = [ allocate(intArrayFromString("/bin/this.program"), "i8", ALLOC_STATIC) ];
  pad();
  for (var i = 0; i < argc - 1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), "i8", ALLOC_STATIC));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, "i32", ALLOC_STATIC);
  return _main(argc, argv, 0);
};

var _DebuggerFrame_class;

var _DebuggerObject_class;

var __ZN2js8Debugger7jsclassE;

var __ZN2js8Debugger10propertiesE;

var __ZN2js8Debugger7methodsE;

var _DebuggerScript_class;

var __ZL25DebuggerScript_properties;

var __ZL22DebuggerScript_methods;

var _DebuggerArguments_class;

var __ZL24DebuggerFrame_properties;

var __ZL21DebuggerFrame_methods;

var __ZL25DebuggerObject_properties;

var __ZL22DebuggerObject_methods;

var __ZTVN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEEE;

var __ZTVN2js11WeakMapBaseE;

var __ZN2jsL21GlobalDebuggees_classE;

var __ZN16JSExternalString14str_finalizersE;

var __ZN2js7unicode11js_charinfoE;

var __ZN2js7unicode6index1E;

var __ZN2js7unicode6index2E;

var _stdout;

var _stderr;

var __ZN2v88internalL14kCachedPowers8E;

var _JSVAL_NULL;

var _JSVAL_ZERO;

var _JSVAL_ONE;

var _JSVAL_FALSE;

var _JSVAL_TRUE;

var _JSVAL_VOID;

var __ZL22js_NewRuntimeWasCalled_b;

var _js_dummy_class;

var __ZL20standard_class_atoms;

var __ZL20standard_class_names;

var __ZL22object_prototype_names;

var __ZL15prop_iter_class;

var _stdin;

var _js_CStringsAreUTF8_b;

var __ZZN2js6RegExp7compileEP9JSContextPNS_11TokenStreamEE6prefix;

var __ZZN2js6RegExp7compileEP9JSContextPNS_11TokenStreamEE7postfix;

__ATINIT__ = __ATINIT__.concat([ {
  func: __GLOBAL__I_a
}, {
  func: __GLOBAL__I_a891
} ]);

var __ZN2js10ArrayClassE;

var __ZN2js14SlowArrayClassE;

var __ZL13array_methods;

var __ZL20array_static_methods;

var __ZZL18array_toString_subP9JSContextP8JSObjectiP8JSStringPN2JS5ValueEE5comma;

var _js_common_atom_names;

var __ZN2js12BooleanClassE;

var __ZL15boolean_methods;

var _js_ErrorFormatString;

var __ZN2js5crashL8gGCStackE;

var __ZN2js5crashL11gErrorStackE;

var __ZN2js5crashL11gRingBufferE;

var __ZN2js9DateClassE;

var __ZL19date_static_methods;

var __ZL12date_methods;

var __ZL8LocalTZA;

var __ZL15firstDayOfMonth;

var __ZL16yearStartingWith;

var __ZL3wtb;

var __ZL3ttb;

var __ZL4days;

var __ZL6months;

var __ZL8stub_ops;

var _tens;

var _bigtens;

var _p05;

var _tinytens;

var _js_SrcNoteSpec;

var __ZL13statementName;

var __ZN2js10ErrorClassE;

var __ZL17exception_methods;

var __ZN2js26StrictArgumentsObjectClassE;

var __ZN2js26NormalArgumentsObjectClassE;

var __ZN2js12DeclEnvClassE;

var __ZN2js9CallClassE;

var __ZL15poisonPillProps;

var __ZN2js13FunctionClassE;

var __ZN2js16function_methodsE;

var __ZN2js2gc16slotsToThingKindE;

var __ZN2js2gc5Arena10ThingSizesE;

var __ZN2js2gc5Arena17FirstThingOffsetsE;

var __ZZN2js2gcL19MapAllocToTraceKindENS0_9AllocKindEE3map;

var __ZN2js8gcReasonE;

var __ZL19defaultHashAllocOps;

var __ZN2js5types15emptyTypeObjectE;

var __ZTV18TypeConstraintProp;

var __ZTV22TypeConstraintCallProp;

var __ZTV24TypeConstraintSetElement;

var __ZTV18TypeConstraintCall;

var __ZTV19TypeConstraintArith;

var __ZTV27TypeConstraintTransformThis;

var __ZTV27TypeConstraintPropagateThis;

var __ZTVN2js5types14TypeConstraintE;

var __ZTV27TypeConstraintLazyArguments;

var __ZTV27TypeConstraintSubsetBarrier;

var __ZTV29TypeConstraintFilterPrimitive;

var __ZTV20TypeConstraintSubset;

var __ZTV33TypeConstraintClearDefiniteSingle;

var __ZTV33TypeConstraintClearDefiniteSetter;

var __ZZL15InferSpewActiveN2js5types11SpewChannelEE6active;

var __ZZL15InferSpewActiveN2js5types11SpewChannelEE7checked_b;

var _js_NoSuchMethodClass;

var __ZTV23GenericInterruptEnablerIiE;

var __ZTVN2js17InterpreterFrames20InterruptEnablerBaseE;

var __ZN2js13IteratorClassE;

var _sCustomIteratorCount;

var __ZL16iterator_methods;

var __ZN2js18StopIterationClassE;

var __ZN2js14GeneratorClassE;

var __ZL17generator_methods;

var __ZN2js9MathClassE;

var __ZL19math_static_methods;

var __ZL14math_constants;

var __ZL16number_functions;

var __ZN2js11NumberClassE;

var __ZL14number_methods;

var _js_NaN;

var _js_PositiveInfinity;

var _js_NegativeInfinity;

var __ZL16number_constants;

var __ZN2js5Shape15sharedNonNativeE;

var __ZN2js11ObjectClassE;

var _object_props;

var _sSetProtoCalled;

var _object_methods;

var _object_static_methods;

var __ZN2js9WithClassE;

var __ZN2js10BlockClassE;

var __ZL19lazy_prototype_init;

var __ZN2js9JSONClassE;

var __ZL19json_static_methods;

var _js_CodeSpec;

var __ZL9CodeToken;

var __ZL10var_prefix;

var _table;

var __ZL6pm_fns;

var __ZL8pm_class;

var __ZL8pm_props;

var __ZL9pm_consts;

var __str23014;

var __ZL27sScriptedProxyHandlerFamily;

var __ZTV22JSScriptedProxyHandler;

var __ZN22JSScriptedProxyHandler9singletonE;

var __ZN2js16ObjectProxyClassE;

var __ZN2js21OuterWindowProxyClassE;

var __ZN2js18FunctionProxyClassE;

var __ZL14static_methods;

var __ZN2js19CallableObjectClassE;

var __ZN2js10ProxyClassE;

var __ZN2js8aopNamesE;

var __ZN2js10binopNamesE;

var __ZN2js9unopNamesE;

var __ZN2js13nodeTypeNamesE;

var __ZN2js13callbackNamesE;

var __ZL14static_methods3391;

var __ZN2js20regexp_statics_classE;

var __ZL19regexp_static_props;

var __ZN2js11RegExpClassE;

var __ZL14regexp_methods;

var __ZL8keywords;

var __ZN2js11ScriptClassE;

var __ZL16string_functions;

var _js_empty_ucstr;

var _js_EmptySubString;

var __ZN2js11StringClassE;

var __ZL14string_methods;

var __ZL21string_static_methods;

var __ZZ16js_ValueToSourceP9JSContextRKN2JS5ValueEE17js_negzero_ucNstr;

var __ZZL17Utf8ToOneUcs4CharPKhiE12minucs4Table;

var __ZL21js_uriUnescaped_ucstr;

var __ZL29js_uriReservedPlusPound_ucstr;

var __ZN2js11ArrayBuffer9slowClassE;

var __ZN2js16ArrayBufferClassE;

var __ZN2js11ArrayBuffer7jspropsE;

var __ZN2js10TypedArray7jspropsE;

var __ZN9Int8Array7jsfuncsE;

var __ZN10Uint8Array7jsfuncsE;

var __ZN10Int16Array7jsfuncsE;

var __ZN11Uint16Array7jsfuncsE;

var __ZN10Int32Array7jsfuncsE;

var __ZN11Uint32Array7jsfuncsE;

var __ZN12Float32Array7jsfuncsE;

var __ZN12Float64Array7jsfuncsE;

var __ZN17Uint8ClampedArray7jsfuncsE;

var __ZN2js10TypedArray11fastClassesE;

var __ZN2js10TypedArray11slowClassesE;

var __ZN2js12WeakMapClassE;

var __ZL16weak_map_methods;

var __ZTVN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEEE;

var __ZL14sWrapperFamily;

var __ZTV9JSWrapper;

var __ZN9JSWrapper9singletonE;

var __ZN25JSCrossCompartmentWrapper9singletonE;

var __ZTV25JSCrossCompartmentWrapper;

var __ZL10xdrmem_ops;

var __ZZ11JS_XDRBytesE6padbuf;

var _sE4XObjectsCreated;

var __ZN2js14NamespaceClassE;

var __ZL17namespace_methods;

var __ZN2js10QNameClassE;

var __ZN2js18AttributeNameClassE;

var __ZN2js12AnyNameClassE;

var __ZL13qname_methods;

var __ZL16xml_static_props;

var __ZN2js8XMLClassE;

var _js_xml_class_str;

var __ZL11xml_methods;

var __ZL18xml_static_methods;

var __ZL15namespace_props;

var _js_XMLFilterClass;

var __ZZL15MakeXMLPIStringP9JSContextRN2js12StringBufferEP8JSStringS5_E16pi_prefix_ucNstr;

var __ZZL15MakeXMLPIStringP9JSContextRN2js12StringBufferEP8JSStringS5_E16pi_suffix_ucNstr;

var __ZZL20MakeXMLCommentStringP9JSContextRN2js12StringBufferEP8JSStringE21comment_prefix_ucNstr;

var __ZZL20MakeXMLCommentStringP9JSContextRN2js12StringBufferEP8JSStringE21comment_suffix_ucNstr;

var __ZZL18MakeXMLCDATAStringP9JSContextRN2js12StringBufferEP8JSStringE19cdata_prefix_ucNstr;

var __ZZL18MakeXMLCDATAStringP9JSContextRN2js12StringBufferEP8JSStringE19cdata_suffix_ucNstr;

var __ZL11qname_props;

var __ZL7escapes;

var __ZZL38repeatInformationFromInstructionOffsetsRbRiS0_E35maximumRepeatsFromInstructionOffset;

var _jsc_pcre_utf8_table1;

var _jsc_pcre_utf8_table2;

var _jsc_pcre_utf8_table3;

var __ZL9ucp_table;

var __ZL9gCanceled;

var __ZL14enableTraceJit_b;

var __ZL15enableMethodJit_b;

var __ZL19enableTypeInference;

var __ZL22enableDisassemblyDumps_b;

var __ZL11printTiming_b;

var __ZL8gRuntime;

var _gExitCode;

var _gQuitting_b;

var _gErrFile;

var _gOutFile;

var __ZL13sandbox_class;

var __ZL14resolver_class;

var __ZL15shell_functions;

var __ZL9its_props;

var __ZL9its_class;

var _jsShell_ErrorFormatString;

var _global_class;

var __ZL9env_class;

var _shellTrustedPrincipals;

var _securityCallbacks;

var __ZL16gTimeoutInterval;

var __ZTVN2js3cli6detail10BoolOptionE;

var __ZTVN2js3cli6detail6OptionE;

var __ZZL13env_enumerateP9JSContextP8JSObjectE9reflected_b;

var __ZL9its_noisy;

var __ZL13its_enum_fail;

var __ZL19shell_help_messages;

var __ZZL7CompileP9JSContextjPN2JS5ValueEE11dummy_class;

var __ZL12badSurrogate;

var __ZL13finalizeCount;

var __ZL20FinalizeCounterClass;

var __ZZL9CountHeapP9JSContextjPN2JS5ValueEE14traceKindNames;

var __ZZL11GCParameterP9JSContextjPN2JS5ValueEE8paramMap;

var __ZL10js_options;

var __ZTVN2js3cli6detail17MultiStringOptionE;

var __ZTVN2js3cli6detail12ValuedOptionE;

var __ZTVN2js3cli6detail12StringOptionE;

var __ZZL23OptionFlagsToFormatInfocbPjE3fmt;

var __str17668;

var __gm_;

var _mparams;

var __ZL13__new_handler;

var __ZTVSt9bad_alloc;

var __ZTVN10__cxxabiv120__si_class_type_infoE;

var __ZTISt9exception;

var __ZTISt9bad_alloc;

_DebuggerFrame_class = allocate([ 0, 0, 0, 0, 769, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

_DebuggerObject_class = allocate([ 0, 0, 0, 0, 257, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 304, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str2 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str3 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 79, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str4 = allocate([ 104, 105, 116, 0 ], "i8", ALLOC_STATIC);

__ZN2js8Debugger7jsclassE = allocate([ 0, 0, 0, 0, 1793, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 306, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 308, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str11 = allocate([ 112, 114, 111, 116, 111, 116, 121, 112, 101, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str12 = allocate([ 103, 101, 116, 32, 101, 110, 97, 98, 108, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str13 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 115, 101, 116, 32, 101, 110, 97, 98, 108, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str14 = allocate([ 115, 101, 116, 32, 101, 110, 97, 98, 108, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str15 = allocate([ 103, 101, 116, 72, 111, 111, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str16 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 115, 101, 116, 72, 111, 111, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str17 = allocate([ 115, 101, 116, 72, 111, 111, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str18 = allocate([ 103, 101, 116, 32, 117, 110, 99, 97, 117, 103, 104, 116, 69, 120, 99, 101, 112, 116, 105, 111, 110, 72, 111, 111, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str19 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 115, 101, 116, 32, 117, 110, 99, 97, 117, 103, 104, 116, 69, 120, 99, 101, 112, 116, 105, 111, 110, 72, 111, 111, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str20 = allocate([ 115, 101, 116, 32, 117, 110, 99, 97, 117, 103, 104, 116, 69, 120, 99, 101, 112, 116, 105, 111, 110, 72, 111, 111, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str21 = allocate([ 117, 110, 99, 97, 117, 103, 104, 116, 69, 120, 99, 101, 112, 116, 105, 111, 110, 72, 111, 111, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str22 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 97, 100, 100, 68, 101, 98, 117, 103, 103, 101, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str23 = allocate([ 97, 100, 100, 68, 101, 98, 117, 103, 103, 101, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str24 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 114, 101, 109, 111, 118, 101, 68, 101, 98, 117, 103, 103, 101, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str25 = allocate([ 114, 101, 109, 111, 118, 101, 68, 101, 98, 117, 103, 103, 101, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str26 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 104, 97, 115, 68, 101, 98, 117, 103, 103, 101, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str27 = allocate([ 104, 97, 115, 68, 101, 98, 117, 103, 103, 101, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str28 = allocate([ 103, 101, 116, 68, 101, 98, 117, 103, 103, 101, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str29 = allocate([ 103, 101, 116, 78, 101, 119, 101, 115, 116, 70, 114, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str30 = allocate([ 99, 108, 101, 97, 114, 65, 108, 108, 66, 114, 101, 97, 107, 112, 111, 105, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str31 = allocate([ 101, 110, 97, 98, 108, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str32 = allocate([ 111, 110, 68, 101, 98, 117, 103, 103, 101, 114, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str33 = allocate([ 111, 110, 69, 120, 99, 101, 112, 116, 105, 111, 110, 85, 110, 119, 105, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str34 = allocate([ 111, 110, 78, 101, 119, 83, 99, 114, 105, 112, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str35 = allocate([ 111, 110, 69, 110, 116, 101, 114, 70, 114, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

__ZN2js8Debugger10propertiesE = allocate([ 0, 0, 0, 0, 0, 72, 0, 0, 310, 0, 0, 0, 312, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 314, 0, 0, 0, 316, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 318, 0, 0, 0, 320, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 322, 0, 0, 0, 324, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 326, 0, 0, 0, 328, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 330, 0, 0, 0, 332, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

__ZN2js8Debugger7methodsE = allocate([ 0, 0, 0, 0, 334, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 336, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 338, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 340, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 342, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 344, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

_DebuggerScript_class = allocate([ 0, 0, 0, 0, 513, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 346, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str37 = allocate([ 117, 114, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str38 = allocate([ 115, 116, 97, 114, 116, 76, 105, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str39 = allocate([ 108, 105, 110, 101, 67, 111, 117, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str40 = allocate([ 108, 105, 118, 101, 0 ], "i8", ALLOC_STATIC);

__ZL25DebuggerScript_properties = allocate([ 0, 0, 0, 0, 0, 72, 0, 0, 348, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 350, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 352, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 354, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str41 = allocate([ 103, 101, 116, 67, 104, 105, 108, 100, 83, 99, 114, 105, 112, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str42 = allocate([ 103, 101, 116, 65, 108, 108, 79, 102, 102, 115, 101, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str43 = allocate([ 103, 101, 116, 76, 105, 110, 101, 79, 102, 102, 115, 101, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str44 = allocate([ 103, 101, 116, 79, 102, 102, 115, 101, 116, 76, 105, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str45 = allocate([ 115, 101, 116, 66, 114, 101, 97, 107, 112, 111, 105, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str46 = allocate([ 103, 101, 116, 66, 114, 101, 97, 107, 112, 111, 105, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str47 = allocate([ 99, 108, 101, 97, 114, 66, 114, 101, 97, 107, 112, 111, 105, 110, 116, 0 ], "i8", ALLOC_STATIC);

__ZL22DebuggerScript_methods = allocate([ 0, 0, 0, 0, 356, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 358, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 360, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 362, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 364, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 366, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 368, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 370, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str48 = allocate([ 70, 114, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

_DebuggerArguments_class = allocate([ 0, 0, 0, 0, 256, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str52 = allocate([ 99, 111, 110, 115, 116, 114, 117, 99, 116, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str54 = allocate([ 111, 102, 102, 115, 101, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str55 = allocate([ 111, 108, 100, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str57 = allocate([ 116, 104, 105, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str59 = allocate([ 111, 110, 83, 116, 101, 112, 0 ], "i8", ALLOC_STATIC);

__ZL24DebuggerFrame_properties = allocate([ 0, 0, 0, 0, 0, 72, 0, 0, 372, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 374, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 376, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 378, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 380, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 384, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 386, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 388, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 390, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 392, 0, 0, 0, 394, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str60 = allocate([ 101, 118, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str61 = allocate([ 101, 118, 97, 108, 87, 105, 116, 104, 66, 105, 110, 100, 105, 110, 103, 115, 0 ], "i8", ALLOC_STATIC);

__ZL21DebuggerFrame_methods = allocate([ 0, 0, 0, 0, 396, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 398, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str62 = allocate([ 79, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str63 = allocate([ 112, 114, 111, 116, 111, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str64 = allocate([ 99, 108, 97, 115, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str65 = allocate([ 99, 97, 108, 108, 97, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str67 = allocate([ 112, 97, 114, 97, 109, 101, 116, 101, 114, 78, 97, 109, 101, 115, 0 ], "i8", ALLOC_STATIC);

__ZL25DebuggerObject_properties = allocate([ 0, 0, 0, 0, 0, 72, 0, 0, 400, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 402, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 404, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 406, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 408, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 410, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str72 = allocate([ 100, 101, 108, 101, 116, 101, 80, 114, 111, 112, 101, 114, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str79 = allocate([ 97, 112, 112, 108, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str80 = allocate([ 99, 97, 108, 108, 0 ], "i8", ALLOC_STATIC);

__ZL22DebuggerObject_methods = allocate([ 0, 0, 0, 0, 412, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 414, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 416, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 418, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 420, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 422, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 424, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 426, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 428, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 430, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 432, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 434, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 436, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZTVN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEEE = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 438, 0, 0, 0, 440, 0, 0, 0, 442, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTVN2js11WeakMapBaseE = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 444, 0, 0, 0, 444, 0, 0, 0, 444, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

STRING_TABLE.__str82 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 83, 99, 114, 105, 112, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str83 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 70, 114, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str84 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 79, 98, 106, 101, 99, 116, 46, 100, 101, 102, 105, 110, 101, 80, 114, 111, 112, 101, 114, 116, 105, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str88 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 79, 98, 106, 101, 99, 116, 46, 100, 101, 102, 105, 110, 101, 80, 114, 111, 112, 101, 114, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str89 = allocate([ 103, 101, 116, 32, 115, 99, 114, 105, 112, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str90 = allocate([ 103, 101, 116, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 78, 97, 109, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str91 = allocate([ 103, 101, 116, 32, 110, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str92 = allocate([ 103, 101, 116, 32, 99, 97, 108, 108, 97, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str93 = allocate([ 103, 101, 116, 32, 99, 108, 97, 115, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str94 = allocate([ 103, 101, 116, 32, 112, 114, 111, 116, 111, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str96 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 70, 114, 97, 109, 101, 46, 101, 118, 97, 108, 87, 105, 116, 104, 66, 105, 110, 100, 105, 110, 103, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str97 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 70, 114, 97, 109, 101, 46, 101, 118, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str99 = allocate([ 100, 101, 98, 117, 103, 103, 101, 114, 32, 101, 118, 97, 108, 32, 99, 111, 100, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str100 = allocate([ 115, 116, 97, 99, 107, 32, 102, 114, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str101 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 70, 114, 97, 109, 101, 46, 115, 101, 116, 32, 111, 110, 83, 116, 101, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str102 = allocate([ 115, 101, 116, 32, 111, 110, 83, 116, 101, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str103 = allocate([ 103, 101, 116, 32, 111, 110, 83, 116, 101, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str104 = allocate([ 103, 101, 116, 32, 116, 121, 112, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str105 = allocate([ 103, 101, 116, 32, 116, 104, 105, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str106 = allocate([ 103, 101, 116, 32, 111, 102, 102, 115, 101, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str107 = allocate([ 103, 101, 116, 32, 108, 105, 118, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str108 = allocate([ 103, 101, 116, 32, 103, 101, 110, 101, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str109 = allocate([ 103, 101, 116, 32, 99, 111, 110, 115, 116, 114, 117, 99, 116, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str110 = allocate([ 103, 101, 116, 32, 99, 97, 108, 108, 101, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str111 = allocate([ 103, 101, 116, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str112 = allocate([ 103, 101, 116, 65, 114, 103, 117, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str113 = allocate([ 103, 101, 116, 32, 97, 114, 103, 117, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str114 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 83, 99, 114, 105, 112, 116, 46, 99, 108, 101, 97, 114, 66, 114, 101, 97, 107, 112, 111, 105, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str115 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 83, 99, 114, 105, 112, 116, 46, 115, 101, 116, 66, 114, 101, 97, 107, 112, 111, 105, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str116 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 83, 99, 114, 105, 112, 116, 46, 103, 101, 116, 79, 102, 102, 115, 101, 116, 76, 105, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str117 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 83, 99, 114, 105, 112, 116, 46, 103, 101, 116, 76, 105, 110, 101, 79, 102, 102, 115, 101, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str118 = allocate([ 103, 101, 116, 32, 108, 105, 110, 101, 67, 111, 117, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str119 = allocate([ 103, 101, 116, 32, 115, 116, 97, 114, 116, 76, 105, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str120 = allocate([ 103, 101, 116, 32, 117, 114, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str122 = allocate([ 71, 108, 111, 98, 97, 108, 68, 101, 98, 117, 103, 103, 101, 101, 0 ], "i8", ALLOC_STATIC);

__ZN2jsL21GlobalDebuggees_classE = allocate([ 0, 0, 0, 0, 1, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 446, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str156 = allocate([ 65, 98, 111, 117, 116, 32, 116, 111, 32, 100, 101, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 105, 110, 118, 97, 108, 105, 100, 32, 115, 108, 111, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1157 = allocate([ 47, 100, 105, 115, 107, 47, 108, 111, 99, 97, 108, 47, 106, 116, 101, 114, 114, 97, 99, 101, 47, 98, 117, 105, 108, 100, 98, 111, 116, 47, 115, 108, 97, 118, 101, 47, 106, 115, 95, 106, 115, 95, 66, 117, 105, 108, 100, 95, 65, 108, 108, 47, 98, 117, 105, 108, 100, 47, 98, 117, 105, 108, 100, 101, 114, 47, 98, 117, 105, 108, 100, 47, 109, 111, 122, 105, 108, 108, 97, 45, 99, 101, 110, 116, 114, 97, 108, 47, 106, 115, 47, 115, 114, 99, 47, 118, 109, 47, 83, 116, 97, 99, 107, 46, 99, 112, 112, 0 ], "i8", ALLOC_STATIC);

__ZN16JSExternalString14str_finalizersE = allocate(32, "*", ALLOC_STATIC);

STRING_TABLE.__ZN2js13StaticStrings11toSmallCharE = allocate([ 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 255, 255, 255, 255, 255, 255, 255, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 255, 255, 255, 255, 255, 255, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 255, 255, 255, 255, 255 ], "i8", ALLOC_STATIC);

__ZN2js7unicode11js_charinfoE = allocate([ 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 1, undef, 0, 0, 0, 0, 4, undef, 0, 0, 32, 0, 2, undef, -32, 0, 0, 0, 2, undef, 0, 0, 0, 0, 2, undef, 743, 0, 0, 0, 2, undef, 121, 0, 0, 0, 2, undef, 0, 0, 1, 0, 2, undef, -1, 0, 0, 0, 2, undef, 0, 0, -199, 0, 2, undef, -232, 0, 0, 0, 2, undef, 0, 0, -121, 0, 2, undef, -300, 0, 0, 0, 2, undef, 195, 0, 0, 0, 2, undef, 0, 0, 210, 0, 2, undef, 0, 0, 206, 0, 2, undef, 0, 0, 205, 0, 2, undef, 0, 0, 79, 0, 2, undef, 0, 0, 202, 0, 2, undef, 0, 0, 203, 0, 2, undef, 0, 0, 207, 0, 2, undef, 97, 0, 0, 0, 2, undef, 0, 0, 211, 0, 2, undef, 0, 0, 209, 0, 2, undef, 163, 0, 0, 0, 2, undef, 0, 0, 213, 0, 2, undef, 130, 0, 0, 0, 2, undef, 0, 0, 214, 0, 2, undef, 0, 0, 218, 0, 2, undef, 0, 0, 217, 0, 2, undef, 0, 0, 219, 0, 2, undef, 56, 0, 0, 0, 2, undef, 0, 0, 2, 0, 2, undef, -1, 0, 1, 0, 2, undef, -2, 0, 0, 0, 2, undef, -79, 0, 0, 0, 2, undef, 0, 0, -97, 0, 2, undef, 0, 0, -56, 0, 2, undef, 0, 0, -130, 0, 2, undef, 0, 0, 10795, 0, 2, undef, 0, 0, -163, 0, 2, undef, 0, 0, 10792, 0, 2, undef, 10815, 0, 0, 0, 2, undef, 0, 0, -195, 0, 2, undef, 0, 0, 69, 0, 2, undef, 0, 0, 71, 0, 2, undef, 10783, 0, 0, 0, 2, undef, 10780, 0, 0, 0, 2, undef, 10782, 0, 0, 0, 2, undef, -210, 0, 0, 0, 2, undef, -206, 0, 0, 0, 2, undef, -205, 0, 0, 0, 2, undef, -202, 0, 0, 0, 2, undef, -203, 0, 0, 0, 2, undef, -207, 0, 0, 0, 2, undef, -22643, 0, 613, 0, 10, undef, -209, 0, 0, 0, 2, undef, -211, 0, 0, 0, 2, undef, 10743, 0, 0, 0, 2, undef, 10749, 0, 0, 0, 2, undef, -213, 0, 0, 0, 2, undef, -214, 0, 0, 0, 2, undef, 10727, 0, 0, 0, 2, undef, -218, 0, 0, 0, 2, undef, -69, 0, 0, 0, 2, undef, -217, 0, 0, 0, 2, undef, -71, 0, 0, 0, 2, undef, -219, 0, 0, 0, 2, undef, 84, 0, 0, 0, 4, undef, 0, 0, 38, 0, 2, undef, 0, 0, 37, 0, 2, undef, 0, 0, 64, 0, 2, undef, 0, 0, 63, 0, 2, undef, -38, 0, 0, 0, 2, undef, -37, 0, 0, 0, 2, undef, -31, 0, 0, 0, 2, undef, -64, 0, 0, 0, 2, undef, -63, 0, 0, 0, 2, undef, 0, 0, 8, 0, 2, undef, -62, 0, 0, 0, 2, undef, -57, 0, 0, 0, 2, undef, -47, 0, 0, 0, 2, undef, -54, 0, 0, 0, 2, undef, -8, 0, 0, 0, 2, undef, -86, 0, 0, 0, 2, undef, -80, 0, 0, 0, 2, undef, 7, 0, 0, 0, 2, undef, 0, 0, -60, 0, 2, undef, -96, 0, 0, 0, 2, undef, 0, 0, -7, 0, 2, undef, 0, 0, 80, 0, 2, undef, 0, 0, 0, 0, 16, undef, 0, 0, 15, 0, 2, undef, -15, 0, 0, 0, 2, undef, 0, 0, 48, 0, 2, undef, -48, 0, 0, 0, 2, undef, 0, 0, 0, 0, 36, undef, 0, 0, 7264, 0, 2, undef, -22659, 0, 7545, 0, 10, undef, 3814, 0, 0, 0, 2, undef, -59, 0, 0, 0, 2, undef, 0, 0, -7615, 0, 2, undef, 8, 0, 0, 0, 2, undef, 0, 0, -8, 0, 2, undef, 74, 0, 0, 0, 2, undef, 86, 0, 0, 0, 2, undef, 100, 0, 0, 0, 2, undef, 128, 0, 0, 0, 2, undef, 112, 0, 0, 0, 2, undef, 126, 0, 0, 0, 2, undef, 9, 0, 0, 0, 2, undef, 0, 0, -74, 0, 2, undef, 0, 0, -9, 0, 2, undef, -7205, 0, 0, 0, 2, undef, 0, 0, -86, 0, 2, undef, 0, 0, -100, 0, 2, undef, 0, 0, -112, 0, 2, undef, 0, 0, -128, 0, 2, undef, 0, 0, -126, 0, 2, undef, 0, 0, -7517, 0, 2, undef, 0, 0, -8383, 0, 2, undef, 0, 0, -8262, 0, 2, undef, 0, 0, 28, 0, 2, undef, -28, 0, 0, 0, 2, undef, 0, 0, 16, 0, 2, undef, -16, 0, 0, 0, 2, undef, 0, 0, 26, 0, 0, undef, -26, 0, 0, 0, 0, undef, 0, 0, -10743, 0, 2, undef, 0, 0, -3814, 0, 2, undef, 0, 0, -10727, 0, 2, undef, -10795, 0, 0, 0, 2, undef, -10792, 0, 0, 0, 2, undef, 0, 0, -10780, 0, 2, undef, 0, 0, -10749, 0, 2, undef, 0, 0, -10783, 0, 2, undef, 0, 0, -10782, 0, 2, undef, 0, 0, -10815, 0, 2, undef, -7264, 0, 0, 0, 2, undef ], [ "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8" ], ALLOC_STATIC);

__ZN2js7unicode6index1E = allocate([ 0, 0, 1, 0, 2, 0, 3, 0, 4, 0, 5, 0, 6, 0, 7, 0, 8, 0, 9, 0, 10, 0, 11, 0, 12, 0, 13, 0, 14, 0, 15, 0, 16, 0, 17, 0, 18, 0, 19, 0, 20, 0, 21, 0, 22, 0, 23, 0, 24, 0, 25, 0, 26, 0, 27, 0, 28, 0, 29, 0, 30, 0, 31, 0, 32, 0, 33, 0, 34, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 34, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 34, 0, 99, 0, 26, 0, 100, 0, 26, 0, 101, 0, 102, 0, 102, 0, 103, 0, 102, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 115, 0, 116, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 117, 0, 118, 0, 102, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 125, 0, 74, 0, 126, 0, 127, 0, 128, 0, 26, 0, 129, 0, 130, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 85, 0, 34, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 131, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 132, 0, 133, 0, 26, 0, 26, 0, 26, 0, 26, 0, 134, 0, 135, 0, 136, 0, 137, 0, 138, 0, 139, 0, 140, 0, 141, 0, 142, 0, 143, 0, 144, 0, 145, 0, 146, 0, 147, 0, 148, 0, 149, 0, 150, 0, 151, 0, 152, 0, 153, 0, 154, 0, 34, 0, 34, 0, 155, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 156, 0, 157, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 26, 0, 26, 0, 26, 0, 26, 0, 158, 0, 158, 0, 26, 0, 159, 0, 160, 0, 161, 0, 162, 0, 163, 0, 26, 0, 26, 0, 26, 0, 26, 0, 164, 0, 165, 0, 166, 0, 167, 0, 168, 0, 169, 0, 26, 0, 170, 0, 171, 0, 172, 0, 173, 0, 174, 0 ], [ "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN2js7unicode6index2E = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 0, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 5, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 0, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 7, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 10, 0, 11, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 5, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 5, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 12, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 13, 0, 14, 0, 15, 0, 8, 0, 9, 0, 8, 0, 9, 0, 16, 0, 8, 0, 9, 0, 17, 0, 17, 0, 8, 0, 9, 0, 5, 0, 18, 0, 19, 0, 20, 0, 8, 0, 9, 0, 17, 0, 21, 0, 22, 0, 23, 0, 24, 0, 8, 0, 9, 0, 25, 0, 5, 0, 23, 0, 26, 0, 27, 0, 28, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 29, 0, 8, 0, 9, 0, 29, 0, 5, 0, 5, 0, 8, 0, 9, 0, 29, 0, 8, 0, 9, 0, 30, 0, 30, 0, 8, 0, 9, 0, 8, 0, 9, 0, 31, 0, 8, 0, 9, 0, 5, 0, 5, 0, 8, 0, 9, 0, 5, 0, 32, 0, 5, 0, 5, 0, 5, 0, 5, 0, 33, 0, 34, 0, 35, 0, 33, 0, 34, 0, 35, 0, 33, 0, 34, 0, 35, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 36, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 5, 0, 33, 0, 34, 0, 35, 0, 8, 0, 9, 0, 37, 0, 38, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 39, 0, 5, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 40, 0, 8, 0, 9, 0, 41, 0, 42, 0, 43, 0, 43, 0, 8, 0, 9, 0, 44, 0, 45, 0, 46, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 5, 0, 52, 0, 52, 0, 5, 0, 53, 0, 5, 0, 54, 0, 5, 0, 5, 0, 5, 0, 5, 0, 52, 0, 5, 0, 5, 0, 55, 0, 5, 0, 56, 0, 5, 0, 5, 0, 57, 0, 58, 0, 5, 0, 59, 0, 5, 0, 5, 0, 5, 0, 58, 0, 5, 0, 60, 0, 61, 0, 5, 0, 5, 0, 62, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 63, 0, 5, 0, 5, 0, 64, 0, 5, 0, 5, 0, 64, 0, 5, 0, 5, 0, 5, 0, 5, 0, 64, 0, 65, 0, 66, 0, 66, 0, 67, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 68, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 69, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 8, 0, 9, 0, 8, 0, 9, 0, 5, 0, 0, 0, 8, 0, 9, 0, 0, 0, 0, 0, 5, 0, 27, 0, 27, 0, 27, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 70, 0, 0, 0, 71, 0, 71, 0, 71, 0, 0, 0, 72, 0, 0, 0, 73, 0, 73, 0, 5, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 0, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 74, 0, 75, 0, 75, 0, 75, 0, 5, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 76, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 77, 0, 78, 0, 78, 0, 79, 0, 80, 0, 81, 0, 5, 0, 5, 0, 5, 0, 82, 0, 83, 0, 84, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 85, 0, 86, 0, 87, 0, 5, 0, 88, 0, 89, 0, 0, 0, 8, 0, 9, 0, 90, 0, 8, 0, 9, 0, 5, 0, 39, 0, 39, 0, 39, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 92, 0, 92, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 93, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 94, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 2, 0, 0, 0, 2, 0, 2, 0, 0, 0, 2, 0, 2, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 2, 0, 2, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 2, 0, 2, 0, 2, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 97, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 97, 0, 2, 0, 5, 0, 97, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 97, 0, 97, 0, 2, 0, 97, 0, 97, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 2, 0, 97, 0, 97, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 2, 0, 5, 0, 97, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 97, 0, 97, 0, 0, 0, 0, 0, 97, 0, 97, 0, 2, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 97, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 0, 0, 0, 0, 2, 0, 0, 0, 97, 0, 97, 0, 97, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 97, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 2, 0, 5, 0, 97, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 2, 0, 2, 0, 97, 0, 0, 0, 97, 0, 97, 0, 2, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 2, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 97, 0, 97, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 2, 0, 5, 0, 97, 0, 2, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 97, 0, 97, 0, 0, 0, 0, 0, 97, 0, 97, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 2, 0, 97, 0, 97, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 97, 0, 0, 0, 97, 0, 97, 0, 97, 0, 2, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 97, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 97, 0, 97, 0, 0, 0, 2, 0, 2, 0, 2, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 0, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 2, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 2, 0, 5, 0, 97, 0, 2, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 0, 0, 2, 0, 97, 0, 97, 0, 0, 0, 97, 0, 97, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 5, 0, 5, 0, 2, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 97, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 97, 0, 97, 0, 97, 0, 0, 0, 97, 0, 97, 0, 97, 0, 2, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 2, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 97, 0, 97, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 0, 0, 2, 0, 0, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 2, 0, 2, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 2, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 2, 0, 2, 0, 97, 0, 97, 0, 2, 0, 2, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 97, 0, 97, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 5, 0, 97, 0, 97, 0, 97, 0, 5, 0, 5, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 97, 0, 97, 0, 2, 0, 2, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 2, 0, 5, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 97, 0, 2, 0, 0, 0, 0, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 1, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 2, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 1, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 97, 0, 97, 0, 2, 0, 2, 0, 97, 0, 97, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 2, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 97, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 97, 0, 97, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 97, 0, 2, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 2, 0, 97, 0, 2, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 2, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 2, 0, 97, 0, 97, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 97, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 2, 0, 2, 0, 97, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 97, 0, 2, 0, 2, 0, 97, 0, 97, 0, 97, 0, 2, 0, 97, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 99, 0, 5, 0, 5, 0, 5, 0, 100, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 101, 0, 5, 0, 5, 0, 102, 0, 5, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 0, 0, 0, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 0, 0, 0, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 0, 0, 0, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 0, 0, 0, 0, 5, 0, 103, 0, 5, 0, 103, 0, 5, 0, 103, 0, 5, 0, 103, 0, 0, 0, 104, 0, 0, 0, 104, 0, 0, 0, 104, 0, 0, 0, 104, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 105, 0, 105, 0, 106, 0, 106, 0, 106, 0, 106, 0, 107, 0, 107, 0, 108, 0, 108, 0, 109, 0, 109, 0, 110, 0, 110, 0, 0, 0, 0, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 103, 0, 103, 0, 5, 0, 111, 0, 5, 0, 0, 0, 5, 0, 5, 0, 104, 0, 104, 0, 112, 0, 112, 0, 113, 0, 0, 0, 114, 0, 0, 0, 0, 0, 0, 0, 5, 0, 111, 0, 5, 0, 0, 0, 5, 0, 5, 0, 115, 0, 115, 0, 115, 0, 115, 0, 113, 0, 0, 0, 0, 0, 0, 0, 103, 0, 103, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 104, 0, 104, 0, 116, 0, 116, 0, 0, 0, 0, 0, 0, 0, 0, 0, 103, 0, 103, 0, 5, 0, 5, 0, 5, 0, 87, 0, 5, 0, 5, 0, 104, 0, 104, 0, 117, 0, 117, 0, 90, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 111, 0, 5, 0, 0, 0, 5, 0, 5, 0, 118, 0, 118, 0, 119, 0, 119, 0, 113, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 0, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 92, 0, 92, 0, 92, 0, 92, 0, 2, 0, 92, 0, 92, 0, 92, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 120, 0, 0, 0, 5, 0, 0, 0, 121, 0, 122, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 123, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 124, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 5, 0, 5, 0, 5, 0, 8, 0, 9, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 0, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 0, 0, 8, 0, 9, 0, 129, 0, 130, 0, 131, 0, 132, 0, 133, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 134, 0, 135, 0, 136, 0, 137, 0, 5, 0, 8, 0, 9, 0, 5, 0, 8, 0, 9, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 138, 0, 138, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 9, 0, 8, 0, 9, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 2, 0, 2, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 5, 0, 2, 0, 92, 0, 92, 0, 92, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 0, 0, 5, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 5, 0, 5, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 8, 0, 9, 0, 8, 0, 9, 0, 99, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 5, 0, 0, 0, 0, 0, 8, 0, 9, 0, 56, 0, 5, 0, 0, 0, 8, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 5, 0, 5, 0, 5, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 97, 0, 97, 0, 2, 0, 2, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 97, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 2, 0, 97, 0, 97, 0, 97, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 2, 0, 2, 0, 97, 0, 97, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 97, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 5, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 5, 0, 2, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 97, 0, 97, 0, 2, 0, 97, 0, 97, 0, 2, 0, 97, 0, 97, 0, 0, 0, 97, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str1185 = allocate([ 45, 73, 110, 102, 105, 110, 105, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str3187 = allocate([ 48, 46, 0 ], "i8", ALLOC_STATIC);

__ZN2v88internalL14kCachedPowers8E = allocate([ 1025131999, 0, 0, 0, 3860516611, 0, 0, 0, -1087, 0, -308, 0, 3348809418, 0, 0, 0, 2876309015, 0, 0, 0, -1060, 0, -300, 0, 3200048207, 0, 0, 0, 4286034428, 0, 0, 0, -1034, 0, -292, 0, 1097586188, 0, 0, 0, 3193344495, 0, 0, 0, -1007, 0, -284, 0, 2424306748, 0, 0, 0, 2379227053, 0, 0, 0, -980, 0, -276, 0, 827693699, 0, 0, 0, 3545324584, 0, 0, 0, -954, 0, -268, 0, 2913388981, 0, 0, 0, 2641472655, 0, 0, 0, -927, 0, -260, 0, 602835915, 0, 0, 0, 3936100983, 0, 0, 0, -901, 0, -252, 0, 1081627501, 0, 0, 0, 2932623761, 0, 0, 0, -874, 0, -244, 0, 1572261463, 0, 0, 0, 2184974969, 0, 0, 0, -847, 0, -236, 0, 1308317239, 0, 0, 0, 3255866422, 0, 0, 0, -821, 0, -228, 0, 944281679, 0, 0, 0, 2425809519, 0, 0, 0, -794, 0, -220, 0, 629291719, 0, 0, 0, 3614737867, 0, 0, 0, -768, 0, -212, 0, 2545915892, 0, 0, 0, 2693189581, 0, 0, 0, -741, 0, -204, 0, 388672741, 0, 0, 0, 4013165208, 0, 0, 0, -715, 0, -196, 0, 708162190, 0, 0, 0, 2990041083, 0, 0, 0, -688, 0, -188, 0, 3536207675, 0, 0, 0, 2227754207, 0, 0, 0, -661, 0, -180, 0, 450088378, 0, 0, 0, 3319612455, 0, 0, 0, -635, 0, -172, 0, 3139815830, 0, 0, 0, 2473304014, 0, 0, 0, -608, 0, -164, 0, 2103616900, 0, 0, 0, 3685510180, 0, 0, 0, -582, 0, -156, 0, 224385782, 0, 0, 0, 2745919064, 0, 0, 0, -555, 0, -148, 0, 3737383206, 0, 0, 0, 4091738259, 0, 0, 0, -529, 0, -140, 0, 2868871352, 0, 0, 0, 3048582568, 0, 0, 0, -502, 0, -132, 0, 1820084875, 0, 0, 0, 2271371013, 0, 0, 0, -475, 0, -124, 0, 885076051, 0, 0, 0, 3384606560, 0, 0, 0, -449, 0, -116, 0, 2444895829, 0, 0, 0, 2521728396, 0, 0, 0, -422, 0, -108, 0, 1881767613, 0, 0, 0, 3757668132, 0, 0, 0, -396, 0, -100, 0, 3102062735, 0, 0, 0, 2799680927, 0, 0, 0, -369, 0, -92, 0, 2289335700, 0, 0, 0, 4171849679, 0, 0, 0, -343, 0, -84, 0, 2410191823, 0, 0, 0, 3108270227, 0, 0, 0, -316, 0, -76, 0, 3205436779, 0, 0, 0, 2315841784, 0, 0, 0, -289, 0, -68, 0, 1697722806, 0, 0, 0, 3450873173, 0, 0, 0, -263, 0, -60, 0, 3497754540, 0, 0, 0, 2571100870, 0, 0, 0, -236, 0, -52, 0, 707476230, 0, 0, 0, 3831238852, 0, 0, 0, -210, 0, -44, 0, 1769181907, 0, 0, 0, 2854495385, 0, 0, 0, -183, 0, -36, 0, 2197867022, 0, 0, 0, 4253529586, 0, 0, 0, -157, 0, -28, 0, 2450594539, 0, 0, 0, 3169126500, 0, 0, 0, -130, 0, -20, 0, 1867548876, 0, 0, 0, 2361183241, 0, 0, 0, -103, 0, -12, 0, 3793315116, 0, 0, 0, 3518437208, 0, 0, 0, -77, 0, -4, 0, 0, 0, 0, 0, 262144e4, 0, 0, 0, -50, 0, 4, 0, 0, 0, 0, 0, 390625e4, 0, 0, 0, -24, 0, 12, 0, 2892103680, 0, 0, 0, 2910383045, 0, 0, 0, 3, 0, 20, 0, 4170451332, 0, 0, 0, 2168404344, 0, 0, 0, 30, 0, 28, 0, 3372684723, 0, 0, 0, 3231174267, 0, 0, 0, 56, 0, 36, 0, 2078956656, 0, 0, 0, 2407412430, 0, 0, 0, 83, 0, 44, 0, 2884206696, 0, 0, 0, 3587324068, 0, 0, 0, 109, 0, 52, 0, 395977285, 0, 0, 0, 2672764710, 0, 0, 0, 136, 0, 60, 0, 3569679143, 0, 0, 0, 3982729777, 0, 0, 0, 162, 0, 68, 0, 2361961896, 0, 0, 0, 2967364920, 0, 0, 0, 189, 0, 76, 0, 447440347, 0, 0, 0, 2210859150, 0, 0, 0, 216, 0, 84, 0, 1114709402, 0, 0, 0, 3294436857, 0, 0, 0, 242, 0, 92, 0, 2786846552, 0, 0, 0, 2454546732, 0, 0, 0, 269, 0, 100, 0, 443583978, 0, 0, 0, 3657559652, 0, 0, 0, 295, 0, 108, 0, 2599384906, 0, 0, 0, 2725094297, 0, 0, 0, 322, 0, 116, 0, 3028118405, 0, 0, 0, 4060706939, 0, 0, 0, 348, 0, 124, 0, 2044532855, 0, 0, 0, 3025462433, 0, 0, 0, 375, 0, 132, 0, 1536935362, 0, 0, 0, 2254145170, 0, 0, 0, 402, 0, 140, 0, 3365297469, 0, 0, 0, 3358938053, 0, 0, 0, 428, 0, 148, 0, 4204241075, 0, 0, 0, 2502603868, 0, 0, 0, 455, 0, 156, 0, 2577424355, 0, 0, 0, 3729170365, 0, 0, 0, 481, 0, 164, 0, 3677981733, 0, 0, 0, 2778448436, 0, 0, 0, 508, 0, 172, 0, 2744688476, 0, 0, 0, 4140210802, 0, 0, 0, 534, 0, 180, 0, 1424604878, 0, 0, 0, 3084697427, 0, 0, 0, 561, 0, 188, 0, 4062331362, 0, 0, 0, 2298278679, 0, 0, 0, 588, 0, 196, 0, 3546052773, 0, 0, 0, 3424702107, 0, 0, 0, 614, 0, 204, 0, 2065781727, 0, 0, 0, 2551601907, 0, 0, 0, 641, 0, 212, 0, 2535403578, 0, 0, 0, 3802183132, 0, 0, 0, 667, 0, 220, 0, 1558426518, 0, 0, 0, 2832847187, 0, 0, 0, 694, 0, 228, 0, 2762425404, 0, 0, 0, 4221271257, 0, 0, 0, 720, 0, 236, 0, 2812560400, 0, 0, 0, 3145092172, 0, 0, 0, 747, 0, 244, 0, 3057687578, 0, 0, 0, 2343276271, 0, 0, 0, 774, 0, 252, 0, 2790753324, 0, 0, 0, 3491753744, 0, 0, 0, 800, 0, 260, 0, 3918606633, 0, 0, 0, 2601559269, 0, 0, 0, 827, 0, 268, 0, 2711358621, 0, 0, 0, 3876625403, 0, 0, 0, 853, 0, 276, 0, 1648096297, 0, 0, 0, 2888311001, 0, 0, 0, 880, 0, 284, 0, 2057817989, 0, 0, 0, 2151959390, 0, 0, 0, 907, 0, 292, 0, 61660461, 0, 0, 0, 3206669376, 0, 0, 0, 933, 0, 300, 0, 1581580175, 0, 0, 0, 2389154863, 0, 0, 0, 960, 0, 308, 0, 2626467905, 0, 0, 0, 3560118173, 0, 0, 0, 986, 0, 316, 0, 3034782633, 0, 0, 0, 2652494738, 0, 0, 0, 1013, 0, 324, 0, 3135207385, 0, 0, 0, 3952525166, 0, 0, 0, 1039, 0, 332, 0, 2616258155, 0, 0, 0, 2944860731, 0, 0, 0, 1066, 0, 340, 0 ], [ "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

_JSVAL_NULL = allocate(8, [ "i64", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

_JSVAL_ZERO = allocate(8, [ "i64", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

_JSVAL_ONE = allocate(8, [ "i64", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

_JSVAL_FALSE = allocate(8, [ "i64", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

_JSVAL_TRUE = allocate(8, [ "i64", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

_JSVAL_VOID = allocate(8, [ "i64", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

__ZL22js_NewRuntimeWasCalled_b = allocate(1, "i1", ALLOC_STATIC);

STRING_TABLE.__str21214 = allocate([ 74, 97, 118, 97, 83, 99, 114, 105, 112, 116, 45, 67, 32, 49, 46, 56, 46, 53, 43, 32, 50, 48, 49, 49, 45, 48, 52, 45, 49, 54, 0 ], "i8", ALLOC_STATIC);

_js_dummy_class = allocate([ 0, 0, 0, 0, 292608, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

__ZL20standard_class_atoms = allocate([ 448, 0, 0, 0, 80, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 450, 0, 0, 0, 76, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 452, 0, 0, 0, 84, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 454, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 456, 0, 0, 0, 96, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 458, 0, 0, 0, 100, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 460, 0, 0, 0, 104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 462, 0, 0, 0, 108, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 464, 0, 0, 0, 128, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 466, 0, 0, 0, 112, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 468, 0, 0, 0, 116, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 470, 0, 0, 0, 120, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 472, 0, 0, 0, 124, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 474, 0, 0, 0, 164, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 476, 0, 0, 0, 92, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 478, 0, 0, 0, 168, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 480, 0, 0, 0, 216, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

__ZL20standard_class_names = allocate([ 450, 0, 0, 0, 264, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 460, 0, 0, 0, 432, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 460, 0, 0, 0, 428, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 460, 0, 0, 0, 588, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 460, 0, 0, 0, 584, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 460, 0, 0, 0, 608, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 460, 0, 0, 0, 612, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 462, 0, 0, 0, 576, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 462, 0, 0, 0, 620, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 462, 0, 0, 0, 552, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 462, 0, 0, 0, 568, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 462, 0, 0, 0, 556, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 462, 0, 0, 0, 572, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 462, 0, 0, 0, 624, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 464, 0, 0, 0, 128, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 464, 0, 0, 0, 132, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 464, 0, 0, 0, 136, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 464, 0, 0, 0, 140, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 464, 0, 0, 0, 144, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 464, 0, 0, 0, 148, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 464, 0, 0, 0, 152, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 464, 0, 0, 0, 156, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 468, 0, 0, 0, 548, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 468, 0, 0, 0, 596, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 474, 0, 0, 0, 160, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 478, 0, 0, 0, 168, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 478, 0, 0, 0, 172, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 478, 0, 0, 0, 176, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 478, 0, 0, 0, 180, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 478, 0, 0, 0, 184, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 478, 0, 0, 0, 188, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 478, 0, 0, 0, 192, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 478, 0, 0, 0, 196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 478, 0, 0, 0, 200, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 478, 0, 0, 0, 204, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 482, 0, 0, 0, 208, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

__ZL22object_prototype_names = allocate([ 450, 0, 0, 0, 344, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 450, 0, 0, 0, 372, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 450, 0, 0, 0, 376, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 450, 0, 0, 0, 368, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 450, 0, 0, 0, 384, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 450, 0, 0, 0, 632, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 450, 0, 0, 0, 628, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 450, 0, 0, 0, 580, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 450, 0, 0, 0, 592, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 450, 0, 0, 0, 616, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 450, 0, 0, 0, 560, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 450, 0, 0, 0, 564, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 450, 0, 0, 0, 600, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 450, 0, 0, 0, 604, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str23216 = allocate([ 80, 114, 111, 112, 101, 114, 116, 121, 73, 116, 101, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

__ZL15prop_iter_class = allocate([ 0, 0, 0, 0, 257, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 484, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 486, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str26219 = allocate([ 78, 111, 32, 115, 117, 99, 104, 32, 102, 105, 108, 101, 32, 111, 114, 32, 100, 105, 114, 101, 99, 116, 111, 114, 121, 0 ], "i8", ALLOC_STATIC);

_js_CStringsAreUTF8_b = allocate(1, "i1", ALLOC_STATIC);

STRING_TABLE.__str29222 = allocate([ 74, 83, 69, 120, 99, 101, 112, 116, 105, 111, 110, 83, 116, 97, 116, 101, 46, 101, 120, 99, 101, 112, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

__ZZN2js6RegExp7compileEP9JSContextPNS_11TokenStreamEE6prefix = allocate([ 94, 0, 40, 0, 63, 0, 58, 0 ], [ "i16", 0, "i16", 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZZN2js6RegExp7compileEP9JSContextPNS_11TokenStreamEE7postfix = allocate([ 41, 0 ], [ "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str313 = allocate([ 65, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

__ZN2js10ArrayClassE = allocate([ 0, 0, 0, 0, 50855937, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 488, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 490, 0, 0, 0, 490, 0, 0, 0, 492, 0, 0, 0, 494, 0, 0, 0, 496, 0, 0, 0, 496, 0, 0, 0, 498, 0, 0, 0, 500, 0, 0, 0, 502, 0, 0, 0, 504, 0, 0, 0, 506, 0, 0, 0, 508, 0, 0, 0, 510, 0, 0, 0, 510, 0, 0, 0, 512, 0, 0, 0, 514, 0, 0, 0, 516, 0, 0, 0, 516, 0, 0, 0, 518, 0, 0, 0, 520, 0, 0, 0, 522, 0, 0, 0, 522, 0, 0, 0, 524, 0, 0, 0, 526, 0, 0, 0, 528, 0, 0, 0, 528, 0, 0, 0, 530, 0, 0, 0, 532, 0, 0, 0, 0, 0, 0, 0, 534, 0, 0, 0, 536, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZN2js14SlowArrayClassE = allocate([ 0, 0, 0, 0, 50331649, 0, 0, 0, 538, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str1318 = allocate([ 106, 111, 105, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2319 = allocate([ 114, 101, 118, 101, 114, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str3320 = allocate([ 115, 111, 114, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str4321 = allocate([ 112, 117, 115, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str5322 = allocate([ 112, 111, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str6323 = allocate([ 115, 104, 105, 102, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str7324 = allocate([ 117, 110, 115, 104, 105, 102, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str8325 = allocate([ 115, 112, 108, 105, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str13330 = allocate([ 102, 111, 114, 69, 97, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str14331 = allocate([ 109, 97, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str15332 = allocate([ 114, 101, 100, 117, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str16333 = allocate([ 114, 101, 100, 117, 99, 101, 82, 105, 103, 104, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str18335 = allocate([ 115, 111, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str19336 = allocate([ 101, 118, 101, 114, 121, 0 ], "i8", ALLOC_STATIC);

__ZL13array_methods = allocate([ 0, 0, 0, 0, 540, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 542, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 544, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 546, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 548, 0, 0, 0, 0, 0, 4104, 0, 0, 0, 0, 0, 138, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 130, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 132, 0, 0, 0, 0, 0, 4104, 0, 0, 0, 0, 0, 550, 0, 0, 0, 0, 0, 4104, 0, 0, 0, 0, 0, 552, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 554, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 556, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 558, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 560, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 562, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 564, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 566, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 568, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 570, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 572, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 574, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 576, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str20337 = allocate([ 105, 115, 65, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

__ZL20array_static_methods = allocate([ 0, 0, 0, 0, 578, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZZL18array_toString_subP9JSContextP8JSObjectiP8JSStringPN2JS5ValueEE5comma = allocate([ 44 ], [ "i16", 0, 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE._js_Null_str = allocate([ 78, 117, 108, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_JSON_str = allocate([ 74, 83, 79, 78, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Date_str = allocate([ 68, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Math_str = allocate([ 77, 97, 116, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Number_str = allocate([ 78, 117, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_String_str = allocate([ 83, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_RegExp_str = allocate([ 82, 101, 103, 69, 120, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_XML_str = allocate([ 88, 77, 76, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_InternalError_str = allocate([ 73, 110, 116, 101, 114, 110, 97, 108, 69, 114, 114, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_EvalError_str = allocate([ 69, 118, 97, 108, 69, 114, 114, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_RangeError_str = allocate([ 82, 97, 110, 103, 101, 69, 114, 114, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_ReferenceError_str = allocate([ 82, 101, 102, 101, 114, 101, 110, 99, 101, 69, 114, 114, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_SyntaxError_str = allocate([ 83, 121, 110, 116, 97, 120, 69, 114, 114, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_TypeError_str = allocate([ 84, 121, 112, 101, 69, 114, 114, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_URIError_str = allocate([ 85, 82, 73, 69, 114, 114, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_StopIteration_str = allocate([ 83, 116, 111, 112, 73, 116, 101, 114, 97, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_AnyName_str = allocate([ 65, 110, 121, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str6436 = allocate([ 91, 111, 98, 106, 101, 99, 116, 32, 78, 117, 108, 108, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str7437 = allocate([ 91, 111, 98, 106, 101, 99, 116, 32, 85, 110, 100, 101, 102, 105, 110, 101, 100, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str8438 = allocate([ 40, 118, 111, 105, 100, 32, 48, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str9439 = allocate([ 117, 115, 101, 32, 115, 116, 114, 105, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str14444 = allocate([ 98, 117, 105, 108, 100, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str15445 = allocate([ 64, 109, 111, 122, 105, 108, 108, 97, 46, 111, 114, 103, 47, 106, 115, 47, 102, 117, 110, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str18448 = allocate([ 103, 101, 116, 80, 114, 111, 112, 101, 114, 116, 121, 68, 101, 115, 99, 114, 105, 112, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str22452 = allocate([ 101, 110, 117, 109, 101, 114, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str23453 = allocate([ 102, 105, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str25455 = allocate([ 104, 97, 115, 79, 119, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str27457 = allocate([ 105, 116, 101, 114, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str30460 = allocate([ 114, 101, 116, 117, 114, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str31461 = allocate([ 116, 104, 114, 111, 119, 0 ], "i8", ALLOC_STATIC);

_js_common_atom_names = allocate(524, "*", ALLOC_STATIC);

STRING_TABLE._js_anonymous_str = allocate([ 97, 110, 111, 110, 121, 109, 111, 117, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_arity_str = allocate([ 97, 114, 105, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_BYTES_PER_ELEMENT_str = allocate([ 66, 89, 84, 69, 83, 95, 80, 69, 82, 95, 69, 76, 69, 77, 69, 78, 84, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_caller_str = allocate([ 99, 97, 108, 108, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_class_prototype_str = allocate([ 112, 114, 111, 116, 111, 116, 121, 112, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_constructor_str = allocate([ 99, 111, 110, 115, 116, 114, 117, 99, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_fileName_str = allocate([ 102, 105, 108, 101, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_iterator_str = allocate([ 95, 95, 105, 116, 101, 114, 97, 116, 111, 114, 95, 95, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_lineNumber_str = allocate([ 108, 105, 110, 101, 78, 117, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_message_str = allocate([ 109, 101, 115, 115, 97, 103, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_next_str = allocate([ 110, 101, 120, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_noSuchMethod_str = allocate([ 95, 95, 110, 111, 83, 117, 99, 104, 77, 101, 116, 104, 111, 100, 95, 95, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_proto_str = allocate([ 95, 95, 112, 114, 111, 116, 111, 95, 95, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_stack_str = allocate([ 115, 116, 97, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_toGMTString_str = allocate([ 116, 111, 71, 77, 84, 83, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_toLocaleString_str = allocate([ 116, 111, 76, 111, 99, 97, 108, 101, 83, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_toSource_str = allocate([ 116, 111, 83, 111, 117, 114, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_toString_str = allocate([ 116, 111, 83, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_valueOf_str = allocate([ 118, 97, 108, 117, 101, 79, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_toJSON_str = allocate([ 116, 111, 74, 83, 79, 78, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_enumerable_str = allocate([ 101, 110, 117, 109, 101, 114, 97, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_configurable_str = allocate([ 99, 111, 110, 102, 105, 103, 117, 114, 97, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_writable_str = allocate([ 119, 114, 105, 116, 97, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_qualifier_str = allocate([ 58, 58, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_starQualifier_str = allocate([ 42, 58, 58, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_close_str = allocate([ 99, 108, 111, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_send_str = allocate([ 115, 101, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str524 = allocate([ 66, 111, 111, 108, 101, 97, 110, 0 ], "i8", ALLOC_STATIC);

__ZN2js12BooleanClassE = allocate([ 0, 0, 0, 0, 67109120, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZL15boolean_methods = allocate([ 0, 0, 0, 0, 580, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 582, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 584, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str3529 = allocate([ 40, 110, 101, 119, 32, 66, 111, 111, 108, 101, 97, 110, 40, 37, 115, 41, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str573 = allocate([ 116, 114, 117, 110, 99, 97, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1574 = allocate([ 111, 98, 106, 101, 99, 116, 32, 103, 114, 97, 112, 104, 32, 116, 111, 32, 115, 101, 114, 105, 97, 108, 105, 122, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2575 = allocate([ 117, 110, 114, 101, 99, 111, 103, 110, 105, 122, 101, 100, 32, 78, 97, 78, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str3576 = allocate([ 115, 116, 114, 105, 110, 103, 32, 108, 101, 110, 103, 116, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str4577 = allocate([ 100, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str5578 = allocate([ 114, 101, 103, 101, 120, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str6579 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 105, 110, 112, 117, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str7580 = allocate([ 117, 110, 115, 117, 112, 112, 111, 114, 116, 101, 100, 32, 116, 121, 112, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2647 = allocate([ 79, 117, 116, 32, 111, 102, 32, 109, 101, 109, 111, 114, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str3648 = allocate([ 78, 111, 32, 101, 114, 114, 111, 114, 32, 109, 101, 115, 115, 97, 103, 101, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 32, 102, 111, 114, 32, 101, 114, 114, 111, 114, 32, 110, 117, 109, 98, 101, 114, 32, 37, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str7652 = allocate([ 123, 48, 125, 32, 105, 115, 32, 110, 111, 116, 32, 100, 101, 102, 105, 110, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str8653 = allocate([ 110, 111, 116, 104, 105, 110, 103, 32, 97, 99, 116, 105, 118, 101, 32, 111, 110, 32, 99, 111, 110, 116, 101, 120, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str9654 = allocate([ 123, 48, 125, 32, 114, 101, 113, 117, 105, 114, 101, 115, 32, 109, 111, 114, 101, 32, 116, 104, 97, 110, 32, 123, 49, 125, 32, 97, 114, 103, 117, 109, 101, 110, 116, 123, 50, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str10655 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 102, 111, 114, 109, 97, 116, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str11656 = allocate([ 117, 110, 107, 110, 111, 119, 110, 32, 116, 121, 112, 101, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str12657 = allocate([ 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 115, 105, 122, 101, 32, 111, 118, 101, 114, 102, 108, 111, 119, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str13658 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 104, 101, 120, 97, 100, 101, 99, 105, 109, 97, 108, 32, 100, 105, 103, 105, 116, 115, 32, 97, 102, 116, 101, 114, 32, 39, 48, 120, 39, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str14659 = allocate([ 123, 48, 125, 46, 112, 114, 111, 116, 111, 116, 121, 112, 101, 46, 123, 49, 125, 32, 99, 97, 108, 108, 101, 100, 32, 111, 110, 32, 105, 110, 99, 111, 109, 112, 97, 116, 105, 98, 108, 101, 32, 123, 50, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str15660 = allocate([ 123, 48, 125, 32, 104, 97, 115, 32, 110, 111, 32, 99, 111, 110, 115, 116, 114, 117, 99, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str16661 = allocate([ 99, 97, 110, 39, 116, 32, 97, 108, 105, 97, 115, 32, 123, 48, 125, 32, 116, 111, 32, 123, 49, 125, 32, 105, 110, 32, 99, 108, 97, 115, 115, 32, 123, 50, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str17662 = allocate([ 123, 48, 125, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 115, 99, 114, 105, 112, 116, 101, 100, 32, 102, 117, 110, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str18663 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 65, 114, 114, 97, 121, 46, 112, 114, 111, 116, 111, 116, 121, 112, 101, 46, 115, 111, 114, 116, 32, 97, 114, 103, 117, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str19664 = allocate([ 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 110, 111, 32, 105, 110, 100, 101, 120, 32, 102, 111, 114, 32, 97, 116, 111, 109, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str20665 = allocate([ 116, 111, 111, 32, 109, 97, 110, 121, 32, 108, 105, 116, 101, 114, 97, 108, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str21666 = allocate([ 99, 97, 110, 39, 116, 32, 119, 97, 116, 99, 104, 32, 110, 111, 110, 45, 110, 97, 116, 105, 118, 101, 32, 111, 98, 106, 101, 99, 116, 115, 32, 111, 102, 32, 99, 108, 97, 115, 115, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str22667 = allocate([ 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 32, 99, 111, 109, 112, 105, 108, 105, 110, 103, 32, 123, 48, 125, 58, 32, 115, 116, 97, 99, 107, 32, 117, 110, 100, 101, 114, 102, 108, 111, 119, 32, 97, 116, 32, 112, 99, 32, 123, 49, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str23668 = allocate([ 123, 48, 125, 32, 116, 111, 111, 32, 108, 97, 114, 103, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str24669 = allocate([ 111, 117, 116, 32, 111, 102, 32, 108, 111, 99, 97, 108, 32, 114, 111, 111, 116, 32, 115, 112, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str25670 = allocate([ 123, 48, 125, 32, 105, 115, 32, 114, 101, 97, 100, 45, 111, 110, 108, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str26671 = allocate([ 109, 97, 108, 102, 111, 114, 109, 101, 100, 32, 102, 111, 114, 109, 97, 108, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str27672 = allocate([ 112, 114, 111, 112, 101, 114, 116, 121, 32, 123, 48, 125, 32, 105, 115, 32, 110, 111, 110, 45, 99, 111, 110, 102, 105, 103, 117, 114, 97, 98, 108, 101, 32, 97, 110, 100, 32, 99, 97, 110, 39, 116, 32, 98, 101, 32, 100, 101, 108, 101, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str28673 = allocate([ 123, 48, 125, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 102, 117, 110, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str29674 = allocate([ 123, 48, 125, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 99, 111, 110, 115, 116, 114, 117, 99, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str30675 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 100, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str31676 = allocate([ 123, 48, 125, 32, 110, 101, 115, 116, 101, 100, 32, 116, 111, 111, 32, 100, 101, 101, 112, 108, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str32677 = allocate([ 116, 111, 111, 32, 109, 117, 99, 104, 32, 114, 101, 99, 117, 114, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str33678 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 39, 105, 110, 39, 32, 111, 112, 101, 114, 97, 110, 100, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str34679 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 110, 101, 119, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 114, 101, 115, 117, 108, 116, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str35680 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 115, 104, 97, 114, 112, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 35, 123, 48, 125, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str36681 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 115, 104, 97, 114, 112, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 117, 115, 101, 32, 35, 123, 48, 125, 35, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str37682 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 39, 105, 110, 115, 116, 97, 110, 99, 101, 111, 102, 39, 32, 111, 112, 101, 114, 97, 110, 100, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str38683 = allocate([ 117, 110, 105, 109, 112, 108, 101, 109, 101, 110, 116, 101, 100, 32, 74, 97, 118, 97, 83, 99, 114, 105, 112, 116, 32, 98, 121, 116, 101, 99, 111, 100, 101, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str39684 = allocate([ 114, 97, 100, 105, 120, 32, 109, 117, 115, 116, 32, 98, 101, 32, 97, 110, 32, 105, 110, 116, 101, 103, 101, 114, 32, 97, 116, 32, 108, 101, 97, 115, 116, 32, 50, 32, 97, 110, 100, 32, 110, 111, 32, 103, 114, 101, 97, 116, 101, 114, 32, 116, 104, 97, 110, 32, 51, 54, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str40685 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 40, 32, 98, 101, 102, 111, 114, 101, 32, 108, 101, 116, 32, 104, 101, 97, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str41686 = allocate([ 99, 97, 110, 39, 116, 32, 99, 111, 110, 118, 101, 114, 116, 32, 123, 48, 125, 32, 116, 111, 32, 97, 110, 32, 105, 110, 116, 101, 103, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str42687 = allocate([ 99, 121, 99, 108, 105, 99, 32, 123, 48, 125, 32, 118, 97, 108, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str43688 = allocate([ 99, 97, 110, 39, 116, 32, 99, 111, 109, 112, 105, 108, 101, 32, 111, 118, 101, 114, 32, 97, 32, 115, 99, 114, 105, 112, 116, 32, 116, 104, 97, 116, 32, 105, 115, 32, 99, 117, 114, 114, 101, 110, 116, 108, 121, 32, 101, 120, 101, 99, 117, 116, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str44689 = allocate([ 99, 97, 110, 39, 116, 32, 99, 111, 110, 118, 101, 114, 116, 32, 123, 48, 125, 32, 116, 111, 32, 123, 49, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str45690 = allocate([ 123, 48, 125, 32, 104, 97, 115, 32, 110, 111, 32, 112, 114, 111, 112, 101, 114, 116, 105, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str46691 = allocate([ 99, 97, 110, 39, 116, 32, 102, 105, 110, 100, 32, 99, 108, 97, 115, 115, 32, 105, 100, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str47692 = allocate([ 99, 97, 110, 39, 116, 32, 88, 68, 82, 32, 99, 108, 97, 115, 115, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str48693 = allocate([ 98, 121, 116, 101, 99, 111, 100, 101, 32, 123, 48, 125, 32, 116, 111, 111, 32, 108, 97, 114, 103, 101, 32, 40, 108, 105, 109, 105, 116, 32, 123, 49, 125, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str49694 = allocate([ 117, 110, 107, 110, 111, 119, 110, 32, 98, 121, 116, 101, 99, 111, 100, 101, 32, 102, 111, 114, 109, 97, 116, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str50695 = allocate([ 116, 111, 111, 32, 109, 97, 110, 121, 32, 99, 111, 110, 115, 116, 114, 117, 99, 116, 111, 114, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str51696 = allocate([ 116, 111, 111, 32, 109, 97, 110, 121, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str52697 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 113, 117, 97, 110, 116, 105, 102, 105, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str53698 = allocate([ 111, 118, 101, 114, 108, 97, 114, 103, 101, 32, 109, 105, 110, 105, 109, 117, 109, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str54699 = allocate([ 111, 118, 101, 114, 108, 97, 114, 103, 101, 32, 109, 97, 120, 105, 109, 117, 109, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str55700 = allocate([ 109, 97, 120, 105, 109, 117, 109, 32, 123, 48, 125, 32, 108, 101, 115, 115, 32, 116, 104, 97, 110, 32, 109, 105, 110, 105, 109, 117, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str56701 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 61, 32, 105, 110, 32, 100, 101, 115, 116, 114, 117, 99, 116, 117, 114, 105, 110, 103, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str57702 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 100, 101, 115, 116, 114, 117, 99, 116, 117, 114, 105, 110, 103, 32, 97, 115, 115, 105, 103, 110, 109, 101, 110, 116, 32, 111, 112, 101, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str58703 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 41, 32, 97, 102, 116, 101, 114, 32, 108, 101, 116, 32, 104, 101, 97, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str59704 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 125, 32, 97, 102, 116, 101, 114, 32, 108, 101, 116, 32, 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str60705 = allocate([ 117, 110, 116, 101, 114, 109, 105, 110, 97, 116, 101, 100, 32, 112, 97, 114, 101, 110, 116, 104, 101, 116, 105, 99, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str61706 = allocate([ 117, 110, 116, 101, 114, 109, 105, 110, 97, 116, 101, 100, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 99, 108, 97, 115, 115, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str62707 = allocate([ 116, 114, 97, 105, 108, 105, 110, 103, 32, 92, 32, 105, 110, 32, 114, 101, 103, 117, 108, 97, 114, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str63708 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 114, 97, 110, 103, 101, 32, 105, 110, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 99, 108, 97, 115, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str64709 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 114, 101, 103, 117, 108, 97, 114, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 102, 108, 97, 103, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str65710 = allocate([ 110, 111, 32, 105, 110, 112, 117, 116, 32, 102, 111, 114, 32, 47, 123, 48, 125, 47, 123, 49, 125, 123, 50, 125, 123, 51, 125, 123, 52, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str67712 = allocate([ 97, 114, 103, 117, 109, 101, 110, 116, 115, 32, 97, 114, 114, 97, 121, 32, 112, 97, 115, 115, 101, 100, 32, 116, 111, 32, 70, 117, 110, 99, 116, 105, 111, 110, 46, 112, 114, 111, 116, 111, 116, 121, 112, 101, 46, 97, 112, 112, 108, 121, 32, 105, 115, 32, 116, 111, 111, 32, 108, 97, 114, 103, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str68713 = allocate([ 117, 110, 109, 97, 116, 99, 104, 101, 100, 32, 41, 32, 105, 110, 32, 114, 101, 103, 117, 108, 97, 114, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str70715 = allocate([ 105, 108, 108, 101, 103, 97, 108, 32, 115, 101, 101, 107, 32, 98, 101, 121, 111, 110, 100, 32, 115, 116, 97, 114, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str71716 = allocate([ 105, 108, 108, 101, 103, 97, 108, 32, 115, 101, 101, 107, 32, 98, 101, 121, 111, 110, 100, 32, 101, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str72717 = allocate([ 105, 108, 108, 101, 103, 97, 108, 32, 101, 110, 100, 45, 98, 97, 115, 101, 100, 32, 115, 101, 101, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str73718 = allocate([ 117, 110, 107, 110, 111, 119, 110, 32, 115, 101, 101, 107, 32, 119, 104, 101, 110, 99, 101, 58, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str74719 = allocate([ 98, 97, 100, 32, 115, 99, 114, 105, 112, 116, 32, 88, 68, 82, 32, 109, 97, 103, 105, 99, 32, 110, 117, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str75720 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 40, 32, 98, 101, 102, 111, 114, 101, 32, 102, 111, 114, 109, 97, 108, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str76721 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 102, 111, 114, 109, 97, 108, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str77722 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 41, 32, 97, 102, 116, 101, 114, 32, 102, 111, 114, 109, 97, 108, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str78723 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 123, 32, 98, 101, 102, 111, 114, 101, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 98, 111, 100, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str79724 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 125, 32, 97, 102, 116, 101, 114, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 98, 111, 100, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str80725 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 40, 32, 98, 101, 102, 111, 114, 101, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str81726 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 41, 32, 97, 102, 116, 101, 114, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str82727 = allocate([ 100, 117, 112, 108, 105, 99, 97, 116, 101, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 105, 115, 32, 109, 105, 120, 101, 100, 32, 119, 105, 116, 104, 32, 100, 101, 115, 116, 114, 117, 99, 116, 117, 114, 105, 110, 103, 32, 112, 97, 116, 116, 101, 114, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str83728 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 110, 97, 109, 101, 32, 97, 102, 116, 101, 114, 32, 46, 32, 111, 112, 101, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str84729 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 93, 32, 105, 110, 32, 105, 110, 100, 101, 120, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str85730 = allocate([ 88, 77, 76, 32, 99, 97, 110, 39, 116, 32, 98, 101, 32, 116, 104, 101, 32, 119, 104, 111, 108, 101, 32, 112, 114, 111, 103, 114, 97, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str86731 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 40, 32, 98, 101, 102, 111, 114, 101, 32, 115, 119, 105, 116, 99, 104, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str87732 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 41, 32, 97, 102, 116, 101, 114, 32, 115, 119, 105, 116, 99, 104, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str88733 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 123, 32, 98, 101, 102, 111, 114, 101, 32, 115, 119, 105, 116, 99, 104, 32, 98, 111, 100, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str89734 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 58, 32, 97, 102, 116, 101, 114, 32, 99, 97, 115, 101, 32, 108, 97, 98, 101, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str90735 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 119, 104, 105, 108, 101, 32, 97, 102, 116, 101, 114, 32, 100, 111, 45, 108, 111, 111, 112, 32, 98, 111, 100, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str91736 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 40, 32, 97, 102, 116, 101, 114, 32, 102, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str92737 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 59, 32, 97, 102, 116, 101, 114, 32, 102, 111, 114, 45, 108, 111, 111, 112, 32, 105, 110, 105, 116, 105, 97, 108, 105, 122, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str93738 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 59, 32, 97, 102, 116, 101, 114, 32, 102, 111, 114, 45, 108, 111, 111, 112, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str94739 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 41, 32, 97, 102, 116, 101, 114, 32, 102, 111, 114, 45, 108, 111, 111, 112, 32, 99, 111, 110, 116, 114, 111, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str95740 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 123, 32, 98, 101, 102, 111, 114, 101, 32, 116, 114, 121, 32, 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str96741 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 125, 32, 97, 102, 116, 101, 114, 32, 116, 114, 121, 32, 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str97742 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 40, 32, 98, 101, 102, 111, 114, 101, 32, 99, 97, 116, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str98743 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 105, 100, 101, 110, 116, 105, 102, 105, 101, 114, 32, 105, 110, 32, 99, 97, 116, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str99744 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 41, 32, 97, 102, 116, 101, 114, 32, 99, 97, 116, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str100745 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 123, 32, 98, 101, 102, 111, 114, 101, 32, 99, 97, 116, 99, 104, 32, 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str101746 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 125, 32, 97, 102, 116, 101, 114, 32, 99, 97, 116, 99, 104, 32, 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str102747 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 123, 32, 98, 101, 102, 111, 114, 101, 32, 102, 105, 110, 97, 108, 108, 121, 32, 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str103748 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 125, 32, 97, 102, 116, 101, 114, 32, 102, 105, 110, 97, 108, 108, 121, 32, 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str104749 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 99, 97, 116, 99, 104, 32, 111, 114, 32, 102, 105, 110, 97, 108, 108, 121, 32, 97, 102, 116, 101, 114, 32, 116, 114, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str105750 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 40, 32, 98, 101, 102, 111, 114, 101, 32, 119, 105, 116, 104, 45, 115, 116, 97, 116, 101, 109, 101, 110, 116, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str106751 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 41, 32, 97, 102, 116, 101, 114, 32, 119, 105, 116, 104, 45, 115, 116, 97, 116, 101, 109, 101, 110, 116, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str107752 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 125, 32, 105, 110, 32, 99, 111, 109, 112, 111, 117, 110, 100, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str108753 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 110, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str109754 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 58, 32, 105, 110, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 97, 108, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str110755 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 41, 32, 97, 102, 116, 101, 114, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 108, 105, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str111756 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 93, 32, 97, 102, 116, 101, 114, 32, 101, 108, 101, 109, 101, 110, 116, 32, 108, 105, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str112757 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 58, 32, 97, 102, 116, 101, 114, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 105, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str113758 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 125, 32, 97, 102, 116, 101, 114, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 108, 105, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str114759 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 41, 32, 105, 110, 32, 112, 97, 114, 101, 110, 116, 104, 101, 116, 105, 99, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str115760 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 59, 32, 98, 101, 102, 111, 114, 101, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str116761 = allocate([ 102, 117, 110, 99, 116, 105, 111, 110, 32, 123, 48, 125, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 97, 108, 119, 97, 121, 115, 32, 114, 101, 116, 117, 114, 110, 32, 97, 32, 118, 97, 108, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str117762 = allocate([ 100, 117, 112, 108, 105, 99, 97, 116, 101, 32, 102, 111, 114, 109, 97, 108, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str118763 = allocate([ 116, 101, 115, 116, 32, 102, 111, 114, 32, 101, 113, 117, 97, 108, 105, 116, 121, 32, 40, 61, 61, 41, 32, 109, 105, 115, 116, 121, 112, 101, 100, 32, 97, 115, 32, 97, 115, 115, 105, 103, 110, 109, 101, 110, 116, 32, 40, 61, 41, 63, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str119764 = allocate([ 99, 97, 110, 39, 116, 32, 97, 99, 99, 101, 115, 115, 32, 111, 112, 116, 105, 109, 105, 122, 101, 100, 32, 99, 108, 111, 115, 117, 114, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str120765 = allocate([ 109, 111, 114, 101, 32, 116, 104, 97, 110, 32, 111, 110, 101, 32, 115, 119, 105, 116, 99, 104, 32, 100, 101, 102, 97, 117, 108, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str121766 = allocate([ 116, 111, 111, 32, 109, 97, 110, 121, 32, 115, 119, 105, 116, 99, 104, 32, 99, 97, 115, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str122767 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 115, 119, 105, 116, 99, 104, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str123 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 102, 111, 114, 47, 105, 110, 32, 108, 101, 102, 116, 45, 104, 97, 110, 100, 32, 115, 105, 100, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str124 = allocate([ 99, 97, 116, 99, 104, 32, 97, 102, 116, 101, 114, 32, 117, 110, 99, 111, 110, 100, 105, 116, 105, 111, 110, 97, 108, 32, 99, 97, 116, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str125 = allocate([ 99, 97, 116, 99, 104, 32, 119, 105, 116, 104, 111, 117, 116, 32, 116, 114, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str126 = allocate([ 102, 105, 110, 97, 108, 108, 121, 32, 119, 105, 116, 104, 111, 117, 116, 32, 116, 114, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str127 = allocate([ 108, 97, 98, 101, 108, 32, 110, 111, 116, 32, 102, 111, 117, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str128 = allocate([ 117, 110, 108, 97, 98, 101, 108, 101, 100, 32, 98, 114, 101, 97, 107, 32, 109, 117, 115, 116, 32, 98, 101, 32, 105, 110, 115, 105, 100, 101, 32, 108, 111, 111, 112, 32, 111, 114, 32, 115, 119, 105, 116, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str129 = allocate([ 99, 111, 110, 116, 105, 110, 117, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 105, 110, 115, 105, 100, 101, 32, 108, 111, 111, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str130 = allocate([ 123, 48, 125, 32, 110, 111, 116, 32, 105, 110, 32, 102, 117, 110, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str131 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 108, 97, 98, 101, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str132 = allocate([ 100, 117, 112, 108, 105, 99, 97, 116, 101, 32, 108, 97, 98, 101, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str133 = allocate([ 118, 97, 114, 105, 97, 98, 108, 101, 32, 123, 48, 125, 32, 114, 101, 100, 101, 99, 108, 97, 114, 101, 115, 32, 97, 114, 103, 117, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str134 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 105, 110, 105, 116, 105, 97, 108, 105, 122, 97, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str135 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 97, 115, 115, 105, 103, 110, 109, 101, 110, 116, 32, 108, 101, 102, 116, 45, 104, 97, 110, 100, 32, 115, 105, 100, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str136 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 123, 48, 125, 32, 111, 112, 101, 114, 97, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str137 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 105, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str138 = allocate([ 123, 48, 125, 32, 105, 115, 32, 97, 32, 114, 101, 115, 101, 114, 118, 101, 100, 32, 105, 100, 101, 110, 116, 105, 102, 105, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str139 = allocate([ 115, 121, 110, 116, 97, 120, 32, 101, 114, 114, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str140 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 115, 104, 97, 114, 112, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str141 = allocate([ 39, 112, 114, 111, 116, 111, 116, 121, 112, 101, 39, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 111, 102, 32, 123, 48, 125, 32, 105, 115, 32, 110, 111, 116, 32, 97, 110, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str142 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 101, 120, 112, 111, 110, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str143 = allocate([ 111, 117, 116, 32, 111, 102, 32, 109, 101, 109, 111, 114, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str145 = allocate([ 116, 111, 111, 32, 109, 97, 110, 121, 32, 112, 97, 114, 101, 110, 116, 104, 101, 115, 101, 115, 32, 105, 110, 32, 114, 101, 103, 117, 108, 97, 114, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str146 = allocate([ 117, 110, 116, 101, 114, 109, 105, 110, 97, 116, 101, 100, 32, 99, 111, 109, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str147 = allocate([ 117, 110, 116, 101, 114, 109, 105, 110, 97, 116, 101, 100, 32, 114, 101, 103, 117, 108, 97, 114, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 108, 105, 116, 101, 114, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str148 = allocate([ 98, 97, 100, 32, 99, 108, 111, 110, 101, 100, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 115, 99, 111, 112, 101, 32, 99, 104, 97, 105, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str149 = allocate([ 111, 118, 101, 114, 108, 97, 114, 103, 101, 32, 115, 104, 97, 114, 112, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 110, 117, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str150 = allocate([ 105, 108, 108, 101, 103, 97, 108, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str151 = allocate([ 123, 48, 125, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 108, 101, 103, 97, 108, 32, 69, 67, 77, 65, 45, 50, 54, 50, 32, 111, 99, 116, 97, 108, 32, 99, 111, 110, 115, 116, 97, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str152 = allocate([ 102, 117, 110, 99, 116, 105, 111, 110, 32, 123, 48, 125, 32, 109, 117, 115, 116, 32, 98, 101, 32, 99, 97, 108, 108, 101, 100, 32, 100, 105, 114, 101, 99, 116, 108, 121, 44, 32, 97, 110, 100, 32, 110, 111, 116, 32, 98, 121, 32, 119, 97, 121, 32, 111, 102, 32, 97, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 111, 102, 32, 97, 110, 111, 116, 104, 101, 114, 32, 110, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str153 = allocate([ 117, 110, 99, 97, 117, 103, 104, 116, 32, 101, 120, 99, 101, 112, 116, 105, 111, 110, 58, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str154 = allocate([ 110, 111, 110, 45, 111, 99, 116, 97, 108, 32, 100, 105, 103, 105, 116, 32, 105, 110, 32, 97, 110, 32, 101, 115, 99, 97, 112, 101, 32, 115, 101, 113, 117, 101, 110, 99, 101, 32, 116, 104, 97, 116, 32, 100, 111, 101, 115, 110, 39, 116, 32, 109, 97, 116, 99, 104, 32, 97, 32, 98, 97, 99, 107, 45, 114, 101, 102, 101, 114, 101, 110, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str155 = allocate([ 98, 97, 99, 107, 45, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 101, 120, 99, 101, 101, 100, 115, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 99, 97, 112, 116, 117, 114, 105, 110, 103, 32, 112, 97, 114, 101, 110, 116, 104, 101, 115, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str156768 = allocate([ 112, 114, 101, 99, 105, 115, 105, 111, 110, 32, 123, 48, 125, 32, 111, 117, 116, 32, 111, 102, 32, 114, 97, 110, 103, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str157 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 123, 48, 125, 32, 117, 115, 97, 103, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str158 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 97, 114, 114, 97, 121, 32, 108, 101, 110, 103, 116, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str159 = allocate([ 99, 97, 110, 39, 116, 32, 100, 101, 115, 99, 114, 105, 98, 101, 32, 110, 111, 110, 45, 110, 97, 116, 105, 118, 101, 32, 112, 114, 111, 112, 101, 114, 116, 105, 101, 115, 32, 111, 102, 32, 99, 108, 97, 115, 115, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str160 = allocate([ 115, 101, 99, 111, 110, 100, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 116, 111, 32, 70, 117, 110, 99, 116, 105, 111, 110, 46, 112, 114, 111, 116, 111, 116, 121, 112, 101, 46, 123, 48, 125, 32, 109, 117, 115, 116, 32, 98, 101, 32, 97, 110, 32, 97, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str161 = allocate([ 114, 101, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 111, 102, 32, 123, 48, 125, 32, 123, 49, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str162 = allocate([ 97, 115, 115, 105, 103, 110, 109, 101, 110, 116, 32, 116, 111, 32, 117, 110, 100, 101, 99, 108, 97, 114, 101, 100, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str163 = allocate([ 97, 110, 111, 110, 121, 109, 111, 117, 115, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 97, 108, 119, 97, 121, 115, 32, 114, 101, 116, 117, 114, 110, 32, 97, 32, 118, 97, 108, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str164 = allocate([ 100, 101, 112, 114, 101, 99, 97, 116, 101, 100, 32, 123, 48, 125, 32, 117, 115, 97, 103, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str165 = allocate([ 109, 97, 108, 102, 111, 114, 109, 101, 100, 32, 85, 82, 73, 32, 115, 101, 113, 117, 101, 110, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str166 = allocate([ 115, 101, 116, 116, 105, 110, 103, 32, 97, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 116, 104, 97, 116, 32, 104, 97, 115, 32, 111, 110, 108, 121, 32, 97, 32, 103, 101, 116, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str167 = allocate([ 105, 100, 101, 110, 116, 105, 102, 105, 101, 114, 32, 115, 116, 97, 114, 116, 115, 32, 105, 109, 109, 101, 100, 105, 97, 116, 101, 108, 121, 32, 97, 102, 116, 101, 114, 32, 110, 117, 109, 101, 114, 105, 99, 32, 108, 105, 116, 101, 114, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str168 = allocate([ 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 116, 111, 32, 117, 110, 100, 101, 102, 105, 110, 101, 100, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str169 = allocate([ 117, 115, 101, 108, 101, 115, 115, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str170 = allocate([ 114, 101, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 111, 102, 32, 102, 111, 114, 109, 97, 108, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str171 = allocate([ 99, 97, 110, 39, 116, 32, 115, 117, 112, 112, 108, 121, 32, 102, 108, 97, 103, 115, 32, 119, 104, 101, 110, 32, 99, 111, 110, 115, 116, 114, 117, 99, 116, 105, 110, 103, 32, 111, 110, 101, 32, 82, 101, 103, 69, 120, 112, 32, 102, 114, 111, 109, 32, 97, 110, 111, 116, 104, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str172 = allocate([ 114, 101, 115, 101, 114, 118, 101, 100, 32, 115, 108, 111, 116, 32, 105, 110, 100, 101, 120, 32, 111, 117, 116, 32, 111, 102, 32, 114, 97, 110, 103, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str173 = allocate([ 99, 97, 110, 39, 116, 32, 100, 101, 99, 111, 100, 101, 32, 74, 83, 80, 114, 105, 110, 99, 105, 112, 97, 108, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str174769 = allocate([ 99, 97, 110, 39, 116, 32, 115, 101, 97, 108, 32, 123, 48, 125, 32, 111, 98, 106, 101, 99, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str175 = allocate([ 116, 111, 111, 32, 109, 97, 110, 121, 32, 99, 97, 116, 99, 104, 32, 118, 97, 114, 105, 97, 98, 108, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str176 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 88, 77, 76, 32, 109, 97, 114, 107, 117, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str177 = allocate([ 105, 108, 108, 101, 103, 97, 108, 32, 88, 77, 76, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str178 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 100, 101, 102, 97, 117, 108, 116, 32, 88, 77, 76, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str179 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 88, 77, 76, 32, 110, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str180 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 93, 32, 97, 102, 116, 101, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str181 = allocate([ 97, 108, 114, 101, 97, 100, 121, 32, 101, 120, 101, 99, 117, 116, 105, 110, 103, 32, 103, 101, 110, 101, 114, 97, 116, 111, 114, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str182770 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 125, 32, 105, 110, 32, 88, 77, 76, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str183 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 88, 77, 76, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str184771 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 88, 77, 76, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 110, 97, 109, 101, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str185 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 88, 77, 76, 32, 110, 97, 109, 101, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str186 = allocate([ 99, 97, 110, 39, 116, 32, 99, 111, 110, 118, 101, 114, 116, 32, 123, 48, 125, 32, 116, 111, 32, 88, 77, 76, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str187 = allocate([ 99, 97, 110, 39, 116, 32, 99, 111, 110, 118, 101, 114, 116, 32, 123, 48, 125, 32, 116, 111, 32, 88, 77, 76, 76, 105, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str188772 = allocate([ 97, 116, 116, 101, 109, 112, 116, 32, 116, 111, 32, 115, 101, 110, 100, 32, 123, 48, 125, 32, 116, 111, 32, 110, 101, 119, 98, 111, 114, 110, 32, 103, 101, 110, 101, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str189 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 61, 32, 105, 110, 32, 88, 77, 76, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str190 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 88, 77, 76, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 118, 97, 108, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str191 = allocate([ 88, 77, 76, 32, 116, 97, 103, 32, 110, 97, 109, 101, 32, 109, 105, 115, 109, 97, 116, 99, 104, 32, 40, 101, 120, 112, 101, 99, 116, 101, 100, 32, 123, 48, 125, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str192 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 88, 77, 76, 32, 116, 97, 103, 32, 115, 121, 110, 116, 97, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str193 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 88, 77, 76, 32, 108, 105, 115, 116, 32, 115, 121, 110, 116, 97, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str194 = allocate([ 123, 48, 125, 32, 123, 49, 125, 32, 99, 97, 108, 108, 101, 100, 32, 111, 110, 32, 105, 110, 99, 111, 109, 112, 97, 116, 105, 98, 108, 101, 32, 123, 50, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str195 = allocate([ 99, 97, 110, 39, 116, 32, 115, 101, 116, 32, 88, 77, 76, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str196 = allocate([ 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 101, 110, 100, 32, 111, 102, 32, 88, 77, 76, 32, 115, 111, 117, 114, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str197 = allocate([ 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 101, 110, 100, 32, 111, 102, 32, 88, 77, 76, 32, 101, 110, 116, 105, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str198773 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 88, 77, 76, 32, 113, 117, 97, 108, 105, 102, 105, 101, 100, 32, 110, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str199 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 102, 111, 114, 32, 101, 97, 99, 104, 32, 108, 111, 111, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str200 = allocate([ 99, 97, 110, 39, 116, 32, 115, 101, 116, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 123, 48, 125, 32, 105, 110, 32, 88, 77, 76, 76, 105, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str201 = allocate([ 117, 110, 107, 110, 111, 119, 110, 32, 88, 77, 76, 32, 101, 110, 116, 105, 116, 121, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str202 = allocate([ 109, 97, 108, 102, 111, 114, 109, 101, 100, 32, 88, 77, 76, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str203 = allocate([ 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 116, 111, 32, 117, 110, 100, 101, 102, 105, 110, 101, 100, 32, 88, 77, 76, 32, 110, 97, 109, 101, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str204 = allocate([ 100, 117, 112, 108, 105, 99, 97, 116, 101, 32, 88, 77, 76, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str205 = allocate([ 116, 111, 111, 32, 109, 97, 110, 121, 32, 108, 111, 99, 97, 108, 32, 118, 97, 114, 105, 97, 98, 108, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str206 = allocate([ 97, 114, 114, 97, 121, 32, 105, 110, 105, 116, 105, 97, 108, 105, 115, 101, 114, 32, 116, 111, 111, 32, 108, 97, 114, 103, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str207 = allocate([ 114, 101, 103, 117, 108, 97, 114, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 116, 111, 111, 32, 99, 111, 109, 112, 108, 101, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str208 = allocate([ 98, 117, 102, 102, 101, 114, 32, 116, 111, 111, 32, 115, 109, 97, 108, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str209 = allocate([ 98, 97, 100, 32, 115, 117, 114, 114, 111, 103, 97, 116, 101, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str210 = allocate([ 85, 84, 70, 45, 56, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 123, 48, 125, 32, 116, 111, 111, 32, 108, 97, 114, 103, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str211 = allocate([ 109, 97, 108, 102, 111, 114, 109, 101, 100, 32, 85, 84, 70, 45, 56, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 115, 101, 113, 117, 101, 110, 99, 101, 32, 97, 116, 32, 111, 102, 102, 115, 101, 116, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str212 = allocate([ 74, 83, 95, 82, 101, 112, 111, 114, 116, 69, 114, 114, 111, 114, 32, 119, 97, 115, 32, 99, 97, 108, 108, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str213 = allocate([ 119, 114, 111, 110, 103, 32, 99, 111, 110, 115, 116, 114, 117, 99, 116, 111, 114, 32, 99, 97, 108, 108, 101, 100, 32, 102, 111, 114, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str214 = allocate([ 103, 101, 110, 101, 114, 97, 116, 111, 114, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 123, 48, 125, 32, 114, 101, 116, 117, 114, 110, 115, 32, 97, 32, 118, 97, 108, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str215 = allocate([ 97, 110, 111, 110, 121, 109, 111, 117, 115, 32, 103, 101, 110, 101, 114, 97, 116, 111, 114, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 114, 101, 116, 117, 114, 110, 115, 32, 97, 32, 118, 97, 108, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str216 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 110, 97, 109, 101, 32, 97, 102, 116, 101, 114, 32, 102, 111, 114, 32, 40, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str217 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 105, 110, 32, 97, 102, 116, 101, 114, 32, 102, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str218 = allocate([ 116, 114, 97, 112, 32, 123, 49, 125, 32, 102, 111, 114, 32, 123, 48, 125, 32, 114, 101, 116, 117, 114, 110, 101, 100, 32, 97, 32, 112, 114, 105, 109, 105, 116, 105, 118, 101, 32, 118, 97, 108, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str219 = allocate([ 107, 101, 121, 119, 111, 114, 100, 32, 105, 115, 32, 117, 115, 101, 100, 32, 97, 115, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str220 = allocate([ 121, 105, 101, 108, 100, 32, 102, 114, 111, 109, 32, 99, 108, 111, 115, 105, 110, 103, 32, 103, 101, 110, 101, 114, 97, 116, 111, 114, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str221 = allocate([ 123, 48, 125, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 109, 117, 115, 116, 32, 98, 101, 32, 112, 97, 114, 101, 110, 116, 104, 101, 115, 105, 122, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str222 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 97, 114, 114, 97, 121, 32, 99, 111, 109, 112, 114, 101, 104, 101, 110, 115, 105, 111, 110, 32, 108, 101, 102, 116, 45, 104, 97, 110, 100, 32, 115, 105, 100, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str223 = allocate([ 88, 77, 76, 32, 102, 105, 108, 116, 101, 114, 32, 105, 115, 32, 97, 112, 112, 108, 105, 101, 100, 32, 116, 111, 32, 110, 111, 110, 45, 88, 77, 76, 32, 118, 97, 108, 117, 101, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str224 = allocate([ 114, 101, 100, 117, 99, 101, 32, 111, 102, 32, 101, 109, 112, 116, 121, 32, 97, 114, 114, 97, 121, 32, 119, 105, 116, 104, 32, 110, 111, 32, 105, 110, 105, 116, 105, 97, 108, 32, 118, 97, 108, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str225 = allocate([ 99, 97, 110, 39, 116, 32, 99, 97, 108, 108, 32, 123, 48, 125, 32, 109, 101, 116, 104, 111, 100, 32, 111, 110, 32, 97, 110, 32, 88, 77, 76, 32, 108, 105, 115, 116, 32, 119, 105, 116, 104, 32, 123, 49, 125, 32, 101, 108, 101, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str226 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 100, 101, 108, 101, 116, 101, 32, 111, 112, 101, 114, 97, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str227 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 105, 110, 99, 114, 101, 109, 101, 110, 116, 47, 100, 101, 99, 114, 101, 109, 101, 110, 116, 32, 111, 112, 101, 114, 97, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str228 = allocate([ 123, 48, 125, 32, 105, 115, 32, 123, 49, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str229 = allocate([ 108, 101, 116, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 110, 111, 116, 32, 100, 105, 114, 101, 99, 116, 108, 121, 32, 119, 105, 116, 104, 105, 110, 32, 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str230 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 111, 98, 106, 101, 99, 116, 32, 105, 110, 105, 116, 105, 97, 108, 105, 122, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str231 = allocate([ 99, 97, 110, 39, 116, 32, 115, 101, 116, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 32, 111, 110, 32, 105, 110, 100, 101, 120, 101, 100, 32, 97, 114, 114, 97, 121, 32, 112, 114, 111, 112, 101, 114, 116, 105, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str232 = allocate([ 101, 118, 97, 108, 32, 97, 99, 99, 101, 112, 116, 115, 32, 111, 110, 108, 121, 32, 111, 110, 101, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str233 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 123, 48, 125, 32, 119, 104, 101, 110, 32, 99, 97, 108, 108, 105, 110, 103, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 123, 49, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str234 = allocate([ 74, 83, 79, 78, 46, 112, 97, 114, 115, 101, 58, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str235 = allocate([ 74, 83, 79, 78, 46, 115, 116, 114, 105, 110, 103, 105, 102, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str236 = allocate([ 118, 97, 108, 117, 101, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 111, 114, 32, 117, 110, 100, 101, 102, 105, 110, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str237 = allocate([ 118, 97, 108, 117, 101, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 110, 111, 110, 45, 110, 117, 108, 108, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str238 = allocate([ 111, 99, 116, 97, 108, 32, 108, 105, 116, 101, 114, 97, 108, 115, 32, 97, 110, 100, 32, 111, 99, 116, 97, 108, 32, 101, 115, 99, 97, 112, 101, 32, 115, 101, 113, 117, 101, 110, 99, 101, 115, 32, 97, 114, 101, 32, 100, 101, 112, 114, 101, 99, 97, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str239 = allocate([ 115, 116, 114, 105, 99, 116, 32, 109, 111, 100, 101, 32, 99, 111, 100, 101, 32, 109, 97, 121, 32, 110, 111, 116, 32, 99, 111, 110, 116, 97, 105, 110, 32, 39, 119, 105, 116, 104, 39, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str240 = allocate([ 112, 114, 111, 112, 101, 114, 116, 121, 32, 110, 97, 109, 101, 32, 123, 48, 125, 32, 97, 112, 112, 101, 97, 114, 115, 32, 109, 111, 114, 101, 32, 116, 104, 97, 110, 32, 111, 110, 99, 101, 32, 105, 110, 32, 111, 98, 106, 101, 99, 116, 32, 108, 105, 116, 101, 114, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str241 = allocate([ 97, 112, 112, 108, 121, 105, 110, 103, 32, 116, 104, 101, 32, 39, 100, 101, 108, 101, 116, 101, 39, 32, 111, 112, 101, 114, 97, 116, 111, 114, 32, 116, 111, 32, 97, 110, 32, 117, 110, 113, 117, 97, 108, 105, 102, 105, 101, 100, 32, 110, 97, 109, 101, 32, 105, 115, 32, 100, 101, 112, 114, 101, 99, 97, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str242 = allocate([ 97, 115, 115, 105, 103, 110, 109, 101, 110, 116, 32, 116, 111, 32, 123, 48, 125, 32, 105, 115, 32, 100, 101, 112, 114, 101, 99, 97, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str243 = allocate([ 114, 101, 100, 101, 102, 105, 110, 105, 110, 103, 32, 123, 48, 125, 32, 105, 115, 32, 100, 101, 112, 114, 101, 99, 97, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str244 = allocate([ 112, 114, 111, 112, 101, 114, 116, 121, 32, 100, 101, 115, 99, 114, 105, 112, 116, 111, 114, 115, 32, 109, 117, 115, 116, 32, 110, 111, 116, 32, 115, 112, 101, 99, 105, 102, 121, 32, 97, 32, 118, 97, 108, 117, 101, 32, 111, 114, 32, 98, 101, 32, 119, 114, 105, 116, 97, 98, 108, 101, 32, 119, 104, 101, 110, 32, 97, 32, 103, 101, 116, 116, 101, 114, 32, 111, 114, 32, 115, 101, 116, 116, 101, 114, 32, 104, 97, 115, 32, 98, 101, 101, 110, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str245 = allocate([ 123, 48, 125, 32, 105, 115, 32, 110, 111, 116, 32, 101, 120, 116, 101, 110, 115, 105, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str246 = allocate([ 99, 97, 110, 39, 116, 32, 114, 101, 100, 101, 102, 105, 110, 101, 32, 110, 111, 110, 45, 99, 111, 110, 102, 105, 103, 117, 114, 97, 98, 108, 101, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 39, 123, 48, 125, 39, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str247 = allocate([ 99, 97, 110, 39, 116, 32, 97, 100, 100, 32, 101, 108, 101, 109, 101, 110, 116, 115, 32, 112, 97, 115, 116, 32, 116, 104, 101, 32, 101, 110, 100, 32, 111, 102, 32, 97, 110, 32, 97, 114, 114, 97, 121, 32, 105, 102, 32, 105, 116, 115, 32, 108, 101, 110, 103, 116, 104, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 105, 115, 32, 117, 110, 119, 114, 105, 116, 97, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str248 = allocate([ 100, 101, 102, 105, 110, 105, 110, 103, 32, 116, 104, 101, 32, 108, 101, 110, 103, 116, 104, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 111, 110, 32, 97, 110, 32, 97, 114, 114, 97, 121, 32, 105, 115, 32, 110, 111, 116, 32, 99, 117, 114, 114, 101, 110, 116, 108, 121, 32, 115, 117, 112, 112, 111, 114, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str249 = allocate([ 99, 97, 110, 39, 116, 32, 100, 101, 102, 105, 110, 101, 32, 97, 114, 114, 97, 121, 32, 105, 110, 100, 101, 120, 32, 112, 114, 111, 112, 101, 114, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str250 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 111, 114, 32, 111, 117, 116, 45, 111, 102, 45, 114, 97, 110, 103, 101, 32, 105, 110, 100, 101, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str251 = allocate([ 97, 114, 103, 117, 109, 101, 110, 116, 32, 123, 48, 125, 32, 109, 117, 115, 116, 32, 98, 101, 32, 62, 61, 32, 48, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str252 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str253 = allocate([ 99, 97, 108, 108, 32, 116, 111, 32, 70, 117, 110, 99, 116, 105, 111, 110, 40, 41, 32, 98, 108, 111, 99, 107, 101, 100, 32, 98, 121, 32, 67, 83, 80, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str254 = allocate([ 112, 114, 111, 112, 101, 114, 116, 121, 32, 100, 101, 115, 99, 114, 105, 112, 116, 111, 114, 39, 115, 32, 123, 48, 125, 32, 102, 105, 101, 108, 100, 32, 105, 115, 32, 110, 101, 105, 116, 104, 101, 114, 32, 117, 110, 100, 101, 102, 105, 110, 101, 100, 32, 110, 111, 114, 32, 97, 32, 102, 117, 110, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str255 = allocate([ 112, 114, 111, 120, 121, 32, 119, 97, 115, 32, 102, 105, 120, 101, 100, 32, 119, 104, 105, 108, 101, 32, 101, 120, 101, 99, 117, 116, 105, 110, 103, 32, 116, 104, 101, 32, 104, 97, 110, 100, 108, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str256 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 101, 118, 97, 108, 32, 115, 99, 111, 112, 101, 32, 97, 114, 103, 117, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str257 = allocate([ 123, 48, 125, 32, 102, 117, 110, 99, 116, 105, 111, 110, 115, 32, 109, 117, 115, 116, 32, 104, 97, 118, 101, 32, 123, 49, 125, 32, 97, 114, 103, 117, 109, 101, 110, 116, 123, 50, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str258 = allocate([ 39, 99, 97, 108, 108, 101, 114, 39, 44, 32, 39, 99, 97, 108, 108, 101, 101, 39, 44, 32, 97, 110, 100, 32, 39, 97, 114, 103, 117, 109, 101, 110, 116, 115, 39, 32, 112, 114, 111, 112, 101, 114, 116, 105, 101, 115, 32, 109, 97, 121, 32, 110, 111, 116, 32, 98, 101, 32, 97, 99, 99, 101, 115, 115, 101, 100, 32, 111, 110, 32, 115, 116, 114, 105, 99, 116, 32, 109, 111, 100, 101, 32, 102, 117, 110, 99, 116, 105, 111, 110, 115, 32, 111, 114, 32, 116, 104, 101, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 32, 111, 98, 106, 101, 99, 116, 115, 32, 102, 111, 114, 32, 99, 97, 108, 108, 115, 32, 116, 111, 32, 116, 104, 101, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str259 = allocate([ 116, 111, 73, 83, 79, 83, 116, 114, 105, 110, 103, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 105, 115, 32, 110, 111, 116, 32, 99, 97, 108, 108, 97, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str260 = allocate([ 98, 97, 100, 32, 112, 97, 114, 115, 101, 32, 110, 111, 100, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str261 = allocate([ 123, 48, 125, 58, 32, 101, 120, 112, 101, 99, 116, 101, 100, 32, 123, 49, 125, 44, 32, 103, 111, 116, 32, 123, 50, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str262 = allocate([ 97, 99, 99, 101, 115, 115, 32, 116, 111, 32, 115, 116, 114, 105, 99, 116, 32, 109, 111, 100, 101, 32, 99, 97, 108, 108, 101, 114, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 105, 115, 32, 99, 101, 110, 115, 111, 114, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str263 = allocate([ 102, 117, 110, 99, 116, 105, 111, 110, 32, 99, 97, 110, 32, 98, 101, 32, 99, 97, 108, 108, 101, 100, 32, 111, 110, 108, 121, 32, 105, 110, 32, 100, 101, 98, 117, 103, 32, 109, 111, 100, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str264 = allocate([ 115, 116, 114, 105, 99, 116, 32, 109, 111, 100, 101, 32, 99, 111, 100, 101, 32, 109, 97, 121, 32, 110, 111, 116, 32, 99, 111, 110, 116, 97, 105, 110, 32, 117, 110, 112, 97, 114, 101, 110, 116, 104, 101, 115, 105, 122, 101, 100, 32, 108, 101, 116, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str265 = allocate([ 99, 97, 110, 39, 116, 32, 99, 104, 97, 110, 103, 101, 32, 111, 98, 106, 101, 99, 116, 39, 115, 32, 101, 120, 116, 101, 110, 115, 105, 98, 105, 108, 105, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str266 = allocate([ 98, 97, 100, 32, 115, 101, 114, 105, 97, 108, 105, 122, 101, 100, 32, 115, 116, 114, 117, 99, 116, 117, 114, 101, 100, 32, 100, 97, 116, 97, 32, 40, 123, 48, 125, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str267 = allocate([ 117, 110, 115, 117, 112, 112, 111, 114, 116, 101, 100, 32, 116, 121, 112, 101, 32, 102, 111, 114, 32, 115, 116, 114, 117, 99, 116, 117, 114, 101, 100, 32, 100, 97, 116, 97, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str268 = allocate([ 114, 101, 99, 117, 114, 115, 105, 118, 101, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str269 = allocate([ 99, 97, 110, 39, 116, 32, 119, 114, 97, 112, 32, 88, 77, 76, 32, 111, 98, 106, 101, 99, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str270 = allocate([ 117, 110, 115, 117, 112, 112, 111, 114, 116, 101, 100, 32, 115, 116, 114, 117, 99, 116, 117, 114, 101, 100, 32, 99, 108, 111, 110, 101, 32, 118, 101, 114, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str271 = allocate([ 99, 97, 110, 39, 116, 32, 99, 108, 111, 110, 101, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str272 = allocate([ 110, 111, 110, 45, 110, 97, 116, 105, 118, 101, 32, 115, 99, 111, 112, 101, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str273 = allocate([ 105, 110, 32, 115, 116, 114, 105, 99, 116, 32, 109, 111, 100, 101, 32, 99, 111, 100, 101, 44, 32, 102, 117, 110, 99, 116, 105, 111, 110, 115, 32, 109, 97, 121, 32, 98, 101, 32, 100, 101, 99, 108, 97, 114, 101, 100, 32, 111, 110, 108, 121, 32, 97, 116, 32, 116, 111, 112, 32, 108, 101, 118, 101, 108, 32, 111, 114, 32, 105, 109, 109, 101, 100, 105, 97, 116, 101, 108, 121, 32, 119, 105, 116, 104, 105, 110, 32, 97, 110, 111, 116, 104, 101, 114, 32, 102, 117, 110, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str274 = allocate([ 102, 111, 114, 45, 105, 110, 32, 108, 111, 111, 112, 32, 108, 101, 116, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 109, 97, 121, 32, 110, 111, 116, 32, 104, 97, 118, 101, 32, 97, 110, 32, 105, 110, 105, 116, 105, 97, 108, 105, 122, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str275 = allocate([ 97, 116, 116, 101, 109, 112, 116, 32, 116, 111, 32, 114, 117, 110, 32, 99, 111, 109, 112, 105, 108, 101, 45, 97, 110, 100, 45, 103, 111, 32, 115, 99, 114, 105, 112, 116, 32, 111, 110, 32, 97, 32, 99, 108, 101, 97, 114, 101, 100, 32, 115, 99, 111, 112, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str276 = allocate([ 109, 97, 108, 102, 111, 114, 109, 101, 100, 32, 123, 48, 125, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 101, 115, 99, 97, 112, 101, 32, 115, 101, 113, 117, 101, 110, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str277 = allocate([ 105, 108, 108, 101, 103, 97, 108, 32, 117, 115, 101, 32, 111, 102, 32, 123, 48, 125, 32, 105, 110, 32, 103, 101, 110, 101, 114, 97, 116, 111, 114, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str278 = allocate([ 99, 97, 110, 39, 116, 32, 115, 101, 116, 32, 112, 114, 111, 116, 111, 116, 121, 112, 101, 32, 111, 102, 32, 97, 110, 32, 111, 98, 106, 101, 99, 116, 32, 116, 111, 32, 97, 110, 32, 88, 77, 76, 32, 118, 97, 108, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str279 = allocate([ 102, 117, 110, 99, 116, 105, 111, 110, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 32, 114, 101, 113, 117, 105, 114, 101, 115, 32, 97, 32, 110, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str280 = allocate([ 123, 48, 125, 58, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 109, 117, 115, 116, 32, 98, 101, 32, 97, 110, 32, 111, 98, 106, 101, 99, 116, 32, 102, 114, 111, 109, 32, 97, 32, 100, 105, 102, 102, 101, 114, 101, 110, 116, 32, 99, 111, 109, 112, 97, 114, 116, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str281 = allocate([ 100, 101, 98, 117, 103, 103, 101, 114, 32, 114, 101, 115, 117, 109, 112, 116, 105, 111, 110, 32, 118, 97, 108, 117, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 117, 110, 100, 101, 102, 105, 110, 101, 100, 44, 32, 123, 116, 104, 114, 111, 119, 58, 32, 118, 97, 108, 125, 44, 32, 123, 114, 101, 116, 117, 114, 110, 58, 32, 118, 97, 108, 125, 44, 32, 111, 114, 32, 110, 117, 108, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str282 = allocate([ 118, 97, 108, 117, 101, 32, 97, 115, 115, 105, 103, 110, 101, 100, 32, 116, 111, 32, 123, 48, 125, 32, 109, 117, 115, 116, 32, 98, 101, 32, 97, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 111, 114, 32, 110, 117, 108, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str283 = allocate([ 123, 48, 125, 32, 105, 115, 32, 110, 111, 116, 32, 108, 105, 118, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str284 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 79, 98, 106, 101, 99, 116, 32, 98, 101, 108, 111, 110, 103, 115, 32, 116, 111, 32, 97, 32, 100, 105, 102, 102, 101, 114, 101, 110, 116, 32, 68, 101, 98, 117, 103, 103, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str285 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 79, 98, 106, 101, 99, 116, 46, 112, 114, 111, 116, 111, 116, 121, 112, 101, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 118, 97, 108, 105, 100, 32, 68, 101, 98, 117, 103, 103, 101, 114, 46, 79, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str286 = allocate([ 99, 97, 110, 110, 111, 116, 32, 100, 101, 98, 117, 103, 32, 97, 110, 32, 111, 98, 106, 101, 99, 116, 32, 105, 110, 32, 115, 97, 109, 101, 32, 99, 111, 109, 112, 97, 114, 116, 109, 101, 110, 116, 32, 97, 115, 32, 100, 101, 98, 117, 103, 103, 101, 114, 32, 111, 114, 32, 97, 32, 99, 111, 109, 112, 97, 114, 116, 109, 101, 110, 116, 32, 116, 104, 97, 116, 32, 105, 115, 32, 97, 108, 114, 101, 97, 100, 121, 32, 100, 101, 98, 117, 103, 103, 105, 110, 103, 32, 116, 104, 101, 32, 100, 101, 98, 117, 103, 103, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str287 = allocate([ 99, 97, 110, 39, 116, 32, 115, 116, 97, 114, 116, 32, 100, 101, 98, 117, 103, 103, 105, 110, 103, 58, 32, 97, 32, 100, 101, 98, 117, 103, 103, 101, 101, 32, 115, 99, 114, 105, 112, 116, 32, 105, 115, 32, 111, 110, 32, 116, 104, 101, 32, 115, 116, 97, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str288 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 115, 99, 114, 105, 112, 116, 32, 111, 102, 102, 115, 101, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str289 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 108, 105, 110, 101, 32, 110, 117, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str290 = allocate([ 99, 97, 110, 39, 116, 32, 115, 101, 116, 32, 98, 114, 101, 97, 107, 112, 111, 105, 110, 116, 58, 32, 115, 99, 114, 105, 112, 116, 32, 103, 108, 111, 98, 97, 108, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 100, 101, 98, 117, 103, 103, 101, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str291 = allocate([ 123, 48, 125, 58, 32, 100, 101, 115, 99, 114, 105, 112, 116, 111, 114, 32, 46, 123, 49, 125, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 105, 115, 32, 97, 110, 32, 111, 98, 106, 101, 99, 116, 32, 105, 110, 32, 97, 32, 100, 105, 102, 102, 101, 114, 101, 110, 116, 32, 99, 111, 109, 112, 97, 114, 116, 109, 101, 110, 116, 32, 116, 104, 97, 110, 32, 116, 104, 101, 32, 116, 97, 114, 103, 101, 116, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str292 = allocate([ 115, 116, 97, 99, 107, 32, 102, 114, 97, 109, 101, 32, 105, 115, 32, 110, 111, 116, 32, 114, 117, 110, 110, 105, 110, 103, 32, 74, 97, 118, 97, 83, 99, 114, 105, 112, 116, 32, 99, 111, 100, 101, 0 ], "i8", ALLOC_STATIC);

_js_ErrorFormatString = allocate([ 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 1, 0, 4, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 3, 0, 6, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 3, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 3, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 2, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 2, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 2, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 3, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 2, 0, 6, 0, 0, 0, 0, 0, 1, 0, 4, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 4, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 4, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 3, 0, 6, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 4, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 2, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 2, 0, 6, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 2, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 2, 0, 6, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 3, 0, 5, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 3, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN2js5crashL8gGCStackE = allocate(32840, [ "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZN2js5crashL11gErrorStackE = allocate(32840, [ "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZN2js5crashL11gRingBufferE = allocate(32800, [ "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__ZN2js5crashL12crash_cookieE = allocate([ 42, 74, 42, 83, 42, 67, 82, 65, 83, 72, 68, 65, 84, 65, 42, 0 ], "i8", ALLOC_STATIC);

__ZN2js9DateClassE = allocate([ 0, 0, 0, 0, 100665600, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 586, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str894 = allocate([ 85, 84, 67, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2896 = allocate([ 110, 111, 119, 0 ], "i8", ALLOC_STATIC);

__ZL19date_static_methods = allocate([ 0, 0, 0, 0, 588, 0, 0, 0, 7, 0, 4096, 0, 0, 0, 0, 0, 590, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 592, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str3897 = allocate([ 103, 101, 116, 84, 105, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str4898 = allocate([ 103, 101, 116, 84, 105, 109, 101, 122, 111, 110, 101, 79, 102, 102, 115, 101, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str5899 = allocate([ 103, 101, 116, 89, 101, 97, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str6900 = allocate([ 103, 101, 116, 70, 117, 108, 108, 89, 101, 97, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str7901 = allocate([ 103, 101, 116, 85, 84, 67, 70, 117, 108, 108, 89, 101, 97, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str8902 = allocate([ 103, 101, 116, 77, 111, 110, 116, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str9903 = allocate([ 103, 101, 116, 85, 84, 67, 77, 111, 110, 116, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str10904 = allocate([ 103, 101, 116, 68, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str11905 = allocate([ 103, 101, 116, 85, 84, 67, 68, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str12906 = allocate([ 103, 101, 116, 68, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str13907 = allocate([ 103, 101, 116, 85, 84, 67, 68, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str14908 = allocate([ 103, 101, 116, 72, 111, 117, 114, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str15909 = allocate([ 103, 101, 116, 85, 84, 67, 72, 111, 117, 114, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str16910 = allocate([ 103, 101, 116, 77, 105, 110, 117, 116, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str17911 = allocate([ 103, 101, 116, 85, 84, 67, 77, 105, 110, 117, 116, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str18912 = allocate([ 103, 101, 116, 83, 101, 99, 111, 110, 100, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str19913 = allocate([ 103, 101, 116, 85, 84, 67, 83, 101, 99, 111, 110, 100, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str20914 = allocate([ 103, 101, 116, 77, 105, 108, 108, 105, 115, 101, 99, 111, 110, 100, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str21915 = allocate([ 103, 101, 116, 85, 84, 67, 77, 105, 108, 108, 105, 115, 101, 99, 111, 110, 100, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str22916 = allocate([ 115, 101, 116, 84, 105, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str23917 = allocate([ 115, 101, 116, 89, 101, 97, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str24918 = allocate([ 115, 101, 116, 70, 117, 108, 108, 89, 101, 97, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str25919 = allocate([ 115, 101, 116, 85, 84, 67, 70, 117, 108, 108, 89, 101, 97, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str26920 = allocate([ 115, 101, 116, 77, 111, 110, 116, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str27921 = allocate([ 115, 101, 116, 85, 84, 67, 77, 111, 110, 116, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str28922 = allocate([ 115, 101, 116, 68, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str29923 = allocate([ 115, 101, 116, 85, 84, 67, 68, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str30924 = allocate([ 115, 101, 116, 72, 111, 117, 114, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str31925 = allocate([ 115, 101, 116, 85, 84, 67, 72, 111, 117, 114, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str32926 = allocate([ 115, 101, 116, 77, 105, 110, 117, 116, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str33927 = allocate([ 115, 101, 116, 85, 84, 67, 77, 105, 110, 117, 116, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str34928 = allocate([ 115, 101, 116, 83, 101, 99, 111, 110, 100, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str35929 = allocate([ 115, 101, 116, 85, 84, 67, 83, 101, 99, 111, 110, 100, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str36930 = allocate([ 115, 101, 116, 77, 105, 108, 108, 105, 115, 101, 99, 111, 110, 100, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str37931 = allocate([ 115, 101, 116, 85, 84, 67, 77, 105, 108, 108, 105, 115, 101, 99, 111, 110, 100, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str38932 = allocate([ 116, 111, 85, 84, 67, 83, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str39933 = allocate([ 116, 111, 76, 111, 99, 97, 108, 101, 68, 97, 116, 101, 83, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str40934 = allocate([ 116, 111, 76, 111, 99, 97, 108, 101, 84, 105, 109, 101, 83, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str41935 = allocate([ 116, 111, 76, 111, 99, 97, 108, 101, 70, 111, 114, 109, 97, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str42936 = allocate([ 116, 111, 68, 97, 116, 101, 83, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str43937 = allocate([ 116, 111, 84, 105, 109, 101, 83, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str44938 = allocate([ 116, 111, 73, 83, 79, 83, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

__ZL12date_methods = allocate([ 0, 0, 0, 0, 594, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 596, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 598, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 600, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 602, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 604, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 606, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 608, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 610, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 612, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 614, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 616, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 618, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 620, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 622, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 624, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 624, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 626, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 626, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 628, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 630, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 632, 0, 0, 0, 3, 0, 4096, 0, 0, 0, 0, 0, 634, 0, 0, 0, 3, 0, 4096, 0, 0, 0, 0, 0, 636, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 638, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 640, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 642, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 644, 0, 0, 0, 4, 0, 4096, 0, 0, 0, 0, 0, 646, 0, 0, 0, 4, 0, 4096, 0, 0, 0, 0, 0, 648, 0, 0, 0, 3, 0, 4096, 0, 0, 0, 0, 0, 650, 0, 0, 0, 3, 0, 4096, 0, 0, 0, 0, 0, 652, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 654, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 656, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 658, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 660, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 662, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 664, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 666, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 668, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 670, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 672, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 674, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 676, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 678, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 680, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 682, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZL8LocalTZA = allocate(1, "double", ALLOC_STATIC);

__ZL15firstDayOfMonth = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 31, 0, 0, 0, 0, 0, 0, 0, 59, 0, 0, 0, 0, 0, 0, 0, 90, 0, 0, 0, 0, 0, 0, 0, 120, 0, 0, 0, 0, 0, 0, 0, 151, 0, 0, 0, 0, 0, 0, 0, 181, 0, 0, 0, 0, 0, 0, 0, 212, 0, 0, 0, 0, 0, 0, 0, 243, 0, 0, 0, 0, 0, 0, 0, 273, 0, 0, 0, 0, 0, 0, 0, 304, 0, 0, 0, 0, 0, 0, 0, 334, 0, 0, 0, 0, 0, 0, 0, 365, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 31, 0, 0, 0, 0, 0, 0, 0, 60, 0, 0, 0, 0, 0, 0, 0, 91, 0, 0, 0, 0, 0, 0, 0, 121, 0, 0, 0, 0, 0, 0, 0, 152, 0, 0, 0, 0, 0, 0, 0, 182, 0, 0, 0, 0, 0, 0, 0, 213, 0, 0, 0, 0, 0, 0, 0, 244, 0, 0, 0, 0, 0, 0, 0, 274, 0, 0, 0, 0, 0, 0, 0, 305, 0, 0, 0, 0, 0, 0, 0, 335, 0, 0, 0, 0, 0, 0, 0, 366, 0, 0, 0, 0, 0, 0, 0 ], [ "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0 ], ALLOC_STATIC);

__ZL16yearStartingWith = allocate([ 1978, 0, 0, 0, 1973, 0, 0, 0, 1974, 0, 0, 0, 1975, 0, 0, 0, 1981, 0, 0, 0, 1971, 0, 0, 0, 1977, 0, 0, 0, 1984, 0, 0, 0, 1996, 0, 0, 0, 1980, 0, 0, 0, 1992, 0, 0, 0, 1976, 0, 0, 0, 1988, 0, 0, 0, 1972, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

__ZL3wtb = allocate(128, "*", ALLOC_STATIC);

__ZL3ttb = allocate([ -1, 0, 0, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0, 5, 0, 0, 0, 6, 0, 0, 0, 7, 0, 0, 0, 8, 0, 0, 0, 9, 0, 0, 0, 10, 0, 0, 0, 11, 0, 0, 0, 12, 0, 0, 0, 13, 0, 0, 0, 1e4, 0, 0, 0, 1e4, 0, 0, 0, 1e4, 0, 0, 0, 10300, 0, 0, 0, 10240, 0, 0, 0, 10360, 0, 0, 0, 10300, 0, 0, 0, 10420, 0, 0, 0, 10360, 0, 0, 0, 10480, 0, 0, 0, 10420, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str45939 = allocate([ 97, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str46940 = allocate([ 112, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str47941 = allocate([ 109, 111, 110, 100, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str48942 = allocate([ 116, 117, 101, 115, 100, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str49943 = allocate([ 119, 101, 100, 110, 101, 115, 100, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str50944 = allocate([ 116, 104, 117, 114, 115, 100, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str51945 = allocate([ 102, 114, 105, 100, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str52946 = allocate([ 115, 97, 116, 117, 114, 100, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str53947 = allocate([ 115, 117, 110, 100, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str54948 = allocate([ 106, 97, 110, 117, 97, 114, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str55949 = allocate([ 102, 101, 98, 114, 117, 97, 114, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str56950 = allocate([ 109, 97, 114, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str57951 = allocate([ 97, 112, 114, 105, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str58952 = allocate([ 109, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str59953 = allocate([ 106, 117, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str60954 = allocate([ 106, 117, 108, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str61955 = allocate([ 97, 117, 103, 117, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str62956 = allocate([ 115, 101, 112, 116, 101, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str63957 = allocate([ 111, 99, 116, 111, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str64958 = allocate([ 110, 111, 118, 101, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str65959 = allocate([ 100, 101, 99, 101, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str66960 = allocate([ 103, 109, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str67961 = allocate([ 117, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str68962 = allocate([ 117, 116, 99, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str69963 = allocate([ 101, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str70964 = allocate([ 101, 100, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str71965 = allocate([ 99, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str72966 = allocate([ 99, 100, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str73967 = allocate([ 109, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str74968 = allocate([ 109, 100, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str75969 = allocate([ 112, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str76970 = allocate([ 112, 100, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL15js_NaN_date_str = allocate([ 73, 110, 118, 97, 108, 105, 100, 32, 68, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str77971 = allocate([ 40, 37, 90, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str78972 = allocate([ 37, 115, 32, 37, 115, 32, 37, 46, 50, 100, 32, 37, 46, 52, 100, 32, 37, 46, 50, 100, 58, 37, 46, 50, 100, 58, 37, 46, 50, 100, 32, 71, 77, 84, 37, 43, 46, 52, 100, 37, 115, 37, 115, 0 ], "i8", ALLOC_STATIC);

__ZL4days = allocate(28, "*", ALLOC_STATIC);

__ZL6months = allocate(48, "*", ALLOC_STATIC);

STRING_TABLE.__str81975 = allocate([ 37, 115, 32, 37, 115, 32, 37, 46, 50, 100, 32, 37, 46, 52, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str82976 = allocate([ 37, 46, 50, 100, 58, 37, 46, 50, 100, 58, 37, 46, 50, 100, 32, 71, 77, 84, 37, 43, 46, 52, 100, 37, 115, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str83977 = allocate([ 74, 97, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str84978 = allocate([ 70, 101, 98, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str85979 = allocate([ 77, 97, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str86980 = allocate([ 65, 112, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str87981 = allocate([ 77, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str88982 = allocate([ 74, 117, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str89983 = allocate([ 74, 117, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str90984 = allocate([ 65, 117, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str91985 = allocate([ 83, 101, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str92986 = allocate([ 79, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str93987 = allocate([ 78, 111, 118, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str94988 = allocate([ 68, 101, 99, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str95989 = allocate([ 83, 117, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str96990 = allocate([ 77, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str97991 = allocate([ 84, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str98992 = allocate([ 87, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str99993 = allocate([ 84, 104, 117, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str100994 = allocate([ 70, 114, 105, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str101995 = allocate([ 83, 97, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str103997 = allocate([ 37, 46, 52, 100, 45, 37, 46, 50, 100, 45, 37, 46, 50, 100, 84, 37, 46, 50, 100, 58, 37, 46, 50, 100, 58, 37, 46, 50, 100, 46, 37, 46, 51, 100, 90, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str104998 = allocate([ 37, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1061000 = allocate([ 37, 88, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1081002 = allocate([ 37, 115, 44, 32, 37, 46, 50, 100, 32, 37, 115, 32, 37, 46, 52, 100, 32, 37, 46, 50, 100, 58, 37, 46, 50, 100, 58, 37, 46, 50, 100, 32, 71, 77, 84, 0 ], "i8", ALLOC_STATIC);

__ZL8stub_ops = allocate([ 684, 0, 0, 0, 686, 0, 0, 0, 688, 0, 0, 0, 690, 0, 0, 0, 692, 0, 0, 0, 694, 0, 0, 0, 696, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__ZL9dtoaModes = allocate([ 0, 0, 3, 2, 2 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1096 = allocate([ 101, 37, 43, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str11097 = allocate([ 73, 110, 102, 105, 110, 105, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str21098 = allocate([ 78, 97, 78, 0 ], "i8", ALLOC_STATIC);

_tens = allocate([ 1, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 100, 0, 0, 0, 0, 0, 0, 0, 1e3, 0, 0, 0, 0, 0, 0, 0, 1e4, 0, 0, 0, 0, 0, 0, 0, 1e5, 0, 0, 0, 0, 0, 0, 0, 1e6, 0, 0, 0, 0, 0, 0, 0, 1e7, 0, 0, 0, 0, 0, 0, 0, 1e8, 0, 0, 0, 0, 0, 0, 0, 1e9, 0, 0, 0, 0, 0, 0, 0, 1e10, 0, 0, 0, 0, 0, 0, 0, 1e11, 0, 0, 0, 0, 0, 0, 0, 1e12, 0, 0, 0, 0, 0, 0, 0, 1e13, 0, 0, 0, 0, 0, 0, 0, 1e14, 0, 0, 0, 0, 0, 0, 0, 1e15, 0, 0, 0, 0, 0, 0, 0, 1e16, 0, 0, 0, 0, 0, 0, 0, 1e17, 0, 0, 0, 0, 0, 0, 0, 1e18, 0, 0, 0, 0, 0, 0, 0, 1e19, 0, 0, 0, 0, 0, 0, 0, 1e20, 0, 0, 0, 0, 0, 0, 0, 1e+21, 0, 0, 0, 0, 0, 0, 0, 1e+22, 0, 0, 0, 0, 0, 0, 0 ], [ "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0 ], ALLOC_STATIC);

_bigtens = allocate([ 1e16, 0, 0, 0, 0, 0, 0, 0, 1e+32, 0, 0, 0, 0, 0, 0, 0, 1e+64, 0, 0, 0, 0, 0, 0, 0, 1e+128, 0, 0, 0, 0, 0, 0, 0, 1e+256, 0, 0, 0, 0, 0, 0, 0 ], [ "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0 ], ALLOC_STATIC);

_p05 = allocate([ 5, 0, 0, 0, 25, 0, 0, 0, 125, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

_tinytens = allocate([ 1e-16, 0, 0, 0, 0, 0, 0, 0, 1e-32, 0, 0, 0, 0, 0, 0, 0, 1e-64, 0, 0, 0, 0, 0, 0, 0, 1e-128, 0, 0, 0, 0, 0, 0, 0, 8.112963841460668e-225, 0, 0, 0, 0, 0, 0, 0 ], [ "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str11107 = allocate([ 35, 100, 101, 112, 116, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str31109 = allocate([ 105, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str41110 = allocate([ 105, 102, 45, 101, 108, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str51111 = allocate([ 102, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str61112 = allocate([ 119, 104, 105, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str71113 = allocate([ 99, 111, 110, 116, 105, 110, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str81114 = allocate([ 100, 101, 99, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str91115 = allocate([ 112, 99, 100, 101, 108, 116, 97, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str101116 = allocate([ 97, 115, 115, 105, 103, 110, 111, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str111117 = allocate([ 99, 111, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str121118 = allocate([ 98, 114, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str131119 = allocate([ 104, 105, 100, 100, 101, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str141120 = allocate([ 112, 99, 98, 97, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str161122 = allocate([ 108, 97, 98, 101, 108, 98, 114, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str171123 = allocate([ 101, 110, 100, 98, 114, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str181124 = allocate([ 98, 114, 101, 97, 107, 50, 108, 97, 98, 101, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str191125 = allocate([ 99, 111, 110, 116, 50, 108, 97, 98, 101, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str201126 = allocate([ 115, 119, 105, 116, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str211127 = allocate([ 102, 117, 110, 99, 100, 101, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str221128 = allocate([ 99, 97, 116, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str231129 = allocate([ 101, 120, 116, 101, 110, 100, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str241130 = allocate([ 110, 101, 119, 108, 105, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str251131 = allocate([ 115, 101, 116, 108, 105, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str261132 = allocate([ 120, 100, 101, 108, 116, 97, 0 ], "i8", ALLOC_STATIC);

_js_SrcNoteSpec = allocate([ 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 2, 0, 1, undef, 0, 0, 0, 0, 3, 1, 1, undef, 0, 0, 0, 0, 1, 0, 1, undef, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 1, 1, 1, undef, 0, 0, 0, 0, 1, 0, 1, undef, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 1, 0, 1, undef, 0, 0, 0, 0, 1, 0, 1, undef, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 1, 0, -1, undef, 0, 0, 0, 0, 1, 0, 0, undef, 0, 0, 0, 0, 1, 0, 0, undef, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 1, 0, 0, undef, 0, 0, 0, 0, 1, 0, 0, undef, 0, 0, 0, 0, 2, 0, 1, undef, 0, 0, 0, 0, 1, 0, 0, undef, 0, 0, 0, 0, 1, 0, 1, undef, 0, 0, 0, 0, -1, 0, 0, undef, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 1, 0, 0, undef, 0, 0, 0, 0, 0, 0, 0, undef ], [ "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZL13statementName = allocate(60, "*", ALLOC_STATIC);

STRING_TABLE.__str271135 = allocate([ 108, 97, 98, 101, 108, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str281136 = allocate([ 105, 102, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str291137 = allocate([ 101, 108, 115, 101, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str301138 = allocate([ 100, 101, 115, 116, 114, 117, 99, 116, 117, 114, 105, 110, 103, 32, 98, 111, 100, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str311139 = allocate([ 115, 119, 105, 116, 99, 104, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL21js_with_statement_str = allocate([ 119, 105, 116, 104, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str331141 = allocate([ 99, 97, 116, 99, 104, 32, 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str341142 = allocate([ 116, 114, 121, 32, 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL20js_finally_block_str = allocate([ 102, 105, 110, 97, 108, 108, 121, 32, 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str351143 = allocate([ 100, 111, 32, 108, 111, 111, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str361144 = allocate([ 102, 111, 114, 32, 108, 111, 111, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str371145 = allocate([ 102, 111, 114, 47, 105, 110, 32, 108, 111, 111, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str381146 = allocate([ 119, 104, 105, 108, 101, 32, 108, 111, 111, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str401148 = allocate([ 115, 116, 100, 105, 110, 0 ], "i8", ALLOC_STATIC);

__ZN2js10ErrorClassE = allocate([ 0, 0, 0, 0, 234881029, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 698, 0, 0, 0, 86, 0, 0, 0, 700, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 702, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZL17exception_methods = allocate([ 0, 0, 0, 0, 704, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 706, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str1193 = allocate([ 117, 110, 107, 110, 111, 119, 110, 32, 40, 99, 97, 110, 39, 116, 32, 99, 111, 110, 118, 101, 114, 116, 32, 116, 111, 32, 115, 116, 114, 105, 110, 103, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str11194 = allocate([ 69, 114, 114, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str31196 = allocate([ 91, 117, 110, 107, 110, 111, 119, 110, 32, 102, 117, 110, 99, 116, 105, 111, 110, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str41197 = allocate([ 91, 111, 98, 106, 101, 99, 116, 32, 37, 115, 93, 0 ], "i8", ALLOC_STATIC);

__ZN2js26StrictArgumentsObjectClassE = allocate([ 0, 0, 0, 0, 16777733, 0, 0, 0, 10, 0, 0, 0, 708, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 710, 0, 0, 0, 712, 0, 0, 0, 86, 0, 0, 0, 714, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 716, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZN2js26NormalArgumentsObjectClassE = allocate([ 0, 0, 0, 0, 16777733, 0, 0, 0, 10, 0, 0, 0, 708, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 718, 0, 0, 0, 720, 0, 0, 0, 86, 0, 0, 0, 714, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 716, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str1263 = allocate([ 65, 114, 103, 117, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

__ZN2js12DeclEnvClassE = allocate([ 0, 0, 0, 0, 16777217, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str11264 = allocate([ 67, 97, 108, 108, 0 ], "i8", ALLOC_STATIC);

__ZN2js9CallClassE = allocate([ 0, 0, 0, 0, 131589, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 722, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 724, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZL15poisonPillProps = allocate([ 228, 0, 248, 0 ], [ "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN2js13FunctionClassE = allocate([ 0, 0, 0, 0, 33554965, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 726, 0, 0, 0, 728, 0, 0, 0, 86, 0, 0, 0, 730, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 732, 0, 0, 0, 734, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str31270 = allocate([ 98, 105, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str41271 = allocate([ 105, 115, 71, 101, 110, 101, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

__ZN2js16function_methodsE = allocate([ 0, 0, 0, 0, 736, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 738, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 740, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 742, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 744, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 746, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN2js2gc16slotsToThingKindE = allocate([ 0, 0, 0, 0, 2, 0, 0, 0, 2, 0, 0, 0, 4, 0, 0, 0, 4, 0, 0, 0, 6, 0, 0, 0, 6, 0, 0, 0, 6, 0, 0, 0, 6, 0, 0, 0, 8, 0, 0, 0, 8, 0, 0, 0, 8, 0, 0, 0, 8, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

__ZN2js2gc5Arena10ThingSizesE = allocate([ 40, 0, 0, 0, 40, 0, 0, 0, 56, 0, 0, 0, 56, 0, 0, 0, 72, 0, 0, 0, 72, 0, 0, 0, 104, 0, 0, 0, 104, 0, 0, 0, 136, 0, 0, 0, 136, 0, 0, 0, 168, 0, 0, 0, 168, 0, 0, 0, 80, 0, 0, 0, 104, 0, 0, 0, 40, 0, 0, 0, 32, 0, 0, 0, 72, 0, 0, 0, 32, 0, 0, 0, 16, 0, 0, 0, 16, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

__ZN2js2gc5Arena17FirstThingOffsetsE = allocate([ 16, 0, 0, 0, 16, 0, 0, 0, 64, 0, 0, 0, 64, 0, 0, 0, 64, 0, 0, 0, 64, 0, 0, 0, 40, 0, 0, 0, 40, 0, 0, 0, 16, 0, 0, 0, 16, 0, 0, 0, 64, 0, 0, 0, 64, 0, 0, 0, 16, 0, 0, 0, 40, 0, 0, 0, 16, 0, 0, 0, 32, 0, 0, 0, 64, 0, 0, 0, 32, 0, 0, 0, 16, 0, 0, 0, 16, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

__ZZN2js2gcL19MapAllocToTraceKindENS0_9AllocKindEE3map = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 4, 0, 0, 0, 5, 0, 0, 0, 3, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

__ZN2js8gcReasonE = allocate([ 10 ], [ "i32", 0, 0, 0, 0 ], ALLOC_STATIC);

__ZL19defaultHashAllocOps = allocate([ 748, 0, 0, 0, 750, 0, 0, 0, 752, 0, 0, 0, 754, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str1568 = allocate([ 91, 105, 110, 102, 101, 114, 32, 102, 97, 105, 108, 117, 114, 101, 93, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str11569 = allocate([ 47, 100, 105, 115, 107, 47, 108, 111, 99, 97, 108, 47, 106, 116, 101, 114, 114, 97, 99, 101, 47, 98, 117, 105, 108, 100, 98, 111, 116, 47, 115, 108, 97, 118, 101, 47, 106, 115, 95, 106, 115, 95, 66, 117, 105, 108, 100, 95, 65, 108, 108, 47, 98, 117, 105, 108, 100, 47, 98, 117, 105, 108, 100, 101, 114, 47, 98, 117, 105, 108, 100, 47, 109, 111, 122, 105, 108, 108, 97, 45, 99, 101, 110, 116, 114, 97, 108, 47, 106, 115, 47, 115, 114, 99, 47, 106, 115, 105, 110, 102, 101, 114, 46, 99, 112, 112, 0 ], "i8", ALLOC_STATIC);

__ZN2js5types15emptyTypeObjectE = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 33488904, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str231593 = allocate([ 67, 111, 117, 110, 116, 115, 58, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str261596 = allocate([ 32, 40, 37, 117, 32, 111, 118, 101, 114, 41, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str271597 = allocate([ 82, 101, 99, 111, 109, 112, 105, 108, 97, 116, 105, 111, 110, 115, 58, 32, 37, 117, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str471617 = allocate([ 85, 110, 107, 110, 111, 119, 110, 32, 98, 121, 116, 101, 99, 111, 100, 101, 32, 37, 48, 50, 120, 32, 97, 116, 32, 35, 37, 117, 58, 37, 48, 53, 117, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str481618 = allocate([ 85, 110, 107, 110, 111, 119, 110, 32, 98, 121, 116, 101, 99, 111, 100, 101, 32, 37, 48, 50, 120, 0 ], "i8", ALLOC_STATIC);

__ZTV18TypeConstraintProp = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 756, 0, 0, 0, 758, 0, 0, 0, 760, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV22TypeConstraintCallProp = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 762, 0, 0, 0, 758, 0, 0, 0, 760, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV24TypeConstraintSetElement = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 764, 0, 0, 0, 758, 0, 0, 0, 760, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV18TypeConstraintCall = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 766, 0, 0, 0, 758, 0, 0, 0, 760, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV19TypeConstraintArith = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 768, 0, 0, 0, 758, 0, 0, 0, 760, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV27TypeConstraintTransformThis = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 770, 0, 0, 0, 758, 0, 0, 0, 760, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV27TypeConstraintPropagateThis = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 772, 0, 0, 0, 758, 0, 0, 0, 760, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTVN2js5types14TypeConstraintE = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 444, 0, 0, 0, 758, 0, 0, 0, 760, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV27TypeConstraintLazyArguments = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 774, 0, 0, 0, 758, 0, 0, 0, 776, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV27TypeConstraintSubsetBarrier = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 778, 0, 0, 0, 758, 0, 0, 0, 760, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV29TypeConstraintFilterPrimitive = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 780, 0, 0, 0, 758, 0, 0, 0, 760, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV20TypeConstraintSubset = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 782, 0, 0, 0, 758, 0, 0, 0, 760, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV33TypeConstraintClearDefiniteSingle = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 784, 0, 0, 0, 758, 0, 0, 0, 760, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV33TypeConstraintClearDefiniteSetter = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 786, 0, 0, 0, 758, 0, 0, 0, 760, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZZL15InferSpewActiveN2js5types11SpewChannelEE6active = allocate(2, "i8", ALLOC_STATIC);

__ZZL15InferSpewActiveN2js5types11SpewChannelEE7checked_b = allocate(1, "i1", ALLOC_STATIC);

STRING_TABLE.__str741644 = allocate([ 73, 78, 70, 69, 82, 70, 76, 65, 71, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str751645 = allocate([ 111, 112, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str761646 = allocate([ 114, 101, 115, 117, 108, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str771647 = allocate([ 102, 117, 108, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1777 = allocate([ 78, 111, 83, 117, 99, 104, 77, 101, 116, 104, 111, 100, 0 ], "i8", ALLOC_STATIC);

_js_NoSuchMethodClass = allocate([ 0, 0, 0, 0, 131584, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 788, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZTV23GenericInterruptEnablerIiE = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 790, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTVN2js17InterpreterFrames20InterruptEnablerBaseE = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 444, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

STRING_TABLE.__str1907 = allocate([ 73, 116, 101, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

__ZN2js13IteratorClassE = allocate([ 0, 0, 0, 0, 369098769, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 792, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 794, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 796, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

_sCustomIteratorCount = allocate(1, "i32", ALLOC_STATIC);

__ZL16iterator_methods = allocate([ 0, 0, 0, 0, 798, 0, 0, 0, 0, 0, 4102, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN2js18StopIterationClassE = allocate([ 0, 0, 0, 0, 387973120, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 800, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str31916 = allocate([ 71, 101, 110, 101, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

__ZN2js14GeneratorClassE = allocate([ 0, 0, 0, 0, 1, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 802, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 804, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 796, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZL17generator_methods = allocate([ 0, 0, 0, 0, 806, 0, 0, 0, 0, 0, 4102, 0, 0, 0, 0, 0, 808, 0, 0, 0, 1, 0, 4102, 0, 0, 0, 0, 0, 810, 0, 0, 0, 1, 0, 4102, 0, 0, 0, 0, 0, 812, 0, 0, 0, 0, 0, 4102, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN2js9MathClassE = allocate([ 0, 0, 0, 0, 117440512, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str2000 = allocate([ 97, 98, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str12001 = allocate([ 97, 99, 111, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str22002 = allocate([ 97, 115, 105, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str32003 = allocate([ 97, 116, 97, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str42004 = allocate([ 97, 116, 97, 110, 50, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str52005 = allocate([ 99, 101, 105, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str62006 = allocate([ 99, 111, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str72007 = allocate([ 101, 120, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str82008 = allocate([ 102, 108, 111, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str92009 = allocate([ 108, 111, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str102010 = allocate([ 109, 97, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str112011 = allocate([ 109, 105, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str122012 = allocate([ 112, 111, 119, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str132013 = allocate([ 114, 97, 110, 100, 111, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str142014 = allocate([ 114, 111, 117, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str152015 = allocate([ 115, 105, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str162016 = allocate([ 115, 113, 114, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str172017 = allocate([ 116, 97, 110, 0 ], "i8", ALLOC_STATIC);

__ZL19math_static_methods = allocate([ 0, 0, 0, 0, 814, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 816, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 818, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 820, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 822, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 824, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 826, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 828, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 830, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 832, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 834, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 836, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 838, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 840, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 842, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 844, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 846, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 848, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 850, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZL14math_constants = allocate([ 2.718281828459045, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.4426950408889634, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, .4342944819032518, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, .6931471805599453, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2.302585092994046, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3.141592653589793, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.4142135623730951, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, .7071067811865476, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str182018 = allocate([ 69, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str192019 = allocate([ 76, 79, 71, 50, 69, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str202020 = allocate([ 76, 79, 71, 49, 48, 69, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str212021 = allocate([ 76, 78, 50, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str222022 = allocate([ 76, 78, 49, 48, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str232023 = allocate([ 80, 73, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str242024 = allocate([ 83, 81, 82, 84, 50, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str252025 = allocate([ 83, 81, 82, 84, 49, 95, 50, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_isNaN_str = allocate([ 105, 115, 78, 97, 78, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_isFinite_str = allocate([ 105, 115, 70, 105, 110, 105, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_parseFloat_str = allocate([ 112, 97, 114, 115, 101, 70, 108, 111, 97, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_parseInt_str = allocate([ 112, 97, 114, 115, 101, 73, 110, 116, 0 ], "i8", ALLOC_STATIC);

__ZL16number_functions = allocate([ 0, 0, 0, 0, 852, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 854, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 856, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 858, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN2js11NumberClassE = allocate([ 0, 0, 0, 0, 134217984, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str2072 = allocate([ 116, 111, 70, 105, 120, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str12073 = allocate([ 116, 111, 69, 120, 112, 111, 110, 101, 110, 116, 105, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str22074 = allocate([ 116, 111, 80, 114, 101, 99, 105, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

__ZL14number_methods = allocate([ 0, 0, 0, 0, 860, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 862, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 864, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 188, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 866, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 868, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 870, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

_js_NaN = allocate(1, "double", ALLOC_STATIC);

_js_PositiveInfinity = allocate(1, "double", ALLOC_STATIC);

_js_NegativeInfinity = allocate(1, "double", ALLOC_STATIC);

__ZL16number_constants = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.7976931348623157e+308, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str32081 = allocate([ 39, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str52083 = allocate([ 3, 0, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str62084 = allocate([ 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 97, 98, 99, 100, 101, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str72085 = allocate([ 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str82086 = allocate([ 80, 79, 83, 73, 84, 73, 86, 69, 95, 73, 78, 70, 73, 78, 73, 84, 89, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str92087 = allocate([ 78, 69, 71, 65, 84, 73, 86, 69, 95, 73, 78, 70, 73, 78, 73, 84, 89, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str102088 = allocate([ 77, 65, 88, 95, 86, 65, 76, 85, 69, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str112089 = allocate([ 77, 73, 78, 95, 86, 65, 76, 85, 69, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str122090 = allocate([ 40, 110, 101, 119, 32, 37, 115, 40, 37, 115, 41, 41, 0 ], "i8", ALLOC_STATIC);

__ZN2js5Shape15sharedNonNativeE = allocate([ -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i8", "i8", "i16", 0, "*", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

__ZN2js11ObjectClassE = allocate([ 0, 0, 0, 0, 16777216, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

_object_props = allocate([ 0, 0, 0, 0, 0, 68, 0, 0, 872, 0, 0, 0, 874, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

_sSetProtoCalled = allocate(1, "i32", ALLOC_STATIC);

STRING_TABLE.__str12178 = allocate([ 91, 111, 98, 106, 101, 99, 116, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str32180 = allocate([ 110, 117, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str42181 = allocate([ 98, 111, 111, 108, 101, 97, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_defineGetter_str = allocate([ 95, 95, 100, 101, 102, 105, 110, 101, 71, 101, 116, 116, 101, 114, 95, 95, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_defineSetter_str = allocate([ 95, 95, 100, 101, 102, 105, 110, 101, 83, 101, 116, 116, 101, 114, 95, 95, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_lookupGetter_str = allocate([ 95, 95, 108, 111, 111, 107, 117, 112, 71, 101, 116, 116, 101, 114, 95, 95, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_lookupSetter_str = allocate([ 95, 95, 108, 111, 111, 107, 117, 112, 83, 101, 116, 116, 101, 114, 95, 95, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_watch_str = allocate([ 119, 97, 116, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_unwatch_str = allocate([ 117, 110, 119, 97, 116, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_isPrototypeOf_str = allocate([ 105, 115, 80, 114, 111, 116, 111, 116, 121, 112, 101, 79, 102, 0 ], "i8", ALLOC_STATIC);

_object_methods = allocate([ 0, 0, 0, 0, 876, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 878, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 880, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 882, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 884, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 886, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 888, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 890, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 892, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 894, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 896, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 898, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 900, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str92206 = allocate([ 103, 101, 116, 80, 114, 111, 116, 111, 116, 121, 112, 101, 79, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str102207 = allocate([ 103, 101, 116, 79, 119, 110, 80, 114, 111, 112, 101, 114, 116, 121, 68, 101, 115, 99, 114, 105, 112, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str112208 = allocate([ 107, 101, 121, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str122209 = allocate([ 100, 101, 102, 105, 110, 101, 80, 114, 111, 112, 101, 114, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str132210 = allocate([ 100, 101, 102, 105, 110, 101, 80, 114, 111, 112, 101, 114, 116, 105, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str152212 = allocate([ 103, 101, 116, 79, 119, 110, 80, 114, 111, 112, 101, 114, 116, 121, 78, 97, 109, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str162213 = allocate([ 105, 115, 69, 120, 116, 101, 110, 115, 105, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str172214 = allocate([ 112, 114, 101, 118, 101, 110, 116, 69, 120, 116, 101, 110, 115, 105, 111, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str182215 = allocate([ 102, 114, 101, 101, 122, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str192216 = allocate([ 105, 115, 70, 114, 111, 122, 101, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str202217 = allocate([ 115, 101, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str212218 = allocate([ 105, 115, 83, 101, 97, 108, 101, 100, 0 ], "i8", ALLOC_STATIC);

_object_static_methods = allocate([ 0, 0, 0, 0, 902, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 904, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 906, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 908, 0, 0, 0, 3, 0, 4096, 0, 0, 0, 0, 0, 910, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 912, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 914, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 916, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 918, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 920, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 922, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 924, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 926, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str222221 = allocate([ 87, 105, 116, 104, 0 ], "i8", ALLOC_STATIC);

__ZN2js9WithClassE = allocate([ 0, 0, 0, 0, 131585, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 928, 0, 0, 0, 928, 0, 0, 0, 930, 0, 0, 0, 932, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 934, 0, 0, 0, 936, 0, 0, 0, 938, 0, 0, 0, 940, 0, 0, 0, 942, 0, 0, 0, 942, 0, 0, 0, 944, 0, 0, 0, 946, 0, 0, 0, 948, 0, 0, 0, 948, 0, 0, 0, 950, 0, 0, 0, 952, 0, 0, 0, 954, 0, 0, 0, 954, 0, 0, 0, 956, 0, 0, 0, 958, 0, 0, 0, 960, 0, 0, 0, 960, 0, 0, 0, 962, 0, 0, 0, 964, 0, 0, 0, 966, 0, 0, 0, 968, 0, 0, 0, 0, 0, 0, 0, 970, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str232224 = allocate([ 66, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

__ZN2js10BlockClassE = allocate([ 0, 0, 0, 0, 131329, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZL19lazy_prototype_init = allocate([ 972, 0, 0, 0, 450, 0, 0, 0, 448, 0, 0, 0, 452, 0, 0, 0, 454, 0, 0, 0, 476, 0, 0, 0, 456, 0, 0, 0, 458, 0, 0, 0, 460, 0, 0, 0, 462, 0, 0, 0, 466, 0, 0, 0, 468, 0, 0, 0, 470, 0, 0, 0, 472, 0, 0, 0, 464, 0, 0, 0, 464, 0, 0, 0, 464, 0, 0, 0, 464, 0, 0, 0, 464, 0, 0, 0, 464, 0, 0, 0, 464, 0, 0, 0, 464, 0, 0, 0, 474, 0, 0, 0, 474, 0, 0, 0, 478, 0, 0, 0, 478, 0, 0, 0, 478, 0, 0, 0, 478, 0, 0, 0, 478, 0, 0, 0, 478, 0, 0, 0, 478, 0, 0, 0, 478, 0, 0, 0, 478, 0, 0, 0, 478, 0, 0, 0, 482, 0, 0, 0, 972, 0, 0, 0, 480, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str242227 = allocate([ 112, 114, 105, 109, 105, 116, 105, 118, 101, 32, 116, 121, 112, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str262229 = allocate([ 37, 108, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str322235 = allocate([ 79, 98, 106, 101, 99, 116, 46, 105, 115, 83, 101, 97, 108, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str352238 = allocate([ 79, 98, 106, 101, 99, 116, 46, 115, 101, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str362239 = allocate([ 79, 98, 106, 101, 99, 116, 46, 112, 114, 101, 118, 101, 110, 116, 69, 120, 116, 101, 110, 115, 105, 111, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str372240 = allocate([ 79, 98, 106, 101, 99, 116, 46, 102, 114, 101, 101, 122, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str382241 = allocate([ 79, 98, 106, 101, 99, 116, 46, 105, 115, 69, 120, 116, 101, 110, 115, 105, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str392242 = allocate([ 79, 98, 106, 101, 99, 116, 46, 103, 101, 116, 79, 119, 110, 80, 114, 111, 112, 101, 114, 116, 121, 78, 97, 109, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str402243 = allocate([ 79, 98, 106, 101, 99, 116, 46, 99, 114, 101, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str412244 = allocate([ 110, 111, 116, 32, 97, 110, 32, 111, 98, 106, 101, 99, 116, 32, 111, 114, 32, 110, 117, 108, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str422245 = allocate([ 79, 98, 106, 101, 99, 116, 46, 100, 101, 102, 105, 110, 101, 80, 114, 111, 112, 101, 114, 116, 105, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str432246 = allocate([ 79, 98, 106, 101, 99, 116, 46, 100, 101, 102, 105, 110, 101, 80, 114, 111, 112, 101, 114, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str442247 = allocate([ 79, 98, 106, 101, 99, 116, 46, 107, 101, 121, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str452248 = allocate([ 79, 98, 106, 101, 99, 116, 46, 103, 101, 116, 79, 119, 110, 80, 114, 111, 112, 101, 114, 116, 121, 68, 101, 115, 99, 114, 105, 112, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str472250 = allocate([ 99, 97, 108, 108, 32, 116, 111, 32, 101, 118, 97, 108, 40, 41, 32, 98, 108, 111, 99, 107, 101, 100, 32, 98, 121, 32, 67, 83, 80, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL17WarnOnTooManyArgsP9JSContextRKN2js8CallArgsEE20TWO_ARGUMENT_WARNING = allocate([ 83, 117, 112, 112, 111, 114, 116, 32, 102, 111, 114, 32, 101, 118, 97, 108, 40, 99, 111, 100, 101, 44, 32, 115, 99, 111, 112, 101, 79, 98, 106, 101, 99, 116, 41, 32, 104, 97, 115, 32, 98, 101, 101, 110, 32, 114, 101, 109, 111, 118, 101, 100, 46, 32, 85, 115, 101, 32, 124, 119, 105, 116, 104, 32, 40, 115, 99, 111, 112, 101, 79, 98, 106, 101, 99, 116, 41, 32, 101, 118, 97, 108, 40, 99, 111, 100, 101, 41, 59, 124, 32, 105, 110, 115, 116, 101, 97, 100, 46, 0 ], "i8", ALLOC_STATIC);

__ZN2js9JSONClassE = allocate([ 0, 0, 0, 0, 83886080, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str12532 = allocate([ 115, 116, 114, 105, 110, 103, 105, 102, 121, 0 ], "i8", ALLOC_STATIC);

__ZL19json_static_methods = allocate([ 0, 0, 0, 0, 974, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 976, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 978, 0, 0, 0, 3, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str32534 = allocate([ 116, 114, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str42535 = allocate([ 102, 97, 108, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str52536 = allocate([ 92, 117, 48, 48, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2606 = allocate([ 110, 111, 32, 110, 117, 109, 98, 101, 114, 32, 97, 102, 116, 101, 114, 32, 109, 105, 110, 117, 115, 32, 115, 105, 103, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str12607 = allocate([ 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 110, 111, 110, 45, 100, 105, 103, 105, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str22608 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 100, 105, 103, 105, 116, 115, 32, 97, 102, 116, 101, 114, 32, 100, 101, 99, 105, 109, 97, 108, 32, 112, 111, 105, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str32609 = allocate([ 117, 110, 116, 101, 114, 109, 105, 110, 97, 116, 101, 100, 32, 102, 114, 97, 99, 116, 105, 111, 110, 97, 108, 32, 110, 117, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str42610 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 100, 105, 103, 105, 116, 115, 32, 97, 102, 116, 101, 114, 32, 101, 120, 112, 111, 110, 101, 110, 116, 32, 105, 110, 100, 105, 99, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str52611 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 100, 105, 103, 105, 116, 115, 32, 97, 102, 116, 101, 114, 32, 101, 120, 112, 111, 110, 101, 110, 116, 32, 115, 105, 103, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str62612 = allocate([ 101, 120, 112, 111, 110, 101, 110, 116, 32, 112, 97, 114, 116, 32, 105, 115, 32, 109, 105, 115, 115, 105, 110, 103, 32, 97, 32, 110, 117, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str72613 = allocate([ 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 101, 110, 100, 32, 111, 102, 32, 100, 97, 116, 97, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str82614 = allocate([ 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 107, 101, 121, 119, 111, 114, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str92615 = allocate([ 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str102616 = allocate([ 101, 110, 100, 32, 111, 102, 32, 100, 97, 116, 97, 32, 119, 104, 105, 108, 101, 32, 114, 101, 97, 100, 105, 110, 103, 32, 111, 98, 106, 101, 99, 116, 32, 99, 111, 110, 116, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str112617 = allocate([ 101, 120, 112, 101, 99, 116, 101, 100, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 110, 97, 109, 101, 32, 111, 114, 32, 39, 125, 39, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str122618 = allocate([ 101, 110, 100, 32, 111, 102, 32, 100, 97, 116, 97, 32, 119, 104, 101, 110, 32, 39, 44, 39, 32, 111, 114, 32, 39, 93, 39, 32, 119, 97, 115, 32, 101, 120, 112, 101, 99, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str132619 = allocate([ 101, 120, 112, 101, 99, 116, 101, 100, 32, 39, 44, 39, 32, 111, 114, 32, 39, 93, 39, 32, 97, 102, 116, 101, 114, 32, 97, 114, 114, 97, 121, 32, 101, 108, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str142620 = allocate([ 101, 110, 100, 32, 111, 102, 32, 100, 97, 116, 97, 32, 119, 104, 101, 110, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 110, 97, 109, 101, 32, 119, 97, 115, 32, 101, 120, 112, 101, 99, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str152621 = allocate([ 101, 120, 112, 101, 99, 116, 101, 100, 32, 100, 111, 117, 98, 108, 101, 45, 113, 117, 111, 116, 101, 100, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 110, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str162622 = allocate([ 101, 110, 100, 32, 111, 102, 32, 100, 97, 116, 97, 32, 97, 102, 116, 101, 114, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 110, 97, 109, 101, 32, 119, 104, 101, 110, 32, 39, 58, 39, 32, 119, 97, 115, 32, 101, 120, 112, 101, 99, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str172623 = allocate([ 101, 120, 112, 101, 99, 116, 101, 100, 32, 39, 58, 39, 32, 97, 102, 116, 101, 114, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 110, 97, 109, 101, 32, 105, 110, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str182624 = allocate([ 101, 110, 100, 32, 111, 102, 32, 100, 97, 116, 97, 32, 97, 102, 116, 101, 114, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 118, 97, 108, 117, 101, 32, 105, 110, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str192625 = allocate([ 101, 120, 112, 101, 99, 116, 101, 100, 32, 39, 44, 39, 32, 111, 114, 32, 39, 125, 39, 32, 97, 102, 116, 101, 114, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 118, 97, 108, 117, 101, 32, 105, 110, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str202626 = allocate([ 101, 120, 112, 101, 99, 116, 101, 100, 32, 39, 44, 39, 32, 111, 114, 32, 39, 125, 39, 32, 97, 102, 116, 101, 114, 32, 112, 114, 111, 112, 101, 114, 116, 121, 45, 118, 97, 108, 117, 101, 32, 112, 97, 105, 114, 32, 105, 110, 32, 111, 98, 106, 101, 99, 116, 32, 108, 105, 116, 101, 114, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str212627 = allocate([ 112, 114, 111, 112, 101, 114, 116, 121, 32, 110, 97, 109, 101, 115, 32, 109, 117, 115, 116, 32, 98, 101, 32, 100, 111, 117, 98, 108, 101, 45, 113, 117, 111, 116, 101, 100, 32, 115, 116, 114, 105, 110, 103, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str222628 = allocate([ 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 110, 111, 110, 45, 119, 104, 105, 116, 101, 115, 112, 97, 99, 101, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 97, 102, 116, 101, 114, 32, 74, 83, 79, 78, 32, 100, 97, 116, 97, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str232629 = allocate([ 117, 110, 116, 101, 114, 109, 105, 110, 97, 116, 101, 100, 32, 115, 116, 114, 105, 110, 103, 32, 108, 105, 116, 101, 114, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str242630 = allocate([ 98, 97, 100, 32, 99, 111, 110, 116, 114, 111, 108, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 105, 110, 32, 115, 116, 114, 105, 110, 103, 32, 108, 105, 116, 101, 114, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str252631 = allocate([ 98, 97, 100, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 105, 110, 32, 115, 116, 114, 105, 110, 103, 32, 108, 105, 116, 101, 114, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str262632 = allocate([ 98, 97, 100, 32, 85, 110, 105, 99, 111, 100, 101, 32, 101, 115, 99, 97, 112, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str272633 = allocate([ 98, 97, 100, 32, 101, 115, 99, 97, 112, 101, 100, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str282634 = allocate([ 117, 110, 116, 101, 114, 109, 105, 110, 97, 116, 101, 100, 32, 115, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

_js_CodeSpec = allocate([ 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 1, 1, 0, 2, 0, 0, 0, 0, 1, 1, 1, 0, 1048576, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1, 0, 2, 0, 0, 0, 0, 3, 0, 0, 0, 1, 0, 0, 0, 3, 1, 0, 4, 16385, 0, 0, 0, 3, 1, 0, 0, 1048577, 0, 0, 0, 1, 0, 1, 18, 0, 0, 0, 0, 1, 2, 2, 0, 0, 0, 0, 0, 3, -1, 0, 0, 3, 0, 0, 0, 1, 1, 2, 0, 0, 0, 0, 0, 1, 2, 4, 0, 0, 0, 0, 0, 3, 1, 1, 3, 290, 0, 0, 0, 1, 2, 1, 7, 65536, 0, 0, 0, 1, 2, 1, 8, 65536, 0, 0, 0, 1, 2, 1, 9, 65536, 0, 0, 0, 1, 2, 1, 10, 81920, 0, 0, 0, 1, 2, 1, 10, 81920, 0, 0, 0, 1, 2, 1, 11, 65536, 0, 0, 0, 1, 2, 1, 11, 65536, 0, 0, 0, 1, 2, 1, 11, 65536, 0, 0, 0, 1, 2, 1, 11, 65536, 0, 0, 0, 1, 2, 1, 12, 65536, 0, 0, 0, 1, 2, 1, 12, 65536, 0, 0, 0, 1, 2, 1, 12, 65536, 0, 0, 0, 1, 2, 1, 13, 65536, 0, 0, 0, 1, 2, 1, 13, 65536, 0, 0, 0, 1, 2, 1, 14, 65536, 0, 0, 0, 1, 2, 1, 14, 65536, 0, 0, 0, 1, 2, 1, 14, 65536, 0, 0, 0, 1, 1, 1, 15, 16384, 0, 0, 0, 1, 1, 1, 15, 0, 0, 0, 0, 1, 1, 1, 15, 0, 0, 0, 0, 1, 1, 1, 15, 0, 0, 0, 0, 3, 0, 1, 15, 546, 0, 0, 0, 3, 1, 1, 15, 578, 0, 0, 0, 1, 2, 1, 15, 608, 0, 0, 0, 1, 1, 1, 15, 16384, 0, 0, 0, 1, 1, 1, 15, 0, 0, 0, 0, 4, 0, 1, 15, 146802722, 0, 0, 0, 4, 1, 1, 15, 146802754, 0, 0, 0, 2, 2, 1, 15, 142608480, 0, 0, 0, 4, 0, 1, 15, 146801698, 0, 0, 0, 4, 1, 1, 15, 146801730, 0, 0, 0, 2, 2, 1, 15, 142607456, 0, 0, 0, 4, 0, 1, 15, 146806818, 0, 0, 0, 4, 1, 1, 15, 146806850, 0, 0, 0, 2, 2, 1, 15, 142612576, 0, 0, 0, 4, 0, 1, 15, 146805794, 0, 0, 0, 4, 1, 1, 15, 146805826, 0, 0, 0, 2, 2, 1, 15, 142611552, 0, 0, 0, 3, 1, 1, 18, 67108930, 0, 0, 0, 3, 2, 1, 3, 16706, 0, 0, 0, 1, 2, 1, 18, 67174496, 0, 0, 0, 1, 3, 1, 3, 16736, 0, 0, 0, 3, 0, 2, 19, 67633186, 0, 0, 0, 3, -1, 1, 18, 69206019, 0, 0, 0, 3, 0, 1, 19, 67108898, 0, 0, 0, 3, 0, 1, 16, 2, 0, 0, 0, 3, 0, 1, 19, 2, 0, 0, 0, 1, 0, 1, 16, 0, 0, 0, 0, 1, 0, 1, 16, 0, 0, 0, 0, 1, 0, 1, 19, 0, 0, 0, 0, 1, 0, 1, 19, 0, 0, 0, 0, 1, 0, 1, 19, 0, 0, 0, 0, 1, 0, 1, 19, 0, 0, 0, 0, 3, 1, 0, 5, 81921, 0, 0, 0, 3, 1, 0, 6, 81921, 0, 0, 0, -1, 1, 0, 0, 1064964, 0, 0, 0, -1, 1, 0, 0, 1064965, 0, 0, 0, 1, 2, 1, 10, 81920, 0, 0, 0, 1, 2, 1, 10, 81920, 0, 0, 0, 1, 1, 2, 18, 0, 0, 0, 0, 2, 1, 1, 0, 13, 0, 0, 0, 1, 1, 2, 0, 0, 0, 0, 0, 2, 0, 1, 0, 13, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 3, -1, 1, 18, 69206019, 0, 0, 0, 3, 0, 1, 19, 15, 0, 0, 0, 1, 1, 0, 2, 0, 0, 0, 0, 3, -1, 1, 17, 69206019, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 3, 0, 1, 19, 38, 0, 0, 0, 3, 1, 1, 3, 294, 0, 0, 0, 3, 0, 1, 19, 39, 0, 0, 0, 3, 1, 1, 3, 16679, 0, 0, 0, 3, 0, 1, 16, 3, 0, 0, 0, 3, 0, 1, 19, 13, 0, 0, 0, 4, 0, 1, 19, 12, 0, 0, 0, 3, 0, 1, 19, 15, 0, 0, 0, 1, 0, 0, 19, 0, 0, 0, 0, 3, 2, 1, 3, 16706, 0, 0, 0, 1, 3, 1, 3, 16736, 0, 0, 0, 5, 0, 0, 0, 16777236, 0, 0, 0, 5, 0, 1, 0, 16777236, 0, 0, 0, 3, 0, 1, 15, 12584998, 0, 0, 0, 3, 0, 1, 15, 12583974, 0, 0, 0, 3, 0, 1, 15, 12589094, 0, 0, 0, 3, 0, 1, 15, 12588070, 0, 0, 0, 3, 0, 1, 15, 12584999, 0, 0, 0, 3, 0, 1, 15, 12583975, 0, 0, 0, 3, 0, 1, 15, 12589095, 0, 0, 0, 3, 0, 1, 15, 12588071, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 3, 0, 1, 19, 0, 0, 0, 0, 3, 0, 2, 19, 0, 0, 0, 0, 3, -1, 1, 18, 69206019, 0, 0, 0, 3, 0, 0, 0, 3, 0, 0, 0, 3, 0, 1, 0, 290, 0, 0, 0, 3, 2, 1, 3, 16674, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 1, 2, 1, 11, 65536, 0, 0, 0, 1, 2, 1, 11, 4259840, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 1, 0, 0, 0, 1, 2, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 3, 0, 0, 0, 3, 0, 0, 0, 1, 0, 0, 0, 1048576, 0, 0, 0, 3, 2, 1, 0, 8388609, 0, 0, 0, 3, 1, 0, 0, 1, 0, 0, 0, 3, -1, 1, 18, 69206019, 0, 0, 0, 1, 3, 0, 3, 4194560, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 131087, 0, 0, 0, 3, 0, 0, 0, 131074, 0, 0, 0, 3, 0, 0, 0, 131074, 0, 0, 0, 3, 0, 1, 19, 15, 0, 0, 0, 1, 0, 1, 19, 0, 0, 0, 0, 3, 1, 0, 3, 295, 0, 0, 0, 2, 0, 0, 0, 8388621, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0, 0, 0, 0, 3, 0, 1, 19, 67108899, 0, 0, 0, 3, 0, 2, 19, 67633187, 0, 0, 0, 3, 0, 1, 18, 38, 0, 0, 0, 1, 0, 1, 18, 0, 0, 0, 0, 5, 0, 0, 0, 4325392, 0, 0, 0, 5, 0, 0, 0, 9, 0, 0, 0, 5, 1, 0, 4, 16393, 0, 0, 0, 5, 1, 0, 0, 1048585, 0, 0, 0, 5, 1, 0, 5, 16393, 0, 0, 0, 5, 1, 0, 6, 16393, 0, 0, 0, 5, 0, 0, 0, 9, 0, 0, 0, 5, 2, 1, 0, 9, 0, 0, 0, 5, 1, 0, 0, 9, 0, 0, 0, -1, 1, 0, 0, 1064970, 0, 0, 0, -1, 1, 0, 0, 1064971, 0, 0, 0, 3, 0, 0, 0, 32769, 0, 0, 0, 3, 1, 0, 0, 32769, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1, 0, 2, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 3, 0, 1, 19, 100663330, 0, 0, 0, 3, 2, 1, 3, 33571106, 0, 0, 0, 4, 0, 1, 15, 180357154, 0, 0, 0, 4, 0, 1, 15, 180356130, 0, 0, 0, 4, 0, 1, 15, 180361250, 0, 0, 0, 4, 0, 1, 15, 180360226, 0, 0, 0, 3, 0, 1, 19, 17, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 19, 128, 0, 0, 0, 3, 0, 1, 19, 130, 0, 0, 0, 3, 1, 1, 19, 130, 0, 0, 0, 1, 2, 1, 0, 128, 0, 0, 0, 1, 1, 1, 19, 128, 0, 0, 0, 1, 1, 1, 19, 0, 0, 0, 0, 1, 2, 1, 13, 0, 0, 0, 0, 1, 2, 1, 13, 0, 0, 0, 0, 1, 1, 2, 3, 256, 0, 0, 0, 1, 3, 1, 3, 16640, 0, 0, 0, 1, 1, 1, 19, 0, 0, 0, 0, 1, 2, 1, 18, 0, 0, 0, 0, 3, 1, 1, 0, 1, 0, 0, 0, 3, 2, 1, 18, 1, 0, 0, 0, 1, 1, 1, 19, 0, 0, 0, 0, 1, 1, 1, 19, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 3, 0, 0, 0, 3, 0, 0, 0, 3, 0, 1, 19, 2, 0, 0, 0, 3, 0, 1, 19, 2, 0, 0, 0, 3, 1, 1, 19, 2, 0, 0, 0, 1, 2, 1, 15, 608, 0, 0, 0, 3, 1, 2, 18, 80216130, 0, 0, 0, 3, 0, 0, 0, 15, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 4, 0, 1, 16, 12, 0, 0, 0, 2, 0, 0, 0, 262157, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 2, 2, 18, 67698784, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 3, 1, 1, 18, 67108930, 0, 0, 0, 1, 1, 2, 19, 524288, 0, 0, 0, 1, 1, 1, 15, 16384, 0, 0, 0, 3, 0, -1, 0, 15, 0, 0, 0, 5, -1, 0, 0, 3, 0, 0, 0, 3, 1, 1, 0, 16385, 0, 0, 0, 2, 1, 1, 0, 18, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 3, 1, 0, 3, 7, 0, 0, 0, 1, 0, 1, 19, 0, 0, 0, 0, 1, 3, 0, 3, 256, 0, 0, 0, 5, -1, 1, 3, 3, 0, 0, 0, 1, 0, 0, 0, 262144, 0, 0, 0, 1, 0, 0, 0, 262144, 0, 0, 0, 1, 0, 0, 0, 262144, 0, 0, 0, 3, 0, 2, 19, 101187618, 0, 0, 0, 3, 0, 2, 19, 524327, 0, 0, 0, 3, 0, 2, 19, 524326, 0, 0, 0, 3, 0, 1, 0, 33554722, 0, 0, 0, 2, 0, 1, 16, 18, 0, 0, 0, 5, 0, 1, 16, 14, 0, 0, 0, 3, 1, 1, 18, 67108930, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 3, 0, 0, 0, 131087, 0, 0, 0, 5, 0, 0, 0, 4325392, 0, 0, 0, 3, 0, 1, 19, 15, 0, 0, 0, 3, 0, 0, 0, 3, 0, 0, 0, 3, 2, 1, 3, 16706, 0, 0, 0, 3, 2, 1, 3, 16706, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 16777219, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0 ], [ "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str192692 = allocate([ 45, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str202693 = allocate([ 43, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str252698 = allocate([ 60, 110, 101, 120, 116, 62, 0 ], "i8", ALLOC_STATIC);

__ZL9CodeToken = allocate(928, "*", ALLOC_STATIC);

STRING_TABLE._js_EscapeMap = allocate([ 8, 98, 12, 102, 10, 110, 13, 114, 9, 116, 11, 118, 34, 34, 39, 39, 92, 92, 0, 48 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL15native_code_str = allocate([ 9, 91, 110, 97, 116, 105, 118, 101, 32, 99, 111, 100, 101, 93, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str282701 = allocate([ 9, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str292702 = allocate([ 40, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str302703 = allocate([ 37, 115, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str312704 = allocate([ 41, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str322705 = allocate([ 9, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str342707 = allocate([ 41, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str352708 = allocate([ 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str362709 = allocate([ 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str382711 = allocate([ 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str392712 = allocate([ 40, 37, 115, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16exception_cookie = allocate([ 47, 42, 69, 88, 67, 69, 80, 84, 73, 79, 78, 42, 47, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16retsub_pc_cookie = allocate([ 47, 42, 82, 69, 84, 83, 85, 66, 95, 80, 67, 42, 47, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE14forelem_cookie = allocate([ 47, 42, 70, 79, 82, 69, 76, 69, 77, 42, 47, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE11with_cookie = allocate([ 47, 42, 87, 73, 84, 72, 42, 47, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE13predot_format = allocate([ 37, 115, 37, 115, 46, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE14postdot_format = allocate([ 37, 115, 46, 37, 115, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE15preindex_format = allocate([ 37, 115, 37, 115, 91, 37, 115, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16postindex_format = allocate([ 37, 115, 91, 37, 115, 93, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE10sss_format = allocate([ 37, 115, 37, 115, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str402713 = allocate([ 37, 115, 32, 37, 115, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str412714 = allocate([ 9, 100, 111, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str422715 = allocate([ 9, 125, 32, 119, 104, 105, 108, 101, 32, 40, 37, 115, 41, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str432716 = allocate([ 9, 102, 111, 114, 32, 40, 37, 115, 59, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str442717 = allocate([ 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str452718 = allocate([ 59, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str462719 = allocate([ 9, 125, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str472720 = allocate([ 9, 37, 115, 58, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str482721 = allocate([ 9, 37, 115, 58, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str522725 = allocate([ 9, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str532726 = allocate([ 9, 116, 114, 121, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str542727 = allocate([ 9, 125, 32, 102, 105, 110, 97, 108, 108, 121, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str552728 = allocate([ 37, 115, 91, 93, 32, 61, 32, 91, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str562729 = allocate([ 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str572730 = allocate([ 9, 108, 101, 116, 32, 40, 37, 115, 41, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str582731 = allocate([ 9, 37, 115, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str592732 = allocate([ 37, 115, 44, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str602733 = allocate([ 108, 101, 116, 32, 40, 37, 115, 41, 32, 40, 37, 115, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str612734 = allocate([ 108, 101, 116, 32, 40, 37, 115, 41, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str622735 = allocate([ 9, 40, 37, 115, 41, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str632736 = allocate([ 9, 119, 105, 116, 104, 32, 40, 37, 115, 41, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str642737 = allocate([ 9, 125, 32, 99, 97, 116, 99, 104, 32, 40, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str652738 = allocate([ 32, 105, 102, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str662739 = allocate([ 40, 37, 115, 41, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str672740 = allocate([ 9, 37, 115, 32, 37, 115, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str682741 = allocate([ 37, 115, 32, 40, 37, 115, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str692742 = allocate([ 37, 115, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str702743 = allocate([ 32, 37, 115, 32, 40, 37, 115, 32, 105, 110, 32, 37, 115, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL15js_for_each_str = allocate([ 102, 111, 114, 32, 101, 97, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str712744 = allocate([ 9, 37, 115, 32, 40, 37, 115, 37, 115, 32, 105, 110, 32, 37, 115, 41, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str722745 = allocate([ 9, 119, 104, 105, 108, 101, 32, 40, 37, 115, 41, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str732746 = allocate([ 9, 99, 111, 110, 116, 105, 110, 117, 101, 32, 37, 115, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str742747 = allocate([ 9, 99, 111, 110, 116, 105, 110, 117, 101, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str752748 = allocate([ 9, 98, 114, 101, 97, 107, 32, 37, 115, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str762749 = allocate([ 9, 98, 114, 101, 97, 107, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str772750 = allocate([ 32, 105, 102, 32, 40, 37, 115, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str782751 = allocate([ 32, 105, 102, 32, 40, 37, 115, 41, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str792752 = allocate([ 9, 105, 102, 32, 40, 37, 115, 41, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str802753 = allocate([ 9, 125, 32, 101, 108, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str812754 = allocate([ 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str822755 = allocate([ 37, 115, 32, 63, 32, 37, 115, 32, 58, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str842757 = allocate([ 37, 115, 32, 37, 115, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str852758 = allocate([ 37, 42, 115, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str872760 = allocate([ 37, 115, 37, 115, 32, 61, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str882761 = allocate([ 37, 115, 32, 37, 115, 61, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str892762 = allocate([ 37, 115, 32, 37, 115, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str902763 = allocate([ 37, 115, 32, 37, 115, 91, 37, 115, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str912764 = allocate([ 37, 115, 32, 37, 115, 46, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str922765 = allocate([ 37, 115, 32, 37, 115, 46, 46, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL13js_incop_strs = allocate([ 43, 43, 0, 45, 45, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str932766 = allocate([ 37, 115, 91, 37, 115, 93, 32, 37, 115, 61, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str942767 = allocate([ 37, 115, 46, 37, 115, 32, 37, 115, 61, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str952768 = allocate([ 37, 115, 91, 37, 100, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str982771 = allocate([ 9, 99, 97, 115, 101, 32, 37, 115, 58, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str992772 = allocate([ 35, 37, 117, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1002773 = allocate([ 91, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1012774 = allocate([ 123, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1022775 = allocate([ 37, 115, 37, 115, 37, 99, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1032776 = allocate([ 37, 115, 37, 115, 37, 115, 32, 37, 115, 37, 115, 37, 46, 42, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1052778 = allocate([ 37, 115, 37, 115, 37, 115, 58, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1062779 = allocate([ 35, 37, 117, 61, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1072780 = allocate([ 35, 37, 117, 35, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1082781 = allocate([ 9, 100, 101, 98, 117, 103, 103, 101, 114, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1092782 = allocate([ 9, 37, 115, 32, 37, 115, 32, 37, 115, 32, 61, 32, 37, 115, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1102783 = allocate([ 64, 42, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1112784 = allocate([ 64, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1122785 = allocate([ 37, 115, 58, 58, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1132786 = allocate([ 37, 115, 58, 58, 91, 37, 115, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1142787 = allocate([ 64, 91, 37, 115, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1152788 = allocate([ 37, 115, 61, 34, 37, 115, 34, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1162789 = allocate([ 37, 115, 61, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1172790 = allocate([ 123, 37, 115, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1182791 = allocate([ 60, 62, 37, 115, 60, 47, 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1192792 = allocate([ 37, 115, 46, 40, 37, 115, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1202793 = allocate([ 37, 115, 46, 46, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1212794 = allocate([ 60, 33, 91, 67, 68, 65, 84, 65, 91, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1222795 = allocate([ 93, 93, 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1232796 = allocate([ 60, 33, 45, 45, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1242797 = allocate([ 45, 45, 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1252798 = allocate([ 60, 63, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1262799 = allocate([ 63, 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1272800 = allocate([ 9, 115, 119, 105, 116, 99, 104, 32, 40, 37, 115, 41, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1282801 = allocate([ 9, 37, 115, 58, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1292802 = allocate([ 45, 48, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1302803 = allocate([ 48, 32, 47, 32, 48, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1312804 = allocate([ 49, 32, 47, 32, 45, 48, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1322805 = allocate([ 49, 32, 47, 32, 48, 0 ], "i8", ALLOC_STATIC);

__ZL10var_prefix = allocate(12, "*", ALLOC_STATIC);

STRING_TABLE.__str1332806 = allocate([ 118, 97, 114, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1342807 = allocate([ 99, 111, 110, 115, 116, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1352808 = allocate([ 108, 101, 116, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1362809 = allocate([ 37, 115, 91, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1372810 = allocate([ 93, 32, 61, 32, 91, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1382811 = allocate([ 44, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1392812 = allocate([ 37, 115, 46, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1402813 = allocate([ 37, 115, 91, 37, 115, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1412814 = allocate([ 37, 103, 58, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1422815 = allocate([ 58, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1432816 = allocate([ 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1442817 = allocate([ 9, 47, 42, 32, 117, 115, 101, 32, 115, 116, 114, 105, 99, 116, 32, 42, 47, 32, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1452818 = allocate([ 9, 34, 117, 115, 101, 32, 115, 116, 114, 105, 99, 116, 34, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1462819 = allocate([ 37, 99, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1472820 = allocate([ 92, 37, 99, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1482821 = allocate([ 92, 120, 37, 48, 50, 88, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1492822 = allocate([ 92, 117, 37, 48, 52, 88, 0 ], "i8", ALLOC_STATIC);

_table = allocate(24, "*", ALLOC_STATIC);

STRING_TABLE.__ZL14js_unknown_str = allocate([ 117, 110, 107, 110, 111, 119, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str12882 = allocate([ 103, 101, 116, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str22883 = allocate([ 110, 111, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str42885 = allocate([ 115, 101, 116, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str52886 = allocate([ 111, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL14incop_name_str = allocate([ 105, 110, 99, 114, 101, 109, 101, 110, 116, 0, 100, 101, 99, 114, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL15js_variable_str = allocate([ 118, 97, 114, 105, 97, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str12967 = allocate([ 115, 116, 111, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str22968 = allocate([ 114, 101, 115, 101, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str32969 = allocate([ 99, 97, 110, 77, 101, 97, 115, 117, 114, 101, 83, 111, 109, 101, 116, 104, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

__ZL6pm_fns = allocate([ 0, 0, 0, 0, 980, 0, 0, 0, 0, 0, 4166, 0, 0, 0, 0, 0, 982, 0, 0, 0, 0, 0, 4166, 0, 0, 0, 0, 0, 984, 0, 0, 0, 0, 0, 4166, 0, 0, 0, 0, 0, 986, 0, 0, 0, 0, 0, 4166, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str42970 = allocate([ 80, 101, 114, 102, 77, 101, 97, 115, 117, 114, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

__ZL8pm_class = allocate([ 0, 0, 0, 0, 1, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 988, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

__ZL8pm_props = allocate([ 0, 0, 0, 0, 0, 71, 0, 0, 990, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 992, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 994, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 996, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 998, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1e3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1002, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1004, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1006, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1008, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1010, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1012, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

__ZL9pm_consts = allocate([ 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 16, 0, 0, 0, 0, 0, 0, 0, 32, 0, 0, 0, 0, 0, 0, 0, 64, 0, 0, 0, 0, 0, 0, 0, 128, 0, 0, 0, 0, 0, 0, 0, 256, 0, 0, 0, 0, 0, 0, 0, 512, 0, 0, 0, 0, 0, 0, 0, 1024, 0, 0, 0, 0, 0, 0, 0, 2047, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str52971 = allocate([ 67, 80, 85, 95, 67, 89, 67, 76, 69, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str62972 = allocate([ 73, 78, 83, 84, 82, 85, 67, 84, 73, 79, 78, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str72973 = allocate([ 67, 65, 67, 72, 69, 95, 82, 69, 70, 69, 82, 69, 78, 67, 69, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str82974 = allocate([ 67, 65, 67, 72, 69, 95, 77, 73, 83, 83, 69, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str92975 = allocate([ 66, 82, 65, 78, 67, 72, 95, 73, 78, 83, 84, 82, 85, 67, 84, 73, 79, 78, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str102976 = allocate([ 66, 82, 65, 78, 67, 72, 95, 77, 73, 83, 83, 69, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str112977 = allocate([ 66, 85, 83, 95, 67, 89, 67, 76, 69, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str122978 = allocate([ 80, 65, 71, 69, 95, 70, 65, 85, 76, 84, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str132979 = allocate([ 77, 65, 74, 79, 82, 95, 80, 65, 71, 69, 95, 70, 65, 85, 76, 84, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str142980 = allocate([ 67, 79, 78, 84, 69, 88, 84, 95, 83, 87, 73, 84, 67, 72, 69, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str152981 = allocate([ 67, 80, 85, 95, 77, 73, 71, 82, 65, 84, 73, 79, 78, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str162982 = allocate([ 65, 76, 76, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str172983 = allocate([ 78, 85, 77, 95, 77, 69, 65, 83, 85, 82, 65, 66, 76, 69, 95, 69, 86, 69, 78, 84, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str182984 = allocate([ 99, 112, 117, 95, 99, 121, 99, 108, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str192985 = allocate([ 105, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str202986 = allocate([ 99, 97, 99, 104, 101, 95, 114, 101, 102, 101, 114, 101, 110, 99, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str212987 = allocate([ 99, 97, 99, 104, 101, 95, 109, 105, 115, 115, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str222988 = allocate([ 98, 114, 97, 110, 99, 104, 95, 105, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str232989 = allocate([ 98, 114, 97, 110, 99, 104, 95, 109, 105, 115, 115, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str242990 = allocate([ 98, 117, 115, 95, 99, 121, 99, 108, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str252991 = allocate([ 112, 97, 103, 101, 95, 102, 97, 117, 108, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str262992 = allocate([ 109, 97, 106, 111, 114, 95, 112, 97, 103, 101, 95, 102, 97, 117, 108, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str272993 = allocate([ 99, 111, 110, 116, 101, 120, 116, 95, 115, 119, 105, 116, 99, 104, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str282994 = allocate([ 99, 112, 117, 95, 109, 105, 103, 114, 97, 116, 105, 111, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str292995 = allocate([ 101, 118, 101, 110, 116, 115, 77, 101, 97, 115, 117, 114, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str302996 = allocate([ 117, 0 ], "i8", ALLOC_STATIC);

__str23014 = allocate(2, "i8", ALLOC_STATIC);

STRING_TABLE.__str33015 = allocate([ 40, 110, 117, 108, 108, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str3048 = allocate([ 91, 111, 98, 106, 101, 99, 116, 32, 70, 117, 110, 99, 116, 105, 111, 110, 93, 0 ], "i8", ALLOC_STATIC);

__ZL27sScriptedProxyHandlerFamily = allocate(1, "i32", ALLOC_STATIC);

__ZTV22JSScriptedProxyHandler = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 1014, 0, 0, 0, 1016, 0, 0, 0, 1018, 0, 0, 0, 1020, 0, 0, 0, 1022, 0, 0, 0, 1024, 0, 0, 0, 1026, 0, 0, 0, 1028, 0, 0, 0, 1030, 0, 0, 0, 1032, 0, 0, 0, 1034, 0, 0, 0, 1036, 0, 0, 0, 1038, 0, 0, 0, 1040, 0, 0, 0, 1042, 0, 0, 0, 1044, 0, 0, 0, 1046, 0, 0, 0, 1048, 0, 0, 0, 1050, 0, 0, 0, 1052, 0, 0, 0, 1054, 0, 0, 0, 1056, 0, 0, 0, 1058, 0, 0, 0, 1060, 0, 0, 0, 1062, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZN22JSScriptedProxyHandler9singletonE = allocate(8, "*", ALLOC_STATIC);

STRING_TABLE.__str33051 = allocate([ 80, 114, 111, 120, 121, 0 ], "i8", ALLOC_STATIC);

__ZN2js16ObjectProxyClassE = allocate([ 0, 0, 0, 0, 525056, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 1064, 0, 0, 0, 1066, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1068, 0, 0, 0, 1070, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1072, 0, 0, 0, 1072, 0, 0, 0, 1074, 0, 0, 0, 1076, 0, 0, 0, 1078, 0, 0, 0, 1078, 0, 0, 0, 1080, 0, 0, 0, 1082, 0, 0, 0, 1084, 0, 0, 0, 1086, 0, 0, 0, 1088, 0, 0, 0, 1090, 0, 0, 0, 1092, 0, 0, 0, 1092, 0, 0, 0, 1094, 0, 0, 0, 1096, 0, 0, 0, 1098, 0, 0, 0, 1098, 0, 0, 0, 1100, 0, 0, 0, 1102, 0, 0, 0, 1104, 0, 0, 0, 1104, 0, 0, 0, 1106, 0, 0, 0, 1108, 0, 0, 0, 1110, 0, 0, 0, 1110, 0, 0, 0, 1112, 0, 0, 0, 1114, 0, 0, 0, 0, 0, 0, 0, 1116, 0, 0, 0, 1118, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZN2js21OuterWindowProxyClassE = allocate([ 0, 0, 0, 0, 525056, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 1066, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1070, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1120, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1072, 0, 0, 0, 1072, 0, 0, 0, 1074, 0, 0, 0, 1076, 0, 0, 0, 1078, 0, 0, 0, 1078, 0, 0, 0, 1080, 0, 0, 0, 1082, 0, 0, 0, 1084, 0, 0, 0, 1086, 0, 0, 0, 1088, 0, 0, 0, 1090, 0, 0, 0, 1092, 0, 0, 0, 1092, 0, 0, 0, 1094, 0, 0, 0, 1096, 0, 0, 0, 1098, 0, 0, 0, 1098, 0, 0, 0, 1100, 0, 0, 0, 1102, 0, 0, 0, 1104, 0, 0, 0, 1104, 0, 0, 0, 1106, 0, 0, 0, 1108, 0, 0, 0, 1110, 0, 0, 0, 1110, 0, 0, 0, 1112, 0, 0, 0, 1114, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZN2js18FunctionProxyClassE = allocate([ 0, 0, 0, 0, 525568, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1122, 0, 0, 0, 1124, 0, 0, 0, 0, 0, 0, 0, 732, 0, 0, 0, 1126, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1072, 0, 0, 0, 1072, 0, 0, 0, 1074, 0, 0, 0, 1076, 0, 0, 0, 1078, 0, 0, 0, 1078, 0, 0, 0, 1080, 0, 0, 0, 1082, 0, 0, 0, 1084, 0, 0, 0, 1086, 0, 0, 0, 1088, 0, 0, 0, 1090, 0, 0, 0, 1092, 0, 0, 0, 1092, 0, 0, 0, 1094, 0, 0, 0, 1096, 0, 0, 0, 1098, 0, 0, 0, 1098, 0, 0, 0, 1100, 0, 0, 0, 1102, 0, 0, 0, 1104, 0, 0, 0, 1104, 0, 0, 0, 1106, 0, 0, 0, 1108, 0, 0, 0, 1110, 0, 0, 0, 1110, 0, 0, 0, 1112, 0, 0, 0, 1114, 0, 0, 0, 0, 0, 0, 0, 1116, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str53058 = allocate([ 99, 114, 101, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str63059 = allocate([ 99, 114, 101, 97, 116, 101, 70, 117, 110, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

__ZL14static_methods = allocate([ 0, 0, 0, 0, 1128, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 1130, 0, 0, 0, 3, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str73060 = allocate([ 70, 117, 110, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

__ZN2js19CallableObjectClassE = allocate([ 0, 0, 0, 0, 512, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1132, 0, 0, 0, 1134, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZN2js10ProxyClassE = allocate([ 0, 0, 0, 0, 570425344, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str3152 = allocate([ 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str13153 = allocate([ 43, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str23154 = allocate([ 45, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str33155 = allocate([ 42, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str43156 = allocate([ 47, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str53157 = allocate([ 37, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str63158 = allocate([ 60, 60, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str73159 = allocate([ 62, 62, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str83160 = allocate([ 62, 62, 62, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str93161 = allocate([ 124, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str103162 = allocate([ 94, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str113163 = allocate([ 38, 61, 0 ], "i8", ALLOC_STATIC);

__ZN2js8aopNamesE = allocate(48, "*", ALLOC_STATIC);

STRING_TABLE.__str123164 = allocate([ 61, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str133165 = allocate([ 33, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str143166 = allocate([ 61, 61, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str153167 = allocate([ 33, 61, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str163168 = allocate([ 60, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str173169 = allocate([ 60, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str183170 = allocate([ 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str193171 = allocate([ 62, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str203172 = allocate([ 60, 60, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str213173 = allocate([ 62, 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str223174 = allocate([ 62, 62, 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str233175 = allocate([ 43, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str253177 = allocate([ 42, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str263178 = allocate([ 47, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str273179 = allocate([ 37, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str283180 = allocate([ 124, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str293181 = allocate([ 94, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str303182 = allocate([ 38, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str313183 = allocate([ 105, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str323184 = allocate([ 105, 110, 115, 116, 97, 110, 99, 101, 111, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str333185 = allocate([ 46, 46, 0 ], "i8", ALLOC_STATIC);

__ZN2js10binopNamesE = allocate(88, "*", ALLOC_STATIC);

STRING_TABLE.__str353187 = allocate([ 33, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str363188 = allocate([ 126, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str373189 = allocate([ 116, 121, 112, 101, 111, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str383190 = allocate([ 118, 111, 105, 100, 0 ], "i8", ALLOC_STATIC);

__ZN2js9unopNamesE = allocate(28, "*", ALLOC_STATIC);

STRING_TABLE.__str393191 = allocate([ 80, 114, 111, 103, 114, 97, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str403192 = allocate([ 73, 100, 101, 110, 116, 105, 102, 105, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str413193 = allocate([ 76, 105, 116, 101, 114, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str423194 = allocate([ 80, 114, 111, 112, 101, 114, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str433195 = allocate([ 70, 117, 110, 99, 116, 105, 111, 110, 68, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str443196 = allocate([ 86, 97, 114, 105, 97, 98, 108, 101, 68, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str453197 = allocate([ 86, 97, 114, 105, 97, 98, 108, 101, 68, 101, 99, 108, 97, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str463198 = allocate([ 83, 101, 113, 117, 101, 110, 99, 101, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str473199 = allocate([ 67, 111, 110, 100, 105, 116, 105, 111, 110, 97, 108, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str483200 = allocate([ 85, 110, 97, 114, 121, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str493201 = allocate([ 66, 105, 110, 97, 114, 121, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str503202 = allocate([ 65, 115, 115, 105, 103, 110, 109, 101, 110, 116, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str513203 = allocate([ 76, 111, 103, 105, 99, 97, 108, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str523204 = allocate([ 85, 112, 100, 97, 116, 101, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str533205 = allocate([ 78, 101, 119, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str543206 = allocate([ 67, 97, 108, 108, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str553207 = allocate([ 77, 101, 109, 98, 101, 114, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str563208 = allocate([ 70, 117, 110, 99, 116, 105, 111, 110, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str573209 = allocate([ 65, 114, 114, 97, 121, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str583210 = allocate([ 79, 98, 106, 101, 99, 116, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str593211 = allocate([ 84, 104, 105, 115, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str603212 = allocate([ 71, 114, 97, 112, 104, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str613213 = allocate([ 71, 114, 97, 112, 104, 73, 110, 100, 101, 120, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str623214 = allocate([ 67, 111, 109, 112, 114, 101, 104, 101, 110, 115, 105, 111, 110, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str633215 = allocate([ 71, 101, 110, 101, 114, 97, 116, 111, 114, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str643216 = allocate([ 89, 105, 101, 108, 100, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str653217 = allocate([ 76, 101, 116, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str663218 = allocate([ 69, 109, 112, 116, 121, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str673219 = allocate([ 66, 108, 111, 99, 107, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str683220 = allocate([ 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str693221 = allocate([ 76, 97, 98, 101, 108, 101, 100, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str703222 = allocate([ 73, 102, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str713223 = allocate([ 83, 119, 105, 116, 99, 104, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str723224 = allocate([ 87, 104, 105, 108, 101, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str733225 = allocate([ 68, 111, 87, 104, 105, 108, 101, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str743226 = allocate([ 70, 111, 114, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str753227 = allocate([ 70, 111, 114, 73, 110, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str763228 = allocate([ 66, 114, 101, 97, 107, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str773229 = allocate([ 67, 111, 110, 116, 105, 110, 117, 101, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str783230 = allocate([ 87, 105, 116, 104, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str793231 = allocate([ 82, 101, 116, 117, 114, 110, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str803232 = allocate([ 84, 114, 121, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str813233 = allocate([ 84, 104, 114, 111, 119, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str823234 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str833235 = allocate([ 76, 101, 116, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str843236 = allocate([ 83, 119, 105, 116, 99, 104, 67, 97, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str853237 = allocate([ 67, 97, 116, 99, 104, 67, 108, 97, 117, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str863238 = allocate([ 67, 111, 109, 112, 114, 101, 104, 101, 110, 115, 105, 111, 110, 66, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str873239 = allocate([ 65, 114, 114, 97, 121, 80, 97, 116, 116, 101, 114, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str883240 = allocate([ 79, 98, 106, 101, 99, 116, 80, 97, 116, 116, 101, 114, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str893241 = allocate([ 88, 77, 76, 65, 110, 121, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str903242 = allocate([ 88, 77, 76, 65, 116, 116, 114, 105, 98, 117, 116, 101, 83, 101, 108, 101, 99, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str913243 = allocate([ 88, 77, 76, 69, 115, 99, 97, 112, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str923244 = allocate([ 88, 77, 76, 70, 105, 108, 116, 101, 114, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str933245 = allocate([ 88, 77, 76, 68, 101, 102, 97, 117, 108, 116, 68, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str943246 = allocate([ 88, 77, 76, 81, 117, 97, 108, 105, 102, 105, 101, 100, 73, 100, 101, 110, 116, 105, 102, 105, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str953247 = allocate([ 88, 77, 76, 70, 117, 110, 99, 116, 105, 111, 110, 81, 117, 97, 108, 105, 102, 105, 101, 100, 73, 100, 101, 110, 116, 105, 102, 105, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str963248 = allocate([ 88, 77, 76, 69, 108, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str973249 = allocate([ 88, 77, 76, 84, 101, 120, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str983250 = allocate([ 88, 77, 76, 76, 105, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str993251 = allocate([ 88, 77, 76, 83, 116, 97, 114, 116, 84, 97, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1003252 = allocate([ 88, 77, 76, 69, 110, 100, 84, 97, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1013253 = allocate([ 88, 77, 76, 80, 111, 105, 110, 116, 84, 97, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1023254 = allocate([ 88, 77, 76, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1033255 = allocate([ 88, 77, 76, 65, 116, 116, 114, 105, 98, 117, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1043256 = allocate([ 88, 77, 76, 67, 100, 97, 116, 97, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1053257 = allocate([ 88, 77, 76, 67, 111, 109, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1063258 = allocate([ 88, 77, 76, 80, 114, 111, 99, 101, 115, 115, 105, 110, 103, 73, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

__ZN2js13nodeTypeNamesE = allocate(280, "*", ALLOC_STATIC);

STRING_TABLE.__str1073259 = allocate([ 112, 114, 111, 103, 114, 97, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1083260 = allocate([ 105, 100, 101, 110, 116, 105, 102, 105, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1093261 = allocate([ 108, 105, 116, 101, 114, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1103262 = allocate([ 112, 114, 111, 112, 101, 114, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1113263 = allocate([ 102, 117, 110, 99, 116, 105, 111, 110, 68, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1123264 = allocate([ 118, 97, 114, 105, 97, 98, 108, 101, 68, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1133265 = allocate([ 118, 97, 114, 105, 97, 98, 108, 101, 68, 101, 99, 108, 97, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1143266 = allocate([ 115, 101, 113, 117, 101, 110, 99, 101, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1153267 = allocate([ 99, 111, 110, 100, 105, 116, 105, 111, 110, 97, 108, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1163268 = allocate([ 117, 110, 97, 114, 121, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1173269 = allocate([ 98, 105, 110, 97, 114, 121, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1183270 = allocate([ 97, 115, 115, 105, 103, 110, 109, 101, 110, 116, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1193271 = allocate([ 108, 111, 103, 105, 99, 97, 108, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1203272 = allocate([ 117, 112, 100, 97, 116, 101, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1213273 = allocate([ 110, 101, 119, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1223274 = allocate([ 99, 97, 108, 108, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1233275 = allocate([ 109, 101, 109, 98, 101, 114, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1243276 = allocate([ 102, 117, 110, 99, 116, 105, 111, 110, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1253277 = allocate([ 97, 114, 114, 97, 121, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1263278 = allocate([ 111, 98, 106, 101, 99, 116, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1273279 = allocate([ 116, 104, 105, 115, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1283280 = allocate([ 103, 114, 97, 112, 104, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1293281 = allocate([ 103, 114, 97, 112, 104, 73, 110, 100, 101, 120, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1303282 = allocate([ 99, 111, 109, 112, 114, 101, 104, 101, 110, 115, 105, 111, 110, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1313283 = allocate([ 103, 101, 110, 101, 114, 97, 116, 111, 114, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1323284 = allocate([ 121, 105, 101, 108, 100, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1333285 = allocate([ 108, 101, 116, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1343286 = allocate([ 101, 109, 112, 116, 121, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1353287 = allocate([ 98, 108, 111, 99, 107, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1363288 = allocate([ 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1373289 = allocate([ 108, 97, 98, 101, 108, 101, 100, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1383290 = allocate([ 105, 102, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1393291 = allocate([ 115, 119, 105, 116, 99, 104, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1403292 = allocate([ 119, 104, 105, 108, 101, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1413293 = allocate([ 100, 111, 87, 104, 105, 108, 101, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1423294 = allocate([ 102, 111, 114, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1433295 = allocate([ 102, 111, 114, 73, 110, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1443296 = allocate([ 98, 114, 101, 97, 107, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1453297 = allocate([ 99, 111, 110, 116, 105, 110, 117, 101, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1463298 = allocate([ 119, 105, 116, 104, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1473299 = allocate([ 114, 101, 116, 117, 114, 110, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1483300 = allocate([ 116, 114, 121, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1493301 = allocate([ 116, 104, 114, 111, 119, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1503302 = allocate([ 100, 101, 98, 117, 103, 103, 101, 114, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1513303 = allocate([ 108, 101, 116, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1523304 = allocate([ 115, 119, 105, 116, 99, 104, 67, 97, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1533305 = allocate([ 99, 97, 116, 99, 104, 67, 108, 97, 117, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1543306 = allocate([ 99, 111, 109, 112, 114, 101, 104, 101, 110, 115, 105, 111, 110, 66, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1553307 = allocate([ 97, 114, 114, 97, 121, 80, 97, 116, 116, 101, 114, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1563308 = allocate([ 111, 98, 106, 101, 99, 116, 80, 97, 116, 116, 101, 114, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1573309 = allocate([ 112, 114, 111, 112, 101, 114, 116, 121, 80, 97, 116, 116, 101, 114, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1583310 = allocate([ 120, 109, 108, 65, 110, 121, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1593311 = allocate([ 120, 109, 108, 65, 116, 116, 114, 105, 98, 117, 116, 101, 83, 101, 108, 101, 99, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1603312 = allocate([ 120, 109, 108, 69, 115, 99, 97, 112, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1613313 = allocate([ 120, 109, 108, 70, 105, 108, 116, 101, 114, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1623314 = allocate([ 120, 109, 108, 68, 101, 102, 97, 117, 108, 116, 68, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1633315 = allocate([ 120, 109, 108, 81, 117, 97, 108, 105, 102, 105, 101, 100, 73, 100, 101, 110, 116, 105, 102, 105, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1643316 = allocate([ 120, 109, 108, 70, 117, 110, 99, 116, 105, 111, 110, 81, 117, 97, 108, 105, 102, 105, 101, 100, 73, 100, 101, 110, 116, 105, 102, 105, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1653317 = allocate([ 120, 109, 108, 69, 108, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1663318 = allocate([ 120, 109, 108, 84, 101, 120, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1673319 = allocate([ 120, 109, 108, 76, 105, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1683320 = allocate([ 120, 109, 108, 83, 116, 97, 114, 116, 84, 97, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1693321 = allocate([ 120, 109, 108, 69, 110, 100, 84, 97, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1703322 = allocate([ 120, 109, 108, 80, 111, 105, 110, 116, 84, 97, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1713323 = allocate([ 120, 109, 108, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1723324 = allocate([ 120, 109, 108, 65, 116, 116, 114, 105, 98, 117, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1733325 = allocate([ 120, 109, 108, 67, 100, 97, 116, 97, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1743326 = allocate([ 120, 109, 108, 67, 111, 109, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1753327 = allocate([ 120, 109, 108, 80, 114, 111, 99, 101, 115, 115, 105, 110, 103, 73, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

__ZN2js13callbackNamesE = allocate(280, "*", ALLOC_STATIC);

STRING_TABLE.__str1763328 = allocate([ 116, 121, 112, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1773329 = allocate([ 115, 116, 97, 114, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1783330 = allocate([ 108, 105, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1793331 = allocate([ 99, 111, 108, 117, 109, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1803332 = allocate([ 101, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1823334 = allocate([ 108, 111, 99, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1833335 = allocate([ 98, 111, 100, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1843336 = allocate([ 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1863338 = allocate([ 99, 111, 110, 115, 101, 113, 117, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1873339 = allocate([ 97, 108, 116, 101, 114, 110, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1883340 = allocate([ 108, 97, 98, 101, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1893341 = allocate([ 97, 114, 103, 117, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1903342 = allocate([ 105, 110, 105, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1913343 = allocate([ 117, 112, 100, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1923344 = allocate([ 108, 101, 102, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1933345 = allocate([ 114, 105, 103, 104, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1943346 = allocate([ 101, 97, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1963348 = allocate([ 100, 105, 115, 99, 114, 105, 109, 105, 110, 97, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1973349 = allocate([ 99, 97, 115, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1983350 = allocate([ 108, 101, 120, 105, 99, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1993351 = allocate([ 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2003352 = allocate([ 104, 97, 110, 100, 108, 101, 114, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2013353 = allocate([ 102, 105, 110, 97, 108, 105, 122, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2023354 = allocate([ 111, 112, 101, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2033355 = allocate([ 112, 114, 101, 102, 105, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2043356 = allocate([ 43, 43, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2053357 = allocate([ 45, 45, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2063358 = allocate([ 124, 124, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2073359 = allocate([ 38, 38, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2083360 = allocate([ 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2093361 = allocate([ 99, 97, 108, 108, 101, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2113363 = allocate([ 99, 111, 109, 112, 117, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2133365 = allocate([ 107, 101, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2153367 = allocate([ 107, 105, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2183370 = allocate([ 112, 114, 111, 112, 101, 114, 116, 105, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2193371 = allocate([ 98, 108, 111, 99, 107, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2203372 = allocate([ 102, 105, 108, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2213373 = allocate([ 105, 110, 100, 101, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2223374 = allocate([ 104, 101, 97, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2233375 = allocate([ 99, 111, 110, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2243376 = allocate([ 108, 101, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2253377 = allocate([ 118, 97, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2263378 = allocate([ 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2283380 = allocate([ 112, 97, 114, 97, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2293381 = allocate([ 103, 117, 97, 114, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2313383 = allocate([ 112, 97, 114, 97, 109, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2323384 = allocate([ 103, 101, 110, 101, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2333385 = allocate([ 110, 97, 109, 101, 115, 112, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2343386 = allocate([ 97, 116, 116, 114, 105, 98, 117, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2353387 = allocate([ 99, 111, 110, 116, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2363388 = allocate([ 116, 101, 120, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2373389 = allocate([ 116, 97, 114, 103, 101, 116, 0 ], "i8", ALLOC_STATIC);

__ZL14static_methods3391 = allocate([ 0, 0, 0, 0, 1136, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str2393392 = allocate([ 82, 101, 102, 108, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2403393 = allocate([ 82, 101, 102, 108, 101, 99, 116, 46, 112, 97, 114, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2433396 = allocate([ 110, 111, 116, 32, 97, 110, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str3439 = allocate([ 82, 101, 103, 69, 120, 112, 83, 116, 97, 116, 105, 99, 115, 0 ], "i8", ALLOC_STATIC);

__ZN2js20regexp_statics_classE = allocate([ 0, 0, 0, 0, 1, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 1138, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1140, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str13442 = allocate([ 105, 110, 112, 117, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str23443 = allocate([ 109, 117, 108, 116, 105, 108, 105, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str33444 = allocate([ 108, 97, 115, 116, 77, 97, 116, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str43445 = allocate([ 108, 97, 115, 116, 80, 97, 114, 101, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str53446 = allocate([ 108, 101, 102, 116, 67, 111, 110, 116, 101, 120, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str63447 = allocate([ 114, 105, 103, 104, 116, 67, 111, 110, 116, 101, 120, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str73448 = allocate([ 36, 49, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str83449 = allocate([ 36, 50, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str93450 = allocate([ 36, 51, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str103451 = allocate([ 36, 52, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str113452 = allocate([ 36, 53, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str123453 = allocate([ 36, 54, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str133454 = allocate([ 36, 55, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str143455 = allocate([ 36, 56, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str153456 = allocate([ 36, 57, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str163457 = allocate([ 36, 95, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str173458 = allocate([ 36, 42, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str183459 = allocate([ 36, 38, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str193460 = allocate([ 36, 43, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str203461 = allocate([ 36, 96, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str213462 = allocate([ 36, 39, 0 ], "i8", ALLOC_STATIC);

__ZL19regexp_static_props = allocate([ 0, 0, 0, 0, 0, 69, 0, 0, 1142, 0, 0, 0, 1144, 0, 0, 0, 0, 0, 0, 0, 0, 69, 0, 0, 1146, 0, 0, 0, 1148, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1150, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1152, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1154, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1156, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1158, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1160, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1162, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1164, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1166, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1168, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1170, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1172, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1174, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 68, 0, 0, 1142, 0, 0, 0, 1144, 0, 0, 0, 0, 0, 0, 0, 0, 68, 0, 0, 1146, 0, 0, 0, 1148, 0, 0, 0, 0, 0, 0, 0, 0, 70, 0, 0, 1150, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 70, 0, 0, 1152, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 70, 0, 0, 1154, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 70, 0, 0, 1156, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

__ZN2js11RegExpClassE = allocate([ 0, 0, 0, 0, 167773697, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 1176, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1178, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str223465 = allocate([ 47, 40, 63, 58, 41, 47, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str243467 = allocate([ 101, 120, 101, 99, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str253468 = allocate([ 116, 101, 115, 116, 0 ], "i8", ALLOC_STATIC);

__ZL14regexp_methods = allocate([ 0, 0, 0, 0, 1180, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1180, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1182, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 1184, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1186, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str263469 = allocate([ 115, 111, 117, 114, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str283471 = allocate([ 105, 103, 110, 111, 114, 101, 67, 97, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str293472 = allocate([ 115, 116, 105, 99, 107, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str303473 = allocate([ 108, 97, 115, 116, 73, 110, 100, 101, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_break_str = allocate([ 98, 114, 101, 97, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_case_str = allocate([ 99, 97, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_debugger_str = allocate([ 100, 101, 98, 117, 103, 103, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_default_str = allocate([ 100, 101, 102, 97, 117, 108, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_do_str = allocate([ 100, 111, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_else_str = allocate([ 101, 108, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_finally_str = allocate([ 102, 105, 110, 97, 108, 108, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_new_str = allocate([ 110, 101, 119, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_try_str = allocate([ 116, 114, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_with_str = allocate([ 119, 105, 116, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_enum_str = allocate([ 101, 110, 117, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_export_str = allocate([ 101, 120, 112, 111, 114, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_extends_str = allocate([ 101, 120, 116, 101, 110, 100, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_import_str = allocate([ 105, 109, 112, 111, 114, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_super_str = allocate([ 115, 117, 112, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_yield_str = allocate([ 121, 105, 101, 108, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_implements_str = allocate([ 105, 109, 112, 108, 101, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_interface_str = allocate([ 105, 110, 116, 101, 114, 102, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_package_str = allocate([ 112, 97, 99, 107, 97, 103, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_private_str = allocate([ 112, 114, 105, 118, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_protected_str = allocate([ 112, 114, 111, 116, 101, 99, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_public_str = allocate([ 112, 117, 98, 108, 105, 99, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_static_str = allocate([ 115, 116, 97, 116, 105, 99, 0 ], "i8", ALLOC_STATIC);

__ZL8keywords = allocate([ 0, 0, 0, 0, 33, 0, 0, 0, 66, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 33, 0, 0, 0, 67, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 33, 0, 0, 0, 64, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 43, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 38, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 54, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 44, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 58, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 39, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 50, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 41, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 36, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 55, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 42, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 34, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 35, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 0, 0, 0, 113, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 57, 0, 0, 0, 114, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 49, 0, 0, 0, 82, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 48, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 37, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 33, 0, 0, 0, 65, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 56, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 53, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19, 0, 0, 0, 39, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 46, 0, 0, 0, 129, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19, 0, 0, 0, 40, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 40, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 47, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 46, 0, 0, 0, 128, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 81, 0, 0, 0, 0, 0, 0, 0, 170, 0, 0, 0, 0, 0, 0, 0, 77, 0, 0, 0, 0, 0, 0, 0, 170, 0, 0, 0, 0, 0, 0, 0, 87, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 87, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 87, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 87, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 87, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 87, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 87, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str3585 = allocate([ 64, 108, 105, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str13586 = allocate([ 64, 115, 111, 117, 114, 99, 101, 77, 97, 112, 112, 105, 110, 103, 85, 82, 76, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL14firstCharKinds = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 11, 10, 10, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 5, 0, 2, 0, 0, 5, 1, 1, 0, 8, 1, 0, 3, 0, 9, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 1, 0, 4, 0, 1, 0, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 1, 0, 1, 0, 2, 0, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 1, 0, 1, 0, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str23587 = allocate([ 85, 110, 105, 99, 111, 100, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str33588 = allocate([ 104, 101, 120, 97, 100, 101, 99, 105, 109, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str43589 = allocate([ 48, 56, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str53590 = allocate([ 48, 57, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str63591 = allocate([ 35, 37, 117, 37, 99, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str3667 = allocate([ 35, 97, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str23669 = allocate([ 83, 99, 114, 105, 112, 116, 0 ], "i8", ALLOC_STATIC);

__ZN2js11ScriptClassE = allocate([ 0, 0, 0, 0, 16777217, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1188, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE._js_escape_str = allocate([ 101, 115, 99, 97, 112, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_unescape_str = allocate([ 117, 110, 101, 115, 99, 97, 112, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_uneval_str = allocate([ 117, 110, 101, 118, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_decodeURI_str = allocate([ 100, 101, 99, 111, 100, 101, 85, 82, 73, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_encodeURI_str = allocate([ 101, 110, 99, 111, 100, 101, 85, 82, 73, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_decodeURIComponent_str = allocate([ 100, 101, 99, 111, 100, 101, 85, 82, 73, 67, 111, 109, 112, 111, 110, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_encodeURIComponent_str = allocate([ 101, 110, 99, 111, 100, 101, 85, 82, 73, 67, 111, 109, 112, 111, 110, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

__ZL16string_functions = allocate([ 0, 0, 0, 0, 1190, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1192, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1194, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1196, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1198, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1200, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1202, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

_js_empty_ucstr = allocate(2, "i16", ALLOC_STATIC);

_js_EmptySubString = allocate(8, [ "i32", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

__ZN2js11StringClassE = allocate([ 0, 0, 0, 0, 150995460, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 1204, 0, 0, 0, 1206, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str3763 = allocate([ 113, 117, 111, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str13764 = allocate([ 115, 117, 98, 115, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str23765 = allocate([ 116, 111, 76, 111, 119, 101, 114, 67, 97, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str33766 = allocate([ 116, 111, 85, 112, 112, 101, 114, 67, 97, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str43767 = allocate([ 99, 104, 97, 114, 65, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str53768 = allocate([ 99, 104, 97, 114, 67, 111, 100, 101, 65, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str63769 = allocate([ 105, 110, 100, 101, 120, 79, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str73770 = allocate([ 108, 97, 115, 116, 73, 110, 100, 101, 120, 79, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str83771 = allocate([ 116, 114, 105, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str93772 = allocate([ 116, 114, 105, 109, 76, 101, 102, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str103773 = allocate([ 116, 114, 105, 109, 82, 105, 103, 104, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str113774 = allocate([ 116, 111, 76, 111, 99, 97, 108, 101, 76, 111, 119, 101, 114, 67, 97, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str123775 = allocate([ 116, 111, 76, 111, 99, 97, 108, 101, 85, 112, 112, 101, 114, 67, 97, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str133776 = allocate([ 108, 111, 99, 97, 108, 101, 67, 111, 109, 112, 97, 114, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str143777 = allocate([ 109, 97, 116, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str153778 = allocate([ 115, 101, 97, 114, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str173780 = allocate([ 115, 112, 108, 105, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str183781 = allocate([ 115, 117, 98, 115, 116, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str193782 = allocate([ 99, 111, 110, 99, 97, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str203783 = allocate([ 115, 108, 105, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str213784 = allocate([ 98, 111, 108, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str223785 = allocate([ 105, 116, 97, 108, 105, 99, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str233786 = allocate([ 102, 105, 120, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str243787 = allocate([ 102, 111, 110, 116, 115, 105, 122, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str253788 = allocate([ 102, 111, 110, 116, 99, 111, 108, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str263789 = allocate([ 108, 105, 110, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str273790 = allocate([ 97, 110, 99, 104, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str283791 = allocate([ 115, 116, 114, 105, 107, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str293792 = allocate([ 115, 109, 97, 108, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str303793 = allocate([ 98, 105, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str313794 = allocate([ 98, 108, 105, 110, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str323795 = allocate([ 115, 117, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str333796 = allocate([ 115, 117, 98, 0 ], "i8", ALLOC_STATIC);

__ZL14string_methods = allocate([ 0, 0, 0, 0, 1208, 0, 0, 0, 0, 0, 4104, 0, 0, 0, 0, 0, 1210, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 186, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 186, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1212, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1214, 0, 0, 0, 0, 0, 4104, 0, 0, 0, 0, 0, 1216, 0, 0, 0, 0, 0, 4104, 0, 0, 0, 0, 0, 1218, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 1220, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 1222, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 1224, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 1226, 0, 0, 0, 0, 0, 4104, 0, 0, 0, 0, 0, 1228, 0, 0, 0, 0, 0, 4104, 0, 0, 0, 0, 0, 1230, 0, 0, 0, 0, 0, 4104, 0, 0, 0, 0, 0, 1232, 0, 0, 0, 0, 0, 4104, 0, 0, 0, 0, 0, 1234, 0, 0, 0, 0, 0, 4104, 0, 0, 0, 0, 0, 1236, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 1238, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 1240, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 140, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1242, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1244, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1246, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 1248, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1250, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1252, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1254, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1256, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1258, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1260, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1262, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1264, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1266, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1268, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1270, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1272, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1274, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str343797 = allocate([ 102, 114, 111, 109, 67, 104, 97, 114, 67, 111, 100, 101, 0 ], "i8", ALLOC_STATIC);

__ZL21string_static_methods = allocate([ 0, 0, 0, 0, 1276, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str353798 = allocate([ 108, 101, 110, 103, 116, 104, 0 ], "i8", ALLOC_STATIC);

__ZZ16js_ValueToSourceP9JSContextRKN2JS5ValueEE17js_negzero_ucNstr = allocate([ 45, 0, 48, 0 ], [ "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str363799 = allocate([ 48, 120, 37, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_isidstart = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_isident = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_isspace = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], "i8", ALLOC_STATIC);

__ZZL17Utf8ToOneUcs4CharPKhiE12minucs4Table = allocate([ 128, 0, 0, 0, 2048, 0, 0, 0, 65536, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

__ZL21js_uriUnescaped_ucstr = allocate([ 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 45, 0, 95, 0, 46, 0, 33, 0, 126, 0, 42, 0, 39, 0, 40, 0, 41, 0, 0, 0 ], [ "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__ZZL6EncodeP9JSContextP8JSStringPKtS4_PN2JS5ValueEE9HexDigits = allocate([ 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 65, 66, 67, 68, 69, 70, 0 ], "i8", ALLOC_STATIC);

__ZL29js_uriReservedPlusPound_ucstr = allocate([ 59, 0, 47, 0, 63, 0, 58, 0, 64, 0, 38, 0, 61, 0, 43, 0, 36, 0, 44, 0, 35, 0, 0, 0 ], [ "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str383807 = allocate([ 97, 32, 110, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str403809 = allocate([ 97, 32, 104, 114, 101, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str413810 = allocate([ 102, 111, 110, 116, 32, 99, 111, 108, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str423811 = allocate([ 102, 111, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str433812 = allocate([ 102, 111, 110, 116, 32, 115, 105, 122, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str443813 = allocate([ 116, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str453814 = allocate([ 105, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str463815 = allocate([ 98, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str473816 = allocate([ 40, 110, 101, 119, 32, 83, 116, 114, 105, 110, 103, 40, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str483817 = allocate([ 110, 117, 108, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str493818 = allocate([ 117, 110, 100, 101, 102, 105, 110, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL10str_escapeP9JSContextjPN2JS5ValueEE6digits = allocate([ 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 65, 66, 67, 68, 69, 70 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL10str_escapeP9JSContextjPN2JS5ValueEE17shouldPassThrough = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], "i8", ALLOC_STATIC);

__ZN2js11ArrayBuffer9slowClassE = allocate([ 0, 0, 0, 0, 402657281, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 1278, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str13952 = allocate([ 65, 114, 114, 97, 121, 66, 117, 102, 102, 101, 114, 0 ], "i8", ALLOC_STATIC);

__ZN2js16ArrayBufferClassE = allocate([ 0, 0, 0, 0, 403181569, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1280, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1282, 0, 0, 0, 1282, 0, 0, 0, 1284, 0, 0, 0, 1286, 0, 0, 0, 1288, 0, 0, 0, 1288, 0, 0, 0, 1290, 0, 0, 0, 1292, 0, 0, 0, 1294, 0, 0, 0, 1296, 0, 0, 0, 1298, 0, 0, 0, 1300, 0, 0, 0, 1302, 0, 0, 0, 1302, 0, 0, 0, 1304, 0, 0, 0, 1306, 0, 0, 0, 1308, 0, 0, 0, 1308, 0, 0, 0, 1310, 0, 0, 0, 1312, 0, 0, 0, 1314, 0, 0, 0, 1314, 0, 0, 0, 1316, 0, 0, 0, 1318, 0, 0, 0, 1320, 0, 0, 0, 1320, 0, 0, 0, 1322, 0, 0, 0, 1324, 0, 0, 0, 1326, 0, 0, 0, 1328, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str23955 = allocate([ 98, 121, 116, 101, 76, 101, 110, 103, 116, 104, 0 ], "i8", ALLOC_STATIC);

__ZN2js11ArrayBuffer7jspropsE = allocate([ 0, 0, 0, 0, -1, 70, 0, 0, 1330, 0, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str33956 = allocate([ 98, 121, 116, 101, 79, 102, 102, 115, 101, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str43957 = allocate([ 98, 117, 102, 102, 101, 114, 0 ], "i8", ALLOC_STATIC);

__ZN2js10TypedArray7jspropsE = allocate([ 0, 0, 0, 0, -1, 70, 0, 0, 1332, 0, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, -1, 70, 0, 0, 1334, 0, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, -1, 70, 0, 0, 1336, 0, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, -1, 70, 0, 0, 1338, 0, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str53958 = allocate([ 115, 117, 98, 97, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

__ZN9Int8Array7jsfuncsE = allocate([ 0, 0, 0, 0, 1340, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1342, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN10Uint8Array7jsfuncsE = allocate([ 0, 0, 0, 0, 1344, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1346, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN10Int16Array7jsfuncsE = allocate([ 0, 0, 0, 0, 1348, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1350, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN11Uint16Array7jsfuncsE = allocate([ 0, 0, 0, 0, 1352, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1354, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN10Int32Array7jsfuncsE = allocate([ 0, 0, 0, 0, 1356, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1358, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN11Uint32Array7jsfuncsE = allocate([ 0, 0, 0, 0, 1360, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1362, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN12Float32Array7jsfuncsE = allocate([ 0, 0, 0, 0, 1364, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1366, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN12Float64Array7jsfuncsE = allocate([ 0, 0, 0, 0, 1368, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1370, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN17Uint8ClampedArray7jsfuncsE = allocate([ 0, 0, 0, 0, 1372, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1374, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str73960 = allocate([ 73, 110, 116, 56, 65, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str83961 = allocate([ 85, 105, 110, 116, 56, 65, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str93962 = allocate([ 73, 110, 116, 49, 54, 65, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str103963 = allocate([ 85, 105, 110, 116, 49, 54, 65, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str113964 = allocate([ 73, 110, 116, 51, 50, 65, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str123965 = allocate([ 85, 105, 110, 116, 51, 50, 65, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str133966 = allocate([ 70, 108, 111, 97, 116, 51, 50, 65, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str143967 = allocate([ 70, 108, 111, 97, 116, 54, 52, 65, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str153968 = allocate([ 85, 105, 110, 116, 56, 67, 108, 97, 109, 112, 101, 100, 65, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

__ZN2js10TypedArray11fastClassesE = allocate([ 0, 0, 0, 0, 525569, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1376, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1378, 0, 0, 0, 1378, 0, 0, 0, 1380, 0, 0, 0, 1382, 0, 0, 0, 1384, 0, 0, 0, 1384, 0, 0, 0, 1386, 0, 0, 0, 1388, 0, 0, 0, 1390, 0, 0, 0, 1392, 0, 0, 0, 1394, 0, 0, 0, 1396, 0, 0, 0, 1398, 0, 0, 0, 1398, 0, 0, 0, 1400, 0, 0, 0, 1402, 0, 0, 0, 1404, 0, 0, 0, 1404, 0, 0, 0, 1406, 0, 0, 0, 1408, 0, 0, 0, 1410, 0, 0, 0, 1410, 0, 0, 0, 1412, 0, 0, 0, 1414, 0, 0, 0, 1416, 0, 0, 0, 1416, 0, 0, 0, 1418, 0, 0, 0, 1420, 0, 0, 0, 1422, 0, 0, 0, 1424, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 525569, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1426, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1378, 0, 0, 0, 1378, 0, 0, 0, 1380, 0, 0, 0, 1382, 0, 0, 0, 1428, 0, 0, 0, 1428, 0, 0, 0, 1430, 0, 0, 0, 1432, 0, 0, 0, 1434, 0, 0, 0, 1436, 0, 0, 0, 1438, 0, 0, 0, 1440, 0, 0, 0, 1442, 0, 0, 0, 1442, 0, 0, 0, 1444, 0, 0, 0, 1446, 0, 0, 0, 1404, 0, 0, 0, 1404, 0, 0, 0, 1406, 0, 0, 0, 1408, 0, 0, 0, 1410, 0, 0, 0, 1410, 0, 0, 0, 1412, 0, 0, 0, 1414, 0, 0, 0, 1448, 0, 0, 0, 1448, 0, 0, 0, 1450, 0, 0, 0, 1452, 0, 0, 0, 1454, 0, 0, 0, 1456, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 525569, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1458, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1378, 0, 0, 0, 1378, 0, 0, 0, 1380, 0, 0, 0, 1382, 0, 0, 0, 1460, 0, 0, 0, 1460, 0, 0, 0, 1462, 0, 0, 0, 1464, 0, 0, 0, 1466, 0, 0, 0, 1468, 0, 0, 0, 1470, 0, 0, 0, 1472, 0, 0, 0, 1474, 0, 0, 0, 1474, 0, 0, 0, 1476, 0, 0, 0, 1478, 0, 0, 0, 1404, 0, 0, 0, 1404, 0, 0, 0, 1406, 0, 0, 0, 1408, 0, 0, 0, 1410, 0, 0, 0, 1410, 0, 0, 0, 1412, 0, 0, 0, 1414, 0, 0, 0, 1480, 0, 0, 0, 1480, 0, 0, 0, 1482, 0, 0, 0, 1484, 0, 0, 0, 1486, 0, 0, 0, 1488, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 525569, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1490, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1378, 0, 0, 0, 1378, 0, 0, 0, 1380, 0, 0, 0, 1382, 0, 0, 0, 1492, 0, 0, 0, 1492, 0, 0, 0, 1494, 0, 0, 0, 1496, 0, 0, 0, 1498, 0, 0, 0, 1500, 0, 0, 0, 1502, 0, 0, 0, 1504, 0, 0, 0, 1506, 0, 0, 0, 1506, 0, 0, 0, 1508, 0, 0, 0, 1510, 0, 0, 0, 1404, 0, 0, 0, 1404, 0, 0, 0, 1406, 0, 0, 0, 1408, 0, 0, 0, 1410, 0, 0, 0, 1410, 0, 0, 0, 1412, 0, 0, 0, 1414, 0, 0, 0, 1512, 0, 0, 0, 1512, 0, 0, 0, 1514, 0, 0, 0, 1516, 0, 0, 0, 1518, 0, 0, 0, 1520, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 525569, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1522, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1378, 0, 0, 0, 1378, 0, 0, 0, 1380, 0, 0, 0, 1382, 0, 0, 0, 1524, 0, 0, 0, 1524, 0, 0, 0, 1526, 0, 0, 0, 1528, 0, 0, 0, 1530, 0, 0, 0, 1532, 0, 0, 0, 1534, 0, 0, 0, 1536, 0, 0, 0, 1538, 0, 0, 0, 1538, 0, 0, 0, 1540, 0, 0, 0, 1542, 0, 0, 0, 1404, 0, 0, 0, 1404, 0, 0, 0, 1406, 0, 0, 0, 1408, 0, 0, 0, 1410, 0, 0, 0, 1410, 0, 0, 0, 1412, 0, 0, 0, 1414, 0, 0, 0, 1544, 0, 0, 0, 1544, 0, 0, 0, 1546, 0, 0, 0, 1548, 0, 0, 0, 1550, 0, 0, 0, 1552, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 525569, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1554, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1378, 0, 0, 0, 1378, 0, 0, 0, 1380, 0, 0, 0, 1382, 0, 0, 0, 1556, 0, 0, 0, 1556, 0, 0, 0, 1558, 0, 0, 0, 1560, 0, 0, 0, 1562, 0, 0, 0, 1564, 0, 0, 0, 1566, 0, 0, 0, 1568, 0, 0, 0, 1570, 0, 0, 0, 1570, 0, 0, 0, 1572, 0, 0, 0, 1574, 0, 0, 0, 1404, 0, 0, 0, 1404, 0, 0, 0, 1406, 0, 0, 0, 1408, 0, 0, 0, 1410, 0, 0, 0, 1410, 0, 0, 0, 1412, 0, 0, 0, 1414, 0, 0, 0, 1576, 0, 0, 0, 1576, 0, 0, 0, 1578, 0, 0, 0, 1580, 0, 0, 0, 1582, 0, 0, 0, 1584, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 525569, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1586, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1378, 0, 0, 0, 1378, 0, 0, 0, 1380, 0, 0, 0, 1382, 0, 0, 0, 1588, 0, 0, 0, 1588, 0, 0, 0, 1590, 0, 0, 0, 1592, 0, 0, 0, 1594, 0, 0, 0, 1596, 0, 0, 0, 1598, 0, 0, 0, 1600, 0, 0, 0, 1602, 0, 0, 0, 1602, 0, 0, 0, 1604, 0, 0, 0, 1606, 0, 0, 0, 1404, 0, 0, 0, 1404, 0, 0, 0, 1406, 0, 0, 0, 1408, 0, 0, 0, 1410, 0, 0, 0, 1410, 0, 0, 0, 1412, 0, 0, 0, 1414, 0, 0, 0, 1608, 0, 0, 0, 1608, 0, 0, 0, 1610, 0, 0, 0, 1612, 0, 0, 0, 1614, 0, 0, 0, 1616, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 525569, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1618, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1378, 0, 0, 0, 1378, 0, 0, 0, 1380, 0, 0, 0, 1382, 0, 0, 0, 1620, 0, 0, 0, 1620, 0, 0, 0, 1622, 0, 0, 0, 1624, 0, 0, 0, 1626, 0, 0, 0, 1628, 0, 0, 0, 1630, 0, 0, 0, 1632, 0, 0, 0, 1634, 0, 0, 0, 1634, 0, 0, 0, 1636, 0, 0, 0, 1638, 0, 0, 0, 1404, 0, 0, 0, 1404, 0, 0, 0, 1406, 0, 0, 0, 1408, 0, 0, 0, 1410, 0, 0, 0, 1410, 0, 0, 0, 1412, 0, 0, 0, 1414, 0, 0, 0, 1640, 0, 0, 0, 1640, 0, 0, 0, 1642, 0, 0, 0, 1644, 0, 0, 0, 1646, 0, 0, 0, 1648, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 525569, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1650, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1378, 0, 0, 0, 1378, 0, 0, 0, 1380, 0, 0, 0, 1382, 0, 0, 0, 1652, 0, 0, 0, 1652, 0, 0, 0, 1654, 0, 0, 0, 1656, 0, 0, 0, 1658, 0, 0, 0, 1660, 0, 0, 0, 1662, 0, 0, 0, 1664, 0, 0, 0, 1666, 0, 0, 0, 1666, 0, 0, 0, 1668, 0, 0, 0, 1670, 0, 0, 0, 1404, 0, 0, 0, 1404, 0, 0, 0, 1406, 0, 0, 0, 1408, 0, 0, 0, 1410, 0, 0, 0, 1410, 0, 0, 0, 1412, 0, 0, 0, 1414, 0, 0, 0, 1672, 0, 0, 0, 1672, 0, 0, 0, 1674, 0, 0, 0, 1676, 0, 0, 0, 1678, 0, 0, 0, 1680, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZN2js10TypedArray11slowClassesE = allocate([ 0, 0, 0, 0, 419431681, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 1278, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 436208897, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 1278, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 452986113, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 1278, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 469763329, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 1278, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 486540545, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 1278, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 503317761, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 1278, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 520094977, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 1278, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 536872193, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 1278, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 553649409, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 1278, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str163973 = allocate([ 49, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str173974 = allocate([ 50, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str183975 = allocate([ 115, 105, 122, 101, 32, 97, 110, 100, 32, 99, 111, 117, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str4046 = allocate([ 65, 115, 115, 101, 114, 116, 105, 111, 110, 32, 102, 97, 105, 108, 117, 114, 101, 58, 32, 37, 115, 44, 32, 97, 116, 32, 37, 115, 58, 37, 100, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str4075 = allocate([ 87, 101, 97, 107, 77, 97, 112, 0 ], "i8", ALLOC_STATIC);

__ZN2js12WeakMapClassE = allocate([ 0, 0, 0, 0, 603979777, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 1682, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1684, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str14078 = allocate([ 104, 97, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str24079 = allocate([ 103, 101, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str34080 = allocate([ 100, 101, 108, 101, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str44081 = allocate([ 115, 101, 116, 0 ], "i8", ALLOC_STATIC);

__ZL16weak_map_methods = allocate([ 0, 0, 0, 0, 1686, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1688, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 1690, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1692, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str54082 = allocate([ 87, 101, 97, 107, 77, 97, 112, 46, 115, 101, 116, 0 ], "i8", ALLOC_STATIC);

__ZTVN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEEE = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 1694, 0, 0, 0, 1696, 0, 0, 0, 1698, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

STRING_TABLE.__str104087 = allocate([ 87, 101, 97, 107, 77, 97, 112, 46, 100, 101, 108, 101, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str114088 = allocate([ 87, 101, 97, 107, 77, 97, 112, 46, 103, 101, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str124089 = allocate([ 87, 101, 97, 107, 77, 97, 112, 46, 104, 97, 115, 0 ], "i8", ALLOC_STATIC);

__ZL14sWrapperFamily = allocate(1, "i32", ALLOC_STATIC);

__ZTV9JSWrapper = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 1700, 0, 0, 0, 1702, 0, 0, 0, 1704, 0, 0, 0, 1706, 0, 0, 0, 1708, 0, 0, 0, 1710, 0, 0, 0, 1712, 0, 0, 0, 1714, 0, 0, 0, 1716, 0, 0, 0, 1718, 0, 0, 0, 1720, 0, 0, 0, 1722, 0, 0, 0, 1724, 0, 0, 0, 1726, 0, 0, 0, 1728, 0, 0, 0, 1730, 0, 0, 0, 1732, 0, 0, 0, 1734, 0, 0, 0, 1736, 0, 0, 0, 1738, 0, 0, 0, 1740, 0, 0, 0, 1742, 0, 0, 0, 1058, 0, 0, 0, 1744, 0, 0, 0, 1062, 0, 0, 0, 1746, 0, 0, 0, 1748, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

STRING_TABLE.__str4127 = allocate([ 91, 111, 98, 106, 101, 99, 116, 32, 79, 98, 106, 101, 99, 116, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str14128 = allocate([ 102, 117, 110, 99, 116, 105, 111, 110, 32, 40, 41, 32, 123, 10, 32, 32, 32, 32, 91, 110, 97, 116, 105, 118, 101, 32, 99, 111, 100, 101, 93, 10, 125, 0 ], "i8", ALLOC_STATIC);

__ZN9JSWrapper9singletonE = allocate(12, [ "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

__ZN25JSCrossCompartmentWrapper9singletonE = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

__ZTV25JSCrossCompartmentWrapper = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 1700, 0, 0, 0, 1750, 0, 0, 0, 1752, 0, 0, 0, 1754, 0, 0, 0, 1756, 0, 0, 0, 1758, 0, 0, 0, 1760, 0, 0, 0, 1762, 0, 0, 0, 1716, 0, 0, 0, 1764, 0, 0, 0, 1766, 0, 0, 0, 1768, 0, 0, 0, 1770, 0, 0, 0, 1772, 0, 0, 0, 1774, 0, 0, 0, 1776, 0, 0, 0, 1778, 0, 0, 0, 1780, 0, 0, 0, 1736, 0, 0, 0, 1782, 0, 0, 0, 1784, 0, 0, 0, 1786, 0, 0, 0, 1058, 0, 0, 0, 1788, 0, 0, 0, 1062, 0, 0, 0, 1746, 0, 0, 0, 1748, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZL10xdrmem_ops = allocate([ 1790, 0, 0, 0, 1792, 0, 0, 0, 1794, 0, 0, 0, 1796, 0, 0, 0, 1798, 0, 0, 0, 1800, 0, 0, 0, 1802, 0, 0, 0, 1804, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

__ZZ11JS_XDRBytesE6padbuf = allocate(3, "i8", ALLOC_STATIC);

STRING_TABLE._js_AttributeName_str = allocate([ 65, 116, 116, 114, 105, 98, 117, 116, 101, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_isXMLName_str = allocate([ 105, 115, 88, 77, 76, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_amp_entity_str = allocate([ 38, 97, 109, 112, 59, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_gt_entity_str = allocate([ 38, 103, 116, 59, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_lt_entity_str = allocate([ 38, 108, 116, 59, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_quot_entity_str = allocate([ 38, 113, 117, 111, 116, 59, 0 ], "i8", ALLOC_STATIC);

_sE4XObjectsCreated = allocate(1, "i32", ALLOC_STATIC);

STRING_TABLE.__str4236 = allocate([ 78, 97, 109, 101, 115, 112, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

__ZN2js14NamespaceClassE = allocate([ 0, 0, 0, 0, 201327360, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 1278, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1806, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZL17namespace_methods = allocate([ 0, 0, 0, 0, 1808, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str14239 = allocate([ 81, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

__ZN2js10QNameClassE = allocate([ 0, 0, 0, 0, 218104576, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 1278, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1810, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZN2js18AttributeNameClassE = allocate([ 0, 0, 0, 0, 131840, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 1278, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZN2js12AnyNameClassE = allocate([ 0, 0, 0, 0, 131840, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 1278, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZL13qname_methods = allocate([ 0, 0, 0, 0, 1812, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__ZL21js_ignoreComments_str = allocate([ 105, 103, 110, 111, 114, 101, 67, 111, 109, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL35js_ignoreProcessingInstructions_str = allocate([ 105, 103, 110, 111, 114, 101, 80, 114, 111, 99, 101, 115, 115, 105, 110, 103, 73, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL23js_ignoreWhitespace_str = allocate([ 105, 103, 110, 111, 114, 101, 87, 104, 105, 116, 101, 115, 112, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL21js_prettyPrinting_str = allocate([ 112, 114, 101, 116, 116, 121, 80, 114, 105, 110, 116, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL19js_prettyIndent_str = allocate([ 112, 114, 101, 116, 116, 121, 73, 110, 100, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

__ZL16xml_static_props = allocate([ 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

__ZN2js8XMLClassE = allocate([ 0, 0, 0, 0, 184549377, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 1814, 0, 0, 0, 1816, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1818, 0, 0, 0, 1820, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1822, 0, 0, 0, 1822, 0, 0, 0, 1824, 0, 0, 0, 1826, 0, 0, 0, 1828, 0, 0, 0, 1828, 0, 0, 0, 1830, 0, 0, 0, 1832, 0, 0, 0, 1834, 0, 0, 0, 1836, 0, 0, 0, 1838, 0, 0, 0, 1840, 0, 0, 0, 1842, 0, 0, 0, 1842, 0, 0, 0, 1844, 0, 0, 0, 1846, 0, 0, 0, 1848, 0, 0, 0, 1848, 0, 0, 0, 1850, 0, 0, 0, 1852, 0, 0, 0, 1854, 0, 0, 0, 1854, 0, 0, 0, 1856, 0, 0, 0, 1858, 0, 0, 0, 1860, 0, 0, 0, 1860, 0, 0, 0, 1862, 0, 0, 0, 1864, 0, 0, 0, 1866, 0, 0, 0, 1868, 0, 0, 0, 1870, 0, 0, 0, 0, 0, 0, 0, 1872, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str34249 = allocate([ 108, 105, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str44250 = allocate([ 101, 108, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str54251 = allocate([ 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 45, 105, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str64252 = allocate([ 99, 111, 109, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

_js_xml_class_str = allocate(24, "*", ALLOC_STATIC);

STRING_TABLE.__str74253 = allocate([ 97, 100, 100, 78, 97, 109, 101, 115, 112, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str84254 = allocate([ 97, 112, 112, 101, 110, 100, 67, 104, 105, 108, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str94255 = allocate([ 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str104256 = allocate([ 99, 104, 105, 108, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str114257 = allocate([ 99, 104, 105, 108, 100, 73, 110, 100, 101, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str124258 = allocate([ 99, 104, 105, 108, 100, 114, 101, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str134259 = allocate([ 99, 111, 109, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str144260 = allocate([ 99, 111, 110, 116, 97, 105, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str154261 = allocate([ 99, 111, 112, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str164262 = allocate([ 100, 101, 115, 99, 101, 110, 100, 97, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str174263 = allocate([ 101, 108, 101, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str184264 = allocate([ 104, 97, 115, 79, 119, 110, 80, 114, 111, 112, 101, 114, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str194265 = allocate([ 104, 97, 115, 67, 111, 109, 112, 108, 101, 120, 67, 111, 110, 116, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str204266 = allocate([ 104, 97, 115, 83, 105, 109, 112, 108, 101, 67, 111, 110, 116, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str214267 = allocate([ 105, 110, 83, 99, 111, 112, 101, 78, 97, 109, 101, 115, 112, 97, 99, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str224268 = allocate([ 105, 110, 115, 101, 114, 116, 67, 104, 105, 108, 100, 65, 102, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str234269 = allocate([ 105, 110, 115, 101, 114, 116, 67, 104, 105, 108, 100, 66, 101, 102, 111, 114, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL16js_localName_str = allocate([ 108, 111, 99, 97, 108, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str244270 = allocate([ 110, 97, 109, 101, 115, 112, 97, 99, 101, 68, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str254271 = allocate([ 110, 111, 100, 101, 75, 105, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str264272 = allocate([ 110, 111, 114, 109, 97, 108, 105, 122, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str274273 = allocate([ 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 73, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str284274 = allocate([ 112, 114, 101, 112, 101, 110, 100, 67, 104, 105, 108, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str294275 = allocate([ 112, 114, 111, 112, 101, 114, 116, 121, 73, 115, 69, 110, 117, 109, 101, 114, 97, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str304276 = allocate([ 114, 101, 109, 111, 118, 101, 78, 97, 109, 101, 115, 112, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str314277 = allocate([ 114, 101, 112, 108, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str324278 = allocate([ 115, 101, 116, 67, 104, 105, 108, 100, 114, 101, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str334279 = allocate([ 115, 101, 116, 76, 111, 99, 97, 108, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str344280 = allocate([ 115, 101, 116, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str354281 = allocate([ 115, 101, 116, 78, 97, 109, 101, 115, 112, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL18js_toXMLString_str = allocate([ 116, 111, 88, 77, 76, 83, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

__ZL11xml_methods = allocate([ 0, 0, 0, 0, 1874, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1876, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1878, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1880, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1882, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1884, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1886, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1888, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1890, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1892, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1894, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1896, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1898, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1900, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1902, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1904, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1906, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 1908, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 1910, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1912, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1914, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1916, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1918, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1920, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1922, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1924, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1926, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1928, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1930, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1932, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1934, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 1936, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1938, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1940, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1942, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1944, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1946, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1948, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1950, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1952, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str364282 = allocate([ 115, 101, 116, 116, 105, 110, 103, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str374283 = allocate([ 115, 101, 116, 83, 101, 116, 116, 105, 110, 103, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str384284 = allocate([ 100, 101, 102, 97, 117, 108, 116, 83, 101, 116, 116, 105, 110, 103, 115, 0 ], "i8", ALLOC_STATIC);

__ZL18xml_static_methods = allocate([ 0, 0, 0, 0, 1954, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1956, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1958, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str404286 = allocate([ 110, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

__ZL15namespace_props = allocate([ 0, 0, 0, 0, 0, 71, 0, 0, 1960, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1962, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str444290 = allocate([ 100, 101, 115, 99, 101, 110, 100, 97, 110, 116, 115, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 109, 101, 116, 104, 111, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str454291 = allocate([ 88, 77, 76, 70, 105, 108, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

_js_XMLFilterClass = allocate([ 0, 0, 0, 0, 131073, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 1964, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1966, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZZL15MakeXMLPIStringP9JSContextRN2js12StringBufferEP8JSStringS5_E16pi_prefix_ucNstr = allocate([ 60, 0, 63, 0 ], [ "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZZL15MakeXMLPIStringP9JSContextRN2js12StringBufferEP8JSStringS5_E16pi_suffix_ucNstr = allocate([ 63, 0, 62, 0 ], [ "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZZL20MakeXMLCommentStringP9JSContextRN2js12StringBufferEP8JSStringE21comment_prefix_ucNstr = allocate([ 60, 0, 33, 0, 45, 0, 45, 0 ], [ "i16", 0, "i16", 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZZL20MakeXMLCommentStringP9JSContextRN2js12StringBufferEP8JSStringE21comment_suffix_ucNstr = allocate([ 45, 0, 45, 0, 62, 0 ], [ "i16", 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZZL18MakeXMLCDATAStringP9JSContextRN2js12StringBufferEP8JSStringE19cdata_prefix_ucNstr = allocate([ 60, 0, 33, 0, 91, 0, 67, 0, 68, 0, 65, 0, 84, 0, 65, 0, 91, 0 ], [ "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZZL18MakeXMLCDATAStringP9JSContextRN2js12StringBufferEP8JSStringE19cdata_suffix_ucNstr = allocate([ 93, 0, 93, 0, 62, 0 ], [ "i16", 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__ZZL14ParseXMLSourceP9JSContextP8JSStringE6prefix = allocate([ 60, 112, 97, 114, 101, 110, 116, 32, 120, 109, 108, 110, 115, 61, 34, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL14ParseXMLSourceP9JSContextP8JSStringE6middle = allocate([ 34, 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL14ParseXMLSourceP9JSContextP8JSStringE6suffix = allocate([ 60, 47, 112, 97, 114, 101, 110, 116, 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL17xml_namespace_str = allocate([ 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 88, 77, 76, 47, 49, 57, 57, 56, 47, 110, 97, 109, 101, 115, 112, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL19xmlns_namespace_str = allocate([ 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 50, 48, 48, 48, 47, 120, 109, 108, 110, 115, 47, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str464292 = allocate([ 32, 120, 109, 108, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str474293 = allocate([ 47, 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str484294 = allocate([ 60, 47, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str494295 = allocate([ 97, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL23js_leftcurly_entity_str = allocate([ 38, 35, 49, 50, 51, 59, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str504296 = allocate([ 38, 35, 120, 65, 59, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str514297 = allocate([ 38, 35, 120, 68, 59, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str524298 = allocate([ 38, 35, 120, 57, 59, 0 ], "i8", ALLOC_STATIC);

__ZL11qname_props = allocate([ 0, 0, 0, 0, 0, 71, 0, 0, 1968, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1970, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__ZL10js_uri_str = allocate([ 117, 114, 105, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str544300 = allocate([ 37, 117, 0 ], "i8", ALLOC_STATIC);

__ZL7escapes = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 0, 0, -1, 0, 0, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -5, 0, 0, 0, 0, 0, 0, 0, -7, 0, 0, 0, 0, 0, 0, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 7, 0, -2, 0, 0, 0, -4, 0, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 13, 0, -6, 0, 9, 0, 0, 0, 11, 0, -8, 0, 0, 0, 0, 0, 0, 0 ], [ "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__ZZL38repeatInformationFromInstructionOffsetsRbRiS0_E35minimumRepeatsFromInstructionOffset = allocate([ 0, 0, 1, 1, 0, 0 ], "i8", ALLOC_STATIC);

__ZZL38repeatInformationFromInstructionOffsetsRbRiS0_E35maximumRepeatsFromInstructionOffset = allocate([ 2147483647, 0, 0, 0, 2147483647, 0, 0, 0, 2147483647, 0, 0, 0, 2147483647, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

_jsc_pcre_utf8_table1 = allocate([ 127, 0, 0, 0, 2047, 0, 0, 0, 65535, 0, 0, 0, 2097151, 0, 0, 0, 67108863, 0, 0, 0, 2147483647, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

_jsc_pcre_utf8_table2 = allocate([ 0, 0, 0, 0, 192, 0, 0, 0, 224, 0, 0, 0, 240, 0, 0, 0, 248, 0, 0, 0, 252, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

_jsc_pcre_utf8_table3 = allocate([ 255, 0, 0, 0, 31, 0, 0, 0, 15, 0, 0, 0, 7, 0, 0, 0, 3, 0, 0, 0, 1, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE._jsc_pcre_utf8_table4 = allocate([ 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 5, 5, 5, 5 ], "i8", ALLOC_STATIC);

STRING_TABLE._jsc_pcre_default_tables = allocate([ 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 91, 92, 93, 94, 95, 96, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 123, 124, 125, 126, 127, 0, 62, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 3, 254, 255, 255, 135, 254, 255, 255, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 0, 0, 0, 0, 0, 0, 0, 24, 24, 24, 24, 24, 24, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 0, 0, 0, 0, 16, 0, 24, 24, 24, 24, 24, 24, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 0, 0, 0, 0, 0 ], "i8", ALLOC_STATIC);

__ZL9ucp_table = allocate([ 159383552, 0, 0, 0, 31, 0, 0, 0, 150994976, 0, 0, 0, 1946157056, 0, 0, 0, 159383585, 0, 0, 0, 1409286146, 0, 0, 0, 150994980, 0, 0, 0, 1543503872, 0, 0, 0, 159383589, 0, 0, 0, 1409286146, 0, 0, 0, 150994984, 0, 0, 0, 1476395008, 0, 0, 0, 150994985, 0, 0, 0, 1207959552, 0, 0, 0, 150994986, 0, 0, 0, 1409286144, 0, 0, 0, 150994987, 0, 0, 0, 1677721600, 0, 0, 0, 150994988, 0, 0, 0, 1409286144, 0, 0, 0, 150994989, 0, 0, 0, 1140850688, 0, 0, 0, 159383598, 0, 0, 0, 1409286145, 0, 0, 0, 159383600, 0, 0, 0, 872415241, 0, 0, 0, 159383610, 0, 0, 0, 1409286145, 0, 0, 0, 159383612, 0, 0, 0, 1677721602, 0, 0, 0, 159383615, 0, 0, 0, 1409286145, 0, 0, 0, 553648193, 0, 0, 0, 603979808, 0, 0, 0, 553648194, 0, 0, 0, 603979808, 0, 0, 0, 553648195, 0, 0, 0, 603979808, 0, 0, 0, 553648196, 0, 0, 0, 603979808, 0, 0, 0, 553648197, 0, 0, 0, 603979808, 0, 0, 0, 553648198, 0, 0, 0, 603979808, 0, 0, 0, 553648199, 0, 0, 0, 603979808, 0, 0, 0, 553648200, 0, 0, 0, 603979808, 0, 0, 0, 553648201, 0, 0, 0, 603979808, 0, 0, 0, 553648202, 0, 0, 0, 603979808, 0, 0, 0, 553648203, 0, 0, 0, 603979808, 0, 0, 0, 553648204, 0, 0, 0, 603979808, 0, 0, 0, 553648205, 0, 0, 0, 603979808, 0, 0, 0, 553648206, 0, 0, 0, 603979808, 0, 0, 0, 553648207, 0, 0, 0, 603979808, 0, 0, 0, 553648208, 0, 0, 0, 603979808, 0, 0, 0, 553648209, 0, 0, 0, 603979808, 0, 0, 0, 553648210, 0, 0, 0, 603979808, 0, 0, 0, 553648211, 0, 0, 0, 603979808, 0, 0, 0, 553648212, 0, 0, 0, 603979808, 0, 0, 0, 553648213, 0, 0, 0, 603979808, 0, 0, 0, 553648214, 0, 0, 0, 603979808, 0, 0, 0, 553648215, 0, 0, 0, 603979808, 0, 0, 0, 553648216, 0, 0, 0, 603979808, 0, 0, 0, 553648217, 0, 0, 0, 603979808, 0, 0, 0, 553648218, 0, 0, 0, 603979808, 0, 0, 0, 150995035, 0, 0, 0, 1476395008, 0, 0, 0, 150995036, 0, 0, 0, 1409286144, 0, 0, 0, 150995037, 0, 0, 0, 1207959552, 0, 0, 0, 150995038, 0, 0, 0, 1610612736, 0, 0, 0, 150995039, 0, 0, 0, 1073741824, 0, 0, 0, 150995040, 0, 0, 0, 1610612736, 0, 0, 0, 553648225, 0, 0, 0, 335609824, 0, 0, 0, 553648226, 0, 0, 0, 335609824, 0, 0, 0, 553648227, 0, 0, 0, 335609824, 0, 0, 0, 553648228, 0, 0, 0, 335609824, 0, 0, 0, 553648229, 0, 0, 0, 335609824, 0, 0, 0, 553648230, 0, 0, 0, 335609824, 0, 0, 0, 553648231, 0, 0, 0, 335609824, 0, 0, 0, 553648232, 0, 0, 0, 335609824, 0, 0, 0, 553648233, 0, 0, 0, 335609824, 0, 0, 0, 553648234, 0, 0, 0, 335609824, 0, 0, 0, 553648235, 0, 0, 0, 335609824, 0, 0, 0, 553648236, 0, 0, 0, 335609824, 0, 0, 0, 553648237, 0, 0, 0, 335609824, 0, 0, 0, 553648238, 0, 0, 0, 335609824, 0, 0, 0, 553648239, 0, 0, 0, 335609824, 0, 0, 0, 553648240, 0, 0, 0, 335609824, 0, 0, 0, 553648241, 0, 0, 0, 335609824, 0, 0, 0, 553648242, 0, 0, 0, 335609824, 0, 0, 0, 553648243, 0, 0, 0, 335609824, 0, 0, 0, 553648244, 0, 0, 0, 335609824, 0, 0, 0, 553648245, 0, 0, 0, 335609824, 0, 0, 0, 553648246, 0, 0, 0, 335609824, 0, 0, 0, 553648247, 0, 0, 0, 335609824, 0, 0, 0, 553648248, 0, 0, 0, 335609824, 0, 0, 0, 553648249, 0, 0, 0, 335609824, 0, 0, 0, 553648250, 0, 0, 0, 335609824, 0, 0, 0, 150995067, 0, 0, 0, 1476395008, 0, 0, 0, 150995068, 0, 0, 0, 1677721600, 0, 0, 0, 150995069, 0, 0, 0, 1207959552, 0, 0, 0, 150995070, 0, 0, 0, 1677721600, 0, 0, 0, 159383679, 0, 0, 0, 32, 0, 0, 0, 150995104, 0, 0, 0, 1946157056, 0, 0, 0, 150995105, 0, 0, 0, 1409286144, 0, 0, 0, 159383714, 0, 0, 0, 1543503875, 0, 0, 0, 159383718, 0, 0, 0, 1744830465, 0, 0, 0, 150995112, 0, 0, 0, 1610612736, 0, 0, 0, 150995113, 0, 0, 0, 1744830464, 0, 0, 0, 553648298, 0, 0, 0, 335544320, 0, 0, 0, 150995115, 0, 0, 0, 1342177280, 0, 0, 0, 150995116, 0, 0, 0, 1677721600, 0, 0, 0, 150995117, 0, 0, 0, 67108864, 0, 0, 0, 150995118, 0, 0, 0, 1744830464, 0, 0, 0, 150995119, 0, 0, 0, 1610612736, 0, 0, 0, 150995120, 0, 0, 0, 1744830464, 0, 0, 0, 150995121, 0, 0, 0, 1677721600, 0, 0, 0, 159383730, 0, 0, 0, 1006632961, 0, 0, 0, 150995124, 0, 0, 0, 1610612736, 0, 0, 0, 150995125, 0, 0, 0, 335545063, 0, 0, 0, 150995126, 0, 0, 0, 1744830464, 0, 0, 0, 150995127, 0, 0, 0, 1409286144, 0, 0, 0, 150995128, 0, 0, 0, 1610612736, 0, 0, 0, 150995129, 0, 0, 0, 1006632960, 0, 0, 0, 553648314, 0, 0, 0, 335544320, 0, 0, 0, 150995131, 0, 0, 0, 1275068416, 0, 0, 0, 159383740, 0, 0, 0, 1006632962, 0, 0, 0, 150995135, 0, 0, 0, 1409286144, 0, 0, 0, 553648320, 0, 0, 0, 603979808, 0, 0, 0, 553648321, 0, 0, 0, 603979808, 0, 0, 0, 553648322, 0, 0, 0, 603979808, 0, 0, 0, 553648323, 0, 0, 0, 603979808, 0, 0, 0, 553648324, 0, 0, 0, 603979808, 0, 0, 0, 553648325, 0, 0, 0, 603979808, 0, 0, 0, 553648326, 0, 0, 0, 603979808, 0, 0, 0, 553648327, 0, 0, 0, 603979808, 0, 0, 0, 553648328, 0, 0, 0, 603979808, 0, 0, 0, 553648329, 0, 0, 0, 603979808, 0, 0, 0, 553648330, 0, 0, 0, 603979808, 0, 0, 0, 553648331, 0, 0, 0, 603979808, 0, 0, 0, 553648332, 0, 0, 0, 603979808, 0, 0, 0, 553648333, 0, 0, 0, 603979808, 0, 0, 0, 553648334, 0, 0, 0, 603979808, 0, 0, 0, 553648335, 0, 0, 0, 603979808, 0, 0, 0, 553648336, 0, 0, 0, 603979808, 0, 0, 0, 553648337, 0, 0, 0, 603979808, 0, 0, 0, 553648338, 0, 0, 0, 603979808, 0, 0, 0, 553648339, 0, 0, 0, 603979808, 0, 0, 0, 553648340, 0, 0, 0, 603979808, 0, 0, 0, 553648341, 0, 0, 0, 603979808, 0, 0, 0, 553648342, 0, 0, 0, 603979808, 0, 0, 0, 150995159, 0, 0, 0, 1677721600, 0, 0, 0, 553648344, 0, 0, 0, 603979808, 0, 0, 0, 553648345, 0, 0, 0, 603979808, 0, 0, 0, 553648346, 0, 0, 0, 603979808, 0, 0, 0, 553648347, 0, 0, 0, 603979808, 0, 0, 0, 553648348, 0, 0, 0, 603979808, 0, 0, 0, 553648349, 0, 0, 0, 603979808, 0, 0, 0, 553648350, 0, 0, 0, 603979808, 0, 0, 0, 553648351, 0, 0, 0, 335544320, 0, 0, 0, 553648352, 0, 0, 0, 335609824, 0, 0, 0, 553648353, 0, 0, 0, 335609824, 0, 0, 0, 553648354, 0, 0, 0, 335609824, 0, 0, 0, 553648355, 0, 0, 0, 335609824, 0, 0, 0, 553648356, 0, 0, 0, 335609824, 0, 0, 0, 553648357, 0, 0, 0, 335609824, 0, 0, 0, 553648358, 0, 0, 0, 335609824, 0, 0, 0, 553648359, 0, 0, 0, 335609824, 0, 0, 0, 553648360, 0, 0, 0, 335609824, 0, 0, 0, 553648361, 0, 0, 0, 335609824, 0, 0, 0, 553648362, 0, 0, 0, 335609824, 0, 0, 0, 553648363, 0, 0, 0, 335609824, 0, 0, 0, 553648364, 0, 0, 0, 335609824, 0, 0, 0, 553648365, 0, 0, 0, 335609824, 0, 0, 0, 553648366, 0, 0, 0, 335609824, 0, 0, 0, 553648367, 0, 0, 0, 335609824, 0, 0, 0, 553648368, 0, 0, 0, 335609824, 0, 0, 0, 553648369, 0, 0, 0, 335609824, 0, 0, 0, 553648370, 0, 0, 0, 335609824, 0, 0, 0, 553648371, 0, 0, 0, 335609824, 0, 0, 0, 553648372, 0, 0, 0, 335609824, 0, 0, 0, 553648373, 0, 0, 0, 335609824, 0, 0, 0, 553648374, 0, 0, 0, 335609824, 0, 0, 0, 150995191, 0, 0, 0, 1677721600, 0, 0, 0, 553648376, 0, 0, 0, 335609824, 0, 0, 0, 553648377, 0, 0, 0, 335609824, 0, 0, 0, 553648378, 0, 0, 0, 335609824, 0, 0, 0, 553648379, 0, 0, 0, 335609824, 0, 0, 0, 553648380, 0, 0, 0, 335609824, 0, 0, 0, 553648381, 0, 0, 0, 335609824, 0, 0, 0, 553648382, 0, 0, 0, 335609824, 0, 0, 0, 553648383, 0, 0, 0, 335544441, 0, 0, 0, 553648384, 0, 0, 0, 603979777, 0, 0, 0, 553648385, 0, 0, 0, 335609855, 0, 0, 0, 553648386, 0, 0, 0, 603979777, 0, 0, 0, 553648387, 0, 0, 0, 335609855, 0, 0, 0, 553648388, 0, 0, 0, 603979777, 0, 0, 0, 553648389, 0, 0, 0, 335609855, 0, 0, 0, 553648390, 0, 0, 0, 603979777, 0, 0, 0, 553648391, 0, 0, 0, 335609855, 0, 0, 0, 553648392, 0, 0, 0, 603979777, 0, 0, 0, 553648393, 0, 0, 0, 335609855, 0, 0, 0, 553648394, 0, 0, 0, 603979777, 0, 0, 0, 553648395, 0, 0, 0, 335609855, 0, 0, 0, 553648396, 0, 0, 0, 603979777, 0, 0, 0, 553648397, 0, 0, 0, 335609855, 0, 0, 0, 553648398, 0, 0, 0, 603979777, 0, 0, 0, 553648399, 0, 0, 0, 335609855, 0, 0, 0, 553648400, 0, 0, 0, 603979777, 0, 0, 0, 553648401, 0, 0, 0, 335609855, 0, 0, 0, 553648402, 0, 0, 0, 603979777, 0, 0, 0, 553648403, 0, 0, 0, 335609855, 0, 0, 0, 553648404, 0, 0, 0, 603979777, 0, 0, 0, 553648405, 0, 0, 0, 335609855, 0, 0, 0, 553648406, 0, 0, 0, 603979777, 0, 0, 0, 553648407, 0, 0, 0, 335609855, 0, 0, 0, 553648408, 0, 0, 0, 603979777, 0, 0, 0, 553648409, 0, 0, 0, 335609855, 0, 0, 0, 553648410, 0, 0, 0, 603979777, 0, 0, 0, 553648411, 0, 0, 0, 335609855, 0, 0, 0, 553648412, 0, 0, 0, 603979777, 0, 0, 0, 553648413, 0, 0, 0, 335609855, 0, 0, 0, 553648414, 0, 0, 0, 603979777, 0, 0, 0, 553648415, 0, 0, 0, 335609855, 0, 0, 0, 553648416, 0, 0, 0, 603979777, 0, 0, 0, 553648417, 0, 0, 0, 335609855, 0, 0, 0, 553648418, 0, 0, 0, 603979777, 0, 0, 0, 553648419, 0, 0, 0, 335609855, 0, 0, 0, 553648420, 0, 0, 0, 603979777, 0, 0, 0, 553648421, 0, 0, 0, 335609855, 0, 0, 0, 553648422, 0, 0, 0, 603979777, 0, 0, 0, 553648423, 0, 0, 0, 335609855, 0, 0, 0, 553648424, 0, 0, 0, 603979777, 0, 0, 0, 553648425, 0, 0, 0, 335609855, 0, 0, 0, 553648426, 0, 0, 0, 603979777, 0, 0, 0, 553648427, 0, 0, 0, 335609855, 0, 0, 0, 553648428, 0, 0, 0, 603979777, 0, 0, 0, 553648429, 0, 0, 0, 335609855, 0, 0, 0, 553648430, 0, 0, 0, 603979777, 0, 0, 0, 553648431, 0, 0, 0, 335609855, 0, 0, 0, 553648432, 0, 0, 0, 604045113, 0, 0, 0, 553648433, 0, 0, 0, 335609624, 0, 0, 0, 553648434, 0, 0, 0, 603979777, 0, 0, 0, 553648435, 0, 0, 0, 335609855, 0, 0, 0, 553648436, 0, 0, 0, 603979777, 0, 0, 0, 553648437, 0, 0, 0, 335609855, 0, 0, 0, 553648438, 0, 0, 0, 603979777, 0, 0, 0, 553648439, 0, 0, 0, 335609855, 0, 0, 0, 553648440, 0, 0, 0, 335544320, 0, 0, 0, 553648441, 0, 0, 0, 603979777, 0, 0, 0, 553648442, 0, 0, 0, 335609855, 0, 0, 0, 553648443, 0, 0, 0, 603979777, 0, 0, 0, 553648444, 0, 0, 0, 335609855, 0, 0, 0, 553648445, 0, 0, 0, 603979777, 0, 0, 0, 553648446, 0, 0, 0, 335609855, 0, 0, 0, 553648447, 0, 0, 0, 603979777, 0, 0, 0, 553648448, 0, 0, 0, 335609855, 0, 0, 0, 553648449, 0, 0, 0, 603979777, 0, 0, 0, 553648450, 0, 0, 0, 335609855, 0, 0, 0, 553648451, 0, 0, 0, 603979777, 0, 0, 0, 553648452, 0, 0, 0, 335609855, 0, 0, 0, 553648453, 0, 0, 0, 603979777, 0, 0, 0, 553648454, 0, 0, 0, 335609855, 0, 0, 0, 553648455, 0, 0, 0, 603979777, 0, 0, 0, 553648456, 0, 0, 0, 335609855, 0, 0, 0, 553648457, 0, 0, 0, 335544320, 0, 0, 0, 553648458, 0, 0, 0, 603979777, 0, 0, 0, 553648459, 0, 0, 0, 335609855, 0, 0, 0, 553648460, 0, 0, 0, 603979777, 0, 0, 0, 553648461, 0, 0, 0, 335609855, 0, 0, 0, 553648462, 0, 0, 0, 603979777, 0, 0, 0, 553648463, 0, 0, 0, 335609855, 0, 0, 0, 553648464, 0, 0, 0, 603979777, 0, 0, 0, 553648465, 0, 0, 0, 335609855, 0, 0, 0, 553648466, 0, 0, 0, 603979777, 0, 0, 0, 553648467, 0, 0, 0, 335609855, 0, 0, 0, 553648468, 0, 0, 0, 603979777, 0, 0, 0, 553648469, 0, 0, 0, 335609855, 0, 0, 0, 553648470, 0, 0, 0, 603979777, 0, 0, 0, 553648471, 0, 0, 0, 335609855, 0, 0, 0, 553648472, 0, 0, 0, 603979777, 0, 0, 0, 553648473, 0, 0, 0, 335609855, 0, 0, 0, 553648474, 0, 0, 0, 603979777, 0, 0, 0, 553648475, 0, 0, 0, 335609855, 0, 0, 0, 553648476, 0, 0, 0, 603979777, 0, 0, 0, 553648477, 0, 0, 0, 335609855, 0, 0, 0, 553648478, 0, 0, 0, 603979777, 0, 0, 0, 553648479, 0, 0, 0, 335609855, 0, 0, 0, 553648480, 0, 0, 0, 603979777, 0, 0, 0, 553648481, 0, 0, 0, 335609855, 0, 0, 0, 553648482, 0, 0, 0, 603979777, 0, 0, 0, 553648483, 0, 0, 0, 335609855, 0, 0, 0, 553648484, 0, 0, 0, 603979777, 0, 0, 0, 553648485, 0, 0, 0, 335609855, 0, 0, 0, 553648486, 0, 0, 0, 603979777, 0, 0, 0, 553648487, 0, 0, 0, 335609855, 0, 0, 0, 553648488, 0, 0, 0, 603979777, 0, 0, 0, 553648489, 0, 0, 0, 335609855, 0, 0, 0, 553648490, 0, 0, 0, 603979777, 0, 0, 0, 553648491, 0, 0, 0, 335609855, 0, 0, 0, 553648492, 0, 0, 0, 603979777, 0, 0, 0, 553648493, 0, 0, 0, 335609855, 0, 0, 0, 553648494, 0, 0, 0, 603979777, 0, 0, 0, 553648495, 0, 0, 0, 335609855, 0, 0, 0, 553648496, 0, 0, 0, 603979777, 0, 0, 0, 553648497, 0, 0, 0, 335609855, 0, 0, 0, 553648498, 0, 0, 0, 603979777, 0, 0, 0, 553648499, 0, 0, 0, 335609855, 0, 0, 0, 553648500, 0, 0, 0, 603979777, 0, 0, 0, 553648501, 0, 0, 0, 335609855, 0, 0, 0, 553648502, 0, 0, 0, 603979777, 0, 0, 0, 553648503, 0, 0, 0, 335609855, 0, 0, 0, 553648504, 0, 0, 0, 604045191, 0, 0, 0, 553648505, 0, 0, 0, 603979777, 0, 0, 0, 553648506, 0, 0, 0, 335609855, 0, 0, 0, 553648507, 0, 0, 0, 603979777, 0, 0, 0, 553648508, 0, 0, 0, 335609855, 0, 0, 0, 553648509, 0, 0, 0, 603979777, 0, 0, 0, 553648510, 0, 0, 0, 335609855, 0, 0, 0, 553648511, 0, 0, 0, 335609556, 0, 0, 0, 553648512, 0, 0, 0, 335544320, 0, 0, 0, 553648513, 0, 0, 0, 603979986, 0, 0, 0, 553648514, 0, 0, 0, 603979777, 0, 0, 0, 553648515, 0, 0, 0, 335609855, 0, 0, 0, 553648516, 0, 0, 0, 603979777, 0, 0, 0, 553648517, 0, 0, 0, 335609855, 0, 0, 0, 553648518, 0, 0, 0, 603979982, 0, 0, 0, 553648519, 0, 0, 0, 603979777, 0, 0, 0, 553648520, 0, 0, 0, 335609855, 0, 0, 0, 553648521, 0, 0, 0, 603979981, 0, 0, 0, 553648522, 0, 0, 0, 603979981, 0, 0, 0, 553648523, 0, 0, 0, 603979777, 0, 0, 0, 553648524, 0, 0, 0, 335609855, 0, 0, 0, 553648525, 0, 0, 0, 335544320, 0, 0, 0, 553648526, 0, 0, 0, 603979855, 0, 0, 0, 553648527, 0, 0, 0, 603979978, 0, 0, 0, 553648528, 0, 0, 0, 603979979, 0, 0, 0, 553648529, 0, 0, 0, 603979777, 0, 0, 0, 553648530, 0, 0, 0, 335609855, 0, 0, 0, 553648531, 0, 0, 0, 603979981, 0, 0, 0, 553648532, 0, 0, 0, 603979983, 0, 0, 0, 553648533, 0, 0, 0, 335544417, 0, 0, 0, 553648534, 0, 0, 0, 603979987, 0, 0, 0, 553648535, 0, 0, 0, 603979985, 0, 0, 0, 553648536, 0, 0, 0, 603979777, 0, 0, 0, 553648537, 0, 0, 0, 335609855, 0, 0, 0, 553648538, 0, 0, 0, 335544483, 0, 0, 0, 553648539, 0, 0, 0, 335544320, 0, 0, 0, 553648540, 0, 0, 0, 603979987, 0, 0, 0, 553648541, 0, 0, 0, 603979989, 0, 0, 0, 553648542, 0, 0, 0, 335544450, 0, 0, 0, 553648543, 0, 0, 0, 603979990, 0, 0, 0, 553648544, 0, 0, 0, 603979777, 0, 0, 0, 553648545, 0, 0, 0, 335609855, 0, 0, 0, 553648546, 0, 0, 0, 603979777, 0, 0, 0, 553648547, 0, 0, 0, 335609855, 0, 0, 0, 553648548, 0, 0, 0, 603979777, 0, 0, 0, 553648549, 0, 0, 0, 335609855, 0, 0, 0, 553648550, 0, 0, 0, 603979994, 0, 0, 0, 553648551, 0, 0, 0, 603979777, 0, 0, 0, 553648552, 0, 0, 0, 335609855, 0, 0, 0, 553648553, 0, 0, 0, 603979994, 0, 0, 0, 562037162, 0, 0, 0, 335544321, 0, 0, 0, 553648556, 0, 0, 0, 603979777, 0, 0, 0, 553648557, 0, 0, 0, 335609855, 0, 0, 0, 553648558, 0, 0, 0, 603979994, 0, 0, 0, 553648559, 0, 0, 0, 603979777, 0, 0, 0, 553648560, 0, 0, 0, 335609855, 0, 0, 0, 553648561, 0, 0, 0, 603979993, 0, 0, 0, 553648562, 0, 0, 0, 603979993, 0, 0, 0, 553648563, 0, 0, 0, 603979777, 0, 0, 0, 553648564, 0, 0, 0, 335609855, 0, 0, 0, 553648565, 0, 0, 0, 603979777, 0, 0, 0, 553648566, 0, 0, 0, 335609855, 0, 0, 0, 553648567, 0, 0, 0, 603979995, 0, 0, 0, 553648568, 0, 0, 0, 603979777, 0, 0, 0, 553648569, 0, 0, 0, 335609855, 0, 0, 0, 553648570, 0, 0, 0, 335544320, 0, 0, 0, 553648571, 0, 0, 0, 469762048, 0, 0, 0, 553648572, 0, 0, 0, 603979777, 0, 0, 0, 553648573, 0, 0, 0, 335609855, 0, 0, 0, 553648574, 0, 0, 0, 335544320, 0, 0, 0, 553648575, 0, 0, 0, 335544376, 0, 0, 0, 562037184, 0, 0, 0, 469762051, 0, 0, 0, 553648580, 0, 0, 0, 603979778, 0, 0, 0, 553648581, 0, 0, 0, 536936447, 0, 0, 0, 553648582, 0, 0, 0, 335609854, 0, 0, 0, 553648583, 0, 0, 0, 603979778, 0, 0, 0, 553648584, 0, 0, 0, 536936447, 0, 0, 0, 553648585, 0, 0, 0, 335609854, 0, 0, 0, 553648586, 0, 0, 0, 603979778, 0, 0, 0, 553648587, 0, 0, 0, 536936447, 0, 0, 0, 553648588, 0, 0, 0, 335609854, 0, 0, 0, 553648589, 0, 0, 0, 603979777, 0, 0, 0, 553648590, 0, 0, 0, 335609855, 0, 0, 0, 553648591, 0, 0, 0, 603979777, 0, 0, 0, 553648592, 0, 0, 0, 335609855, 0, 0, 0, 553648593, 0, 0, 0, 603979777, 0, 0, 0, 553648594, 0, 0, 0, 335609855, 0, 0, 0, 553648595, 0, 0, 0, 603979777, 0, 0, 0, 553648596, 0, 0, 0, 335609855, 0, 0, 0, 553648597, 0, 0, 0, 603979777, 0, 0, 0, 553648598, 0, 0, 0, 335609855, 0, 0, 0, 553648599, 0, 0, 0, 603979777, 0, 0, 0, 553648600, 0, 0, 0, 335609855, 0, 0, 0, 553648601, 0, 0, 0, 603979777, 0, 0, 0, 553648602, 0, 0, 0, 335609855, 0, 0, 0, 553648603, 0, 0, 0, 603979777, 0, 0, 0, 553648604, 0, 0, 0, 335609855, 0, 0, 0, 553648605, 0, 0, 0, 335609777, 0, 0, 0, 553648606, 0, 0, 0, 603979777, 0, 0, 0, 553648607, 0, 0, 0, 335609855, 0, 0, 0, 553648608, 0, 0, 0, 603979777, 0, 0, 0, 553648609, 0, 0, 0, 335609855, 0, 0, 0, 553648610, 0, 0, 0, 603979777, 0, 0, 0, 553648611, 0, 0, 0, 335609855, 0, 0, 0, 553648612, 0, 0, 0, 603979777, 0, 0, 0, 553648613, 0, 0, 0, 335609855, 0, 0, 0, 553648614, 0, 0, 0, 603979777, 0, 0, 0, 553648615, 0, 0, 0, 335609855, 0, 0, 0, 553648616, 0, 0, 0, 603979777, 0, 0, 0, 553648617, 0, 0, 0, 335609855, 0, 0, 0, 553648618, 0, 0, 0, 603979777, 0, 0, 0, 553648619, 0, 0, 0, 335609855, 0, 0, 0, 553648620, 0, 0, 0, 603979777, 0, 0, 0, 553648621, 0, 0, 0, 335609855, 0, 0, 0, 553648622, 0, 0, 0, 603979777, 0, 0, 0, 553648623, 0, 0, 0, 335609855, 0, 0, 0, 553648624, 0, 0, 0, 335544320, 0, 0, 0, 553648625, 0, 0, 0, 603979778, 0, 0, 0, 553648626, 0, 0, 0, 536936447, 0, 0, 0, 553648627, 0, 0, 0, 335609854, 0, 0, 0, 553648628, 0, 0, 0, 603979777, 0, 0, 0, 553648629, 0, 0, 0, 335609855, 0, 0, 0, 553648630, 0, 0, 0, 604045215, 0, 0, 0, 553648631, 0, 0, 0, 604045256, 0, 0, 0, 553648632, 0, 0, 0, 603979777, 0, 0, 0, 553648633, 0, 0, 0, 335609855, 0, 0, 0, 553648634, 0, 0, 0, 603979777, 0, 0, 0, 553648635, 0, 0, 0, 335609855, 0, 0, 0, 553648636, 0, 0, 0, 603979777, 0, 0, 0, 553648637, 0, 0, 0, 335609855, 0, 0, 0, 553648638, 0, 0, 0, 603979777, 0, 0, 0, 553648639, 0, 0, 0, 335609855, 0, 0, 0, 553648640, 0, 0, 0, 603979777, 0, 0, 0, 553648641, 0, 0, 0, 335609855, 0, 0, 0, 553648642, 0, 0, 0, 603979777, 0, 0, 0, 553648643, 0, 0, 0, 335609855, 0, 0, 0, 553648644, 0, 0, 0, 603979777, 0, 0, 0, 553648645, 0, 0, 0, 335609855, 0, 0, 0, 553648646, 0, 0, 0, 603979777, 0, 0, 0, 553648647, 0, 0, 0, 335609855, 0, 0, 0, 553648648, 0, 0, 0, 603979777, 0, 0, 0, 553648649, 0, 0, 0, 335609855, 0, 0, 0, 553648650, 0, 0, 0, 603979777, 0, 0, 0, 553648651, 0, 0, 0, 335609855, 0, 0, 0, 553648652, 0, 0, 0, 603979777, 0, 0, 0, 553648653, 0, 0, 0, 335609855, 0, 0, 0, 553648654, 0, 0, 0, 603979777, 0, 0, 0, 553648655, 0, 0, 0, 335609855, 0, 0, 0, 553648656, 0, 0, 0, 603979777, 0, 0, 0, 553648657, 0, 0, 0, 335609855, 0, 0, 0, 553648658, 0, 0, 0, 603979777, 0, 0, 0, 553648659, 0, 0, 0, 335609855, 0, 0, 0, 553648660, 0, 0, 0, 603979777, 0, 0, 0, 553648661, 0, 0, 0, 335609855, 0, 0, 0, 553648662, 0, 0, 0, 603979777, 0, 0, 0, 553648663, 0, 0, 0, 335609855, 0, 0, 0, 553648664, 0, 0, 0, 603979777, 0, 0, 0, 553648665, 0, 0, 0, 335609855, 0, 0, 0, 553648666, 0, 0, 0, 603979777, 0, 0, 0, 553648667, 0, 0, 0, 335609855, 0, 0, 0, 553648668, 0, 0, 0, 603979777, 0, 0, 0, 553648669, 0, 0, 0, 335609855, 0, 0, 0, 553648670, 0, 0, 0, 603979777, 0, 0, 0, 553648671, 0, 0, 0, 335609855, 0, 0, 0, 553648672, 0, 0, 0, 604045182, 0, 0, 0, 553648673, 0, 0, 0, 335544320, 0, 0, 0, 553648674, 0, 0, 0, 603979777, 0, 0, 0, 553648675, 0, 0, 0, 335609855, 0, 0, 0, 553648676, 0, 0, 0, 603979777, 0, 0, 0, 553648677, 0, 0, 0, 335609855, 0, 0, 0, 553648678, 0, 0, 0, 603979777, 0, 0, 0, 553648679, 0, 0, 0, 335609855, 0, 0, 0, 553648680, 0, 0, 0, 603979777, 0, 0, 0, 553648681, 0, 0, 0, 335609855, 0, 0, 0, 553648682, 0, 0, 0, 603979777, 0, 0, 0, 553648683, 0, 0, 0, 335609855, 0, 0, 0, 553648684, 0, 0, 0, 603979777, 0, 0, 0, 553648685, 0, 0, 0, 335609855, 0, 0, 0, 553648686, 0, 0, 0, 603979777, 0, 0, 0, 553648687, 0, 0, 0, 335609855, 0, 0, 0, 553648688, 0, 0, 0, 603979777, 0, 0, 0, 553648689, 0, 0, 0, 335609855, 0, 0, 0, 553648690, 0, 0, 0, 603979777, 0, 0, 0, 553648691, 0, 0, 0, 335609855, 0, 0, 0, 562037300, 0, 0, 0, 335544325, 0, 0, 0, 553648698, 0, 0, 0, 603979776, 0, 0, 0, 553648699, 0, 0, 0, 603979777, 0, 0, 0, 553648700, 0, 0, 0, 335609855, 0, 0, 0, 553648701, 0, 0, 0, 604045149, 0, 0, 0, 553648702, 0, 0, 0, 603979776, 0, 0, 0, 562037311, 0, 0, 0, 335544321, 0, 0, 0, 553648705, 0, 0, 0, 603979859, 0, 0, 0, 562037328, 0, 0, 0, 335544322, 0, 0, 0, 553648723, 0, 0, 0, 335609646, 0, 0, 0, 553648724, 0, 0, 0, 335609650, 0, 0, 0, 553648725, 0, 0, 0, 335544320, 0, 0, 0, 553648726, 0, 0, 0, 335609651, 0, 0, 0, 553648727, 0, 0, 0, 335609651, 0, 0, 0, 553648728, 0, 0, 0, 335544320, 0, 0, 0, 553648729, 0, 0, 0, 335609654, 0, 0, 0, 553648730, 0, 0, 0, 335544320, 0, 0, 0, 553648731, 0, 0, 0, 335609653, 0, 0, 0, 562037340, 0, 0, 0, 335544323, 0, 0, 0, 553648736, 0, 0, 0, 335609651, 0, 0, 0, 562037345, 0, 0, 0, 335544321, 0, 0, 0, 553648739, 0, 0, 0, 335609649, 0, 0, 0, 562037348, 0, 0, 0, 335544323, 0, 0, 0, 553648744, 0, 0, 0, 335609647, 0, 0, 0, 553648745, 0, 0, 0, 335609645, 0, 0, 0, 562037354, 0, 0, 0, 335544324, 0, 0, 0, 553648751, 0, 0, 0, 335609645, 0, 0, 0, 562037360, 0, 0, 0, 335544321, 0, 0, 0, 553648754, 0, 0, 0, 335609643, 0, 0, 0, 562037363, 0, 0, 0, 335544321, 0, 0, 0, 553648757, 0, 0, 0, 335609642, 0, 0, 0, 562037366, 0, 0, 0, 335544329, 0, 0, 0, 553648768, 0, 0, 0, 335609638, 0, 0, 0, 562037377, 0, 0, 0, 335544321, 0, 0, 0, 553648771, 0, 0, 0, 335609638, 0, 0, 0, 562037380, 0, 0, 0, 335544323, 0, 0, 0, 553648776, 0, 0, 0, 335609638, 0, 0, 0, 553648777, 0, 0, 0, 335544320, 0, 0, 0, 553648778, 0, 0, 0, 335609639, 0, 0, 0, 553648779, 0, 0, 0, 335609639, 0, 0, 0, 562037388, 0, 0, 0, 335544325, 0, 0, 0, 553648786, 0, 0, 0, 335609637, 0, 0, 0, 553648787, 0, 0, 0, 335544320, 0, 0, 0, 553648788, 0, 0, 0, 335609773, 0, 0, 0, 562037397, 0, 0, 0, 335544346, 0, 0, 0, 562037424, 0, 0, 0, 402653201, 0, 0, 0, 159384258, 0, 0, 0, 1610612739, 0, 0, 0, 159384262, 0, 0, 0, 402653195, 0, 0, 0, 159384274, 0, 0, 0, 1610612749, 0, 0, 0, 562037472, 0, 0, 0, 402653188, 0, 0, 0, 159384293, 0, 0, 0, 1610612744, 0, 0, 0, 150995694, 0, 0, 0, 402653184, 0, 0, 0, 159384303, 0, 0, 0, 1610612752, 0, 0, 0, 461374208, 0, 0, 0, 805306436, 0, 0, 0, 452985669, 0, 0, 0, 805306452, 0, 0, 0, 461374278, 0, 0, 0, 805306409, 0, 0, 0, 327156596, 0, 0, 0, 1610612737, 0, 0, 0, 318767994, 0, 0, 0, 402653184, 0, 0, 0, 150995838, 0, 0, 0, 1409286144, 0, 0, 0, 327156612, 0, 0, 0, 1610612737, 0, 0, 0, 318768006, 0, 0, 0, 603979814, 0, 0, 0, 150995847, 0, 0, 0, 1409286144, 0, 0, 0, 318768008, 0, 0, 0, 603979813, 0, 0, 0, 318768009, 0, 0, 0, 603979813, 0, 0, 0, 318768010, 0, 0, 0, 603979813, 0, 0, 0, 318768012, 0, 0, 0, 603979840, 0, 0, 0, 318768014, 0, 0, 0, 603979839, 0, 0, 0, 318768015, 0, 0, 0, 603979839, 0, 0, 0, 318768016, 0, 0, 0, 335544320, 0, 0, 0, 318768017, 0, 0, 0, 603979808, 0, 0, 0, 318768018, 0, 0, 0, 603979808, 0, 0, 0, 318768019, 0, 0, 0, 603979808, 0, 0, 0, 318768020, 0, 0, 0, 603979808, 0, 0, 0, 318768021, 0, 0, 0, 603979808, 0, 0, 0, 318768022, 0, 0, 0, 603979808, 0, 0, 0, 318768023, 0, 0, 0, 603979808, 0, 0, 0, 318768024, 0, 0, 0, 603979808, 0, 0, 0, 318768025, 0, 0, 0, 603979808, 0, 0, 0, 318768026, 0, 0, 0, 603979808, 0, 0, 0, 318768027, 0, 0, 0, 603979808, 0, 0, 0, 318768028, 0, 0, 0, 603979808, 0, 0, 0, 318768029, 0, 0, 0, 603979808, 0, 0, 0, 318768030, 0, 0, 0, 603979808, 0, 0, 0, 318768031, 0, 0, 0, 603979808, 0, 0, 0, 318768032, 0, 0, 0, 603979808, 0, 0, 0, 318768033, 0, 0, 0, 603979808, 0, 0, 0, 318768035, 0, 0, 0, 603979808, 0, 0, 0, 318768036, 0, 0, 0, 603979808, 0, 0, 0, 318768037, 0, 0, 0, 603979808, 0, 0, 0, 318768038, 0, 0, 0, 603979808, 0, 0, 0, 318768039, 0, 0, 0, 603979808, 0, 0, 0, 318768040, 0, 0, 0, 603979808, 0, 0, 0, 318768041, 0, 0, 0, 603979808, 0, 0, 0, 318768042, 0, 0, 0, 603979808, 0, 0, 0, 318768043, 0, 0, 0, 603979808, 0, 0, 0, 318768044, 0, 0, 0, 335609818, 0, 0, 0, 318768045, 0, 0, 0, 335609819, 0, 0, 0, 318768046, 0, 0, 0, 335609819, 0, 0, 0, 318768047, 0, 0, 0, 335609819, 0, 0, 0, 318768048, 0, 0, 0, 335544320, 0, 0, 0, 318768049, 0, 0, 0, 335609824, 0, 0, 0, 318768050, 0, 0, 0, 335609824, 0, 0, 0, 318768051, 0, 0, 0, 335609824, 0, 0, 0, 318768052, 0, 0, 0, 335609824, 0, 0, 0, 318768053, 0, 0, 0, 335609824, 0, 0, 0, 318768054, 0, 0, 0, 335609824, 0, 0, 0, 318768055, 0, 0, 0, 335609824, 0, 0, 0, 318768056, 0, 0, 0, 335609824, 0, 0, 0, 318768057, 0, 0, 0, 335609824, 0, 0, 0, 318768058, 0, 0, 0, 335609824, 0, 0, 0, 318768059, 0, 0, 0, 335609824, 0, 0, 0, 318768060, 0, 0, 0, 335609824, 0, 0, 0, 318768061, 0, 0, 0, 335609824, 0, 0, 0, 318768062, 0, 0, 0, 335609824, 0, 0, 0, 318768063, 0, 0, 0, 335609824, 0, 0, 0, 318768064, 0, 0, 0, 335609824, 0, 0, 0, 318768065, 0, 0, 0, 335609824, 0, 0, 0, 318768066, 0, 0, 0, 335609825, 0, 0, 0, 318768067, 0, 0, 0, 335609824, 0, 0, 0, 318768068, 0, 0, 0, 335609824, 0, 0, 0, 318768069, 0, 0, 0, 335609824, 0, 0, 0, 318768070, 0, 0, 0, 335609824, 0, 0, 0, 318768071, 0, 0, 0, 335609824, 0, 0, 0, 318768072, 0, 0, 0, 335609824, 0, 0, 0, 318768073, 0, 0, 0, 335609824, 0, 0, 0, 318768074, 0, 0, 0, 335609824, 0, 0, 0, 318768075, 0, 0, 0, 335609824, 0, 0, 0, 318768076, 0, 0, 0, 335609792, 0, 0, 0, 318768077, 0, 0, 0, 335609793, 0, 0, 0, 318768078, 0, 0, 0, 335609793, 0, 0, 0, 318768080, 0, 0, 0, 335609794, 0, 0, 0, 318768081, 0, 0, 0, 335609799, 0, 0, 0, 327156690, 0, 0, 0, 603979778, 0, 0, 0, 318768085, 0, 0, 0, 335609809, 0, 0, 0, 318768086, 0, 0, 0, 335609802, 0, 0, 0, 318768087, 0, 0, 0, 335544320, 0, 0, 0, 318768088, 0, 0, 0, 603979777, 0, 0, 0, 318768089, 0, 0, 0, 335609855, 0, 0, 0, 318768090, 0, 0, 0, 603979777, 0, 0, 0, 318768091, 0, 0, 0, 335609855, 0, 0, 0, 318768092, 0, 0, 0, 603979777, 0, 0, 0, 318768093, 0, 0, 0, 335609855, 0, 0, 0, 318768094, 0, 0, 0, 603979777, 0, 0, 0, 318768095, 0, 0, 0, 335609855, 0, 0, 0, 318768096, 0, 0, 0, 603979777, 0, 0, 0, 318768097, 0, 0, 0, 335609855, 0, 0, 0, 167773154, 0, 0, 0, 603979777, 0, 0, 0, 167773155, 0, 0, 0, 335609855, 0, 0, 0, 167773156, 0, 0, 0, 603979777, 0, 0, 0, 167773157, 0, 0, 0, 335609855, 0, 0, 0, 167773158, 0, 0, 0, 603979777, 0, 0, 0, 167773159, 0, 0, 0, 335609855, 0, 0, 0, 167773160, 0, 0, 0, 603979777, 0, 0, 0, 167773161, 0, 0, 0, 335609855, 0, 0, 0, 167773162, 0, 0, 0, 603979777, 0, 0, 0, 167773163, 0, 0, 0, 335609855, 0, 0, 0, 167773164, 0, 0, 0, 603979777, 0, 0, 0, 167773165, 0, 0, 0, 335609855, 0, 0, 0, 167773166, 0, 0, 0, 603979777, 0, 0, 0, 167773167, 0, 0, 0, 335609855, 0, 0, 0, 318768112, 0, 0, 0, 335609770, 0, 0, 0, 318768113, 0, 0, 0, 335609776, 0, 0, 0, 318768114, 0, 0, 0, 335544327, 0, 0, 0, 318768115, 0, 0, 0, 335544320, 0, 0, 0, 318768116, 0, 0, 0, 604045252, 0, 0, 0, 318768117, 0, 0, 0, 335609760, 0, 0, 0, 318768118, 0, 0, 0, 1677721600, 0, 0, 0, 318768119, 0, 0, 0, 603979777, 0, 0, 0, 318768120, 0, 0, 0, 335609855, 0, 0, 0, 318768121, 0, 0, 0, 604045305, 0, 0, 0, 318768122, 0, 0, 0, 603979777, 0, 0, 0, 318768123, 0, 0, 0, 335609855, 0, 0, 0, 318768124, 0, 0, 0, 335544320, 0, 0, 0, 327156733, 0, 0, 0, 603979778, 0, 0, 0, 201327616, 0, 0, 0, 603979856, 0, 0, 0, 201327617, 0, 0, 0, 603979856, 0, 0, 0, 201327618, 0, 0, 0, 603979856, 0, 0, 0, 201327619, 0, 0, 0, 603979856, 0, 0, 0, 201327620, 0, 0, 0, 603979856, 0, 0, 0, 201327621, 0, 0, 0, 603979856, 0, 0, 0, 201327622, 0, 0, 0, 603979856, 0, 0, 0, 201327623, 0, 0, 0, 603979856, 0, 0, 0, 201327624, 0, 0, 0, 603979856, 0, 0, 0, 201327625, 0, 0, 0, 603979856, 0, 0, 0, 201327626, 0, 0, 0, 603979856, 0, 0, 0, 201327627, 0, 0, 0, 603979856, 0, 0, 0, 201327628, 0, 0, 0, 603979856, 0, 0, 0, 201327629, 0, 0, 0, 603979856, 0, 0, 0, 201327630, 0, 0, 0, 603979856, 0, 0, 0, 201327631, 0, 0, 0, 603979856, 0, 0, 0, 201327632, 0, 0, 0, 603979808, 0, 0, 0, 201327633, 0, 0, 0, 603979808, 0, 0, 0, 201327634, 0, 0, 0, 603979808, 0, 0, 0, 201327635, 0, 0, 0, 603979808, 0, 0, 0, 201327636, 0, 0, 0, 603979808, 0, 0, 0, 201327637, 0, 0, 0, 603979808, 0, 0, 0, 201327638, 0, 0, 0, 603979808, 0, 0, 0, 201327639, 0, 0, 0, 603979808, 0, 0, 0, 201327640, 0, 0, 0, 603979808, 0, 0, 0, 201327641, 0, 0, 0, 603979808, 0, 0, 0, 201327642, 0, 0, 0, 603979808, 0, 0, 0, 201327643, 0, 0, 0, 603979808, 0, 0, 0, 201327644, 0, 0, 0, 603979808, 0, 0, 0, 201327645, 0, 0, 0, 603979808, 0, 0, 0, 201327646, 0, 0, 0, 603979808, 0, 0, 0, 201327647, 0, 0, 0, 603979808, 0, 0, 0, 201327648, 0, 0, 0, 603979808, 0, 0, 0, 201327649, 0, 0, 0, 603979808, 0, 0, 0, 201327650, 0, 0, 0, 603979808, 0, 0, 0, 201327651, 0, 0, 0, 603979808, 0, 0, 0, 201327652, 0, 0, 0, 603979808, 0, 0, 0, 201327653, 0, 0, 0, 603979808, 0, 0, 0, 201327654, 0, 0, 0, 603979808, 0, 0, 0, 201327655, 0, 0, 0, 603979808, 0, 0, 0, 201327656, 0, 0, 0, 603979808, 0, 0, 0, 201327657, 0, 0, 0, 603979808, 0, 0, 0, 201327658, 0, 0, 0, 603979808, 0, 0, 0, 201327659, 0, 0, 0, 603979808, 0, 0, 0, 201327660, 0, 0, 0, 603979808, 0, 0, 0, 201327661, 0, 0, 0, 603979808, 0, 0, 0, 201327662, 0, 0, 0, 603979808, 0, 0, 0, 201327663, 0, 0, 0, 603979808, 0, 0, 0, 201327664, 0, 0, 0, 335609824, 0, 0, 0, 201327665, 0, 0, 0, 335609824, 0, 0, 0, 201327666, 0, 0, 0, 335609824, 0, 0, 0, 201327667, 0, 0, 0, 335609824, 0, 0, 0, 201327668, 0, 0, 0, 335609824, 0, 0, 0, 201327669, 0, 0, 0, 335609824, 0, 0, 0, 201327670, 0, 0, 0, 335609824, 0, 0, 0, 201327671, 0, 0, 0, 335609824, 0, 0, 0, 201327672, 0, 0, 0, 335609824, 0, 0, 0, 201327673, 0, 0, 0, 335609824, 0, 0, 0, 201327674, 0, 0, 0, 335609824, 0, 0, 0, 201327675, 0, 0, 0, 335609824, 0, 0, 0, 201327676, 0, 0, 0, 335609824, 0, 0, 0, 201327677, 0, 0, 0, 335609824, 0, 0, 0, 201327678, 0, 0, 0, 335609824, 0, 0, 0, 201327679, 0, 0, 0, 335609824, 0, 0, 0, 201327680, 0, 0, 0, 335609824, 0, 0, 0, 201327681, 0, 0, 0, 335609824, 0, 0, 0, 201327682, 0, 0, 0, 335609824, 0, 0, 0, 201327683, 0, 0, 0, 335609824, 0, 0, 0, 201327684, 0, 0, 0, 335609824, 0, 0, 0, 201327685, 0, 0, 0, 335609824, 0, 0, 0, 201327686, 0, 0, 0, 335609824, 0, 0, 0, 201327687, 0, 0, 0, 335609824, 0, 0, 0, 201327688, 0, 0, 0, 335609824, 0, 0, 0, 201327689, 0, 0, 0, 335609824, 0, 0, 0, 201327690, 0, 0, 0, 335609824, 0, 0, 0, 201327691, 0, 0, 0, 335609824, 0, 0, 0, 201327692, 0, 0, 0, 335609824, 0, 0, 0, 201327693, 0, 0, 0, 335609824, 0, 0, 0, 201327694, 0, 0, 0, 335609824, 0, 0, 0, 201327695, 0, 0, 0, 335609824, 0, 0, 0, 201327696, 0, 0, 0, 335609776, 0, 0, 0, 201327697, 0, 0, 0, 335609776, 0, 0, 0, 201327698, 0, 0, 0, 335609776, 0, 0, 0, 201327699, 0, 0, 0, 335609776, 0, 0, 0, 201327700, 0, 0, 0, 335609776, 0, 0, 0, 201327701, 0, 0, 0, 335609776, 0, 0, 0, 201327702, 0, 0, 0, 335609776, 0, 0, 0, 201327703, 0, 0, 0, 335609776, 0, 0, 0, 201327704, 0, 0, 0, 335609776, 0, 0, 0, 201327705, 0, 0, 0, 335609776, 0, 0, 0, 201327706, 0, 0, 0, 335609776, 0, 0, 0, 201327707, 0, 0, 0, 335609776, 0, 0, 0, 201327708, 0, 0, 0, 335609776, 0, 0, 0, 201327709, 0, 0, 0, 335609776, 0, 0, 0, 201327710, 0, 0, 0, 335609776, 0, 0, 0, 201327711, 0, 0, 0, 335609776, 0, 0, 0, 201327712, 0, 0, 0, 603979777, 0, 0, 0, 201327713, 0, 0, 0, 335609855, 0, 0, 0, 201327714, 0, 0, 0, 603979777, 0, 0, 0, 201327715, 0, 0, 0, 335609855, 0, 0, 0, 201327716, 0, 0, 0, 603979777, 0, 0, 0, 201327717, 0, 0, 0, 335609855, 0, 0, 0, 201327718, 0, 0, 0, 603979777, 0, 0, 0, 201327719, 0, 0, 0, 335609855, 0, 0, 0, 201327720, 0, 0, 0, 603979777, 0, 0, 0, 201327721, 0, 0, 0, 335609855, 0, 0, 0, 201327722, 0, 0, 0, 603979777, 0, 0, 0, 201327723, 0, 0, 0, 335609855, 0, 0, 0, 201327724, 0, 0, 0, 603979777, 0, 0, 0, 201327725, 0, 0, 0, 335609855, 0, 0, 0, 201327726, 0, 0, 0, 603979777, 0, 0, 0, 201327727, 0, 0, 0, 335609855, 0, 0, 0, 201327728, 0, 0, 0, 603979777, 0, 0, 0, 201327729, 0, 0, 0, 335609855, 0, 0, 0, 201327730, 0, 0, 0, 603979777, 0, 0, 0, 201327731, 0, 0, 0, 335609855, 0, 0, 0, 201327732, 0, 0, 0, 603979777, 0, 0, 0, 201327733, 0, 0, 0, 335609855, 0, 0, 0, 201327734, 0, 0, 0, 603979777, 0, 0, 0, 201327735, 0, 0, 0, 335609855, 0, 0, 0, 201327736, 0, 0, 0, 603979777, 0, 0, 0, 201327737, 0, 0, 0, 335609855, 0, 0, 0, 201327738, 0, 0, 0, 603979777, 0, 0, 0, 201327739, 0, 0, 0, 335609855, 0, 0, 0, 201327740, 0, 0, 0, 603979777, 0, 0, 0, 201327741, 0, 0, 0, 335609855, 0, 0, 0, 201327742, 0, 0, 0, 603979777, 0, 0, 0, 201327743, 0, 0, 0, 335609855, 0, 0, 0, 201327744, 0, 0, 0, 603979777, 0, 0, 0, 201327745, 0, 0, 0, 335609855, 0, 0, 0, 201327746, 0, 0, 0, 1744830464, 0, 0, 0, 209716355, 0, 0, 0, 805306371, 0, 0, 0, 209716360, 0, 0, 0, 738197505, 0, 0, 0, 201327754, 0, 0, 0, 603979777, 0, 0, 0, 201327755, 0, 0, 0, 335609855, 0, 0, 0, 201327756, 0, 0, 0, 603979777, 0, 0, 0, 201327757, 0, 0, 0, 335609855, 0, 0, 0, 201327758, 0, 0, 0, 603979777, 0, 0, 0, 201327759, 0, 0, 0, 335609855, 0, 0, 0, 201327760, 0, 0, 0, 603979777, 0, 0, 0, 201327761, 0, 0, 0, 335609855, 0, 0, 0, 201327762, 0, 0, 0, 603979777, 0, 0, 0, 201327763, 0, 0, 0, 335609855, 0, 0, 0, 201327764, 0, 0, 0, 603979777, 0, 0, 0, 201327765, 0, 0, 0, 335609855, 0, 0, 0, 201327766, 0, 0, 0, 603979777, 0, 0, 0, 201327767, 0, 0, 0, 335609855, 0, 0, 0, 201327768, 0, 0, 0, 603979777, 0, 0, 0, 201327769, 0, 0, 0, 335609855, 0, 0, 0, 201327770, 0, 0, 0, 603979777, 0, 0, 0, 201327771, 0, 0, 0, 335609855, 0, 0, 0, 201327772, 0, 0, 0, 603979777, 0, 0, 0, 201327773, 0, 0, 0, 335609855, 0, 0, 0, 201327774, 0, 0, 0, 603979777, 0, 0, 0, 201327775, 0, 0, 0, 335609855, 0, 0, 0, 201327776, 0, 0, 0, 603979777, 0, 0, 0, 201327777, 0, 0, 0, 335609855, 0, 0, 0, 201327778, 0, 0, 0, 603979777, 0, 0, 0, 201327779, 0, 0, 0, 335609855, 0, 0, 0, 201327780, 0, 0, 0, 603979777, 0, 0, 0, 201327781, 0, 0, 0, 335609855, 0, 0, 0, 201327782, 0, 0, 0, 603979777, 0, 0, 0, 201327783, 0, 0, 0, 335609855, 0, 0, 0, 201327784, 0, 0, 0, 603979777, 0, 0, 0, 201327785, 0, 0, 0, 335609855, 0, 0, 0, 201327786, 0, 0, 0, 603979777, 0, 0, 0, 201327787, 0, 0, 0, 335609855, 0, 0, 0, 201327788, 0, 0, 0, 603979777, 0, 0, 0, 201327789, 0, 0, 0, 335609855, 0, 0, 0, 201327790, 0, 0, 0, 603979777, 0, 0, 0, 201327791, 0, 0, 0, 335609855, 0, 0, 0, 201327792, 0, 0, 0, 603979777, 0, 0, 0, 201327793, 0, 0, 0, 335609855, 0, 0, 0, 201327794, 0, 0, 0, 603979777, 0, 0, 0, 201327795, 0, 0, 0, 335609855, 0, 0, 0, 201327796, 0, 0, 0, 603979777, 0, 0, 0, 201327797, 0, 0, 0, 335609855, 0, 0, 0, 201327798, 0, 0, 0, 603979777, 0, 0, 0, 201327799, 0, 0, 0, 335609855, 0, 0, 0, 201327800, 0, 0, 0, 603979777, 0, 0, 0, 201327801, 0, 0, 0, 335609855, 0, 0, 0, 201327802, 0, 0, 0, 603979777, 0, 0, 0, 201327803, 0, 0, 0, 335609855, 0, 0, 0, 201327804, 0, 0, 0, 603979777, 0, 0, 0, 201327805, 0, 0, 0, 335609855, 0, 0, 0, 201327806, 0, 0, 0, 603979777, 0, 0, 0, 201327807, 0, 0, 0, 335609855, 0, 0, 0, 201327808, 0, 0, 0, 603979776, 0, 0, 0, 201327809, 0, 0, 0, 603979777, 0, 0, 0, 201327810, 0, 0, 0, 335609855, 0, 0, 0, 201327811, 0, 0, 0, 603979777, 0, 0, 0, 201327812, 0, 0, 0, 335609855, 0, 0, 0, 201327813, 0, 0, 0, 603979777, 0, 0, 0, 201327814, 0, 0, 0, 335609855, 0, 0, 0, 201327815, 0, 0, 0, 603979777, 0, 0, 0, 201327816, 0, 0, 0, 335609855, 0, 0, 0, 201327817, 0, 0, 0, 603979777, 0, 0, 0, 201327818, 0, 0, 0, 335609855, 0, 0, 0, 201327819, 0, 0, 0, 603979777, 0, 0, 0, 201327820, 0, 0, 0, 335609855, 0, 0, 0, 201327821, 0, 0, 0, 603979777, 0, 0, 0, 201327822, 0, 0, 0, 335609855, 0, 0, 0, 201327824, 0, 0, 0, 603979777, 0, 0, 0, 201327825, 0, 0, 0, 335609855, 0, 0, 0, 201327826, 0, 0, 0, 603979777, 0, 0, 0, 201327827, 0, 0, 0, 335609855, 0, 0, 0, 201327828, 0, 0, 0, 603979777, 0, 0, 0, 201327829, 0, 0, 0, 335609855, 0, 0, 0, 201327830, 0, 0, 0, 603979777, 0, 0, 0, 201327831, 0, 0, 0, 335609855, 0, 0, 0, 201327832, 0, 0, 0, 603979777, 0, 0, 0, 201327833, 0, 0, 0, 335609855, 0, 0, 0, 201327834, 0, 0, 0, 603979777, 0, 0, 0, 201327835, 0, 0, 0, 335609855, 0, 0, 0, 201327836, 0, 0, 0, 603979777, 0, 0, 0, 201327837, 0, 0, 0, 335609855, 0, 0, 0, 201327838, 0, 0, 0, 603979777, 0, 0, 0, 201327839, 0, 0, 0, 335609855, 0, 0, 0, 201327840, 0, 0, 0, 603979777, 0, 0, 0, 201327841, 0, 0, 0, 335609855, 0, 0, 0, 201327842, 0, 0, 0, 603979777, 0, 0, 0, 201327843, 0, 0, 0, 335609855, 0, 0, 0, 201327844, 0, 0, 0, 603979777, 0, 0, 0, 201327845, 0, 0, 0, 335609855, 0, 0, 0, 201327846, 0, 0, 0, 603979777, 0, 0, 0, 201327847, 0, 0, 0, 335609855, 0, 0, 0, 201327848, 0, 0, 0, 603979777, 0, 0, 0, 201327849, 0, 0, 0, 335609855, 0, 0, 0, 201327850, 0, 0, 0, 603979777, 0, 0, 0, 201327851, 0, 0, 0, 335609855, 0, 0, 0, 201327852, 0, 0, 0, 603979777, 0, 0, 0, 201327853, 0, 0, 0, 335609855, 0, 0, 0, 201327854, 0, 0, 0, 603979777, 0, 0, 0, 201327855, 0, 0, 0, 335609855, 0, 0, 0, 201327856, 0, 0, 0, 603979777, 0, 0, 0, 201327857, 0, 0, 0, 335609855, 0, 0, 0, 201327858, 0, 0, 0, 603979777, 0, 0, 0, 201327859, 0, 0, 0, 335609855, 0, 0, 0, 201327860, 0, 0, 0, 603979777, 0, 0, 0, 201327861, 0, 0, 0, 335609855, 0, 0, 0, 201327862, 0, 0, 0, 603979777, 0, 0, 0, 201327863, 0, 0, 0, 335609855, 0, 0, 0, 201327864, 0, 0, 0, 603979777, 0, 0, 0, 201327865, 0, 0, 0, 335609855, 0, 0, 0, 201327872, 0, 0, 0, 603979777, 0, 0, 0, 201327873, 0, 0, 0, 335609855, 0, 0, 0, 201327874, 0, 0, 0, 603979777, 0, 0, 0, 201327875, 0, 0, 0, 335609855, 0, 0, 0, 201327876, 0, 0, 0, 603979777, 0, 0, 0, 201327877, 0, 0, 0, 335609855, 0, 0, 0, 201327878, 0, 0, 0, 603979777, 0, 0, 0, 201327879, 0, 0, 0, 335609855, 0, 0, 0, 201327880, 0, 0, 0, 603979777, 0, 0, 0, 201327881, 0, 0, 0, 335609855, 0, 0, 0, 201327882, 0, 0, 0, 603979777, 0, 0, 0, 201327883, 0, 0, 0, 335609855, 0, 0, 0, 201327884, 0, 0, 0, 603979777, 0, 0, 0, 201327885, 0, 0, 0, 335609855, 0, 0, 0, 201327886, 0, 0, 0, 603979777, 0, 0, 0, 201327887, 0, 0, 0, 335609855, 0, 0, 0, 16778545, 0, 0, 0, 603979824, 0, 0, 0, 16778546, 0, 0, 0, 603979824, 0, 0, 0, 16778547, 0, 0, 0, 603979824, 0, 0, 0, 16778548, 0, 0, 0, 603979824, 0, 0, 0, 16778549, 0, 0, 0, 603979824, 0, 0, 0, 16778550, 0, 0, 0, 603979824, 0, 0, 0, 16778551, 0, 0, 0, 603979824, 0, 0, 0, 16778552, 0, 0, 0, 603979824, 0, 0, 0, 16778553, 0, 0, 0, 603979824, 0, 0, 0, 16778554, 0, 0, 0, 603979824, 0, 0, 0, 16778555, 0, 0, 0, 603979824, 0, 0, 0, 16778556, 0, 0, 0, 603979824, 0, 0, 0, 16778557, 0, 0, 0, 603979824, 0, 0, 0, 16778558, 0, 0, 0, 603979824, 0, 0, 0, 16778559, 0, 0, 0, 603979824, 0, 0, 0, 16778560, 0, 0, 0, 603979824, 0, 0, 0, 16778561, 0, 0, 0, 603979824, 0, 0, 0, 16778562, 0, 0, 0, 603979824, 0, 0, 0, 16778563, 0, 0, 0, 603979824, 0, 0, 0, 16778564, 0, 0, 0, 603979824, 0, 0, 0, 16778565, 0, 0, 0, 603979824, 0, 0, 0, 16778566, 0, 0, 0, 603979824, 0, 0, 0, 16778567, 0, 0, 0, 603979824, 0, 0, 0, 16778568, 0, 0, 0, 603979824, 0, 0, 0, 16778569, 0, 0, 0, 603979824, 0, 0, 0, 16778570, 0, 0, 0, 603979824, 0, 0, 0, 16778571, 0, 0, 0, 603979824, 0, 0, 0, 16778572, 0, 0, 0, 603979824, 0, 0, 0, 16778573, 0, 0, 0, 603979824, 0, 0, 0, 16778574, 0, 0, 0, 603979824, 0, 0, 0, 16778575, 0, 0, 0, 603979824, 0, 0, 0, 16778576, 0, 0, 0, 603979824, 0, 0, 0, 16778577, 0, 0, 0, 603979824, 0, 0, 0, 16778578, 0, 0, 0, 603979824, 0, 0, 0, 16778579, 0, 0, 0, 603979824, 0, 0, 0, 16778580, 0, 0, 0, 603979824, 0, 0, 0, 16778581, 0, 0, 0, 603979824, 0, 0, 0, 16778582, 0, 0, 0, 603979824, 0, 0, 0, 16778585, 0, 0, 0, 402653184, 0, 0, 0, 25167194, 0, 0, 0, 1409286149, 0, 0, 0, 16778593, 0, 0, 0, 335609808, 0, 0, 0, 16778594, 0, 0, 0, 335609808, 0, 0, 0, 16778595, 0, 0, 0, 335609808, 0, 0, 0, 16778596, 0, 0, 0, 335609808, 0, 0, 0, 16778597, 0, 0, 0, 335609808, 0, 0, 0, 16778598, 0, 0, 0, 335609808, 0, 0, 0, 16778599, 0, 0, 0, 335609808, 0, 0, 0, 16778600, 0, 0, 0, 335609808, 0, 0, 0, 16778601, 0, 0, 0, 335609808, 0, 0, 0, 16778602, 0, 0, 0, 335609808, 0, 0, 0, 16778603, 0, 0, 0, 335609808, 0, 0, 0, 16778604, 0, 0, 0, 335609808, 0, 0, 0, 16778605, 0, 0, 0, 335609808, 0, 0, 0, 16778606, 0, 0, 0, 335609808, 0, 0, 0, 16778607, 0, 0, 0, 335609808, 0, 0, 0, 16778608, 0, 0, 0, 335609808, 0, 0, 0, 16778609, 0, 0, 0, 335609808, 0, 0, 0, 16778610, 0, 0, 0, 335609808, 0, 0, 0, 16778611, 0, 0, 0, 335609808, 0, 0, 0, 16778612, 0, 0, 0, 335609808, 0, 0, 0, 16778613, 0, 0, 0, 335609808, 0, 0, 0, 16778614, 0, 0, 0, 335609808, 0, 0, 0, 16778615, 0, 0, 0, 335609808, 0, 0, 0, 16778616, 0, 0, 0, 335609808, 0, 0, 0, 16778617, 0, 0, 0, 335609808, 0, 0, 0, 16778618, 0, 0, 0, 335609808, 0, 0, 0, 16778619, 0, 0, 0, 335609808, 0, 0, 0, 16778620, 0, 0, 0, 335609808, 0, 0, 0, 16778621, 0, 0, 0, 335609808, 0, 0, 0, 16778622, 0, 0, 0, 335609808, 0, 0, 0, 16778623, 0, 0, 0, 335609808, 0, 0, 0, 16778624, 0, 0, 0, 335609808, 0, 0, 0, 16778625, 0, 0, 0, 335609808, 0, 0, 0, 16778626, 0, 0, 0, 335609808, 0, 0, 0, 16778627, 0, 0, 0, 335609808, 0, 0, 0, 16778628, 0, 0, 0, 335609808, 0, 0, 0, 16778629, 0, 0, 0, 335609808, 0, 0, 0, 16778630, 0, 0, 0, 335609808, 0, 0, 0, 16778631, 0, 0, 0, 335544320, 0, 0, 0, 150996361, 0, 0, 0, 1409286144, 0, 0, 0, 16778634, 0, 0, 0, 1140850688, 0, 0, 0, 427820433, 0, 0, 0, 805306408, 0, 0, 0, 427820475, 0, 0, 0, 805306370, 0, 0, 0, 419431870, 0, 0, 0, 1409286144, 0, 0, 0, 419431871, 0, 0, 0, 805306368, 0, 0, 0, 419431872, 0, 0, 0, 1409286144, 0, 0, 0, 427820481, 0, 0, 0, 805306369, 0, 0, 0, 419431875, 0, 0, 0, 1409286144, 0, 0, 0, 427820484, 0, 0, 0, 805306369, 0, 0, 0, 419431878, 0, 0, 0, 1409286144, 0, 0, 0, 419431879, 0, 0, 0, 805306368, 0, 0, 0, 427820496, 0, 0, 0, 469762074, 0, 0, 0, 427820528, 0, 0, 0, 469762050, 0, 0, 0, 427820531, 0, 0, 0, 1409286145, 0, 0, 0, 159385088, 0, 0, 0, 67108867, 0, 0, 0, 1547, 0, 0, 0, 1543503872, 0, 0, 0, 159385100, 0, 0, 0, 1409286145, 0, 0, 0, 8390158, 0, 0, 0, 1744830465, 0, 0, 0, 8390160, 0, 0, 0, 805306373, 0, 0, 0, 150996507, 0, 0, 0, 1409286144, 0, 0, 0, 8390174, 0, 0, 0, 1409286145, 0, 0, 0, 8390177, 0, 0, 0, 469762073, 0, 0, 0, 150996544, 0, 0, 0, 402653184, 0, 0, 0, 8390209, 0, 0, 0, 469762057, 0, 0, 0, 461375051, 0, 0, 0, 805306387, 0, 0, 0, 159385184, 0, 0, 0, 872415241, 0, 0, 0, 8390250, 0, 0, 0, 1409286147, 0, 0, 0, 8390254, 0, 0, 0, 469762049, 0, 0, 0, 452986480, 0, 0, 0, 805306368, 0, 0, 0, 8390257, 0, 0, 0, 469762146, 0, 0, 0, 1748, 0, 0, 0, 1409286144, 0, 0, 0, 1749, 0, 0, 0, 469762048, 0, 0, 0, 8390358, 0, 0, 0, 805306374, 0, 0, 0, 150996701, 0, 0, 0, 67108864, 0, 0, 0, 1758, 0, 0, 0, 738197504, 0, 0, 0, 8390367, 0, 0, 0, 805306373, 0, 0, 0, 8390373, 0, 0, 0, 402653185, 0, 0, 0, 8390375, 0, 0, 0, 805306369, 0, 0, 0, 1769, 0, 0, 0, 1744830464, 0, 0, 0, 8390378, 0, 0, 0, 805306371, 0, 0, 0, 8390382, 0, 0, 0, 469762049, 0, 0, 0, 8390384, 0, 0, 0, 872415241, 0, 0, 0, 8390394, 0, 0, 0, 469762050, 0, 0, 0, 8390397, 0, 0, 0, 1744830465, 0, 0, 0, 1791, 0, 0, 0, 469762048, 0, 0, 0, 830473984, 0, 0, 0, 1409286157, 0, 0, 0, 822085391, 0, 0, 0, 67108864, 0, 0, 0, 822085392, 0, 0, 0, 469762048, 0, 0, 0, 822085393, 0, 0, 0, 805306368, 0, 0, 0, 830474002, 0, 0, 0, 469762077, 0, 0, 0, 830474032, 0, 0, 0, 805306394, 0, 0, 0, 830474061, 0, 0, 0, 469762080, 0, 0, 0, 931137408, 0, 0, 0, 469762085, 0, 0, 0, 931137446, 0, 0, 0, 805306378, 0, 0, 0, 922748849, 0, 0, 0, 469762048, 0, 0, 0, 243271937, 0, 0, 0, 805306369, 0, 0, 0, 234883331, 0, 0, 0, 671088640, 0, 0, 0, 243271940, 0, 0, 0, 469762101, 0, 0, 0, 234883388, 0, 0, 0, 805306368, 0, 0, 0, 234883389, 0, 0, 0, 469762048, 0, 0, 0, 243271998, 0, 0, 0, 671088642, 0, 0, 0, 243272001, 0, 0, 0, 805306375, 0, 0, 0, 243272009, 0, 0, 0, 671088643, 0, 0, 0, 234883405, 0, 0, 0, 805306368, 0, 0, 0, 234883408, 0, 0, 0, 469762048, 0, 0, 0, 243272017, 0, 0, 0, 805306371, 0, 0, 0, 243272024, 0, 0, 0, 469762057, 0, 0, 0, 243272034, 0, 0, 0, 805306369, 0, 0, 0, 159385956, 0, 0, 0, 1409286145, 0, 0, 0, 243272038, 0, 0, 0, 872415241, 0, 0, 0, 150997360, 0, 0, 0, 1409286144, 0, 0, 0, 234883453, 0, 0, 0, 469762048, 0, 0, 0, 33556865, 0, 0, 0, 805306368, 0, 0, 0, 41945474, 0, 0, 0, 671088641, 0, 0, 0, 41945477, 0, 0, 0, 469762055, 0, 0, 0, 41945487, 0, 0, 0, 469762049, 0, 0, 0, 41945491, 0, 0, 0, 469762069, 0, 0, 0, 41945514, 0, 0, 0, 469762054, 0, 0, 0, 33556914, 0, 0, 0, 469762048, 0, 0, 0, 41945526, 0, 0, 0, 469762051, 0, 0, 0, 33556924, 0, 0, 0, 805306368, 0, 0, 0, 33556925, 0, 0, 0, 469762048, 0, 0, 0, 41945534, 0, 0, 0, 671088642, 0, 0, 0, 41945537, 0, 0, 0, 805306371, 0, 0, 0, 41945543, 0, 0, 0, 671088641, 0, 0, 0, 41945547, 0, 0, 0, 671088641, 0, 0, 0, 33556941, 0, 0, 0, 805306368, 0, 0, 0, 33556942, 0, 0, 0, 469762048, 0, 0, 0, 33556951, 0, 0, 0, 671088640, 0, 0, 0, 41945564, 0, 0, 0, 469762049, 0, 0, 0, 41945567, 0, 0, 0, 469762050, 0, 0, 0, 41945570, 0, 0, 0, 805306369, 0, 0, 0, 41945574, 0, 0, 0, 872415241, 0, 0, 0, 41945584, 0, 0, 0, 469762049, 0, 0, 0, 41945586, 0, 0, 0, 1543503873, 0, 0, 0, 41945588, 0, 0, 0, 1006632965, 0, 0, 0, 33556986, 0, 0, 0, 1744830464, 0, 0, 0, 360712705, 0, 0, 0, 805306369, 0, 0, 0, 352324099, 0, 0, 0, 671088640, 0, 0, 0, 360712709, 0, 0, 0, 469762053, 0, 0, 0, 360712719, 0, 0, 0, 469762049, 0, 0, 0, 360712723, 0, 0, 0, 469762069, 0, 0, 0, 360712746, 0, 0, 0, 469762054, 0, 0, 0, 360712754, 0, 0, 0, 469762049, 0, 0, 0, 360712757, 0, 0, 0, 469762049, 0, 0, 0, 360712760, 0, 0, 0, 469762049, 0, 0, 0, 352324156, 0, 0, 0, 805306368, 0, 0, 0, 360712766, 0, 0, 0, 671088642, 0, 0, 0, 360712769, 0, 0, 0, 805306369, 0, 0, 0, 360712775, 0, 0, 0, 805306369, 0, 0, 0, 360712779, 0, 0, 0, 805306370, 0, 0, 0, 360712793, 0, 0, 0, 469762051, 0, 0, 0, 352324190, 0, 0, 0, 469762048, 0, 0, 0, 360712806, 0, 0, 0, 872415241, 0, 0, 0, 360712816, 0, 0, 0, 805306369, 0, 0, 0, 360712818, 0, 0, 0, 469762050, 0, 0, 0, 343935617, 0, 0, 0, 805306369, 0, 0, 0, 335547011, 0, 0, 0, 671088640, 0, 0, 0, 343935621, 0, 0, 0, 469762056, 0, 0, 0, 343935631, 0, 0, 0, 469762050, 0, 0, 0, 343935635, 0, 0, 0, 469762069, 0, 0, 0, 343935658, 0, 0, 0, 469762054, 0, 0, 0, 343935666, 0, 0, 0, 469762049, 0, 0, 0, 343935669, 0, 0, 0, 469762052, 0, 0, 0, 335547068, 0, 0, 0, 805306368, 0, 0, 0, 335547069, 0, 0, 0, 469762048, 0, 0, 0, 343935678, 0, 0, 0, 671088642, 0, 0, 0, 343935681, 0, 0, 0, 805306372, 0, 0, 0, 343935687, 0, 0, 0, 805306369, 0, 0, 0, 335547081, 0, 0, 0, 671088640, 0, 0, 0, 343935691, 0, 0, 0, 671088641, 0, 0, 0, 335547085, 0, 0, 0, 805306368, 0, 0, 0, 335547088, 0, 0, 0, 469762048, 0, 0, 0, 343935712, 0, 0, 0, 469762049, 0, 0, 0, 343935714, 0, 0, 0, 805306369, 0, 0, 0, 343935718, 0, 0, 0, 872415241, 0, 0, 0, 335547121, 0, 0, 0, 1543503872, 0, 0, 0, 721423105, 0, 0, 0, 805306368, 0, 0, 0, 729811714, 0, 0, 0, 671088641, 0, 0, 0, 729811717, 0, 0, 0, 469762055, 0, 0, 0, 729811727, 0, 0, 0, 469762049, 0, 0, 0, 729811731, 0, 0, 0, 469762069, 0, 0, 0, 729811754, 0, 0, 0, 469762054, 0, 0, 0, 729811762, 0, 0, 0, 469762049, 0, 0, 0, 729811765, 0, 0, 0, 469762052, 0, 0, 0, 721423164, 0, 0, 0, 805306368, 0, 0, 0, 721423165, 0, 0, 0, 469762048, 0, 0, 0, 721423166, 0, 0, 0, 671088640, 0, 0, 0, 721423167, 0, 0, 0, 805306368, 0, 0, 0, 721423168, 0, 0, 0, 671088640, 0, 0, 0, 729811777, 0, 0, 0, 805306370, 0, 0, 0, 729811783, 0, 0, 0, 671088641, 0, 0, 0, 729811787, 0, 0, 0, 671088641, 0, 0, 0, 721423181, 0, 0, 0, 805306368, 0, 0, 0, 721423190, 0, 0, 0, 805306368, 0, 0, 0, 721423191, 0, 0, 0, 671088640, 0, 0, 0, 729811804, 0, 0, 0, 469762049, 0, 0, 0, 729811807, 0, 0, 0, 469762050, 0, 0, 0, 729811814, 0, 0, 0, 872415241, 0, 0, 0, 721423216, 0, 0, 0, 1744830464, 0, 0, 0, 721423217, 0, 0, 0, 469762048, 0, 0, 0, 889195394, 0, 0, 0, 805306368, 0, 0, 0, 889195395, 0, 0, 0, 469762048, 0, 0, 0, 897584005, 0, 0, 0, 469762053, 0, 0, 0, 897584014, 0, 0, 0, 469762050, 0, 0, 0, 897584018, 0, 0, 0, 469762051, 0, 0, 0, 897584025, 0, 0, 0, 469762049, 0, 0, 0, 889195420, 0, 0, 0, 469762048, 0, 0, 0, 897584030, 0, 0, 0, 469762049, 0, 0, 0, 897584035, 0, 0, 0, 469762049, 0, 0, 0, 897584040, 0, 0, 0, 469762050, 0, 0, 0, 897584046, 0, 0, 0, 469762059, 0, 0, 0, 897584062, 0, 0, 0, 671088641, 0, 0, 0, 889195456, 0, 0, 0, 805306368, 0, 0, 0, 897584065, 0, 0, 0, 671088641, 0, 0, 0, 897584070, 0, 0, 0, 671088642, 0, 0, 0, 897584074, 0, 0, 0, 671088642, 0, 0, 0, 889195469, 0, 0, 0, 805306368, 0, 0, 0, 889195479, 0, 0, 0, 671088640, 0, 0, 0, 897584102, 0, 0, 0, 872415241, 0, 0, 0, 897584112, 0, 0, 0, 1006632962, 0, 0, 0, 897584115, 0, 0, 0, 1744830469, 0, 0, 0, 889195513, 0, 0, 0, 1543503872, 0, 0, 0, 889195514, 0, 0, 0, 1744830464, 0, 0, 0, 914361345, 0, 0, 0, 671088642, 0, 0, 0, 914361349, 0, 0, 0, 469762055, 0, 0, 0, 914361358, 0, 0, 0, 469762050, 0, 0, 0, 914361362, 0, 0, 0, 469762070, 0, 0, 0, 914361386, 0, 0, 0, 469762057, 0, 0, 0, 914361397, 0, 0, 0, 469762052, 0, 0, 0, 914361406, 0, 0, 0, 805306370, 0, 0, 0, 914361409, 0, 0, 0, 671088643, 0, 0, 0, 914361414, 0, 0, 0, 805306370, 0, 0, 0, 914361418, 0, 0, 0, 805306371, 0, 0, 0, 914361429, 0, 0, 0, 805306369, 0, 0, 0, 914361440, 0, 0, 0, 469762049, 0, 0, 0, 914361446, 0, 0, 0, 872415241, 0, 0, 0, 478153858, 0, 0, 0, 671088641, 0, 0, 0, 478153861, 0, 0, 0, 469762055, 0, 0, 0, 478153870, 0, 0, 0, 469762050, 0, 0, 0, 478153874, 0, 0, 0, 469762070, 0, 0, 0, 478153898, 0, 0, 0, 469762057, 0, 0, 0, 478153909, 0, 0, 0, 469762052, 0, 0, 0, 469765308, 0, 0, 0, 805306368, 0, 0, 0, 469765309, 0, 0, 0, 469762048, 0, 0, 0, 469765310, 0, 0, 0, 671088640, 0, 0, 0, 469765311, 0, 0, 0, 805306368, 0, 0, 0, 478153920, 0, 0, 0, 671088644, 0, 0, 0, 469765318, 0, 0, 0, 805306368, 0, 0, 0, 478153927, 0, 0, 0, 671088641, 0, 0, 0, 478153930, 0, 0, 0, 671088641, 0, 0, 0, 478153932, 0, 0, 0, 805306369, 0, 0, 0, 478153941, 0, 0, 0, 671088641, 0, 0, 0, 469765342, 0, 0, 0, 469762048, 0, 0, 0, 478153952, 0, 0, 0, 469762049, 0, 0, 0, 478153958, 0, 0, 0, 872415241, 0, 0, 0, 612371714, 0, 0, 0, 671088641, 0, 0, 0, 612371717, 0, 0, 0, 469762055, 0, 0, 0, 612371726, 0, 0, 0, 469762050, 0, 0, 0, 612371730, 0, 0, 0, 469762070, 0, 0, 0, 612371754, 0, 0, 0, 469762063, 0, 0, 0, 612371774, 0, 0, 0, 671088642, 0, 0, 0, 612371777, 0, 0, 0, 805306370, 0, 0, 0, 612371782, 0, 0, 0, 671088642, 0, 0, 0, 612371786, 0, 0, 0, 671088642, 0, 0, 0, 603983181, 0, 0, 0, 805306368, 0, 0, 0, 603983191, 0, 0, 0, 671088640, 0, 0, 0, 612371808, 0, 0, 0, 469762049, 0, 0, 0, 612371814, 0, 0, 0, 872415241, 0, 0, 0, 796921218, 0, 0, 0, 671088641, 0, 0, 0, 796921221, 0, 0, 0, 469762065, 0, 0, 0, 796921242, 0, 0, 0, 469762071, 0, 0, 0, 796921267, 0, 0, 0, 469762056, 0, 0, 0, 788532669, 0, 0, 0, 469762048, 0, 0, 0, 796921280, 0, 0, 0, 469762054, 0, 0, 0, 788532682, 0, 0, 0, 805306368, 0, 0, 0, 796921295, 0, 0, 0, 671088642, 0, 0, 0, 796921298, 0, 0, 0, 805306370, 0, 0, 0, 788532694, 0, 0, 0, 805306368, 0, 0, 0, 796921304, 0, 0, 0, 671088647, 0, 0, 0, 796921330, 0, 0, 0, 671088641, 0, 0, 0, 788532724, 0, 0, 0, 1409286144, 0, 0, 0, 947916289, 0, 0, 0, 469762095, 0, 0, 0, 939527729, 0, 0, 0, 805306368, 0, 0, 0, 947916338, 0, 0, 0, 469762049, 0, 0, 0, 947916340, 0, 0, 0, 805306374, 0, 0, 0, 150998591, 0, 0, 0, 1543503872, 0, 0, 0, 947916352, 0, 0, 0, 469762053, 0, 0, 0, 939527750, 0, 0, 0, 402653184, 0, 0, 0, 947916359, 0, 0, 0, 805306375, 0, 0, 0, 939527759, 0, 0, 0, 1409286144, 0, 0, 0, 947916368, 0, 0, 0, 872415241, 0, 0, 0, 947916378, 0, 0, 0, 1409286145, 0, 0, 0, 545263233, 0, 0, 0, 469762049, 0, 0, 0, 536874628, 0, 0, 0, 469762048, 0, 0, 0, 545263239, 0, 0, 0, 469762049, 0, 0, 0, 536874634, 0, 0, 0, 469762048, 0, 0, 0, 536874637, 0, 0, 0, 469762048, 0, 0, 0, 545263252, 0, 0, 0, 469762051, 0, 0, 0, 545263257, 0, 0, 0, 469762054, 0, 0, 0, 545263265, 0, 0, 0, 469762050, 0, 0, 0, 536874661, 0, 0, 0, 469762048, 0, 0, 0, 536874663, 0, 0, 0, 469762048, 0, 0, 0, 545263274, 0, 0, 0, 469762049, 0, 0, 0, 545263277, 0, 0, 0, 469762051, 0, 0, 0, 536874673, 0, 0, 0, 805306368, 0, 0, 0, 545263282, 0, 0, 0, 469762049, 0, 0, 0, 545263284, 0, 0, 0, 805306373, 0, 0, 0, 545263291, 0, 0, 0, 805306369, 0, 0, 0, 536874685, 0, 0, 0, 469762048, 0, 0, 0, 545263296, 0, 0, 0, 469762052, 0, 0, 0, 536874694, 0, 0, 0, 402653184, 0, 0, 0, 545263304, 0, 0, 0, 805306373, 0, 0, 0, 545263312, 0, 0, 0, 872415241, 0, 0, 0, 545263324, 0, 0, 0, 469762049, 0, 0, 0, 956305152, 0, 0, 0, 469762048, 0, 0, 0, 964693761, 0, 0, 0, 1744830466, 0, 0, 0, 964693764, 0, 0, 0, 1409286158, 0, 0, 0, 964693779, 0, 0, 0, 1744830468, 0, 0, 0, 964693784, 0, 0, 0, 805306369, 0, 0, 0, 964693786, 0, 0, 0, 1744830469, 0, 0, 0, 964693792, 0, 0, 0, 872415241, 0, 0, 0, 964693802, 0, 0, 0, 1006632969, 0, 0, 0, 956305204, 0, 0, 0, 1744830464, 0, 0, 0, 956305205, 0, 0, 0, 805306368, 0, 0, 0, 956305206, 0, 0, 0, 1744830464, 0, 0, 0, 956305207, 0, 0, 0, 805306368, 0, 0, 0, 956305208, 0, 0, 0, 1744830464, 0, 0, 0, 956305209, 0, 0, 0, 805306368, 0, 0, 0, 956305210, 0, 0, 0, 1476395008, 0, 0, 0, 956305211, 0, 0, 0, 1207959552, 0, 0, 0, 956305212, 0, 0, 0, 1476395008, 0, 0, 0, 956305213, 0, 0, 0, 1207959552, 0, 0, 0, 964693822, 0, 0, 0, 671088641, 0, 0, 0, 964693824, 0, 0, 0, 469762055, 0, 0, 0, 964693833, 0, 0, 0, 469762081, 0, 0, 0, 964693873, 0, 0, 0, 805306381, 0, 0, 0, 956305279, 0, 0, 0, 671088640, 0, 0, 0, 964693888, 0, 0, 0, 805306372, 0, 0, 0, 956305285, 0, 0, 0, 1409286144, 0, 0, 0, 964693894, 0, 0, 0, 805306369, 0, 0, 0, 964693896, 0, 0, 0, 469762051, 0, 0, 0, 964693904, 0, 0, 0, 805306375, 0, 0, 0, 964693913, 0, 0, 0, 805306403, 0, 0, 0, 964693950, 0, 0, 0, 1744830471, 0, 0, 0, 956305350, 0, 0, 0, 805306368, 0, 0, 0, 964693959, 0, 0, 0, 1744830469, 0, 0, 0, 956305359, 0, 0, 0, 1744830464, 0, 0, 0, 964693968, 0, 0, 0, 1409286145, 0, 0, 0, 645926912, 0, 0, 0, 469762081, 0, 0, 0, 645926947, 0, 0, 0, 469762052, 0, 0, 0, 645926953, 0, 0, 0, 469762049, 0, 0, 0, 637538348, 0, 0, 0, 671088640, 0, 0, 0, 645926957, 0, 0, 0, 805306371, 0, 0, 0, 637538353, 0, 0, 0, 671088640, 0, 0, 0, 637538354, 0, 0, 0, 805306368, 0, 0, 0, 645926966, 0, 0, 0, 805306369, 0, 0, 0, 637538360, 0, 0, 0, 671088640, 0, 0, 0, 637538361, 0, 0, 0, 805306368, 0, 0, 0, 645926976, 0, 0, 0, 872415241, 0, 0, 0, 645926986, 0, 0, 0, 1409286149, 0, 0, 0, 645926992, 0, 0, 0, 469762053, 0, 0, 0, 645926998, 0, 0, 0, 671088641, 0, 0, 0, 645927e3, 0, 0, 0, 805306369, 0, 0, 0, 268439712, 0, 0, 0, 603987040, 0, 0, 0, 268439713, 0, 0, 0, 603987040, 0, 0, 0, 268439714, 0, 0, 0, 603987040, 0, 0, 0, 268439715, 0, 0, 0, 603987040, 0, 0, 0, 268439716, 0, 0, 0, 603987040, 0, 0, 0, 268439717, 0, 0, 0, 603987040, 0, 0, 0, 268439718, 0, 0, 0, 603987040, 0, 0, 0, 268439719, 0, 0, 0, 603987040, 0, 0, 0, 268439720, 0, 0, 0, 603987040, 0, 0, 0, 268439721, 0, 0, 0, 603987040, 0, 0, 0, 268439722, 0, 0, 0, 603987040, 0, 0, 0, 268439723, 0, 0, 0, 603987040, 0, 0, 0, 268439724, 0, 0, 0, 603987040, 0, 0, 0, 268439725, 0, 0, 0, 603987040, 0, 0, 0, 268439726, 0, 0, 0, 603987040, 0, 0, 0, 268439727, 0, 0, 0, 603987040, 0, 0, 0, 268439728, 0, 0, 0, 603987040, 0, 0, 0, 268439729, 0, 0, 0, 603987040, 0, 0, 0, 268439730, 0, 0, 0, 603987040, 0, 0, 0, 268439731, 0, 0, 0, 603987040, 0, 0, 0, 268439732, 0, 0, 0, 603987040, 0, 0, 0, 268439733, 0, 0, 0, 603987040, 0, 0, 0, 268439734, 0, 0, 0, 603987040, 0, 0, 0, 268439735, 0, 0, 0, 603987040, 0, 0, 0, 268439736, 0, 0, 0, 603987040, 0, 0, 0, 268439737, 0, 0, 0, 603987040, 0, 0, 0, 268439738, 0, 0, 0, 603987040, 0, 0, 0, 268439739, 0, 0, 0, 603987040, 0, 0, 0, 268439740, 0, 0, 0, 603987040, 0, 0, 0, 268439741, 0, 0, 0, 603987040, 0, 0, 0, 268439742, 0, 0, 0, 603987040, 0, 0, 0, 268439743, 0, 0, 0, 603987040, 0, 0, 0, 268439744, 0, 0, 0, 603987040, 0, 0, 0, 268439745, 0, 0, 0, 603987040, 0, 0, 0, 268439746, 0, 0, 0, 603987040, 0, 0, 0, 268439747, 0, 0, 0, 603987040, 0, 0, 0, 268439748, 0, 0, 0, 603987040, 0, 0, 0, 268439749, 0, 0, 0, 603987040, 0, 0, 0, 276828368, 0, 0, 0, 469762090, 0, 0, 0, 150999291, 0, 0, 0, 1409286144, 0, 0, 0, 268439804, 0, 0, 0, 402653184, 0, 0, 0, 394268928, 0, 0, 0, 469762137, 0, 0, 0, 394269023, 0, 0, 0, 469762115, 0, 0, 0, 394269096, 0, 0, 0, 469762129, 0, 0, 0, 260051456, 0, 0, 0, 469762120, 0, 0, 0, 260051530, 0, 0, 0, 469762051, 0, 0, 0, 260051536, 0, 0, 0, 469762054, 0, 0, 0, 251662936, 0, 0, 0, 469762048, 0, 0, 0, 260051546, 0, 0, 0, 469762051, 0, 0, 0, 260051552, 0, 0, 0, 469762088, 0, 0, 0, 260051594, 0, 0, 0, 469762051, 0, 0, 0, 260051600, 0, 0, 0, 469762080, 0, 0, 0, 260051634, 0, 0, 0, 469762051, 0, 0, 0, 260051640, 0, 0, 0, 469762054, 0, 0, 0, 251663040, 0, 0, 0, 469762048, 0, 0, 0, 260051650, 0, 0, 0, 469762051, 0, 0, 0, 260051656, 0, 0, 0, 469762062, 0, 0, 0, 260051672, 0, 0, 0, 469762104, 0, 0, 0, 260051730, 0, 0, 0, 469762051, 0, 0, 0, 260051736, 0, 0, 0, 469762114, 0, 0, 0, 251663199, 0, 0, 0, 805306368, 0, 0, 0, 251663200, 0, 0, 0, 1744830464, 0, 0, 0, 260051809, 0, 0, 0, 1409286151, 0, 0, 0, 260051817, 0, 0, 0, 1006632979, 0, 0, 0, 260051840, 0, 0, 0, 469762063, 0, 0, 0, 260051856, 0, 0, 0, 1744830473, 0, 0, 0, 142611360, 0, 0, 0, 469762132, 0, 0, 0, 125834241, 0, 0, 0, 469762667, 0, 0, 0, 125834861, 0, 0, 0, 1409286145, 0, 0, 0, 125834863, 0, 0, 0, 469762055, 0, 0, 0, 671094400, 0, 0, 0, 1946157056, 0, 0, 0, 679483009, 0, 0, 0, 469762073, 0, 0, 0, 671094427, 0, 0, 0, 1476395008, 0, 0, 0, 671094428, 0, 0, 0, 1207959552, 0, 0, 0, 763369120, 0, 0, 0, 469762122, 0, 0, 0, 159389419, 0, 0, 0, 1409286146, 0, 0, 0, 763369198, 0, 0, 0, 939524098, 0, 0, 0, 847255296, 0, 0, 0, 469762060, 0, 0, 0, 847255310, 0, 0, 0, 469762051, 0, 0, 0, 847255314, 0, 0, 0, 805306370, 0, 0, 0, 411047712, 0, 0, 0, 469762065, 0, 0, 0, 411047730, 0, 0, 0, 805306370, 0, 0, 0, 159389493, 0, 0, 0, 1409286145, 0, 0, 0, 109057856, 0, 0, 0, 469762065, 0, 0, 0, 109057874, 0, 0, 0, 805306369, 0, 0, 0, 864032608, 0, 0, 0, 469762060, 0, 0, 0, 864032622, 0, 0, 0, 469762050, 0, 0, 0, 864032626, 0, 0, 0, 805306369, 0, 0, 0, 528488320, 0, 0, 0, 469762099, 0, 0, 0, 528488372, 0, 0, 0, 67108865, 0, 0, 0, 520099766, 0, 0, 0, 671088640, 0, 0, 0, 528488375, 0, 0, 0, 805306374, 0, 0, 0, 528488382, 0, 0, 0, 671088647, 0, 0, 0, 520099782, 0, 0, 0, 805306368, 0, 0, 0, 528488391, 0, 0, 0, 671088641, 0, 0, 0, 528488393, 0, 0, 0, 805306378, 0, 0, 0, 528488404, 0, 0, 0, 1409286146, 0, 0, 0, 520099799, 0, 0, 0, 402653184, 0, 0, 0, 528488408, 0, 0, 0, 1409286146, 0, 0, 0, 520099803, 0, 0, 0, 1543503872, 0, 0, 0, 520099804, 0, 0, 0, 469762048, 0, 0, 0, 520099805, 0, 0, 0, 805306368, 0, 0, 0, 528488416, 0, 0, 0, 872415241, 0, 0, 0, 528488432, 0, 0, 0, 1006632969, 0, 0, 0, 629151744, 0, 0, 0, 1409286149, 0, 0, 0, 620763142, 0, 0, 0, 1140850688, 0, 0, 0, 629151751, 0, 0, 0, 1409286147, 0, 0, 0, 629151755, 0, 0, 0, 805306370, 0, 0, 0, 620763150, 0, 0, 0, 1946157056, 0, 0, 0, 629151760, 0, 0, 0, 872415241, 0, 0, 0, 629151776, 0, 0, 0, 469762082, 0, 0, 0, 620763203, 0, 0, 0, 402653184, 0, 0, 0, 629151812, 0, 0, 0, 469762099, 0, 0, 0, 629151872, 0, 0, 0, 469762088, 0, 0, 0, 620763305, 0, 0, 0, 805306368, 0, 0, 0, 578820352, 0, 0, 0, 469762076, 0, 0, 0, 578820384, 0, 0, 0, 805306370, 0, 0, 0, 578820387, 0, 0, 0, 671088643, 0, 0, 0, 578820391, 0, 0, 0, 805306369, 0, 0, 0, 578820393, 0, 0, 0, 671088642, 0, 0, 0, 578820400, 0, 0, 0, 671088641, 0, 0, 0, 570431794, 0, 0, 0, 805306368, 0, 0, 0, 578820403, 0, 0, 0, 671088645, 0, 0, 0, 578820409, 0, 0, 0, 805306370, 0, 0, 0, 570431808, 0, 0, 0, 1744830464, 0, 0, 0, 578820420, 0, 0, 0, 1409286145, 0, 0, 0, 578820422, 0, 0, 0, 872415241, 0, 0, 0, 880810320, 0, 0, 0, 469762077, 0, 0, 0, 880810352, 0, 0, 0, 469762052, 0, 0, 0, 662706560, 0, 0, 0, 469762089, 0, 0, 0, 662706608, 0, 0, 0, 671088656, 0, 0, 0, 662706625, 0, 0, 0, 469762054, 0, 0, 0, 662706632, 0, 0, 0, 671088641, 0, 0, 0, 662706640, 0, 0, 0, 872415241, 0, 0, 0, 662706654, 0, 0, 0, 1409286145, 0, 0, 0, 528488928, 0, 0, 0, 1744830495, 0, 0, 0, 92281344, 0, 0, 0, 469762070, 0, 0, 0, 92281367, 0, 0, 0, 805306369, 0, 0, 0, 92281369, 0, 0, 0, 671088642, 0, 0, 0, 92281374, 0, 0, 0, 1409286145, 0, 0, 0, 562044160, 0, 0, 0, 335544363, 0, 0, 0, 562044204, 0, 0, 0, 402653237, 0, 0, 0, 562044258, 0, 0, 0, 335544341, 0, 0, 0, 201334136, 0, 0, 0, 402653184, 0, 0, 0, 562044281, 0, 0, 0, 335544353, 0, 0, 0, 562044315, 0, 0, 0, 402653220, 0, 0, 0, 461381056, 0, 0, 0, 805306371, 0, 0, 0, 553655808, 0, 0, 0, 603979777, 0, 0, 0, 553655809, 0, 0, 0, 335609855, 0, 0, 0, 553655810, 0, 0, 0, 603979777, 0, 0, 0, 553655811, 0, 0, 0, 335609855, 0, 0, 0, 553655812, 0, 0, 0, 603979777, 0, 0, 0, 553655813, 0, 0, 0, 335609855, 0, 0, 0, 553655814, 0, 0, 0, 603979777, 0, 0, 0, 553655815, 0, 0, 0, 335609855, 0, 0, 0, 553655816, 0, 0, 0, 603979777, 0, 0, 0, 553655817, 0, 0, 0, 335609855, 0, 0, 0, 553655818, 0, 0, 0, 603979777, 0, 0, 0, 553655819, 0, 0, 0, 335609855, 0, 0, 0, 553655820, 0, 0, 0, 603979777, 0, 0, 0, 553655821, 0, 0, 0, 335609855, 0, 0, 0, 553655822, 0, 0, 0, 603979777, 0, 0, 0, 553655823, 0, 0, 0, 335609855, 0, 0, 0, 553655824, 0, 0, 0, 603979777, 0, 0, 0, 553655825, 0, 0, 0, 335609855, 0, 0, 0, 553655826, 0, 0, 0, 603979777, 0, 0, 0, 553655827, 0, 0, 0, 335609855, 0, 0, 0, 553655828, 0, 0, 0, 603979777, 0, 0, 0, 553655829, 0, 0, 0, 335609855, 0, 0, 0, 553655830, 0, 0, 0, 603979777, 0, 0, 0, 553655831, 0, 0, 0, 335609855, 0, 0, 0, 553655832, 0, 0, 0, 603979777, 0, 0, 0, 553655833, 0, 0, 0, 335609855, 0, 0, 0, 553655834, 0, 0, 0, 603979777, 0, 0, 0, 553655835, 0, 0, 0, 335609855, 0, 0, 0, 553655836, 0, 0, 0, 603979777, 0, 0, 0, 553655837, 0, 0, 0, 335609855, 0, 0, 0, 553655838, 0, 0, 0, 603979777, 0, 0, 0, 553655839, 0, 0, 0, 335609855, 0, 0, 0, 553655840, 0, 0, 0, 603979777, 0, 0, 0, 553655841, 0, 0, 0, 335609855, 0, 0, 0, 553655842, 0, 0, 0, 603979777, 0, 0, 0, 553655843, 0, 0, 0, 335609855, 0, 0, 0, 553655844, 0, 0, 0, 603979777, 0, 0, 0, 553655845, 0, 0, 0, 335609855, 0, 0, 0, 553655846, 0, 0, 0, 603979777, 0, 0, 0, 553655847, 0, 0, 0, 335609855, 0, 0, 0, 553655848, 0, 0, 0, 603979777, 0, 0, 0, 553655849, 0, 0, 0, 335609855, 0, 0, 0, 553655850, 0, 0, 0, 603979777, 0, 0, 0, 553655851, 0, 0, 0, 335609855, 0, 0, 0, 553655852, 0, 0, 0, 603979777, 0, 0, 0, 553655853, 0, 0, 0, 335609855, 0, 0, 0, 553655854, 0, 0, 0, 603979777, 0, 0, 0, 553655855, 0, 0, 0, 335609855, 0, 0, 0, 553655856, 0, 0, 0, 603979777, 0, 0, 0, 553655857, 0, 0, 0, 335609855, 0, 0, 0, 553655858, 0, 0, 0, 603979777, 0, 0, 0, 553655859, 0, 0, 0, 335609855, 0, 0, 0, 553655860, 0, 0, 0, 603979777, 0, 0, 0, 553655861, 0, 0, 0, 335609855, 0, 0, 0, 553655862, 0, 0, 0, 603979777, 0, 0, 0, 553655863, 0, 0, 0, 335609855, 0, 0, 0, 553655864, 0, 0, 0, 603979777, 0, 0, 0, 553655865, 0, 0, 0, 335609855, 0, 0, 0, 553655866, 0, 0, 0, 603979777, 0, 0, 0, 553655867, 0, 0, 0, 335609855, 0, 0, 0, 553655868, 0, 0, 0, 603979777, 0, 0, 0, 553655869, 0, 0, 0, 335609855, 0, 0, 0, 553655870, 0, 0, 0, 603979777, 0, 0, 0, 553655871, 0, 0, 0, 335609855, 0, 0, 0, 553655872, 0, 0, 0, 603979777, 0, 0, 0, 553655873, 0, 0, 0, 335609855, 0, 0, 0, 553655874, 0, 0, 0, 603979777, 0, 0, 0, 553655875, 0, 0, 0, 335609855, 0, 0, 0, 553655876, 0, 0, 0, 603979777, 0, 0, 0, 553655877, 0, 0, 0, 335609855, 0, 0, 0, 553655878, 0, 0, 0, 603979777, 0, 0, 0, 553655879, 0, 0, 0, 335609855, 0, 0, 0, 553655880, 0, 0, 0, 603979777, 0, 0, 0, 553655881, 0, 0, 0, 335609855, 0, 0, 0, 553655882, 0, 0, 0, 603979777, 0, 0, 0, 553655883, 0, 0, 0, 335609855, 0, 0, 0, 553655884, 0, 0, 0, 603979777, 0, 0, 0, 553655885, 0, 0, 0, 335609855, 0, 0, 0, 553655886, 0, 0, 0, 603979777, 0, 0, 0, 553655887, 0, 0, 0, 335609855, 0, 0, 0, 553655888, 0, 0, 0, 603979777, 0, 0, 0, 553655889, 0, 0, 0, 335609855, 0, 0, 0, 553655890, 0, 0, 0, 603979777, 0, 0, 0, 553655891, 0, 0, 0, 335609855, 0, 0, 0, 553655892, 0, 0, 0, 603979777, 0, 0, 0, 553655893, 0, 0, 0, 335609855, 0, 0, 0, 553655894, 0, 0, 0, 603979777, 0, 0, 0, 553655895, 0, 0, 0, 335609855, 0, 0, 0, 553655896, 0, 0, 0, 603979777, 0, 0, 0, 553655897, 0, 0, 0, 335609855, 0, 0, 0, 553655898, 0, 0, 0, 603979777, 0, 0, 0, 553655899, 0, 0, 0, 335609855, 0, 0, 0, 553655900, 0, 0, 0, 603979777, 0, 0, 0, 553655901, 0, 0, 0, 335609855, 0, 0, 0, 553655902, 0, 0, 0, 603979777, 0, 0, 0, 553655903, 0, 0, 0, 335609855, 0, 0, 0, 553655904, 0, 0, 0, 603979777, 0, 0, 0, 553655905, 0, 0, 0, 335609855, 0, 0, 0, 553655906, 0, 0, 0, 603979777, 0, 0, 0, 553655907, 0, 0, 0, 335609855, 0, 0, 0, 553655908, 0, 0, 0, 603979777, 0, 0, 0, 553655909, 0, 0, 0, 335609855, 0, 0, 0, 553655910, 0, 0, 0, 603979777, 0, 0, 0, 553655911, 0, 0, 0, 335609855, 0, 0, 0, 553655912, 0, 0, 0, 603979777, 0, 0, 0, 553655913, 0, 0, 0, 335609855, 0, 0, 0, 553655914, 0, 0, 0, 603979777, 0, 0, 0, 553655915, 0, 0, 0, 335609855, 0, 0, 0, 553655916, 0, 0, 0, 603979777, 0, 0, 0, 553655917, 0, 0, 0, 335609855, 0, 0, 0, 553655918, 0, 0, 0, 603979777, 0, 0, 0, 553655919, 0, 0, 0, 335609855, 0, 0, 0, 553655920, 0, 0, 0, 603979777, 0, 0, 0, 553655921, 0, 0, 0, 335609855, 0, 0, 0, 553655922, 0, 0, 0, 603979777, 0, 0, 0, 553655923, 0, 0, 0, 335609855, 0, 0, 0, 553655924, 0, 0, 0, 603979777, 0, 0, 0, 553655925, 0, 0, 0, 335609855, 0, 0, 0, 553655926, 0, 0, 0, 603979777, 0, 0, 0, 553655927, 0, 0, 0, 335609855, 0, 0, 0, 553655928, 0, 0, 0, 603979777, 0, 0, 0, 553655929, 0, 0, 0, 335609855, 0, 0, 0, 553655930, 0, 0, 0, 603979777, 0, 0, 0, 553655931, 0, 0, 0, 335609855, 0, 0, 0, 553655932, 0, 0, 0, 603979777, 0, 0, 0, 553655933, 0, 0, 0, 335609855, 0, 0, 0, 553655934, 0, 0, 0, 603979777, 0, 0, 0, 553655935, 0, 0, 0, 335609855, 0, 0, 0, 553655936, 0, 0, 0, 603979777, 0, 0, 0, 553655937, 0, 0, 0, 335609855, 0, 0, 0, 553655938, 0, 0, 0, 603979777, 0, 0, 0, 553655939, 0, 0, 0, 335609855, 0, 0, 0, 553655940, 0, 0, 0, 603979777, 0, 0, 0, 553655941, 0, 0, 0, 335609855, 0, 0, 0, 553655942, 0, 0, 0, 603979777, 0, 0, 0, 553655943, 0, 0, 0, 335609855, 0, 0, 0, 553655944, 0, 0, 0, 603979777, 0, 0, 0, 553655945, 0, 0, 0, 335609855, 0, 0, 0, 553655946, 0, 0, 0, 603979777, 0, 0, 0, 553655947, 0, 0, 0, 335609855, 0, 0, 0, 553655948, 0, 0, 0, 603979777, 0, 0, 0, 553655949, 0, 0, 0, 335609855, 0, 0, 0, 553655950, 0, 0, 0, 603979777, 0, 0, 0, 553655951, 0, 0, 0, 335609855, 0, 0, 0, 553655952, 0, 0, 0, 603979777, 0, 0, 0, 553655953, 0, 0, 0, 335609855, 0, 0, 0, 553655954, 0, 0, 0, 603979777, 0, 0, 0, 553655955, 0, 0, 0, 335609855, 0, 0, 0, 553655956, 0, 0, 0, 603979777, 0, 0, 0, 553655957, 0, 0, 0, 335609855, 0, 0, 0, 562044566, 0, 0, 0, 335544324, 0, 0, 0, 553655963, 0, 0, 0, 335609797, 0, 0, 0, 553655968, 0, 0, 0, 603979777, 0, 0, 0, 553655969, 0, 0, 0, 335609855, 0, 0, 0, 553655970, 0, 0, 0, 603979777, 0, 0, 0, 553655971, 0, 0, 0, 335609855, 0, 0, 0, 553655972, 0, 0, 0, 603979777, 0, 0, 0, 553655973, 0, 0, 0, 335609855, 0, 0, 0, 553655974, 0, 0, 0, 603979777, 0, 0, 0, 553655975, 0, 0, 0, 335609855, 0, 0, 0, 553655976, 0, 0, 0, 603979777, 0, 0, 0, 553655977, 0, 0, 0, 335609855, 0, 0, 0, 553655978, 0, 0, 0, 603979777, 0, 0, 0, 553655979, 0, 0, 0, 335609855, 0, 0, 0, 553655980, 0, 0, 0, 603979777, 0, 0, 0, 553655981, 0, 0, 0, 335609855, 0, 0, 0, 553655982, 0, 0, 0, 603979777, 0, 0, 0, 553655983, 0, 0, 0, 335609855, 0, 0, 0, 553655984, 0, 0, 0, 603979777, 0, 0, 0, 553655985, 0, 0, 0, 335609855, 0, 0, 0, 553655986, 0, 0, 0, 603979777, 0, 0, 0, 553655987, 0, 0, 0, 335609855, 0, 0, 0, 553655988, 0, 0, 0, 603979777, 0, 0, 0, 553655989, 0, 0, 0, 335609855, 0, 0, 0, 553655990, 0, 0, 0, 603979777, 0, 0, 0, 553655991, 0, 0, 0, 335609855, 0, 0, 0, 553655992, 0, 0, 0, 603979777, 0, 0, 0, 553655993, 0, 0, 0, 335609855, 0, 0, 0, 553655994, 0, 0, 0, 603979777, 0, 0, 0, 553655995, 0, 0, 0, 335609855, 0, 0, 0, 553655996, 0, 0, 0, 603979777, 0, 0, 0, 553655997, 0, 0, 0, 335609855, 0, 0, 0, 553655998, 0, 0, 0, 603979777, 0, 0, 0, 553655999, 0, 0, 0, 335609855, 0, 0, 0, 553656e3, 0, 0, 0, 603979777, 0, 0, 0, 553656001, 0, 0, 0, 335609855, 0, 0, 0, 553656002, 0, 0, 0, 603979777, 0, 0, 0, 553656003, 0, 0, 0, 335609855, 0, 0, 0, 553656004, 0, 0, 0, 603979777, 0, 0, 0, 553656005, 0, 0, 0, 335609855, 0, 0, 0, 553656006, 0, 0, 0, 603979777, 0, 0, 0, 553656007, 0, 0, 0, 335609855, 0, 0, 0, 553656008, 0, 0, 0, 603979777, 0, 0, 0, 553656009, 0, 0, 0, 335609855, 0, 0, 0, 553656010, 0, 0, 0, 603979777, 0, 0, 0, 553656011, 0, 0, 0, 335609855, 0, 0, 0, 553656012, 0, 0, 0, 603979777, 0, 0, 0, 553656013, 0, 0, 0, 335609855, 0, 0, 0, 553656014, 0, 0, 0, 603979777, 0, 0, 0, 553656015, 0, 0, 0, 335609855, 0, 0, 0, 553656016, 0, 0, 0, 603979777, 0, 0, 0, 553656017, 0, 0, 0, 335609855, 0, 0, 0, 553656018, 0, 0, 0, 603979777, 0, 0, 0, 553656019, 0, 0, 0, 335609855, 0, 0, 0, 553656020, 0, 0, 0, 603979777, 0, 0, 0, 553656021, 0, 0, 0, 335609855, 0, 0, 0, 553656022, 0, 0, 0, 603979777, 0, 0, 0, 553656023, 0, 0, 0, 335609855, 0, 0, 0, 553656024, 0, 0, 0, 603979777, 0, 0, 0, 553656025, 0, 0, 0, 335609855, 0, 0, 0, 553656026, 0, 0, 0, 603979777, 0, 0, 0, 553656027, 0, 0, 0, 335609855, 0, 0, 0, 553656028, 0, 0, 0, 603979777, 0, 0, 0, 553656029, 0, 0, 0, 335609855, 0, 0, 0, 553656030, 0, 0, 0, 603979777, 0, 0, 0, 553656031, 0, 0, 0, 335609855, 0, 0, 0, 553656032, 0, 0, 0, 603979777, 0, 0, 0, 553656033, 0, 0, 0, 335609855, 0, 0, 0, 553656034, 0, 0, 0, 603979777, 0, 0, 0, 553656035, 0, 0, 0, 335609855, 0, 0, 0, 553656036, 0, 0, 0, 603979777, 0, 0, 0, 553656037, 0, 0, 0, 335609855, 0, 0, 0, 553656038, 0, 0, 0, 603979777, 0, 0, 0, 553656039, 0, 0, 0, 335609855, 0, 0, 0, 553656040, 0, 0, 0, 603979777, 0, 0, 0, 553656041, 0, 0, 0, 335609855, 0, 0, 0, 553656042, 0, 0, 0, 603979777, 0, 0, 0, 553656043, 0, 0, 0, 335609855, 0, 0, 0, 553656044, 0, 0, 0, 603979777, 0, 0, 0, 553656045, 0, 0, 0, 335609855, 0, 0, 0, 553656046, 0, 0, 0, 603979777, 0, 0, 0, 553656047, 0, 0, 0, 335609855, 0, 0, 0, 553656048, 0, 0, 0, 603979777, 0, 0, 0, 553656049, 0, 0, 0, 335609855, 0, 0, 0, 553656050, 0, 0, 0, 603979777, 0, 0, 0, 553656051, 0, 0, 0, 335609855, 0, 0, 0, 553656052, 0, 0, 0, 603979777, 0, 0, 0, 553656053, 0, 0, 0, 335609855, 0, 0, 0, 553656054, 0, 0, 0, 603979777, 0, 0, 0, 553656055, 0, 0, 0, 335609855, 0, 0, 0, 553656056, 0, 0, 0, 603979777, 0, 0, 0, 553656057, 0, 0, 0, 335609855, 0, 0, 0, 318775040, 0, 0, 0, 335544328, 0, 0, 0, 318775041, 0, 0, 0, 335544328, 0, 0, 0, 318775042, 0, 0, 0, 335544328, 0, 0, 0, 318775043, 0, 0, 0, 335544328, 0, 0, 0, 318775044, 0, 0, 0, 335544328, 0, 0, 0, 318775045, 0, 0, 0, 335544328, 0, 0, 0, 318775046, 0, 0, 0, 335544328, 0, 0, 0, 318775047, 0, 0, 0, 335544328, 0, 0, 0, 318775048, 0, 0, 0, 604045304, 0, 0, 0, 318775049, 0, 0, 0, 604045304, 0, 0, 0, 318775050, 0, 0, 0, 604045304, 0, 0, 0, 318775051, 0, 0, 0, 604045304, 0, 0, 0, 318775052, 0, 0, 0, 604045304, 0, 0, 0, 318775053, 0, 0, 0, 604045304, 0, 0, 0, 318775054, 0, 0, 0, 604045304, 0, 0, 0, 318775055, 0, 0, 0, 604045304, 0, 0, 0, 318775056, 0, 0, 0, 335544328, 0, 0, 0, 318775057, 0, 0, 0, 335544328, 0, 0, 0, 318775058, 0, 0, 0, 335544328, 0, 0, 0, 318775059, 0, 0, 0, 335544328, 0, 0, 0, 318775060, 0, 0, 0, 335544328, 0, 0, 0, 318775061, 0, 0, 0, 335544328, 0, 0, 0, 318775064, 0, 0, 0, 604045304, 0, 0, 0, 318775065, 0, 0, 0, 604045304, 0, 0, 0, 318775066, 0, 0, 0, 604045304, 0, 0, 0, 318775067, 0, 0, 0, 604045304, 0, 0, 0, 318775068, 0, 0, 0, 604045304, 0, 0, 0, 318775069, 0, 0, 0, 604045304, 0, 0, 0, 318775072, 0, 0, 0, 335544328, 0, 0, 0, 318775073, 0, 0, 0, 335544328, 0, 0, 0, 318775074, 0, 0, 0, 335544328, 0, 0, 0, 318775075, 0, 0, 0, 335544328, 0, 0, 0, 318775076, 0, 0, 0, 335544328, 0, 0, 0, 318775077, 0, 0, 0, 335544328, 0, 0, 0, 318775078, 0, 0, 0, 335544328, 0, 0, 0, 318775079, 0, 0, 0, 335544328, 0, 0, 0, 318775080, 0, 0, 0, 604045304, 0, 0, 0, 318775081, 0, 0, 0, 604045304, 0, 0, 0, 318775082, 0, 0, 0, 604045304, 0, 0, 0, 318775083, 0, 0, 0, 604045304, 0, 0, 0, 318775084, 0, 0, 0, 604045304, 0, 0, 0, 318775085, 0, 0, 0, 604045304, 0, 0, 0, 318775086, 0, 0, 0, 604045304, 0, 0, 0, 318775087, 0, 0, 0, 604045304, 0, 0, 0, 318775088, 0, 0, 0, 335544328, 0, 0, 0, 318775089, 0, 0, 0, 335544328, 0, 0, 0, 318775090, 0, 0, 0, 335544328, 0, 0, 0, 318775091, 0, 0, 0, 335544328, 0, 0, 0, 318775092, 0, 0, 0, 335544328, 0, 0, 0, 318775093, 0, 0, 0, 335544328, 0, 0, 0, 318775094, 0, 0, 0, 335544328, 0, 0, 0, 318775095, 0, 0, 0, 335544328, 0, 0, 0, 318775096, 0, 0, 0, 604045304, 0, 0, 0, 318775097, 0, 0, 0, 604045304, 0, 0, 0, 318775098, 0, 0, 0, 604045304, 0, 0, 0, 318775099, 0, 0, 0, 604045304, 0, 0, 0, 318775100, 0, 0, 0, 604045304, 0, 0, 0, 318775101, 0, 0, 0, 604045304, 0, 0, 0, 318775102, 0, 0, 0, 604045304, 0, 0, 0, 318775103, 0, 0, 0, 604045304, 0, 0, 0, 318775104, 0, 0, 0, 335544328, 0, 0, 0, 318775105, 0, 0, 0, 335544328, 0, 0, 0, 318775106, 0, 0, 0, 335544328, 0, 0, 0, 318775107, 0, 0, 0, 335544328, 0, 0, 0, 318775108, 0, 0, 0, 335544328, 0, 0, 0, 318775109, 0, 0, 0, 335544328, 0, 0, 0, 318775112, 0, 0, 0, 604045304, 0, 0, 0, 318775113, 0, 0, 0, 604045304, 0, 0, 0, 318775114, 0, 0, 0, 604045304, 0, 0, 0, 318775115, 0, 0, 0, 604045304, 0, 0, 0, 318775116, 0, 0, 0, 604045304, 0, 0, 0, 318775117, 0, 0, 0, 604045304, 0, 0, 0, 318775120, 0, 0, 0, 335544320, 0, 0, 0, 318775121, 0, 0, 0, 335544328, 0, 0, 0, 318775122, 0, 0, 0, 335544320, 0, 0, 0, 318775123, 0, 0, 0, 335544328, 0, 0, 0, 318775124, 0, 0, 0, 335544320, 0, 0, 0, 318775125, 0, 0, 0, 335544328, 0, 0, 0, 318775126, 0, 0, 0, 335544320, 0, 0, 0, 318775127, 0, 0, 0, 335544328, 0, 0, 0, 318775129, 0, 0, 0, 604045304, 0, 0, 0, 318775131, 0, 0, 0, 604045304, 0, 0, 0, 318775133, 0, 0, 0, 604045304, 0, 0, 0, 318775135, 0, 0, 0, 604045304, 0, 0, 0, 318775136, 0, 0, 0, 335544328, 0, 0, 0, 318775137, 0, 0, 0, 335544328, 0, 0, 0, 318775138, 0, 0, 0, 335544328, 0, 0, 0, 318775139, 0, 0, 0, 335544328, 0, 0, 0, 318775140, 0, 0, 0, 335544328, 0, 0, 0, 318775141, 0, 0, 0, 335544328, 0, 0, 0, 318775142, 0, 0, 0, 335544328, 0, 0, 0, 318775143, 0, 0, 0, 335544328, 0, 0, 0, 318775144, 0, 0, 0, 604045304, 0, 0, 0, 318775145, 0, 0, 0, 604045304, 0, 0, 0, 318775146, 0, 0, 0, 604045304, 0, 0, 0, 318775147, 0, 0, 0, 604045304, 0, 0, 0, 318775148, 0, 0, 0, 604045304, 0, 0, 0, 318775149, 0, 0, 0, 604045304, 0, 0, 0, 318775150, 0, 0, 0, 604045304, 0, 0, 0, 318775151, 0, 0, 0, 604045304, 0, 0, 0, 318775152, 0, 0, 0, 335544394, 0, 0, 0, 318775153, 0, 0, 0, 335544394, 0, 0, 0, 318775154, 0, 0, 0, 335544406, 0, 0, 0, 318775155, 0, 0, 0, 335544406, 0, 0, 0, 318775156, 0, 0, 0, 335544406, 0, 0, 0, 318775157, 0, 0, 0, 335544406, 0, 0, 0, 318775158, 0, 0, 0, 335544420, 0, 0, 0, 318775159, 0, 0, 0, 335544420, 0, 0, 0, 318775160, 0, 0, 0, 335544448, 0, 0, 0, 318775161, 0, 0, 0, 335544448, 0, 0, 0, 318775162, 0, 0, 0, 335544432, 0, 0, 0, 318775163, 0, 0, 0, 335544432, 0, 0, 0, 318775164, 0, 0, 0, 335544446, 0, 0, 0, 318775165, 0, 0, 0, 335544446, 0, 0, 0, 318775168, 0, 0, 0, 335544328, 0, 0, 0, 318775169, 0, 0, 0, 335544328, 0, 0, 0, 318775170, 0, 0, 0, 335544328, 0, 0, 0, 318775171, 0, 0, 0, 335544328, 0, 0, 0, 318775172, 0, 0, 0, 335544328, 0, 0, 0, 318775173, 0, 0, 0, 335544328, 0, 0, 0, 318775174, 0, 0, 0, 335544328, 0, 0, 0, 318775175, 0, 0, 0, 335544328, 0, 0, 0, 318775176, 0, 0, 0, 536936440, 0, 0, 0, 318775177, 0, 0, 0, 536936440, 0, 0, 0, 318775178, 0, 0, 0, 536936440, 0, 0, 0, 318775179, 0, 0, 0, 536936440, 0, 0, 0, 318775180, 0, 0, 0, 536936440, 0, 0, 0, 318775181, 0, 0, 0, 536936440, 0, 0, 0, 318775182, 0, 0, 0, 536936440, 0, 0, 0, 318775183, 0, 0, 0, 536936440, 0, 0, 0, 318775184, 0, 0, 0, 335544328, 0, 0, 0, 318775185, 0, 0, 0, 335544328, 0, 0, 0, 318775186, 0, 0, 0, 335544328, 0, 0, 0, 318775187, 0, 0, 0, 335544328, 0, 0, 0, 318775188, 0, 0, 0, 335544328, 0, 0, 0, 318775189, 0, 0, 0, 335544328, 0, 0, 0, 318775190, 0, 0, 0, 335544328, 0, 0, 0, 318775191, 0, 0, 0, 335544328, 0, 0, 0, 318775192, 0, 0, 0, 536936440, 0, 0, 0, 318775193, 0, 0, 0, 536936440, 0, 0, 0, 318775194, 0, 0, 0, 536936440, 0, 0, 0, 318775195, 0, 0, 0, 536936440, 0, 0, 0, 318775196, 0, 0, 0, 536936440, 0, 0, 0, 318775197, 0, 0, 0, 536936440, 0, 0, 0, 318775198, 0, 0, 0, 536936440, 0, 0, 0, 318775199, 0, 0, 0, 536936440, 0, 0, 0, 318775200, 0, 0, 0, 335544328, 0, 0, 0, 318775201, 0, 0, 0, 335544328, 0, 0, 0, 318775202, 0, 0, 0, 335544328, 0, 0, 0, 318775203, 0, 0, 0, 335544328, 0, 0, 0, 318775204, 0, 0, 0, 335544328, 0, 0, 0, 318775205, 0, 0, 0, 335544328, 0, 0, 0, 318775206, 0, 0, 0, 335544328, 0, 0, 0, 318775207, 0, 0, 0, 335544328, 0, 0, 0, 318775208, 0, 0, 0, 536936440, 0, 0, 0, 318775209, 0, 0, 0, 536936440, 0, 0, 0, 318775210, 0, 0, 0, 536936440, 0, 0, 0, 318775211, 0, 0, 0, 536936440, 0, 0, 0, 318775212, 0, 0, 0, 536936440, 0, 0, 0, 318775213, 0, 0, 0, 536936440, 0, 0, 0, 318775214, 0, 0, 0, 536936440, 0, 0, 0, 318775215, 0, 0, 0, 536936440, 0, 0, 0, 318775216, 0, 0, 0, 335544328, 0, 0, 0, 318775217, 0, 0, 0, 335544328, 0, 0, 0, 318775218, 0, 0, 0, 335544320, 0, 0, 0, 318775219, 0, 0, 0, 335544329, 0, 0, 0, 318775220, 0, 0, 0, 335544320, 0, 0, 0, 327163830, 0, 0, 0, 335544321, 0, 0, 0, 318775224, 0, 0, 0, 604045304, 0, 0, 0, 318775225, 0, 0, 0, 604045304, 0, 0, 0, 318775226, 0, 0, 0, 604045238, 0, 0, 0, 318775227, 0, 0, 0, 604045238, 0, 0, 0, 318775228, 0, 0, 0, 536936439, 0, 0, 0, 318775229, 0, 0, 0, 1610612736, 0, 0, 0, 318775230, 0, 0, 0, 335602651, 0, 0, 0, 327163839, 0, 0, 0, 1610612738, 0, 0, 0, 318775234, 0, 0, 0, 335544320, 0, 0, 0, 318775235, 0, 0, 0, 335544329, 0, 0, 0, 318775236, 0, 0, 0, 335544320, 0, 0, 0, 327163846, 0, 0, 0, 335544321, 0, 0, 0, 318775240, 0, 0, 0, 604045226, 0, 0, 0, 318775241, 0, 0, 0, 604045226, 0, 0, 0, 318775242, 0, 0, 0, 604045226, 0, 0, 0, 318775243, 0, 0, 0, 604045226, 0, 0, 0, 318775244, 0, 0, 0, 536936439, 0, 0, 0, 327163853, 0, 0, 0, 1610612738, 0, 0, 0, 318775248, 0, 0, 0, 335544328, 0, 0, 0, 318775249, 0, 0, 0, 335544328, 0, 0, 0, 327163858, 0, 0, 0, 335544321, 0, 0, 0, 327163862, 0, 0, 0, 335544321, 0, 0, 0, 318775256, 0, 0, 0, 604045304, 0, 0, 0, 318775257, 0, 0, 0, 604045304, 0, 0, 0, 318775258, 0, 0, 0, 604045212, 0, 0, 0, 318775259, 0, 0, 0, 604045212, 0, 0, 0, 327163869, 0, 0, 0, 1610612738, 0, 0, 0, 318775264, 0, 0, 0, 335544328, 0, 0, 0, 318775265, 0, 0, 0, 335544328, 0, 0, 0, 327163874, 0, 0, 0, 335544322, 0, 0, 0, 318775269, 0, 0, 0, 335544327, 0, 0, 0, 327163878, 0, 0, 0, 335544321, 0, 0, 0, 318775272, 0, 0, 0, 604045304, 0, 0, 0, 318775273, 0, 0, 0, 604045304, 0, 0, 0, 318775274, 0, 0, 0, 604045200, 0, 0, 0, 318775275, 0, 0, 0, 604045200, 0, 0, 0, 318775276, 0, 0, 0, 604045305, 0, 0, 0, 327163885, 0, 0, 0, 1610612738, 0, 0, 0, 318775282, 0, 0, 0, 335544320, 0, 0, 0, 318775283, 0, 0, 0, 335544329, 0, 0, 0, 318775284, 0, 0, 0, 335544320, 0, 0, 0, 327163894, 0, 0, 0, 335544321, 0, 0, 0, 318775288, 0, 0, 0, 604045184, 0, 0, 0, 318775289, 0, 0, 0, 604045184, 0, 0, 0, 318775290, 0, 0, 0, 604045186, 0, 0, 0, 318775291, 0, 0, 0, 604045186, 0, 0, 0, 318775292, 0, 0, 0, 536936439, 0, 0, 0, 327163901, 0, 0, 0, 1610612737, 0, 0, 0, 159391744, 0, 0, 0, 1946157066, 0, 0, 0, 159391755, 0, 0, 0, 67108868, 0, 0, 0, 159391760, 0, 0, 0, 1140850693, 0, 0, 0, 159391766, 0, 0, 0, 1409286145, 0, 0, 0, 151003160, 0, 0, 0, 1342177280, 0, 0, 0, 151003161, 0, 0, 0, 1275068416, 0, 0, 0, 151003162, 0, 0, 0, 1476395008, 0, 0, 0, 159391771, 0, 0, 0, 1342177281, 0, 0, 0, 151003165, 0, 0, 0, 1275068416, 0, 0, 0, 151003166, 0, 0, 0, 1476395008, 0, 0, 0, 151003167, 0, 0, 0, 1342177280, 0, 0, 0, 159391776, 0, 0, 0, 1409286151, 0, 0, 0, 151003176, 0, 0, 0, 1811939328, 0, 0, 0, 151003177, 0, 0, 0, 1879048192, 0, 0, 0, 159391786, 0, 0, 0, 67108868, 0, 0, 0, 151003183, 0, 0, 0, 1946157056, 0, 0, 0, 159391792, 0, 0, 0, 1409286152, 0, 0, 0, 151003193, 0, 0, 0, 1342177280, 0, 0, 0, 151003194, 0, 0, 0, 1275068416, 0, 0, 0, 159391803, 0, 0, 0, 1409286147, 0, 0, 0, 159391807, 0, 0, 0, 1073741825, 0, 0, 0, 159391809, 0, 0, 0, 1409286146, 0, 0, 0, 151003204, 0, 0, 0, 1677721600, 0, 0, 0, 151003205, 0, 0, 0, 1476395008, 0, 0, 0, 151003206, 0, 0, 0, 1207959552, 0, 0, 0, 159391815, 0, 0, 0, 1409286154, 0, 0, 0, 151003218, 0, 0, 0, 1677721600, 0, 0, 0, 151003219, 0, 0, 0, 1409286144, 0, 0, 0, 151003220, 0, 0, 0, 1073741824, 0, 0, 0, 159391829, 0, 0, 0, 1409286153, 0, 0, 0, 151003231, 0, 0, 0, 1946157056, 0, 0, 0, 159391840, 0, 0, 0, 67108867, 0, 0, 0, 159391850, 0, 0, 0, 67108869, 0, 0, 0, 151003248, 0, 0, 0, 1006632960, 0, 0, 0, 553656433, 0, 0, 0, 335544320, 0, 0, 0, 159391860, 0, 0, 0, 1006632965, 0, 0, 0, 159391866, 0, 0, 0, 1677721602, 0, 0, 0, 151003261, 0, 0, 0, 1476395008, 0, 0, 0, 151003262, 0, 0, 0, 1207959552, 0, 0, 0, 553656447, 0, 0, 0, 335544320, 0, 0, 0, 159391872, 0, 0, 0, 1006632969, 0, 0, 0, 159391882, 0, 0, 0, 1677721602, 0, 0, 0, 151003277, 0, 0, 0, 1476395008, 0, 0, 0, 151003278, 0, 0, 0, 1207959552, 0, 0, 0, 562045072, 0, 0, 0, 402653188, 0, 0, 0, 159391904, 0, 0, 0, 1543503893, 0, 0, 0, 461381840, 0, 0, 0, 805306380, 0, 0, 0, 461381853, 0, 0, 0, 738197507, 0, 0, 0, 452993249, 0, 0, 0, 805306368, 0, 0, 0, 461381858, 0, 0, 0, 738197506, 0, 0, 0, 461381861, 0, 0, 0, 805306374, 0, 0, 0, 159392e3, 0, 0, 0, 1744830465, 0, 0, 0, 151003394, 0, 0, 0, 603979776, 0, 0, 0, 159392003, 0, 0, 0, 1744830467, 0, 0, 0, 151003399, 0, 0, 0, 603979776, 0, 0, 0, 159392008, 0, 0, 0, 1744830465, 0, 0, 0, 151003402, 0, 0, 0, 335544320, 0, 0, 0, 159392011, 0, 0, 0, 603979778, 0, 0, 0, 159392014, 0, 0, 0, 335544321, 0, 0, 0, 159392016, 0, 0, 0, 603979778, 0, 0, 0, 151003411, 0, 0, 0, 335544320, 0, 0, 0, 151003412, 0, 0, 0, 1744830464, 0, 0, 0, 151003413, 0, 0, 0, 603979776, 0, 0, 0, 159392022, 0, 0, 0, 1744830466, 0, 0, 0, 159392025, 0, 0, 0, 603979780, 0, 0, 0, 159392030, 0, 0, 0, 1744830469, 0, 0, 0, 151003428, 0, 0, 0, 603979776, 0, 0, 0, 151003429, 0, 0, 0, 1744830464, 0, 0, 0, 318775590, 0, 0, 0, 604037795, 0, 0, 0, 151003431, 0, 0, 0, 1744830464, 0, 0, 0, 151003432, 0, 0, 0, 603979776, 0, 0, 0, 151003433, 0, 0, 0, 1744830464, 0, 0, 0, 553656618, 0, 0, 0, 604036929, 0, 0, 0, 553656619, 0, 0, 0, 604037050, 0, 0, 0, 159392044, 0, 0, 0, 603979777, 0, 0, 0, 151003438, 0, 0, 0, 1744830464, 0, 0, 0, 151003439, 0, 0, 0, 335544320, 0, 0, 0, 159392048, 0, 0, 0, 603979777, 0, 0, 0, 151003442, 0, 0, 0, 1744830464, 0, 0, 0, 151003443, 0, 0, 0, 603979776, 0, 0, 0, 151003444, 0, 0, 0, 335544320, 0, 0, 0, 159392053, 0, 0, 0, 469762051, 0, 0, 0, 151003449, 0, 0, 0, 335544320, 0, 0, 0, 159392058, 0, 0, 0, 1744830465, 0, 0, 0, 159392060, 0, 0, 0, 335544321, 0, 0, 0, 159392062, 0, 0, 0, 603979777, 0, 0, 0, 159392064, 0, 0, 0, 1677721604, 0, 0, 0, 151003461, 0, 0, 0, 603979776, 0, 0, 0, 159392070, 0, 0, 0, 335544323, 0, 0, 0, 151003466, 0, 0, 0, 1744830464, 0, 0, 0, 151003467, 0, 0, 0, 1677721600, 0, 0, 0, 151003468, 0, 0, 0, 1744830464, 0, 0, 0, 159392083, 0, 0, 0, 1006632972, 0, 0, 0, 151003488, 0, 0, 0, 939524112, 0, 0, 0, 151003489, 0, 0, 0, 939524112, 0, 0, 0, 151003490, 0, 0, 0, 939524112, 0, 0, 0, 151003491, 0, 0, 0, 939524112, 0, 0, 0, 151003492, 0, 0, 0, 939524112, 0, 0, 0, 151003493, 0, 0, 0, 939524112, 0, 0, 0, 151003494, 0, 0, 0, 939524112, 0, 0, 0, 151003495, 0, 0, 0, 939524112, 0, 0, 0, 151003496, 0, 0, 0, 939524112, 0, 0, 0, 151003497, 0, 0, 0, 939524112, 0, 0, 0, 151003498, 0, 0, 0, 939524112, 0, 0, 0, 151003499, 0, 0, 0, 939524112, 0, 0, 0, 151003500, 0, 0, 0, 939524112, 0, 0, 0, 151003501, 0, 0, 0, 939524112, 0, 0, 0, 151003502, 0, 0, 0, 939524112, 0, 0, 0, 151003503, 0, 0, 0, 939524112, 0, 0, 0, 151003504, 0, 0, 0, 939589616, 0, 0, 0, 151003505, 0, 0, 0, 939589616, 0, 0, 0, 151003506, 0, 0, 0, 939589616, 0, 0, 0, 151003507, 0, 0, 0, 939589616, 0, 0, 0, 151003508, 0, 0, 0, 939589616, 0, 0, 0, 151003509, 0, 0, 0, 939589616, 0, 0, 0, 151003510, 0, 0, 0, 939589616, 0, 0, 0, 151003511, 0, 0, 0, 939589616, 0, 0, 0, 151003512, 0, 0, 0, 939589616, 0, 0, 0, 151003513, 0, 0, 0, 939589616, 0, 0, 0, 151003514, 0, 0, 0, 939589616, 0, 0, 0, 151003515, 0, 0, 0, 939589616, 0, 0, 0, 151003516, 0, 0, 0, 939589616, 0, 0, 0, 151003517, 0, 0, 0, 939589616, 0, 0, 0, 151003518, 0, 0, 0, 939589616, 0, 0, 0, 151003519, 0, 0, 0, 939589616, 0, 0, 0, 159392128, 0, 0, 0, 939524099, 0, 0, 0, 159392144, 0, 0, 0, 1677721604, 0, 0, 0, 159392149, 0, 0, 0, 1744830468, 0, 0, 0, 159392154, 0, 0, 0, 1677721601, 0, 0, 0, 159392156, 0, 0, 0, 1744830467, 0, 0, 0, 151003552, 0, 0, 0, 1677721600, 0, 0, 0, 159392161, 0, 0, 0, 1744830465, 0, 0, 0, 151003555, 0, 0, 0, 1677721600, 0, 0, 0, 159392164, 0, 0, 0, 1744830465, 0, 0, 0, 151003558, 0, 0, 0, 1677721600, 0, 0, 0, 159392167, 0, 0, 0, 1744830470, 0, 0, 0, 151003566, 0, 0, 0, 1677721600, 0, 0, 0, 159392175, 0, 0, 0, 1744830494, 0, 0, 0, 159392206, 0, 0, 0, 1677721601, 0, 0, 0, 159392208, 0, 0, 0, 1744830465, 0, 0, 0, 151003602, 0, 0, 0, 1677721600, 0, 0, 0, 151003603, 0, 0, 0, 1744830464, 0, 0, 0, 151003604, 0, 0, 0, 1677721600, 0, 0, 0, 159392213, 0, 0, 0, 1744830494, 0, 0, 0, 159392244, 0, 0, 0, 1677721867, 0, 0, 0, 159392512, 0, 0, 0, 1744830471, 0, 0, 0, 159392520, 0, 0, 0, 1677721603, 0, 0, 0, 159392524, 0, 0, 0, 1744830483, 0, 0, 0, 159392544, 0, 0, 0, 1677721601, 0, 0, 0, 159392546, 0, 0, 0, 1744830470, 0, 0, 0, 151003945, 0, 0, 0, 1476395008, 0, 0, 0, 151003946, 0, 0, 0, 1207959552, 0, 0, 0, 159392555, 0, 0, 0, 1744830544, 0, 0, 0, 151004028, 0, 0, 0, 1677721600, 0, 0, 0, 159392637, 0, 0, 0, 1744830493, 0, 0, 0, 159392667, 0, 0, 0, 1677721624, 0, 0, 0, 151004084, 0, 0, 0, 1476395008, 0, 0, 0, 151004085, 0, 0, 0, 1207959552, 0, 0, 0, 151004086, 0, 0, 0, 1409286144, 0, 0, 0, 159392695, 0, 0, 0, 1744830500, 0, 0, 0, 159392768, 0, 0, 0, 1744830502, 0, 0, 0, 159392832, 0, 0, 0, 1744830474, 0, 0, 0, 159392864, 0, 0, 0, 1006633019, 0, 0, 0, 159392924, 0, 0, 0, 1744830489, 0, 0, 0, 151004342, 0, 0, 0, 1744830490, 0, 0, 0, 151004343, 0, 0, 0, 1744830490, 0, 0, 0, 151004344, 0, 0, 0, 1744830490, 0, 0, 0, 151004345, 0, 0, 0, 1744830490, 0, 0, 0, 151004346, 0, 0, 0, 1744830490, 0, 0, 0, 151004347, 0, 0, 0, 1744830490, 0, 0, 0, 151004348, 0, 0, 0, 1744830490, 0, 0, 0, 151004349, 0, 0, 0, 1744830490, 0, 0, 0, 151004350, 0, 0, 0, 1744830490, 0, 0, 0, 151004351, 0, 0, 0, 1744830490, 0, 0, 0, 151004352, 0, 0, 0, 1744830490, 0, 0, 0, 151004353, 0, 0, 0, 1744830490, 0, 0, 0, 151004354, 0, 0, 0, 1744830490, 0, 0, 0, 151004355, 0, 0, 0, 1744830490, 0, 0, 0, 151004356, 0, 0, 0, 1744830490, 0, 0, 0, 151004357, 0, 0, 0, 1744830490, 0, 0, 0, 151004358, 0, 0, 0, 1744830490, 0, 0, 0, 151004359, 0, 0, 0, 1744830490, 0, 0, 0, 151004360, 0, 0, 0, 1744830490, 0, 0, 0, 151004361, 0, 0, 0, 1744830490, 0, 0, 0, 151004362, 0, 0, 0, 1744830490, 0, 0, 0, 151004363, 0, 0, 0, 1744830490, 0, 0, 0, 151004364, 0, 0, 0, 1744830490, 0, 0, 0, 151004365, 0, 0, 0, 1744830490, 0, 0, 0, 151004366, 0, 0, 0, 1744830490, 0, 0, 0, 151004367, 0, 0, 0, 1744830490, 0, 0, 0, 151004368, 0, 0, 0, 1744895974, 0, 0, 0, 151004369, 0, 0, 0, 1744895974, 0, 0, 0, 151004370, 0, 0, 0, 1744895974, 0, 0, 0, 151004371, 0, 0, 0, 1744895974, 0, 0, 0, 151004372, 0, 0, 0, 1744895974, 0, 0, 0, 151004373, 0, 0, 0, 1744895974, 0, 0, 0, 151004374, 0, 0, 0, 1744895974, 0, 0, 0, 151004375, 0, 0, 0, 1744895974, 0, 0, 0, 151004376, 0, 0, 0, 1744895974, 0, 0, 0, 151004377, 0, 0, 0, 1744895974, 0, 0, 0, 151004378, 0, 0, 0, 1744895974, 0, 0, 0, 151004379, 0, 0, 0, 1744895974, 0, 0, 0, 151004380, 0, 0, 0, 1744895974, 0, 0, 0, 151004381, 0, 0, 0, 1744895974, 0, 0, 0, 151004382, 0, 0, 0, 1744895974, 0, 0, 0, 151004383, 0, 0, 0, 1744895974, 0, 0, 0, 151004384, 0, 0, 0, 1744895974, 0, 0, 0, 151004385, 0, 0, 0, 1744895974, 0, 0, 0, 151004386, 0, 0, 0, 1744895974, 0, 0, 0, 151004387, 0, 0, 0, 1744895974, 0, 0, 0, 151004388, 0, 0, 0, 1744895974, 0, 0, 0, 151004389, 0, 0, 0, 1744895974, 0, 0, 0, 151004390, 0, 0, 0, 1744895974, 0, 0, 0, 151004391, 0, 0, 0, 1744895974, 0, 0, 0, 151004392, 0, 0, 0, 1744895974, 0, 0, 0, 151004393, 0, 0, 0, 1744895974, 0, 0, 0, 159393002, 0, 0, 0, 1006632981, 0, 0, 0, 159393024, 0, 0, 0, 1744830646, 0, 0, 0, 151004599, 0, 0, 0, 1677721600, 0, 0, 0, 159393208, 0, 0, 0, 1744830472, 0, 0, 0, 151004609, 0, 0, 0, 1677721600, 0, 0, 0, 159393218, 0, 0, 0, 1744830517, 0, 0, 0, 159393272, 0, 0, 0, 1677721607, 0, 0, 0, 159393280, 0, 0, 0, 1744830574, 0, 0, 0, 151004783, 0, 0, 0, 1677721600, 0, 0, 0, 159393392, 0, 0, 0, 1744830508, 0, 0, 0, 159393440, 0, 0, 0, 1744830481, 0, 0, 0, 159393537, 0, 0, 0, 1744830467, 0, 0, 0, 159393542, 0, 0, 0, 1744830467, 0, 0, 0, 159393548, 0, 0, 0, 1744830491, 0, 0, 0, 159393577, 0, 0, 0, 1744830498, 0, 0, 0, 151005005, 0, 0, 0, 1744830464, 0, 0, 0, 159393615, 0, 0, 0, 1744830467, 0, 0, 0, 151005014, 0, 0, 0, 1744830464, 0, 0, 0, 159393624, 0, 0, 0, 1744830470, 0, 0, 0, 159393633, 0, 0, 0, 1744830470, 0, 0, 0, 151005032, 0, 0, 0, 1476395008, 0, 0, 0, 151005033, 0, 0, 0, 1207959552, 0, 0, 0, 151005034, 0, 0, 0, 1476395008, 0, 0, 0, 151005035, 0, 0, 0, 1207959552, 0, 0, 0, 151005036, 0, 0, 0, 1476395008, 0, 0, 0, 151005037, 0, 0, 0, 1207959552, 0, 0, 0, 151005038, 0, 0, 0, 1476395008, 0, 0, 0, 151005039, 0, 0, 0, 1207959552, 0, 0, 0, 151005040, 0, 0, 0, 1476395008, 0, 0, 0, 151005041, 0, 0, 0, 1207959552, 0, 0, 0, 151005042, 0, 0, 0, 1476395008, 0, 0, 0, 151005043, 0, 0, 0, 1207959552, 0, 0, 0, 151005044, 0, 0, 0, 1476395008, 0, 0, 0, 151005045, 0, 0, 0, 1207959552, 0, 0, 0, 159393654, 0, 0, 0, 1006632989, 0, 0, 0, 151005076, 0, 0, 0, 1744830464, 0, 0, 0, 159393688, 0, 0, 0, 1744830487, 0, 0, 0, 159393713, 0, 0, 0, 1744830477, 0, 0, 0, 159393728, 0, 0, 0, 1677721604, 0, 0, 0, 151005125, 0, 0, 0, 1476395008, 0, 0, 0, 151005126, 0, 0, 0, 1207959552, 0, 0, 0, 159393744, 0, 0, 0, 1677721621, 0, 0, 0, 151005158, 0, 0, 0, 1476395008, 0, 0, 0, 151005159, 0, 0, 0, 1207959552, 0, 0, 0, 151005160, 0, 0, 0, 1476395008, 0, 0, 0, 151005161, 0, 0, 0, 1207959552, 0, 0, 0, 151005162, 0, 0, 0, 1476395008, 0, 0, 0, 151005163, 0, 0, 0, 1207959552, 0, 0, 0, 159393776, 0, 0, 0, 1677721615, 0, 0, 0, 75507712, 0, 0, 0, 1744830719, 0, 0, 0, 159394048, 0, 0, 0, 1677721730, 0, 0, 0, 151005571, 0, 0, 0, 1476395008, 0, 0, 0, 151005572, 0, 0, 0, 1207959552, 0, 0, 0, 151005573, 0, 0, 0, 1476395008, 0, 0, 0, 151005574, 0, 0, 0, 1207959552, 0, 0, 0, 151005575, 0, 0, 0, 1476395008, 0, 0, 0, 151005576, 0, 0, 0, 1207959552, 0, 0, 0, 151005577, 0, 0, 0, 1476395008, 0, 0, 0, 151005578, 0, 0, 0, 1207959552, 0, 0, 0, 151005579, 0, 0, 0, 1476395008, 0, 0, 0, 151005580, 0, 0, 0, 1207959552, 0, 0, 0, 151005581, 0, 0, 0, 1476395008, 0, 0, 0, 151005582, 0, 0, 0, 1207959552, 0, 0, 0, 151005583, 0, 0, 0, 1476395008, 0, 0, 0, 151005584, 0, 0, 0, 1207959552, 0, 0, 0, 151005585, 0, 0, 0, 1476395008, 0, 0, 0, 151005586, 0, 0, 0, 1207959552, 0, 0, 0, 151005587, 0, 0, 0, 1476395008, 0, 0, 0, 151005588, 0, 0, 0, 1207959552, 0, 0, 0, 151005589, 0, 0, 0, 1476395008, 0, 0, 0, 151005590, 0, 0, 0, 1207959552, 0, 0, 0, 151005591, 0, 0, 0, 1476395008, 0, 0, 0, 151005592, 0, 0, 0, 1207959552, 0, 0, 0, 159394201, 0, 0, 0, 1677721662, 0, 0, 0, 151005656, 0, 0, 0, 1476395008, 0, 0, 0, 151005657, 0, 0, 0, 1207959552, 0, 0, 0, 151005658, 0, 0, 0, 1476395008, 0, 0, 0, 151005659, 0, 0, 0, 1207959552, 0, 0, 0, 159394268, 0, 0, 0, 1677721631, 0, 0, 0, 151005692, 0, 0, 0, 1476395008, 0, 0, 0, 151005693, 0, 0, 0, 1207959552, 0, 0, 0, 159394302, 0, 0, 0, 1677721857, 0, 0, 0, 159394560, 0, 0, 0, 1744830483, 0, 0, 0, 285223936, 0, 0, 0, 603979824, 0, 0, 0, 285223937, 0, 0, 0, 603979824, 0, 0, 0, 285223938, 0, 0, 0, 603979824, 0, 0, 0, 285223939, 0, 0, 0, 603979824, 0, 0, 0, 285223940, 0, 0, 0, 603979824, 0, 0, 0, 285223941, 0, 0, 0, 603979824, 0, 0, 0, 285223942, 0, 0, 0, 603979824, 0, 0, 0, 285223943, 0, 0, 0, 603979824, 0, 0, 0, 285223944, 0, 0, 0, 603979824, 0, 0, 0, 285223945, 0, 0, 0, 603979824, 0, 0, 0, 285223946, 0, 0, 0, 603979824, 0, 0, 0, 285223947, 0, 0, 0, 603979824, 0, 0, 0, 285223948, 0, 0, 0, 603979824, 0, 0, 0, 285223949, 0, 0, 0, 603979824, 0, 0, 0, 285223950, 0, 0, 0, 603979824, 0, 0, 0, 285223951, 0, 0, 0, 603979824, 0, 0, 0, 285223952, 0, 0, 0, 603979824, 0, 0, 0, 285223953, 0, 0, 0, 603979824, 0, 0, 0, 285223954, 0, 0, 0, 603979824, 0, 0, 0, 285223955, 0, 0, 0, 603979824, 0, 0, 0, 285223956, 0, 0, 0, 603979824, 0, 0, 0, 285223957, 0, 0, 0, 603979824, 0, 0, 0, 285223958, 0, 0, 0, 603979824, 0, 0, 0, 285223959, 0, 0, 0, 603979824, 0, 0, 0, 285223960, 0, 0, 0, 603979824, 0, 0, 0, 285223961, 0, 0, 0, 603979824, 0, 0, 0, 285223962, 0, 0, 0, 603979824, 0, 0, 0, 285223963, 0, 0, 0, 603979824, 0, 0, 0, 285223964, 0, 0, 0, 603979824, 0, 0, 0, 285223965, 0, 0, 0, 603979824, 0, 0, 0, 285223966, 0, 0, 0, 603979824, 0, 0, 0, 285223967, 0, 0, 0, 603979824, 0, 0, 0, 285223968, 0, 0, 0, 603979824, 0, 0, 0, 285223969, 0, 0, 0, 603979824, 0, 0, 0, 285223970, 0, 0, 0, 603979824, 0, 0, 0, 285223971, 0, 0, 0, 603979824, 0, 0, 0, 285223972, 0, 0, 0, 603979824, 0, 0, 0, 285223973, 0, 0, 0, 603979824, 0, 0, 0, 285223974, 0, 0, 0, 603979824, 0, 0, 0, 285223975, 0, 0, 0, 603979824, 0, 0, 0, 285223976, 0, 0, 0, 603979824, 0, 0, 0, 285223977, 0, 0, 0, 603979824, 0, 0, 0, 285223978, 0, 0, 0, 603979824, 0, 0, 0, 285223979, 0, 0, 0, 603979824, 0, 0, 0, 285223980, 0, 0, 0, 603979824, 0, 0, 0, 285223981, 0, 0, 0, 603979824, 0, 0, 0, 285223982, 0, 0, 0, 603979824, 0, 0, 0, 285223984, 0, 0, 0, 335609808, 0, 0, 0, 285223985, 0, 0, 0, 335609808, 0, 0, 0, 285223986, 0, 0, 0, 335609808, 0, 0, 0, 285223987, 0, 0, 0, 335609808, 0, 0, 0, 285223988, 0, 0, 0, 335609808, 0, 0, 0, 285223989, 0, 0, 0, 335609808, 0, 0, 0, 285223990, 0, 0, 0, 335609808, 0, 0, 0, 285223991, 0, 0, 0, 335609808, 0, 0, 0, 285223992, 0, 0, 0, 335609808, 0, 0, 0, 285223993, 0, 0, 0, 335609808, 0, 0, 0, 285223994, 0, 0, 0, 335609808, 0, 0, 0, 285223995, 0, 0, 0, 335609808, 0, 0, 0, 285223996, 0, 0, 0, 335609808, 0, 0, 0, 285223997, 0, 0, 0, 335609808, 0, 0, 0, 285223998, 0, 0, 0, 335609808, 0, 0, 0, 285223999, 0, 0, 0, 335609808, 0, 0, 0, 285224e3, 0, 0, 0, 335609808, 0, 0, 0, 285224001, 0, 0, 0, 335609808, 0, 0, 0, 285224002, 0, 0, 0, 335609808, 0, 0, 0, 285224003, 0, 0, 0, 335609808, 0, 0, 0, 285224004, 0, 0, 0, 335609808, 0, 0, 0, 285224005, 0, 0, 0, 335609808, 0, 0, 0, 285224006, 0, 0, 0, 335609808, 0, 0, 0, 285224007, 0, 0, 0, 335609808, 0, 0, 0, 285224008, 0, 0, 0, 335609808, 0, 0, 0, 285224009, 0, 0, 0, 335609808, 0, 0, 0, 285224010, 0, 0, 0, 335609808, 0, 0, 0, 285224011, 0, 0, 0, 335609808, 0, 0, 0, 285224012, 0, 0, 0, 335609808, 0, 0, 0, 285224013, 0, 0, 0, 335609808, 0, 0, 0, 285224014, 0, 0, 0, 335609808, 0, 0, 0, 285224015, 0, 0, 0, 335609808, 0, 0, 0, 285224016, 0, 0, 0, 335609808, 0, 0, 0, 285224017, 0, 0, 0, 335609808, 0, 0, 0, 285224018, 0, 0, 0, 335609808, 0, 0, 0, 285224019, 0, 0, 0, 335609808, 0, 0, 0, 285224020, 0, 0, 0, 335609808, 0, 0, 0, 285224021, 0, 0, 0, 335609808, 0, 0, 0, 285224022, 0, 0, 0, 335609808, 0, 0, 0, 285224023, 0, 0, 0, 335609808, 0, 0, 0, 285224024, 0, 0, 0, 335609808, 0, 0, 0, 285224025, 0, 0, 0, 335609808, 0, 0, 0, 285224026, 0, 0, 0, 335609808, 0, 0, 0, 285224027, 0, 0, 0, 335609808, 0, 0, 0, 285224028, 0, 0, 0, 335609808, 0, 0, 0, 285224029, 0, 0, 0, 335609808, 0, 0, 0, 285224030, 0, 0, 0, 335609808, 0, 0, 0, 167783552, 0, 0, 0, 603979777, 0, 0, 0, 167783553, 0, 0, 0, 335609855, 0, 0, 0, 167783554, 0, 0, 0, 603979777, 0, 0, 0, 167783555, 0, 0, 0, 335609855, 0, 0, 0, 167783556, 0, 0, 0, 603979777, 0, 0, 0, 167783557, 0, 0, 0, 335609855, 0, 0, 0, 167783558, 0, 0, 0, 603979777, 0, 0, 0, 167783559, 0, 0, 0, 335609855, 0, 0, 0, 167783560, 0, 0, 0, 603979777, 0, 0, 0, 167783561, 0, 0, 0, 335609855, 0, 0, 0, 167783562, 0, 0, 0, 603979777, 0, 0, 0, 167783563, 0, 0, 0, 335609855, 0, 0, 0, 167783564, 0, 0, 0, 603979777, 0, 0, 0, 167783565, 0, 0, 0, 335609855, 0, 0, 0, 167783566, 0, 0, 0, 603979777, 0, 0, 0, 167783567, 0, 0, 0, 335609855, 0, 0, 0, 167783568, 0, 0, 0, 603979777, 0, 0, 0, 167783569, 0, 0, 0, 335609855, 0, 0, 0, 167783570, 0, 0, 0, 603979777, 0, 0, 0, 167783571, 0, 0, 0, 335609855, 0, 0, 0, 167783572, 0, 0, 0, 603979777, 0, 0, 0, 167783573, 0, 0, 0, 335609855, 0, 0, 0, 167783574, 0, 0, 0, 603979777, 0, 0, 0, 167783575, 0, 0, 0, 335609855, 0, 0, 0, 167783576, 0, 0, 0, 603979777, 0, 0, 0, 167783577, 0, 0, 0, 335609855, 0, 0, 0, 167783578, 0, 0, 0, 603979777, 0, 0, 0, 167783579, 0, 0, 0, 335609855, 0, 0, 0, 167783580, 0, 0, 0, 603979777, 0, 0, 0, 167783581, 0, 0, 0, 335609855, 0, 0, 0, 167783582, 0, 0, 0, 603979777, 0, 0, 0, 167783583, 0, 0, 0, 335609855, 0, 0, 0, 167783584, 0, 0, 0, 603979777, 0, 0, 0, 167783585, 0, 0, 0, 335609855, 0, 0, 0, 167783586, 0, 0, 0, 603979777, 0, 0, 0, 167783587, 0, 0, 0, 335609855, 0, 0, 0, 167783588, 0, 0, 0, 603979777, 0, 0, 0, 167783589, 0, 0, 0, 335609855, 0, 0, 0, 167783590, 0, 0, 0, 603979777, 0, 0, 0, 167783591, 0, 0, 0, 335609855, 0, 0, 0, 167783592, 0, 0, 0, 603979777, 0, 0, 0, 167783593, 0, 0, 0, 335609855, 0, 0, 0, 167783594, 0, 0, 0, 603979777, 0, 0, 0, 167783595, 0, 0, 0, 335609855, 0, 0, 0, 167783596, 0, 0, 0, 603979777, 0, 0, 0, 167783597, 0, 0, 0, 335609855, 0, 0, 0, 167783598, 0, 0, 0, 603979777, 0, 0, 0, 167783599, 0, 0, 0, 335609855, 0, 0, 0, 167783600, 0, 0, 0, 603979777, 0, 0, 0, 167783601, 0, 0, 0, 335609855, 0, 0, 0, 167783602, 0, 0, 0, 603979777, 0, 0, 0, 167783603, 0, 0, 0, 335609855, 0, 0, 0, 167783604, 0, 0, 0, 603979777, 0, 0, 0, 167783605, 0, 0, 0, 335609855, 0, 0, 0, 167783606, 0, 0, 0, 603979777, 0, 0, 0, 167783607, 0, 0, 0, 335609855, 0, 0, 0, 167783608, 0, 0, 0, 603979777, 0, 0, 0, 167783609, 0, 0, 0, 335609855, 0, 0, 0, 167783610, 0, 0, 0, 603979777, 0, 0, 0, 167783611, 0, 0, 0, 335609855, 0, 0, 0, 167783612, 0, 0, 0, 603979777, 0, 0, 0, 167783613, 0, 0, 0, 335609855, 0, 0, 0, 167783614, 0, 0, 0, 603979777, 0, 0, 0, 167783615, 0, 0, 0, 335609855, 0, 0, 0, 167783616, 0, 0, 0, 603979777, 0, 0, 0, 167783617, 0, 0, 0, 335609855, 0, 0, 0, 167783618, 0, 0, 0, 603979777, 0, 0, 0, 167783619, 0, 0, 0, 335609855, 0, 0, 0, 167783620, 0, 0, 0, 603979777, 0, 0, 0, 167783621, 0, 0, 0, 335609855, 0, 0, 0, 167783622, 0, 0, 0, 603979777, 0, 0, 0, 167783623, 0, 0, 0, 335609855, 0, 0, 0, 167783624, 0, 0, 0, 603979777, 0, 0, 0, 167783625, 0, 0, 0, 335609855, 0, 0, 0, 167783626, 0, 0, 0, 603979777, 0, 0, 0, 167783627, 0, 0, 0, 335609855, 0, 0, 0, 167783628, 0, 0, 0, 603979777, 0, 0, 0, 167783629, 0, 0, 0, 335609855, 0, 0, 0, 167783630, 0, 0, 0, 603979777, 0, 0, 0, 167783631, 0, 0, 0, 335609855, 0, 0, 0, 167783632, 0, 0, 0, 603979777, 0, 0, 0, 167783633, 0, 0, 0, 335609855, 0, 0, 0, 167783634, 0, 0, 0, 603979777, 0, 0, 0, 167783635, 0, 0, 0, 335609855, 0, 0, 0, 167783636, 0, 0, 0, 603979777, 0, 0, 0, 167783637, 0, 0, 0, 335609855, 0, 0, 0, 167783638, 0, 0, 0, 603979777, 0, 0, 0, 167783639, 0, 0, 0, 335609855, 0, 0, 0, 167783640, 0, 0, 0, 603979777, 0, 0, 0, 167783641, 0, 0, 0, 335609855, 0, 0, 0, 167783642, 0, 0, 0, 603979777, 0, 0, 0, 167783643, 0, 0, 0, 335609855, 0, 0, 0, 167783644, 0, 0, 0, 603979777, 0, 0, 0, 167783645, 0, 0, 0, 335609855, 0, 0, 0, 167783646, 0, 0, 0, 603979777, 0, 0, 0, 167783647, 0, 0, 0, 335609855, 0, 0, 0, 167783648, 0, 0, 0, 603979777, 0, 0, 0, 167783649, 0, 0, 0, 335609855, 0, 0, 0, 167783650, 0, 0, 0, 603979777, 0, 0, 0, 167783651, 0, 0, 0, 335609855, 0, 0, 0, 167783652, 0, 0, 0, 335544320, 0, 0, 0, 176172261, 0, 0, 0, 1744830469, 0, 0, 0, 176172281, 0, 0, 0, 1409286147, 0, 0, 0, 167783677, 0, 0, 0, 1006632960, 0, 0, 0, 176172286, 0, 0, 0, 1409286145, 0, 0, 0, 268446976, 0, 0, 0, 335602592, 0, 0, 0, 268446977, 0, 0, 0, 335602592, 0, 0, 0, 268446978, 0, 0, 0, 335602592, 0, 0, 0, 268446979, 0, 0, 0, 335602592, 0, 0, 0, 268446980, 0, 0, 0, 335602592, 0, 0, 0, 268446981, 0, 0, 0, 335602592, 0, 0, 0, 268446982, 0, 0, 0, 335602592, 0, 0, 0, 268446983, 0, 0, 0, 335602592, 0, 0, 0, 268446984, 0, 0, 0, 335602592, 0, 0, 0, 268446985, 0, 0, 0, 335602592, 0, 0, 0, 268446986, 0, 0, 0, 335602592, 0, 0, 0, 268446987, 0, 0, 0, 335602592, 0, 0, 0, 268446988, 0, 0, 0, 335602592, 0, 0, 0, 268446989, 0, 0, 0, 335602592, 0, 0, 0, 268446990, 0, 0, 0, 335602592, 0, 0, 0, 268446991, 0, 0, 0, 335602592, 0, 0, 0, 268446992, 0, 0, 0, 335602592, 0, 0, 0, 268446993, 0, 0, 0, 335602592, 0, 0, 0, 268446994, 0, 0, 0, 335602592, 0, 0, 0, 268446995, 0, 0, 0, 335602592, 0, 0, 0, 268446996, 0, 0, 0, 335602592, 0, 0, 0, 268446997, 0, 0, 0, 335602592, 0, 0, 0, 268446998, 0, 0, 0, 335602592, 0, 0, 0, 268446999, 0, 0, 0, 335602592, 0, 0, 0, 268447e3, 0, 0, 0, 335602592, 0, 0, 0, 268447001, 0, 0, 0, 335602592, 0, 0, 0, 268447002, 0, 0, 0, 335602592, 0, 0, 0, 268447003, 0, 0, 0, 335602592, 0, 0, 0, 268447004, 0, 0, 0, 335602592, 0, 0, 0, 268447005, 0, 0, 0, 335602592, 0, 0, 0, 268447006, 0, 0, 0, 335602592, 0, 0, 0, 268447007, 0, 0, 0, 335602592, 0, 0, 0, 268447008, 0, 0, 0, 335602592, 0, 0, 0, 268447009, 0, 0, 0, 335602592, 0, 0, 0, 268447010, 0, 0, 0, 335602592, 0, 0, 0, 268447011, 0, 0, 0, 335602592, 0, 0, 0, 268447012, 0, 0, 0, 335602592, 0, 0, 0, 268447013, 0, 0, 0, 335602592, 0, 0, 0, 981478704, 0, 0, 0, 469762101, 0, 0, 0, 973090159, 0, 0, 0, 402653184, 0, 0, 0, 260058496, 0, 0, 0, 469762070, 0, 0, 0, 260058528, 0, 0, 0, 469762054, 0, 0, 0, 260058536, 0, 0, 0, 469762054, 0, 0, 0, 260058544, 0, 0, 0, 469762054, 0, 0, 0, 260058552, 0, 0, 0, 469762054, 0, 0, 0, 260058560, 0, 0, 0, 469762054, 0, 0, 0, 260058568, 0, 0, 0, 469762054, 0, 0, 0, 260058576, 0, 0, 0, 469762054, 0, 0, 0, 260058584, 0, 0, 0, 469762054, 0, 0, 0, 159395328, 0, 0, 0, 1409286145, 0, 0, 0, 151006722, 0, 0, 0, 1342177280, 0, 0, 0, 151006723, 0, 0, 0, 1275068416, 0, 0, 0, 151006724, 0, 0, 0, 1342177280, 0, 0, 0, 151006725, 0, 0, 0, 1275068416, 0, 0, 0, 159395334, 0, 0, 0, 1409286146, 0, 0, 0, 151006729, 0, 0, 0, 1342177280, 0, 0, 0, 151006730, 0, 0, 0, 1275068416, 0, 0, 0, 151006731, 0, 0, 0, 1409286144, 0, 0, 0, 151006732, 0, 0, 0, 1342177280, 0, 0, 0, 151006733, 0, 0, 0, 1275068416, 0, 0, 0, 159395342, 0, 0, 0, 1409286152, 0, 0, 0, 151006743, 0, 0, 0, 1140850688, 0, 0, 0, 151006748, 0, 0, 0, 1342177280, 0, 0, 0, 151006749, 0, 0, 0, 1275068416, 0, 0, 0, 377499264, 0, 0, 0, 1744830489, 0, 0, 0, 377499291, 0, 0, 0, 1744830552, 0, 0, 0, 377499392, 0, 0, 0, 1744830677, 0, 0, 0, 159395824, 0, 0, 0, 1744830475, 0, 0, 0, 151007232, 0, 0, 0, 1946157056, 0, 0, 0, 159395841, 0, 0, 0, 1409286146, 0, 0, 0, 151007236, 0, 0, 0, 1744830464, 0, 0, 0, 369111045, 0, 0, 0, 402653184, 0, 0, 0, 151007238, 0, 0, 0, 469762048, 0, 0, 0, 369111047, 0, 0, 0, 939524096, 0, 0, 0, 151007240, 0, 0, 0, 1476395008, 0, 0, 0, 151007241, 0, 0, 0, 1207959552, 0, 0, 0, 151007242, 0, 0, 0, 1476395008, 0, 0, 0, 151007243, 0, 0, 0, 1207959552, 0, 0, 0, 151007244, 0, 0, 0, 1476395008, 0, 0, 0, 151007245, 0, 0, 0, 1207959552, 0, 0, 0, 151007246, 0, 0, 0, 1476395008, 0, 0, 0, 151007247, 0, 0, 0, 1207959552, 0, 0, 0, 151007248, 0, 0, 0, 1476395008, 0, 0, 0, 151007249, 0, 0, 0, 1207959552, 0, 0, 0, 159395858, 0, 0, 0, 1744830465, 0, 0, 0, 151007252, 0, 0, 0, 1476395008, 0, 0, 0, 151007253, 0, 0, 0, 1207959552, 0, 0, 0, 151007254, 0, 0, 0, 1476395008, 0, 0, 0, 151007255, 0, 0, 0, 1207959552, 0, 0, 0, 151007256, 0, 0, 0, 1476395008, 0, 0, 0, 151007257, 0, 0, 0, 1207959552, 0, 0, 0, 151007258, 0, 0, 0, 1476395008, 0, 0, 0, 151007259, 0, 0, 0, 1207959552, 0, 0, 0, 151007260, 0, 0, 0, 1140850688, 0, 0, 0, 151007261, 0, 0, 0, 1476395008, 0, 0, 0, 159395870, 0, 0, 0, 1207959553, 0, 0, 0, 151007264, 0, 0, 0, 1744830464, 0, 0, 0, 377499681, 0, 0, 0, 939524104, 0, 0, 0, 461385770, 0, 0, 0, 805306373, 0, 0, 0, 151007280, 0, 0, 0, 1140850688, 0, 0, 0, 159395889, 0, 0, 0, 402653188, 0, 0, 0, 159395894, 0, 0, 0, 1744830465, 0, 0, 0, 377499704, 0, 0, 0, 939524098, 0, 0, 0, 369111099, 0, 0, 0, 402653184, 0, 0, 0, 151007292, 0, 0, 0, 469762048, 0, 0, 0, 151007293, 0, 0, 0, 1409286144, 0, 0, 0, 159395902, 0, 0, 0, 1744830465, 0, 0, 0, 444608577, 0, 0, 0, 469762133, 0, 0, 0, 461385881, 0, 0, 0, 805306369, 0, 0, 0, 159395995, 0, 0, 0, 1610612737, 0, 0, 0, 444608669, 0, 0, 0, 402653185, 0, 0, 0, 436220063, 0, 0, 0, 469762048, 0, 0, 0, 151007392, 0, 0, 0, 1140850688, 0, 0, 0, 494940321, 0, 0, 0, 469762137, 0, 0, 0, 151007483, 0, 0, 0, 1409286144, 0, 0, 0, 159396092, 0, 0, 0, 402653186, 0, 0, 0, 486551807, 0, 0, 0, 469762048, 0, 0, 0, 58732805, 0, 0, 0, 469762087, 0, 0, 0, 394277169, 0, 0, 0, 469762141, 0, 0, 0, 159396240, 0, 0, 0, 1744830465, 0, 0, 0, 159396242, 0, 0, 0, 1006632963, 0, 0, 0, 159396246, 0, 0, 0, 1744830473, 0, 0, 0, 58732960, 0, 0, 0, 469762071, 0, 0, 0, 159396288, 0, 0, 0, 1744830479, 0, 0, 0, 494940656, 0, 0, 0, 469762063, 0, 0, 0, 394277376, 0, 0, 0, 1744830494, 0, 0, 0, 159396384, 0, 0, 0, 1006632969, 0, 0, 0, 159396394, 0, 0, 0, 1744830489, 0, 0, 0, 151007824, 0, 0, 0, 1744830464, 0, 0, 0, 159396433, 0, 0, 0, 1006632974, 0, 0, 0, 394277472, 0, 0, 0, 1744830495, 0, 0, 0, 159396480, 0, 0, 0, 1006632969, 0, 0, 0, 159396490, 0, 0, 0, 1744830502, 0, 0, 0, 159396529, 0, 0, 0, 1006632974, 0, 0, 0, 159396544, 0, 0, 0, 1744830526, 0, 0, 0, 159396608, 0, 0, 0, 1744830719, 0, 0, 0, 377500672, 0, 0, 0, 469768629, 0, 0, 0, 159403456, 0, 0, 0, 1744830527, 0, 0, 0, 377507328, 0, 0, 0, 469782971, 0, 0, 0, 1015062528, 0, 0, 0, 469762068, 0, 0, 0, 1006673941, 0, 0, 0, 402653184, 0, 0, 0, 1015062550, 0, 0, 0, 469763190, 0, 0, 0, 1015063696, 0, 0, 0, 1744830518, 0, 0, 0, 159426304, 0, 0, 0, 1610612758, 0, 0, 0, 813737984, 0, 0, 0, 469762049, 0, 0, 0, 805349378, 0, 0, 0, 671088640, 0, 0, 0, 813737987, 0, 0, 0, 469762050, 0, 0, 0, 805349382, 0, 0, 0, 805306368, 0, 0, 0, 813737991, 0, 0, 0, 469762051, 0, 0, 0, 805349387, 0, 0, 0, 805306368, 0, 0, 0, 813737996, 0, 0, 0, 469762070, 0, 0, 0, 813738019, 0, 0, 0, 671088641, 0, 0, 0, 813738021, 0, 0, 0, 805306369, 0, 0, 0, 805349415, 0, 0, 0, 671088640, 0, 0, 0, 813738024, 0, 0, 0, 1744830467, 0, 0, 0, 394308608, 0, 0, 0, 469773219, 0, 0, 0, 159438848, 0, 0, 0, 268436351, 0, 0, 0, 159439744, 0, 0, 0, 268435583, 0, 0, 0, 159439872, 0, 0, 0, 268436479, 0, 0, 0, 159440896, 0, 0, 0, 201332991, 0, 0, 0, 377551104, 0, 0, 0, 469762349, 0, 0, 0, 377551408, 0, 0, 0, 469762106, 0, 0, 0, 377551472, 0, 0, 0, 469762153, 0, 0, 0, 562100992, 0, 0, 0, 335544326, 0, 0, 0, 25230099, 0, 0, 0, 335544324, 0, 0, 0, 419494685, 0, 0, 0, 469762048, 0, 0, 0, 419494686, 0, 0, 0, 805306368, 0, 0, 0, 427883295, 0, 0, 0, 469762057, 0, 0, 0, 419494697, 0, 0, 0, 1677721600, 0, 0, 0, 427883306, 0, 0, 0, 469762060, 0, 0, 0, 427883320, 0, 0, 0, 469762052, 0, 0, 0, 419494718, 0, 0, 0, 469762048, 0, 0, 0, 427883328, 0, 0, 0, 469762049, 0, 0, 0, 427883331, 0, 0, 0, 469762049, 0, 0, 0, 427883334, 0, 0, 0, 469762155, 0, 0, 0, 8453075, 0, 0, 0, 469762410, 0, 0, 0, 151059774, 0, 0, 0, 1476395008, 0, 0, 0, 151059775, 0, 0, 0, 1207959552, 0, 0, 0, 8453456, 0, 0, 0, 469762111, 0, 0, 0, 8453522, 0, 0, 0, 469762101, 0, 0, 0, 8453616, 0, 0, 0, 469762059, 0, 0, 0, 65020, 0, 0, 0, 1543503872, 0, 0, 0, 151059965, 0, 0, 0, 1744830464, 0, 0, 0, 461438464, 0, 0, 0, 805306383, 0, 0, 0, 159448592, 0, 0, 0, 1409286150, 0, 0, 0, 151059991, 0, 0, 0, 1476395008, 0, 0, 0, 151059992, 0, 0, 0, 1207959552, 0, 0, 0, 151059993, 0, 0, 0, 1409286144, 0, 0, 0, 461438496, 0, 0, 0, 805306371, 0, 0, 0, 151060016, 0, 0, 0, 1409286144, 0, 0, 0, 159448625, 0, 0, 0, 1140850689, 0, 0, 0, 159448627, 0, 0, 0, 1073741825, 0, 0, 0, 151060021, 0, 0, 0, 1476395008, 0, 0, 0, 151060022, 0, 0, 0, 1207959552, 0, 0, 0, 151060023, 0, 0, 0, 1476395008, 0, 0, 0, 151060024, 0, 0, 0, 1207959552, 0, 0, 0, 151060025, 0, 0, 0, 1476395008, 0, 0, 0, 151060026, 0, 0, 0, 1207959552, 0, 0, 0, 151060027, 0, 0, 0, 1476395008, 0, 0, 0, 151060028, 0, 0, 0, 1207959552, 0, 0, 0, 151060029, 0, 0, 0, 1476395008, 0, 0, 0, 151060030, 0, 0, 0, 1207959552, 0, 0, 0, 151060031, 0, 0, 0, 1476395008, 0, 0, 0, 151060032, 0, 0, 0, 1207959552, 0, 0, 0, 151060033, 0, 0, 0, 1476395008, 0, 0, 0, 151060034, 0, 0, 0, 1207959552, 0, 0, 0, 151060035, 0, 0, 0, 1476395008, 0, 0, 0, 151060036, 0, 0, 0, 1207959552, 0, 0, 0, 159448645, 0, 0, 0, 1409286145, 0, 0, 0, 151060039, 0, 0, 0, 1476395008, 0, 0, 0, 151060040, 0, 0, 0, 1207959552, 0, 0, 0, 159448649, 0, 0, 0, 1409286147, 0, 0, 0, 159448653, 0, 0, 0, 1073741826, 0, 0, 0, 159448656, 0, 0, 0, 1409286146, 0, 0, 0, 159448660, 0, 0, 0, 1409286147, 0, 0, 0, 151060056, 0, 0, 0, 1140850688, 0, 0, 0, 151060057, 0, 0, 0, 1476395008, 0, 0, 0, 151060058, 0, 0, 0, 1207959552, 0, 0, 0, 151060059, 0, 0, 0, 1476395008, 0, 0, 0, 151060060, 0, 0, 0, 1207959552, 0, 0, 0, 151060061, 0, 0, 0, 1476395008, 0, 0, 0, 151060062, 0, 0, 0, 1207959552, 0, 0, 0, 159448671, 0, 0, 0, 1409286146, 0, 0, 0, 151060066, 0, 0, 0, 1677721600, 0, 0, 0, 151060067, 0, 0, 0, 1140850688, 0, 0, 0, 159448676, 0, 0, 0, 1677721602, 0, 0, 0, 151060072, 0, 0, 0, 1409286144, 0, 0, 0, 151060073, 0, 0, 0, 1543503872, 0, 0, 0, 159448682, 0, 0, 0, 1409286145, 0, 0, 0, 8453744, 0, 0, 0, 469762052, 0, 0, 0, 8453750, 0, 0, 0, 469762182, 0, 0, 0, 151060223, 0, 0, 0, 67108864, 0, 0, 0, 159448833, 0, 0, 0, 1409286146, 0, 0, 0, 151060228, 0, 0, 0, 1543503872, 0, 0, 0, 159448837, 0, 0, 0, 1409286146, 0, 0, 0, 151060232, 0, 0, 0, 1476395008, 0, 0, 0, 151060233, 0, 0, 0, 1207959552, 0, 0, 0, 151060234, 0, 0, 0, 1409286144, 0, 0, 0, 151060235, 0, 0, 0, 1677721600, 0, 0, 0, 151060236, 0, 0, 0, 1409286144, 0, 0, 0, 151060237, 0, 0, 0, 1140850688, 0, 0, 0, 159448846, 0, 0, 0, 1409286145, 0, 0, 0, 159448848, 0, 0, 0, 872415241, 0, 0, 0, 159448858, 0, 0, 0, 1409286145, 0, 0, 0, 159448860, 0, 0, 0, 1677721602, 0, 0, 0, 159448863, 0, 0, 0, 1409286145, 0, 0, 0, 553713441, 0, 0, 0, 603979808, 0, 0, 0, 553713442, 0, 0, 0, 603979808, 0, 0, 0, 553713443, 0, 0, 0, 603979808, 0, 0, 0, 553713444, 0, 0, 0, 603979808, 0, 0, 0, 553713445, 0, 0, 0, 603979808, 0, 0, 0, 553713446, 0, 0, 0, 603979808, 0, 0, 0, 553713447, 0, 0, 0, 603979808, 0, 0, 0, 553713448, 0, 0, 0, 603979808, 0, 0, 0, 553713449, 0, 0, 0, 603979808, 0, 0, 0, 553713450, 0, 0, 0, 603979808, 0, 0, 0, 553713451, 0, 0, 0, 603979808, 0, 0, 0, 553713452, 0, 0, 0, 603979808, 0, 0, 0, 553713453, 0, 0, 0, 603979808, 0, 0, 0, 553713454, 0, 0, 0, 603979808, 0, 0, 0, 553713455, 0, 0, 0, 603979808, 0, 0, 0, 553713456, 0, 0, 0, 603979808, 0, 0, 0, 553713457, 0, 0, 0, 603979808, 0, 0, 0, 553713458, 0, 0, 0, 603979808, 0, 0, 0, 553713459, 0, 0, 0, 603979808, 0, 0, 0, 553713460, 0, 0, 0, 603979808, 0, 0, 0, 553713461, 0, 0, 0, 603979808, 0, 0, 0, 553713462, 0, 0, 0, 603979808, 0, 0, 0, 553713463, 0, 0, 0, 603979808, 0, 0, 0, 553713464, 0, 0, 0, 603979808, 0, 0, 0, 553713465, 0, 0, 0, 603979808, 0, 0, 0, 553713466, 0, 0, 0, 603979808, 0, 0, 0, 151060283, 0, 0, 0, 1476395008, 0, 0, 0, 151060284, 0, 0, 0, 1409286144, 0, 0, 0, 151060285, 0, 0, 0, 1207959552, 0, 0, 0, 151060286, 0, 0, 0, 1610612736, 0, 0, 0, 151060287, 0, 0, 0, 1073741824, 0, 0, 0, 151060288, 0, 0, 0, 1610612736, 0, 0, 0, 553713473, 0, 0, 0, 335609824, 0, 0, 0, 553713474, 0, 0, 0, 335609824, 0, 0, 0, 553713475, 0, 0, 0, 335609824, 0, 0, 0, 553713476, 0, 0, 0, 335609824, 0, 0, 0, 553713477, 0, 0, 0, 335609824, 0, 0, 0, 553713478, 0, 0, 0, 335609824, 0, 0, 0, 553713479, 0, 0, 0, 335609824, 0, 0, 0, 553713480, 0, 0, 0, 335609824, 0, 0, 0, 553713481, 0, 0, 0, 335609824, 0, 0, 0, 553713482, 0, 0, 0, 335609824, 0, 0, 0, 553713483, 0, 0, 0, 335609824, 0, 0, 0, 553713484, 0, 0, 0, 335609824, 0, 0, 0, 553713485, 0, 0, 0, 335609824, 0, 0, 0, 553713486, 0, 0, 0, 335609824, 0, 0, 0, 553713487, 0, 0, 0, 335609824, 0, 0, 0, 553713488, 0, 0, 0, 335609824, 0, 0, 0, 553713489, 0, 0, 0, 335609824, 0, 0, 0, 553713490, 0, 0, 0, 335609824, 0, 0, 0, 553713491, 0, 0, 0, 335609824, 0, 0, 0, 553713492, 0, 0, 0, 335609824, 0, 0, 0, 553713493, 0, 0, 0, 335609824, 0, 0, 0, 553713494, 0, 0, 0, 335609824, 0, 0, 0, 553713495, 0, 0, 0, 335609824, 0, 0, 0, 553713496, 0, 0, 0, 335609824, 0, 0, 0, 553713497, 0, 0, 0, 335609824, 0, 0, 0, 553713498, 0, 0, 0, 335609824, 0, 0, 0, 151060315, 0, 0, 0, 1476395008, 0, 0, 0, 151060316, 0, 0, 0, 1677721600, 0, 0, 0, 151060317, 0, 0, 0, 1207959552, 0, 0, 0, 151060318, 0, 0, 0, 1677721600, 0, 0, 0, 151060319, 0, 0, 0, 1476395008, 0, 0, 0, 151060320, 0, 0, 0, 1207959552, 0, 0, 0, 151060321, 0, 0, 0, 1409286144, 0, 0, 0, 151060322, 0, 0, 0, 1476395008, 0, 0, 0, 151060323, 0, 0, 0, 1207959552, 0, 0, 0, 159448932, 0, 0, 0, 1409286145, 0, 0, 0, 494993254, 0, 0, 0, 469762057, 0, 0, 0, 151060336, 0, 0, 0, 402653184, 0, 0, 0, 494993265, 0, 0, 0, 469762092, 0, 0, 0, 159448990, 0, 0, 0, 402653185, 0, 0, 0, 394330016, 0, 0, 0, 469762078, 0, 0, 0, 394330050, 0, 0, 0, 469762053, 0, 0, 0, 394330058, 0, 0, 0, 469762053, 0, 0, 0, 394330066, 0, 0, 0, 469762053, 0, 0, 0, 394330074, 0, 0, 0, 469762050, 0, 0, 0, 159449056, 0, 0, 0, 1543503873, 0, 0, 0, 151060450, 0, 0, 0, 1677721600, 0, 0, 0, 151060451, 0, 0, 0, 1610612736, 0, 0, 0, 151060452, 0, 0, 0, 1744830464, 0, 0, 0, 159449061, 0, 0, 0, 1543503873, 0, 0, 0, 151060456, 0, 0, 0, 1744830464, 0, 0, 0, 159449065, 0, 0, 0, 1677721603, 0, 0, 0, 159449069, 0, 0, 0, 1744830465, 0, 0, 0, 159449081, 0, 0, 0, 67108866, 0, 0, 0, 159449084, 0, 0, 0, 1744830465, 0, 0, 0, 595656704, 0, 0, 0, 469762059, 0, 0, 0, 595656717, 0, 0, 0, 469762073, 0, 0, 0, 595656744, 0, 0, 0, 469762066, 0, 0, 0, 595656764, 0, 0, 0, 469762049, 0, 0, 0, 595656767, 0, 0, 0, 469762062, 0, 0, 0, 595656784, 0, 0, 0, 469762061, 0, 0, 0, 595656832, 0, 0, 0, 469762170, 0, 0, 0, 159449344, 0, 0, 0, 1409286145, 0, 0, 0, 151060738, 0, 0, 0, 1744830464, 0, 0, 0, 159449351, 0, 0, 0, 1006633004, 0, 0, 0, 159449399, 0, 0, 0, 1744830472, 0, 0, 0, 327221568, 0, 0, 0, 939524148, 0, 0, 0, 327221621, 0, 0, 0, 1006632963, 0, 0, 0, 327221625, 0, 0, 0, 1744830480, 0, 0, 0, 318833034, 0, 0, 0, 1006632960, 0, 0, 0, 696320768, 0, 0, 0, 469762078, 0, 0, 0, 696320800, 0, 0, 0, 1006632963, 0, 0, 0, 310444848, 0, 0, 0, 469762073, 0, 0, 0, 302056266, 0, 0, 0, 939524096, 0, 0, 0, 998310784, 0, 0, 0, 469762077, 0, 0, 0, 989922207, 0, 0, 0, 1409286144, 0, 0, 0, 713098144, 0, 0, 0, 469762083, 0, 0, 0, 713098184, 0, 0, 0, 469762055, 0, 0, 0, 704709584, 0, 0, 0, 1744830464, 0, 0, 0, 713098193, 0, 0, 0, 939524100, 0, 0, 0, 218170368, 0, 0, 0, 603979816, 0, 0, 0, 218170369, 0, 0, 0, 603979816, 0, 0, 0, 218170370, 0, 0, 0, 603979816, 0, 0, 0, 218170371, 0, 0, 0, 603979816, 0, 0, 0, 218170372, 0, 0, 0, 603979816, 0, 0, 0, 218170373, 0, 0, 0, 603979816, 0, 0, 0, 218170374, 0, 0, 0, 603979816, 0, 0, 0, 218170375, 0, 0, 0, 603979816, 0, 0, 0, 218170376, 0, 0, 0, 603979816, 0, 0, 0, 218170377, 0, 0, 0, 603979816, 0, 0, 0, 218170378, 0, 0, 0, 603979816, 0, 0, 0, 218170379, 0, 0, 0, 603979816, 0, 0, 0, 218170380, 0, 0, 0, 603979816, 0, 0, 0, 218170381, 0, 0, 0, 603979816, 0, 0, 0, 218170382, 0, 0, 0, 603979816, 0, 0, 0, 218170383, 0, 0, 0, 603979816, 0, 0, 0, 218170384, 0, 0, 0, 603979816, 0, 0, 0, 218170385, 0, 0, 0, 603979816, 0, 0, 0, 218170386, 0, 0, 0, 603979816, 0, 0, 0, 218170387, 0, 0, 0, 603979816, 0, 0, 0, 218170388, 0, 0, 0, 603979816, 0, 0, 0, 218170389, 0, 0, 0, 603979816, 0, 0, 0, 218170390, 0, 0, 0, 603979816, 0, 0, 0, 218170391, 0, 0, 0, 603979816, 0, 0, 0, 218170392, 0, 0, 0, 603979816, 0, 0, 0, 218170393, 0, 0, 0, 603979816, 0, 0, 0, 218170394, 0, 0, 0, 603979816, 0, 0, 0, 218170395, 0, 0, 0, 603979816, 0, 0, 0, 218170396, 0, 0, 0, 603979816, 0, 0, 0, 218170397, 0, 0, 0, 603979816, 0, 0, 0, 218170398, 0, 0, 0, 603979816, 0, 0, 0, 218170399, 0, 0, 0, 603979816, 0, 0, 0, 218170400, 0, 0, 0, 603979816, 0, 0, 0, 218170401, 0, 0, 0, 603979816, 0, 0, 0, 218170402, 0, 0, 0, 603979816, 0, 0, 0, 218170403, 0, 0, 0, 603979816, 0, 0, 0, 218170404, 0, 0, 0, 603979816, 0, 0, 0, 218170405, 0, 0, 0, 603979816, 0, 0, 0, 218170406, 0, 0, 0, 603979816, 0, 0, 0, 218170407, 0, 0, 0, 603979816, 0, 0, 0, 218170408, 0, 0, 0, 335609816, 0, 0, 0, 218170409, 0, 0, 0, 335609816, 0, 0, 0, 218170410, 0, 0, 0, 335609816, 0, 0, 0, 218170411, 0, 0, 0, 335609816, 0, 0, 0, 218170412, 0, 0, 0, 335609816, 0, 0, 0, 218170413, 0, 0, 0, 335609816, 0, 0, 0, 218170414, 0, 0, 0, 335609816, 0, 0, 0, 218170415, 0, 0, 0, 335609816, 0, 0, 0, 218170416, 0, 0, 0, 335609816, 0, 0, 0, 218170417, 0, 0, 0, 335609816, 0, 0, 0, 218170418, 0, 0, 0, 335609816, 0, 0, 0, 218170419, 0, 0, 0, 335609816, 0, 0, 0, 218170420, 0, 0, 0, 335609816, 0, 0, 0, 218170421, 0, 0, 0, 335609816, 0, 0, 0, 218170422, 0, 0, 0, 335609816, 0, 0, 0, 218170423, 0, 0, 0, 335609816, 0, 0, 0, 218170424, 0, 0, 0, 335609816, 0, 0, 0, 218170425, 0, 0, 0, 335609816, 0, 0, 0, 218170426, 0, 0, 0, 335609816, 0, 0, 0, 218170427, 0, 0, 0, 335609816, 0, 0, 0, 218170428, 0, 0, 0, 335609816, 0, 0, 0, 218170429, 0, 0, 0, 335609816, 0, 0, 0, 218170430, 0, 0, 0, 335609816, 0, 0, 0, 218170431, 0, 0, 0, 335609816, 0, 0, 0, 218170432, 0, 0, 0, 335609816, 0, 0, 0, 218170433, 0, 0, 0, 335609816, 0, 0, 0, 218170434, 0, 0, 0, 335609816, 0, 0, 0, 218170435, 0, 0, 0, 335609816, 0, 0, 0, 218170436, 0, 0, 0, 335609816, 0, 0, 0, 218170437, 0, 0, 0, 335609816, 0, 0, 0, 218170438, 0, 0, 0, 335609816, 0, 0, 0, 218170439, 0, 0, 0, 335609816, 0, 0, 0, 218170440, 0, 0, 0, 335609816, 0, 0, 0, 218170441, 0, 0, 0, 335609816, 0, 0, 0, 218170442, 0, 0, 0, 335609816, 0, 0, 0, 218170443, 0, 0, 0, 335609816, 0, 0, 0, 218170444, 0, 0, 0, 335609816, 0, 0, 0, 218170445, 0, 0, 0, 335609816, 0, 0, 0, 218170446, 0, 0, 0, 335609816, 0, 0, 0, 218170447, 0, 0, 0, 335609816, 0, 0, 0, 780207184, 0, 0, 0, 469762125, 0, 0, 0, 746652832, 0, 0, 0, 872415241, 0, 0, 0, 193005568, 0, 0, 0, 469762053, 0, 0, 0, 184616968, 0, 0, 0, 469762048, 0, 0, 0, 193005578, 0, 0, 0, 469762091, 0, 0, 0, 193005623, 0, 0, 0, 469762049, 0, 0, 0, 184617020, 0, 0, 0, 469762048, 0, 0, 0, 184617023, 0, 0, 0, 469762048, 0, 0, 0, 503384576, 0, 0, 0, 469762048, 0, 0, 0, 511773185, 0, 0, 0, 805306370, 0, 0, 0, 511773189, 0, 0, 0, 805306369, 0, 0, 0, 511773196, 0, 0, 0, 805306371, 0, 0, 0, 511773200, 0, 0, 0, 469762051, 0, 0, 0, 511773205, 0, 0, 0, 469762050, 0, 0, 0, 511773209, 0, 0, 0, 469762074, 0, 0, 0, 511773240, 0, 0, 0, 805306370, 0, 0, 0, 503384639, 0, 0, 0, 805306368, 0, 0, 0, 511773248, 0, 0, 0, 1006632967, 0, 0, 0, 511773264, 0, 0, 0, 1409286152, 0, 0, 0, 159502336, 0, 0, 0, 1744830709, 0, 0, 0, 159502592, 0, 0, 0, 1744830502, 0, 0, 0, 159502634, 0, 0, 0, 1744830522, 0, 0, 0, 159502693, 0, 0, 0, 671088641, 0, 0, 0, 461492583, 0, 0, 0, 805306370, 0, 0, 0, 159502698, 0, 0, 0, 1744830466, 0, 0, 0, 159502701, 0, 0, 0, 671088645, 0, 0, 0, 159502707, 0, 0, 0, 67108871, 0, 0, 0, 461492603, 0, 0, 0, 805306375, 0, 0, 0, 159502723, 0, 0, 0, 1744830465, 0, 0, 0, 461492613, 0, 0, 0, 805306374, 0, 0, 0, 159502732, 0, 0, 0, 1744830493, 0, 0, 0, 461492650, 0, 0, 0, 805306371, 0, 0, 0, 159502766, 0, 0, 0, 1744830511, 0, 0, 0, 327275008, 0, 0, 0, 1744830529, 0, 0, 0, 327275074, 0, 0, 0, 805306370, 0, 0, 0, 318886469, 0, 0, 0, 1744830464, 0, 0, 0, 159503104, 0, 0, 0, 1744830550, 0, 0, 0, 159503360, 0, 0, 0, 603979801, 0, 0, 0, 159503386, 0, 0, 0, 335544345, 0, 0, 0, 159503412, 0, 0, 0, 603979801, 0, 0, 0, 159503438, 0, 0, 0, 335544326, 0, 0, 0, 159503446, 0, 0, 0, 335544337, 0, 0, 0, 159503464, 0, 0, 0, 603979801, 0, 0, 0, 159503490, 0, 0, 0, 335544345, 0, 0, 0, 151114908, 0, 0, 0, 603979776, 0, 0, 0, 159503518, 0, 0, 0, 603979777, 0, 0, 0, 151114914, 0, 0, 0, 603979776, 0, 0, 0, 159503525, 0, 0, 0, 603979777, 0, 0, 0, 159503529, 0, 0, 0, 603979779, 0, 0, 0, 159503534, 0, 0, 0, 603979783, 0, 0, 0, 159503542, 0, 0, 0, 335544323, 0, 0, 0, 151114939, 0, 0, 0, 335544320, 0, 0, 0, 159503549, 0, 0, 0, 335544326, 0, 0, 0, 159503557, 0, 0, 0, 335544330, 0, 0, 0, 159503568, 0, 0, 0, 603979801, 0, 0, 0, 159503594, 0, 0, 0, 335544345, 0, 0, 0, 159503620, 0, 0, 0, 603979777, 0, 0, 0, 159503623, 0, 0, 0, 603979779, 0, 0, 0, 159503629, 0, 0, 0, 603979783, 0, 0, 0, 159503638, 0, 0, 0, 603979782, 0, 0, 0, 159503646, 0, 0, 0, 335544345, 0, 0, 0, 159503672, 0, 0, 0, 603979777, 0, 0, 0, 159503675, 0, 0, 0, 603979779, 0, 0, 0, 159503680, 0, 0, 0, 603979780, 0, 0, 0, 151115078, 0, 0, 0, 603979776, 0, 0, 0, 159503690, 0, 0, 0, 603979782, 0, 0, 0, 159503698, 0, 0, 0, 335544345, 0, 0, 0, 159503724, 0, 0, 0, 603979801, 0, 0, 0, 159503750, 0, 0, 0, 335544345, 0, 0, 0, 159503776, 0, 0, 0, 603979801, 0, 0, 0, 159503802, 0, 0, 0, 335544345, 0, 0, 0, 159503828, 0, 0, 0, 603979801, 0, 0, 0, 159503854, 0, 0, 0, 335544345, 0, 0, 0, 159503880, 0, 0, 0, 603979801, 0, 0, 0, 159503906, 0, 0, 0, 335544345, 0, 0, 0, 159503932, 0, 0, 0, 603979801, 0, 0, 0, 159503958, 0, 0, 0, 335544345, 0, 0, 0, 159503984, 0, 0, 0, 603979801, 0, 0, 0, 159504010, 0, 0, 0, 335544347, 0, 0, 0, 159504040, 0, 0, 0, 603979800, 0, 0, 0, 151115457, 0, 0, 0, 1677721600, 0, 0, 0, 159504066, 0, 0, 0, 335544344, 0, 0, 0, 151115483, 0, 0, 0, 1677721600, 0, 0, 0, 159504092, 0, 0, 0, 335544325, 0, 0, 0, 159504098, 0, 0, 0, 603979800, 0, 0, 0, 151115515, 0, 0, 0, 1677721600, 0, 0, 0, 159504124, 0, 0, 0, 335544344, 0, 0, 0, 151115541, 0, 0, 0, 1677721600, 0, 0, 0, 159504150, 0, 0, 0, 335544325, 0, 0, 0, 159504156, 0, 0, 0, 603979800, 0, 0, 0, 151115573, 0, 0, 0, 1677721600, 0, 0, 0, 159504182, 0, 0, 0, 335544344, 0, 0, 0, 151115599, 0, 0, 0, 1677721600, 0, 0, 0, 159504208, 0, 0, 0, 335544325, 0, 0, 0, 159504214, 0, 0, 0, 603979800, 0, 0, 0, 151115631, 0, 0, 0, 1677721600, 0, 0, 0, 159504240, 0, 0, 0, 335544344, 0, 0, 0, 151115657, 0, 0, 0, 1677721600, 0, 0, 0, 159504266, 0, 0, 0, 335544325, 0, 0, 0, 159504272, 0, 0, 0, 603979800, 0, 0, 0, 151115689, 0, 0, 0, 1677721600, 0, 0, 0, 159504298, 0, 0, 0, 335544344, 0, 0, 0, 151115715, 0, 0, 0, 1677721600, 0, 0, 0, 159504324, 0, 0, 0, 335544325, 0, 0, 0, 159504334, 0, 0, 0, 872415281, 0, 0, 0, 377618432, 0, 0, 0, 469804758, 0, 0, 0, 377681920, 0, 0, 0, 469762589, 0, 0, 0, 151912449, 0, 0, 0, 67108864, 0, 0, 0, 160301088, 0, 0, 0, 67108959, 0, 0, 0, 462291200, 0, 0, 0, 805306607, 0, 0, 0, 160366592, 0, 0, 0, 201392125, 0, 0, 0, 160432128, 0, 0, 0, 201392125, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str4498 = allocate([ 37, 100, 0 ], "i8", ALLOC_STATIC);

__ZL9gCanceled = allocate(1, "i8", ALLOC_STATIC);

__ZL14enableTraceJit_b = allocate(1, "i1", ALLOC_STATIC);

__ZL15enableMethodJit_b = allocate(1, "i1", ALLOC_STATIC);

__ZL19enableTypeInference = allocate(1, "i8", ALLOC_STATIC);

__ZL22enableDisassemblyDumps_b = allocate(1, "i1", ALLOC_STATIC);

__ZL11printTiming_b = allocate(1, "i1", ALLOC_STATIC);

__ZL8gRuntime = allocate(1, "%struct.JSRuntime*", ALLOC_STATIC);

_gExitCode = allocate(1, "i32", ALLOC_STATIC);

_gQuitting_b = allocate(1, "i1", ALLOC_STATIC);

_gErrFile = allocate(1, "%struct.__sFILE*", ALLOC_STATIC);

_gOutFile = allocate(1, "%struct.__sFILE*", ALLOC_STATIC);

STRING_TABLE.__str293 = allocate([ 101, 118, 97, 108, 45, 99, 111, 100, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1294 = allocate([ 103, 108, 111, 98, 97, 108, 45, 99, 111, 100, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2295 = allocate([ 115, 97, 110, 100, 98, 111, 120, 0 ], "i8", ALLOC_STATIC);

__ZL13sandbox_class = allocate([ 0, 0, 0, 0, 292612, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 1972, 0, 0, 0, 1974, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str3296 = allocate([ 114, 101, 115, 111, 108, 118, 101, 114, 0 ], "i8", ALLOC_STATIC);

__ZL14resolver_class = allocate([ 0, 0, 0, 0, 260, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 1976, 0, 0, 0, 1978, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str4297 = allocate([ 100, 101, 115, 101, 114, 105, 97, 108, 105, 122, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str5298 = allocate([ 110, 101, 119, 71, 108, 111, 98, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str6299 = allocate([ 115, 97, 109, 101, 45, 99, 111, 109, 112, 97, 114, 116, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str7300 = allocate([ 110, 101, 119, 45, 99, 111, 109, 112, 97, 114, 116, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str8301 = allocate([ 118, 101, 114, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str9302 = allocate([ 114, 101, 118, 101, 114, 116, 86, 101, 114, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str10303 = allocate([ 111, 112, 116, 105, 111, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str11304 = allocate([ 108, 111, 97, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str12305 = allocate([ 101, 118, 97, 108, 117, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str13306 = allocate([ 114, 117, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str14307 = allocate([ 114, 101, 97, 100, 108, 105, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str15308 = allocate([ 112, 114, 105, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str16309 = allocate([ 112, 117, 116, 115, 116, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str17310 = allocate([ 100, 97, 116, 101, 78, 111, 119, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str18311 = allocate([ 104, 101, 108, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str19312 = allocate([ 113, 117, 105, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str20313 = allocate([ 97, 115, 115, 101, 114, 116, 69, 113, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str21314 = allocate([ 97, 115, 115, 101, 114, 116, 74, 105, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str22315 = allocate([ 103, 99, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str23316 = allocate([ 103, 99, 112, 97, 114, 97, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str24317 = allocate([ 99, 111, 117, 110, 116, 72, 101, 97, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str25318 = allocate([ 109, 97, 107, 101, 70, 105, 110, 97, 108, 105, 122, 101, 79, 98, 115, 101, 114, 118, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str26319 = allocate([ 102, 105, 110, 97, 108, 105, 122, 101, 67, 111, 117, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str27320 = allocate([ 105, 110, 116, 101, 114, 110, 97, 108, 67, 111, 110, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str28321 = allocate([ 115, 101, 116, 68, 101, 98, 117, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str29322 = allocate([ 115, 101, 116, 68, 101, 98, 117, 103, 103, 101, 114, 72, 97, 110, 100, 108, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str30323 = allocate([ 115, 101, 116, 84, 104, 114, 111, 119, 72, 111, 111, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str31324 = allocate([ 116, 114, 97, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str32325 = allocate([ 117, 110, 116, 114, 97, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str33326 = allocate([ 108, 105, 110, 101, 50, 112, 99, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str34327 = allocate([ 112, 99, 50, 108, 105, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str35328 = allocate([ 115, 116, 114, 105, 110, 103, 115, 65, 114, 101, 85, 84, 70, 56, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str36329 = allocate([ 116, 101, 115, 116, 85, 84, 70, 56, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str37330 = allocate([ 116, 104, 114, 111, 119, 69, 114, 114, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str38331 = allocate([ 100, 117, 109, 112, 83, 116, 97, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str39332 = allocate([ 98, 117, 105, 108, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str40333 = allocate([ 99, 108, 101, 97, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str41334 = allocate([ 105, 110, 116, 101, 114, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str42335 = allocate([ 99, 108, 111, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str43336 = allocate([ 103, 101, 116, 112, 100, 97, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str44337 = allocate([ 103, 101, 116, 115, 108, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str45338 = allocate([ 116, 111, 105, 110, 116, 51, 50, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str46339 = allocate([ 101, 118, 97, 108, 99, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str47340 = allocate([ 101, 118, 97, 108, 73, 110, 70, 114, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str48341 = allocate([ 115, 104, 97, 112, 101, 79, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str49342 = allocate([ 115, 110, 97, 114, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str50343 = allocate([ 114, 101, 97, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str51344 = allocate([ 99, 111, 109, 112, 105, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str52345 = allocate([ 112, 97, 114, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str53346 = allocate([ 116, 105, 109, 101, 111, 117, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str54347 = allocate([ 101, 108, 97, 112, 115, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str55348 = allocate([ 112, 97, 114, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str56349 = allocate([ 119, 114, 97, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str57350 = allocate([ 115, 101, 114, 105, 97, 108, 105, 122, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str58351 = allocate([ 115, 116, 114, 105, 110, 103, 115, 116, 97, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str59352 = allocate([ 112, 97, 114, 115, 101, 76, 101, 103, 97, 99, 121, 74, 83, 79, 78, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str60353 = allocate([ 101, 110, 97, 98, 108, 101, 83, 116, 97, 99, 107, 87, 97, 108, 107, 105, 110, 103, 65, 115, 115, 101, 114, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str61354 = allocate([ 103, 101, 116, 77, 97, 120, 65, 114, 103, 115, 0 ], "i8", ALLOC_STATIC);

__ZL15shell_functions = allocate([ 0, 0, 0, 0, 1980, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1982, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1984, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1986, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1988, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1990, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1992, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1994, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1996, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1998, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 2e3, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 2002, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 2004, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 2006, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 2008, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 2010, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 2012, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 2014, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 2016, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 2018, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2020, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2022, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2024, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2026, 0, 0, 0, 3, 0, 4096, 0, 0, 0, 0, 0, 2028, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 2030, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 2032, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 2034, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 2036, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2038, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 2040, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2042, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 2044, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 2046, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2048, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2050, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2052, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2054, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2056, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2058, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 2060, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2062, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2064, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 2064, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 2066, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2068, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2070, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2072, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 2074, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2076, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2078, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2080, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2082, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 2084, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2086, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2088, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 2090, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str62355 = allocate([ 99, 111, 108, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str63356 = allocate([ 104, 101, 105, 103, 104, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str64357 = allocate([ 119, 105, 100, 116, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str65358 = allocate([ 102, 117, 110, 110, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str66359 = allocate([ 97, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str67360 = allocate([ 114, 100, 111, 110, 108, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str68361 = allocate([ 99, 117, 115, 116, 111, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str69362 = allocate([ 99, 117, 115, 116, 111, 109, 82, 100, 79, 110, 108, 121, 0 ], "i8", ALLOC_STATIC);

__ZL9its_props = allocate([ 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 1, 0, 0, 288, 0, 0, 0, 290, 0, 0, 0, 0, 0, 0, 0, 7, 3, 0, 0, 288, 0, 0, 0, 290, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str70363 = allocate([ 73, 116, 0 ], "i8", ALLOC_STATIC);

__ZL9its_class = allocate([ 0, 0, 0, 0, 7, 0, 0, 0, 2092, 0, 0, 0, 2094, 0, 0, 0, 2096, 0, 0, 0, 2098, 0, 0, 0, 2100, 0, 0, 0, 2102, 0, 0, 0, 2104, 0, 0, 0, 2106, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str71364 = allocate([ 60, 69, 114, 114, 111, 114, 32, 35, 48, 32, 105, 115, 32, 114, 101, 115, 101, 114, 118, 101, 100, 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str72365 = allocate([ 99, 97, 110, 39, 116, 32, 111, 112, 101, 110, 32, 123, 48, 125, 58, 32, 123, 49, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str73366 = allocate([ 117, 115, 97, 103, 101, 58, 32, 116, 114, 97, 112, 32, 91, 102, 117, 110, 93, 32, 91, 112, 99, 93, 32, 101, 120, 112, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str74367 = allocate([ 117, 115, 97, 103, 101, 58, 32, 108, 105, 110, 101, 50, 112, 99, 32, 91, 102, 117, 110, 93, 32, 108, 105, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str75368 = allocate([ 111, 110, 108, 121, 32, 119, 111, 114, 107, 115, 32, 111, 110, 32, 74, 83, 32, 115, 99, 114, 105, 112, 116, 115, 32, 114, 101, 97, 100, 32, 102, 114, 111, 109, 32, 102, 105, 108, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str76369 = allocate([ 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 69, 79, 70, 32, 105, 110, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str77370 = allocate([ 117, 115, 97, 103, 101, 58, 32, 100, 111, 101, 120, 112, 32, 111, 98, 106, 32, 105, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str78371 = allocate([ 111, 110, 108, 121, 32, 119, 111, 114, 107, 115, 32, 111, 110, 32, 115, 99, 114, 105, 112, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str79372 = allocate([ 123, 48, 125, 58, 32, 110, 111, 116, 32, 101, 110, 111, 117, 103, 104, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str80373 = allocate([ 123, 48, 125, 58, 32, 116, 111, 111, 32, 109, 97, 110, 121, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str81374 = allocate([ 65, 115, 115, 101, 114, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 58, 32, 103, 111, 116, 32, 123, 48, 125, 44, 32, 101, 120, 112, 101, 99, 116, 101, 100, 32, 123, 49, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str82375 = allocate([ 65, 115, 115, 101, 114, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 58, 32, 103, 111, 116, 32, 123, 48, 125, 44, 32, 101, 120, 112, 101, 99, 116, 101, 100, 32, 123, 49, 125, 58, 32, 123, 50, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str83376 = allocate([ 123, 48, 125, 58, 32, 105, 110, 118, 97, 108, 105, 100, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str84377 = allocate([ 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 102, 97, 105, 108, 117, 114, 101, 32, 116, 111, 32, 74, 73, 84, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str85378 = allocate([ 115, 101, 114, 105, 97, 108, 105, 122, 101, 100, 32, 100, 97, 116, 97, 32, 109, 117, 115, 116, 32, 98, 101, 32, 56, 45, 98, 121, 116, 101, 45, 97, 108, 105, 103, 110, 101, 100, 0 ], "i8", ALLOC_STATIC);

_jsShell_ErrorFormatString = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str86379 = allocate([ 103, 108, 111, 98, 97, 108, 0 ], "i8", ALLOC_STATIC);

_global_class = allocate([ 0, 0, 0, 0, 292613, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 2108, 0, 0, 0, 2110, 0, 0, 0, 86, 0, 0, 0, 2106, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str87380 = allocate([ 101, 110, 118, 105, 114, 111, 110, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

__ZL9env_class = allocate([ 0, 0, 0, 0, 5, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 2112, 0, 0, 0, 2114, 0, 0, 0, 2116, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str88381 = allocate([ 91, 115, 104, 101, 108, 108, 32, 116, 114, 117, 115, 116, 101, 100, 32, 112, 114, 105, 110, 99, 105, 112, 97, 108, 115, 93, 0 ], "i8", ALLOC_STATIC);

_shellTrustedPrincipals = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 2118, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

_securityCallbacks = allocate([ 2120, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str90383 = allocate([ 74, 83, 95, 83, 84, 68, 69, 82, 82, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str91384 = allocate([ 74, 83, 95, 83, 84, 68, 79, 85, 84, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str92385 = allocate([ 85, 115, 97, 103, 101, 58, 32, 123, 112, 114, 111, 103, 110, 97, 109, 101, 125, 32, 91, 111, 112, 116, 105, 111, 110, 115, 93, 32, 91, 91, 115, 99, 114, 105, 112, 116, 93, 32, 115, 99, 114, 105, 112, 116, 65, 114, 103, 115, 42, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str93386 = allocate([ 84, 104, 101, 32, 83, 112, 105, 100, 101, 114, 77, 111, 110, 107, 101, 121, 32, 115, 104, 101, 108, 108, 32, 112, 114, 111, 118, 105, 100, 101, 115, 32, 97, 32, 99, 111, 109, 109, 97, 110, 100, 32, 108, 105, 110, 101, 32, 105, 110, 116, 101, 114, 102, 97, 99, 101, 32, 116, 111, 32, 116, 104, 101, 32, 74, 97, 118, 97, 83, 99, 114, 105, 112, 116, 32, 101, 110, 103, 105, 110, 101, 46, 32, 67, 111, 100, 101, 32, 97, 110, 100, 32, 102, 105, 108, 101, 32, 111, 112, 116, 105, 111, 110, 115, 32, 112, 114, 111, 118, 105, 100, 101, 100, 32, 118, 105, 97, 32, 116, 104, 101, 32, 99, 111, 109, 109, 97, 110, 100, 32, 108, 105, 110, 101, 32, 97, 114, 101, 32, 114, 117, 110, 32, 108, 101, 102, 116, 32, 116, 111, 32, 114, 105, 103, 104, 116, 46, 32, 73, 102, 32, 112, 114, 111, 118, 105, 100, 101, 100, 44, 32, 116, 104, 101, 32, 111, 112, 116, 105, 111, 110, 97, 108, 32, 115, 99, 114, 105, 112, 116, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 105, 115, 32, 114, 117, 110, 32, 97, 102, 116, 101, 114, 32, 97, 108, 108, 32, 111, 112, 116, 105, 111, 110, 115, 32, 104, 97, 118, 101, 32, 98, 101, 101, 110, 32, 112, 114, 111, 99, 101, 115, 115, 101, 100, 46, 32, 74, 117, 115, 116, 45, 73, 110, 45, 84, 105, 109, 101, 32, 99, 111, 109, 112, 105, 108, 97, 116, 105, 111, 110, 32, 109, 111, 100, 101, 115, 32, 109, 97, 121, 32, 98, 101, 32, 101, 110, 97, 98, 108, 101, 100, 32, 118, 105, 97, 32, 99, 111, 109, 109, 97, 110, 100, 32, 108, 105, 110, 101, 32, 111, 112, 116, 105, 111, 110, 115, 46, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str94387 = allocate([ 102, 105, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str95388 = allocate([ 80, 65, 84, 72, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str96389 = allocate([ 70, 105, 108, 101, 32, 112, 97, 116, 104, 32, 116, 111, 32, 114, 117, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str97390 = allocate([ 101, 120, 101, 99, 117, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str98391 = allocate([ 67, 79, 68, 69, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str99392 = allocate([ 73, 110, 108, 105, 110, 101, 32, 99, 111, 100, 101, 32, 116, 111, 32, 114, 117, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str100393 = allocate([ 115, 104, 101, 108, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str101394 = allocate([ 69, 110, 116, 101, 114, 32, 112, 114, 111, 109, 112, 116, 32, 97, 102, 116, 101, 114, 32, 114, 117, 110, 110, 105, 110, 103, 32, 99, 111, 100, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str102395 = allocate([ 109, 101, 116, 104, 111, 100, 106, 105, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str103396 = allocate([ 69, 110, 97, 98, 108, 101, 32, 116, 104, 101, 32, 74, 97, 101, 103, 101, 114, 77, 111, 110, 107, 101, 121, 32, 109, 101, 116, 104, 111, 100, 32, 74, 73, 84, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str104397 = allocate([ 116, 114, 97, 99, 101, 106, 105, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str105398 = allocate([ 69, 110, 97, 98, 108, 101, 32, 116, 104, 101, 32, 74, 97, 101, 103, 101, 114, 77, 111, 110, 107, 101, 121, 32, 116, 114, 97, 99, 101, 32, 74, 73, 84, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str106399 = allocate([ 112, 114, 111, 102, 105, 108, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str107400 = allocate([ 69, 110, 97, 98, 108, 101, 32, 114, 117, 110, 116, 105, 109, 101, 32, 112, 114, 111, 102, 105, 108, 105, 110, 103, 32, 115, 101, 108, 101, 99, 116, 32, 74, 73, 84, 32, 109, 111, 100, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str108401 = allocate([ 116, 121, 112, 101, 105, 110, 102, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str109402 = allocate([ 69, 110, 97, 98, 108, 101, 32, 116, 121, 112, 101, 32, 105, 110, 102, 101, 114, 101, 110, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str110403 = allocate([ 100, 101, 98, 117, 103, 106, 105, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str111404 = allocate([ 69, 110, 97, 98, 108, 101, 32, 114, 117, 110, 116, 105, 109, 101, 32, 100, 101, 98, 117, 103, 32, 109, 111, 100, 101, 32, 102, 111, 114, 32, 109, 101, 116, 104, 111, 100, 32, 74, 73, 84, 32, 99, 111, 100, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str112405 = allocate([ 97, 108, 119, 97, 121, 115, 45, 109, 106, 105, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str113406 = allocate([ 68, 111, 32, 110, 111, 116, 32, 116, 114, 121, 32, 116, 111, 32, 114, 117, 110, 32, 105, 110, 32, 116, 104, 101, 32, 105, 110, 116, 101, 114, 112, 114, 101, 116, 101, 114, 32, 98, 101, 102, 111, 114, 101, 32, 109, 101, 116, 104, 111, 100, 32, 106, 105, 116, 116, 105, 110, 103, 46, 32, 78, 111, 116, 101, 32, 116, 104, 97, 116, 32, 116, 104, 105, 115, 32, 104, 97, 115, 32, 110, 111, 32, 112, 97, 114, 116, 105, 99, 117, 108, 97, 114, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 116, 104, 101, 32, 116, 114, 97, 99, 101, 114, 59, 32, 105, 116, 32, 115, 116, 105, 108, 108, 32, 107, 105, 99, 107, 115, 32, 105, 110, 32, 105, 102, 32, 101, 110, 97, 98, 108, 101, 100, 46, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str114407 = allocate([ 100, 117, 109, 112, 45, 98, 121, 116, 101, 99, 111, 100, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str115408 = allocate([ 68, 117, 109, 112, 32, 98, 121, 116, 101, 99, 111, 100, 101, 32, 119, 105, 116, 104, 32, 101, 120, 101, 99, 32, 99, 111, 117, 110, 116, 32, 102, 111, 114, 32, 97, 108, 108, 32, 115, 99, 114, 105, 112, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str116409 = allocate([ 112, 114, 105, 110, 116, 45, 116, 105, 109, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str117410 = allocate([ 80, 114, 105, 110, 116, 32, 115, 117, 98, 45, 109, 115, 32, 114, 117, 110, 116, 105, 109, 101, 32, 102, 111, 114, 32, 101, 97, 99, 104, 32, 102, 105, 108, 101, 32, 116, 104, 97, 116, 39, 115, 32, 114, 117, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str118411 = allocate([ 117, 116, 102, 56, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str119412 = allocate([ 67, 32, 115, 116, 114, 105, 110, 103, 115, 32, 112, 97, 115, 115, 101, 100, 32, 116, 111, 32, 116, 104, 101, 32, 74, 83, 65, 80, 73, 32, 97, 114, 101, 32, 85, 84, 70, 45, 56, 32, 101, 110, 99, 111, 100, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str120413 = allocate([ 115, 99, 114, 105, 112, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str121414 = allocate([ 65, 32, 115, 99, 114, 105, 112, 116, 32, 116, 111, 32, 101, 120, 101, 99, 117, 116, 101, 32, 40, 97, 102, 116, 101, 114, 32, 97, 108, 108, 32, 111, 112, 116, 105, 111, 110, 115, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str122415 = allocate([ 115, 99, 114, 105, 112, 116, 65, 114, 103, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str123416 = allocate([ 83, 116, 114, 105, 110, 103, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 32, 116, 111, 32, 98, 105, 110, 100, 32, 97, 115, 32, 124, 97, 114, 103, 117, 109, 101, 110, 116, 115, 124, 32, 105, 110, 32, 116, 104, 101, 32, 115, 104, 101, 108, 108, 39, 115, 32, 103, 108, 111, 98, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL15CancelExecutionP9JSRuntimeE3msg = allocate([ 83, 99, 114, 105, 112, 116, 32, 114, 117, 110, 115, 32, 102, 111, 114, 32, 116, 111, 111, 32, 108, 111, 110, 103, 44, 32, 116, 101, 114, 109, 105, 110, 97, 116, 105, 110, 103, 46, 10, 0 ], "i8", ALLOC_STATIC);

__ZL16gTimeoutInterval = allocate([ -1 ], [ "double", 0, 0, 0, 0, 0, 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str124417 = allocate([ 37, 115, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str125418 = allocate([ 37, 115, 58, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str126419 = allocate([ 37, 115, 37, 117, 58, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str127420 = allocate([ 37, 115, 37, 115, 119, 97, 114, 110, 105, 110, 103, 58, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str128421 = allocate([ 115, 116, 114, 105, 99, 116, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str129422 = allocate([ 58, 10, 37, 115, 37, 115, 37, 115, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str130423 = allocate([ 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str131424 = allocate([ 94, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str132425 = allocate([ 68, 105, 115, 112, 108, 97, 121, 32, 104, 101, 108, 112, 32, 105, 110, 102, 111, 114, 109, 97, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

__ZTVN2js3cli6detail10BoolOptionE = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 2122, 0, 0, 0, 2124, 0, 0, 0, 2126, 0, 0, 0, 2128, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTVN2js3cli6detail6OptionE = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 444, 0, 0, 0, 444, 0, 0, 0, 2126, 0, 0, 0, 2128, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

STRING_TABLE.__str133426 = allocate([ 119, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str134427 = allocate([ 45, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str135428 = allocate([ 45, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str136429 = allocate([ 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str137430 = allocate([ 114, 117, 110, 116, 105, 109, 101, 32, 61, 32, 37, 46, 51, 102, 32, 109, 115, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str138431 = allocate([ 106, 115, 62, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str139432 = allocate([ 73, 110, 118, 97, 108, 105, 100, 32, 85, 84, 70, 45, 56, 32, 105, 110, 32, 105, 110, 112, 117, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str140433 = allocate([ 116, 121, 112, 101, 105, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str142435 = allocate([ 97, 114, 103, 117, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str143436 = allocate([ 105, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str144437 = allocate([ 40, 101, 114, 114, 111, 114, 32, 99, 111, 110, 118, 101, 114, 116, 105, 110, 103, 32, 118, 97, 108, 117, 101, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str145438 = allocate([ 86, 97, 108, 117, 101, 32, 84, 111, 83, 116, 114, 105, 110, 103, 32, 104, 101, 108, 112, 101, 114, 0 ], "i8", ALLOC_STATIC);

__ZZL13env_enumerateP9JSContextP8JSObjectE9reflected_b = allocate(1, "i1", ALLOC_STATIC);

STRING_TABLE.__str146439 = allocate([ 99, 97, 110, 39, 116, 32, 115, 101, 116, 32, 101, 110, 118, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 37, 115, 32, 116, 111, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

__ZL9its_noisy = allocate(1, "i32", ALLOC_STATIC);

STRING_TABLE.__str147440 = allocate([ 102, 105, 110, 97, 108, 105, 122, 105, 110, 103, 32, 105, 116, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str148441 = allocate([ 99, 111, 110, 118, 101, 114, 116, 105, 110, 103, 32, 105, 116, 32, 116, 111, 32, 37, 115, 32, 116, 121, 112, 101, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str149442 = allocate([ 114, 101, 115, 111, 108, 118, 105, 110, 103, 32, 105, 116, 115, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 37, 115, 44, 32, 102, 108, 97, 103, 115, 32, 123, 37, 115, 44, 37, 115, 44, 37, 115, 125, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str150443 = allocate([ 113, 117, 97, 108, 105, 102, 105, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str151444 = allocate([ 97, 115, 115, 105, 103, 110, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str152445 = allocate([ 100, 101, 116, 101, 99, 116, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str153446 = allocate([ 101, 110, 117, 109, 101, 114, 97, 116, 101, 32, 105, 116, 115, 32, 112, 114, 111, 112, 101, 114, 116, 105, 101, 115, 10, 0 ], "i8", ALLOC_STATIC);

__ZL13its_enum_fail = allocate(1, "i32", ALLOC_STATIC);

STRING_TABLE.__str154447 = allocate([ 105, 116, 115, 32, 101, 110, 117, 109, 101, 114, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str155448 = allocate([ 115, 101, 116, 116, 105, 110, 103, 32, 105, 116, 115, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 37, 115, 44, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str156449 = allocate([ 32, 110, 101, 119, 32, 118, 97, 108, 117, 101, 32, 37, 115, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str157450 = allocate([ 110, 111, 105, 115, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str158451 = allocate([ 101, 110, 117, 109, 95, 102, 97, 105, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str159452 = allocate([ 103, 101, 116, 116, 105, 110, 103, 32, 105, 116, 115, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 37, 115, 44, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str160453 = allocate([ 32, 105, 110, 105, 116, 105, 97, 108, 32, 118, 97, 108, 117, 101, 32, 37, 115, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str161454 = allocate([ 100, 101, 108, 101, 116, 105, 110, 103, 32, 105, 116, 115, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 37, 115, 44, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str162455 = allocate([ 97, 100, 100, 105, 110, 103, 32, 105, 116, 115, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 37, 115, 44, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL17shell_help_header = allocate([ 67, 111, 109, 109, 97, 110, 100, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 68, 101, 115, 99, 114, 105, 112, 116, 105, 111, 110, 10, 61, 61, 61, 61, 61, 61, 61, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 61, 61, 61, 61, 61, 61, 61, 61, 61, 61, 61, 10, 0 ], "i8", ALLOC_STATIC);

__ZL19shell_help_messages = allocate(228, "*", ALLOC_STATIC);

STRING_TABLE.__str163456 = allocate([ 83, 111, 114, 114, 121, 44, 32, 110, 111, 32, 104, 101, 108, 112, 32, 102, 111, 114, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str164457 = allocate([ 118, 101, 114, 115, 105, 111, 110, 40, 91, 110, 117, 109, 98, 101, 114, 93, 41, 32, 32, 32, 32, 32, 32, 32, 32, 71, 101, 116, 32, 111, 114, 32, 102, 111, 114, 99, 101, 32, 97, 32, 115, 99, 114, 105, 112, 116, 32, 99, 111, 109, 112, 105, 108, 97, 116, 105, 111, 110, 32, 118, 101, 114, 115, 105, 111, 110, 32, 110, 117, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str165458 = allocate([ 114, 101, 118, 101, 114, 116, 86, 101, 114, 115, 105, 111, 110, 40, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 82, 101, 118, 101, 114, 116, 32, 112, 114, 101, 118, 105, 111, 117, 115, 108, 121, 32, 115, 101, 116, 32, 118, 101, 114, 115, 105, 111, 110, 32, 110, 117, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str166459 = allocate([ 111, 112, 116, 105, 111, 110, 115, 40, 91, 111, 112, 116, 105, 111, 110, 32, 46, 46, 46, 93, 41, 32, 32, 32, 32, 71, 101, 116, 32, 111, 114, 32, 116, 111, 103, 103, 108, 101, 32, 74, 97, 118, 97, 83, 99, 114, 105, 112, 116, 32, 111, 112, 116, 105, 111, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str167460 = allocate([ 108, 111, 97, 100, 40, 91, 39, 102, 111, 111, 46, 106, 115, 39, 32, 46, 46, 46, 93, 41, 32, 32, 32, 32, 32, 76, 111, 97, 100, 32, 102, 105, 108, 101, 115, 32, 110, 97, 109, 101, 100, 32, 98, 121, 32, 115, 116, 114, 105, 110, 103, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str168461 = allocate([ 101, 118, 97, 108, 117, 97, 116, 101, 40, 99, 111, 100, 101, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 69, 118, 97, 108, 117, 97, 116, 101, 32, 99, 111, 100, 101, 32, 97, 115, 32, 116, 104, 111, 117, 103, 104, 32, 105, 116, 32, 119, 101, 114, 101, 32, 116, 104, 101, 32, 99, 111, 110, 116, 101, 110, 116, 115, 32, 111, 102, 32, 97, 32, 102, 105, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str169462 = allocate([ 114, 117, 110, 40, 39, 102, 111, 111, 46, 106, 115, 39, 41, 10, 32, 32, 82, 117, 110, 32, 116, 104, 101, 32, 102, 105, 108, 101, 32, 110, 97, 109, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 102, 105, 114, 115, 116, 32, 97, 114, 103, 117, 109, 101, 110, 116, 44, 32, 114, 101, 116, 117, 114, 110, 105, 110, 103, 32, 116, 104, 101, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 10, 32, 32, 111, 102, 32, 109, 105, 108, 108, 105, 115, 101, 99, 111, 110, 100, 115, 32, 115, 112, 101, 110, 116, 32, 99, 111, 109, 112, 105, 108, 105, 110, 103, 32, 97, 110, 100, 32, 101, 120, 101, 99, 117, 116, 105, 110, 103, 32, 105, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str170463 = allocate([ 114, 101, 97, 100, 108, 105, 110, 101, 40, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 82, 101, 97, 100, 32, 97, 32, 115, 105, 110, 103, 108, 101, 32, 108, 105, 110, 101, 32, 102, 114, 111, 109, 32, 115, 116, 100, 105, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str171464 = allocate([ 112, 114, 105, 110, 116, 40, 91, 101, 120, 112, 32, 46, 46, 46, 93, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 69, 118, 97, 108, 117, 97, 116, 101, 32, 97, 110, 100, 32, 112, 114, 105, 110, 116, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str172465 = allocate([ 112, 117, 116, 115, 116, 114, 40, 91, 101, 120, 112, 93, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 69, 118, 97, 108, 117, 97, 116, 101, 32, 97, 110, 100, 32, 112, 114, 105, 110, 116, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 119, 105, 116, 104, 111, 117, 116, 32, 110, 101, 119, 108, 105, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str173466 = allocate([ 100, 97, 116, 101, 78, 111, 119, 40, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 82, 101, 116, 117, 114, 110, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116, 32, 116, 105, 109, 101, 32, 119, 105, 116, 104, 32, 115, 117, 98, 45, 109, 115, 32, 112, 114, 101, 99, 105, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str174467 = allocate([ 104, 101, 108, 112, 40, 91, 110, 97, 109, 101, 32, 46, 46, 46, 93, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 68, 105, 115, 112, 108, 97, 121, 32, 117, 115, 97, 103, 101, 32, 97, 110, 100, 32, 104, 101, 108, 112, 32, 109, 101, 115, 115, 97, 103, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str175468 = allocate([ 113, 117, 105, 116, 40, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 81, 117, 105, 116, 32, 116, 104, 101, 32, 115, 104, 101, 108, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str176469 = allocate([ 97, 115, 115, 101, 114, 116, 69, 113, 40, 97, 99, 116, 117, 97, 108, 44, 32, 101, 120, 112, 101, 99, 116, 101, 100, 91, 44, 32, 109, 115, 103, 93, 41, 10, 32, 32, 84, 104, 114, 111, 119, 32, 105, 102, 32, 116, 104, 101, 32, 102, 105, 114, 115, 116, 32, 116, 119, 111, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 32, 97, 114, 101, 32, 110, 111, 116, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 40, 98, 111, 116, 104, 32, 43, 48, 32, 111, 114, 32, 98, 111, 116, 104, 32, 45, 48, 44, 10, 32, 32, 98, 111, 116, 104, 32, 78, 97, 78, 44, 32, 111, 114, 32, 110, 111, 110, 45, 122, 101, 114, 111, 32, 97, 110, 100, 32, 61, 61, 61, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str177470 = allocate([ 97, 115, 115, 101, 114, 116, 74, 105, 116, 40, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 84, 104, 114, 111, 119, 32, 105, 102, 32, 116, 104, 101, 32, 99, 97, 108, 108, 105, 110, 103, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 74, 73, 84, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str178471 = allocate([ 103, 99, 40, 91, 111, 98, 106, 93, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 82, 117, 110, 32, 116, 104, 101, 32, 103, 97, 114, 98, 97, 103, 101, 32, 99, 111, 108, 108, 101, 99, 116, 111, 114, 10, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 87, 104, 101, 110, 32, 111, 98, 106, 32, 105, 115, 32, 103, 105, 118, 101, 110, 44, 32, 71, 67, 32, 111, 110, 108, 121, 32, 116, 104, 101, 32, 99, 111, 109, 112, 97, 114, 116, 109, 101, 110, 116, 32, 105, 116, 39, 115, 32, 105, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str179472 = allocate([ 103, 99, 112, 97, 114, 97, 109, 40, 110, 97, 109, 101, 44, 32, 118, 97, 108, 117, 101, 41, 10, 32, 32, 87, 114, 97, 112, 112, 101, 114, 32, 102, 111, 114, 32, 74, 83, 95, 83, 101, 116, 71, 67, 80, 97, 114, 97, 109, 101, 116, 101, 114, 46, 32, 84, 104, 101, 32, 110, 97, 109, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 101, 105, 116, 104, 101, 114, 32, 39, 109, 97, 120, 66, 121, 116, 101, 115, 39, 32, 111, 114, 10, 32, 32, 39, 109, 97, 120, 77, 97, 108, 108, 111, 99, 66, 121, 116, 101, 115, 39, 32, 97, 110, 100, 32, 116, 104, 101, 32, 118, 97, 108, 117, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 99, 111, 110, 118, 101, 114, 116, 97, 98, 108, 101, 32, 116, 111, 32, 97, 32, 112, 111, 115, 105, 116, 105, 118, 101, 32, 117, 105, 110, 116, 51, 50, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str180473 = allocate([ 99, 111, 117, 110, 116, 72, 101, 97, 112, 40, 91, 115, 116, 97, 114, 116, 91, 44, 32, 107, 105, 110, 100, 93, 93, 41, 10, 32, 32, 67, 111, 117, 110, 116, 32, 116, 104, 101, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 108, 105, 118, 101, 32, 71, 67, 32, 116, 104, 105, 110, 103, 115, 32, 105, 110, 32, 116, 104, 101, 32, 104, 101, 97, 112, 32, 111, 114, 32, 116, 104, 105, 110, 103, 115, 32, 114, 101, 97, 99, 104, 97, 98, 108, 101, 32, 102, 114, 111, 109, 10, 32, 32, 115, 116, 97, 114, 116, 32, 119, 104, 101, 110, 32, 105, 116, 32, 105, 115, 32, 103, 105, 118, 101, 110, 32, 97, 110, 100, 32, 105, 115, 32, 110, 111, 116, 32, 110, 117, 108, 108, 46, 32, 107, 105, 110, 100, 32, 105, 115, 32, 101, 105, 116, 104, 101, 114, 32, 39, 97, 108, 108, 39, 32, 40, 100, 101, 102, 97, 117, 108, 116, 41, 32, 116, 111, 10, 32, 32, 99, 111, 117, 110, 116, 32, 97, 108, 108, 32, 116, 104, 105, 110, 103, 115, 32, 111, 114, 32, 111, 110, 101, 32, 111, 102, 32, 39, 111, 98, 106, 101, 99, 116, 39, 44, 32, 39, 100, 111, 117, 98, 108, 101, 39, 44, 32, 39, 115, 116, 114, 105, 110, 103, 39, 44, 32, 39, 102, 117, 110, 99, 116, 105, 111, 110, 39, 44, 10, 32, 32, 39, 113, 110, 97, 109, 101, 39, 44, 32, 39, 110, 97, 109, 101, 115, 112, 97, 99, 101, 39, 44, 32, 39, 120, 109, 108, 39, 32, 116, 111, 32, 99, 111, 117, 110, 116, 32, 111, 110, 108, 121, 32, 116, 104, 105, 110, 103, 115, 32, 111, 102, 32, 116, 104, 97, 116, 32, 107, 105, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str181474 = allocate([ 109, 97, 107, 101, 70, 105, 110, 97, 108, 105, 122, 101, 79, 98, 115, 101, 114, 118, 101, 114, 40, 41, 10, 32, 32, 103, 101, 116, 32, 97, 32, 115, 112, 101, 99, 105, 97, 108, 32, 111, 98, 106, 101, 99, 116, 32, 119, 104, 111, 115, 101, 32, 102, 105, 110, 97, 108, 105, 122, 97, 116, 105, 111, 110, 32, 105, 110, 99, 114, 101, 97, 115, 101, 115, 32, 116, 104, 101, 32, 99, 111, 117, 110, 116, 101, 114, 32, 114, 101, 116, 117, 114, 110, 101, 100, 10, 32, 32, 98, 121, 32, 116, 104, 101, 32, 102, 105, 110, 97, 108, 105, 122, 101, 67, 111, 117, 110, 116, 32, 102, 117, 110, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str182475 = allocate([ 102, 105, 110, 97, 108, 105, 122, 101, 67, 111, 117, 110, 116, 40, 41, 10, 32, 32, 114, 101, 116, 117, 114, 110, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116, 32, 118, 97, 108, 117, 101, 32, 111, 102, 32, 116, 104, 101, 32, 102, 105, 110, 97, 108, 105, 122, 97, 116, 105, 111, 110, 32, 99, 111, 117, 110, 116, 101, 114, 32, 116, 104, 97, 116, 32, 105, 115, 32, 105, 110, 99, 114, 101, 109, 101, 110, 116, 101, 100, 10, 32, 32, 101, 97, 99, 104, 32, 116, 105, 109, 101, 32, 97, 110, 32, 111, 98, 106, 101, 99, 116, 32, 114, 101, 116, 117, 114, 110, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 109, 97, 107, 101, 70, 105, 110, 97, 108, 105, 122, 101, 79, 98, 115, 101, 114, 118, 101, 114, 32, 105, 115, 32, 102, 105, 110, 97, 108, 105, 122, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str183476 = allocate([ 105, 110, 116, 101, 114, 110, 97, 108, 67, 111, 110, 115, 116, 40, 110, 97, 109, 101, 41, 10, 32, 32, 81, 117, 101, 114, 121, 32, 97, 110, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 99, 111, 110, 115, 116, 97, 110, 116, 32, 102, 111, 114, 32, 116, 104, 101, 32, 101, 110, 103, 105, 110, 101, 46, 32, 83, 101, 101, 32, 73, 110, 116, 101, 114, 110, 97, 108, 67, 111, 110, 115, 116, 32, 115, 111, 117, 114, 99, 101, 32, 102, 111, 114, 32, 116, 104, 101, 10, 32, 32, 108, 105, 115, 116, 32, 111, 102, 32, 99, 111, 110, 115, 116, 97, 110, 116, 32, 110, 97, 109, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str184477 = allocate([ 115, 101, 116, 68, 101, 98, 117, 103, 40, 100, 101, 98, 117, 103, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 83, 101, 116, 32, 100, 101, 98, 117, 103, 32, 109, 111, 100, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str185478 = allocate([ 115, 101, 116, 68, 101, 98, 117, 103, 103, 101, 114, 72, 97, 110, 100, 108, 101, 114, 40, 102, 41, 32, 32, 32, 32, 83, 101, 116, 32, 104, 97, 110, 100, 108, 101, 114, 32, 102, 111, 114, 32, 100, 101, 98, 117, 103, 103, 101, 114, 32, 107, 101, 121, 119, 111, 114, 100, 32, 116, 111, 32, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str186479 = allocate([ 115, 101, 116, 84, 104, 114, 111, 119, 72, 111, 111, 107, 40, 102, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 83, 101, 116, 32, 116, 104, 114, 111, 119, 32, 104, 111, 111, 107, 32, 116, 111, 32, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str187480 = allocate([ 116, 114, 97, 112, 40, 91, 102, 117, 110, 44, 32, 91, 112, 99, 44, 93, 93, 32, 101, 120, 112, 41, 32, 32, 32, 84, 114, 97, 112, 32, 98, 121, 116, 101, 99, 111, 100, 101, 32, 101, 120, 101, 99, 117, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str188481 = allocate([ 117, 110, 116, 114, 97, 112, 40, 102, 117, 110, 91, 44, 32, 112, 99, 93, 41, 32, 32, 32, 32, 32, 32, 32, 32, 82, 101, 109, 111, 118, 101, 32, 97, 32, 116, 114, 97, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str189482 = allocate([ 108, 105, 110, 101, 50, 112, 99, 40, 91, 102, 117, 110, 44, 93, 32, 108, 105, 110, 101, 41, 32, 32, 32, 32, 32, 77, 97, 112, 32, 108, 105, 110, 101, 32, 110, 117, 109, 98, 101, 114, 32, 116, 111, 32, 80, 67, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str190483 = allocate([ 112, 99, 50, 108, 105, 110, 101, 40, 102, 117, 110, 91, 44, 32, 112, 99, 93, 41, 32, 32, 32, 32, 32, 32, 32, 77, 97, 112, 32, 80, 67, 32, 116, 111, 32, 108, 105, 110, 101, 32, 110, 117, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str191484 = allocate([ 115, 116, 114, 105, 110, 103, 115, 65, 114, 101, 85, 84, 70, 56, 40, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 67, 104, 101, 99, 107, 32, 105, 102, 32, 115, 116, 114, 105, 110, 103, 115, 32, 97, 114, 101, 32, 85, 84, 70, 45, 56, 32, 101, 110, 99, 111, 100, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str192485 = allocate([ 116, 101, 115, 116, 85, 84, 70, 56, 40, 109, 111, 100, 101, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 80, 101, 114, 102, 111, 114, 109, 32, 85, 84, 70, 45, 56, 32, 116, 101, 115, 116, 115, 32, 40, 109, 111, 100, 101, 115, 32, 97, 114, 101, 32, 49, 32, 116, 111, 32, 52, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str193486 = allocate([ 116, 104, 114, 111, 119, 69, 114, 114, 111, 114, 40, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 84, 104, 114, 111, 119, 32, 97, 110, 32, 101, 114, 114, 111, 114, 32, 102, 114, 111, 109, 32, 74, 83, 95, 82, 101, 112, 111, 114, 116, 69, 114, 114, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str194487 = allocate([ 100, 117, 109, 112, 83, 116, 97, 99, 107, 40, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 68, 117, 109, 112, 32, 116, 104, 101, 32, 115, 116, 97, 99, 107, 32, 97, 115, 32, 97, 110, 32, 97, 114, 114, 97, 121, 32, 111, 102, 32, 99, 97, 108, 108, 101, 101, 115, 32, 40, 121, 111, 117, 110, 103, 101, 115, 116, 32, 102, 105, 114, 115, 116, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str195488 = allocate([ 98, 117, 105, 108, 100, 40, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 83, 104, 111, 119, 32, 98, 117, 105, 108, 100, 32, 100, 97, 116, 101, 32, 97, 110, 100, 32, 116, 105, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str196489 = allocate([ 99, 108, 101, 97, 114, 40, 91, 111, 98, 106, 93, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 67, 108, 101, 97, 114, 32, 112, 114, 111, 112, 101, 114, 116, 105, 101, 115, 32, 111, 102, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str197490 = allocate([ 105, 110, 116, 101, 114, 110, 40, 115, 116, 114, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 73, 110, 116, 101, 114, 110, 97, 108, 105, 122, 101, 32, 115, 116, 114, 32, 105, 110, 32, 116, 104, 101, 32, 97, 116, 111, 109, 32, 116, 97, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str198491 = allocate([ 99, 108, 111, 110, 101, 40, 102, 117, 110, 91, 44, 32, 115, 99, 111, 112, 101, 93, 41, 32, 32, 32, 32, 32, 32, 67, 108, 111, 110, 101, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str199492 = allocate([ 103, 101, 116, 112, 100, 97, 40, 111, 98, 106, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 71, 101, 116, 32, 116, 104, 101, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 100, 101, 115, 99, 114, 105, 112, 116, 111, 114, 115, 32, 102, 111, 114, 32, 111, 98, 106, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str200493 = allocate([ 103, 101, 116, 115, 108, 120, 40, 111, 98, 106, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 71, 101, 116, 32, 115, 99, 114, 105, 112, 116, 32, 108, 105, 110, 101, 32, 101, 120, 116, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str201494 = allocate([ 116, 111, 105, 110, 116, 51, 50, 40, 110, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 84, 101, 115, 116, 105, 110, 103, 32, 104, 111, 111, 107, 32, 102, 111, 114, 32, 74, 83, 95, 86, 97, 108, 117, 101, 84, 111, 73, 110, 116, 51, 50, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str202495 = allocate([ 101, 118, 97, 108, 99, 120, 40, 115, 91, 44, 32, 111, 93, 41, 10, 32, 32, 69, 118, 97, 108, 117, 97, 116, 101, 32, 115, 32, 105, 110, 32, 111, 112, 116, 105, 111, 110, 97, 108, 32, 115, 97, 110, 100, 98, 111, 120, 32, 111, 98, 106, 101, 99, 116, 32, 111, 10, 32, 32, 105, 102, 32, 40, 115, 32, 61, 61, 32, 39, 39, 32, 38, 38, 32, 33, 111, 41, 32, 114, 101, 116, 117, 114, 110, 32, 110, 101, 119, 32, 111, 32, 119, 105, 116, 104, 32, 101, 97, 103, 101, 114, 32, 115, 116, 97, 110, 100, 97, 114, 100, 32, 99, 108, 97, 115, 115, 101, 115, 10, 32, 32, 105, 102, 32, 40, 115, 32, 61, 61, 32, 39, 108, 97, 122, 121, 39, 32, 38, 38, 32, 33, 111, 41, 32, 114, 101, 116, 117, 114, 110, 32, 110, 101, 119, 32, 111, 32, 119, 105, 116, 104, 32, 108, 97, 122, 121, 32, 115, 116, 97, 110, 100, 97, 114, 100, 32, 99, 108, 97, 115, 115, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str203496 = allocate([ 101, 118, 97, 108, 73, 110, 70, 114, 97, 109, 101, 40, 110, 44, 115, 116, 114, 44, 115, 97, 118, 101, 41, 32, 32, 69, 118, 97, 108, 117, 97, 116, 101, 32, 39, 115, 116, 114, 39, 32, 105, 110, 32, 116, 104, 101, 32, 110, 116, 104, 32, 117, 112, 32, 102, 114, 97, 109, 101, 46, 10, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 73, 102, 32, 39, 115, 97, 118, 101, 39, 32, 40, 100, 101, 102, 97, 117, 108, 116, 32, 102, 97, 108, 115, 101, 41, 44, 32, 115, 97, 118, 101, 32, 116, 104, 101, 32, 102, 114, 97, 109, 101, 32, 99, 104, 97, 105, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str204497 = allocate([ 115, 104, 97, 112, 101, 79, 102, 40, 111, 98, 106, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 71, 101, 116, 32, 116, 104, 101, 32, 115, 104, 97, 112, 101, 32, 111, 102, 32, 111, 98, 106, 32, 40, 97, 110, 32, 105, 109, 112, 108, 101, 109, 101, 110, 116, 97, 116, 105, 111, 110, 32, 100, 101, 116, 97, 105, 108, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str205498 = allocate([ 114, 101, 115, 111, 108, 118, 101, 114, 40, 115, 114, 99, 91, 44, 32, 112, 114, 111, 116, 111, 93, 41, 32, 32, 32, 67, 114, 101, 97, 116, 101, 32, 111, 98, 106, 101, 99, 116, 32, 119, 105, 116, 104, 32, 114, 101, 115, 111, 108, 118, 101, 32, 104, 111, 111, 107, 32, 116, 104, 97, 116, 32, 99, 111, 112, 105, 101, 115, 32, 112, 114, 111, 112, 101, 114, 116, 105, 101, 115, 10, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 102, 114, 111, 109, 32, 115, 114, 99, 46, 32, 73, 102, 32, 112, 114, 111, 116, 111, 32, 105, 115, 32, 111, 109, 105, 116, 116, 101, 100, 44, 32, 117, 115, 101, 32, 79, 98, 106, 101, 99, 116, 46, 112, 114, 111, 116, 111, 116, 121, 112, 101, 46, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str206499 = allocate([ 115, 110, 97, 114, 102, 40, 102, 105, 108, 101, 110, 97, 109, 101, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 82, 101, 97, 100, 32, 102, 105, 108, 101, 110, 97, 109, 101, 32, 105, 110, 116, 111, 32, 114, 101, 116, 117, 114, 110, 101, 100, 32, 115, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str207500 = allocate([ 114, 101, 97, 100, 40, 102, 105, 108, 101, 110, 97, 109, 101, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 83, 121, 110, 111, 110, 121, 109, 32, 102, 111, 114, 32, 115, 110, 97, 114, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str208501 = allocate([ 99, 111, 109, 112, 105, 108, 101, 40, 99, 111, 100, 101, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 67, 111, 109, 112, 105, 108, 101, 115, 32, 97, 32, 115, 116, 114, 105, 110, 103, 32, 116, 111, 32, 98, 121, 116, 101, 99, 111, 100, 101, 44, 32, 112, 111, 116, 101, 110, 116, 105, 97, 108, 108, 121, 32, 116, 104, 114, 111, 119, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str209502 = allocate([ 112, 97, 114, 115, 101, 40, 99, 111, 100, 101, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 80, 97, 114, 115, 101, 115, 32, 97, 32, 115, 116, 114, 105, 110, 103, 44, 32, 112, 111, 116, 101, 110, 116, 105, 97, 108, 108, 121, 32, 116, 104, 114, 111, 119, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str210503 = allocate([ 116, 105, 109, 101, 111, 117, 116, 40, 91, 115, 101, 99, 111, 110, 100, 115, 93, 41, 10, 32, 32, 71, 101, 116, 47, 83, 101, 116, 32, 116, 104, 101, 32, 108, 105, 109, 105, 116, 32, 105, 110, 32, 115, 101, 99, 111, 110, 100, 115, 32, 102, 111, 114, 32, 116, 104, 101, 32, 101, 120, 101, 99, 117, 116, 105, 111, 110, 32, 116, 105, 109, 101, 32, 102, 111, 114, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116, 32, 99, 111, 110, 116, 101, 120, 116, 46, 10, 32, 32, 65, 32, 110, 101, 103, 97, 116, 105, 118, 101, 32, 118, 97, 108, 117, 101, 32, 40, 100, 101, 102, 97, 117, 108, 116, 41, 32, 109, 101, 97, 110, 115, 32, 116, 104, 97, 116, 32, 116, 104, 101, 32, 101, 120, 101, 99, 117, 116, 105, 111, 110, 32, 116, 105, 109, 101, 32, 105, 115, 32, 117, 110, 108, 105, 109, 105, 116, 101, 100, 46, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str211504 = allocate([ 101, 108, 97, 112, 115, 101, 100, 40, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 69, 120, 101, 99, 117, 116, 105, 111, 110, 32, 116, 105, 109, 101, 32, 101, 108, 97, 112, 115, 101, 100, 32, 102, 111, 114, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116, 32, 99, 111, 110, 116, 101, 120, 116, 46, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str212505 = allocate([ 112, 97, 114, 101, 110, 116, 40, 111, 98, 106, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 82, 101, 116, 117, 114, 110, 115, 32, 116, 104, 101, 32, 112, 97, 114, 101, 110, 116, 32, 111, 102, 32, 111, 98, 106, 46, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str213506 = allocate([ 119, 114, 97, 112, 40, 111, 98, 106, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 87, 114, 97, 112, 32, 97, 110, 32, 111, 98, 106, 101, 99, 116, 32, 105, 110, 116, 111, 32, 97, 32, 110, 111, 111, 112, 32, 119, 114, 97, 112, 112, 101, 114, 46, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str214507 = allocate([ 115, 101, 114, 105, 97, 108, 105, 122, 101, 40, 115, 100, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 83, 101, 114, 105, 97, 108, 105, 122, 101, 32, 115, 100, 32, 117, 115, 105, 110, 103, 32, 74, 83, 95, 87, 114, 105, 116, 101, 83, 116, 114, 117, 99, 116, 117, 114, 101, 100, 67, 108, 111, 110, 101, 46, 32, 82, 101, 116, 117, 114, 110, 115, 32, 97, 32, 84, 121, 112, 101, 100, 65, 114, 114, 97, 121, 46, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str215508 = allocate([ 100, 101, 115, 101, 114, 105, 97, 108, 105, 122, 101, 40, 97, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 68, 101, 115, 101, 114, 105, 97, 108, 105, 122, 101, 32, 100, 97, 116, 97, 32, 103, 101, 110, 101, 114, 97, 116, 101, 100, 32, 98, 121, 32, 115, 101, 114, 105, 97, 108, 105, 122, 101, 46, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str216509 = allocate([ 115, 116, 114, 105, 110, 103, 115, 116, 97, 116, 115, 40, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 82, 101, 116, 117, 114, 110, 32, 115, 116, 97, 116, 115, 32, 111, 110, 32, 115, 116, 114, 105, 110, 103, 32, 109, 101, 109, 111, 114, 121, 32, 117, 115, 97, 103, 101, 46, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str217510 = allocate([ 110, 101, 119, 71, 108, 111, 98, 97, 108, 40, 107, 105, 110, 100, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 82, 101, 116, 117, 114, 110, 32, 97, 32, 110, 101, 119, 32, 103, 108, 111, 98, 97, 108, 32, 111, 98, 106, 101, 99, 116, 44, 32, 105, 110, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116, 10, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 99, 111, 109, 112, 97, 114, 116, 109, 101, 110, 116, 32, 105, 102, 32, 107, 105, 110, 100, 32, 61, 61, 61, 32, 39, 115, 97, 109, 101, 45, 99, 111, 109, 112, 97, 114, 116, 109, 101, 110, 116, 39, 32, 111, 114, 32, 105, 110, 32, 97, 10, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 110, 101, 119, 32, 99, 111, 109, 112, 97, 114, 116, 109, 101, 110, 116, 32, 105, 102, 32, 107, 105, 110, 100, 32, 61, 61, 61, 32, 39, 110, 101, 119, 45, 99, 111, 109, 112, 97, 114, 116, 109, 101, 110, 116, 39, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str218511 = allocate([ 112, 97, 114, 115, 101, 76, 101, 103, 97, 99, 121, 74, 83, 79, 78, 40, 115, 116, 114, 41, 32, 32, 32, 32, 32, 80, 97, 114, 115, 101, 32, 115, 116, 114, 32, 97, 115, 32, 108, 101, 103, 97, 99, 121, 32, 74, 83, 79, 78, 44, 32, 114, 101, 116, 117, 114, 110, 105, 110, 103, 32, 116, 104, 101, 32, 114, 101, 115, 117, 108, 116, 32, 105, 102, 32, 116, 104, 101, 10, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 112, 97, 114, 115, 101, 32, 115, 117, 99, 99, 101, 101, 100, 101, 100, 32, 97, 110, 100, 32, 116, 104, 114, 111, 119, 105, 110, 103, 32, 97, 32, 83, 121, 110, 116, 97, 120, 69, 114, 114, 111, 114, 32, 105, 102, 32, 110, 111, 116, 46, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str219512 = allocate([ 101, 110, 97, 98, 108, 101, 83, 116, 97, 99, 107, 87, 97, 108, 107, 105, 110, 103, 65, 115, 115, 101, 114, 116, 105, 111, 110, 40, 101, 110, 97, 98, 108, 101, 100, 41, 10, 32, 32, 69, 110, 97, 98, 108, 101, 115, 32, 111, 114, 32, 100, 105, 115, 97, 98, 108, 101, 115, 32, 97, 32, 112, 97, 114, 116, 105, 99, 117, 108, 97, 114, 108, 121, 32, 101, 120, 112, 101, 110, 115, 105, 118, 101, 32, 97, 115, 115, 101, 114, 116, 105, 111, 110, 32, 105, 110, 32, 115, 116, 97, 99, 107, 45, 119, 97, 108, 107, 105, 110, 103, 10, 32, 32, 99, 111, 100, 101, 46, 32, 32, 73, 102, 32, 121, 111, 117, 114, 32, 116, 101, 115, 116, 32, 105, 115, 110, 39, 116, 32, 114, 105, 100, 105, 99, 117, 108, 111, 117, 115, 108, 121, 32, 116, 104, 111, 114, 111, 117, 103, 104, 44, 32, 115, 117, 99, 104, 32, 116, 104, 97, 116, 32, 112, 101, 114, 102, 111, 114, 109, 105, 110, 103, 32, 116, 104, 105, 115, 10, 32, 32, 97, 115, 115, 101, 114, 116, 105, 111, 110, 32, 105, 110, 99, 114, 101, 97, 115, 101, 115, 32, 116, 101, 115, 116, 32, 100, 117, 114, 97, 116, 105, 111, 110, 32, 98, 121, 32, 97, 110, 32, 111, 114, 100, 101, 114, 32, 111, 102, 32, 109, 97, 103, 110, 105, 116, 117, 100, 101, 44, 32, 121, 111, 117, 32, 115, 104, 111, 117, 108, 100, 110, 39, 116, 10, 32, 32, 117, 115, 101, 32, 116, 104, 105, 115, 46, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str220513 = allocate([ 103, 101, 116, 77, 97, 120, 65, 114, 103, 115, 40, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 82, 101, 116, 117, 114, 110, 32, 116, 104, 101, 32, 109, 97, 120, 105, 109, 117, 109, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 115, 117, 112, 112, 111, 114, 116, 101, 100, 32, 97, 114, 103, 115, 32, 102, 111, 114, 32, 97, 32, 99, 97, 108, 108, 46, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str221514 = allocate([ 87, 114, 111, 110, 103, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str222515 = allocate([ 79, 110, 108, 121, 32, 111, 98, 106, 101, 99, 116, 115, 32, 104, 97, 118, 101, 32, 112, 97, 114, 101, 110, 116, 115, 33, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str223516 = allocate([ 69, 120, 99, 101, 115, 115, 105, 118, 101, 32, 116, 105, 109, 101, 111, 117, 116, 32, 118, 97, 108, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str225518 = allocate([ 48, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str226519 = allocate([ 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str227520 = allocate([ 101, 120, 112, 101, 99, 116, 101, 100, 32, 115, 116, 114, 105, 110, 103, 32, 116, 111, 32, 112, 97, 114, 115, 101, 44, 32, 103, 111, 116, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str228521 = allocate([ 60, 115, 116, 114, 105, 110, 103, 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str229522 = allocate([ 101, 120, 112, 101, 99, 116, 101, 100, 32, 115, 116, 114, 105, 110, 103, 32, 116, 111, 32, 99, 111, 109, 112, 105, 108, 101, 44, 32, 103, 111, 116, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

__ZZL7CompileP9JSContextjPN2JS5ValueEE11dummy_class = allocate([ 0, 0, 0, 0, 292608, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str230523 = allocate([ 106, 100, 117, 109, 109, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str231524 = allocate([ 98, 105, 110, 97, 114, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str232525 = allocate([ 114, 98, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str233526 = allocate([ 99, 97, 110, 39, 116, 32, 111, 112, 101, 110, 32, 37, 115, 58, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str234527 = allocate([ 99, 97, 110, 39, 116, 32, 115, 101, 101, 107, 32, 101, 110, 100, 32, 111, 102, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str235528 = allocate([ 99, 97, 110, 39, 116, 32, 115, 101, 101, 107, 32, 115, 116, 97, 114, 116, 32, 111, 102, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str236529 = allocate([ 99, 97, 110, 39, 116, 32, 114, 101, 97, 100, 32, 37, 115, 58, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str237530 = allocate([ 115, 104, 111, 114, 116, 32, 114, 101, 97, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str238531 = allocate([ 73, 110, 118, 97, 108, 105, 100, 32, 85, 84, 70, 45, 56, 32, 105, 110, 32, 102, 105, 108, 101, 32, 39, 37, 115, 39, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str239532 = allocate([ 111, 47, 111, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str240533 = allocate([ 115, 104, 97, 112, 101, 79, 102, 58, 32, 111, 98, 106, 101, 99, 116, 32, 101, 120, 112, 101, 99, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str241534 = allocate([ 73, 110, 118, 97, 108, 105, 100, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 32, 116, 111, 32, 101, 118, 97, 108, 73, 110, 70, 114, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str242535 = allocate([ 99, 97, 110, 110, 111, 116, 32, 101, 118, 97, 108, 32, 105, 110, 32, 110, 111, 110, 45, 115, 99, 114, 105, 112, 116, 32, 102, 114, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str243536 = allocate([ 83, 32, 47, 32, 111, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str244537 = allocate([ 73, 110, 118, 97, 108, 105, 100, 32, 115, 99, 111, 112, 101, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 116, 111, 32, 101, 118, 97, 108, 99, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str245538 = allocate([ 108, 97, 122, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str246539 = allocate([ 105, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str247540 = allocate([ 118, 97, 108, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str248541 = allocate([ 102, 108, 97, 103, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str249542 = allocate([ 115, 108, 111, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str250543 = allocate([ 97, 108, 105, 97, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str251544 = allocate([ 73, 110, 118, 97, 108, 105, 100, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 32, 116, 111, 32, 99, 108, 111, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str252545 = allocate([ 102, 117, 110, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str253546 = allocate([ 99, 111, 109, 112, 105, 108, 101, 45, 97, 110, 100, 45, 103, 111, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL9BuildDateP9JSContextjPN2JS5ValueEE7version = allocate([ 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str254547 = allocate([ 98, 117, 105, 108, 116, 32, 111, 110, 32, 37, 115, 32, 97, 116, 32, 37, 115, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str255548 = allocate([ 65, 112, 114, 32, 49, 57, 32, 50, 48, 49, 50, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str256549 = allocate([ 49, 55, 58, 48, 51, 58, 49, 54, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str257550 = allocate([ 84, 104, 105, 115, 32, 105, 115, 32, 97, 110, 32, 101, 114, 114, 111, 114, 0 ], "i8", ALLOC_STATIC);

__ZL12badSurrogate = allocate([ 65, 0, 66, 0, 67, 0, -8466, 0, 68, 0, 69, 0, 0, 0 ], [ "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str258551 = allocate([ 49, 50, 51, 52, 53, 54, 55, 56, 57, 48, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str259552 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 109, 111, 100, 101, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str260553 = allocate([ 46, 46, 46, 251, 191, 191, 191, 191, 46, 46, 46, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str261554 = allocate([ 46, 46, 46, 192, 46, 46, 46, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str262555 = allocate([ 116, 104, 101, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 116, 97, 107, 101, 115, 32, 101, 120, 97, 99, 116, 108, 121, 32, 111, 110, 101, 32, 97, 114, 103, 117, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str263556 = allocate([ 79, 66, 74, 69, 67, 84, 95, 77, 65, 82, 75, 95, 83, 84, 65, 67, 75, 95, 76, 69, 78, 71, 84, 72, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str264557 = allocate([ 117, 110, 107, 110, 111, 119, 110, 32, 99, 111, 110, 115, 116, 32, 110, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

__ZL13finalizeCount = allocate(1, "i32", ALLOC_STATIC);

__ZL20FinalizeCounterClass = allocate([ 0, 0, 0, 0, 131072, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 144, 0, 0, 0, 176, 0, 0, 0, 86, 0, 0, 0, 2130, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str265558 = allocate([ 70, 105, 110, 97, 108, 105, 122, 101, 67, 111, 117, 110, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

__ZZL9CountHeapP9JSContextjPN2JS5ValueEE14traceKindNames = allocate([ 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str266559 = allocate([ 97, 108, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str267560 = allocate([ 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str268561 = allocate([ 115, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str269562 = allocate([ 120, 109, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str270563 = allocate([ 116, 104, 101, 32, 102, 105, 114, 115, 116, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 105, 115, 32, 110, 111, 116, 32, 110, 117, 108, 108, 32, 111, 114, 32, 97, 32, 104, 101, 97, 112, 45, 97, 108, 108, 111, 99, 97, 116, 101, 100, 32, 116, 104, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str271564 = allocate([ 116, 114, 97, 99, 101, 32, 107, 105, 110, 100, 32, 110, 97, 109, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 117, 110, 107, 110, 111, 119, 110, 0 ], "i8", ALLOC_STATIC);

__ZZL11GCParameterP9JSContextjPN2JS5ValueEE8paramMap = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str272565 = allocate([ 109, 97, 120, 66, 121, 116, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str273566 = allocate([ 109, 97, 120, 77, 97, 108, 108, 111, 99, 66, 121, 116, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str274567 = allocate([ 103, 99, 83, 116, 97, 99, 107, 112, 111, 111, 108, 76, 105, 102, 101, 115, 112, 97, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str275568 = allocate([ 103, 99, 66, 121, 116, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str276569 = allocate([ 103, 99, 78, 117, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str277570 = allocate([ 116, 104, 101, 32, 102, 105, 114, 115, 116, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 109, 117, 115, 116, 32, 98, 101, 32, 109, 97, 120, 66, 121, 116, 101, 115, 44, 32, 109, 97, 120, 77, 97, 108, 108, 111, 99, 66, 121, 116, 101, 115, 44, 32, 103, 99, 83, 116, 97, 99, 107, 112, 111, 111, 108, 76, 105, 102, 101, 115, 112, 97, 110, 44, 32, 103, 99, 66, 121, 116, 101, 115, 32, 111, 114, 32, 103, 99, 78, 117, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str278571 = allocate([ 65, 116, 116, 101, 109, 112, 116, 32, 116, 111, 32, 99, 104, 97, 110, 103, 101, 32, 114, 101, 97, 100, 45, 111, 110, 108, 121, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str279572 = allocate([ 116, 104, 101, 32, 115, 101, 99, 111, 110, 100, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 109, 117, 115, 116, 32, 98, 101, 32, 99, 111, 110, 118, 101, 114, 116, 97, 98, 108, 101, 32, 116, 111, 32, 117, 105, 110, 116, 51, 50, 32, 119, 105, 116, 104, 32, 110, 111, 110, 45, 122, 101, 114, 111, 32, 118, 97, 108, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str280573 = allocate([ 98, 101, 102, 111, 114, 101, 32, 37, 108, 117, 44, 32, 97, 102, 116, 101, 114, 32, 37, 108, 117, 44, 32, 98, 114, 101, 97, 107, 32, 37, 48, 56, 108, 120, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str281574 = allocate([ 60, 60, 101, 114, 114, 111, 114, 32, 99, 111, 110, 118, 101, 114, 116, 105, 110, 103, 32, 118, 97, 108, 117, 101, 32, 116, 111, 32, 115, 116, 114, 105, 110, 103, 62, 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str282575 = allocate([ 47, 32, 105, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str283576 = allocate([ 37, 115, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str284577 = allocate([ 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str285578 = allocate([ 116, 104, 105, 115, 45, 118, 97, 108, 117, 101, 32, 112, 97, 115, 115, 101, 100, 32, 116, 111, 32, 101, 118, 97, 108, 117, 97, 116, 101, 40, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str286579 = allocate([ 110, 111, 116, 32, 97, 32, 103, 108, 111, 98, 97, 108, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str287580 = allocate([ 64, 101, 118, 97, 108, 117, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

__ZL10js_options = allocate([ 0, 0, 0, 0, 32, 0, 0, 0, 0, 0, 0, 0, 32768, 0, 0, 0, 0, 0, 0, 0, 2048, 0, 0, 0, 0, 0, 0, 0, 16384, 0, 0, 0, 0, 0, 0, 0, 65536, 0, 0, 0, 0, 0, 0, 0, 512, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 262144, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 64, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str288581 = allocate([ 44, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str289582 = allocate([ 97, 116, 108, 105, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str290583 = allocate([ 106, 105, 116, 112, 114, 111, 102, 105, 108, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str291584 = allocate([ 109, 101, 116, 104, 111, 100, 106, 105, 116, 95, 97, 108, 119, 97, 121, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str292585 = allocate([ 114, 101, 108, 105, 109, 105, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str293586 = allocate([ 115, 116, 114, 105, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str294 = allocate([ 119, 101, 114, 114, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str295 = allocate([ 117, 110, 107, 110, 111, 119, 110, 32, 111, 112, 116, 105, 111, 110, 32, 110, 97, 109, 101, 32, 39, 37, 115, 39, 46, 32, 84, 104, 101, 32, 118, 97, 108, 105, 100, 32, 110, 97, 109, 101, 115, 32, 97, 114, 101, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str296 = allocate([ 44, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str297 = allocate([ 32, 97, 110, 100, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str298 = allocate([ 46, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZN2js3cli12OptionParser12prognameMetaE = allocate([ 123, 112, 114, 111, 103, 110, 97, 109, 101, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str651 = allocate([ 69, 114, 114, 111, 114, 58, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1652 = allocate([ 10, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2653 = allocate([ 37, 46, 42, 115, 37, 115, 37, 115, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str3654 = allocate([ 10, 86, 101, 114, 115, 105, 111, 110, 58, 32, 37, 115, 10, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZN2js3cli12OptionParser9printHelpEPKcE3fmt = allocate([ 32, 32, 37, 115, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str6657 = allocate([ 65, 32, 118, 97, 108, 117, 101, 32, 105, 115, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 102, 111, 114, 32, 111, 112, 116, 105, 111, 110, 32, 37, 46, 42, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str7658 = allocate([ 69, 120, 112, 101, 99, 116, 101, 100, 32, 97, 32, 118, 97, 108, 117, 101, 32, 102, 111, 114, 32, 111, 112, 116, 105, 111, 110, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str8659 = allocate([ 84, 111, 111, 32, 109, 97, 110, 121, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 32, 112, 114, 111, 118, 105, 100, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str9660 = allocate([ 73, 110, 118, 97, 108, 105, 100, 32, 108, 111, 110, 103, 32, 111, 112, 116, 105, 111, 110, 58, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str10661 = allocate([ 83, 104, 111, 114, 116, 32, 111, 112, 116, 105, 111, 110, 32, 102, 111, 108, 108, 111, 119, 101, 100, 32, 98, 121, 32, 106, 117, 110, 107, 58, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str11662 = allocate([ 73, 110, 118, 97, 108, 105, 100, 32, 115, 104, 111, 114, 116, 32, 111, 112, 116, 105, 111, 110, 58, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

__ZTVN2js3cli6detail17MultiStringOptionE = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 2132, 0, 0, 0, 2134, 0, 0, 0, 2136, 0, 0, 0, 2138, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTVN2js3cli6detail12ValuedOptionE = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 444, 0, 0, 0, 444, 0, 0, 0, 2136, 0, 0, 0, 2128, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTVN2js3cli6detail12StringOptionE = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 2140, 0, 0, 0, 2142, 0, 0, 0, 2136, 0, 0, 0, 2128, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZZL23OptionFlagsToFormatInfocbPjE3fmt = allocate(16, "*", ALLOC_STATIC);

STRING_TABLE.__str12663 = allocate([ 32, 32, 45, 37, 99, 32, 45, 45, 37, 115, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str13664 = allocate([ 32, 32, 45, 45, 37, 115, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str14665 = allocate([ 32, 32, 45, 37, 99, 32, 45, 45, 37, 115, 61, 37, 115, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str15666 = allocate([ 32, 32, 45, 45, 37, 115, 61, 37, 115, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str16667 = allocate([ 37, 42, 115, 0 ], "i8", ALLOC_STATIC);

__str17668 = allocate(1, "i8", ALLOC_STATIC);

STRING_TABLE.__str18669 = allocate([ 10, 37, 42, 115, 37, 46, 42, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str19670 = allocate([ 37, 46, 42, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str20671 = allocate([ 10, 37, 42, 115, 0 ], "i8", ALLOC_STATIC);

__gm_ = allocate(468, [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

_mparams = allocate(24, "i32", ALLOC_STATIC);

__ZL13__new_handler = allocate(1, "void ()*", ALLOC_STATIC);

__ZTVSt9bad_alloc = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 302, 0, 0, 0, 2144, 0, 0, 0, 2146, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

STRING_TABLE.__str3302 = allocate([ 115, 116, 100, 58, 58, 98, 97, 100, 95, 97, 108, 108, 111, 99, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZTSSt9bad_alloc = allocate([ 83, 116, 57, 98, 97, 100, 95, 97, 108, 108, 111, 99, 0 ], "i8", ALLOC_STATIC);

__ZTISt9bad_alloc = allocate(12, "*", ALLOC_STATIC);

STRING_TABLE._str2 = allocate([ 65, 114, 103, 117, 109, 101, 110, 116, 115, 58, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._str3 = allocate([ 79, 112, 116, 105, 111, 110, 115, 58, 0 ], "i8", ALLOC_STATIC);

HEAP32[_DebuggerFrame_class >> 2] = STRING_TABLE.__str48 | 0;

HEAP32[_DebuggerObject_class >> 2] = STRING_TABLE.__str62 | 0;

HEAP32[__ZN2js8Debugger7jsclassE >> 2] = STRING_TABLE.__str2 | 0;

HEAP32[__ZN2js8Debugger10propertiesE >> 2] = STRING_TABLE.__str31 | 0;

HEAP32[__ZN2js8Debugger10propertiesE + 16 >> 2] = STRING_TABLE.__str32 | 0;

HEAP32[__ZN2js8Debugger10propertiesE + 32 >> 2] = STRING_TABLE.__str33 | 0;

HEAP32[__ZN2js8Debugger10propertiesE + 48 >> 2] = STRING_TABLE.__str34 | 0;

HEAP32[__ZN2js8Debugger10propertiesE + 64 >> 2] = STRING_TABLE.__str35 | 0;

HEAP32[__ZN2js8Debugger10propertiesE + 80 >> 2] = STRING_TABLE.__str21 | 0;

HEAP32[__ZN2js8Debugger7methodsE >> 2] = STRING_TABLE.__str23 | 0;

HEAP32[__ZN2js8Debugger7methodsE + 12 >> 2] = STRING_TABLE.__str25 | 0;

HEAP32[__ZN2js8Debugger7methodsE + 24 >> 2] = STRING_TABLE.__str27 | 0;

HEAP32[__ZN2js8Debugger7methodsE + 36 >> 2] = STRING_TABLE.__str28 | 0;

HEAP32[__ZN2js8Debugger7methodsE + 48 >> 2] = STRING_TABLE.__str29 | 0;

HEAP32[__ZN2js8Debugger7methodsE + 60 >> 2] = STRING_TABLE.__str30 | 0;

HEAP32[_DebuggerScript_class >> 2] = STRING_TABLE.__str23669 | 0;

HEAP32[__ZL25DebuggerScript_properties >> 2] = STRING_TABLE.__str37 | 0;

HEAP32[__ZL25DebuggerScript_properties + 16 >> 2] = STRING_TABLE.__str38 | 0;

HEAP32[__ZL25DebuggerScript_properties + 32 >> 2] = STRING_TABLE.__str39 | 0;

HEAP32[__ZL25DebuggerScript_properties + 48 >> 2] = STRING_TABLE.__str40 | 0;

HEAP32[__ZL22DebuggerScript_methods >> 2] = STRING_TABLE.__str41 | 0;

HEAP32[__ZL22DebuggerScript_methods + 12 >> 2] = STRING_TABLE.__str42 | 0;

HEAP32[__ZL22DebuggerScript_methods + 24 >> 2] = STRING_TABLE.__str43 | 0;

HEAP32[__ZL22DebuggerScript_methods + 36 >> 2] = STRING_TABLE.__str44 | 0;

HEAP32[__ZL22DebuggerScript_methods + 48 >> 2] = STRING_TABLE.__str45 | 0;

HEAP32[__ZL22DebuggerScript_methods + 60 >> 2] = STRING_TABLE.__str46 | 0;

HEAP32[__ZL22DebuggerScript_methods + 72 >> 2] = STRING_TABLE.__str47 | 0;

HEAP32[__ZL22DebuggerScript_methods + 84 >> 2] = STRING_TABLE.__str30 | 0;

HEAP32[_DebuggerArguments_class >> 2] = STRING_TABLE.__str1263 | 0;

HEAP32[__ZL24DebuggerFrame_properties >> 2] = STRING_TABLE.__str142435 | 0;

HEAP32[__ZL24DebuggerFrame_properties + 16 >> 2] = STRING_TABLE.__str2093361 | 0;

HEAP32[__ZL24DebuggerFrame_properties + 32 >> 2] = STRING_TABLE.__str52 | 0;

HEAP32[__ZL24DebuggerFrame_properties + 48 >> 2] = STRING_TABLE.__str2323384 | 0;

HEAP32[__ZL24DebuggerFrame_properties + 64 >> 2] = STRING_TABLE.__str40 | 0;

HEAP32[__ZL24DebuggerFrame_properties + 80 >> 2] = STRING_TABLE.__str54 | 0;

HEAP32[__ZL24DebuggerFrame_properties + 96 >> 2] = STRING_TABLE.__str55 | 0;

HEAP32[__ZL24DebuggerFrame_properties + 112 >> 2] = STRING_TABLE.__str120413 | 0;

HEAP32[__ZL24DebuggerFrame_properties + 128 >> 2] = STRING_TABLE.__str57 | 0;

HEAP32[__ZL24DebuggerFrame_properties + 144 >> 2] = STRING_TABLE.__str1763328 | 0;

HEAP32[__ZL24DebuggerFrame_properties + 160 >> 2] = STRING_TABLE.__str59 | 0;

HEAP32[__ZL21DebuggerFrame_methods >> 2] = STRING_TABLE.__str60 | 0;

HEAP32[__ZL21DebuggerFrame_methods + 12 >> 2] = STRING_TABLE.__str61 | 0;

HEAP32[__ZL25DebuggerObject_properties >> 2] = STRING_TABLE.__str63 | 0;

HEAP32[__ZL25DebuggerObject_properties + 16 >> 2] = STRING_TABLE.__str64 | 0;

HEAP32[__ZL25DebuggerObject_properties + 32 >> 2] = STRING_TABLE.__str65 | 0;

HEAP32[__ZL25DebuggerObject_properties + 48 >> 2] = STRING_TABLE.__str404286 | 0;

HEAP32[__ZL25DebuggerObject_properties + 64 >> 2] = STRING_TABLE.__str67 | 0;

HEAP32[__ZL25DebuggerObject_properties + 80 >> 2] = STRING_TABLE.__str120413 | 0;

HEAP32[__ZL22DebuggerObject_methods >> 2] = STRING_TABLE.__str102207 | 0;

HEAP32[__ZL22DebuggerObject_methods + 12 >> 2] = STRING_TABLE.__str152212 | 0;

HEAP32[__ZL22DebuggerObject_methods + 24 >> 2] = STRING_TABLE.__str122209 | 0;

HEAP32[__ZL22DebuggerObject_methods + 36 >> 2] = STRING_TABLE.__str132210 | 0;

HEAP32[__ZL22DebuggerObject_methods + 48 >> 2] = STRING_TABLE.__str72 | 0;

HEAP32[__ZL22DebuggerObject_methods + 60 >> 2] = STRING_TABLE.__str202217 | 0;

HEAP32[__ZL22DebuggerObject_methods + 72 >> 2] = STRING_TABLE.__str182215 | 0;

HEAP32[__ZL22DebuggerObject_methods + 84 >> 2] = STRING_TABLE.__str172214 | 0;

HEAP32[__ZL22DebuggerObject_methods + 96 >> 2] = STRING_TABLE.__str212218 | 0;

HEAP32[__ZL22DebuggerObject_methods + 108 >> 2] = STRING_TABLE.__str192216 | 0;

HEAP32[__ZL22DebuggerObject_methods + 120 >> 2] = STRING_TABLE.__str162213 | 0;

HEAP32[__ZL22DebuggerObject_methods + 132 >> 2] = STRING_TABLE.__str79 | 0;

HEAP32[__ZL22DebuggerObject_methods + 144 >> 2] = STRING_TABLE.__str80 | 0;

HEAP32[__ZN2jsL21GlobalDebuggees_classE >> 2] = STRING_TABLE.__str122 | 0;

HEAP32[_js_dummy_class >> 2] = STRING_TABLE.__str230523 | 0;

HEAP32[__ZL20standard_class_atoms + 12 >> 2] = __ZN2js13FunctionClassE;

HEAP32[__ZL20standard_class_atoms + 28 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL20standard_class_atoms + 44 >> 2] = __ZN2js10ArrayClassE;

HEAP32[__ZL20standard_class_atoms + 60 >> 2] = __ZN2js12BooleanClassE;

HEAP32[__ZL20standard_class_atoms + 76 >> 2] = __ZN2js9DateClassE;

HEAP32[__ZL20standard_class_atoms + 92 >> 2] = __ZN2js9MathClassE;

HEAP32[__ZL20standard_class_atoms + 108 >> 2] = __ZN2js11NumberClassE;

HEAP32[__ZL20standard_class_atoms + 124 >> 2] = __ZN2js11StringClassE;

HEAP32[__ZL20standard_class_atoms + 140 >> 2] = __ZN2js10ErrorClassE;

HEAP32[__ZL20standard_class_atoms + 156 >> 2] = __ZN2js11RegExpClassE;

HEAP32[__ZL20standard_class_atoms + 172 >> 2] = __ZN2js8XMLClassE;

HEAP32[__ZL20standard_class_atoms + 188 >> 2] = __ZN2js14NamespaceClassE;

HEAP32[__ZL20standard_class_atoms + 204 >> 2] = __ZN2js10QNameClassE;

HEAP32[__ZL20standard_class_atoms + 220 >> 2] = __ZN2js18StopIterationClassE;

HEAP32[__ZL20standard_class_atoms + 236 >> 2] = __ZN2js9JSONClassE;

HEAP32[__ZL20standard_class_atoms + 252 >> 2] = __ZN2js11ArrayBuffer9slowClassE;

HEAP32[__ZL20standard_class_atoms + 268 >> 2] = __ZN2js12WeakMapClassE;

HEAP32[__ZL20standard_class_names + 12 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL20standard_class_names + 28 >> 2] = __ZN2js11NumberClassE;

HEAP32[__ZL20standard_class_names + 44 >> 2] = __ZN2js11NumberClassE;

HEAP32[__ZL20standard_class_names + 56 >> 2] = STRING_TABLE._js_isNaN_str | 0;

HEAP32[__ZL20standard_class_names + 60 >> 2] = __ZN2js11NumberClassE;

HEAP32[__ZL20standard_class_names + 72 >> 2] = STRING_TABLE._js_isFinite_str | 0;

HEAP32[__ZL20standard_class_names + 76 >> 2] = __ZN2js11NumberClassE;

HEAP32[__ZL20standard_class_names + 88 >> 2] = STRING_TABLE._js_parseFloat_str | 0;

HEAP32[__ZL20standard_class_names + 92 >> 2] = __ZN2js11NumberClassE;

HEAP32[__ZL20standard_class_names + 104 >> 2] = STRING_TABLE._js_parseInt_str | 0;

HEAP32[__ZL20standard_class_names + 108 >> 2] = __ZN2js11NumberClassE;

HEAP32[__ZL20standard_class_names + 120 >> 2] = STRING_TABLE._js_escape_str | 0;

HEAP32[__ZL20standard_class_names + 124 >> 2] = __ZN2js11StringClassE;

HEAP32[__ZL20standard_class_names + 136 >> 2] = STRING_TABLE._js_unescape_str | 0;

HEAP32[__ZL20standard_class_names + 140 >> 2] = __ZN2js11StringClassE;

HEAP32[__ZL20standard_class_names + 152 >> 2] = STRING_TABLE._js_decodeURI_str | 0;

HEAP32[__ZL20standard_class_names + 156 >> 2] = __ZN2js11StringClassE;

HEAP32[__ZL20standard_class_names + 168 >> 2] = STRING_TABLE._js_encodeURI_str | 0;

HEAP32[__ZL20standard_class_names + 172 >> 2] = __ZN2js11StringClassE;

HEAP32[__ZL20standard_class_names + 184 >> 2] = STRING_TABLE._js_decodeURIComponent_str | 0;

HEAP32[__ZL20standard_class_names + 188 >> 2] = __ZN2js11StringClassE;

HEAP32[__ZL20standard_class_names + 200 >> 2] = STRING_TABLE._js_encodeURIComponent_str | 0;

HEAP32[__ZL20standard_class_names + 204 >> 2] = __ZN2js11StringClassE;

HEAP32[__ZL20standard_class_names + 216 >> 2] = STRING_TABLE._js_uneval_str | 0;

HEAP32[__ZL20standard_class_names + 220 >> 2] = __ZN2js11StringClassE;

HEAP32[__ZL20standard_class_names + 236 >> 2] = __ZN2js10ErrorClassE;

HEAP32[__ZL20standard_class_names + 252 >> 2] = __ZN2js10ErrorClassE;

HEAP32[__ZL20standard_class_names + 268 >> 2] = __ZN2js10ErrorClassE;

HEAP32[__ZL20standard_class_names + 284 >> 2] = __ZN2js10ErrorClassE;

HEAP32[__ZL20standard_class_names + 300 >> 2] = __ZN2js10ErrorClassE;

HEAP32[__ZL20standard_class_names + 316 >> 2] = __ZN2js10ErrorClassE;

HEAP32[__ZL20standard_class_names + 332 >> 2] = __ZN2js10ErrorClassE;

HEAP32[__ZL20standard_class_names + 348 >> 2] = __ZN2js10ErrorClassE;

HEAP32[__ZL20standard_class_names + 360 >> 2] = STRING_TABLE.__str983250 | 0;

HEAP32[__ZL20standard_class_names + 364 >> 2] = __ZN2js8XMLClassE;

HEAP32[__ZL20standard_class_names + 376 >> 2] = STRING_TABLE._js_isXMLName_str | 0;

HEAP32[__ZL20standard_class_names + 380 >> 2] = __ZN2js8XMLClassE;

HEAP32[__ZL20standard_class_names + 396 >> 2] = __ZN2js13IteratorClassE;

HEAP32[__ZL20standard_class_names + 412 >> 2] = __ZN2js16ArrayBufferClassE;

HEAP32[__ZL20standard_class_names + 428 >> 2] = __ZN2js10TypedArray11fastClassesE | 0;

HEAP32[__ZL20standard_class_names + 444 >> 2] = __ZN2js10TypedArray11fastClassesE + 232 | 0;

HEAP32[__ZL20standard_class_names + 460 >> 2] = __ZN2js10TypedArray11fastClassesE + 464 | 0;

HEAP32[__ZL20standard_class_names + 476 >> 2] = __ZN2js10TypedArray11fastClassesE + 696 | 0;

HEAP32[__ZL20standard_class_names + 492 >> 2] = __ZN2js10TypedArray11fastClassesE + 928 | 0;

HEAP32[__ZL20standard_class_names + 508 >> 2] = __ZN2js10TypedArray11fastClassesE + 1160 | 0;

HEAP32[__ZL20standard_class_names + 524 >> 2] = __ZN2js10TypedArray11fastClassesE + 1392 | 0;

HEAP32[__ZL20standard_class_names + 540 >> 2] = __ZN2js10TypedArray11fastClassesE + 1624 | 0;

HEAP32[__ZL20standard_class_names + 556 >> 2] = __ZN2js10TypedArray11fastClassesE + 1856 | 0;

HEAP32[__ZL20standard_class_names + 572 >> 2] = __ZN2js10ProxyClassE;

HEAP32[__ZL22object_prototype_names + 12 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 28 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 44 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 60 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 76 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 88 >> 2] = STRING_TABLE._js_watch_str | 0;

HEAP32[__ZL22object_prototype_names + 92 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 104 >> 2] = STRING_TABLE._js_unwatch_str | 0;

HEAP32[__ZL22object_prototype_names + 108 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 120 >> 2] = STRING_TABLE.__str184264 | 0;

HEAP32[__ZL22object_prototype_names + 124 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 136 >> 2] = STRING_TABLE._js_isPrototypeOf_str | 0;

HEAP32[__ZL22object_prototype_names + 140 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 152 >> 2] = STRING_TABLE.__str294275 | 0;

HEAP32[__ZL22object_prototype_names + 156 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 168 >> 2] = STRING_TABLE._js_defineGetter_str | 0;

HEAP32[__ZL22object_prototype_names + 172 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 184 >> 2] = STRING_TABLE._js_defineSetter_str | 0;

HEAP32[__ZL22object_prototype_names + 188 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 200 >> 2] = STRING_TABLE._js_lookupGetter_str | 0;

HEAP32[__ZL22object_prototype_names + 204 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 216 >> 2] = STRING_TABLE._js_lookupSetter_str | 0;

HEAP32[__ZL22object_prototype_names + 220 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL15prop_iter_class >> 2] = STRING_TABLE.__str23216 | 0;

HEAP32[__ZN2js10ArrayClassE >> 2] = STRING_TABLE.__str313 | 0;

HEAP32[__ZN2js14SlowArrayClassE >> 2] = STRING_TABLE.__str313 | 0;

HEAP32[__ZL13array_methods >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[__ZL13array_methods + 12 >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[__ZL13array_methods + 24 >> 2] = STRING_TABLE._js_toLocaleString_str | 0;

HEAP32[__ZL13array_methods + 36 >> 2] = STRING_TABLE.__str1318 | 0;

HEAP32[__ZL13array_methods + 48 >> 2] = STRING_TABLE.__str2319 | 0;

HEAP32[__ZL13array_methods + 60 >> 2] = STRING_TABLE.__str3320 | 0;

HEAP32[__ZL13array_methods + 72 >> 2] = STRING_TABLE.__str4321 | 0;

HEAP32[__ZL13array_methods + 84 >> 2] = STRING_TABLE.__str5322 | 0;

HEAP32[__ZL13array_methods + 96 >> 2] = STRING_TABLE.__str6323 | 0;

HEAP32[__ZL13array_methods + 108 >> 2] = STRING_TABLE.__str7324 | 0;

HEAP32[__ZL13array_methods + 120 >> 2] = STRING_TABLE.__str8325 | 0;

HEAP32[__ZL13array_methods + 132 >> 2] = STRING_TABLE.__str193782 | 0;

HEAP32[__ZL13array_methods + 144 >> 2] = STRING_TABLE.__str203783 | 0;

HEAP32[__ZL13array_methods + 156 >> 2] = STRING_TABLE.__str63769 | 0;

HEAP32[__ZL13array_methods + 168 >> 2] = STRING_TABLE.__str73770 | 0;

HEAP32[__ZL13array_methods + 180 >> 2] = STRING_TABLE.__str13330 | 0;

HEAP32[__ZL13array_methods + 192 >> 2] = STRING_TABLE.__str14331 | 0;

HEAP32[__ZL13array_methods + 204 >> 2] = STRING_TABLE.__str15332 | 0;

HEAP32[__ZL13array_methods + 216 >> 2] = STRING_TABLE.__str16333 | 0;

HEAP32[__ZL13array_methods + 228 >> 2] = STRING_TABLE.__str2203372 | 0;

HEAP32[__ZL13array_methods + 240 >> 2] = STRING_TABLE.__str18335 | 0;

HEAP32[__ZL13array_methods + 252 >> 2] = STRING_TABLE.__str19336 | 0;

HEAP32[__ZL20array_static_methods >> 2] = STRING_TABLE.__str20337 | 0;

HEAP32[_js_common_atom_names >> 2] = __str17668 | 0;

HEAP32[_js_common_atom_names + 4 >> 2] = STRING_TABLE.__str42535 | 0;

HEAP32[_js_common_atom_names + 8 >> 2] = STRING_TABLE.__str32534 | 0;

HEAP32[_js_common_atom_names + 12 >> 2] = STRING_TABLE.__str493818 | 0;

HEAP32[_js_common_atom_names + 16 >> 2] = STRING_TABLE.__str267560 | 0;

HEAP32[_js_common_atom_names + 20 >> 2] = STRING_TABLE.__str252545 | 0;

HEAP32[_js_common_atom_names + 24 >> 2] = STRING_TABLE.__str268561 | 0;

HEAP32[_js_common_atom_names + 28 >> 2] = STRING_TABLE.__str32180 | 0;

HEAP32[_js_common_atom_names + 32 >> 2] = STRING_TABLE.__str42181 | 0;

HEAP32[_js_common_atom_names + 36 >> 2] = STRING_TABLE.__str483817 | 0;

HEAP32[_js_common_atom_names + 40 >> 2] = STRING_TABLE.__str269562 | 0;

HEAP32[_js_common_atom_names + 44 >> 2] = STRING_TABLE.__str483817 | 0;

HEAP32[_js_common_atom_names + 48 >> 2] = STRING_TABLE._js_Null_str | 0;

HEAP32[_js_common_atom_names + 52 >> 2] = STRING_TABLE.__str62 | 0;

HEAP32[_js_common_atom_names + 56 >> 2] = STRING_TABLE.__str73060 | 0;

HEAP32[_js_common_atom_names + 60 >> 2] = STRING_TABLE.__str313 | 0;

HEAP32[_js_common_atom_names + 64 >> 2] = STRING_TABLE.__str524 | 0;

HEAP32[_js_common_atom_names + 68 >> 2] = STRING_TABLE._js_JSON_str | 0;

HEAP32[_js_common_atom_names + 72 >> 2] = STRING_TABLE._js_Date_str | 0;

HEAP32[_js_common_atom_names + 76 >> 2] = STRING_TABLE._js_Math_str | 0;

HEAP32[_js_common_atom_names + 80 >> 2] = STRING_TABLE._js_Number_str | 0;

HEAP32[_js_common_atom_names + 84 >> 2] = STRING_TABLE._js_String_str | 0;

HEAP32[_js_common_atom_names + 88 >> 2] = STRING_TABLE._js_RegExp_str | 0;

HEAP32[_js_common_atom_names + 92 >> 2] = STRING_TABLE._js_XML_str | 0;

HEAP32[_js_common_atom_names + 96 >> 2] = STRING_TABLE.__str4236 | 0;

HEAP32[_js_common_atom_names + 100 >> 2] = STRING_TABLE.__str14239 | 0;

HEAP32[_js_common_atom_names + 104 >> 2] = STRING_TABLE.__str11194 | 0;

HEAP32[_js_common_atom_names + 108 >> 2] = STRING_TABLE._js_InternalError_str | 0;

HEAP32[_js_common_atom_names + 112 >> 2] = STRING_TABLE._js_EvalError_str | 0;

HEAP32[_js_common_atom_names + 116 >> 2] = STRING_TABLE._js_RangeError_str | 0;

HEAP32[_js_common_atom_names + 120 >> 2] = STRING_TABLE._js_ReferenceError_str | 0;

HEAP32[_js_common_atom_names + 124 >> 2] = STRING_TABLE._js_SyntaxError_str | 0;

HEAP32[_js_common_atom_names + 128 >> 2] = STRING_TABLE._js_TypeError_str | 0;

HEAP32[_js_common_atom_names + 132 >> 2] = STRING_TABLE._js_URIError_str | 0;

HEAP32[_js_common_atom_names + 136 >> 2] = STRING_TABLE.__str1907 | 0;

HEAP32[_js_common_atom_names + 140 >> 2] = STRING_TABLE._js_StopIteration_str | 0;

HEAP32[_js_common_atom_names + 144 >> 2] = STRING_TABLE.__str13952 | 0;

HEAP32[_js_common_atom_names + 148 >> 2] = STRING_TABLE.__str73960 | 0;

HEAP32[_js_common_atom_names + 152 >> 2] = STRING_TABLE.__str83961 | 0;

HEAP32[_js_common_atom_names + 156 >> 2] = STRING_TABLE.__str93962 | 0;

HEAP32[_js_common_atom_names + 160 >> 2] = STRING_TABLE.__str103963 | 0;

HEAP32[_js_common_atom_names + 164 >> 2] = STRING_TABLE.__str113964 | 0;

HEAP32[_js_common_atom_names + 168 >> 2] = STRING_TABLE.__str123965 | 0;

HEAP32[_js_common_atom_names + 172 >> 2] = STRING_TABLE.__str133966 | 0;

HEAP32[_js_common_atom_names + 176 >> 2] = STRING_TABLE.__str143967 | 0;

HEAP32[_js_common_atom_names + 180 >> 2] = STRING_TABLE.__str153968 | 0;

HEAP32[_js_common_atom_names + 184 >> 2] = STRING_TABLE.__str33051 | 0;

HEAP32[_js_common_atom_names + 188 >> 2] = STRING_TABLE._js_AnyName_str | 0;

HEAP32[_js_common_atom_names + 192 >> 2] = STRING_TABLE.__str4075 | 0;

HEAP32[_js_common_atom_names + 196 >> 2] = STRING_TABLE._js_anonymous_str | 0;

HEAP32[_js_common_atom_names + 200 >> 2] = STRING_TABLE.__str79 | 0;

HEAP32[_js_common_atom_names + 204 >> 2] = STRING_TABLE.__str142435 | 0;

HEAP32[_js_common_atom_names + 208 >> 2] = STRING_TABLE._js_arity_str | 0;

HEAP32[_js_common_atom_names + 212 >> 2] = STRING_TABLE._js_BYTES_PER_ELEMENT_str | 0;

HEAP32[_js_common_atom_names + 216 >> 2] = STRING_TABLE.__str80 | 0;

HEAP32[_js_common_atom_names + 220 >> 2] = STRING_TABLE.__str2093361 | 0;

HEAP32[_js_common_atom_names + 224 >> 2] = STRING_TABLE._js_caller_str | 0;

HEAP32[_js_common_atom_names + 228 >> 2] = STRING_TABLE._js_class_prototype_str | 0;

HEAP32[_js_common_atom_names + 232 >> 2] = STRING_TABLE._js_constructor_str | 0;

HEAP32[_js_common_atom_names + 236 >> 2] = STRING_TABLE.__str1943346 | 0;

HEAP32[_js_common_atom_names + 240 >> 2] = STRING_TABLE.__str60 | 0;

HEAP32[_js_common_atom_names + 244 >> 2] = STRING_TABLE._js_fileName_str | 0;

HEAP32[_js_common_atom_names + 248 >> 2] = STRING_TABLE.__str24079 | 0;

HEAP32[_js_common_atom_names + 252 >> 2] = STRING_TABLE.__str86379 | 0;

HEAP32[_js_common_atom_names + 256 >> 2] = STRING_TABLE.__str283471 | 0;

HEAP32[_js_common_atom_names + 260 >> 2] = STRING_TABLE.__str2213373 | 0;

HEAP32[_js_common_atom_names + 264 >> 2] = STRING_TABLE.__str13442 | 0;

HEAP32[_js_common_atom_names + 268 >> 2] = STRING_TABLE.__str44938 | 0;

HEAP32[_js_common_atom_names + 272 >> 2] = STRING_TABLE._js_iterator_str | 0;

HEAP32[_js_common_atom_names + 276 >> 2] = STRING_TABLE.__str1318 | 0;

HEAP32[_js_common_atom_names + 280 >> 2] = STRING_TABLE.__str303473 | 0;

HEAP32[_js_common_atom_names + 284 >> 2] = STRING_TABLE.__str353798 | 0;

HEAP32[_js_common_atom_names + 288 >> 2] = STRING_TABLE._js_lineNumber_str | 0;

HEAP32[_js_common_atom_names + 292 >> 2] = STRING_TABLE._js_message_str | 0;

HEAP32[_js_common_atom_names + 296 >> 2] = STRING_TABLE.__str23443 | 0;

HEAP32[_js_common_atom_names + 300 >> 2] = STRING_TABLE.__str404286 | 0;

HEAP32[_js_common_atom_names + 304 >> 2] = STRING_TABLE._js_next_str | 0;

HEAP32[_js_common_atom_names + 308 >> 2] = STRING_TABLE._js_noSuchMethod_str | 0;

HEAP32[_js_common_atom_names + 312 >> 2] = STRING_TABLE.__str6436 | 0;

HEAP32[_js_common_atom_names + 316 >> 2] = STRING_TABLE.__str7437 | 0;

HEAP32[_js_common_atom_names + 320 >> 2] = STRING_TABLE._js_proto_str | 0;

HEAP32[_js_common_atom_names + 324 >> 2] = STRING_TABLE.__str44081 | 0;

HEAP32[_js_common_atom_names + 328 >> 2] = STRING_TABLE.__str263469 | 0;

HEAP32[_js_common_atom_names + 332 >> 2] = STRING_TABLE._js_stack_str | 0;

HEAP32[_js_common_atom_names + 336 >> 2] = STRING_TABLE.__str293472 | 0;

HEAP32[_js_common_atom_names + 340 >> 2] = STRING_TABLE._js_toGMTString_str | 0;

HEAP32[_js_common_atom_names + 344 >> 2] = STRING_TABLE._js_toLocaleString_str | 0;

HEAP32[_js_common_atom_names + 348 >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[_js_common_atom_names + 352 >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[_js_common_atom_names + 356 >> 2] = STRING_TABLE.__str38932 | 0;

HEAP32[_js_common_atom_names + 360 >> 2] = STRING_TABLE._js_valueOf_str | 0;

HEAP32[_js_common_atom_names + 364 >> 2] = STRING_TABLE._js_toJSON_str | 0;

HEAP32[_js_common_atom_names + 368 >> 2] = STRING_TABLE.__str8438 | 0;

HEAP32[_js_common_atom_names + 372 >> 2] = STRING_TABLE._js_enumerable_str | 0;

HEAP32[_js_common_atom_names + 376 >> 2] = STRING_TABLE._js_configurable_str | 0;

HEAP32[_js_common_atom_names + 380 >> 2] = STRING_TABLE._js_writable_str | 0;

HEAP32[_js_common_atom_names + 384 >> 2] = STRING_TABLE.__str247540 | 0;

HEAP32[_js_common_atom_names + 388 >> 2] = STRING_TABLE.__str253468 | 0;

HEAP32[_js_common_atom_names + 392 >> 2] = STRING_TABLE.__str9439 | 0;

HEAP32[_js_common_atom_names + 396 >> 2] = STRING_TABLE.__str1823334 | 0;

HEAP32[_js_common_atom_names + 400 >> 2] = STRING_TABLE.__str1783330 | 0;

HEAP32[_js_common_atom_names + 404 >> 2] = STRING_TABLE.__str11097 | 0;

HEAP32[_js_common_atom_names + 408 >> 2] = STRING_TABLE.__str21098 | 0;

HEAP32[_js_common_atom_names + 412 >> 2] = STRING_TABLE.__str14444 | 0;

HEAP32[_js_common_atom_names + 416 >> 2] = STRING_TABLE.__str484294 | 0;

HEAP32[_js_common_atom_names + 420 >> 2] = STRING_TABLE.__str2333385 | 0;

HEAP32[_js_common_atom_names + 424 >> 2] = STRING_TABLE.__str474293 | 0;

HEAP32[_js_common_atom_names + 428 >> 2] = STRING_TABLE._js_qualifier_str | 0;

HEAP32[_js_common_atom_names + 432 >> 2] = STRING_TABLE.__str284577 | 0;

HEAP32[_js_common_atom_names + 436 >> 2] = STRING_TABLE.__str163168 | 0;

HEAP32[_js_common_atom_names + 440 >> 2] = STRING_TABLE.__str253177 | 0;

HEAP32[_js_common_atom_names + 444 >> 2] = STRING_TABLE._js_starQualifier_str | 0;

HEAP32[_js_common_atom_names + 448 >> 2] = STRING_TABLE.__str183170 | 0;

HEAP32[_js_common_atom_names + 452 >> 2] = STRING_TABLE.__str269562 | 0;

HEAP32[_js_common_atom_names + 456 >> 2] = STRING_TABLE.__str15445 | 0;

HEAP32[_js_common_atom_names + 460 >> 2] = STRING_TABLE.__str33051 | 0;

HEAP32[_js_common_atom_names + 464 >> 2] = STRING_TABLE.__str102207 | 0;

HEAP32[_js_common_atom_names + 468 >> 2] = STRING_TABLE.__str18448 | 0;

HEAP32[_js_common_atom_names + 472 >> 2] = STRING_TABLE.__str122209 | 0;

HEAP32[_js_common_atom_names + 476 >> 2] = STRING_TABLE.__str34080 | 0;

HEAP32[_js_common_atom_names + 480 >> 2] = STRING_TABLE.__str152212 | 0;

HEAP32[_js_common_atom_names + 484 >> 2] = STRING_TABLE.__str22452 | 0;

HEAP32[_js_common_atom_names + 488 >> 2] = STRING_TABLE.__str23453 | 0;

HEAP32[_js_common_atom_names + 492 >> 2] = STRING_TABLE.__str14078 | 0;

HEAP32[_js_common_atom_names + 496 >> 2] = STRING_TABLE.__str25455 | 0;

HEAP32[_js_common_atom_names + 500 >> 2] = STRING_TABLE.__str112208 | 0;

HEAP32[_js_common_atom_names + 504 >> 2] = STRING_TABLE.__str27457 | 0;

HEAP32[_js_common_atom_names + 508 >> 2] = STRING_TABLE.__str4075 | 0;

HEAP32[_js_common_atom_names + 512 >> 2] = STRING_TABLE.__str23955 | 0;

HEAP32[_js_common_atom_names + 516 >> 2] = STRING_TABLE.__str30460 | 0;

HEAP32[_js_common_atom_names + 520 >> 2] = STRING_TABLE.__str31461 | 0;

HEAP32[__ZN2js12BooleanClassE >> 2] = STRING_TABLE.__str524 | 0;

HEAP32[__ZL15boolean_methods >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[__ZL15boolean_methods + 12 >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[__ZL15boolean_methods + 24 >> 2] = STRING_TABLE._js_valueOf_str | 0;

HEAP32[_js_ErrorFormatString >> 2] = STRING_TABLE.__str71364 | 0;

HEAP32[_js_ErrorFormatString + 8 >> 2] = STRING_TABLE.__str7652 | 0;

HEAP32[_js_ErrorFormatString + 16 >> 2] = STRING_TABLE.__str8653 | 0;

HEAP32[_js_ErrorFormatString + 24 >> 2] = STRING_TABLE.__str9654 | 0;

HEAP32[_js_ErrorFormatString + 32 >> 2] = STRING_TABLE.__str10655 | 0;

HEAP32[_js_ErrorFormatString + 40 >> 2] = STRING_TABLE.__str11656 | 0;

HEAP32[_js_ErrorFormatString + 48 >> 2] = STRING_TABLE.__str12657 | 0;

HEAP32[_js_ErrorFormatString + 56 >> 2] = STRING_TABLE.__str13658 | 0;

HEAP32[_js_ErrorFormatString + 64 >> 2] = STRING_TABLE.__str14659 | 0;

HEAP32[_js_ErrorFormatString + 72 >> 2] = STRING_TABLE.__str15660 | 0;

HEAP32[_js_ErrorFormatString + 80 >> 2] = STRING_TABLE.__str16661 | 0;

HEAP32[_js_ErrorFormatString + 88 >> 2] = STRING_TABLE.__str17662 | 0;

HEAP32[_js_ErrorFormatString + 96 >> 2] = STRING_TABLE.__str18663 | 0;

HEAP32[_js_ErrorFormatString + 104 >> 2] = STRING_TABLE.__str19664 | 0;

HEAP32[_js_ErrorFormatString + 112 >> 2] = STRING_TABLE.__str20665 | 0;

HEAP32[_js_ErrorFormatString + 120 >> 2] = STRING_TABLE.__str21666 | 0;

HEAP32[_js_ErrorFormatString + 128 >> 2] = STRING_TABLE.__str22667 | 0;

HEAP32[_js_ErrorFormatString + 136 >> 2] = STRING_TABLE.__str23668 | 0;

HEAP32[_js_ErrorFormatString + 144 >> 2] = STRING_TABLE.__str24669 | 0;

HEAP32[_js_ErrorFormatString + 152 >> 2] = STRING_TABLE.__str25670 | 0;

HEAP32[_js_ErrorFormatString + 160 >> 2] = STRING_TABLE.__str26671 | 0;

HEAP32[_js_ErrorFormatString + 168 >> 2] = STRING_TABLE.__str27672 | 0;

HEAP32[_js_ErrorFormatString + 176 >> 2] = STRING_TABLE.__str28673 | 0;

HEAP32[_js_ErrorFormatString + 184 >> 2] = STRING_TABLE.__str29674 | 0;

HEAP32[_js_ErrorFormatString + 192 >> 2] = STRING_TABLE.__str30675 | 0;

HEAP32[_js_ErrorFormatString + 200 >> 2] = STRING_TABLE.__str31676 | 0;

HEAP32[_js_ErrorFormatString + 208 >> 2] = STRING_TABLE.__str32677 | 0;

HEAP32[_js_ErrorFormatString + 216 >> 2] = STRING_TABLE.__str33678 | 0;

HEAP32[_js_ErrorFormatString + 224 >> 2] = STRING_TABLE.__str34679 | 0;

HEAP32[_js_ErrorFormatString + 232 >> 2] = STRING_TABLE.__str35680 | 0;

HEAP32[_js_ErrorFormatString + 240 >> 2] = STRING_TABLE.__str36681 | 0;

HEAP32[_js_ErrorFormatString + 248 >> 2] = STRING_TABLE.__str37682 | 0;

HEAP32[_js_ErrorFormatString + 256 >> 2] = STRING_TABLE.__str38683 | 0;

HEAP32[_js_ErrorFormatString + 264 >> 2] = STRING_TABLE.__str39684 | 0;

HEAP32[_js_ErrorFormatString + 272 >> 2] = STRING_TABLE.__str40685 | 0;

HEAP32[_js_ErrorFormatString + 280 >> 2] = STRING_TABLE.__str41686 | 0;

HEAP32[_js_ErrorFormatString + 288 >> 2] = STRING_TABLE.__str42687 | 0;

HEAP32[_js_ErrorFormatString + 296 >> 2] = STRING_TABLE.__str43688 | 0;

HEAP32[_js_ErrorFormatString + 304 >> 2] = STRING_TABLE.__str44689 | 0;

HEAP32[_js_ErrorFormatString + 312 >> 2] = STRING_TABLE.__str45690 | 0;

HEAP32[_js_ErrorFormatString + 320 >> 2] = STRING_TABLE.__str46691 | 0;

HEAP32[_js_ErrorFormatString + 328 >> 2] = STRING_TABLE.__str47692 | 0;

HEAP32[_js_ErrorFormatString + 336 >> 2] = STRING_TABLE.__str48693 | 0;

HEAP32[_js_ErrorFormatString + 344 >> 2] = STRING_TABLE.__str49694 | 0;

HEAP32[_js_ErrorFormatString + 352 >> 2] = STRING_TABLE.__str50695 | 0;

HEAP32[_js_ErrorFormatString + 360 >> 2] = STRING_TABLE.__str51696 | 0;

HEAP32[_js_ErrorFormatString + 368 >> 2] = STRING_TABLE.__str52697 | 0;

HEAP32[_js_ErrorFormatString + 376 >> 2] = STRING_TABLE.__str53698 | 0;

HEAP32[_js_ErrorFormatString + 384 >> 2] = STRING_TABLE.__str54699 | 0;

HEAP32[_js_ErrorFormatString + 392 >> 2] = STRING_TABLE.__str55700 | 0;

HEAP32[_js_ErrorFormatString + 400 >> 2] = STRING_TABLE.__str56701 | 0;

HEAP32[_js_ErrorFormatString + 408 >> 2] = STRING_TABLE.__str57702 | 0;

HEAP32[_js_ErrorFormatString + 416 >> 2] = STRING_TABLE.__str58703 | 0;

HEAP32[_js_ErrorFormatString + 424 >> 2] = STRING_TABLE.__str59704 | 0;

HEAP32[_js_ErrorFormatString + 432 >> 2] = STRING_TABLE.__str60705 | 0;

HEAP32[_js_ErrorFormatString + 440 >> 2] = STRING_TABLE.__str61706 | 0;

HEAP32[_js_ErrorFormatString + 448 >> 2] = STRING_TABLE.__str62707 | 0;

HEAP32[_js_ErrorFormatString + 456 >> 2] = STRING_TABLE.__str63708 | 0;

HEAP32[_js_ErrorFormatString + 464 >> 2] = STRING_TABLE.__str64709 | 0;

HEAP32[_js_ErrorFormatString + 472 >> 2] = STRING_TABLE.__str65710 | 0;

HEAP32[_js_ErrorFormatString + 480 >> 2] = STRING_TABLE.__str72365 | 0;

HEAP32[_js_ErrorFormatString + 488 >> 2] = STRING_TABLE.__str67712 | 0;

HEAP32[_js_ErrorFormatString + 496 >> 2] = STRING_TABLE.__str68713 | 0;

HEAP32[_js_ErrorFormatString + 504 >> 2] = STRING_TABLE.__str72613 | 0;

HEAP32[_js_ErrorFormatString + 512 >> 2] = STRING_TABLE.__str70715 | 0;

HEAP32[_js_ErrorFormatString + 520 >> 2] = STRING_TABLE.__str71716 | 0;

HEAP32[_js_ErrorFormatString + 528 >> 2] = STRING_TABLE.__str72717 | 0;

HEAP32[_js_ErrorFormatString + 536 >> 2] = STRING_TABLE.__str73718 | 0;

HEAP32[_js_ErrorFormatString + 544 >> 2] = STRING_TABLE.__str74719 | 0;

HEAP32[_js_ErrorFormatString + 552 >> 2] = STRING_TABLE.__str75720 | 0;

HEAP32[_js_ErrorFormatString + 560 >> 2] = STRING_TABLE.__str76721 | 0;

HEAP32[_js_ErrorFormatString + 568 >> 2] = STRING_TABLE.__str77722 | 0;

HEAP32[_js_ErrorFormatString + 576 >> 2] = STRING_TABLE.__str78723 | 0;

HEAP32[_js_ErrorFormatString + 584 >> 2] = STRING_TABLE.__str79724 | 0;

HEAP32[_js_ErrorFormatString + 592 >> 2] = STRING_TABLE.__str80725 | 0;

HEAP32[_js_ErrorFormatString + 600 >> 2] = STRING_TABLE.__str81726 | 0;

HEAP32[_js_ErrorFormatString + 608 >> 2] = STRING_TABLE.__str82727 | 0;

HEAP32[_js_ErrorFormatString + 616 >> 2] = STRING_TABLE.__str83728 | 0;

HEAP32[_js_ErrorFormatString + 624 >> 2] = STRING_TABLE.__str84729 | 0;

HEAP32[_js_ErrorFormatString + 632 >> 2] = STRING_TABLE.__str85730 | 0;

HEAP32[_js_ErrorFormatString + 640 >> 2] = STRING_TABLE.__str86731 | 0;

HEAP32[_js_ErrorFormatString + 648 >> 2] = STRING_TABLE.__str87732 | 0;

HEAP32[_js_ErrorFormatString + 656 >> 2] = STRING_TABLE.__str88733 | 0;

HEAP32[_js_ErrorFormatString + 664 >> 2] = STRING_TABLE.__str89734 | 0;

HEAP32[_js_ErrorFormatString + 672 >> 2] = STRING_TABLE.__str90735 | 0;

HEAP32[_js_ErrorFormatString + 680 >> 2] = STRING_TABLE.__str91736 | 0;

HEAP32[_js_ErrorFormatString + 688 >> 2] = STRING_TABLE.__str92737 | 0;

HEAP32[_js_ErrorFormatString + 696 >> 2] = STRING_TABLE.__str93738 | 0;

HEAP32[_js_ErrorFormatString + 704 >> 2] = STRING_TABLE.__str94739 | 0;

HEAP32[_js_ErrorFormatString + 712 >> 2] = STRING_TABLE.__str95740 | 0;

HEAP32[_js_ErrorFormatString + 720 >> 2] = STRING_TABLE.__str96741 | 0;

HEAP32[_js_ErrorFormatString + 728 >> 2] = STRING_TABLE.__str97742 | 0;

HEAP32[_js_ErrorFormatString + 736 >> 2] = STRING_TABLE.__str98743 | 0;

HEAP32[_js_ErrorFormatString + 744 >> 2] = STRING_TABLE.__str99744 | 0;

HEAP32[_js_ErrorFormatString + 752 >> 2] = STRING_TABLE.__str100745 | 0;

HEAP32[_js_ErrorFormatString + 760 >> 2] = STRING_TABLE.__str101746 | 0;

HEAP32[_js_ErrorFormatString + 768 >> 2] = STRING_TABLE.__str102747 | 0;

HEAP32[_js_ErrorFormatString + 776 >> 2] = STRING_TABLE.__str103748 | 0;

HEAP32[_js_ErrorFormatString + 784 >> 2] = STRING_TABLE.__str104749 | 0;

HEAP32[_js_ErrorFormatString + 792 >> 2] = STRING_TABLE.__str105750 | 0;

HEAP32[_js_ErrorFormatString + 800 >> 2] = STRING_TABLE.__str106751 | 0;

HEAP32[_js_ErrorFormatString + 808 >> 2] = STRING_TABLE.__str107752 | 0;

HEAP32[_js_ErrorFormatString + 816 >> 2] = STRING_TABLE.__str108753 | 0;

HEAP32[_js_ErrorFormatString + 824 >> 2] = STRING_TABLE.__str109754 | 0;

HEAP32[_js_ErrorFormatString + 832 >> 2] = STRING_TABLE.__str110755 | 0;

HEAP32[_js_ErrorFormatString + 840 >> 2] = STRING_TABLE.__str111756 | 0;

HEAP32[_js_ErrorFormatString + 848 >> 2] = STRING_TABLE.__str112757 | 0;

HEAP32[_js_ErrorFormatString + 856 >> 2] = STRING_TABLE.__str113758 | 0;

HEAP32[_js_ErrorFormatString + 864 >> 2] = STRING_TABLE.__str114759 | 0;

HEAP32[_js_ErrorFormatString + 872 >> 2] = STRING_TABLE.__str115760 | 0;

HEAP32[_js_ErrorFormatString + 880 >> 2] = STRING_TABLE.__str116761 | 0;

HEAP32[_js_ErrorFormatString + 888 >> 2] = STRING_TABLE.__str117762 | 0;

HEAP32[_js_ErrorFormatString + 896 >> 2] = STRING_TABLE.__str118763 | 0;

HEAP32[_js_ErrorFormatString + 904 >> 2] = STRING_TABLE.__str119764 | 0;

HEAP32[_js_ErrorFormatString + 912 >> 2] = STRING_TABLE.__str120765 | 0;

HEAP32[_js_ErrorFormatString + 920 >> 2] = STRING_TABLE.__str121766 | 0;

HEAP32[_js_ErrorFormatString + 928 >> 2] = STRING_TABLE.__str122767 | 0;

HEAP32[_js_ErrorFormatString + 936 >> 2] = STRING_TABLE.__str123 | 0;

HEAP32[_js_ErrorFormatString + 944 >> 2] = STRING_TABLE.__str124 | 0;

HEAP32[_js_ErrorFormatString + 952 >> 2] = STRING_TABLE.__str125 | 0;

HEAP32[_js_ErrorFormatString + 960 >> 2] = STRING_TABLE.__str126 | 0;

HEAP32[_js_ErrorFormatString + 968 >> 2] = STRING_TABLE.__str127 | 0;

HEAP32[_js_ErrorFormatString + 976 >> 2] = STRING_TABLE.__str128 | 0;

HEAP32[_js_ErrorFormatString + 984 >> 2] = STRING_TABLE.__str129 | 0;

HEAP32[_js_ErrorFormatString + 992 >> 2] = STRING_TABLE.__str130 | 0;

HEAP32[_js_ErrorFormatString + 1e3 >> 2] = STRING_TABLE.__str131 | 0;

HEAP32[_js_ErrorFormatString + 1008 >> 2] = STRING_TABLE.__str132 | 0;

HEAP32[_js_ErrorFormatString + 1016 >> 2] = STRING_TABLE.__str133 | 0;

HEAP32[_js_ErrorFormatString + 1024 >> 2] = STRING_TABLE.__str134 | 0;

HEAP32[_js_ErrorFormatString + 1032 >> 2] = STRING_TABLE.__str135 | 0;

HEAP32[_js_ErrorFormatString + 1040 >> 2] = STRING_TABLE.__str136 | 0;

HEAP32[_js_ErrorFormatString + 1048 >> 2] = STRING_TABLE.__str137 | 0;

HEAP32[_js_ErrorFormatString + 1056 >> 2] = STRING_TABLE.__str138 | 0;

HEAP32[_js_ErrorFormatString + 1064 >> 2] = STRING_TABLE.__str139 | 0;

HEAP32[_js_ErrorFormatString + 1072 >> 2] = STRING_TABLE.__str140 | 0;

HEAP32[_js_ErrorFormatString + 1080 >> 2] = STRING_TABLE.__str141 | 0;

HEAP32[_js_ErrorFormatString + 1088 >> 2] = STRING_TABLE.__str142 | 0;

HEAP32[_js_ErrorFormatString + 1096 >> 2] = STRING_TABLE.__str143 | 0;

HEAP32[_js_ErrorFormatString + 1104 >> 2] = STRING_TABLE.__str232629 | 0;

HEAP32[_js_ErrorFormatString + 1112 >> 2] = STRING_TABLE.__str145 | 0;

HEAP32[_js_ErrorFormatString + 1120 >> 2] = STRING_TABLE.__str146 | 0;

HEAP32[_js_ErrorFormatString + 1128 >> 2] = STRING_TABLE.__str147 | 0;

HEAP32[_js_ErrorFormatString + 1136 >> 2] = STRING_TABLE.__str148 | 0;

HEAP32[_js_ErrorFormatString + 1144 >> 2] = STRING_TABLE.__str149 | 0;

HEAP32[_js_ErrorFormatString + 1152 >> 2] = STRING_TABLE.__str150 | 0;

HEAP32[_js_ErrorFormatString + 1160 >> 2] = STRING_TABLE.__str151 | 0;

HEAP32[_js_ErrorFormatString + 1168 >> 2] = STRING_TABLE.__str152 | 0;

HEAP32[_js_ErrorFormatString + 1176 >> 2] = STRING_TABLE.__str153 | 0;

HEAP32[_js_ErrorFormatString + 1184 >> 2] = STRING_TABLE.__str154 | 0;

HEAP32[_js_ErrorFormatString + 1192 >> 2] = STRING_TABLE.__str155 | 0;

HEAP32[_js_ErrorFormatString + 1200 >> 2] = STRING_TABLE.__str156768 | 0;

HEAP32[_js_ErrorFormatString + 1208 >> 2] = STRING_TABLE.__str157 | 0;

HEAP32[_js_ErrorFormatString + 1216 >> 2] = STRING_TABLE.__str158 | 0;

HEAP32[_js_ErrorFormatString + 1224 >> 2] = STRING_TABLE.__str159 | 0;

HEAP32[_js_ErrorFormatString + 1232 >> 2] = STRING_TABLE.__str160 | 0;

HEAP32[_js_ErrorFormatString + 1240 >> 2] = STRING_TABLE.__str161 | 0;

HEAP32[_js_ErrorFormatString + 1248 >> 2] = STRING_TABLE.__str162 | 0;

HEAP32[_js_ErrorFormatString + 1256 >> 2] = STRING_TABLE.__str163 | 0;

HEAP32[_js_ErrorFormatString + 1264 >> 2] = STRING_TABLE.__str164 | 0;

HEAP32[_js_ErrorFormatString + 1272 >> 2] = STRING_TABLE.__str165 | 0;

HEAP32[_js_ErrorFormatString + 1280 >> 2] = STRING_TABLE.__str166 | 0;

HEAP32[_js_ErrorFormatString + 1288 >> 2] = STRING_TABLE.__str167 | 0;

HEAP32[_js_ErrorFormatString + 1296 >> 2] = STRING_TABLE.__str168 | 0;

HEAP32[_js_ErrorFormatString + 1304 >> 2] = STRING_TABLE.__str169 | 0;

HEAP32[_js_ErrorFormatString + 1312 >> 2] = STRING_TABLE.__str170 | 0;

HEAP32[_js_ErrorFormatString + 1320 >> 2] = STRING_TABLE.__str171 | 0;

HEAP32[_js_ErrorFormatString + 1328 >> 2] = STRING_TABLE.__str172 | 0;

HEAP32[_js_ErrorFormatString + 1336 >> 2] = STRING_TABLE.__str173 | 0;

HEAP32[_js_ErrorFormatString + 1344 >> 2] = STRING_TABLE.__str174769 | 0;

HEAP32[_js_ErrorFormatString + 1352 >> 2] = STRING_TABLE.__str175 | 0;

HEAP32[_js_ErrorFormatString + 1360 >> 2] = STRING_TABLE.__str176 | 0;

HEAP32[_js_ErrorFormatString + 1368 >> 2] = STRING_TABLE.__str177 | 0;

HEAP32[_js_ErrorFormatString + 1376 >> 2] = STRING_TABLE.__str178 | 0;

HEAP32[_js_ErrorFormatString + 1384 >> 2] = STRING_TABLE.__str179 | 0;

HEAP32[_js_ErrorFormatString + 1392 >> 2] = STRING_TABLE.__str180 | 0;

HEAP32[_js_ErrorFormatString + 1400 >> 2] = STRING_TABLE.__str181 | 0;

HEAP32[_js_ErrorFormatString + 1408 >> 2] = STRING_TABLE.__str182770 | 0;

HEAP32[_js_ErrorFormatString + 1416 >> 2] = STRING_TABLE.__str183 | 0;

HEAP32[_js_ErrorFormatString + 1424 >> 2] = STRING_TABLE.__str184771 | 0;

HEAP32[_js_ErrorFormatString + 1432 >> 2] = STRING_TABLE.__str185 | 0;

HEAP32[_js_ErrorFormatString + 1440 >> 2] = STRING_TABLE.__str186 | 0;

HEAP32[_js_ErrorFormatString + 1448 >> 2] = STRING_TABLE.__str187 | 0;

HEAP32[_js_ErrorFormatString + 1456 >> 2] = STRING_TABLE.__str188772 | 0;

HEAP32[_js_ErrorFormatString + 1464 >> 2] = STRING_TABLE.__str189 | 0;

HEAP32[_js_ErrorFormatString + 1472 >> 2] = STRING_TABLE.__str190 | 0;

HEAP32[_js_ErrorFormatString + 1480 >> 2] = STRING_TABLE.__str191 | 0;

HEAP32[_js_ErrorFormatString + 1488 >> 2] = STRING_TABLE.__str192 | 0;

HEAP32[_js_ErrorFormatString + 1496 >> 2] = STRING_TABLE.__str193 | 0;

HEAP32[_js_ErrorFormatString + 1504 >> 2] = STRING_TABLE.__str194 | 0;

HEAP32[_js_ErrorFormatString + 1512 >> 2] = STRING_TABLE.__str195 | 0;

HEAP32[_js_ErrorFormatString + 1520 >> 2] = STRING_TABLE.__str196 | 0;

HEAP32[_js_ErrorFormatString + 1528 >> 2] = STRING_TABLE.__str197 | 0;

HEAP32[_js_ErrorFormatString + 1536 >> 2] = STRING_TABLE.__str198773 | 0;

HEAP32[_js_ErrorFormatString + 1544 >> 2] = STRING_TABLE.__str199 | 0;

HEAP32[_js_ErrorFormatString + 1552 >> 2] = STRING_TABLE.__str200 | 0;

HEAP32[_js_ErrorFormatString + 1560 >> 2] = STRING_TABLE.__str201 | 0;

HEAP32[_js_ErrorFormatString + 1568 >> 2] = STRING_TABLE.__str202 | 0;

HEAP32[_js_ErrorFormatString + 1576 >> 2] = STRING_TABLE.__str203 | 0;

HEAP32[_js_ErrorFormatString + 1584 >> 2] = STRING_TABLE.__str204 | 0;

HEAP32[_js_ErrorFormatString + 1592 >> 2] = STRING_TABLE.__str205 | 0;

HEAP32[_js_ErrorFormatString + 1600 >> 2] = STRING_TABLE.__str206 | 0;

HEAP32[_js_ErrorFormatString + 1608 >> 2] = STRING_TABLE.__str207 | 0;

HEAP32[_js_ErrorFormatString + 1616 >> 2] = STRING_TABLE.__str208 | 0;

HEAP32[_js_ErrorFormatString + 1624 >> 2] = STRING_TABLE.__str209 | 0;

HEAP32[_js_ErrorFormatString + 1632 >> 2] = STRING_TABLE.__str210 | 0;

HEAP32[_js_ErrorFormatString + 1640 >> 2] = STRING_TABLE.__str211 | 0;

HEAP32[_js_ErrorFormatString + 1648 >> 2] = STRING_TABLE.__str212 | 0;

HEAP32[_js_ErrorFormatString + 1656 >> 2] = STRING_TABLE.__str213 | 0;

HEAP32[_js_ErrorFormatString + 1664 >> 2] = STRING_TABLE.__str214 | 0;

HEAP32[_js_ErrorFormatString + 1672 >> 2] = STRING_TABLE.__str215 | 0;

HEAP32[_js_ErrorFormatString + 1680 >> 2] = STRING_TABLE.__str216 | 0;

HEAP32[_js_ErrorFormatString + 1688 >> 2] = STRING_TABLE.__str217 | 0;

HEAP32[_js_ErrorFormatString + 1696 >> 2] = STRING_TABLE.__str218 | 0;

HEAP32[_js_ErrorFormatString + 1704 >> 2] = STRING_TABLE.__str219 | 0;

HEAP32[_js_ErrorFormatString + 1712 >> 2] = STRING_TABLE.__str220 | 0;

HEAP32[_js_ErrorFormatString + 1720 >> 2] = STRING_TABLE.__str221 | 0;

HEAP32[_js_ErrorFormatString + 1728 >> 2] = STRING_TABLE.__str222 | 0;

HEAP32[_js_ErrorFormatString + 1736 >> 2] = STRING_TABLE.__str223 | 0;

HEAP32[_js_ErrorFormatString + 1744 >> 2] = STRING_TABLE.__str224 | 0;

HEAP32[_js_ErrorFormatString + 1752 >> 2] = STRING_TABLE.__str225 | 0;

HEAP32[_js_ErrorFormatString + 1760 >> 2] = STRING_TABLE.__str226 | 0;

HEAP32[_js_ErrorFormatString + 1768 >> 2] = STRING_TABLE.__str227 | 0;

HEAP32[_js_ErrorFormatString + 1776 >> 2] = STRING_TABLE.__str228 | 0;

HEAP32[_js_ErrorFormatString + 1784 >> 2] = STRING_TABLE.__str229 | 0;

HEAP32[_js_ErrorFormatString + 1792 >> 2] = STRING_TABLE.__str230 | 0;

HEAP32[_js_ErrorFormatString + 1800 >> 2] = STRING_TABLE.__str231 | 0;

HEAP32[_js_ErrorFormatString + 1808 >> 2] = STRING_TABLE.__str232 | 0;

HEAP32[_js_ErrorFormatString + 1816 >> 2] = STRING_TABLE.__str233 | 0;

HEAP32[_js_ErrorFormatString + 1824 >> 2] = STRING_TABLE.__str234 | 0;

HEAP32[_js_ErrorFormatString + 1832 >> 2] = STRING_TABLE.__str235 | 0;

HEAP32[_js_ErrorFormatString + 1840 >> 2] = STRING_TABLE.__str236 | 0;

HEAP32[_js_ErrorFormatString + 1848 >> 2] = STRING_TABLE.__str237 | 0;

HEAP32[_js_ErrorFormatString + 1856 >> 2] = STRING_TABLE.__str238 | 0;

HEAP32[_js_ErrorFormatString + 1864 >> 2] = STRING_TABLE.__str239 | 0;

HEAP32[_js_ErrorFormatString + 1872 >> 2] = STRING_TABLE.__str240 | 0;

HEAP32[_js_ErrorFormatString + 1880 >> 2] = STRING_TABLE.__str241 | 0;

HEAP32[_js_ErrorFormatString + 1888 >> 2] = STRING_TABLE.__str242 | 0;

HEAP32[_js_ErrorFormatString + 1896 >> 2] = STRING_TABLE.__str243 | 0;

HEAP32[_js_ErrorFormatString + 1904 >> 2] = STRING_TABLE.__str244 | 0;

HEAP32[_js_ErrorFormatString + 1912 >> 2] = STRING_TABLE.__str245 | 0;

HEAP32[_js_ErrorFormatString + 1920 >> 2] = STRING_TABLE.__str246 | 0;

HEAP32[_js_ErrorFormatString + 1928 >> 2] = STRING_TABLE.__str247 | 0;

HEAP32[_js_ErrorFormatString + 1936 >> 2] = STRING_TABLE.__str248 | 0;

HEAP32[_js_ErrorFormatString + 1944 >> 2] = STRING_TABLE.__str249 | 0;

HEAP32[_js_ErrorFormatString + 1952 >> 2] = STRING_TABLE.__str250 | 0;

HEAP32[_js_ErrorFormatString + 1960 >> 2] = STRING_TABLE.__str251 | 0;

HEAP32[_js_ErrorFormatString + 1968 >> 2] = STRING_TABLE.__str252 | 0;

HEAP32[_js_ErrorFormatString + 1976 >> 2] = STRING_TABLE.__str253 | 0;

HEAP32[_js_ErrorFormatString + 1984 >> 2] = STRING_TABLE.__str254 | 0;

HEAP32[_js_ErrorFormatString + 1992 >> 2] = STRING_TABLE.__str255 | 0;

HEAP32[_js_ErrorFormatString + 2e3 >> 2] = STRING_TABLE.__str256 | 0;

HEAP32[_js_ErrorFormatString + 2008 >> 2] = STRING_TABLE.__str257 | 0;

HEAP32[_js_ErrorFormatString + 2016 >> 2] = STRING_TABLE.__str258 | 0;

HEAP32[_js_ErrorFormatString + 2024 >> 2] = STRING_TABLE.__str259 | 0;

HEAP32[_js_ErrorFormatString + 2032 >> 2] = STRING_TABLE.__str260 | 0;

HEAP32[_js_ErrorFormatString + 2040 >> 2] = STRING_TABLE.__str261 | 0;

HEAP32[_js_ErrorFormatString + 2048 >> 2] = STRING_TABLE.__str262 | 0;

HEAP32[_js_ErrorFormatString + 2056 >> 2] = STRING_TABLE.__str263 | 0;

HEAP32[_js_ErrorFormatString + 2064 >> 2] = STRING_TABLE.__str264 | 0;

HEAP32[_js_ErrorFormatString + 2072 >> 2] = STRING_TABLE.__str265 | 0;

HEAP32[_js_ErrorFormatString + 2080 >> 2] = STRING_TABLE.__str266 | 0;

HEAP32[_js_ErrorFormatString + 2088 >> 2] = STRING_TABLE.__str267 | 0;

HEAP32[_js_ErrorFormatString + 2096 >> 2] = STRING_TABLE.__str268 | 0;

HEAP32[_js_ErrorFormatString + 2104 >> 2] = STRING_TABLE.__str269 | 0;

HEAP32[_js_ErrorFormatString + 2112 >> 2] = STRING_TABLE.__str270 | 0;

HEAP32[_js_ErrorFormatString + 2120 >> 2] = STRING_TABLE.__str271 | 0;

HEAP32[_js_ErrorFormatString + 2128 >> 2] = STRING_TABLE.__str272 | 0;

HEAP32[_js_ErrorFormatString + 2136 >> 2] = STRING_TABLE.__str273 | 0;

HEAP32[_js_ErrorFormatString + 2144 >> 2] = STRING_TABLE.__str274 | 0;

HEAP32[_js_ErrorFormatString + 2152 >> 2] = STRING_TABLE.__str275 | 0;

HEAP32[_js_ErrorFormatString + 2160 >> 2] = STRING_TABLE.__str276 | 0;

HEAP32[_js_ErrorFormatString + 2168 >> 2] = STRING_TABLE.__str277 | 0;

HEAP32[_js_ErrorFormatString + 2176 >> 2] = STRING_TABLE.__str278 | 0;

HEAP32[_js_ErrorFormatString + 2184 >> 2] = STRING_TABLE.__str279 | 0;

HEAP32[_js_ErrorFormatString + 2192 >> 2] = STRING_TABLE.__str280 | 0;

HEAP32[_js_ErrorFormatString + 2200 >> 2] = STRING_TABLE.__str281 | 0;

HEAP32[_js_ErrorFormatString + 2208 >> 2] = STRING_TABLE.__str282 | 0;

HEAP32[_js_ErrorFormatString + 2216 >> 2] = STRING_TABLE.__str283 | 0;

HEAP32[_js_ErrorFormatString + 2224 >> 2] = STRING_TABLE.__str284 | 0;

HEAP32[_js_ErrorFormatString + 2232 >> 2] = STRING_TABLE.__str285 | 0;

HEAP32[_js_ErrorFormatString + 2240 >> 2] = STRING_TABLE.__str286 | 0;

HEAP32[_js_ErrorFormatString + 2248 >> 2] = STRING_TABLE.__str287 | 0;

HEAP32[_js_ErrorFormatString + 2256 >> 2] = STRING_TABLE.__str288 | 0;

HEAP32[_js_ErrorFormatString + 2264 >> 2] = STRING_TABLE.__str289 | 0;

HEAP32[_js_ErrorFormatString + 2272 >> 2] = STRING_TABLE.__str290 | 0;

HEAP32[_js_ErrorFormatString + 2280 >> 2] = STRING_TABLE.__str291 | 0;

HEAP32[_js_ErrorFormatString + 2288 >> 2] = STRING_TABLE.__str292 | 0;

HEAP32[__ZN2js9DateClassE >> 2] = STRING_TABLE._js_Date_str | 0;

HEAP32[__ZL19date_static_methods >> 2] = STRING_TABLE.__str894 | 0;

HEAP32[__ZL19date_static_methods + 12 >> 2] = STRING_TABLE.__str52345 | 0;

HEAP32[__ZL19date_static_methods + 24 >> 2] = STRING_TABLE.__str2896 | 0;

HEAP32[__ZL12date_methods >> 2] = STRING_TABLE.__str3897 | 0;

HEAP32[__ZL12date_methods + 12 >> 2] = STRING_TABLE.__str4898 | 0;

HEAP32[__ZL12date_methods + 24 >> 2] = STRING_TABLE.__str5899 | 0;

HEAP32[__ZL12date_methods + 36 >> 2] = STRING_TABLE.__str6900 | 0;

HEAP32[__ZL12date_methods + 48 >> 2] = STRING_TABLE.__str7901 | 0;

HEAP32[__ZL12date_methods + 60 >> 2] = STRING_TABLE.__str8902 | 0;

HEAP32[__ZL12date_methods + 72 >> 2] = STRING_TABLE.__str9903 | 0;

HEAP32[__ZL12date_methods + 84 >> 2] = STRING_TABLE.__str10904 | 0;

HEAP32[__ZL12date_methods + 96 >> 2] = STRING_TABLE.__str11905 | 0;

HEAP32[__ZL12date_methods + 108 >> 2] = STRING_TABLE.__str12906 | 0;

HEAP32[__ZL12date_methods + 120 >> 2] = STRING_TABLE.__str13907 | 0;

HEAP32[__ZL12date_methods + 132 >> 2] = STRING_TABLE.__str14908 | 0;

HEAP32[__ZL12date_methods + 144 >> 2] = STRING_TABLE.__str15909 | 0;

HEAP32[__ZL12date_methods + 156 >> 2] = STRING_TABLE.__str16910 | 0;

HEAP32[__ZL12date_methods + 168 >> 2] = STRING_TABLE.__str17911 | 0;

HEAP32[__ZL12date_methods + 180 >> 2] = STRING_TABLE.__str18912 | 0;

HEAP32[__ZL12date_methods + 192 >> 2] = STRING_TABLE.__str19913 | 0;

HEAP32[__ZL12date_methods + 204 >> 2] = STRING_TABLE.__str20914 | 0;

HEAP32[__ZL12date_methods + 216 >> 2] = STRING_TABLE.__str21915 | 0;

HEAP32[__ZL12date_methods + 228 >> 2] = STRING_TABLE.__str22916 | 0;

HEAP32[__ZL12date_methods + 240 >> 2] = STRING_TABLE.__str23917 | 0;

HEAP32[__ZL12date_methods + 252 >> 2] = STRING_TABLE.__str24918 | 0;

HEAP32[__ZL12date_methods + 264 >> 2] = STRING_TABLE.__str25919 | 0;

HEAP32[__ZL12date_methods + 276 >> 2] = STRING_TABLE.__str26920 | 0;

HEAP32[__ZL12date_methods + 288 >> 2] = STRING_TABLE.__str27921 | 0;

HEAP32[__ZL12date_methods + 300 >> 2] = STRING_TABLE.__str28922 | 0;

HEAP32[__ZL12date_methods + 312 >> 2] = STRING_TABLE.__str29923 | 0;

HEAP32[__ZL12date_methods + 324 >> 2] = STRING_TABLE.__str30924 | 0;

HEAP32[__ZL12date_methods + 336 >> 2] = STRING_TABLE.__str31925 | 0;

HEAP32[__ZL12date_methods + 348 >> 2] = STRING_TABLE.__str32926 | 0;

HEAP32[__ZL12date_methods + 360 >> 2] = STRING_TABLE.__str33927 | 0;

HEAP32[__ZL12date_methods + 372 >> 2] = STRING_TABLE.__str34928 | 0;

HEAP32[__ZL12date_methods + 384 >> 2] = STRING_TABLE.__str35929 | 0;

HEAP32[__ZL12date_methods + 396 >> 2] = STRING_TABLE.__str36930 | 0;

HEAP32[__ZL12date_methods + 408 >> 2] = STRING_TABLE.__str37931 | 0;

HEAP32[__ZL12date_methods + 420 >> 2] = STRING_TABLE.__str38932 | 0;

HEAP32[__ZL12date_methods + 432 >> 2] = STRING_TABLE._js_toLocaleString_str | 0;

HEAP32[__ZL12date_methods + 444 >> 2] = STRING_TABLE.__str39933 | 0;

HEAP32[__ZL12date_methods + 456 >> 2] = STRING_TABLE.__str40934 | 0;

HEAP32[__ZL12date_methods + 468 >> 2] = STRING_TABLE.__str41935 | 0;

HEAP32[__ZL12date_methods + 480 >> 2] = STRING_TABLE.__str42936 | 0;

HEAP32[__ZL12date_methods + 492 >> 2] = STRING_TABLE.__str43937 | 0;

HEAP32[__ZL12date_methods + 504 >> 2] = STRING_TABLE.__str44938 | 0;

HEAP32[__ZL12date_methods + 516 >> 2] = STRING_TABLE._js_toJSON_str | 0;

HEAP32[__ZL12date_methods + 528 >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[__ZL12date_methods + 540 >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[__ZL12date_methods + 552 >> 2] = STRING_TABLE._js_valueOf_str | 0;

HEAP32[__ZL3wtb >> 2] = STRING_TABLE.__str45939 | 0;

HEAP32[__ZL3wtb + 4 >> 2] = STRING_TABLE.__str46940 | 0;

HEAP32[__ZL3wtb + 8 >> 2] = STRING_TABLE.__str47941 | 0;

HEAP32[__ZL3wtb + 12 >> 2] = STRING_TABLE.__str48942 | 0;

HEAP32[__ZL3wtb + 16 >> 2] = STRING_TABLE.__str49943 | 0;

HEAP32[__ZL3wtb + 20 >> 2] = STRING_TABLE.__str50944 | 0;

HEAP32[__ZL3wtb + 24 >> 2] = STRING_TABLE.__str51945 | 0;

HEAP32[__ZL3wtb + 28 >> 2] = STRING_TABLE.__str52946 | 0;

HEAP32[__ZL3wtb + 32 >> 2] = STRING_TABLE.__str53947 | 0;

HEAP32[__ZL3wtb + 36 >> 2] = STRING_TABLE.__str54948 | 0;

HEAP32[__ZL3wtb + 40 >> 2] = STRING_TABLE.__str55949 | 0;

HEAP32[__ZL3wtb + 44 >> 2] = STRING_TABLE.__str56950 | 0;

HEAP32[__ZL3wtb + 48 >> 2] = STRING_TABLE.__str57951 | 0;

HEAP32[__ZL3wtb + 52 >> 2] = STRING_TABLE.__str58952 | 0;

HEAP32[__ZL3wtb + 56 >> 2] = STRING_TABLE.__str59953 | 0;

HEAP32[__ZL3wtb + 60 >> 2] = STRING_TABLE.__str60954 | 0;

HEAP32[__ZL3wtb + 64 >> 2] = STRING_TABLE.__str61955 | 0;

HEAP32[__ZL3wtb + 68 >> 2] = STRING_TABLE.__str62956 | 0;

HEAP32[__ZL3wtb + 72 >> 2] = STRING_TABLE.__str63957 | 0;

HEAP32[__ZL3wtb + 76 >> 2] = STRING_TABLE.__str64958 | 0;

HEAP32[__ZL3wtb + 80 >> 2] = STRING_TABLE.__str65959 | 0;

HEAP32[__ZL3wtb + 84 >> 2] = STRING_TABLE.__str66960 | 0;

HEAP32[__ZL3wtb + 88 >> 2] = STRING_TABLE.__str67961 | 0;

HEAP32[__ZL3wtb + 92 >> 2] = STRING_TABLE.__str68962 | 0;

HEAP32[__ZL3wtb + 96 >> 2] = STRING_TABLE.__str69963 | 0;

HEAP32[__ZL3wtb + 100 >> 2] = STRING_TABLE.__str70964 | 0;

HEAP32[__ZL3wtb + 104 >> 2] = STRING_TABLE.__str71965 | 0;

HEAP32[__ZL3wtb + 108 >> 2] = STRING_TABLE.__str72966 | 0;

HEAP32[__ZL3wtb + 112 >> 2] = STRING_TABLE.__str73967 | 0;

HEAP32[__ZL3wtb + 116 >> 2] = STRING_TABLE.__str74968 | 0;

HEAP32[__ZL3wtb + 120 >> 2] = STRING_TABLE.__str75969 | 0;

HEAP32[__ZL3wtb + 124 >> 2] = STRING_TABLE.__str76970 | 0;

HEAP32[__ZL4days >> 2] = STRING_TABLE.__str95989 | 0;

HEAP32[__ZL4days + 4 >> 2] = STRING_TABLE.__str96990 | 0;

HEAP32[__ZL4days + 8 >> 2] = STRING_TABLE.__str97991 | 0;

HEAP32[__ZL4days + 12 >> 2] = STRING_TABLE.__str98992 | 0;

HEAP32[__ZL4days + 16 >> 2] = STRING_TABLE.__str99993 | 0;

HEAP32[__ZL4days + 20 >> 2] = STRING_TABLE.__str100994 | 0;

HEAP32[__ZL4days + 24 >> 2] = STRING_TABLE.__str101995 | 0;

HEAP32[__ZL6months >> 2] = STRING_TABLE.__str83977 | 0;

HEAP32[__ZL6months + 4 >> 2] = STRING_TABLE.__str84978 | 0;

HEAP32[__ZL6months + 8 >> 2] = STRING_TABLE.__str85979 | 0;

HEAP32[__ZL6months + 12 >> 2] = STRING_TABLE.__str86980 | 0;

HEAP32[__ZL6months + 16 >> 2] = STRING_TABLE.__str87981 | 0;

HEAP32[__ZL6months + 20 >> 2] = STRING_TABLE.__str88982 | 0;

HEAP32[__ZL6months + 24 >> 2] = STRING_TABLE.__str89983 | 0;

HEAP32[__ZL6months + 28 >> 2] = STRING_TABLE.__str90984 | 0;

HEAP32[__ZL6months + 32 >> 2] = STRING_TABLE.__str91985 | 0;

HEAP32[__ZL6months + 36 >> 2] = STRING_TABLE.__str92986 | 0;

HEAP32[__ZL6months + 40 >> 2] = STRING_TABLE.__str93987 | 0;

HEAP32[__ZL6months + 44 >> 2] = STRING_TABLE.__str94988 | 0;

HEAP32[_js_SrcNoteSpec >> 2] = STRING_TABLE.__str483817 | 0;

HEAP32[_js_SrcNoteSpec + 8 >> 2] = STRING_TABLE.__str31109 | 0;

HEAP32[_js_SrcNoteSpec + 16 >> 2] = STRING_TABLE.__str41110 | 0;

HEAP32[_js_SrcNoteSpec + 24 >> 2] = STRING_TABLE.__str51111 | 0;

HEAP32[_js_SrcNoteSpec + 32 >> 2] = STRING_TABLE.__str61112 | 0;

HEAP32[_js_SrcNoteSpec + 40 >> 2] = STRING_TABLE.__str71113 | 0;

HEAP32[_js_SrcNoteSpec + 48 >> 2] = STRING_TABLE.__str81114 | 0;

HEAP32[_js_SrcNoteSpec + 56 >> 2] = STRING_TABLE.__str91115 | 0;

HEAP32[_js_SrcNoteSpec + 64 >> 2] = STRING_TABLE.__str101116 | 0;

HEAP32[_js_SrcNoteSpec + 72 >> 2] = STRING_TABLE.__str111117 | 0;

HEAP32[_js_SrcNoteSpec + 80 >> 2] = STRING_TABLE.__str121118 | 0;

HEAP32[_js_SrcNoteSpec + 88 >> 2] = STRING_TABLE.__str131119 | 0;

HEAP32[_js_SrcNoteSpec + 96 >> 2] = STRING_TABLE.__str141120 | 0;

HEAP32[_js_SrcNoteSpec + 104 >> 2] = STRING_TABLE.__str1883340 | 0;

HEAP32[_js_SrcNoteSpec + 112 >> 2] = STRING_TABLE.__str161122 | 0;

HEAP32[_js_SrcNoteSpec + 120 >> 2] = STRING_TABLE.__str171123 | 0;

HEAP32[_js_SrcNoteSpec + 128 >> 2] = STRING_TABLE.__str181124 | 0;

HEAP32[_js_SrcNoteSpec + 136 >> 2] = STRING_TABLE.__str191125 | 0;

HEAP32[_js_SrcNoteSpec + 144 >> 2] = STRING_TABLE.__str201126 | 0;

HEAP32[_js_SrcNoteSpec + 152 >> 2] = STRING_TABLE.__str211127 | 0;

HEAP32[_js_SrcNoteSpec + 160 >> 2] = STRING_TABLE.__str221128 | 0;

HEAP32[_js_SrcNoteSpec + 168 >> 2] = STRING_TABLE.__str231129 | 0;

HEAP32[_js_SrcNoteSpec + 176 >> 2] = STRING_TABLE.__str241130 | 0;

HEAP32[_js_SrcNoteSpec + 184 >> 2] = STRING_TABLE.__str251131 | 0;

HEAP32[_js_SrcNoteSpec + 192 >> 2] = STRING_TABLE.__str261132 | 0;

HEAP32[__ZL13statementName >> 2] = STRING_TABLE.__str271135 | 0;

HEAP32[__ZL13statementName + 4 >> 2] = STRING_TABLE.__str281136 | 0;

HEAP32[__ZL13statementName + 8 >> 2] = STRING_TABLE.__str291137 | 0;

HEAP32[__ZL13statementName + 12 >> 2] = STRING_TABLE.__str301138 | 0;

HEAP32[__ZL13statementName + 16 >> 2] = STRING_TABLE.__str311139 | 0;

HEAP32[__ZL13statementName + 20 >> 2] = STRING_TABLE.__str1993351 | 0;

HEAP32[__ZL13statementName + 24 >> 2] = STRING_TABLE.__ZL21js_with_statement_str | 0;

HEAP32[__ZL13statementName + 28 >> 2] = STRING_TABLE.__str331141 | 0;

HEAP32[__ZL13statementName + 32 >> 2] = STRING_TABLE.__str341142 | 0;

HEAP32[__ZL13statementName + 36 >> 2] = STRING_TABLE.__ZL20js_finally_block_str | 0;

HEAP32[__ZL13statementName + 40 >> 2] = STRING_TABLE.__ZL20js_finally_block_str | 0;

HEAP32[__ZL13statementName + 44 >> 2] = STRING_TABLE.__str351143 | 0;

HEAP32[__ZL13statementName + 48 >> 2] = STRING_TABLE.__str361144 | 0;

HEAP32[__ZL13statementName + 52 >> 2] = STRING_TABLE.__str371145 | 0;

HEAP32[__ZL13statementName + 56 >> 2] = STRING_TABLE.__str381146 | 0;

HEAP32[__ZN2js10ErrorClassE >> 2] = STRING_TABLE.__str11194 | 0;

HEAP32[__ZL17exception_methods >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[__ZL17exception_methods + 12 >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[__ZN2js26StrictArgumentsObjectClassE >> 2] = STRING_TABLE.__str1263 | 0;

HEAP32[__ZN2js26NormalArgumentsObjectClassE >> 2] = STRING_TABLE.__str1263 | 0;

HEAP32[__ZN2js12DeclEnvClassE >> 2] = STRING_TABLE.__str62 | 0;

HEAP32[__ZN2js9CallClassE >> 2] = STRING_TABLE.__str11264 | 0;

HEAP32[__ZN2js13FunctionClassE >> 2] = STRING_TABLE.__str73060 | 0;

HEAP32[__ZN2js16function_methodsE >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[__ZN2js16function_methodsE + 12 >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[__ZN2js16function_methodsE + 24 >> 2] = STRING_TABLE.__str79 | 0;

HEAP32[__ZN2js16function_methodsE + 36 >> 2] = STRING_TABLE.__str80 | 0;

HEAP32[__ZN2js16function_methodsE + 48 >> 2] = STRING_TABLE.__str31270 | 0;

HEAP32[__ZN2js16function_methodsE + 60 >> 2] = STRING_TABLE.__str41271 | 0;

HEAP32[_js_NoSuchMethodClass >> 2] = STRING_TABLE.__str1777 | 0;

HEAP32[__ZN2js13IteratorClassE >> 2] = STRING_TABLE.__str1907 | 0;

HEAP32[__ZL16iterator_methods >> 2] = STRING_TABLE._js_next_str | 0;

HEAP32[__ZN2js18StopIterationClassE >> 2] = STRING_TABLE._js_StopIteration_str | 0;

HEAP32[__ZN2js14GeneratorClassE >> 2] = STRING_TABLE.__str31916 | 0;

HEAP32[__ZL17generator_methods >> 2] = STRING_TABLE._js_next_str | 0;

HEAP32[__ZL17generator_methods + 12 >> 2] = STRING_TABLE._js_send_str | 0;

HEAP32[__ZL17generator_methods + 24 >> 2] = STRING_TABLE.__str31461 | 0;

HEAP32[__ZL17generator_methods + 36 >> 2] = STRING_TABLE._js_close_str | 0;

HEAP32[__ZN2js9MathClassE >> 2] = STRING_TABLE._js_Math_str | 0;

HEAP32[__ZL19math_static_methods >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[__ZL19math_static_methods + 12 >> 2] = STRING_TABLE.__str2000 | 0;

HEAP32[__ZL19math_static_methods + 24 >> 2] = STRING_TABLE.__str12001 | 0;

HEAP32[__ZL19math_static_methods + 36 >> 2] = STRING_TABLE.__str22002 | 0;

HEAP32[__ZL19math_static_methods + 48 >> 2] = STRING_TABLE.__str32003 | 0;

HEAP32[__ZL19math_static_methods + 60 >> 2] = STRING_TABLE.__str42004 | 0;

HEAP32[__ZL19math_static_methods + 72 >> 2] = STRING_TABLE.__str52005 | 0;

HEAP32[__ZL19math_static_methods + 84 >> 2] = STRING_TABLE.__str62006 | 0;

HEAP32[__ZL19math_static_methods + 96 >> 2] = STRING_TABLE.__str72007 | 0;

HEAP32[__ZL19math_static_methods + 108 >> 2] = STRING_TABLE.__str82008 | 0;

HEAP32[__ZL19math_static_methods + 120 >> 2] = STRING_TABLE.__str92009 | 0;

HEAP32[__ZL19math_static_methods + 132 >> 2] = STRING_TABLE.__str102010 | 0;

HEAP32[__ZL19math_static_methods + 144 >> 2] = STRING_TABLE.__str112011 | 0;

HEAP32[__ZL19math_static_methods + 156 >> 2] = STRING_TABLE.__str122012 | 0;

HEAP32[__ZL19math_static_methods + 168 >> 2] = STRING_TABLE.__str132013 | 0;

HEAP32[__ZL19math_static_methods + 180 >> 2] = STRING_TABLE.__str142014 | 0;

HEAP32[__ZL19math_static_methods + 192 >> 2] = STRING_TABLE.__str152015 | 0;

HEAP32[__ZL19math_static_methods + 204 >> 2] = STRING_TABLE.__str162016 | 0;

HEAP32[__ZL19math_static_methods + 216 >> 2] = STRING_TABLE.__str172017 | 0;

HEAP32[__ZL14math_constants + 8 >> 2] = STRING_TABLE.__str182018 | 0;

HEAP32[__ZL14math_constants + 24 >> 2] = STRING_TABLE.__str192019 | 0;

HEAP32[__ZL14math_constants + 40 >> 2] = STRING_TABLE.__str202020 | 0;

HEAP32[__ZL14math_constants + 56 >> 2] = STRING_TABLE.__str212021 | 0;

HEAP32[__ZL14math_constants + 72 >> 2] = STRING_TABLE.__str222022 | 0;

HEAP32[__ZL14math_constants + 88 >> 2] = STRING_TABLE.__str232023 | 0;

HEAP32[__ZL14math_constants + 104 >> 2] = STRING_TABLE.__str242024 | 0;

HEAP32[__ZL14math_constants + 120 >> 2] = STRING_TABLE.__str252025 | 0;

HEAP32[__ZL16number_functions >> 2] = STRING_TABLE._js_isNaN_str | 0;

HEAP32[__ZL16number_functions + 12 >> 2] = STRING_TABLE._js_isFinite_str | 0;

HEAP32[__ZL16number_functions + 24 >> 2] = STRING_TABLE._js_parseFloat_str | 0;

HEAP32[__ZL16number_functions + 36 >> 2] = STRING_TABLE._js_parseInt_str | 0;

HEAP32[__ZN2js11NumberClassE >> 2] = STRING_TABLE._js_Number_str | 0;

HEAP32[__ZL14number_methods >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[__ZL14number_methods + 12 >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[__ZL14number_methods + 24 >> 2] = STRING_TABLE._js_toLocaleString_str | 0;

HEAP32[__ZL14number_methods + 36 >> 2] = STRING_TABLE._js_valueOf_str | 0;

HEAP32[__ZL14number_methods + 48 >> 2] = STRING_TABLE.__str2072 | 0;

HEAP32[__ZL14number_methods + 60 >> 2] = STRING_TABLE.__str12073 | 0;

HEAP32[__ZL14number_methods + 72 >> 2] = STRING_TABLE.__str22074 | 0;

HEAP32[__ZL16number_constants + 8 >> 2] = STRING_TABLE.__str21098 | 0;

HEAP32[__ZL16number_constants + 24 >> 2] = STRING_TABLE.__str82086 | 0;

HEAP32[__ZL16number_constants + 40 >> 2] = STRING_TABLE.__str92087 | 0;

HEAP32[__ZL16number_constants + 56 >> 2] = STRING_TABLE.__str102088 | 0;

HEAP32[__ZL16number_constants + 72 >> 2] = STRING_TABLE.__str112089 | 0;

HEAP32[__ZN2js11ObjectClassE >> 2] = STRING_TABLE.__str62 | 0;

HEAP32[_object_props >> 2] = STRING_TABLE._js_proto_str | 0;

HEAP32[_object_methods >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[_object_methods + 12 >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[_object_methods + 24 >> 2] = STRING_TABLE._js_toLocaleString_str | 0;

HEAP32[_object_methods + 36 >> 2] = STRING_TABLE._js_valueOf_str | 0;

HEAP32[_object_methods + 48 >> 2] = STRING_TABLE._js_watch_str | 0;

HEAP32[_object_methods + 60 >> 2] = STRING_TABLE._js_unwatch_str | 0;

HEAP32[_object_methods + 72 >> 2] = STRING_TABLE.__str184264 | 0;

HEAP32[_object_methods + 84 >> 2] = STRING_TABLE._js_isPrototypeOf_str | 0;

HEAP32[_object_methods + 96 >> 2] = STRING_TABLE.__str294275 | 0;

HEAP32[_object_methods + 108 >> 2] = STRING_TABLE._js_defineGetter_str | 0;

HEAP32[_object_methods + 120 >> 2] = STRING_TABLE._js_defineSetter_str | 0;

HEAP32[_object_methods + 132 >> 2] = STRING_TABLE._js_lookupGetter_str | 0;

HEAP32[_object_methods + 144 >> 2] = STRING_TABLE._js_lookupSetter_str | 0;

HEAP32[_object_static_methods >> 2] = STRING_TABLE.__str92206 | 0;

HEAP32[_object_static_methods + 12 >> 2] = STRING_TABLE.__str102207 | 0;

HEAP32[_object_static_methods + 24 >> 2] = STRING_TABLE.__str112208 | 0;

HEAP32[_object_static_methods + 36 >> 2] = STRING_TABLE.__str122209 | 0;

HEAP32[_object_static_methods + 48 >> 2] = STRING_TABLE.__str132210 | 0;

HEAP32[_object_static_methods + 60 >> 2] = STRING_TABLE.__str53058 | 0;

HEAP32[_object_static_methods + 72 >> 2] = STRING_TABLE.__str152212 | 0;

HEAP32[_object_static_methods + 84 >> 2] = STRING_TABLE.__str162213 | 0;

HEAP32[_object_static_methods + 96 >> 2] = STRING_TABLE.__str172214 | 0;

HEAP32[_object_static_methods + 108 >> 2] = STRING_TABLE.__str182215 | 0;

HEAP32[_object_static_methods + 120 >> 2] = STRING_TABLE.__str192216 | 0;

HEAP32[_object_static_methods + 132 >> 2] = STRING_TABLE.__str202217 | 0;

HEAP32[_object_static_methods + 144 >> 2] = STRING_TABLE.__str212218 | 0;

HEAP32[__ZN2js9WithClassE >> 2] = STRING_TABLE.__str222221 | 0;

HEAP32[__ZN2js10BlockClassE >> 2] = STRING_TABLE.__str232224 | 0;

HEAP32[__ZN2js9JSONClassE >> 2] = STRING_TABLE._js_JSON_str | 0;

HEAP32[__ZL19json_static_methods >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[__ZL19json_static_methods + 12 >> 2] = STRING_TABLE.__str52345 | 0;

HEAP32[__ZL19json_static_methods + 24 >> 2] = STRING_TABLE.__str12532 | 0;

HEAP32[__ZL9CodeToken + 36 >> 2] = STRING_TABLE.__str142435 | 0;

HEAP32[__ZL9CodeToken + 60 >> 2] = STRING_TABLE.__str283180 | 0;

HEAP32[__ZL9CodeToken + 64 >> 2] = STRING_TABLE.__str293181 | 0;

HEAP32[__ZL9CodeToken + 68 >> 2] = STRING_TABLE.__str303182 | 0;

HEAP32[__ZL9CodeToken + 72 >> 2] = STRING_TABLE.__str123164 | 0;

HEAP32[__ZL9CodeToken + 76 >> 2] = STRING_TABLE.__str133165 | 0;

HEAP32[__ZL9CodeToken + 80 >> 2] = STRING_TABLE.__str163168 | 0;

HEAP32[__ZL9CodeToken + 84 >> 2] = STRING_TABLE.__str173169 | 0;

HEAP32[__ZL9CodeToken + 88 >> 2] = STRING_TABLE.__str183170 | 0;

HEAP32[__ZL9CodeToken + 92 >> 2] = STRING_TABLE.__str193171 | 0;

HEAP32[__ZL9CodeToken + 96 >> 2] = STRING_TABLE.__str203172 | 0;

HEAP32[__ZL9CodeToken + 100 >> 2] = STRING_TABLE.__str213173 | 0;

HEAP32[__ZL9CodeToken + 104 >> 2] = STRING_TABLE.__str223174 | 0;

HEAP32[__ZL9CodeToken + 108 >> 2] = STRING_TABLE.__str233175 | 0;

HEAP32[__ZL9CodeToken + 112 >> 2] = STRING_TABLE.__str135428 | 0;

HEAP32[__ZL9CodeToken + 116 >> 2] = STRING_TABLE.__str253177 | 0;

HEAP32[__ZL9CodeToken + 120 >> 2] = STRING_TABLE.__str263178 | 0;

HEAP32[__ZL9CodeToken + 124 >> 2] = STRING_TABLE.__str273179 | 0;

HEAP32[__ZL9CodeToken + 128 >> 2] = STRING_TABLE.__str353187 | 0;

HEAP32[__ZL9CodeToken + 132 >> 2] = STRING_TABLE.__str363188 | 0;

HEAP32[__ZL9CodeToken + 136 >> 2] = STRING_TABLE.__str192692 | 0;

HEAP32[__ZL9CodeToken + 140 >> 2] = STRING_TABLE.__str202693 | 0;

HEAP32[__ZL9CodeToken + 248 >> 2] = STRING_TABLE.__str225518 | 0;

HEAP32[__ZL9CodeToken + 252 >> 2] = STRING_TABLE.__str163973 | 0;

HEAP32[__ZL9CodeToken + 256 >> 2] = STRING_TABLE.__str483817 | 0;

HEAP32[__ZL9CodeToken + 260 >> 2] = STRING_TABLE.__str57 | 0;

HEAP32[__ZL9CodeToken + 264 >> 2] = STRING_TABLE.__str42535 | 0;

HEAP32[__ZL9CodeToken + 268 >> 2] = STRING_TABLE.__str32534 | 0;

HEAP32[__ZL9CodeToken + 288 >> 2] = STRING_TABLE.__str143166 | 0;

HEAP32[__ZL9CodeToken + 292 >> 2] = STRING_TABLE.__str153167 | 0;

HEAP32[__ZL9CodeToken + 308 >> 2] = STRING_TABLE.__str252698 | 0;

HEAP32[__ZL9CodeToken + 452 >> 2] = STRING_TABLE.__str313183 | 0;

HEAP32[__ZL9CodeToken + 456 >> 2] = STRING_TABLE.__str323184 | 0;

HEAP32[__ZL10var_prefix >> 2] = STRING_TABLE.__str1332806 | 0;

HEAP32[__ZL10var_prefix + 4 >> 2] = STRING_TABLE.__str1342807 | 0;

HEAP32[__ZL10var_prefix + 8 >> 2] = STRING_TABLE.__str1352808 | 0;

HEAP32[_table >> 2] = STRING_TABLE.__str2253377 | 0;

HEAP32[_table + 4 >> 2] = STRING_TABLE.__str2233375 | 0;

HEAP32[_table + 8 >> 2] = STRING_TABLE.__str2243376 | 0;

HEAP32[_table + 12 >> 2] = STRING_TABLE.__str252545 | 0;

HEAP32[_table + 16 >> 2] = STRING_TABLE.__str1893341 | 0;

HEAP32[_table + 20 >> 2] = STRING_TABLE.__ZL14js_unknown_str | 0;

HEAP32[__ZL6pm_fns >> 2] = STRING_TABLE.__str1773329 | 0;

HEAP32[__ZL6pm_fns + 12 >> 2] = STRING_TABLE.__str12967 | 0;

HEAP32[__ZL6pm_fns + 24 >> 2] = STRING_TABLE.__str22968 | 0;

HEAP32[__ZL6pm_fns + 36 >> 2] = STRING_TABLE.__str32969 | 0;

HEAP32[__ZL8pm_class >> 2] = STRING_TABLE.__str42970 | 0;

HEAP32[__ZL8pm_props >> 2] = STRING_TABLE.__str182984 | 0;

HEAP32[__ZL8pm_props + 16 >> 2] = STRING_TABLE.__str192985 | 0;

HEAP32[__ZL8pm_props + 32 >> 2] = STRING_TABLE.__str202986 | 0;

HEAP32[__ZL8pm_props + 48 >> 2] = STRING_TABLE.__str212987 | 0;

HEAP32[__ZL8pm_props + 64 >> 2] = STRING_TABLE.__str222988 | 0;

HEAP32[__ZL8pm_props + 80 >> 2] = STRING_TABLE.__str232989 | 0;

HEAP32[__ZL8pm_props + 96 >> 2] = STRING_TABLE.__str242990 | 0;

HEAP32[__ZL8pm_props + 112 >> 2] = STRING_TABLE.__str252991 | 0;

HEAP32[__ZL8pm_props + 128 >> 2] = STRING_TABLE.__str262992 | 0;

HEAP32[__ZL8pm_props + 144 >> 2] = STRING_TABLE.__str272993 | 0;

HEAP32[__ZL8pm_props + 160 >> 2] = STRING_TABLE.__str282994 | 0;

HEAP32[__ZL8pm_props + 176 >> 2] = STRING_TABLE.__str292995 | 0;

HEAP32[__ZL9pm_consts >> 2] = STRING_TABLE.__str52971 | 0;

HEAP32[__ZL9pm_consts + 8 >> 2] = STRING_TABLE.__str62972 | 0;

HEAP32[__ZL9pm_consts + 16 >> 2] = STRING_TABLE.__str72973 | 0;

HEAP32[__ZL9pm_consts + 24 >> 2] = STRING_TABLE.__str82974 | 0;

HEAP32[__ZL9pm_consts + 32 >> 2] = STRING_TABLE.__str92975 | 0;

HEAP32[__ZL9pm_consts + 40 >> 2] = STRING_TABLE.__str102976 | 0;

HEAP32[__ZL9pm_consts + 48 >> 2] = STRING_TABLE.__str112977 | 0;

HEAP32[__ZL9pm_consts + 56 >> 2] = STRING_TABLE.__str122978 | 0;

HEAP32[__ZL9pm_consts + 64 >> 2] = STRING_TABLE.__str132979 | 0;

HEAP32[__ZL9pm_consts + 72 >> 2] = STRING_TABLE.__str142980 | 0;

HEAP32[__ZL9pm_consts + 80 >> 2] = STRING_TABLE.__str152981 | 0;

HEAP32[__ZL9pm_consts + 88 >> 2] = STRING_TABLE.__str162982 | 0;

HEAP32[__ZL9pm_consts + 96 >> 2] = STRING_TABLE.__str172983 | 0;

HEAP32[__ZN22JSScriptedProxyHandler9singletonE >> 2] = __ZTV22JSScriptedProxyHandler + 8 | 0;

HEAP32[__ZN22JSScriptedProxyHandler9singletonE + 4 >> 2] = __ZL27sScriptedProxyHandlerFamily;

HEAP32[__ZN2js16ObjectProxyClassE >> 2] = STRING_TABLE.__str33051 | 0;

HEAP32[__ZN2js21OuterWindowProxyClassE >> 2] = STRING_TABLE.__str33051 | 0;

HEAP32[__ZN2js18FunctionProxyClassE >> 2] = STRING_TABLE.__str33051 | 0;

HEAP32[__ZL14static_methods >> 2] = STRING_TABLE.__str53058 | 0;

HEAP32[__ZL14static_methods + 12 >> 2] = STRING_TABLE.__str63059 | 0;

HEAP32[__ZN2js19CallableObjectClassE >> 2] = STRING_TABLE.__str73060 | 0;

HEAP32[__ZN2js10ProxyClassE >> 2] = STRING_TABLE.__str33051 | 0;

HEAP32[__ZN2js8aopNamesE >> 2] = STRING_TABLE.__str3152 | 0;

HEAP32[__ZN2js8aopNamesE + 4 >> 2] = STRING_TABLE.__str13153 | 0;

HEAP32[__ZN2js8aopNamesE + 8 >> 2] = STRING_TABLE.__str23154 | 0;

HEAP32[__ZN2js8aopNamesE + 12 >> 2] = STRING_TABLE.__str33155 | 0;

HEAP32[__ZN2js8aopNamesE + 16 >> 2] = STRING_TABLE.__str43156 | 0;

HEAP32[__ZN2js8aopNamesE + 20 >> 2] = STRING_TABLE.__str53157 | 0;

HEAP32[__ZN2js8aopNamesE + 24 >> 2] = STRING_TABLE.__str63158 | 0;

HEAP32[__ZN2js8aopNamesE + 28 >> 2] = STRING_TABLE.__str73159 | 0;

HEAP32[__ZN2js8aopNamesE + 32 >> 2] = STRING_TABLE.__str83160 | 0;

HEAP32[__ZN2js8aopNamesE + 36 >> 2] = STRING_TABLE.__str93161 | 0;

HEAP32[__ZN2js8aopNamesE + 40 >> 2] = STRING_TABLE.__str103162 | 0;

HEAP32[__ZN2js8aopNamesE + 44 >> 2] = STRING_TABLE.__str113163 | 0;

HEAP32[__ZN2js10binopNamesE >> 2] = STRING_TABLE.__str123164 | 0;

HEAP32[__ZN2js10binopNamesE + 4 >> 2] = STRING_TABLE.__str133165 | 0;

HEAP32[__ZN2js10binopNamesE + 8 >> 2] = STRING_TABLE.__str143166 | 0;

HEAP32[__ZN2js10binopNamesE + 12 >> 2] = STRING_TABLE.__str153167 | 0;

HEAP32[__ZN2js10binopNamesE + 16 >> 2] = STRING_TABLE.__str163168 | 0;

HEAP32[__ZN2js10binopNamesE + 20 >> 2] = STRING_TABLE.__str173169 | 0;

HEAP32[__ZN2js10binopNamesE + 24 >> 2] = STRING_TABLE.__str183170 | 0;

HEAP32[__ZN2js10binopNamesE + 28 >> 2] = STRING_TABLE.__str193171 | 0;

HEAP32[__ZN2js10binopNamesE + 32 >> 2] = STRING_TABLE.__str203172 | 0;

HEAP32[__ZN2js10binopNamesE + 36 >> 2] = STRING_TABLE.__str213173 | 0;

HEAP32[__ZN2js10binopNamesE + 40 >> 2] = STRING_TABLE.__str223174 | 0;

HEAP32[__ZN2js10binopNamesE + 44 >> 2] = STRING_TABLE.__str233175 | 0;

HEAP32[__ZN2js10binopNamesE + 48 >> 2] = STRING_TABLE.__str135428 | 0;

HEAP32[__ZN2js10binopNamesE + 52 >> 2] = STRING_TABLE.__str253177 | 0;

HEAP32[__ZN2js10binopNamesE + 56 >> 2] = STRING_TABLE.__str263178 | 0;

HEAP32[__ZN2js10binopNamesE + 60 >> 2] = STRING_TABLE.__str273179 | 0;

HEAP32[__ZN2js10binopNamesE + 64 >> 2] = STRING_TABLE.__str283180 | 0;

HEAP32[__ZN2js10binopNamesE + 68 >> 2] = STRING_TABLE.__str293181 | 0;

HEAP32[__ZN2js10binopNamesE + 72 >> 2] = STRING_TABLE.__str303182 | 0;

HEAP32[__ZN2js10binopNamesE + 76 >> 2] = STRING_TABLE.__str313183 | 0;

HEAP32[__ZN2js10binopNamesE + 80 >> 2] = STRING_TABLE.__str323184 | 0;

HEAP32[__ZN2js10binopNamesE + 84 >> 2] = STRING_TABLE.__str333185 | 0;

HEAP32[__ZN2js9unopNamesE >> 2] = STRING_TABLE.__str34080 | 0;

HEAP32[__ZN2js9unopNamesE + 4 >> 2] = STRING_TABLE.__str135428 | 0;

HEAP32[__ZN2js9unopNamesE + 8 >> 2] = STRING_TABLE.__str233175 | 0;

HEAP32[__ZN2js9unopNamesE + 12 >> 2] = STRING_TABLE.__str353187 | 0;

HEAP32[__ZN2js9unopNamesE + 16 >> 2] = STRING_TABLE.__str363188 | 0;

HEAP32[__ZN2js9unopNamesE + 20 >> 2] = STRING_TABLE.__str373189 | 0;

HEAP32[__ZN2js9unopNamesE + 24 >> 2] = STRING_TABLE.__str383190 | 0;

HEAP32[__ZN2js13nodeTypeNamesE >> 2] = STRING_TABLE.__str393191 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 4 >> 2] = STRING_TABLE.__str403192 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 8 >> 2] = STRING_TABLE.__str413193 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 12 >> 2] = STRING_TABLE.__str423194 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 16 >> 2] = STRING_TABLE.__str433195 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 20 >> 2] = STRING_TABLE.__str443196 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 24 >> 2] = STRING_TABLE.__str453197 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 28 >> 2] = STRING_TABLE.__str463198 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 32 >> 2] = STRING_TABLE.__str473199 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 36 >> 2] = STRING_TABLE.__str483200 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 40 >> 2] = STRING_TABLE.__str493201 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 44 >> 2] = STRING_TABLE.__str503202 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 48 >> 2] = STRING_TABLE.__str513203 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 52 >> 2] = STRING_TABLE.__str523204 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 56 >> 2] = STRING_TABLE.__str533205 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 60 >> 2] = STRING_TABLE.__str543206 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 64 >> 2] = STRING_TABLE.__str553207 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 68 >> 2] = STRING_TABLE.__str563208 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 72 >> 2] = STRING_TABLE.__str573209 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 76 >> 2] = STRING_TABLE.__str583210 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 80 >> 2] = STRING_TABLE.__str593211 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 84 >> 2] = STRING_TABLE.__str603212 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 88 >> 2] = STRING_TABLE.__str613213 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 92 >> 2] = STRING_TABLE.__str623214 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 96 >> 2] = STRING_TABLE.__str633215 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 100 >> 2] = STRING_TABLE.__str643216 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 104 >> 2] = STRING_TABLE.__str653217 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 108 >> 2] = STRING_TABLE.__str663218 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 112 >> 2] = STRING_TABLE.__str673219 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 116 >> 2] = STRING_TABLE.__str683220 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 120 >> 2] = STRING_TABLE.__str693221 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 124 >> 2] = STRING_TABLE.__str703222 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 128 >> 2] = STRING_TABLE.__str713223 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 132 >> 2] = STRING_TABLE.__str723224 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 136 >> 2] = STRING_TABLE.__str733225 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 140 >> 2] = STRING_TABLE.__str743226 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 144 >> 2] = STRING_TABLE.__str753227 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 148 >> 2] = STRING_TABLE.__str763228 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 152 >> 2] = STRING_TABLE.__str773229 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 156 >> 2] = STRING_TABLE.__str783230 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 160 >> 2] = STRING_TABLE.__str793231 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 164 >> 2] = STRING_TABLE.__str803232 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 168 >> 2] = STRING_TABLE.__str813233 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 172 >> 2] = STRING_TABLE.__str823234 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 176 >> 2] = STRING_TABLE.__str833235 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 180 >> 2] = STRING_TABLE.__str843236 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 184 >> 2] = STRING_TABLE.__str853237 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 188 >> 2] = STRING_TABLE.__str863238 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 192 >> 2] = STRING_TABLE.__str873239 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 196 >> 2] = STRING_TABLE.__str883240 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 200 >> 2] = STRING_TABLE.__str423194 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 204 >> 2] = STRING_TABLE.__str893241 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 208 >> 2] = STRING_TABLE.__str903242 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 212 >> 2] = STRING_TABLE.__str913243 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 216 >> 2] = STRING_TABLE.__str923244 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 220 >> 2] = STRING_TABLE.__str933245 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 224 >> 2] = STRING_TABLE.__str943246 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 228 >> 2] = STRING_TABLE.__str953247 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 232 >> 2] = STRING_TABLE.__str963248 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 236 >> 2] = STRING_TABLE.__str973249 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 240 >> 2] = STRING_TABLE.__str983250 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 244 >> 2] = STRING_TABLE.__str993251 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 248 >> 2] = STRING_TABLE.__str1003252 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 252 >> 2] = STRING_TABLE.__str1013253 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 256 >> 2] = STRING_TABLE.__str1023254 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 260 >> 2] = STRING_TABLE.__str1033255 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 264 >> 2] = STRING_TABLE.__str1043256 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 268 >> 2] = STRING_TABLE.__str1053257 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 272 >> 2] = STRING_TABLE.__str1063258 | 0;

HEAP32[__ZN2js13callbackNamesE >> 2] = STRING_TABLE.__str1073259 | 0;

HEAP32[__ZN2js13callbackNamesE + 4 >> 2] = STRING_TABLE.__str1083260 | 0;

HEAP32[__ZN2js13callbackNamesE + 8 >> 2] = STRING_TABLE.__str1093261 | 0;

HEAP32[__ZN2js13callbackNamesE + 12 >> 2] = STRING_TABLE.__str1103262 | 0;

HEAP32[__ZN2js13callbackNamesE + 16 >> 2] = STRING_TABLE.__str1113263 | 0;

HEAP32[__ZN2js13callbackNamesE + 20 >> 2] = STRING_TABLE.__str1123264 | 0;

HEAP32[__ZN2js13callbackNamesE + 24 >> 2] = STRING_TABLE.__str1133265 | 0;

HEAP32[__ZN2js13callbackNamesE + 28 >> 2] = STRING_TABLE.__str1143266 | 0;

HEAP32[__ZN2js13callbackNamesE + 32 >> 2] = STRING_TABLE.__str1153267 | 0;

HEAP32[__ZN2js13callbackNamesE + 36 >> 2] = STRING_TABLE.__str1163268 | 0;

HEAP32[__ZN2js13callbackNamesE + 40 >> 2] = STRING_TABLE.__str1173269 | 0;

HEAP32[__ZN2js13callbackNamesE + 44 >> 2] = STRING_TABLE.__str1183270 | 0;

HEAP32[__ZN2js13callbackNamesE + 48 >> 2] = STRING_TABLE.__str1193271 | 0;

HEAP32[__ZN2js13callbackNamesE + 52 >> 2] = STRING_TABLE.__str1203272 | 0;

HEAP32[__ZN2js13callbackNamesE + 56 >> 2] = STRING_TABLE.__str1213273 | 0;

HEAP32[__ZN2js13callbackNamesE + 60 >> 2] = STRING_TABLE.__str1223274 | 0;

HEAP32[__ZN2js13callbackNamesE + 64 >> 2] = STRING_TABLE.__str1233275 | 0;

HEAP32[__ZN2js13callbackNamesE + 68 >> 2] = STRING_TABLE.__str1243276 | 0;

HEAP32[__ZN2js13callbackNamesE + 72 >> 2] = STRING_TABLE.__str1253277 | 0;

HEAP32[__ZN2js13callbackNamesE + 76 >> 2] = STRING_TABLE.__str1263278 | 0;

HEAP32[__ZN2js13callbackNamesE + 80 >> 2] = STRING_TABLE.__str1273279 | 0;

HEAP32[__ZN2js13callbackNamesE + 84 >> 2] = STRING_TABLE.__str1283280 | 0;

HEAP32[__ZN2js13callbackNamesE + 88 >> 2] = STRING_TABLE.__str1293281 | 0;

HEAP32[__ZN2js13callbackNamesE + 92 >> 2] = STRING_TABLE.__str1303282 | 0;

HEAP32[__ZN2js13callbackNamesE + 96 >> 2] = STRING_TABLE.__str1313283 | 0;

HEAP32[__ZN2js13callbackNamesE + 100 >> 2] = STRING_TABLE.__str1323284 | 0;

HEAP32[__ZN2js13callbackNamesE + 104 >> 2] = STRING_TABLE.__str1333285 | 0;

HEAP32[__ZN2js13callbackNamesE + 108 >> 2] = STRING_TABLE.__str1343286 | 0;

HEAP32[__ZN2js13callbackNamesE + 112 >> 2] = STRING_TABLE.__str1353287 | 0;

HEAP32[__ZN2js13callbackNamesE + 116 >> 2] = STRING_TABLE.__str1363288 | 0;

HEAP32[__ZN2js13callbackNamesE + 120 >> 2] = STRING_TABLE.__str1373289 | 0;

HEAP32[__ZN2js13callbackNamesE + 124 >> 2] = STRING_TABLE.__str1383290 | 0;

HEAP32[__ZN2js13callbackNamesE + 128 >> 2] = STRING_TABLE.__str1393291 | 0;

HEAP32[__ZN2js13callbackNamesE + 132 >> 2] = STRING_TABLE.__str1403292 | 0;

HEAP32[__ZN2js13callbackNamesE + 136 >> 2] = STRING_TABLE.__str1413293 | 0;

HEAP32[__ZN2js13callbackNamesE + 140 >> 2] = STRING_TABLE.__str1423294 | 0;

HEAP32[__ZN2js13callbackNamesE + 144 >> 2] = STRING_TABLE.__str1433295 | 0;

HEAP32[__ZN2js13callbackNamesE + 148 >> 2] = STRING_TABLE.__str1443296 | 0;

HEAP32[__ZN2js13callbackNamesE + 152 >> 2] = STRING_TABLE.__str1453297 | 0;

HEAP32[__ZN2js13callbackNamesE + 156 >> 2] = STRING_TABLE.__str1463298 | 0;

HEAP32[__ZN2js13callbackNamesE + 160 >> 2] = STRING_TABLE.__str1473299 | 0;

HEAP32[__ZN2js13callbackNamesE + 164 >> 2] = STRING_TABLE.__str1483300 | 0;

HEAP32[__ZN2js13callbackNamesE + 168 >> 2] = STRING_TABLE.__str1493301 | 0;

HEAP32[__ZN2js13callbackNamesE + 172 >> 2] = STRING_TABLE.__str1503302 | 0;

HEAP32[__ZN2js13callbackNamesE + 176 >> 2] = STRING_TABLE.__str1513303 | 0;

HEAP32[__ZN2js13callbackNamesE + 180 >> 2] = STRING_TABLE.__str1523304 | 0;

HEAP32[__ZN2js13callbackNamesE + 184 >> 2] = STRING_TABLE.__str1533305 | 0;

HEAP32[__ZN2js13callbackNamesE + 188 >> 2] = STRING_TABLE.__str1543306 | 0;

HEAP32[__ZN2js13callbackNamesE + 192 >> 2] = STRING_TABLE.__str1553307 | 0;

HEAP32[__ZN2js13callbackNamesE + 196 >> 2] = STRING_TABLE.__str1563308 | 0;

HEAP32[__ZN2js13callbackNamesE + 200 >> 2] = STRING_TABLE.__str1573309 | 0;

HEAP32[__ZN2js13callbackNamesE + 204 >> 2] = STRING_TABLE.__str1583310 | 0;

HEAP32[__ZN2js13callbackNamesE + 208 >> 2] = STRING_TABLE.__str1593311 | 0;

HEAP32[__ZN2js13callbackNamesE + 212 >> 2] = STRING_TABLE.__str1603312 | 0;

HEAP32[__ZN2js13callbackNamesE + 216 >> 2] = STRING_TABLE.__str1613313 | 0;

HEAP32[__ZN2js13callbackNamesE + 220 >> 2] = STRING_TABLE.__str1623314 | 0;

HEAP32[__ZN2js13callbackNamesE + 224 >> 2] = STRING_TABLE.__str1633315 | 0;

HEAP32[__ZN2js13callbackNamesE + 228 >> 2] = STRING_TABLE.__str1643316 | 0;

HEAP32[__ZN2js13callbackNamesE + 232 >> 2] = STRING_TABLE.__str1653317 | 0;

HEAP32[__ZN2js13callbackNamesE + 236 >> 2] = STRING_TABLE.__str1663318 | 0;

HEAP32[__ZN2js13callbackNamesE + 240 >> 2] = STRING_TABLE.__str1673319 | 0;

HEAP32[__ZN2js13callbackNamesE + 244 >> 2] = STRING_TABLE.__str1683320 | 0;

HEAP32[__ZN2js13callbackNamesE + 248 >> 2] = STRING_TABLE.__str1693321 | 0;

HEAP32[__ZN2js13callbackNamesE + 252 >> 2] = STRING_TABLE.__str1703322 | 0;

HEAP32[__ZN2js13callbackNamesE + 256 >> 2] = STRING_TABLE.__str1713323 | 0;

HEAP32[__ZN2js13callbackNamesE + 260 >> 2] = STRING_TABLE.__str1723324 | 0;

HEAP32[__ZN2js13callbackNamesE + 264 >> 2] = STRING_TABLE.__str1733325 | 0;

HEAP32[__ZN2js13callbackNamesE + 268 >> 2] = STRING_TABLE.__str1743326 | 0;

HEAP32[__ZN2js13callbackNamesE + 272 >> 2] = STRING_TABLE.__str1753327 | 0;

HEAP32[__ZL14static_methods3391 >> 2] = STRING_TABLE.__str52345 | 0;

HEAP32[__ZN2js20regexp_statics_classE >> 2] = STRING_TABLE.__str3439 | 0;

HEAP32[__ZL19regexp_static_props >> 2] = STRING_TABLE.__str13442 | 0;

HEAP32[__ZL19regexp_static_props + 16 >> 2] = STRING_TABLE.__str23443 | 0;

HEAP32[__ZL19regexp_static_props + 32 >> 2] = STRING_TABLE.__str33444 | 0;

HEAP32[__ZL19regexp_static_props + 48 >> 2] = STRING_TABLE.__str43445 | 0;

HEAP32[__ZL19regexp_static_props + 64 >> 2] = STRING_TABLE.__str53446 | 0;

HEAP32[__ZL19regexp_static_props + 80 >> 2] = STRING_TABLE.__str63447 | 0;

HEAP32[__ZL19regexp_static_props + 96 >> 2] = STRING_TABLE.__str73448 | 0;

HEAP32[__ZL19regexp_static_props + 112 >> 2] = STRING_TABLE.__str83449 | 0;

HEAP32[__ZL19regexp_static_props + 128 >> 2] = STRING_TABLE.__str93450 | 0;

HEAP32[__ZL19regexp_static_props + 144 >> 2] = STRING_TABLE.__str103451 | 0;

HEAP32[__ZL19regexp_static_props + 160 >> 2] = STRING_TABLE.__str113452 | 0;

HEAP32[__ZL19regexp_static_props + 176 >> 2] = STRING_TABLE.__str123453 | 0;

HEAP32[__ZL19regexp_static_props + 192 >> 2] = STRING_TABLE.__str133454 | 0;

HEAP32[__ZL19regexp_static_props + 208 >> 2] = STRING_TABLE.__str143455 | 0;

HEAP32[__ZL19regexp_static_props + 224 >> 2] = STRING_TABLE.__str153456 | 0;

HEAP32[__ZL19regexp_static_props + 240 >> 2] = STRING_TABLE.__str163457 | 0;

HEAP32[__ZL19regexp_static_props + 256 >> 2] = STRING_TABLE.__str173458 | 0;

HEAP32[__ZL19regexp_static_props + 272 >> 2] = STRING_TABLE.__str183459 | 0;

HEAP32[__ZL19regexp_static_props + 288 >> 2] = STRING_TABLE.__str193460 | 0;

HEAP32[__ZL19regexp_static_props + 304 >> 2] = STRING_TABLE.__str203461 | 0;

HEAP32[__ZL19regexp_static_props + 320 >> 2] = STRING_TABLE.__str213462 | 0;

HEAP32[__ZN2js11RegExpClassE >> 2] = STRING_TABLE._js_RegExp_str | 0;

HEAP32[__ZL14regexp_methods >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[__ZL14regexp_methods + 12 >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[__ZL14regexp_methods + 24 >> 2] = STRING_TABLE.__str51344 | 0;

HEAP32[__ZL14regexp_methods + 36 >> 2] = STRING_TABLE.__str243467 | 0;

HEAP32[__ZL14regexp_methods + 48 >> 2] = STRING_TABLE.__str253468 | 0;

HEAP32[__ZL8keywords >> 2] = STRING_TABLE.__str42535 | 0;

HEAP32[__ZL8keywords + 16 >> 2] = STRING_TABLE.__str32534 | 0;

HEAP32[__ZL8keywords + 32 >> 2] = STRING_TABLE.__str483817 | 0;

HEAP32[__ZL8keywords + 48 >> 2] = STRING_TABLE._js_break_str | 0;

HEAP32[__ZL8keywords + 64 >> 2] = STRING_TABLE._js_case_str | 0;

HEAP32[__ZL8keywords + 80 >> 2] = STRING_TABLE.__str221128 | 0;

HEAP32[__ZL8keywords + 96 >> 2] = STRING_TABLE.__str71113 | 0;

HEAP32[__ZL8keywords + 112 >> 2] = STRING_TABLE._js_debugger_str | 0;

HEAP32[__ZL8keywords + 128 >> 2] = STRING_TABLE._js_default_str | 0;

HEAP32[__ZL8keywords + 144 >> 2] = STRING_TABLE.__str34080 | 0;

HEAP32[__ZL8keywords + 160 >> 2] = STRING_TABLE._js_do_str | 0;

HEAP32[__ZL8keywords + 176 >> 2] = STRING_TABLE._js_else_str | 0;

HEAP32[__ZL8keywords + 192 >> 2] = STRING_TABLE._js_finally_str | 0;

HEAP32[__ZL8keywords + 208 >> 2] = STRING_TABLE.__str51111 | 0;

HEAP32[__ZL8keywords + 224 >> 2] = STRING_TABLE.__str252545 | 0;

HEAP32[__ZL8keywords + 240 >> 2] = STRING_TABLE.__str31109 | 0;

HEAP32[__ZL8keywords + 256 >> 2] = STRING_TABLE.__str313183 | 0;

HEAP32[__ZL8keywords + 272 >> 2] = STRING_TABLE.__str323184 | 0;

HEAP32[__ZL8keywords + 288 >> 2] = STRING_TABLE._js_new_str | 0;

HEAP32[__ZL8keywords + 304 >> 2] = STRING_TABLE.__str30460 | 0;

HEAP32[__ZL8keywords + 320 >> 2] = STRING_TABLE.__str201126 | 0;

HEAP32[__ZL8keywords + 336 >> 2] = STRING_TABLE.__str57 | 0;

HEAP32[__ZL8keywords + 352 >> 2] = STRING_TABLE.__str31461 | 0;

HEAP32[__ZL8keywords + 368 >> 2] = STRING_TABLE._js_try_str | 0;

HEAP32[__ZL8keywords + 384 >> 2] = STRING_TABLE.__str373189 | 0;

HEAP32[__ZL8keywords + 400 >> 2] = STRING_TABLE.__str2253377 | 0;

HEAP32[__ZL8keywords + 416 >> 2] = STRING_TABLE.__str383190 | 0;

HEAP32[__ZL8keywords + 432 >> 2] = STRING_TABLE.__str61112 | 0;

HEAP32[__ZL8keywords + 448 >> 2] = STRING_TABLE._js_with_str | 0;

HEAP32[__ZL8keywords + 464 >> 2] = STRING_TABLE.__str64 | 0;

HEAP32[__ZL8keywords + 480 >> 2] = STRING_TABLE._js_enum_str | 0;

HEAP32[__ZL8keywords + 496 >> 2] = STRING_TABLE._js_export_str | 0;

HEAP32[__ZL8keywords + 512 >> 2] = STRING_TABLE._js_extends_str | 0;

HEAP32[__ZL8keywords + 528 >> 2] = STRING_TABLE._js_import_str | 0;

HEAP32[__ZL8keywords + 544 >> 2] = STRING_TABLE._js_super_str | 0;

HEAP32[__ZL8keywords + 560 >> 2] = STRING_TABLE.__str2233375 | 0;

HEAP32[__ZL8keywords + 576 >> 2] = STRING_TABLE.__str2243376 | 0;

HEAP32[__ZL8keywords + 592 >> 2] = STRING_TABLE._js_yield_str | 0;

HEAP32[__ZL8keywords + 608 >> 2] = STRING_TABLE._js_implements_str | 0;

HEAP32[__ZL8keywords + 624 >> 2] = STRING_TABLE._js_interface_str | 0;

HEAP32[__ZL8keywords + 640 >> 2] = STRING_TABLE._js_package_str | 0;

HEAP32[__ZL8keywords + 656 >> 2] = STRING_TABLE._js_private_str | 0;

HEAP32[__ZL8keywords + 672 >> 2] = STRING_TABLE._js_protected_str | 0;

HEAP32[__ZL8keywords + 688 >> 2] = STRING_TABLE._js_public_str | 0;

HEAP32[__ZL8keywords + 704 >> 2] = STRING_TABLE._js_static_str | 0;

HEAP32[__ZN2js11ScriptClassE >> 2] = STRING_TABLE.__str23669 | 0;

HEAP32[__ZL16string_functions >> 2] = STRING_TABLE._js_escape_str | 0;

HEAP32[__ZL16string_functions + 12 >> 2] = STRING_TABLE._js_unescape_str | 0;

HEAP32[__ZL16string_functions + 24 >> 2] = STRING_TABLE._js_uneval_str | 0;

HEAP32[__ZL16string_functions + 36 >> 2] = STRING_TABLE._js_decodeURI_str | 0;

HEAP32[__ZL16string_functions + 48 >> 2] = STRING_TABLE._js_encodeURI_str | 0;

HEAP32[__ZL16string_functions + 60 >> 2] = STRING_TABLE._js_decodeURIComponent_str | 0;

HEAP32[__ZL16string_functions + 72 >> 2] = STRING_TABLE._js_encodeURIComponent_str | 0;

HEAP32[_js_EmptySubString + 4 >> 2] = _js_empty_ucstr | 0;

HEAP32[__ZN2js11StringClassE >> 2] = STRING_TABLE._js_String_str | 0;

HEAP32[__ZL14string_methods >> 2] = STRING_TABLE.__str3763 | 0;

HEAP32[__ZL14string_methods + 12 >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[__ZL14string_methods + 24 >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[__ZL14string_methods + 36 >> 2] = STRING_TABLE._js_valueOf_str | 0;

HEAP32[__ZL14string_methods + 48 >> 2] = STRING_TABLE.__str13764 | 0;

HEAP32[__ZL14string_methods + 60 >> 2] = STRING_TABLE.__str23765 | 0;

HEAP32[__ZL14string_methods + 72 >> 2] = STRING_TABLE.__str33766 | 0;

HEAP32[__ZL14string_methods + 84 >> 2] = STRING_TABLE.__str43767 | 0;

HEAP32[__ZL14string_methods + 96 >> 2] = STRING_TABLE.__str53768 | 0;

HEAP32[__ZL14string_methods + 108 >> 2] = STRING_TABLE.__str63769 | 0;

HEAP32[__ZL14string_methods + 120 >> 2] = STRING_TABLE.__str73770 | 0;

HEAP32[__ZL14string_methods + 132 >> 2] = STRING_TABLE.__str83771 | 0;

HEAP32[__ZL14string_methods + 144 >> 2] = STRING_TABLE.__str93772 | 0;

HEAP32[__ZL14string_methods + 156 >> 2] = STRING_TABLE.__str103773 | 0;

HEAP32[__ZL14string_methods + 168 >> 2] = STRING_TABLE.__str113774 | 0;

HEAP32[__ZL14string_methods + 180 >> 2] = STRING_TABLE.__str123775 | 0;

HEAP32[__ZL14string_methods + 192 >> 2] = STRING_TABLE.__str133776 | 0;

HEAP32[__ZL14string_methods + 204 >> 2] = STRING_TABLE.__str143777 | 0;

HEAP32[__ZL14string_methods + 216 >> 2] = STRING_TABLE.__str153778 | 0;

HEAP32[__ZL14string_methods + 228 >> 2] = STRING_TABLE.__str314277 | 0;

HEAP32[__ZL14string_methods + 240 >> 2] = STRING_TABLE.__str173780 | 0;

HEAP32[__ZL14string_methods + 252 >> 2] = STRING_TABLE.__str183781 | 0;

HEAP32[__ZL14string_methods + 264 >> 2] = STRING_TABLE.__str193782 | 0;

HEAP32[__ZL14string_methods + 276 >> 2] = STRING_TABLE.__str203783 | 0;

HEAP32[__ZL14string_methods + 288 >> 2] = STRING_TABLE.__str213784 | 0;

HEAP32[__ZL14string_methods + 300 >> 2] = STRING_TABLE.__str223785 | 0;

HEAP32[__ZL14string_methods + 312 >> 2] = STRING_TABLE.__str233786 | 0;

HEAP32[__ZL14string_methods + 324 >> 2] = STRING_TABLE.__str243787 | 0;

HEAP32[__ZL14string_methods + 336 >> 2] = STRING_TABLE.__str253788 | 0;

HEAP32[__ZL14string_methods + 348 >> 2] = STRING_TABLE.__str263789 | 0;

HEAP32[__ZL14string_methods + 360 >> 2] = STRING_TABLE.__str273790 | 0;

HEAP32[__ZL14string_methods + 372 >> 2] = STRING_TABLE.__str283791 | 0;

HEAP32[__ZL14string_methods + 384 >> 2] = STRING_TABLE.__str293792 | 0;

HEAP32[__ZL14string_methods + 396 >> 2] = STRING_TABLE.__str303793 | 0;

HEAP32[__ZL14string_methods + 408 >> 2] = STRING_TABLE.__str313794 | 0;

HEAP32[__ZL14string_methods + 420 >> 2] = STRING_TABLE.__str323795 | 0;

HEAP32[__ZL14string_methods + 432 >> 2] = STRING_TABLE.__str333796 | 0;

HEAP32[__ZL21string_static_methods >> 2] = STRING_TABLE.__str343797 | 0;

HEAP32[__ZN2js11ArrayBuffer9slowClassE >> 2] = STRING_TABLE.__str13952 | 0;

HEAP32[__ZN2js16ArrayBufferClassE >> 2] = STRING_TABLE.__str13952 | 0;

HEAP32[__ZN2js11ArrayBuffer7jspropsE >> 2] = STRING_TABLE.__str23955 | 0;

HEAP32[__ZN2js10TypedArray7jspropsE >> 2] = STRING_TABLE.__str353798 | 0;

HEAP32[__ZN2js10TypedArray7jspropsE + 16 >> 2] = STRING_TABLE.__str23955 | 0;

HEAP32[__ZN2js10TypedArray7jspropsE + 32 >> 2] = STRING_TABLE.__str33956 | 0;

HEAP32[__ZN2js10TypedArray7jspropsE + 48 >> 2] = STRING_TABLE.__str43957 | 0;

HEAP32[__ZN9Int8Array7jsfuncsE >> 2] = STRING_TABLE.__str53958 | 0;

HEAP32[__ZN9Int8Array7jsfuncsE + 12 >> 2] = STRING_TABLE.__str44081 | 0;

HEAP32[__ZN10Uint8Array7jsfuncsE >> 2] = STRING_TABLE.__str53958 | 0;

HEAP32[__ZN10Uint8Array7jsfuncsE + 12 >> 2] = STRING_TABLE.__str44081 | 0;

HEAP32[__ZN10Int16Array7jsfuncsE >> 2] = STRING_TABLE.__str53958 | 0;

HEAP32[__ZN10Int16Array7jsfuncsE + 12 >> 2] = STRING_TABLE.__str44081 | 0;

HEAP32[__ZN11Uint16Array7jsfuncsE >> 2] = STRING_TABLE.__str53958 | 0;

HEAP32[__ZN11Uint16Array7jsfuncsE + 12 >> 2] = STRING_TABLE.__str44081 | 0;

HEAP32[__ZN10Int32Array7jsfuncsE >> 2] = STRING_TABLE.__str53958 | 0;

HEAP32[__ZN10Int32Array7jsfuncsE + 12 >> 2] = STRING_TABLE.__str44081 | 0;

HEAP32[__ZN11Uint32Array7jsfuncsE >> 2] = STRING_TABLE.__str53958 | 0;

HEAP32[__ZN11Uint32Array7jsfuncsE + 12 >> 2] = STRING_TABLE.__str44081 | 0;

HEAP32[__ZN12Float32Array7jsfuncsE >> 2] = STRING_TABLE.__str53958 | 0;

HEAP32[__ZN12Float32Array7jsfuncsE + 12 >> 2] = STRING_TABLE.__str44081 | 0;

HEAP32[__ZN12Float64Array7jsfuncsE >> 2] = STRING_TABLE.__str53958 | 0;

HEAP32[__ZN12Float64Array7jsfuncsE + 12 >> 2] = STRING_TABLE.__str44081 | 0;

HEAP32[__ZN17Uint8ClampedArray7jsfuncsE >> 2] = STRING_TABLE.__str53958 | 0;

HEAP32[__ZN17Uint8ClampedArray7jsfuncsE + 12 >> 2] = STRING_TABLE.__str44081 | 0;

HEAP32[__ZN2js10TypedArray11fastClassesE >> 2] = STRING_TABLE.__str73960 | 0;

HEAP32[__ZN2js10TypedArray11fastClassesE + 232 >> 2] = STRING_TABLE.__str83961 | 0;

HEAP32[__ZN2js10TypedArray11fastClassesE + 464 >> 2] = STRING_TABLE.__str93962 | 0;

HEAP32[__ZN2js10TypedArray11fastClassesE + 696 >> 2] = STRING_TABLE.__str103963 | 0;

HEAP32[__ZN2js10TypedArray11fastClassesE + 928 >> 2] = STRING_TABLE.__str113964 | 0;

HEAP32[__ZN2js10TypedArray11fastClassesE + 1160 >> 2] = STRING_TABLE.__str123965 | 0;

HEAP32[__ZN2js10TypedArray11fastClassesE + 1392 >> 2] = STRING_TABLE.__str133966 | 0;

HEAP32[__ZN2js10TypedArray11fastClassesE + 1624 >> 2] = STRING_TABLE.__str143967 | 0;

HEAP32[__ZN2js10TypedArray11fastClassesE + 1856 >> 2] = STRING_TABLE.__str153968 | 0;

HEAP32[__ZN2js10TypedArray11slowClassesE >> 2] = STRING_TABLE.__str73960 | 0;

HEAP32[__ZN2js10TypedArray11slowClassesE + 232 >> 2] = STRING_TABLE.__str83961 | 0;

HEAP32[__ZN2js10TypedArray11slowClassesE + 464 >> 2] = STRING_TABLE.__str93962 | 0;

HEAP32[__ZN2js10TypedArray11slowClassesE + 696 >> 2] = STRING_TABLE.__str103963 | 0;

HEAP32[__ZN2js10TypedArray11slowClassesE + 928 >> 2] = STRING_TABLE.__str113964 | 0;

HEAP32[__ZN2js10TypedArray11slowClassesE + 1160 >> 2] = STRING_TABLE.__str123965 | 0;

HEAP32[__ZN2js10TypedArray11slowClassesE + 1392 >> 2] = STRING_TABLE.__str133966 | 0;

HEAP32[__ZN2js10TypedArray11slowClassesE + 1624 >> 2] = STRING_TABLE.__str143967 | 0;

HEAP32[__ZN2js10TypedArray11slowClassesE + 1856 >> 2] = STRING_TABLE.__str153968 | 0;

HEAP32[__ZN2js12WeakMapClassE >> 2] = STRING_TABLE.__str4075 | 0;

HEAP32[__ZL16weak_map_methods >> 2] = STRING_TABLE.__str14078 | 0;

HEAP32[__ZL16weak_map_methods + 12 >> 2] = STRING_TABLE.__str24079 | 0;

HEAP32[__ZL16weak_map_methods + 24 >> 2] = STRING_TABLE.__str34080 | 0;

HEAP32[__ZL16weak_map_methods + 36 >> 2] = STRING_TABLE.__str44081 | 0;

HEAP32[__ZN9JSWrapper9singletonE >> 2] = __ZTV9JSWrapper + 8 | 0;

HEAP32[__ZN9JSWrapper9singletonE + 4 >> 2] = __ZL14sWrapperFamily;

HEAP32[__ZN25JSCrossCompartmentWrapper9singletonE >> 2] = __ZTV25JSCrossCompartmentWrapper + 8 | 0;

HEAP32[__ZN25JSCrossCompartmentWrapper9singletonE + 4 >> 2] = __ZL14sWrapperFamily;

HEAP32[__ZN2js14NamespaceClassE >> 2] = STRING_TABLE.__str4236 | 0;

HEAP32[__ZL17namespace_methods >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[__ZN2js10QNameClassE >> 2] = STRING_TABLE.__str14239 | 0;

HEAP32[__ZN2js18AttributeNameClassE >> 2] = STRING_TABLE._js_AttributeName_str | 0;

HEAP32[__ZN2js12AnyNameClassE >> 2] = STRING_TABLE._js_AnyName_str | 0;

HEAP32[__ZL13qname_methods >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[__ZL16xml_static_props >> 2] = STRING_TABLE.__ZL21js_ignoreComments_str | 0;

HEAP32[__ZL16xml_static_props + 16 >> 2] = STRING_TABLE.__ZL35js_ignoreProcessingInstructions_str | 0;

HEAP32[__ZL16xml_static_props + 32 >> 2] = STRING_TABLE.__ZL23js_ignoreWhitespace_str | 0;

HEAP32[__ZL16xml_static_props + 48 >> 2] = STRING_TABLE.__ZL21js_prettyPrinting_str | 0;

HEAP32[__ZL16xml_static_props + 64 >> 2] = STRING_TABLE.__ZL19js_prettyIndent_str | 0;

HEAP32[__ZN2js8XMLClassE >> 2] = STRING_TABLE._js_XML_str | 0;

HEAP32[_js_xml_class_str >> 2] = STRING_TABLE.__str34249 | 0;

HEAP32[_js_xml_class_str + 4 >> 2] = STRING_TABLE.__str44250 | 0;

HEAP32[_js_xml_class_str + 8 >> 2] = STRING_TABLE.__str2343386 | 0;

HEAP32[_js_xml_class_str + 12 >> 2] = STRING_TABLE.__str54251 | 0;

HEAP32[_js_xml_class_str + 16 >> 2] = STRING_TABLE.__str2363388 | 0;

HEAP32[_js_xml_class_str + 20 >> 2] = STRING_TABLE.__str64252 | 0;

HEAP32[__ZL11xml_methods >> 2] = STRING_TABLE.__str74253 | 0;

HEAP32[__ZL11xml_methods + 12 >> 2] = STRING_TABLE.__str84254 | 0;

HEAP32[__ZL11xml_methods + 24 >> 2] = STRING_TABLE.__str2343386 | 0;

HEAP32[__ZL11xml_methods + 36 >> 2] = STRING_TABLE.__str94255 | 0;

HEAP32[__ZL11xml_methods + 48 >> 2] = STRING_TABLE.__str104256 | 0;

HEAP32[__ZL11xml_methods + 60 >> 2] = STRING_TABLE.__str114257 | 0;

HEAP32[__ZL11xml_methods + 72 >> 2] = STRING_TABLE.__str124258 | 0;

HEAP32[__ZL11xml_methods + 84 >> 2] = STRING_TABLE.__str134259 | 0;

HEAP32[__ZL11xml_methods + 96 >> 2] = STRING_TABLE.__str144260 | 0;

HEAP32[__ZL11xml_methods + 108 >> 2] = STRING_TABLE.__str154261 | 0;

HEAP32[__ZL11xml_methods + 120 >> 2] = STRING_TABLE.__str164262 | 0;

HEAP32[__ZL11xml_methods + 132 >> 2] = STRING_TABLE.__str174263 | 0;

HEAP32[__ZL11xml_methods + 144 >> 2] = STRING_TABLE.__str184264 | 0;

HEAP32[__ZL11xml_methods + 156 >> 2] = STRING_TABLE.__str194265 | 0;

HEAP32[__ZL11xml_methods + 168 >> 2] = STRING_TABLE.__str204266 | 0;

HEAP32[__ZL11xml_methods + 180 >> 2] = STRING_TABLE.__str214267 | 0;

HEAP32[__ZL11xml_methods + 192 >> 2] = STRING_TABLE.__str224268 | 0;

HEAP32[__ZL11xml_methods + 204 >> 2] = STRING_TABLE.__str234269 | 0;

HEAP32[__ZL11xml_methods + 216 >> 2] = STRING_TABLE.__str353798 | 0;

HEAP32[__ZL11xml_methods + 228 >> 2] = STRING_TABLE.__ZL16js_localName_str | 0;

HEAP32[__ZL11xml_methods + 240 >> 2] = STRING_TABLE.__str404286 | 0;

HEAP32[__ZL11xml_methods + 252 >> 2] = STRING_TABLE.__str2333385 | 0;

HEAP32[__ZL11xml_methods + 264 >> 2] = STRING_TABLE.__str244270 | 0;

HEAP32[__ZL11xml_methods + 276 >> 2] = STRING_TABLE.__str254271 | 0;

HEAP32[__ZL11xml_methods + 288 >> 2] = STRING_TABLE.__str264272 | 0;

HEAP32[__ZL11xml_methods + 300 >> 2] = STRING_TABLE.__str55348 | 0;

HEAP32[__ZL11xml_methods + 312 >> 2] = STRING_TABLE.__str274273 | 0;

HEAP32[__ZL11xml_methods + 324 >> 2] = STRING_TABLE.__str284274 | 0;

HEAP32[__ZL11xml_methods + 336 >> 2] = STRING_TABLE.__str294275 | 0;

HEAP32[__ZL11xml_methods + 348 >> 2] = STRING_TABLE.__str304276 | 0;

HEAP32[__ZL11xml_methods + 360 >> 2] = STRING_TABLE.__str314277 | 0;

HEAP32[__ZL11xml_methods + 372 >> 2] = STRING_TABLE.__str324278 | 0;

HEAP32[__ZL11xml_methods + 384 >> 2] = STRING_TABLE.__str334279 | 0;

HEAP32[__ZL11xml_methods + 396 >> 2] = STRING_TABLE.__str344280 | 0;

HEAP32[__ZL11xml_methods + 408 >> 2] = STRING_TABLE.__str354281 | 0;

HEAP32[__ZL11xml_methods + 420 >> 2] = STRING_TABLE.__str2363388 | 0;

HEAP32[__ZL11xml_methods + 432 >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[__ZL11xml_methods + 444 >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[__ZL11xml_methods + 456 >> 2] = STRING_TABLE.__ZL18js_toXMLString_str | 0;

HEAP32[__ZL11xml_methods + 468 >> 2] = STRING_TABLE._js_valueOf_str | 0;

HEAP32[__ZL18xml_static_methods >> 2] = STRING_TABLE.__str364282 | 0;

HEAP32[__ZL18xml_static_methods + 12 >> 2] = STRING_TABLE.__str374283 | 0;

HEAP32[__ZL18xml_static_methods + 24 >> 2] = STRING_TABLE.__str384284 | 0;

HEAP32[__ZL15namespace_props >> 2] = STRING_TABLE.__str2033355 | 0;

HEAP32[__ZL15namespace_props + 16 >> 2] = STRING_TABLE.__ZL10js_uri_str | 0;

HEAP32[_js_XMLFilterClass >> 2] = STRING_TABLE.__str454291 | 0;

HEAP32[__ZL11qname_props >> 2] = STRING_TABLE.__ZL10js_uri_str | 0;

HEAP32[__ZL11qname_props + 16 >> 2] = STRING_TABLE.__ZL16js_localName_str | 0;

HEAP32[__ZL13sandbox_class >> 2] = STRING_TABLE.__str2295 | 0;

HEAP32[__ZL14resolver_class >> 2] = STRING_TABLE.__str3296 | 0;

HEAP32[__ZL15shell_functions >> 2] = STRING_TABLE.__str8301 | 0;

HEAP32[__ZL15shell_functions + 12 >> 2] = STRING_TABLE.__str9302 | 0;

HEAP32[__ZL15shell_functions + 24 >> 2] = STRING_TABLE.__str10303 | 0;

HEAP32[__ZL15shell_functions + 36 >> 2] = STRING_TABLE.__str11304 | 0;

HEAP32[__ZL15shell_functions + 48 >> 2] = STRING_TABLE.__str12305 | 0;

HEAP32[__ZL15shell_functions + 60 >> 2] = STRING_TABLE.__str13306 | 0;

HEAP32[__ZL15shell_functions + 72 >> 2] = STRING_TABLE.__str14307 | 0;

HEAP32[__ZL15shell_functions + 84 >> 2] = STRING_TABLE.__str15308 | 0;

HEAP32[__ZL15shell_functions + 96 >> 2] = STRING_TABLE.__str16309 | 0;

HEAP32[__ZL15shell_functions + 108 >> 2] = STRING_TABLE.__str17310 | 0;

HEAP32[__ZL15shell_functions + 120 >> 2] = STRING_TABLE.__str18311 | 0;

HEAP32[__ZL15shell_functions + 132 >> 2] = STRING_TABLE.__str19312 | 0;

HEAP32[__ZL15shell_functions + 144 >> 2] = STRING_TABLE.__str20313 | 0;

HEAP32[__ZL15shell_functions + 156 >> 2] = STRING_TABLE.__str21314 | 0;

HEAP32[__ZL15shell_functions + 168 >> 2] = STRING_TABLE.__str22315 | 0;

HEAP32[__ZL15shell_functions + 180 >> 2] = STRING_TABLE.__str23316 | 0;

HEAP32[__ZL15shell_functions + 192 >> 2] = STRING_TABLE.__str24317 | 0;

HEAP32[__ZL15shell_functions + 204 >> 2] = STRING_TABLE.__str25318 | 0;

HEAP32[__ZL15shell_functions + 216 >> 2] = STRING_TABLE.__str26319 | 0;

HEAP32[__ZL15shell_functions + 228 >> 2] = STRING_TABLE.__str27320 | 0;

HEAP32[__ZL15shell_functions + 240 >> 2] = STRING_TABLE.__str28321 | 0;

HEAP32[__ZL15shell_functions + 252 >> 2] = STRING_TABLE.__str29322 | 0;

HEAP32[__ZL15shell_functions + 264 >> 2] = STRING_TABLE.__str30323 | 0;

HEAP32[__ZL15shell_functions + 276 >> 2] = STRING_TABLE.__str31324 | 0;

HEAP32[__ZL15shell_functions + 288 >> 2] = STRING_TABLE.__str32325 | 0;

HEAP32[__ZL15shell_functions + 300 >> 2] = STRING_TABLE.__str33326 | 0;

HEAP32[__ZL15shell_functions + 312 >> 2] = STRING_TABLE.__str34327 | 0;

HEAP32[__ZL15shell_functions + 324 >> 2] = STRING_TABLE.__str35328 | 0;

HEAP32[__ZL15shell_functions + 336 >> 2] = STRING_TABLE.__str36329 | 0;

HEAP32[__ZL15shell_functions + 348 >> 2] = STRING_TABLE.__str37330 | 0;

HEAP32[__ZL15shell_functions + 360 >> 2] = STRING_TABLE.__str38331 | 0;

HEAP32[__ZL15shell_functions + 372 >> 2] = STRING_TABLE.__str39332 | 0;

HEAP32[__ZL15shell_functions + 384 >> 2] = STRING_TABLE.__str40333 | 0;

HEAP32[__ZL15shell_functions + 396 >> 2] = STRING_TABLE.__str41334 | 0;

HEAP32[__ZL15shell_functions + 408 >> 2] = STRING_TABLE.__str42335 | 0;

HEAP32[__ZL15shell_functions + 420 >> 2] = STRING_TABLE.__str43336 | 0;

HEAP32[__ZL15shell_functions + 432 >> 2] = STRING_TABLE.__str44337 | 0;

HEAP32[__ZL15shell_functions + 444 >> 2] = STRING_TABLE.__str45338 | 0;

HEAP32[__ZL15shell_functions + 456 >> 2] = STRING_TABLE.__str46339 | 0;

HEAP32[__ZL15shell_functions + 468 >> 2] = STRING_TABLE.__str47340 | 0;

HEAP32[__ZL15shell_functions + 480 >> 2] = STRING_TABLE.__str48341 | 0;

HEAP32[__ZL15shell_functions + 492 >> 2] = STRING_TABLE.__str3296 | 0;

HEAP32[__ZL15shell_functions + 504 >> 2] = STRING_TABLE.__str49342 | 0;

HEAP32[__ZL15shell_functions + 516 >> 2] = STRING_TABLE.__str50343 | 0;

HEAP32[__ZL15shell_functions + 528 >> 2] = STRING_TABLE.__str51344 | 0;

HEAP32[__ZL15shell_functions + 540 >> 2] = STRING_TABLE.__str52345 | 0;

HEAP32[__ZL15shell_functions + 552 >> 2] = STRING_TABLE.__str53346 | 0;

HEAP32[__ZL15shell_functions + 564 >> 2] = STRING_TABLE.__str54347 | 0;

HEAP32[__ZL15shell_functions + 576 >> 2] = STRING_TABLE.__str55348 | 0;

HEAP32[__ZL15shell_functions + 588 >> 2] = STRING_TABLE.__str56349 | 0;

HEAP32[__ZL15shell_functions + 600 >> 2] = STRING_TABLE.__str57350 | 0;

HEAP32[__ZL15shell_functions + 612 >> 2] = STRING_TABLE.__str4297 | 0;

HEAP32[__ZL15shell_functions + 624 >> 2] = STRING_TABLE.__str58351 | 0;

HEAP32[__ZL15shell_functions + 636 >> 2] = STRING_TABLE.__str5298 | 0;

HEAP32[__ZL15shell_functions + 648 >> 2] = STRING_TABLE.__str59352 | 0;

HEAP32[__ZL15shell_functions + 660 >> 2] = STRING_TABLE.__str60353 | 0;

HEAP32[__ZL15shell_functions + 672 >> 2] = STRING_TABLE.__str61354 | 0;

HEAP32[__ZL9its_props >> 2] = STRING_TABLE.__str62355 | 0;

HEAP32[__ZL9its_props + 16 >> 2] = STRING_TABLE.__str63356 | 0;

HEAP32[__ZL9its_props + 32 >> 2] = STRING_TABLE.__str64357 | 0;

HEAP32[__ZL9its_props + 48 >> 2] = STRING_TABLE.__str65358 | 0;

HEAP32[__ZL9its_props + 64 >> 2] = STRING_TABLE.__str66359 | 0;

HEAP32[__ZL9its_props + 80 >> 2] = STRING_TABLE.__str67360 | 0;

HEAP32[__ZL9its_props + 96 >> 2] = STRING_TABLE.__str68361 | 0;

HEAP32[__ZL9its_props + 112 >> 2] = STRING_TABLE.__str69362 | 0;

HEAP32[__ZL9its_class >> 2] = STRING_TABLE.__str70363 | 0;

HEAP32[_jsShell_ErrorFormatString >> 2] = STRING_TABLE.__str71364 | 0;

HEAP32[_jsShell_ErrorFormatString + 8 >> 2] = STRING_TABLE.__str72365 | 0;

HEAP32[_jsShell_ErrorFormatString + 16 >> 2] = STRING_TABLE.__str73366 | 0;

HEAP32[_jsShell_ErrorFormatString + 24 >> 2] = STRING_TABLE.__str74367 | 0;

HEAP32[_jsShell_ErrorFormatString + 32 >> 2] = STRING_TABLE.__str75368 | 0;

HEAP32[_jsShell_ErrorFormatString + 40 >> 2] = STRING_TABLE.__str76369 | 0;

HEAP32[_jsShell_ErrorFormatString + 48 >> 2] = STRING_TABLE.__str77370 | 0;

HEAP32[_jsShell_ErrorFormatString + 56 >> 2] = STRING_TABLE.__str78371 | 0;

HEAP32[_jsShell_ErrorFormatString + 64 >> 2] = STRING_TABLE.__str79372 | 0;

HEAP32[_jsShell_ErrorFormatString + 72 >> 2] = STRING_TABLE.__str80373 | 0;

HEAP32[_jsShell_ErrorFormatString + 80 >> 2] = STRING_TABLE.__str81374 | 0;

HEAP32[_jsShell_ErrorFormatString + 88 >> 2] = STRING_TABLE.__str82375 | 0;

HEAP32[_jsShell_ErrorFormatString + 96 >> 2] = STRING_TABLE.__str83376 | 0;

HEAP32[_jsShell_ErrorFormatString + 104 >> 2] = STRING_TABLE.__str84377 | 0;

HEAP32[_jsShell_ErrorFormatString + 112 >> 2] = STRING_TABLE.__str85378 | 0;

HEAP32[_global_class >> 2] = STRING_TABLE.__str86379 | 0;

HEAP32[__ZL9env_class >> 2] = STRING_TABLE.__str87380 | 0;

HEAP32[_shellTrustedPrincipals >> 2] = STRING_TABLE.__str88381 | 0;

HEAP32[__ZL19shell_help_messages >> 2] = STRING_TABLE.__str164457 | 0;

HEAP32[__ZL19shell_help_messages + 4 >> 2] = STRING_TABLE.__str165458 | 0;

HEAP32[__ZL19shell_help_messages + 8 >> 2] = STRING_TABLE.__str166459 | 0;

HEAP32[__ZL19shell_help_messages + 12 >> 2] = STRING_TABLE.__str167460 | 0;

HEAP32[__ZL19shell_help_messages + 16 >> 2] = STRING_TABLE.__str168461 | 0;

HEAP32[__ZL19shell_help_messages + 20 >> 2] = STRING_TABLE.__str169462 | 0;

HEAP32[__ZL19shell_help_messages + 24 >> 2] = STRING_TABLE.__str170463 | 0;

HEAP32[__ZL19shell_help_messages + 28 >> 2] = STRING_TABLE.__str171464 | 0;

HEAP32[__ZL19shell_help_messages + 32 >> 2] = STRING_TABLE.__str172465 | 0;

HEAP32[__ZL19shell_help_messages + 36 >> 2] = STRING_TABLE.__str173466 | 0;

HEAP32[__ZL19shell_help_messages + 40 >> 2] = STRING_TABLE.__str174467 | 0;

HEAP32[__ZL19shell_help_messages + 44 >> 2] = STRING_TABLE.__str175468 | 0;

HEAP32[__ZL19shell_help_messages + 48 >> 2] = STRING_TABLE.__str176469 | 0;

HEAP32[__ZL19shell_help_messages + 52 >> 2] = STRING_TABLE.__str177470 | 0;

HEAP32[__ZL19shell_help_messages + 56 >> 2] = STRING_TABLE.__str178471 | 0;

HEAP32[__ZL19shell_help_messages + 60 >> 2] = STRING_TABLE.__str179472 | 0;

HEAP32[__ZL19shell_help_messages + 64 >> 2] = STRING_TABLE.__str180473 | 0;

HEAP32[__ZL19shell_help_messages + 68 >> 2] = STRING_TABLE.__str181474 | 0;

HEAP32[__ZL19shell_help_messages + 72 >> 2] = STRING_TABLE.__str182475 | 0;

HEAP32[__ZL19shell_help_messages + 76 >> 2] = STRING_TABLE.__str183476 | 0;

HEAP32[__ZL19shell_help_messages + 80 >> 2] = STRING_TABLE.__str184477 | 0;

HEAP32[__ZL19shell_help_messages + 84 >> 2] = STRING_TABLE.__str185478 | 0;

HEAP32[__ZL19shell_help_messages + 88 >> 2] = STRING_TABLE.__str186479 | 0;

HEAP32[__ZL19shell_help_messages + 92 >> 2] = STRING_TABLE.__str187480 | 0;

HEAP32[__ZL19shell_help_messages + 96 >> 2] = STRING_TABLE.__str188481 | 0;

HEAP32[__ZL19shell_help_messages + 100 >> 2] = STRING_TABLE.__str189482 | 0;

HEAP32[__ZL19shell_help_messages + 104 >> 2] = STRING_TABLE.__str190483 | 0;

HEAP32[__ZL19shell_help_messages + 108 >> 2] = STRING_TABLE.__str191484 | 0;

HEAP32[__ZL19shell_help_messages + 112 >> 2] = STRING_TABLE.__str192485 | 0;

HEAP32[__ZL19shell_help_messages + 116 >> 2] = STRING_TABLE.__str193486 | 0;

HEAP32[__ZL19shell_help_messages + 120 >> 2] = STRING_TABLE.__str194487 | 0;

HEAP32[__ZL19shell_help_messages + 124 >> 2] = STRING_TABLE.__str195488 | 0;

HEAP32[__ZL19shell_help_messages + 128 >> 2] = STRING_TABLE.__str196489 | 0;

HEAP32[__ZL19shell_help_messages + 132 >> 2] = STRING_TABLE.__str197490 | 0;

HEAP32[__ZL19shell_help_messages + 136 >> 2] = STRING_TABLE.__str198491 | 0;

HEAP32[__ZL19shell_help_messages + 140 >> 2] = STRING_TABLE.__str199492 | 0;

HEAP32[__ZL19shell_help_messages + 144 >> 2] = STRING_TABLE.__str200493 | 0;

HEAP32[__ZL19shell_help_messages + 148 >> 2] = STRING_TABLE.__str201494 | 0;

HEAP32[__ZL19shell_help_messages + 152 >> 2] = STRING_TABLE.__str202495 | 0;

HEAP32[__ZL19shell_help_messages + 156 >> 2] = STRING_TABLE.__str203496 | 0;

HEAP32[__ZL19shell_help_messages + 160 >> 2] = STRING_TABLE.__str204497 | 0;

HEAP32[__ZL19shell_help_messages + 164 >> 2] = STRING_TABLE.__str205498 | 0;

HEAP32[__ZL19shell_help_messages + 168 >> 2] = STRING_TABLE.__str206499 | 0;

HEAP32[__ZL19shell_help_messages + 172 >> 2] = STRING_TABLE.__str207500 | 0;

HEAP32[__ZL19shell_help_messages + 176 >> 2] = STRING_TABLE.__str208501 | 0;

HEAP32[__ZL19shell_help_messages + 180 >> 2] = STRING_TABLE.__str209502 | 0;

HEAP32[__ZL19shell_help_messages + 184 >> 2] = STRING_TABLE.__str210503 | 0;

HEAP32[__ZL19shell_help_messages + 188 >> 2] = STRING_TABLE.__str211504 | 0;

HEAP32[__ZL19shell_help_messages + 192 >> 2] = STRING_TABLE.__str212505 | 0;

HEAP32[__ZL19shell_help_messages + 196 >> 2] = STRING_TABLE.__str213506 | 0;

HEAP32[__ZL19shell_help_messages + 200 >> 2] = STRING_TABLE.__str214507 | 0;

HEAP32[__ZL19shell_help_messages + 204 >> 2] = STRING_TABLE.__str215508 | 0;

HEAP32[__ZL19shell_help_messages + 208 >> 2] = STRING_TABLE.__str216509 | 0;

HEAP32[__ZL19shell_help_messages + 212 >> 2] = STRING_TABLE.__str217510 | 0;

HEAP32[__ZL19shell_help_messages + 216 >> 2] = STRING_TABLE.__str218511 | 0;

HEAP32[__ZL19shell_help_messages + 220 >> 2] = STRING_TABLE.__str219512 | 0;

HEAP32[__ZL19shell_help_messages + 224 >> 2] = STRING_TABLE.__str220513 | 0;

HEAP32[__ZZL7CompileP9JSContextjPN2JS5ValueEE11dummy_class >> 2] = STRING_TABLE.__str230523 | 0;

HEAP32[__ZL20FinalizeCounterClass >> 2] = STRING_TABLE.__str265558 | 0;

HEAP32[__ZZL9CountHeapP9JSContextjPN2JS5ValueEE14traceKindNames >> 2] = STRING_TABLE.__str266559 | 0;

HEAP32[__ZZL9CountHeapP9JSContextjPN2JS5ValueEE14traceKindNames + 8 >> 2] = STRING_TABLE.__str267560 | 0;

HEAP32[__ZZL9CountHeapP9JSContextjPN2JS5ValueEE14traceKindNames + 16 >> 2] = STRING_TABLE.__str268561 | 0;

HEAP32[__ZZL9CountHeapP9JSContextjPN2JS5ValueEE14traceKindNames + 24 >> 2] = STRING_TABLE.__str269562 | 0;

HEAP32[__ZZL11GCParameterP9JSContextjPN2JS5ValueEE8paramMap >> 2] = STRING_TABLE.__str272565 | 0;

HEAP32[__ZZL11GCParameterP9JSContextjPN2JS5ValueEE8paramMap + 8 >> 2] = STRING_TABLE.__str273566 | 0;

HEAP32[__ZZL11GCParameterP9JSContextjPN2JS5ValueEE8paramMap + 16 >> 2] = STRING_TABLE.__str274567 | 0;

HEAP32[__ZZL11GCParameterP9JSContextjPN2JS5ValueEE8paramMap + 24 >> 2] = STRING_TABLE.__str275568 | 0;

HEAP32[__ZZL11GCParameterP9JSContextjPN2JS5ValueEE8paramMap + 32 >> 2] = STRING_TABLE.__str276569 | 0;

HEAP32[__ZL10js_options >> 2] = STRING_TABLE.__str289582 | 0;

HEAP32[__ZL10js_options + 8 >> 2] = STRING_TABLE.__str290583 | 0;

HEAP32[__ZL10js_options + 16 >> 2] = STRING_TABLE.__str104397 | 0;

HEAP32[__ZL10js_options + 24 >> 2] = STRING_TABLE.__str102395 | 0;

HEAP32[__ZL10js_options + 32 >> 2] = STRING_TABLE.__str291584 | 0;

HEAP32[__ZL10js_options + 40 >> 2] = STRING_TABLE.__str292585 | 0;

HEAP32[__ZL10js_options + 48 >> 2] = STRING_TABLE.__str293586 | 0;

HEAP32[__ZL10js_options + 56 >> 2] = STRING_TABLE.__str108401 | 0;

HEAP32[__ZL10js_options + 64 >> 2] = STRING_TABLE.__str294 | 0;

HEAP32[__ZL10js_options + 72 >> 2] = STRING_TABLE.__str269562 | 0;

HEAP32[__ZZL23OptionFlagsToFormatInfocbPjE3fmt >> 2] = STRING_TABLE.__str12663 | 0;

HEAP32[__ZZL23OptionFlagsToFormatInfocbPjE3fmt + 4 >> 2] = STRING_TABLE.__str13664 | 0;

HEAP32[__ZZL23OptionFlagsToFormatInfocbPjE3fmt + 8 >> 2] = STRING_TABLE.__str14665 | 0;

HEAP32[__ZZL23OptionFlagsToFormatInfocbPjE3fmt + 12 >> 2] = STRING_TABLE.__str15666 | 0;

HEAP32[__ZTVSt9bad_alloc + 4 >> 2] = __ZTISt9bad_alloc;

__ZTVN10__cxxabiv120__si_class_type_infoE = allocate([ 2, 0, 0, 0, 0 ], [ "i8*", 0, 0, 0, 0 ], ALLOC_STATIC);

HEAP32[__ZTISt9bad_alloc >> 2] = __ZTVN10__cxxabiv120__si_class_type_infoE + 8 | 0;

HEAP32[__ZTISt9bad_alloc + 4 >> 2] = STRING_TABLE.__ZTSSt9bad_alloc | 0;

HEAP32[__ZTISt9bad_alloc + 8 >> 2] = __ZTISt9exception;

FUNCTION_TABLE = [ 0, 0, __ZL11TrapHandlerP9JSContextP8JSScriptPhPN2JS5ValueES5_, 0, __Z18js_GetErrorMessagePvPKcj, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv, 0, _JS_PropertyStub, 0, _JS_StrictPropertyStub, 0, __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv, 0, __ZL24DebuggerArguments_getArgP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger9constructEP9JSContextjPN2JS5ValueE, 0, __ZL23DebuggerFrame_constructP9JSContextjPN2JS5ValueE, 0, __ZL24DebuggerScript_constructP9JSContextjPN2JS5ValueE, 0, __ZL24DebuggerObject_constructP9JSContextjPN2JS5ValueE, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3Ptr7nonNullEv, 0, __Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej, 0, __Z9js_ObjectP9JSContextjPN2JS5ValueE, 0, __ZN2js8FunctionEP9JSContextjPN2JS5ValueE, 0, __ZN2js4evalEP9JSContextjPN2JS5ValueE, 0, __ZL14ThrowTypeErrorP9JSContextjPN2JS5ValueE, 0, _TransparentObjectWrapper, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr7nonNullEv, 0, __ZL12pm_constructP9JSContextjPN2JS5ValueE, 0, __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty, 0, __ZL22ShellOperationCallbackP9JSContext, 0, __ZL35js_generic_native_method_dispatcherP9JSContextjPN2JS5ValueE, 0, __Z16js_SetAttributesP9JSContextP8JSObjectiPj, 0, __Z16js_GetAttributesP9JSContextP8JSObjectiPj, 0, __ZL19array_length_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL19array_length_setterP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZL20sort_compare_stringsPvPKvS1_Pi, 0, __ZL12sort_comparePvPKvS1_Pi, 0, __Z8js_ArrayP9JSContextjPN2JS5ValueE, 0, __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv, 0, __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv, 0, __Z16js_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty, 0, __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv, 0, __ZL7BooleanP9JSContextjPN2JS5ValueE, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv, 0, __ZL16print_gmt_stringPcjd, 0, __ZL16print_iso_stringPcjd, 0, __Z7js_DateP9JSContextjPN2JS5ValueE, 0, _JS_ConvertStub, 0, __ZN2js12DefaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE, 0, __ZL23DebuggerAndThrowHandlerP9JSContextP8JSScriptPhPN2JS5ValueEPv, 0, __ZN2js10GetCallArgEP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZN2js10GetCallVarEP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv, 0, __ZL21EmitDestructuringDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode, 0, __ZL22EmitDestructuringDeclsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode, 0, __ZL9ExceptionP9JSContextjPN2JS5ValueE, 0, __ZL15StrictArgGetterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL15StrictArgSetterP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZL9ArgGetterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL9ArgSetterP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZN2jsL16GetCallArgumentsEP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZN2jsL16SetCallArgumentsEP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZL15fun_getPropertyP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv, 0, __ZN2js28CallOrConstructBoundFunctionEP9JSContextjPN2JS5ValueE, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv, 0, __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv, 0, __ZL14js_hash_objectPKv, 0, _JS_CompareValues, 0, __ZN2js10array_pushEP9JSContextjPN2JS5ValueE, 0, __ZN2js9array_popEP9JSContextjPN2JS5ValueE, 0, __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv, 0, __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr7nonNullEv, 0, __ZN2js10array_sortEP9JSContextjPN2JS5ValueE, 0, __ZN2js11str_replaceEP9JSContextjPN2JS5ValueE, 0, __Z9js_TypeOfP9JSContextP8JSObject, 0, _JS_EnumerateStub, 0, __ZL8IteratorP9JSContextjPN2JS5ValueE, 0, __Z12js_EnumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3Ptr7nonNullEv, 0, _sqrt, 0, _acos, 0, _asin, 0, _atan, 0, _cos, 0, __ZL13math_exp_bodyd, 0, _log, 0, _sin, 0, _tan, 0, __ZL6NumberP9JSContextjPN2JS5ValueE, 0, __ZL17block_getPropertyP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL17block_setPropertyP9JSContextP8JSObjectiiPN2JS5ValueE, 0, _JS_ResolveStub, 0, __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL11PutPropertyP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __Z23js_GetElementAttributesP9JSContextP8JSObjectjPj, 0, __Z23js_SetElementAttributesP9JSContextP8JSObjectjPj, 0, __Z15js_str_toStringP9JSContextjPN2JS5ValueE, 0, __Z14js_num_valueOfP9JSContextjPN2JS5ValueE, 0, __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3Ptr7nonNullEv, 0, __ZL2JAP9JSContextP8JSObjectP16StringifyContext, 0, __ZL2JOP9JSContextP8JSObjectP16StringifyContext, 0, __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv, 0, __ZL14CompareOffsetsPvPKvS1_Pi, 0, __ZL20BindDestructuringArgP9JSContextP8BindDataP6JSAtomP13JSTreeContext, 0, __ZL7BindLetP9JSContextP8BindDataP6JSAtomP13JSTreeContext, 0, __ZL14BindVarOrConstP9JSContextP8BindDataP6JSAtomP13JSTreeContext, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv, 0, __ZL9GrowStuffP15SprintfStateStrPKcj, 0, __ZL10LimitStuffP15SprintfStateStrPKcj, 0, __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr7nonNullEv, 0, __ZL16regexp_constructP9JSContextjPN2JS5ValueE, 0, __ZN2js10SetCallArgEP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZN2js12GetCallUpvarEP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZN2js12SetCallUpvarEP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZN2js10SetCallVarEP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr7nonNullEv, 0, __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr7nonNullEv, 0, __ZL21ReplaceRegExpCallbackP9JSContextPN2js13RegExpStaticsEjPv, 0, __ZL13MatchCallbackP9JSContextPN2js13RegExpStaticsEjPv, 0, __Z9js_StringP9JSContextjPN2JS5ValueE, 0, __Z16js_DefineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej, 0, __ZN18TypedArrayTemplateIaE17class_constructorEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIhE17class_constructorEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIsE17class_constructorEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateItE17class_constructorEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIiE17class_constructorEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIjE17class_constructorEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIfE17class_constructorEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIdE17class_constructorEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateI13uint8_clampedE17class_constructorEP9JSContextjPN2JS5ValueE, 0, __ZN2js11ArrayBuffer17class_constructorEP9JSContextjPN2JS5ValueE, 0, __ZL17obj_watch_handlerP9JSContextP8JSObjectiN2JS5ValueEPS4_Pv, 0, __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv, 0, __ZL17WeakMap_constructP9JSContextjPN2JS5ValueE, 0, __ZL13attr_identityPKvS0_, 0, __ZL15namespace_matchPKvS0_, 0, __ZL9NamespaceP9JSContextjPN2JS5ValueE, 0, __ZL5QNameP9JSContextjPN2JS5ValueE, 0, __ZL3XMLP9JSContextjPN2JS5ValueE, 0, __ZL7XMLListP9JSContextjPN2JS5ValueE, 0, __ZL13xml_isXMLNameP9JSContextjPN2JS5ValueE, 0, __ZL13MatchAttrNameP8JSObjectP5JSXML, 0, __ZL13MatchElemNameP8JSObjectP5JSXML, 0, __ZL18namespace_identityPKvS0_, 0, __ZL20namespace_full_matchPKvS0_, 0, __ZL18my_GetErrorMessagePvPKcj, 0, __ZL10its_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL10its_setterP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZL15CountHeapNotifyP8JSTracerPv13JSGCTraceKind, 0, _JS_NewObjectWithGivenProto, 0, _JS_NewObject, 0, __ZL16my_ErrorReporterP9JSContextPKcP13JSErrorReport, 0, __ZL12AlarmHandleri, 0, __ZNSt9bad_allocD2Ev, 0, __ZL20DebuggerObject_traceP8JSTracerP8JSObject, 0, __ZN2js8Debugger8finalizeEP9JSContextP8JSObject, 0, __ZN2js8Debugger11traceObjectEP8JSTracerP8JSObject, 0, __ZN2js8Debugger10getEnabledEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger10setEnabledEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger22getOnDebuggerStatementEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger22setOnDebuggerStatementEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger20getOnExceptionUnwindEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger20setOnExceptionUnwindEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger14getOnNewScriptEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger14setOnNewScriptEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger15getOnEnterFrameEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger15setOnEnterFrameEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger24getUncaughtExceptionHookEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger24setUncaughtExceptionHookEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger11addDebuggeeEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger14removeDebuggeeEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger11hasDebuggeeEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger12getDebuggeesEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger14getNewestFrameEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger19clearAllBreakpointsEP9JSContextjPN2JS5ValueE, 0, __ZL20DebuggerScript_traceP8JSTracerP8JSObject, 0, __ZL21DebuggerScript_getUrlP9JSContextjPN2JS5ValueE, 0, __ZL27DebuggerScript_getStartLineP9JSContextjPN2JS5ValueE, 0, __ZL27DebuggerScript_getLineCountP9JSContextjPN2JS5ValueE, 0, __ZL22DebuggerScript_getLiveP9JSContextjPN2JS5ValueE, 0, __ZL30DebuggerScript_getChildScriptsP9JSContextjPN2JS5ValueE, 0, __ZL28DebuggerScript_getAllOffsetsP9JSContextjPN2JS5ValueE, 0, __ZL29DebuggerScript_getLineOffsetsP9JSContextjPN2JS5ValueE, 0, __ZL28DebuggerScript_getOffsetLineP9JSContextjPN2JS5ValueE, 0, __ZL28DebuggerScript_setBreakpointP9JSContextjPN2JS5ValueE, 0, __ZL29DebuggerScript_getBreakpointsP9JSContextjPN2JS5ValueE, 0, __ZL30DebuggerScript_clearBreakpointP9JSContextjPN2JS5ValueE, 0, __ZL34DebuggerScript_clearAllBreakpointsP9JSContextjPN2JS5ValueE, 0, __ZL26DebuggerFrame_getArgumentsP9JSContextjPN2JS5ValueE, 0, __ZL23DebuggerFrame_getCalleeP9JSContextjPN2JS5ValueE, 0, __ZL29DebuggerFrame_getConstructingP9JSContextjPN2JS5ValueE, 0, __ZL26DebuggerFrame_getGeneratorP9JSContextjPN2JS5ValueE, 0, __ZL21DebuggerFrame_getLiveP9JSContextjPN2JS5ValueE, 0, __ZL23DebuggerFrame_getOffsetP9JSContextjPN2JS5ValueE, 0, __ZL22DebuggerFrame_getOlderP9JSContextjPN2JS5ValueE, 0, __ZL23DebuggerFrame_getScriptP9JSContextjPN2JS5ValueE, 0, __ZL21DebuggerFrame_getThisP9JSContextjPN2JS5ValueE, 0, __ZL21DebuggerFrame_getTypeP9JSContextjPN2JS5ValueE, 0, __ZL23DebuggerFrame_getOnStepP9JSContextjPN2JS5ValueE, 0, __ZL23DebuggerFrame_setOnStepP9JSContextjPN2JS5ValueE, 0, __ZL18DebuggerFrame_evalP9JSContextjPN2JS5ValueE, 0, __ZL30DebuggerFrame_evalWithBindingsP9JSContextjPN2JS5ValueE, 0, __ZL23DebuggerObject_getProtoP9JSContextjPN2JS5ValueE, 0, __ZL23DebuggerObject_getClassP9JSContextjPN2JS5ValueE, 0, __ZL26DebuggerObject_getCallableP9JSContextjPN2JS5ValueE, 0, __ZL22DebuggerObject_getNameP9JSContextjPN2JS5ValueE, 0, __ZL32DebuggerObject_getParameterNamesP9JSContextjPN2JS5ValueE, 0, __ZL24DebuggerObject_getScriptP9JSContextjPN2JS5ValueE, 0, __ZL39DebuggerObject_getOwnPropertyDescriptorP9JSContextjPN2JS5ValueE, 0, __ZL34DebuggerObject_getOwnPropertyNamesP9JSContextjPN2JS5ValueE, 0, __ZL29DebuggerObject_definePropertyP9JSContextjPN2JS5ValueE, 0, __ZL31DebuggerObject_definePropertiesP9JSContextjPN2JS5ValueE, 0, __ZL29DebuggerObject_deletePropertyP9JSContextjPN2JS5ValueE, 0, __ZL19DebuggerObject_sealP9JSContextjPN2JS5ValueE, 0, __ZL21DebuggerObject_freezeP9JSContextjPN2JS5ValueE, 0, __ZL32DebuggerObject_preventExtensionsP9JSContextjPN2JS5ValueE, 0, __ZL23DebuggerObject_isSealedP9JSContextjPN2JS5ValueE, 0, __ZL23DebuggerObject_isFrozenP9JSContextjPN2JS5ValueE, 0, __ZL27DebuggerObject_isExtensibleP9JSContextjPN2JS5ValueE, 0, __ZL20DebuggerObject_applyP9JSContextjPN2JS5ValueE, 0, __ZL19DebuggerObject_callP9JSContextjPN2JS5ValueE, 0, __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEE15nonMarkingTraceEP8JSTracer, 0, __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEE15markIterativelyEP8JSTracer, 0, __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEE5sweepEP8JSTracer, 0, ___cxa_pure_virtual, 0, __ZN2js24GlobalDebuggees_finalizeEP9JSContextP8JSObject, 0, __Z20js_InitFunctionClassP9JSContextP8JSObject, 0, __Z18js_InitObjectClassP9JSContextP8JSObject, 0, __Z17js_InitArrayClassP9JSContextP8JSObject, 0, __Z19js_InitBooleanClassP9JSContextP8JSObject, 0, __Z16js_InitDateClassP9JSContextP8JSObject, 0, __Z16js_InitMathClassP9JSContextP8JSObject, 0, __Z18js_InitNumberClassP9JSContextP8JSObject, 0, __Z18js_InitStringClassP9JSContextP8JSObject, 0, __Z23js_InitExceptionClassesP9JSContextP8JSObject, 0, __Z18js_InitRegExpClassP9JSContextP8JSObject, 0, __Z15js_InitXMLClassP9JSContextP8JSObject, 0, __Z21js_InitNamespaceClassP9JSContextP8JSObject, 0, __Z17js_InitQNameClassP9JSContextP8JSObject, 0, __Z22js_InitIteratorClassesP9JSContextP8JSObject, 0, __Z16js_InitJSONClassP9JSContextP8JSObject, 0, __Z24js_InitTypedArrayClassesP9JSContextP8JSObject, 0, __Z19js_InitWeakMapClassP9JSContextP8JSObject, 0, _js_InitProxyClass, 0, __ZL18prop_iter_finalizeP9JSContextP8JSObject, 0, __ZL15prop_iter_traceP8JSTracerP8JSObject, 0, __ZL11array_traceP8JSTracerP8JSObject, 0, __ZL20array_lookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty, 0, __ZL19array_lookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty, 0, __ZL19array_lookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty, 0, __ZN2js20array_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ej, 0, __ZN2js19array_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ej, 0, __ZL19array_defineSpecialP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ej, 0, __ZL16array_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE, 0, __ZL17array_getPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZL16array_getElementP9JSContextP8JSObjectS2_jPN2JS5ValueE, 0, __ZL16array_getSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE, 0, __ZL17array_setPropertyP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZL16array_setElementP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZL16array_setSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZL19array_getAttributesP9JSContextP8JSObjectiPj, 0, __ZL26array_getElementAttributesP9JSContextP8JSObjectjPj, 0, __ZL26array_getSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj, 0, __ZL19array_setAttributesP9JSContextP8JSObjectiPj, 0, __ZL26array_setElementAttributesP9JSContextP8JSObjectjPj, 0, __ZL26array_setSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj, 0, __ZN2js20array_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN2js19array_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZL19array_deleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZL12array_typeOfP9JSContextP8JSObject, 0, __ZL9array_fixP9JSContextP8JSObjectPbPN2js12AutoIdVectorE, 0, __ZL21slowarray_addPropertyP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL14array_toSourceP9JSContextjPN2JS5ValueE, 0, __ZL14array_toStringP9JSContextjPN2JS5ValueE, 0, __ZL20array_toLocaleStringP9JSContextjPN2JS5ValueE, 0, __ZL10array_joinP9JSContextjPN2JS5ValueE, 0, __ZL13array_reverseP9JSContextjPN2JS5ValueE, 0, __ZL11array_shiftP9JSContextjPN2JS5ValueE, 0, __ZL13array_unshiftP9JSContextjPN2JS5ValueE, 0, __ZL12array_spliceP9JSContextjPN2JS5ValueE, 0, __ZL12array_concatP9JSContextjPN2JS5ValueE, 0, __ZL11array_sliceP9JSContextjPN2JS5ValueE, 0, __ZL13array_indexOfP9JSContextjPN2JS5ValueE, 0, __ZL17array_lastIndexOfP9JSContextjPN2JS5ValueE, 0, __ZL13array_forEachP9JSContextjPN2JS5ValueE, 0, __ZL9array_mapP9JSContextjPN2JS5ValueE, 0, __ZL12array_reduceP9JSContextjPN2JS5ValueE, 0, __ZL17array_reduceRightP9JSContextjPN2JS5ValueE, 0, __ZL12array_filterP9JSContextjPN2JS5ValueE, 0, __ZL10array_someP9JSContextjPN2JS5ValueE, 0, __ZL11array_everyP9JSContextjPN2JS5ValueE, 0, __ZL13array_isArrayP9JSContextjPN2JS5ValueE, 0, __ZL13bool_toSourceP9JSContextjPN2JS5ValueE, 0, __ZL13bool_toStringP9JSContextjPN2JS5ValueE, 0, __ZL12bool_valueOfP9JSContextjPN2JS5ValueE, 0, __ZL12date_convertP9JSContextP8JSObject6JSTypePN2JS5ValueE, 0, __ZL8date_UTCP9JSContextjPN2JS5ValueE, 0, __ZL10date_parseP9JSContextjPN2JS5ValueE, 0, __ZL8date_nowP9JSContextjPN2JS5ValueE, 0, __ZL12date_getTimeP9JSContextjPN2JS5ValueE, 0, __ZL22date_getTimezoneOffsetP9JSContextjPN2JS5ValueE, 0, __ZL12date_getYearP9JSContextjPN2JS5ValueE, 0, __ZL16date_getFullYearP9JSContextjPN2JS5ValueE, 0, __ZL19date_getUTCFullYearP9JSContextjPN2JS5ValueE, 0, __ZL13date_getMonthP9JSContextjPN2JS5ValueE, 0, __ZL16date_getUTCMonthP9JSContextjPN2JS5ValueE, 0, __ZL12date_getDateP9JSContextjPN2JS5ValueE, 0, __ZL15date_getUTCDateP9JSContextjPN2JS5ValueE, 0, __ZL11date_getDayP9JSContextjPN2JS5ValueE, 0, __ZL14date_getUTCDayP9JSContextjPN2JS5ValueE, 0, __ZL13date_getHoursP9JSContextjPN2JS5ValueE, 0, __ZL16date_getUTCHoursP9JSContextjPN2JS5ValueE, 0, __ZL15date_getMinutesP9JSContextjPN2JS5ValueE, 0, __ZL18date_getUTCMinutesP9JSContextjPN2JS5ValueE, 0, __ZL18date_getUTCSecondsP9JSContextjPN2JS5ValueE, 0, __ZL23date_getUTCMillisecondsP9JSContextjPN2JS5ValueE, 0, __ZL12date_setTimeP9JSContextjPN2JS5ValueE, 0, __ZL12date_setYearP9JSContextjPN2JS5ValueE, 0, __ZL16date_setFullYearP9JSContextjPN2JS5ValueE, 0, __ZL19date_setUTCFullYearP9JSContextjPN2JS5ValueE, 0, __ZL13date_setMonthP9JSContextjPN2JS5ValueE, 0, __ZL16date_setUTCMonthP9JSContextjPN2JS5ValueE, 0, __ZL12date_setDateP9JSContextjPN2JS5ValueE, 0, __ZL15date_setUTCDateP9JSContextjPN2JS5ValueE, 0, __ZL13date_setHoursP9JSContextjPN2JS5ValueE, 0, __ZL16date_setUTCHoursP9JSContextjPN2JS5ValueE, 0, __ZL15date_setMinutesP9JSContextjPN2JS5ValueE, 0, __ZL18date_setUTCMinutesP9JSContextjPN2JS5ValueE, 0, __ZL15date_setSecondsP9JSContextjPN2JS5ValueE, 0, __ZL18date_setUTCSecondsP9JSContextjPN2JS5ValueE, 0, __ZL20date_setMillisecondsP9JSContextjPN2JS5ValueE, 0, __ZL23date_setUTCMillisecondsP9JSContextjPN2JS5ValueE, 0, __ZL16date_toGMTStringP9JSContextjPN2JS5ValueE, 0, __ZL19date_toLocaleStringP9JSContextjPN2JS5ValueE, 0, __ZL23date_toLocaleDateStringP9JSContextjPN2JS5ValueE, 0, __ZL23date_toLocaleTimeStringP9JSContextjPN2JS5ValueE, 0, __ZL19date_toLocaleFormatP9JSContextjPN2JS5ValueE, 0, __ZL17date_toDateStringP9JSContextjPN2JS5ValueE, 0, __ZL17date_toTimeStringP9JSContextjPN2JS5ValueE, 0, __ZL16date_toISOStringP9JSContextjPN2JS5ValueE, 0, __ZL11date_toJSONP9JSContextjPN2JS5ValueE, 0, __ZL13date_toSourceP9JSContextjPN2JS5ValueE, 0, __ZL13date_toStringP9JSContextjPN2JS5ValueE, 0, __ZL12date_valueOfP9JSContextjPN2JS5ValueE, 0, _JS_DHashAllocTable, 0, _JS_DHashFreeTable, 0, _JS_DHashVoidPtrKeyStub, 0, _JS_DHashMatchEntryStub, 0, _JS_DHashMoveEntryStub, 0, _JS_DHashClearEntryStub, 0, _JS_DHashFinalizeStub, 0, __ZL11exn_resolveP9JSContextP8JSObjectijPS2_, 0, __ZL12exn_finalizeP9JSContextP8JSObject, 0, __ZL9exn_traceP8JSTracerP8JSObject, 0, __ZL12exn_toSourceP9JSContextjPN2JS5ValueE, 0, __ZL12exn_toStringP9JSContextjPN2JS5ValueE, 0, __ZL16args_delPropertyP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL20strictargs_enumerateP9JSContextP8JSObject, 0, __ZL18strictargs_resolveP9JSContextP8JSObjectijPS2_, 0, __ZL13args_finalizeP9JSContextP8JSObject, 0, __ZL10args_traceP8JSTracerP8JSObject, 0, __ZL14args_enumerateP9JSContextP8JSObject, 0, __ZL12args_resolveP9JSContextP8JSObjectijPS2_, 0, __ZL12call_resolveP9JSContextP8JSObjectijPS2_, 0, __ZL10call_traceP8JSTracerP8JSObject, 0, __ZL13fun_enumerateP9JSContextP8JSObject, 0, __ZL11fun_resolveP9JSContextP8JSObjectijPS2_, 0, __ZL12fun_finalizeP9JSContextP8JSObject, 0, __ZL15fun_hasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi, 0, __ZL9fun_traceP8JSTracerP8JSObject, 0, __ZL12fun_toSourceP9JSContextjPN2JS5ValueE, 0, __ZL12fun_toStringP9JSContextjPN2JS5ValueE, 0, __Z12js_fun_applyP9JSContextjPN2JS5ValueE, 0, __Z11js_fun_callP9JSContextjPN2JS5ValueE, 0, __ZL8fun_bindP9JSContextjPN2JS5ValueE, 0, __ZL15fun_isGeneratorP9JSContextjPN2JS5ValueE, 0, __ZL17DefaultAllocTablePvj, 0, __ZL16DefaultFreeTablePvS_j, 0, __ZL17DefaultAllocEntryPvPKv, 0, __ZL16DefaultFreeEntryPvP11JSHashEntryj, 0, __ZN18TypeConstraintProp7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN2js5types14TypeConstraint16newPropertyStateEP9JSContextPNS0_7TypeSetE, 0, __ZN2js5types14TypeConstraint14newObjectStateEP9JSContextPNS0_10TypeObjectEb, 0, __ZN22TypeConstraintCallProp7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN24TypeConstraintSetElement7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN18TypeConstraintCall7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN19TypeConstraintArith7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN27TypeConstraintTransformThis7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN27TypeConstraintPropagateThis7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN27TypeConstraintLazyArguments7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN27TypeConstraintLazyArguments14newObjectStateEP9JSContextPN2js5types10TypeObjectEb, 0, __ZN27TypeConstraintSubsetBarrier7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN29TypeConstraintFilterPrimitive7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN20TypeConstraintSubset7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN33TypeConstraintClearDefiniteSingle7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN33TypeConstraintClearDefiniteSetter7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZL20no_such_method_traceP8JSTracerP8JSObject, 0, __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv, 0, __ZL17iterator_finalizeP9JSContextP8JSObject, 0, __ZL14iterator_traceP8JSTracerP8JSObject, 0, __ZL17iterator_iteratorP9JSContextP8JSObjecti, 0, __ZL13iterator_nextP9JSContextjPN2JS5ValueE, 0, __ZL20stopiter_hasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi, 0, __ZL18generator_finalizeP9JSContextP8JSObject, 0, __ZL15generator_traceP8JSTracerP8JSObject, 0, __ZL14generator_nextP9JSContextjPN2JS5ValueE, 0, __ZL14generator_sendP9JSContextjPN2JS5ValueE, 0, __ZL15generator_throwP9JSContextjPN2JS5ValueE, 0, __ZL15generator_closeP9JSContextjPN2JS5ValueE, 0, __ZL13math_toSourceP9JSContextjPN2JS5ValueE, 0, __Z11js_math_absP9JSContextjPN2JS5ValueE, 0, __ZL9math_acosP9JSContextjPN2JS5ValueE, 0, __ZL9math_asinP9JSContextjPN2JS5ValueE, 0, __ZL9math_atanP9JSContextjPN2JS5ValueE, 0, __ZL10math_atan2P9JSContextjPN2JS5ValueE, 0, __Z12js_math_ceilP9JSContextjPN2JS5ValueE, 0, __ZL8math_cosP9JSContextjPN2JS5ValueE, 0, __ZL8math_expP9JSContextjPN2JS5ValueE, 0, __Z13js_math_floorP9JSContextjPN2JS5ValueE, 0, __ZL8math_logP9JSContextjPN2JS5ValueE, 0, __Z11js_math_maxP9JSContextjPN2JS5ValueE, 0, __Z11js_math_minP9JSContextjPN2JS5ValueE, 0, __Z11js_math_powP9JSContextjPN2JS5ValueE, 0, __ZL11math_randomP9JSContextjPN2JS5ValueE, 0, __Z13js_math_roundP9JSContextjPN2JS5ValueE, 0, __ZL8math_sinP9JSContextjPN2JS5ValueE, 0, __Z12js_math_sqrtP9JSContextjPN2JS5ValueE, 0, __ZL8math_tanP9JSContextjPN2JS5ValueE, 0, __ZL9num_isNaNP9JSContextjPN2JS5ValueE, 0, __ZL12num_isFiniteP9JSContextjPN2JS5ValueE, 0, __ZL14num_parseFloatP9JSContextjPN2JS5ValueE, 0, __ZL12num_parseIntP9JSContextjPN2JS5ValueE, 0, __ZL12num_toSourceP9JSContextjPN2JS5ValueE, 0, __ZL12num_toStringP9JSContextjPN2JS5ValueE, 0, __ZL18num_toLocaleStringP9JSContextjPN2JS5ValueE, 0, __ZL11num_toFixedP9JSContextjPN2JS5ValueE, 0, __ZL17num_toExponentialP9JSContextjPN2JS5ValueE, 0, __ZL15num_toPrecisionP9JSContextjPN2JS5ValueE, 0, __ZL12obj_getProtoP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL12obj_setProtoP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZL12obj_toSourceP9JSContextjPN2JS5ValueE, 0, __ZL12obj_toStringP9JSContextjPN2JS5ValueE, 0, __ZL18obj_toLocaleStringP9JSContextjPN2JS5ValueE, 0, __ZL11obj_valueOfP9JSContextjPN2JS5ValueE, 0, __ZL9obj_watchP9JSContextjPN2JS5ValueE, 0, __ZL11obj_unwatchP9JSContextjPN2JS5ValueE, 0, __ZL18obj_hasOwnPropertyP9JSContextjPN2JS5ValueE, 0, __ZL17obj_isPrototypeOfP9JSContextjPN2JS5ValueE, 0, __ZL24obj_propertyIsEnumerableP9JSContextjPN2JS5ValueE, 0, __Z19js_obj_defineGetterP9JSContextjPN2JS5ValueE, 0, __Z19js_obj_defineSetterP9JSContextjPN2JS5ValueE, 0, __ZL16obj_lookupGetterP9JSContextjPN2JS5ValueE, 0, __ZL16obj_lookupSetterP9JSContextjPN2JS5ValueE, 0, __Z18obj_getPrototypeOfP9JSContextjPN2JS5ValueE, 0, __ZL28obj_getOwnPropertyDescriptorP9JSContextjPN2JS5ValueE, 0, __ZL8obj_keysP9JSContextjPN2JS5ValueE, 0, __ZL18obj_definePropertyP9JSContextjPN2JS5ValueE, 0, __ZL20obj_definePropertiesP9JSContextjPN2JS5ValueE, 0, __ZL10obj_createP9JSContextjPN2JS5ValueE, 0, __ZL23obj_getOwnPropertyNamesP9JSContextjPN2JS5ValueE, 0, __ZL16obj_isExtensibleP9JSContextjPN2JS5ValueE, 0, __ZL21obj_preventExtensionsP9JSContextjPN2JS5ValueE, 0, __ZL10obj_freezeP9JSContextjPN2JS5ValueE, 0, __ZL12obj_isFrozenP9JSContextjPN2JS5ValueE, 0, __ZL8obj_sealP9JSContextjPN2JS5ValueE, 0, __ZL12obj_isSealedP9JSContextjPN2JS5ValueE, 0, __ZL19with_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty, 0, __ZL18with_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty, 0, __ZL18with_LookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty, 0, __ZL15with_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE, 0, __ZL16with_GetPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZL15with_GetElementP9JSContextP8JSObjectS2_jPN2JS5ValueE, 0, __ZL15with_GetSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE, 0, __ZL16with_SetPropertyP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZL15with_SetElementP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZL15with_SetSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZL18with_GetAttributesP9JSContextP8JSObjectiPj, 0, __ZL25with_GetElementAttributesP9JSContextP8JSObjectjPj, 0, __ZL25with_GetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj, 0, __ZL18with_SetAttributesP9JSContextP8JSObjectiPj, 0, __ZL25with_SetElementAttributesP9JSContextP8JSObjectjPj, 0, __ZL25with_SetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj, 0, __ZL19with_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZL18with_DeleteElementP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZL18with_DeleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZL14with_EnumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZL11with_TypeOfP9JSContextP8JSObject, 0, __ZL15with_ThisObjectP9JSContextP8JSObject, 0, __ZL16js_InitNullClassP9JSContextP8JSObject, 0, __ZL13json_toSourceP9JSContextjPN2JS5ValueE, 0, __Z13js_json_parseP9JSContextjPN2JS5ValueE, 0, __Z17js_json_stringifyP9JSContextjPN2JS5ValueE, 0, __ZL8pm_startP9JSContextjPN2JS5ValueE, 0, __ZL7pm_stopP9JSContextjPN2JS5ValueE, 0, __ZL8pm_resetP9JSContextjPN2JS5ValueE, 0, __ZL22pm_canMeasureSomethingP9JSContextjPN2JS5ValueE, 0, __ZL11pm_finalizeP9JSContextP8JSObject, 0, __ZL17pm_get_cpu_cyclesP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL19pm_get_instructionsP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL23pm_get_cache_referencesP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL19pm_get_cache_missesP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL26pm_get_branch_instructionsP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL20pm_get_branch_missesP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL17pm_get_bus_cyclesP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL18pm_get_page_faultsP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL24pm_get_major_page_faultsP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL23pm_get_context_switchesP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL21pm_get_cpu_migrationsP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL21pm_get_eventsMeasuredP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZN2js14JSProxyHandlerD2Ev, 0, __ZN22JSScriptedProxyHandlerD0Ev, 0, __ZN22JSScriptedProxyHandler21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor, 0, __ZN22JSScriptedProxyHandler24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor, 0, __ZN22JSScriptedProxyHandler14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor, 0, __ZN22JSScriptedProxyHandler19getOwnPropertyNamesEP9JSContextP8JSObjectRN2js12AutoIdVectorE, 0, __ZN22JSScriptedProxyHandler7delete_EP9JSContextP8JSObjectiPb, 0, __ZN22JSScriptedProxyHandler9enumerateEP9JSContextP8JSObjectRN2js12AutoIdVectorE, 0, __ZN22JSScriptedProxyHandler3fixEP9JSContextP8JSObjectPN2JS5ValueE, 0, __ZN22JSScriptedProxyHandler3hasEP9JSContextP8JSObjectiPb, 0, __ZN22JSScriptedProxyHandler6hasOwnEP9JSContextP8JSObjectiPb, 0, __ZN22JSScriptedProxyHandler3getEP9JSContextP8JSObjectS3_iPN2JS5ValueE, 0, __ZN22JSScriptedProxyHandler3setEP9JSContextP8JSObjectS3_ibPN2JS5ValueE, 0, __ZN22JSScriptedProxyHandler4keysEP9JSContextP8JSObjectRN2js12AutoIdVectorE, 0, __ZN22JSScriptedProxyHandler7iterateEP9JSContextP8JSObjectjPN2JS5ValueE, 0, __ZN2js14JSProxyHandler4callEP9JSContextP8JSObjectjPN2JS5ValueE, 0, __ZN2js14JSProxyHandler9constructEP9JSContextP8JSObjectjPN2JS5ValueES7_, 0, __ZN2js14JSProxyHandler11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb, 0, __ZN2js14JSProxyHandler6typeOfEP9JSContextP8JSObject, 0, __ZN2js14JSProxyHandler12obj_toStringEP9JSContextP8JSObject, 0, __ZN2js14JSProxyHandler12fun_toStringEP9JSContextP8JSObjectj, 0, __ZN2js14JSProxyHandler12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE, 0, __ZN2js14JSProxyHandler8finalizeEP9JSContextP8JSObject, 0, __ZN2js14JSProxyHandler5traceEP8JSTracerP8JSObject, 0, __ZN2js14JSProxyHandler13isOuterWindowEv, 0, __ZL13proxy_ConvertP9JSContextP8JSObject6JSTypePN2JS5ValueE, 0, __ZL14proxy_FinalizeP9JSContextP8JSObject, 0, __ZL17proxy_HasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi, 0, __ZL17proxy_TraceObjectP8JSTracerP8JSObject, 0, __ZL20proxy_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty, 0, __ZL19proxy_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty, 0, __ZL19proxy_LookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty, 0, __ZL20proxy_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej, 0, __ZL19proxy_DefineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej, 0, __ZL19proxy_DefineSpecialP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ej, 0, __ZL16proxy_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE, 0, __ZL17proxy_GetPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZL16proxy_GetElementP9JSContextP8JSObjectS2_jPN2JS5ValueE, 0, __ZL16proxy_GetSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE, 0, __ZL17proxy_SetPropertyP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZL16proxy_SetElementP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZL16proxy_SetSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZL19proxy_GetAttributesP9JSContextP8JSObjectiPj, 0, __ZL26proxy_GetElementAttributesP9JSContextP8JSObjectjPj, 0, __ZL26proxy_GetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj, 0, __ZL19proxy_SetAttributesP9JSContextP8JSObjectiPj, 0, __ZL26proxy_SetElementAttributesP9JSContextP8JSObjectjPj, 0, __ZL26proxy_SetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj, 0, __ZL20proxy_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZL19proxy_DeleteElementP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZL19proxy_DeleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZL12proxy_TypeOfP9JSContextP8JSObject, 0, __ZL9proxy_FixP9JSContextP8JSObjectPbPN2js12AutoIdVectorE, 0, __ZL17proxy_innerObjectP9JSContextP8JSObject, 0, __ZL10proxy_CallP9JSContextjPN2JS5ValueE, 0, __ZL15proxy_ConstructP9JSContextjPN2JS5ValueE, 0, __ZL19proxy_TraceFunctionP8JSTracerP8JSObject, 0, __ZL12proxy_createP9JSContextjPN2JS5ValueE, 0, __ZL20proxy_createFunctionP9JSContextjPN2JS5ValueE, 0, __ZL13callable_CallP9JSContextjPN2JS5ValueE, 0, __Z18callable_ConstructP9JSContextjPN2JS5ValueE, 0, __ZL13reflect_parseP9JSContextjPN2JS5ValueE, 0, __ZL13resc_finalizeP9JSContextP8JSObject, 0, __ZL10resc_traceP8JSTracerP8JSObject, 0, __ZL19static_input_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL19static_input_setterP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZL23static_multiline_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL23static_multiline_setterP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZL23static_lastMatch_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL23static_lastParen_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL25static_leftContext_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL26static_rightContext_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL20static_paren1_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL20static_paren2_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL20static_paren3_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL20static_paren4_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL20static_paren5_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL20static_paren6_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL20static_paren7_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL20static_paren8_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL20static_paren9_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL15regexp_finalizeP9JSContextP8JSObject, 0, __Z18js_XDRRegExpObjectP10JSXDRStatePP8JSObject, 0, __ZL15regexp_toStringP9JSContextjPN2JS5ValueE, 0, __ZL14regexp_compileP9JSContextjPN2JS5ValueE, 0, __Z14js_regexp_execP9JSContextjPN2JS5ValueE, 0, __Z14js_regexp_testP9JSContextjPN2JS5ValueE, 0, __ZL12script_traceP8JSTracerP8JSObject, 0, __ZL10str_escapeP9JSContextjPN2JS5ValueE, 0, __ZL12str_unescapeP9JSContextjPN2JS5ValueE, 0, __ZL10str_unevalP9JSContextjPN2JS5ValueE, 0, __ZL13str_decodeURIP9JSContextjPN2JS5ValueE, 0, __ZL13str_encodeURIP9JSContextjPN2JS5ValueE, 0, __ZL23str_decodeURI_ComponentP9JSContextjPN2JS5ValueE, 0, __ZL23str_encodeURI_ComponentP9JSContextjPN2JS5ValueE, 0, __ZL13str_enumerateP9JSContextP8JSObject, 0, __ZL11str_resolveP9JSContextP8JSObjectijPS2_, 0, __ZL9str_quoteP9JSContextjPN2JS5ValueE, 0, __ZL12str_toSourceP9JSContextjPN2JS5ValueE, 0, __ZL13str_substringP9JSContextjPN2JS5ValueE, 0, __ZL15str_toLowerCaseP9JSContextjPN2JS5ValueE, 0, __ZL15str_toUpperCaseP9JSContextjPN2JS5ValueE, 0, __Z13js_str_charAtP9JSContextjPN2JS5ValueE, 0, __Z17js_str_charCodeAtP9JSContextjPN2JS5ValueE, 0, __ZL11str_indexOfP9JSContextjPN2JS5ValueE, 0, __ZL15str_lastIndexOfP9JSContextjPN2JS5ValueE, 0, __ZL8str_trimP9JSContextjPN2JS5ValueE, 0, __ZL12str_trimLeftP9JSContextjPN2JS5ValueE, 0, __ZL13str_trimRightP9JSContextjPN2JS5ValueE, 0, __ZL21str_toLocaleLowerCaseP9JSContextjPN2JS5ValueE, 0, __ZL21str_toLocaleUpperCaseP9JSContextjPN2JS5ValueE, 0, __ZL17str_localeCompareP9JSContextjPN2JS5ValueE, 0, __ZL9str_matchP9JSContextjPN2JS5ValueE, 0, __ZL10str_searchP9JSContextjPN2JS5ValueE, 0, __ZL9str_splitP9JSContextjPN2JS5ValueE, 0, __ZL10str_substrP9JSContextjPN2JS5ValueE, 0, __ZL10str_concatP9JSContextjPN2JS5ValueE, 0, __ZL9str_sliceP9JSContextjPN2JS5ValueE, 0, __ZL8str_boldP9JSContextjPN2JS5ValueE, 0, __ZL11str_italicsP9JSContextjPN2JS5ValueE, 0, __ZL9str_fixedP9JSContextjPN2JS5ValueE, 0, __ZL12str_fontsizeP9JSContextjPN2JS5ValueE, 0, __ZL13str_fontcolorP9JSContextjPN2JS5ValueE, 0, __ZL8str_linkP9JSContextjPN2JS5ValueE, 0, __ZL10str_anchorP9JSContextjPN2JS5ValueE, 0, __ZL10str_strikeP9JSContextjPN2JS5ValueE, 0, __ZL9str_smallP9JSContextjPN2JS5ValueE, 0, __ZL7str_bigP9JSContextjPN2JS5ValueE, 0, __ZL9str_blinkP9JSContextjPN2JS5ValueE, 0, __ZL7str_supP9JSContextjPN2JS5ValueE, 0, __ZL7str_subP9JSContextjPN2JS5ValueE, 0, __ZL16str_fromCharCodeP9JSContextjPN2JS5ValueE, 0, _JS_FinalizeStub, 0, __ZN2js11ArrayBuffer9obj_traceEP8JSTracerP8JSObject, 0, __ZN2js11ArrayBuffer18obj_lookupPropertyEP9JSContextP8JSObjectiPS4_PP10JSProperty, 0, __ZN2js11ArrayBuffer17obj_lookupElementEP9JSContextP8JSObjectjPS4_PP10JSProperty, 0, __ZN2js11ArrayBuffer17obj_lookupSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPS4_PP10JSProperty, 0, __ZN2js11ArrayBuffer18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN2js11ArrayBuffer17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN2js11ArrayBuffer17obj_defineSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS7_EPFiS2_S4_iiSA_Ej, 0, __ZN2js11ArrayBuffer14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE, 0, __ZN2js11ArrayBuffer15obj_getPropertyEP9JSContextP8JSObjectS4_PNS_12PropertyNameEPN2JS5ValueE, 0, __ZN2js11ArrayBuffer14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE, 0, __ZN2js11ArrayBuffer14obj_getSpecialEP9JSContextP8JSObjectS4_NS_9SpecialIdEPN2JS5ValueE, 0, __ZN2js11ArrayBuffer15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN2js11ArrayBuffer14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN2js11ArrayBuffer14obj_setSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPN2JS5ValueEi, 0, __ZN2js11ArrayBuffer17obj_getAttributesEP9JSContextP8JSObjectiPj, 0, __ZN2js11ArrayBuffer24obj_getElementAttributesEP9JSContextP8JSObjectjPj, 0, __ZN2js11ArrayBuffer24obj_getSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj, 0, __ZN2js11ArrayBuffer17obj_setAttributesEP9JSContextP8JSObjectiPj, 0, __ZN2js11ArrayBuffer24obj_setElementAttributesEP9JSContextP8JSObjectjPj, 0, __ZN2js11ArrayBuffer24obj_setSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj, 0, __ZN2js11ArrayBuffer18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN2js11ArrayBuffer17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN2js11ArrayBuffer17obj_deleteSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPN2JS5ValueEi, 0, __ZN2js11ArrayBuffer13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZN2js11ArrayBuffer10obj_typeOfEP9JSContextP8JSObject, 0, __ZN2js11ArrayBuffer18prop_getByteLengthEP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZN2js10TypedArray14prop_getLengthEP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZN2js10TypedArray18prop_getByteLengthEP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZN2js10TypedArray18prop_getByteOffsetEP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZN2js10TypedArray14prop_getBufferEP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIaE12fun_subarrayEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIaE7fun_setEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIhE12fun_subarrayEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIhE7fun_setEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIsE12fun_subarrayEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIsE7fun_setEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateItE12fun_subarrayEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateItE7fun_setEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIiE12fun_subarrayEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIiE7fun_setEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIjE12fun_subarrayEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIjE7fun_setEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIfE12fun_subarrayEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIfE7fun_setEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIdE12fun_subarrayEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIdE7fun_setEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateI13uint8_clampedE12fun_subarrayEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateI13uint8_clampedE7fun_setEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIaE9obj_traceEP8JSTracerP8JSObject, 0, __ZN2js10TypedArray18obj_lookupPropertyEP9JSContextP8JSObjectiPS4_PP10JSProperty, 0, __ZN2js10TypedArray17obj_lookupElementEP9JSContextP8JSObjectjPS4_PP10JSProperty, 0, __ZN2js10TypedArray17obj_lookupSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPS4_PP10JSProperty, 0, __ZN18TypedArrayTemplateIaE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIaE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIaE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej, 0, __ZN18TypedArrayTemplateIaE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIaE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIaE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIaE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIaE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIaE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIaE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN2js10TypedArray17obj_getAttributesEP9JSContextP8JSObjectiPj, 0, __ZN2js10TypedArray24obj_getElementAttributesEP9JSContextP8JSObjectjPj, 0, __ZN2js10TypedArray24obj_getSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj, 0, __ZN2js10TypedArray17obj_setAttributesEP9JSContextP8JSObjectiPj, 0, __ZN2js10TypedArray24obj_setElementAttributesEP9JSContextP8JSObjectjPj, 0, __ZN2js10TypedArray24obj_setSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj, 0, __ZN18TypedArrayTemplateIaE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIaE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIaE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIaE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZN18TypedArrayTemplateIaE10obj_typeOfEP9JSContextP8JSObject, 0, __ZN18TypedArrayTemplateIhE9obj_traceEP8JSTracerP8JSObject, 0, __ZN18TypedArrayTemplateIhE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIhE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIhE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej, 0, __ZN18TypedArrayTemplateIhE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIhE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIhE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIhE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIhE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIhE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIhE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIhE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIhE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIhE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIhE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZN18TypedArrayTemplateIhE10obj_typeOfEP9JSContextP8JSObject, 0, __ZN18TypedArrayTemplateIsE9obj_traceEP8JSTracerP8JSObject, 0, __ZN18TypedArrayTemplateIsE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIsE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIsE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej, 0, __ZN18TypedArrayTemplateIsE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIsE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIsE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIsE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIsE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIsE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIsE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIsE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIsE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIsE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIsE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZN18TypedArrayTemplateIsE10obj_typeOfEP9JSContextP8JSObject, 0, __ZN18TypedArrayTemplateItE9obj_traceEP8JSTracerP8JSObject, 0, __ZN18TypedArrayTemplateItE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateItE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateItE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej, 0, __ZN18TypedArrayTemplateItE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE, 0, __ZN18TypedArrayTemplateItE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateItE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE, 0, __ZN18TypedArrayTemplateItE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateItE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateItE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateItE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateItE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateItE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateItE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateItE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZN18TypedArrayTemplateItE10obj_typeOfEP9JSContextP8JSObject, 0, __ZN18TypedArrayTemplateIiE9obj_traceEP8JSTracerP8JSObject, 0, __ZN18TypedArrayTemplateIiE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIiE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIiE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej, 0, __ZN18TypedArrayTemplateIiE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIiE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIiE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIiE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIiE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIiE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIiE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIiE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIiE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIiE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIiE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZN18TypedArrayTemplateIiE10obj_typeOfEP9JSContextP8JSObject, 0, __ZN18TypedArrayTemplateIjE9obj_traceEP8JSTracerP8JSObject, 0, __ZN18TypedArrayTemplateIjE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIjE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIjE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej, 0, __ZN18TypedArrayTemplateIjE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIjE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIjE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIjE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIjE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIjE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIjE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIjE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIjE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIjE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIjE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZN18TypedArrayTemplateIjE10obj_typeOfEP9JSContextP8JSObject, 0, __ZN18TypedArrayTemplateIfE9obj_traceEP8JSTracerP8JSObject, 0, __ZN18TypedArrayTemplateIfE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIfE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIfE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej, 0, __ZN18TypedArrayTemplateIfE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIfE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIfE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIfE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIfE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIfE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIfE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIfE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIfE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIfE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIfE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZN18TypedArrayTemplateIfE10obj_typeOfEP9JSContextP8JSObject, 0, __ZN18TypedArrayTemplateIdE9obj_traceEP8JSTracerP8JSObject, 0, __ZN18TypedArrayTemplateIdE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIdE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIdE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej, 0, __ZN18TypedArrayTemplateIdE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIdE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIdE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIdE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIdE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIdE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIdE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIdE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIdE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIdE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIdE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZN18TypedArrayTemplateIdE10obj_typeOfEP9JSContextP8JSObject, 0, __ZN18TypedArrayTemplateI13uint8_clampedE9obj_traceEP8JSTracerP8JSObject, 0, __ZN18TypedArrayTemplateI13uint8_clampedE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS3_S5_iPS7_EPFiS3_S5_iiSA_Ej, 0, __ZN18TypedArrayTemplateI13uint8_clampedE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS3_S5_iPS7_EPFiS3_S5_iiSA_Ej, 0, __ZN18TypedArrayTemplateI13uint8_clampedE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS3_S5_iPS9_EPFiS3_S5_iiSC_Ej, 0, __ZN18TypedArrayTemplateI13uint8_clampedE14obj_getGenericEP9JSContextP8JSObjectS5_iPN2JS5ValueE, 0, __ZN18TypedArrayTemplateI13uint8_clampedE15obj_getPropertyEP9JSContextP8JSObjectS5_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateI13uint8_clampedE14obj_getElementEP9JSContextP8JSObjectS5_jPN2JS5ValueE, 0, __ZN18TypedArrayTemplateI13uint8_clampedE14obj_getSpecialEP9JSContextP8JSObjectS5_N2js9SpecialIdEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateI13uint8_clampedE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateI13uint8_clampedE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateI13uint8_clampedE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateI13uint8_clampedE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateI13uint8_clampedE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateI13uint8_clampedE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateI13uint8_clampedE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZN18TypedArrayTemplateI13uint8_clampedE10obj_typeOfEP9JSContextP8JSObject, 0, __ZL16WeakMap_finalizeP9JSContextP8JSObject, 0, __ZL12WeakMap_markP8JSTracerP8JSObject, 0, __ZL11WeakMap_hasP9JSContextjPN2JS5ValueE, 0, __ZL11WeakMap_getP9JSContextjPN2JS5ValueE, 0, __ZL14WeakMap_deleteP9JSContextjPN2JS5ValueE, 0, __ZL11WeakMap_setP9JSContextjPN2JS5ValueE, 0, __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEE15nonMarkingTraceEP8JSTracer, 0, __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEE15markIterativelyEP8JSTracer, 0, __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEE5sweepEP8JSTracer, 0, __ZN9JSWrapperD2Ev, 0, __ZN9JSWrapperD0Ev, 0, __ZN9JSWrapper21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor, 0, __ZN9JSWrapper24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor, 0, __ZN9JSWrapper14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor, 0, __ZN9JSWrapper19getOwnPropertyNamesEP9JSContextP8JSObjectRN2js12AutoIdVectorE, 0, __ZN9JSWrapper7delete_EP9JSContextP8JSObjectiPb, 0, __ZN9JSWrapper9enumerateEP9JSContextP8JSObjectRN2js12AutoIdVectorE, 0, __ZN9JSWrapper3fixEP9JSContextP8JSObjectPN2JS5ValueE, 0, __ZN9JSWrapper3hasEP9JSContextP8JSObjectiPb, 0, __ZN9JSWrapper6hasOwnEP9JSContextP8JSObjectiPb, 0, __ZN9JSWrapper3getEP9JSContextP8JSObjectS3_iPN2JS5ValueE, 0, __ZN9JSWrapper3setEP9JSContextP8JSObjectS3_ibPN2JS5ValueE, 0, __ZN9JSWrapper4keysEP9JSContextP8JSObjectRN2js12AutoIdVectorE, 0, __ZN9JSWrapper7iterateEP9JSContextP8JSObjectjPN2JS5ValueE, 0, __ZN9JSWrapper4callEP9JSContextP8JSObjectjPN2JS5ValueE, 0, __ZN9JSWrapper9constructEP9JSContextP8JSObjectjPN2JS5ValueES6_, 0, __ZN9JSWrapper11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb, 0, __ZN9JSWrapper6typeOfEP9JSContextP8JSObject, 0, __ZN9JSWrapper12obj_toStringEP9JSContextP8JSObject, 0, __ZN9JSWrapper12fun_toStringEP9JSContextP8JSObjectj, 0, __ZN9JSWrapper12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE, 0, __ZN9JSWrapper5traceEP8JSTracerP8JSObject, 0, __ZN9JSWrapper5enterEP9JSContextP8JSObjectiNS_6ActionEPb, 0, __ZN9JSWrapper5leaveEP9JSContextP8JSObject, 0, __ZN25JSCrossCompartmentWrapperD0Ev, 0, __ZN25JSCrossCompartmentWrapper21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor, 0, __ZN25JSCrossCompartmentWrapper24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor, 0, __ZN25JSCrossCompartmentWrapper14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor, 0, __ZN25JSCrossCompartmentWrapper19getOwnPropertyNamesEP9JSContextP8JSObjectRN2js12AutoIdVectorE, 0, __ZN25JSCrossCompartmentWrapper7delete_EP9JSContextP8JSObjectiPb, 0, __ZN25JSCrossCompartmentWrapper9enumerateEP9JSContextP8JSObjectRN2js12AutoIdVectorE, 0, __ZN25JSCrossCompartmentWrapper3hasEP9JSContextP8JSObjectiPb, 0, __ZN25JSCrossCompartmentWrapper6hasOwnEP9JSContextP8JSObjectiPb, 0, __ZN25JSCrossCompartmentWrapper3getEP9JSContextP8JSObjectS3_iPN2JS5ValueE, 0, __ZN25JSCrossCompartmentWrapper3setEP9JSContextP8JSObjectS3_ibPN2JS5ValueE, 0, __ZN25JSCrossCompartmentWrapper4keysEP9JSContextP8JSObjectRN2js12AutoIdVectorE, 0, __ZN25JSCrossCompartmentWrapper7iterateEP9JSContextP8JSObjectjPN2JS5ValueE, 0, __ZN25JSCrossCompartmentWrapper4callEP9JSContextP8JSObjectjPN2JS5ValueE, 0, __ZN25JSCrossCompartmentWrapper9constructEP9JSContextP8JSObjectjPN2JS5ValueES6_, 0, __ZN25JSCrossCompartmentWrapper11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb, 0, __ZN25JSCrossCompartmentWrapper12obj_toStringEP9JSContextP8JSObject, 0, __ZN25JSCrossCompartmentWrapper12fun_toStringEP9JSContextP8JSObjectj, 0, __ZN25JSCrossCompartmentWrapper12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE, 0, __ZN25JSCrossCompartmentWrapper5traceEP8JSTracerP8JSObject, 0, __ZL9mem_get32P10JSXDRStatePj, 0, __ZL9mem_set32P10JSXDRStatePj, 0, __ZL12mem_getbytesP10JSXDRStatePcj, 0, __ZL12mem_setbytesP10JSXDRStatePcj, 0, __ZL7mem_rawP10JSXDRStatej, 0, __ZL8mem_seekP10JSXDRStatei11JSXDRWhence, 0, __ZL8mem_tellP10JSXDRState, 0, __ZL12mem_finalizeP10JSXDRState, 0, __ZL18namespace_equalityP9JSContextP8JSObjectPKN2JS5ValueEPi, 0, __ZL18namespace_toStringP9JSContextjPN2JS5ValueE, 0, __ZL14qname_equalityP9JSContextP8JSObjectPKN2JS5ValueEPi, 0, __ZL14qname_toStringP9JSContextjPN2JS5ValueE, 0, __Z11xml_convertP9JSContextP8JSObject6JSTypePN2JS5ValueE, 0, __ZL12xml_finalizeP9JSContextP8JSObject, 0, __ZL15xml_hasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi, 0, __ZL9xml_traceP8JSTracerP8JSObject, 0, __ZL18xml_lookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty, 0, __ZL17xml_lookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty, 0, __ZL17xml_lookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty, 0, __ZL18xml_definePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej, 0, __ZL17xml_defineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej, 0, __ZL17xml_defineSpecialP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ej, 0, __ZL14xml_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE, 0, __ZL15xml_getPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZL14xml_getElementP9JSContextP8JSObjectS2_jPN2JS5ValueE, 0, __ZL14xml_getSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE, 0, __ZL15xml_setPropertyP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZL14xml_setElementP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZL14xml_setSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZL17xml_getAttributesP9JSContextP8JSObjectiPj, 0, __ZL24xml_getElementAttributesP9JSContextP8JSObjectjPj, 0, __ZL24xml_getSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj, 0, __ZL17xml_setAttributesP9JSContextP8JSObjectiPj, 0, __ZL24xml_setElementAttributesP9JSContextP8JSObjectjPj, 0, __ZL24xml_setSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj, 0, __ZL18xml_deletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZL17xml_deleteElementP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZL17xml_deleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZL13xml_enumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZL10xml_typeOfP9JSContextP8JSObject, 0, __ZL7xml_fixP9JSContextP8JSObjectPbPN2js12AutoIdVectorE, 0, __ZL9xml_clearP9JSContextP8JSObject, 0, __ZL16xml_addNamespaceP9JSContextjPN2JS5ValueE, 0, __ZL15xml_appendChildP9JSContextjPN2JS5ValueE, 0, __ZL13xml_attributeP9JSContextjPN2JS5ValueE, 0, __ZL14xml_attributesP9JSContextjPN2JS5ValueE, 0, __ZL9xml_childP9JSContextjPN2JS5ValueE, 0, __ZL14xml_childIndexP9JSContextjPN2JS5ValueE, 0, __ZL12xml_childrenP9JSContextjPN2JS5ValueE, 0, __ZL12xml_commentsP9JSContextjPN2JS5ValueE, 0, __ZL12xml_containsP9JSContextjPN2JS5ValueE, 0, __ZL8xml_copyP9JSContextjPN2JS5ValueE, 0, __ZL15xml_descendantsP9JSContextjPN2JS5ValueE, 0, __ZL12xml_elementsP9JSContextjPN2JS5ValueE, 0, __ZL18xml_hasOwnPropertyP9JSContextjPN2JS5ValueE, 0, __ZL21xml_hasComplexContentP9JSContextjPN2JS5ValueE, 0, __ZL20xml_hasSimpleContentP9JSContextjPN2JS5ValueE, 0, __ZL21xml_inScopeNamespacesP9JSContextjPN2JS5ValueE, 0, __ZL20xml_insertChildAfterP9JSContextjPN2JS5ValueE, 0, __ZL21xml_insertChildBeforeP9JSContextjPN2JS5ValueE, 0, __ZL10xml_lengthP9JSContextjPN2JS5ValueE, 0, __ZL13xml_localNameP9JSContextjPN2JS5ValueE, 0, __ZL8xml_nameP9JSContextjPN2JS5ValueE, 0, __ZL13xml_namespaceP9JSContextjPN2JS5ValueE, 0, __ZL25xml_namespaceDeclarationsP9JSContextjPN2JS5ValueE, 0, __ZL12xml_nodeKindP9JSContextjPN2JS5ValueE, 0, __ZL13xml_normalizeP9JSContextjPN2JS5ValueE, 0, __ZL10xml_parentP9JSContextjPN2JS5ValueE, 0, __ZL26xml_processingInstructionsP9JSContextjPN2JS5ValueE, 0, __ZL16xml_prependChildP9JSContextjPN2JS5ValueE, 0, __ZL24xml_propertyIsEnumerableP9JSContextjPN2JS5ValueE, 0, __ZL19xml_removeNamespaceP9JSContextjPN2JS5ValueE, 0, __ZL11xml_replaceP9JSContextjPN2JS5ValueE, 0, __ZL15xml_setChildrenP9JSContextjPN2JS5ValueE, 0, __ZL16xml_setLocalNameP9JSContextjPN2JS5ValueE, 0, __ZL11xml_setNameP9JSContextjPN2JS5ValueE, 0, __ZL16xml_setNamespaceP9JSContextjPN2JS5ValueE, 0, __ZL8xml_textP9JSContextjPN2JS5ValueE, 0, __ZL12xml_toSourceP9JSContextjPN2JS5ValueE, 0, __ZL12xml_toStringP9JSContextjPN2JS5ValueE, 0, __ZL15xml_toXMLStringP9JSContextjPN2JS5ValueE, 0, __ZL11xml_valueOfP9JSContextjPN2JS5ValueE, 0, __ZL12xml_settingsP9JSContextjPN2JS5ValueE, 0, __ZL15xml_setSettingsP9JSContextjPN2JS5ValueE, 0, __ZL19xml_defaultSettingsP9JSContextjPN2JS5ValueE, 0, __ZL17NamePrefix_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL14NameURI_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL18xmlfilter_finalizeP9JSContextP8JSObject, 0, __ZL15xmlfilter_traceP8JSTracerP8JSObject, 0, __ZL19QNameNameURI_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL21QNameLocalName_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL17sandbox_enumerateP9JSContextP8JSObject, 0, __ZL15sandbox_resolveP9JSContextP8JSObjectijPS2_, 0, __ZL18resolver_enumerateP9JSContextP8JSObject, 0, __ZL16resolver_resolveP9JSContextP8JSObjectijPS2_, 0, __ZL7VersionP9JSContextjPN2JS5ValueE, 0, __ZL13RevertVersionP9JSContextjPN2JS5ValueE, 0, __ZL7OptionsP9JSContextjPN2JS5ValueE, 0, __ZL4LoadP9JSContextjPN2JS5ValueE, 0, __ZL8EvaluateP9JSContextjPN2JS5ValueE, 0, __ZL3RunP9JSContextjPN2JS5ValueE, 0, __ZL8ReadLineP9JSContextjPN2JS5ValueE, 0, __ZL5PrintP9JSContextjPN2JS5ValueE, 0, __ZL6PutStrP9JSContextjPN2JS5ValueE, 0, __ZL3NowP9JSContextjPN2JS5ValueE, 0, __ZL4HelpP9JSContextjPN2JS5ValueE, 0, __ZL4QuitP9JSContextjPN2JS5ValueE, 0, __ZL8AssertEqP9JSContextjPN2JS5ValueE, 0, __ZL9AssertJitP9JSContextjPN2JS5ValueE, 0, __ZL2GCP9JSContextjPN2JS5ValueE, 0, __ZL11GCParameterP9JSContextjPN2JS5ValueE, 0, __ZL9CountHeapP9JSContextjPN2JS5ValueE, 0, __ZL20MakeFinalizeObserverP9JSContextjPN2JS5ValueE, 0, __ZL13FinalizeCountP9JSContextjPN2JS5ValueE, 0, __ZL13InternalConstP9JSContextjPN2JS5ValueE, 0, __ZL8SetDebugP9JSContextjPN2JS5ValueE, 0, __ZL18SetDebuggerHandlerP9JSContextjPN2JS5ValueE, 0, __ZL12SetThrowHookP9JSContextjPN2JS5ValueE, 0, __ZL4TrapP9JSContextjPN2JS5ValueE, 0, __ZL6UntrapP9JSContextjPN2JS5ValueE, 0, __ZL8LineToPCP9JSContextjPN2JS5ValueE, 0, __ZL8PCToLineP9JSContextjPN2JS5ValueE, 0, __ZL14StringsAreUTF8P9JSContextjPN2JS5ValueE, 0, __ZL8TestUTF8P9JSContextjPN2JS5ValueE, 0, __ZL10ThrowErrorP9JSContextjPN2JS5ValueE, 0, __Z9DumpStackP9JSContextjPN2JS5ValueE, 0, __ZL9BuildDateP9JSContextjPN2JS5ValueE, 0, __ZL5ClearP9JSContextjPN2JS5ValueE, 0, __ZL6InternP9JSContextjPN2JS5ValueE, 0, __ZL5CloneP9JSContextjPN2JS5ValueE, 0, __ZL6GetPDAP9JSContextjPN2JS5ValueE, 0, __ZL6GetSLXP9JSContextjPN2JS5ValueE, 0, __ZL7ToInt32P9JSContextjPN2JS5ValueE, 0, __ZL13EvalInContextP9JSContextjPN2JS5ValueE, 0, __ZL11EvalInFrameP9JSContextjPN2JS5ValueE, 0, __ZL7ShapeOfP9JSContextjPN2JS5ValueE, 0, __ZL8ResolverP9JSContextjPN2JS5ValueE, 0, __ZL5SnarfP9JSContextjPN2JS5ValueE, 0, __ZL7CompileP9JSContextjPN2JS5ValueE, 0, __ZL5ParseP9JSContextjPN2JS5ValueE, 0, __ZL7TimeoutP9JSContextjPN2JS5ValueE, 0, __ZL7ElapsedP9JSContextjPN2JS5ValueE, 0, __ZL6ParentP9JSContextjPN2JS5ValueE, 0, __Z4WrapP9JSContextjPN2JS5ValueE, 0, __Z9SerializeP9JSContextjPN2JS5ValueE, 0, __Z11DeserializeP9JSContextjPN2JS5ValueE, 0, __Z11StringStatsP9JSContextjPN2JS5ValueE, 0, __Z9NewGlobalP9JSContextjPN2JS5ValueE, 0, __ZL15ParseLegacyJSONP9JSContextjPN2JS5ValueE, 0, __ZL27EnableStackWalkingAssertionP9JSContextjPN2JS5ValueE, 0, __ZL10GetMaxArgsP9JSContextjPN2JS5ValueE, 0, __ZL15its_addPropertyP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL15its_delPropertyP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL15its_getPropertyP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL15its_setPropertyP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZL13its_enumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZL11its_resolveP9JSContextP8JSObjectijPS2_, 0, __ZL11its_convertP9JSContextP8JSObject6JSTypePN2JS5ValueE, 0, __ZL12its_finalizeP9JSContextP8JSObject, 0, __ZL16global_enumerateP9JSContextP8JSObject, 0, __ZL14global_resolveP9JSContextP8JSObjectijPS2_, 0, __ZL15env_setPropertyP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZL13env_enumerateP9JSContextP8JSObject, 0, __ZL11env_resolveP9JSContextP8JSObjectijPS2_, 0, __Z22ShellPrincipalsSubsumeP12JSPrincipalsS0_, 0, __Z17CheckObjectAccessP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueE, 0, __ZN2js3cli6detail10BoolOptionD1Ev, 0, __ZN2js3cli6detail10BoolOptionD0Ev, 0, __ZNK2js3cli6detail6Option8isValuedEv, 0, __ZNK2js3cli6detail6Option10isVariadicEv, 0, __ZL25finalize_counter_finalizeP9JSContextP8JSObject, 0, __ZN2js3cli6detail17MultiStringOptionD1Ev, 0, __ZN2js3cli6detail17MultiStringOptionD0Ev, 0, __ZNK2js3cli6detail12ValuedOption8isValuedEv, 0, __ZNK2js3cli6detail17MultiStringOption10isVariadicEv, 0, __ZN2js3cli6detail12StringOptionD1Ev, 0, __ZN2js3cli6detail12StringOptionD0Ev, 0, __ZNSt9bad_allocD0Ev, 0, __ZNKSt9bad_alloc4whatEv, 0 ];

Module["FUNCTION_TABLE"] = FUNCTION_TABLE;

function run(args) {
  args = args || Module["arguments"];
  if (Module["setStatus"]) {
    Module["setStatus"]("");
  }
  if (Module["preRun"]) {
    Module["preRun"]();
  }
  var ret = null;
  if (Module["_main"]) {
    preMain();
    ret = Module.callMain(args);
    if (!Module["noExitRuntime"]) {
      exitRuntime();
    }
  }
  if (Module["postRun"]) {
    Module["postRun"]();
  }
  return ret;
}

Module["run"] = run;

initRuntime();

if (Module["noInitialRun"]) {
  addRunDependency();
}

if (runDependencies == 0) {
  var ret = run();
}
// EMSCRIPTEN_GENERATED_FUNCTIONS: ["__ZN2js2gcL14GetGCKindSlotsENS0_9AllocKindE","__ZNK2js8Bindings9lastShapeEv","__ZNK2js8Bindings16countArgsAndVarsEv","__ZN9JSContext20typeInferenceEnabledEv","__ZNK8JSObject10fixedSlotsEv","__ZNK2js8Bindings17extensibleParentsEv","__ZN8JSObject6asCallEv","__ZN2js2gcL15GetGCObjectKindEjb","__ZN8JSObject10makeVarObjEv","_BUILD_JSVAL","_OBJECT_TO_JSVAL_IMPL","__ZN8JSObject11setOwnShapeEj","__ZN8JSObject7setTypeEPN2js5types10TypeObjectE","__ZN8JSObject11setDelegateEv","_MAGIC_TO_JSVAL_IMPL","__ZN2js2gc5Arena9thingSizeENS0_9AllocKindE","__ZN8JSObject9earlyInitEj","__ZN2js2gc8FreeSpan8allocateEj","__ZN2js14BreakpointSite3incEP9JSContext","__ZN2js14BreakpointSite3decEP9JSContext","__ZN2js14BreakpointSite7setTrapEP9JSContextPF12JSTrapStatusS2_P8JSScriptPhPN2JS5ValueES8_ERKS8_","__ZN2js10Breakpoint13fromSiteLinksEP10JSCListStr","__ZN2js10BreakpointC2EPNS_8DebuggerEPNS_14BreakpointSiteEP8JSObject","__ZN2js10Breakpoint17fromDebuggerLinksEP10JSCListStr","__ZN2js10CallObject6createEP9JSContextP8JSScriptR8JSObjectPS5_","__Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE","__ZN8JSObject8initCallEP9JSContextRKN2js8BindingsEPS_","__ZN2js10CallObject9setCalleeEP8JSObject","__ZN8JSObject12setFixedSlotEjRKN2JS5ValueE","__ZN2JSL17ObjectOrNullValueEP8JSObject","__ZN2JS5Value15setObjectOrNullEP8JSObject","__ZN2JS5Value9setObjectER8JSObject","__ZN2JS5Value7setNullEv","__ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb","__ZN2jsL15ClearValueRangeEPN2JS5ValueEjb","__ZN8JSObject9setParentEPS_","__ZN8JSObject19setDelegateNullSafeEPS_","__ZN2JS5Value8setMagicE10JSWhyMagic","__ZN2JS5Value12setUndefinedEv","__Z10NewGCThingI8JSObjectEPT_P9JSContextN2js2gc9AllocKindEj","__ZN2js2gc10ArenaLists20allocateFromFreeListENS0_9AllocKindEj","__Z20ReportMoreArgsNeededP9JSContextPKcj","__Z20ReportObjectRequiredP9JSContext","__ZN2js14BreakpointSiteC2EP8JSScriptPh","__ZN2JSL14UndefinedValueEv","__ZN2js14BreakpointSite9clearTrapEP9JSContextPNS_6detail9HashTableINS_12HashMapEntryIPhPS0_EENS_7HashMapIS6_S7_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESC_E4EnumEPPF12JSTrapStatusS2_P8JSScriptS6_PN2JS5ValueESM_ESN_","__ZN2js14BreakpointSite14destroyIfEmptyEP9JSRuntimePNS_6detail9HashTableINS_12HashMapEntryIPhPS0_EENS_7HashMapIS6_S7_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESC_E4EnumE","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4Enum11removeFrontEv","__ZNK2js2gc4Cell11compartmentEv","__ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE6removeERKS1_","__ZN9JSRuntime7delete_IN2js14BreakpointSiteEEEvPT_","__ZNK2js14BreakpointSite15firstBreakpointEv","__ZN2js14BreakpointSite13hasBreakpointEPNS_10BreakpointE","__ZN2js10Breakpoint10nextInSiteEv","__ZN2js10Breakpoint7destroyEP9JSContextPNS_6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS6_S8_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESD_E4EnumE","__ZN9JSRuntime7delete_IN2js10BreakpointEEEvPT_","__ZN2js10Breakpoint14nextInDebuggerEv","__ZN2js8DebuggerC2EP9JSContextP8JSObject","__ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES5_","__ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC1ES7_","__ZN2js18RuntimeAllocPolicyC1EP9JSContext","__ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEEC1EP9JSContext","__ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC1ES7_","__ZN2js10AutoLockGCC1EP9JSRuntime","__ZN2js8DebuggerD2Ev","__ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED1Ev","__ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEED1Ev","__ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED1Ev","__ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev","__ZN2js8Debugger4initEP9JSContext","__ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj","__ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj","__ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE4initEj","__ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj","__ZNK2js14BreakpointSite15getScriptObjectEv","__ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5beginEv","__ZNK2js8Debugger10toJSObjectEv","__ZNK8JSObject8getClassEv","__ZNK8JSObject10getPrivateEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv","__ZNK2js10StackFrame13isScriptFrameEv","__ZNK2js10StackFrame11isEvalFrameEv","__ZN9JSContext18isExceptionPendingEv","__ZN8JSObject10setPrivateEPv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3PtrptEv","__ZN2js8Debugger17fromChildJSObjectEP8JSObject","__ZNK8JSObject15getReservedSlotEj","__ZNK2JS5Value8toObjectEv","__ZN2js8Debugger12fromJSObjectEP8JSObject","__ZN2js8Debugger14getScriptFrameEP9JSContextPNS_10StackFrameEPN2JS5ValueE","__ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_","__ZN8JSObject24ensureClassReservedSlotsEP9JSContext","__ZN8JSObject15setReservedSlotEjRKN2JS5ValueE","__ZN2JSL11ObjectValueER8JSObject","__ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_","__ZNK2js8Debugger7getHookENS0_4HookE","__ZNK2JS5Value11isUndefinedEv","__ZNK2js8Debugger15hasAnyLiveHooksEP9JSContext","__ZNK2js8Debugger15firstBreakpointEv","__ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv","__ZN2js8Debugger20slowPathOnEnterFrameEP9JSContext","__ZN2js15AutoValueVectorC1EP9JSContext","__ZNK9JSContext2fpEv","__ZNK2js10StackFrame10scopeChainEv","__ZNK2js8Debugger18observesEnterFrameEv","__ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_","__ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv","__ZN2js16AutoVectorRooterIN2JS5ValueEE3endEv","__ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3hasERKS2_","__ZN2js8Debugger14fireEnterFrameEP9JSContext","__ZN2js15AutoValueVectorD1Ev","__ZN2js8Debugger20slowPathOnLeaveFrameEP9JSContext","__ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_","__ZNK2js10StackFrame6scriptEv","__ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE","__ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE","__ZNK2JS5Value8isObjectEv","__ZNK2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv","__ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13relookupOrAddERNS_6detail9HashTableINS_12HashMapEntryIS2_S2_EENS6_13MapHashPolicyES5_E6AddPtrERKS2_SG_","__ZN2js8Debugger19unwrapDebuggeeValueEP9JSContextPN2JS5ValueE","__ZNK2JS5Value14toObjectOrNullEv","__ZNK2JS5Value6isNullEv","__ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb","__ZNK8JSObject12lastPropertyEv","__ZNK2js5Shape8previousEv","__ZNK8JSObject8isObjectEv","__ZNK2js5Shape16isDataDescriptorEv","__ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv","__ZN9JSContext19getPendingExceptionEv","__ZN9JSContext19setPendingExceptionEN2JS5ValueE","__ZN13JSCompartment12getDebuggeesEv","__ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv","__ZN9JSContext21clearPendingExceptionEv","__ZN2js8Debugger20parseResumptionValueERNS_15AutoCompartmentEbRKN2JS5ValueEPS4_b","__ZN2js8Debugger18newCompletionValueERNS_15AutoCompartmentEbN2JS5ValueEPS4_","__ZL12ATOM_TO_JSIDP6JSAtom","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE","__Z19CallMethodIfPresentP9JSContextP8JSObjectPKciPN2JS5ValueES7_","__ZL13js_IsCallableRKN2JS5ValueE","__ZN2js8Debugger21fireDebuggerStatementEP9JSContextPN2JS5ValueE","__ZN2js8Debugger19fireExceptionUnwindEP9JSContextPN2JS5ValueE","__ZN2js8Debugger13fireNewScriptEP9JSContextP8JSScriptP8JSObjectNS0_13NewScriptKindE","__ZN2js8Debugger14wrapHeldScriptEP9JSContextP8JSScriptP8JSObject","__ZN2js8Debugger17wrapNonHeldScriptEP9JSContextP8JSScript","__ZN2js8Debugger12dispatchHookEP9JSContextPN2JS5ValueENS0_4HookE","__ZN2js8Debugger19slowPathOnNewScriptEP9JSContextP8JSScriptP8JSObjectNS0_13NewScriptKindE","__ZL22AddNewScriptRecipientsPN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEEEPNS_15AutoValueVectorE","__ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3allEv","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv","__ZNK2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE5beginEv","__ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv","__ZNK2js10Breakpoint10getHandlerEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv","__ZN2js8Debugger9fromLinksEP10JSCListStr","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE3endEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv","__ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv","__ZN2js8Debugger6onTrapEP9JSContextPN2JS5ValueE","__ZNK9JSContext4regsEv","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEEC1ES3_","__ZN2js15TempAllocPolicyC1EP9JSContext","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_","__ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6lookupERKS2_","__ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv","__ZN2JS5Value8setInt32Ei","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEED1Ev","__ZN2js8Debugger12onSingleStepEP9JSContextPN2JS5ValueE","__ZN2js16AutoObjectVectorC1EP9JSContext","__ZN2js16AutoVectorRooterIP8JSObjectE6appendERKS2_","__ZN2js16AutoVectorRooterIP8JSObjectE5beginEv","__ZN2js16AutoVectorRooterIP8JSObjectE3endEv","__ZN2js16AutoObjectVectorD1Ev","__ZN2js8Debugger21markKeysInCompartmentEP8JSTracerRKNS_7WeakMapIP8JSObjectS5_NS_13DefaultHasherIS5_EENS_17DefaultMarkPolicyIS5_S5_EEEE","__ZNK2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv","__ZN2js8Debugger43markCrossCompartmentDebuggerObjectReferentsEP8JSTracer","__ZN2js8Debugger18markAllIterativelyEPNS_8GCMarkerE","__ZN2js8Debugger11traceObjectEP8JSTracerP8JSObject","__ZN2js8Debugger5traceEP8JSTracer","__ZN2js11WeakMapBase5traceEP8JSTracer","__ZNK2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv","__ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5emptyEv","__ZNK2js12CallReceiver5thisvEv","__ZNK2js12CallReceiver4rvalEv","__ZNK2js8CallArgsixEj","__ZN2js8Debugger8sweepAllEP9JSContext","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC1IS9_EERT_","__ZN2js8Debugger20removeDebuggeeGlobalEP9JSContextPNS_12GlobalObjectEPNS_6detail9HashTableIKS4_NS_7HashSetIS4_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE6SetOpsESB_E4EnumESG_","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD1Ev","__ZN2js8Debugger28detachAllDebuggersFromGlobalEP9JSContextPNS_12GlobalObjectEPNS_6detail9HashTableIKS4_NS_7HashSetIS4_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE6SetOpsESB_E4EnumE","__ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE4backEv","__ZN2js8Debugger8finalizeEP9JSContextP8JSObject","__ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5emptyEv","__ZN9JSContext7delete_IN2js8DebuggerEEEvPT_","__ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc","__ZN2js8Debugger10getEnabledEP9JSContextjPN2JS5ValueE","__ZN2js14CallArgsFromVpEjPN2JS5ValueE","__ZN2JS5Value10setBooleanEb","__ZN2js8Debugger10setEnabledEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger11getHookImplEP9JSContextjPN2JS5ValueENS0_4HookE","__ZN2js8Debugger11setHookImplEP9JSContextjPN2JS5ValueENS0_4HookE","__ZN8JSObject10isCallableEv","__ZN2js8Debugger22getOnDebuggerStatementEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger22setOnDebuggerStatementEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger20getOnExceptionUnwindEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger20setOnExceptionUnwindEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger14getOnNewScriptEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger14setOnNewScriptEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger15getOnEnterFrameEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger15setOnEnterFrameEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger24getUncaughtExceptionHookEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger24setUncaughtExceptionHookEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger22unwrapDebuggeeArgumentEP9JSContextRKN2JS5ValueE","__ZNK8JSObject15getProxyPrivateEv","__ZN2js8Debugger11addDebuggeeEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger17addDebuggeeGlobalEP9JSContextPNS_12GlobalObjectE","__ZNK2js12ContextStack5spaceEv","__ZNK2js13AllFramesIter2fpEv","__ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE6lengthEv","__ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE6lengthEv","__ZNK2js13AllFramesIter4doneEv","__ZNK13JSCompartment9debugModeEv","__ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE3endEv","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE7popBackEv","__ZNK10JSFunction6scriptEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv","__ZN2js8Debugger14removeDebuggeeEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger11hasDebuggeeEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger12getDebuggeesEP9JSContextjPN2JS5ValueE","__ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5countEv","__ZN8JSObject33ensureDenseArrayInitializedLengthEP9JSContextjj","__ZN2js8Debugger14getNewestFrameEP9JSContextjPN2JS5ValueE","__ZNK2js8Debugger13observesFrameEPNS_10StackFrameE","__ZN2js8Debugger19clearAllBreakpointsEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger9constructEP9JSContextjPN2JS5ValueE","__ZNK2js12CallReceiver6calleeEv","__ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE","__ZN9JSContext4new_IN2js8DebuggerEPS_P8JSObjectEEPT_T0_T1_","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEC1ES3_","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEixEj","__ZN2jsL4FindINS_6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEEEEPNT_11ElementTypeERS6_RKS7_","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE6appendIS2_EEbT_","__ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3putERKS2_","__ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeERKS2_","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC1ISC_EERT_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4Enum11removeFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD1Ev","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5eraseEPS2_","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4Enum11removeFrontEv","__ZL20DebuggerScript_traceP8JSTracerP8JSObject","__ZN2js8Debugger17newDebuggerScriptEP9JSContextP8JSScriptP8JSObject","__ZN2JSL12PrivateValueEPv","__ZN2js8Debugger18wrapFunctionScriptEP9JSContextP10JSFunction","__ZN2js8Debugger15wrapJSAPIScriptEP9JSContextP8JSObject","__ZNK8JSObject9getScriptEv","__ZNK2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv","__ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13relookupOrAddERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_","__ZN2js8Debugger23slowPathOnDestroyScriptEP8JSScript","__ZN2js8Debugger20destroyNonHeldScriptEP8JSScript","__ZNK2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_","__ZL19ClearScriptReferentP8JSObject","__ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE","__ZL21DebuggerScript_getUrlP9JSContextjPN2JS5ValueE","__ZL27DebuggerScript_getStartLineP9JSContextjPN2JS5ValueE","__ZL27DebuggerScript_getLineCountP9JSContextjPN2JS5ValueE","__ZL22DebuggerScript_getLiveP9JSContextjPN2JS5ValueE","__ZL30DebuggerScript_getChildScriptsP9JSContextjPN2JS5ValueE","__ZL28DebuggerScript_getAllOffsetsP9JSContextjPN2JS5ValueE","__ZL29DebuggerScript_getLineOffsetsP9JSContextjPN2JS5ValueE","__ZL28DebuggerScript_getOffsetLineP9JSContextjPN2JS5ValueE","__ZL28DebuggerScript_setBreakpointP9JSContextjPN2JS5ValueE","__ZL29DebuggerScript_getBreakpointsP9JSContextjPN2JS5ValueE","__ZL30DebuggerScript_clearBreakpointP9JSContextjPN2JS5ValueE","__ZL34DebuggerScript_clearAllBreakpointsP9JSContextjPN2JS5ValueE","__ZN2js15EvaluateInScopeEP9JSContextP8JSObjectPNS_10StackFrameEPKtjPKcjPN2JS5ValueE","__ZN2js11ComputeThisEP9JSContextPNS_10StackFrameE","__ZN8JSObject10principalsEP9JSContext","__ZNK9JSContext11findVersionEv","__ZNK2js10StackFrame9thisValueEv","__ZL26DebuggerFrame_getArgumentsP9JSContextjPN2JS5ValueE","__ZL23DebuggerFrame_getCalleeP9JSContextjPN2JS5ValueE","__ZL29DebuggerFrame_getConstructingP9JSContextjPN2JS5ValueE","__ZL26DebuggerFrame_getGeneratorP9JSContextjPN2JS5ValueE","__ZL21DebuggerFrame_getLiveP9JSContextjPN2JS5ValueE","__ZL23DebuggerFrame_getOffsetP9JSContextjPN2JS5ValueE","__ZL22DebuggerFrame_getOlderP9JSContextjPN2JS5ValueE","__ZL23DebuggerFrame_getScriptP9JSContextjPN2JS5ValueE","__ZL21DebuggerFrame_getThisP9JSContextjPN2JS5ValueE","__ZL21DebuggerFrame_getTypeP9JSContextjPN2JS5ValueE","__ZL23DebuggerFrame_getOnStepP9JSContextjPN2JS5ValueE","__ZL23DebuggerFrame_setOnStepP9JSContextjPN2JS5ValueE","__ZL18DebuggerFrame_evalP9JSContextjPN2JS5ValueE","__ZL30DebuggerFrame_evalWithBindingsP9JSContextjPN2JS5ValueE","__ZL20DebuggerObject_traceP8JSTracerP8JSObject","__ZL23DebuggerObject_getProtoP9JSContextjPN2JS5ValueE","__ZL23DebuggerObject_getClassP9JSContextjPN2JS5ValueE","__ZL26DebuggerObject_getCallableP9JSContextjPN2JS5ValueE","__ZL22DebuggerObject_getNameP9JSContextjPN2JS5ValueE","__ZL32DebuggerObject_getParameterNamesP9JSContextjPN2JS5ValueE","__ZL24DebuggerObject_getScriptP9JSContextjPN2JS5ValueE","__ZL39DebuggerObject_getOwnPropertyDescriptorP9JSContextjPN2JS5ValueE","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE10getKeyHashEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEptEv","__ZNK2js7MoveRefINS_12HashMapEntryIP8JSScriptP8JSObjectEEEptEv","__ZNK2js7MoveRefIP8JSScriptEcvRS2_Ev","__ZNK2js7MoveRefIP8JSObjectEcvRS2_Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isFreeEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE10isLiveHashEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE12hasCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11underloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE14unsetCollisionEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEC2ERS9_","__ZN2js7MoveRefINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC2ERS6_","__ZN2js7MoveRefIP8JSObjectEC2ERS2_","__ZN2js7MoveRefIP8JSScriptEC2ERS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE12setCollisionEv","__ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC2Ev","__ZN2js12HashMapEntryIP8JSScriptP8JSObjectEaSERKS5_","__ZL34DebuggerObject_getOwnPropertyNamesP9JSContextjPN2JS5ValueE","__ZL29DebuggerObject_definePropertyP9JSContextjPN2JS5ValueE","__ZL31DebuggerObject_definePropertiesP9JSContextjPN2JS5ValueE","__ZL29DebuggerObject_deletePropertyP9JSContextjPN2JS5ValueE","__ZL19DebuggerObject_sealP9JSContextjPN2JS5ValueE","__ZL21DebuggerObject_freezeP9JSContextjPN2JS5ValueE","__ZL32DebuggerObject_preventExtensionsP9JSContextjPN2JS5ValueE","__ZL23DebuggerObject_isSealedP9JSContextjPN2JS5ValueE","__ZL23DebuggerObject_isFrozenP9JSContextjPN2JS5ValueE","__ZL27DebuggerObject_isExtensibleP9JSContextjPN2JS5ValueE","__ZL20DebuggerObject_applyP9JSContextjPN2JS5ValueE","__ZL19DebuggerObject_callP9JSContextjPN2JS5ValueE","_JS_DefineDebuggerObject","__ZL23DebuggerFrame_constructP9JSContextjPN2JS5ValueE","__ZL24DebuggerScript_constructP9JSContextjPN2JS5ValueE","__ZL24DebuggerObject_constructP9JSContextjPN2JS5ValueE","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isLiveEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEaSENS_7MoveRefIS8_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEENS_7MoveRefIT_EERSB_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj","__ZN2js18RuntimeAllocPolicy5free_EPv","__ZN9JSRuntime5free_EPv","__ZN2js10Foreground5free_EPv","_js_free","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEC1ERS9_","__ZN2js12HashMapEntryIP8JSScriptP8JSObjectEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_12HashMapEntryIP8JSScriptP8JSObjectEEEENS_7MoveRefIT_EERS8_","__ZN2js7MoveRefINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC1ERS6_","__ZN2js4MoveIP8JSScriptEENS_7MoveRefIT_EERKS4_","__ZN2js4MoveIP8JSObjectEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefIP8JSObjectEC1ERS2_","__ZN2js7MoveRefIP8JSScriptEC1ERS2_","__ZN2js18RuntimeAllocPolicy7malloc_Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC2Ev","__ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC1Ev","__ZN9JSRuntime7malloc_EjP9JSContext","__ZN9JSRuntime19updateMallocCounterEj","_js_malloc","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE7setFreeEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE10getKeyHashEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEptEv","__ZNK2js7MoveRefINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEptEv","__ZNK2js7MoveRefIPNS_10StackFrameEEcvRS2_Ev","__ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE10getKeyHashEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEptEv","__ZNK2js7MoveRefIPNS_12GlobalObjectEEcvRS2_Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE9matchHashEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE9isRemovedEv","__ZN2js13PointerHasherIP8JSScriptLj2EE5matchERKS2_S5_","__ZN2js13PointerHasherIP8JSScriptLj2EE4hashERKS2_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10overloadedEv","__ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE12hasCollisionEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE12hasCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isFreeEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE10isLiveHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE12setCollisionEj","__ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE","__ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC2ERKS2_RKS4_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE7setLiveEj","__ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE10setRemovedEv","__ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE7setFreeEv","__ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEaSERKS5_","__ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11underloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE14unsetCollisionEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEC2ERS9_","__ZN2js7MoveRefINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC2ERS6_","__ZN2js7MoveRefIPNS_10StackFrameEEC2ERS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE12setCollisionEv","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE10endNoCheckEv","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE14unsetCollisionEv","__ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEC2ERS6_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13relookupOrAddERNSE_6AddPtrERKS4_RKS7_","__ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC1ERKS2_RKS4_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrERKS7_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS4_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE7setFreeEv","__ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEC1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isLiveEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEaSENS_7MoveRefIS8_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEENS_7MoveRefIT_EERSB_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEC1ERS9_","__ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEENS_7MoveRefIT_EERS8_","__ZN2js7MoveRefINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC1ERS6_","__ZN2js4MoveIPNS_10StackFrameEEENS_7MoveRefIT_EERKS4_","__ZN2js7MoveRefIPNS_10StackFrameEEC1ERS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC2ISC_EERT_","__ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS6_6SetOpsES5_E3PtrE","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j","__ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isLiveEv","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEENS_7MoveRefIT_EERS8_","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj","__ZN2js17SystemAllocPolicy5free_EPv","__ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEC1ERS6_","__ZN2js4MoveIPNS_12GlobalObjectEEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefIPNS_12GlobalObjectEEC1ERS2_","__ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_","__ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE12beginNoCheckEv","__ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE5beginEv","__ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5countEv","__ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE5beginEv","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj","__ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isFreeEv","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj","__ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE10isLiveHashEj","__ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE9isRemovedEv","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv","__ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE9matchHashEj","__ZN2js13PointerHasherIPNS_12GlobalObjectELj2EE5matchERKS2_S5_","__ZN2js13PointerHasherIPNS_12GlobalObjectELj2EE4hashERKS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE10isLiveHashEj","__ZNK7mozilla14AlignedStorageILj1EE4addrEv","__ZN7mozilla14AlignedStorageILj1EE4addrEv","__ZN2js7MoveRefIPNS_12GlobalObjectEEC2ERS2_","__ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE12setCollisionEv","__ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEEC2Ev","__ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrdeEv","__ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE7setLiveEj","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE","__ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE12setCollisionEj","__ZN2js10VectorImplIPNS_8DebuggerELj0ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_","__ZN2jsL4FindIP13JSCompartmentEEPT_S4_S4_RKS3_","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js10VectorImplIP13JSCompartmentLj0ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE3endEv","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js17SystemAllocPolicy7malloc_Ej","__ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEEC1Ev","__ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE12lookupForAddERKS2_","__ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS6_6SetOpsES5_E6AddPtrERS9_","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS4_","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE","__ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERS4_","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS4_","__ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_jj","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE13growStorageByEj","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_","__ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIPNS_8DebuggerELj0ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj","__ZN2js17SystemAllocPolicy8realloc_EPvjj","_js_realloc","__ZN2js11RoundUpPow2Ej","__ZN2js10VectorImplIPNS_8DebuggerELj0ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_","__ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIP13JSCompartmentLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj","__ZN2js15TempAllocPolicy8realloc_EPvjj","__ZN2js15TempAllocPolicy7malloc_Ej","__ZN2js10VectorImplIP13JSCompartmentLj0ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEED2Ev","__ZN2js15TempAllocPolicy5free_EPv","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEC2ES3_","__ZN9JSContext7malloc_Ej","__ZN9JSContext5free_EPv","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD2Ev","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC2IS9_EERT_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isLiveEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE6appendIS2_EEbT_","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_","__ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv","__ZNK2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE10getKeyHashEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEptEv","__ZNK2js7MoveRefINS_12HashMapEntryIP8JSObjectS3_EEEptEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E10overloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isFreeEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE9matchHashEj","__ZN2js13PointerHasherIP8JSObjectLj2EE5matchERKS2_S5_","__ZN2js13PointerHasherIP8JSObjectLj2EE4hashERKS2_","__ZNK7mozilla14AlignedStorageILj32EE4addrEv","__ZN2js10VectorImplIP8JSObjectLj8ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js10VectorImplIPNS_10BreakpointELj0ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_","__ZN2js12HashMapEntryIP8JSObjectS2_EC2ERKS2_S5_","__ZN2js12HashMapEntryIP8JSObjectS2_EaSERKS3_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE7setLiveEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE14unsetCollisionEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEC2ERS7_","__ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectS3_EEEC2ERS4_","__ZN2js12HashMapEntryIP8JSObjectS2_EC2Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE12setCollisionEj","__ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S2_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIP8JSObjectLj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj8ES3_EEj","__ZN2js10VectorImplIP8JSObjectLj8ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv","__ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_","__ZNK2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIPNS_10BreakpointELj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj","__ZN2js10VectorImplIPNS_10BreakpointELj0ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEED2Ev","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEEC2ES3_","__ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3allEv","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC1EPNS0_14HashTableEntryIS4_EESF_","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC2EPNS0_14HashTableEntryIS4_EESF_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E13relookupOrAddERNSC_6AddPtrERKS4_RKS5_","__ZN2js12HashMapEntryIP8JSObjectS2_EC1ERKS2_S5_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrERKS5_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEEaSENS_7MoveRefIS6_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEENS_7MoveRefIT_EERS9_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEC1ERS7_","__ZN2js12HashMapEntryIP8JSObjectS2_EaSENS_7MoveRefIS3_EE","__ZN2js4MoveINS_12HashMapEntryIP8JSObjectS3_EEEENS_7MoveRefIT_EERS6_","__ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectS3_EEEC1ERS4_","__ZN2js4MoveIP8JSObjectEENS_7MoveRefIT_EERKS4_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEEC2Ev","__ZN2js12HashMapEntryIP8JSObjectS2_EC1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE","__ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE","__ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js7MoveRefIN2JS5ValueEEcvRS2_Ev","__ZNK8JSObject9getParentEv","__ZNK8JSObject8numSlotsEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE9matchHashEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE9isRemovedEv","__ZN2js13PointerHasherIPNS_10StackFrameELj2EE5matchERKS2_S5_","__ZN2js13PointerHasherIPNS_10StackFrameELj2EE4hashERKS2_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10overloadedEv","__ZNK2js5Class8isNativeEv","__ZNK8JSObject12isDenseArrayEv","__ZN2js5types10TypeObject17unknownPropertiesEv","__ZNK7mozilla14AlignedStorageILj64EE4addrEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE12setCollisionEj","__ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js7MoveRefIN2JS5ValueEEC2ERS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE7setLiveEj","__ZN2js2gcL15GetGCObjectKindEjb1","__ZN8JSObject6setMapEPN2js5ShapeE","__ZN2js11KidsPointer7setNullEv","__ZNK2js10EmptyShape8getClassEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE6appendIS2_EEbT_","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_","__ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIN2JS5ValueELj8ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj8ES3_EEj","__ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefIN2JS5ValueEEC1ERS2_","__ZN2js10VectorImplIN2JS5ValueELj8ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERKS4_","__ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE","__ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE","__ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE","__ZN8JSObject21setSharedNonNativeMapEv","__ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE","__ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE","__ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE","__ZN2js10EmptyShapeC1EP13JSCompartmentPNS_5ClassE","__ZN2js10EmptyShapeC2EP13JSCompartmentPNS_5ClassE","__ZN2js5ShapeC2EP13JSCompartmentPNS_5ClassE","__ZN9JSContext7calloc_Ej","__ZN9JSRuntime7calloc_EjP9JSContext","_js_calloc","__ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2","__ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4initEj","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4initEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE10getKeyHashEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEptEv","__ZNK2js7MoveRefINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEptEv","__ZNK2js7MoveRefIPhEcvRS1_Ev","__ZNK2js7MoveRefIPNS_14BreakpointSiteEEcvRS2_Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3Ptr7nonNullEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE12hasCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5hash1Ejj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isFreeEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE10isLiveHashEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE12hasCollisionEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE9matchHashEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE9isRemovedEv","__ZN2js13PointerHasherIPhLj2EE5matchERKS1_S4_","__ZN2js13PointerHasherIPhLj2EE4hashERKS1_","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC2ESB_","__ZN2js11WeakMapBaseC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E11underloadedEv","__ZN2js17DefaultMarkPolicyIP8JSObjectS2_EC2EP8JSTracer","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_EC2ES9_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC2ESB_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E11underloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE14unsetCollisionEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEC2ERS8_","__ZN2js7MoveRefINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC2ERS5_","__ZN2js7MoveRefIPNS_14BreakpointSiteEEC2ERS2_","__ZN2js7MoveRefIPhEC2ERS1_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE12setCollisionEv","__ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEC2Ev","__ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEaSERKS4_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE12setCollisionEj","__ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S3_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrC2ERNS0_14HashTableEntryIS6_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4initEj","__ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_","__ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES7_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC1ESB_","__ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEEC2EP9JSContext","__ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES5_","__ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEE15nonMarkingTraceEP8JSTracer","__ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEE15markIterativelyEP8JSTracer","__ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEE5sweepEP8JSTracer","__ZN2js17DefaultMarkPolicyIP8JSObjectS2_EC1EP8JSTracer","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumC1INS_7WeakMapIS4_S4_S8_NS_17DefaultMarkPolicyIS4_S4_EEEEEERT_","__ZN2js17DefaultMarkPolicyIP8JSObjectS2_E9keyMarkedES2_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS5_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE7setFreeEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumC2INS_7WeakMapIS4_S4_S8_NS_17DefaultMarkPolicyIS4_S4_EEEEEERT_","__ZN2js17DefaultMarkPolicyIP8JSObjectS2_E15markEntryIfLiveES2_S2_","__ZN2js17DefaultMarkPolicyIP8JSObjectS2_E11valueMarkedES2_","__ZN2js17DefaultMarkPolicyIP8JSObjectS2_E9markEntryES2_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_EC1ES9_","__ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES7_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC1ESB_","__ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE6lookupERKS1_","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrcvMSE_FvvEEv","__ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS1_S3_EENS7_13MapHashPolicyES6_E3PtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6removeENSD_3PtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6removeERNS0_14HashTableEntryIS6_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E16checkUnderloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E11createTableERSA_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isLiveEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEaSENS_7MoveRefIS7_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEENS_7MoveRefIT_EERSA_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E12destroyTableERSA_PNS0_14HashTableEntryIS6_EEj","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEC1ERS8_","__ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEaSENS_7MoveRefIS4_EE","__ZN2js4MoveINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEENS_7MoveRefIT_EERS7_","__ZN2js7MoveRefINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC1ERS5_","__ZN2js4MoveIPhEENS_7MoveRefIT_EERKS3_","__ZN2js4MoveIPNS_14BreakpointSiteEEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefIPNS_14BreakpointSiteEEC1ERS2_","__ZN2js7MoveRefIPhEC1ERS1_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC2Ev","__ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE7setFreeEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3Ptr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6lookupERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E11prepareHashERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrC1ERNS0_14HashTableEntryIS6_EE","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6lookupERKS3_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5matchERNS0_14HashTableEntryIS6_EERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E10isLiveHashEj","__ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE5beginEv","__ZNK2js8CallArgs4argvEv","__ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE6lengthEv","__ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK8JSObject4typeEv","__ZN2js5types8Property6getKeyEPS1_","__ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5emptyEv","__ZNK8JSObject12isExtensibleEv","__ZNK2js5Shape8isNativeEv","__ZNK8JSObject11hasLazyTypeEv","__ZNK8JSObject16hasSingletonTypeEv","__ZNK2js5types10TypeObject17basePropertyCountEv","__ZN7mozilla14AlignedStorageILj32EE4addrEv","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE3endEv","__ZN2js11ErrorCopierC2ERNS_15AutoCompartmentEP8JSObject","__ZN2js12AutoGCRooterD2Ev","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js12AutoGCRooterC2EP9JSContexti","__ZL11ApplyOrCallP9JSContextjPN2JS5ValueE15ApplyOrCallMode","__ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc","__ZNK2JS5Value17isNullOrUndefinedEv","__ZN2js16AutoVectorRooterIN2JS5ValueEE6growByEj","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE19growByUninitializedEj","__ZN2jsL15MakeRangeGCSafeEPN2JS5ValueES2_","__ZN2jsL7PodZeroIN2JS5ValueEEEvPT_j","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj","__ZL29DebuggerObject_isSealedHelperP9JSContextjPN2JS5ValueE12SealHelperOpPKc","__ZN2js11ErrorCopierC1ERNS_15AutoCompartmentEP8JSObject","__ZN8JSObject8isSealedEP9JSContextPb","__ZN8JSObject8isFrozenEP9JSContextPb","__ZL25DebuggerObject_sealHelperP9JSContextjPN2JS5ValueE12SealHelperOpPKc","__ZN8JSObject4sealEP9JSContext","__ZN8JSObject6freezeEP9JSContext","__ZN2js12AutoIdVectorC1EP9JSContext","__ZN8JSObject17preventExtensionsEP9JSContextPN2js12AutoIdVectorE","__ZN2js12AutoIdVectorD1Ev","__ZN2js12AutoIdVectorD2Ev","__ZN2js16AutoVectorRooterIiED2Ev","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEED2Ev","__ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZNK8JSObject6getOpsEv","__ZNK8JSObject8isNativeEv","__ZN8JSObject21extensibleShapeChangeEP9JSContext","__ZN2js12AutoIdVectorC2EP9JSContext","__ZN2js16AutoVectorRooterIiEC2EP9JSContexti","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEEC1ES1_","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEEC2ES1_","__ZN8JSObject14deletePropertyEP9JSContextiPN2JS5ValueEi","__ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiNS0_4TypeE","__ZN2js5types4Type13UndefinedTypeEv","__ZN2js5types26MarkTypePropertyConfiguredEP9JSContextP8JSObjecti","__ZN2js5types10MakeTypeIdEP9JSContexti","__ZN2js5types18TrackPropertyTypesEP9JSContextP8JSObjecti","__ZN2js5types10TypeObject16maybeGetPropertyEP9JSContexti","__ZN2js5typesL13HashSetLookupIiNS0_8PropertyES2_EEPT0_PS4_jT_","__ZN2js5typesL15HashSetCapacityEj","__ZN2js5types8Property7keyBitsEi","__ZNK14JSLinearString5charsEv","__ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE5beginEv","__ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE5beginEv","__ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE6lengthEv","__ZNK2js7MoveRefINS_8PropDescEEcvRS1_Ev","_JSID_IS_INT","_JSID_IS_STRING","_JSID_TO_FLAT_STRING","__ZNK8JSString6isFlatEv","__ZNK8JSString11isDependentEv","__ZNK8JSObject13isObjectProxyEv","__ZNK8JSObject15isFunctionProxyEv","_JSID_TO_INT","_JSID_TO_STRING","_JSID_TO_OBJECT","__ZNK8JSObject10isFunctionEv","__ZN8JSString6asFlatEv","__ZN8JSString11asDependentEv","__ZN8JSString6asRopeEv","__ZNK7mozilla14AlignedStorageILj40EE4addrEv","__ZN7mozilla14AlignedStorageILj40EE4addrEv","__ZN2js12CastAsObjectEPFiP9JSContextP8JSObjectiPN2JS5ValueEE","__ZN2jsL16CastAsPropertyOpEP8JSObject","__ZN2js12CastAsObjectEPFiP9JSContextP8JSObjectiiPN2JS5ValueEE","__ZN2jsL22CastAsStrictPropertyOpEP8JSObject","__ZN2js5types4TypeC2Ej","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE3endEv","__ZN2js7MoveRefINS_8PropDescEEC2ERS1_","_STRING_TO_JSVAL_IMPL","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE8shrinkByEj","__ZN2js5typesL7HashKeyIiNS0_8PropertyEEEjT_","__ZN8JSString9getCharsZEP9JSContext","__ZN8JSString10ensureFlatEP9JSContext","__ZN2js5types4TypeC1Ej","__ZN2js8ToObjectEP9JSContextPN2JS5ValueE","__ZN2js23AutoPropDescArrayRooterC1EP9JSContext","__ZNK2js16AutoVectorRooterIiE6lengthEv","__ZL14UnwrapPropDescP9JSContextPN2js8DebuggerEP8JSObjectPNS1_8PropDescE","__ZN2js23AutoPropDescArrayRooterixEj","__ZL17WrapIdAndPropDescP9JSContextP8JSObjectPiPN2js8PropDescE","__ZN2js16AutoVectorRooterIiEixEj","__ZN2js23AutoPropDescArrayRooterD1Ev","__ZN2js23AutoPropDescArrayRooterD2Ev","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEED2Ev","__ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEEixEj","__ZNK8JSObject7isProxyEv","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEEixEj","__ZL19CheckArgCompartmentP9JSContextP8JSObjectRKN2JS5ValueEPKcS8_","__ZN2js8PropDesc11checkGetterEP9JSContext","__ZN2js8PropDesc11checkSetterEP9JSContext","__ZN2js23AutoPropDescArrayRooterC2EP9JSContext","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEEC1ES2_","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEEC2ES2_","__ZN2js23AutoPropDescArrayRooter6appendEv","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE6appendIS1_EEbT_","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE4backEv","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE14internalAppendIS1_EEvT_","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplINS_8PropDescELj1ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj1ES2_EEj","__ZN2js4MoveINS_8PropDescEEENS_7MoveRefIT_EERS3_","__ZN2js7MoveRefINS_8PropDescEEC1ERS1_","__ZN2js10VectorImplINS_8PropDescELj1ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_","__ZN2js4MoveINS_8PropDescEEENS_7MoveRefIT_EERKS3_","__ZN2js16AutoVectorRooterIN2JS5ValueEE6resizeEj","__ZN2JSL10Int32ValueEi","__ZN2js16AutoVectorRooterIN2JS5ValueEEixEj","__ZN2JS5Value9setStringEP8JSString","__ZL12JSID_IS_ATOMi","__ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEEixEj","__ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext","__ZN2JSL17ObjectOrNullValueEP8JSObject5","__ZN2js28AutoPropertyDescriptorRooterD1Ev","__ZN2js28AutoPropertyDescriptorRooterD2Ev","__ZN2js28AutoPropertyDescriptorRooterC2EP9JSContext","__ZNK8JSObject18getFunctionPrivateEv","__ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE5beginEv","__ZNK8JSObject8getProtoEv","__ZNK2js10StackFrame4prevEv","_JSVAL_TO_INT32_IMPL","__ZNK2js12StackSegment9maybeRegsEv","__ZNK10JSFunction4kindEv","__ZNK2js10StackFrame22isNonEvalFunctionFrameEv","__ZNK2js10StackFrame10hasCallObjEv","__ZNK8JSString6lengthEv","__ZNK8JSString8isLinearEv","_JSVAL_TO_STRING_IMPL","_JSVAL_IS_STRING_IMPL","__ZNK2js10StackFrame13isGlobalFrameEv","__ZNK2js10StackFrame15isFunctionFrameEv","__ZNK2js10StackFrame12isDummyFrameEv","__ZNK2js10StackFrame16isGeneratorFrameEv","__ZNK2js10StackFrame14isConstructingEv","_INT_TO_JSID","__ZNK2js10StackFrame10hasArgsObjEv","__ZNK8JSObject13numFixedSlotsEv","__ZNK8JSScript10getVersionEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv","__ZN8JSString8asLinearEv","_DOUBLE_TO_JSVAL_IMPL","_JSDOUBLE_IS_NEGZERO","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2JS6AnchorIP8JSStringEC2ES2_","__ZNK2js10StackFrame3funEv","__ZNK2js10StackFrame7argsObjEv","__ZN2js20CallReceiverFromArgvEPN2JS5ValueE","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5frontEv","__ZNK10JSFunction13isInterpretedEv","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEC1ES3_","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEixEj","__ZN2JSL11StringValueEP8JSString","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED2Ev","__ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEC2ES3_","__ZL17DebuggerFrameEvalP9JSContextjPN2JS5ValueE16EvalBindingsMode","__ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb","__ZNK2JS5Value8isStringEv","__ZNK2JS5Value8toStringEv","__ZN8JSString12ensureLinearEP9JSContext","__ZN8JSObject10getGenericEP9JSContextPS_iPN2JS5ValueE","__ZN2JS6AnchorIP8JSStringEC1ES2_","__ZL11IsValidHookRKN2JS5ValueE","__ZNK2js10StackFrame6calleeEv","__ZNK2js10StackFrame7calleevEv","__ZNK2js10StackFrame14mutableCalleevEv","__ZNK2js10StackFrame10formalArgsEv","__ZNK2js10StackFrame13numFormalArgsEv","__ZN2JS5Value9setNumberEd","_JSDOUBLE_IS_INT32","__ZN2JS5Value9setDoubleEd","__ZN2JSL9NullValueEv","__ZNK2js10StackFrame7hasArgsEv","__ZNK2js10StackFrame13numActualArgsEv","__ZL24DebuggerArguments_getArgP9JSContextjPN2JS5ValueE","__ZNK2JS5Value7toInt32Ev","__ZNK2js10StackFrame18canonicalActualArgEj","__ZNK2js10StackFrame9formalArgEj","__ZNK2js10StackFrame10actualArgsEv","__ZNK2js15ArgumentsObject13initialLengthEv","__ZNK8JSObject7getSlotEj","__ZNK2js12ContextStack5hasfpEv","__ZNK10JSFunction12inStrictModeEv","__ZNK2js10StackFrame12callReceiverEv","__ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb","__ZL17GetScriptReferentP8JSObject","__ZL20DebuggerScript_checkP9JSContextRKN2JS5ValueEPKcS6_b","__ZL12ScriptOffsetP9JSContextP8JSScriptRKN2JS5ValueEPj","__ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE3allEv","__ZNK28BytecodeRangeWithLineNumbers15frontLineNumberEv","__ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js13BytecodeRange7frontPCEv","__ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE5beginEv","__ZN2js13FlowsIntoNextE4JSOp","_JSVAL_IS_DOUBLE_IMPL","_JSVAL_IS_NUMBER_IMPL","_JSVAL_TO_PRIVATE_PTR_IMPL","__ZNK2js13BytecodeRange5emptyEv","__ZNK2js13BytecodeRange11frontOffsetEv","__ZNK10JSCodeSpec4typeEv","__ZNK2JS5Value8toDoubleEv","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js13BytecodeRangeC2EP9JSContextP8JSScript","__ZN8JSScript5notesEv","__ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE10initializeEPjS3_","__ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE13copyConstructIjEEvPjPKT_S7_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range8popFrontEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5RangeC1EPNS0_14HashTableEntryIS6_EESH_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5RangeC2EPNS0_14HashTableEntryIS6_EESH_","__ZNK2JS5Value8isNumberEv","__ZNK2JS5Value8toNumberEv","__ZNK2JS5Value8isDoubleEv","__ZL15GetScriptHolderP8JSObject","__ZNK2js8Debugger13observesScopeEP8JSObject","__ZL11ScriptScopeP9JSContextP8JSScriptP8JSObject","__ZN9JSRuntime4new_IN2js10BreakpointEPNS1_8DebuggerEPNS1_14BreakpointSiteEP8JSObjectEEPT_T0_T1_T2_","__ZNK2js10StackFrame11maybeScriptEv","__ZNK2JS5Value9toPrivateEv","__ZN2JS5Value9setNumberEj","__ZN16FlowGraphSummaryC1EP9JSContext","__ZN16FlowGraphSummary8populateEP9JSContextP8JSScript","__ZN28BytecodeRangeWithLineNumbersC1EP9JSContextP8JSScript","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEixEj","__ZN2JSL11NumberValueEd","__ZN28BytecodeRangeWithLineNumbers8popFrontEv","__ZN16FlowGraphSummaryD1Ev","__ZN16FlowGraphSummaryD2Ev","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEED2Ev","__ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js13BytecodeRange8popFrontEv","__ZN28BytecodeRangeWithLineNumbers10updateLineEv","__ZN28BytecodeRangeWithLineNumbersC2EP9JSContextP8JSScript","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE6growByEj","__ZNK2js13BytecodeRange11frontOpcodeEv","__ZN16FlowGraphSummary7addEdgeEjj","__ZL12js_GetOpcodeP9JSContextP8JSScriptPh","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE10growByImplILb1EEEbj","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIjLj0ES1_EEj","__ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE13moveConstructIjEEvPjPKT_S7_","__ZN16FlowGraphSummaryC2EP9JSContext","__ZNK2js12StackSegment4regsEv","__ZL14JSID_FROM_BITSj","__ZNK2js9FrameRegs2fpEv","__ZN8JSScript13isValidOffsetEh","__ZN2js5types10TypeObject11hasAllFlagsEj","__ZNK2JS5ValueeqERKS0_","_JSVAL_IS_NULL_IMPL","_JSVAL_TO_OBJECT_IMPL","_JSVAL_IS_OBJECT_IMPL","_JSVAL_IS_UNDEFINED_IMPL","__ZNK2js5Shape12isEmptyShapeEv","__ZNK2js2gc4Cell7addressEv","__ZN7mozilla14AlignedStorageILj64EE4addrEv","__ZN8JSObject8asGlobalEv","__ZN8JSScript7objectsEv","_PRIVATE_PTR_TO_JSVAL_IMPL","_BOOLEAN_TO_JSVAL_IMPL","__ZN2js16CallArgsFromArgvEjPN2JS5ValueE","_INT32_TO_JSVAL_IMPL","__ZN2js15TempAllocPolicyC2EP9JSContext","__ZN2js10AutoLockGCC2EP9JSRuntime","__ZN2js18RuntimeAllocPolicyC2EP9JSContext","__ZN10JSFunction19setConstructorClassEPN2js5ClassE","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEC2ES1_","__ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej","__ZN2JS5Value10setPrivateEPv","__ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE","__ZN8JSObject23markDenseArrayNotPackedEP9JSContext","__ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj","__ZN2js16AutoObjectVectorD2Ev","__ZN2js16AutoVectorRooterIP8JSObjectED2Ev","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEED2Ev","__ZN2js16AutoObjectVectorC2EP9JSContext","__ZN2js16AutoVectorRooterIP8JSObjectEC2EP9JSContexti","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEEC1ES3_","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEEC2ES3_","__ZNK2js12ContextStack4regsEv","__ZNK2js8Debugger17observesNewScriptEv","__ZN2jsL4FindIN2JS5ValueEEEPT_S4_S4_RKS3_","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE","__ZNK9JSContext5hasfpEv","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE","__ZN2js15AutoValueVectorD2Ev","__ZN2js16AutoVectorRooterIN2JS5ValueEED2Ev","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEED2Ev","__ZNK2js12ContextStack2fpEv","__ZNK2js12StackSegment2fpEv","__ZN2js15AutoValueVectorC2EP9JSContext","__ZN2js16AutoVectorRooterIN2JS5ValueEEC2EP9JSContexti","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEEC1ES3_","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEEC2ES3_","__ZN8JSObject7setSlotEjRKN2JS5ValueE","__ZN8JSObject10getSlotRefEj","__ZN8JSObject14getSlotAddressEj","__ZNK8JSObject11nativeEmptyEv","__ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev","__ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED2Ev","__ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEED2Ev","__ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_ED2Ev","__ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED2Ev","__ZNK2js2gc4Cell11arenaHeaderEv","__Z18js_InitObjectClassP9JSContextP8JSObject","__ZNK2js12GlobalObject32functionObjectClassesInitializedEv","__ZN2js12GlobalObject28initFunctionAndObjectClassesEP9JSContext","__ZNK2js12GlobalObject18getObjectPrototypeEv","__Z20js_InitFunctionClassP9JSContextP8JSObject","__ZNK2js12GlobalObject20getFunctionPrototypeEv","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_123","__ZN8JSObject16setSingletonTypeEP9JSContext","__ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_","__ZN8JSObject7getTypeEP9JSContext","__ZL12ATOM_TO_JSIDP6JSAtom124","__ZL12JSID_TO_ATOMi","__ZN2js12GlobalObject21setObjectClassDetailsEP10JSFunctionP8JSObject","__ZN2js12GlobalObject23setFunctionClassDetailsEP10JSFunctionP8JSObject","__ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE12beginNoCheckEv","_JSVAL_IS_SPECIFIC_BOOLEAN","__ZN2js2gcL15GetGCObjectKindEjb135","__ZL26js_IsPropertyCacheDisabledP9JSContext","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE5clearEv","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE10endNoCheckEv","__ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_","__ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec","__ZN8JSObject15addDataPropertyEP9JSContextijj","__ZN2js12GlobalObject15setOriginalEvalEP8JSObject","__ZL14ThrowTypeErrorP9JSContextjPN2JS5ValueE","__ZN2js12GlobalObject17setThrowTypeErrorEP10JSFunction","__ZN2js12GlobalObject6createEP9JSContextPNS_5ClassE","__ZN8JSObject19syncSpecialEqualityEv","__ZN2jsL24regexp_statics_constructEP9JSContextPNS_12GlobalObjectE","__ZN2JSL11ObjectValueER8JSObject125","__ZN2js12GlobalObject8setFlagsEi","__ZN2js12GlobalObject19initStandardClassesEP9JSContext","__ZN2JSL14UndefinedValueEv126","__ZN2js12GlobalObject5clearEP9JSContext","__ZN8JSObject7unbrandEP9JSContext","__ZN2js13RegExpStatics11extractFromEPNS_12GlobalObjectE","__ZN2js13RegExpStatics5clearEv","__ZN2JSL10Int32ValueEi127","__ZN2js12GlobalObject23isRuntimeCodeGenEnabledEP9JSContext","__ZN2JSL12BooleanValueEb","__ZNK2JS5Value7isFalseEv","__ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj","__ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE","__ZN2jsL16CreateBlankProtoEP9JSContextPNS_5ClassER8JSObjectRNS_12GlobalObjectE","__ZN2js12GlobalObject30createBlankPrototypeInheritingEP9JSContextPNS_5ClassER8JSObject","__ZN8JSObject5brandEP9JSContext","__ZN2js24GlobalDebuggees_finalizeEP9JSContextP8JSObject","__ZN9JSContext7delete_IN2js6VectorIPNS1_8DebuggerELj0ENS1_17SystemAllocPolicyEEEEEvPT_","__ZN2js12GlobalObject12getDebuggersEv","__ZN2js12GlobalObject20getOrCreateDebuggersEP9JSContext","__ZN9JSContext4new_IN2js6VectorIPNS1_8DebuggerELj0ENS1_17SystemAllocPolicyEEEEEPT_v","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEEC1ES3_","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEEC2ES3_","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEED1Ev","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEED2Ev","__ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE136","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE139","__ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE","__ZN2js6detailL9NewObjectILb1ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE","__Z16js_NewGCFunctionP9JSContext","__Z10NewGCThingI10JSFunctionEPT_P9JSContextN2js2gc9AllocKindEj","__ZN2js13RegExpStatics12aboutToWriteEv","__ZN2js13RegExpStatics6copyToERS0_","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE16infallibleAppendIiLj20ES1_EEvRKNS0_IT_XT0_ET1_EE","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE14internalAppendIiLj20ES1_EEvRKNS0_IT_XT0_ET1_EE","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE14internalAppendIiEEvPKT_j","__ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE5beginEv","__ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE6lengthEv","__ZL14JSID_FROM_BITSj151","__ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE5beginEv","__ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE6lengthEv","__ZNK2js12DefnOrHeader4defnEv","__ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE12beginNoCheckEv","__ZN8JSObject7brandedEv","_JSID_TO_STRING150","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E10overloadedEv","__ZN7mozilla14AlignedStorageILj80EE4addrEv","__ZN2js12ParseMapPool9asAtomMapEPv","__ZNK2js12DefnOrHeader8isHeaderEv","__ZNK2js12DefnOrHeader6headerEv","__ZNK7mozilla14AlignedStorageILj128EE4addrEv","__ZN7mozilla14AlignedStorageILj128EE4addrEv","__ZN2js10VectorImplIiLj20ENS_17SystemAllocPolicyELb1EE13copyConstructIiEEvPiPKT_S7_","__ZN8JSObject10setGenericEv","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE3endEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC2ES9_","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE10endNoCheckEv","__ZN2js10VectorImplIPvLj32ENS_17SystemAllocPolicyELb1EE13copyConstructIS1_EEvPS1_PKT_S8_","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE5clearEv","__ZNK2js12GlobalObject16getRegExpStaticsEv","__ZN9JSContext4new_IN2js13RegExpStaticsEEEPT_v","__ZN2js13RegExpStaticsC1Ev","__ZN2js13RegExpStaticsC2Ev","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEEC1ES1_","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEEC2ES1_","__ZN2js12GlobalObject16setDetailsForKeyE10JSProtoKeyP8JSObjectS3_","__ZN2js12ParseMapPool8purgeAllEv","__ZN9JSContext7delete_IN2js9InlineMapIP6JSAtomjLj24EEEEEvPT_","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE12clearAndFreeEv","__ZN2js12ParseMapPool13allocateFreshEv","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE7reserveEj","__ZN9JSContext4new_IN2js9InlineMapIP6JSAtomjLj24EEEPS_EEPT_T0_","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE16infallibleAppendERKS1_","__ZN2js9AtomDecls9allocNodeEP12JSDefinition","__ZN2js12AtomDeclNodeC1EP12JSDefinition","__ZN2js9AtomDecls9addShadowEP6JSAtomP12JSDefinition","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE12lookupForAddERKS2_","__ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrcvPPPPPPPS5_Ev","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3addERNS4_6AddPtrERKS2_RKS3_","__ZN2js12DefnOrHeaderC1EPNS_12AtomDeclNodeE","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtr5valueEv","__ZN2js9AtomDecls10lastAsNodeEPNS_12DefnOrHeaderE","__ZN2js9AtomDecls8addHoistEP6JSAtomP12JSDefinition","__ZN2js9InlineMapIP6JSAtomjLj24EEC1EP9JSContext","__ZN2js9InlineMapIP6JSAtomjLj24EEC2EP9JSContext","__ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_","__ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC1ES9_","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE13growStorageByEj","__ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIPvLj32ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS1_Lj32ES2_EEj","__ZN2js10VectorImplIPvLj32ENS_17SystemAllocPolicyELb1EE13moveConstructIS1_EEvPS1_PKT_S8_","__ZN2js9InlineMapIP6JSAtomjLj24EED1Ev","__ZN2js9InlineMapIP6JSAtomjLj24EED2Ev","__ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev","__ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE12switchAndAddERKS2_RKS3_","__ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E6AddPtrERKS2_RKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrEPPS6_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrE","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE10getKeyHashEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEptEv","__ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEptEv","__ZNK2js7MoveRefIP6JSAtomEcvRS2_Ev","__ZNK2js7MoveRefINS_12DefnOrHeaderEEcvRS1_Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5countEv","__ZNK2js9FrameRegs7inlinedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5hash1Ejj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isFreeEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE10isLiveHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE9matchHashEj","__ZN2js13PointerHasherIP6JSAtomLj2EE5matchERKS2_S5_","__ZN2js13PointerHasherIP6JSAtomLj2EE4hashERKS2_","__ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE8usingMapEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11initializedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE7setLiveEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE14unsetCollisionEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEC2ERS8_","__ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC2ERS5_","__ZN2js7MoveRefINS_12DefnOrHeaderEEC2ERS1_","__ZN2js7MoveRefIP6JSAtomEC2ERS2_","__ZN2js12DefnOrHeaderC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3PtrC2ERNS0_14HashTableEntryIS6_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE12setCollisionEj","__ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S3_EE","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3PtrptEv","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC2EPNS4_10InlineElemEb","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC2ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E6AddPtrE","__ZN2js12DefnOrHeaderC2EPNS_12AtomDeclNodeE","__ZN2js12AtomDeclNodeC2EP12JSDefinition","__ZNK2js10StackFrame10annotationEv","__ZN2js10StackFrame13setAnnotationEPv","__ZN2js10StackFrame22setScopeChainNoCallObjER8JSObject","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E13findFreeEntryEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11createTableERSA_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isLiveEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEaSENS_7MoveRefIS7_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEENS_7MoveRefIT_EERSA_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E12destroyTableERSA_PNS0_14HashTableEntryIS6_EEj","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEC1ERS8_","__ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEaSENS_7MoveRefIS4_EE","__ZN2js4MoveINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEENS_7MoveRefIT_EERS7_","__ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC1ERS5_","__ZN2js4MoveIP6JSAtomEENS_7MoveRefIT_EERKS4_","__ZN2js4MoveINS_12DefnOrHeaderEEENS_7MoveRefIT_EERS3_","__ZN2js7MoveRefINS_12DefnOrHeaderEEC1ERS1_","__ZN2js7MoveRefIP6JSAtomEC1ERS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC2Ev","__ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEC1Ev","__ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEC2Ev","__ZN2js12DefnOrHeaderC1Ev","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE11switchToMapEv","__ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKS3_","__ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11prepareHashERKS4_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6AddPtrC1ERNS0_14HashTableEntryIS6_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6AddPtrC2ERNS0_14HashTableEntryIS6_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5matchERNS0_14HashTableEntryIS6_EERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E10isLiveHashEj","__ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE11initializedEv","__ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv","__ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5countEv","__ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E4initEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5clearEv","__ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3Ptr5foundEv","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC1ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E6AddPtrE","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC1EPNS4_10InlineElemEb","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE14internalAppendIS1_EEvT_","__ZN2js10StackFrame16initExecuteFrameEP8JSScriptPS0_PNS_9FrameRegsERKN2JS5ValueER8JSObjectNS_11ExecuteTypeE","__ZN2JSL9NullValueEv158","__ZN2js10StackFrame14initDummyFrameEP9JSContextR8JSObject","__ZN2jsL7PodZeroINS_10StackFrameEEEvPT_","__ZN2js10StackFrame8initPrevEP9JSContext","__ZN2js10StackFrame18stealFrameAndSlotsEPN2JS5ValueEPS0_S3_S3_","__ZNK2js12StackSegment12prevInMemoryEv","__ZNK9JSRuntime17trustedPrincipalsEv","__ZNK2js12StackSegment13prevInContextEv","__ZNK2js12StackSegment10maybeCallsEv","__ZN2jsL12ToFrameFlagsENS_17InitialFrameFlagsE","__ZNK2js8CallArgs4argcEv","__ZNK8JSObject17isNormalArgumentsEv","__ZN2jsL3MaxIPN2JS5ValueEEET_S4_S4_","__Z16js_IsNamedLambdaP10JSFunction","__ZN2js10StackFrame6prevpcEPPNS_13JSInlinedSiteE","__ZNK2js12StackSegment10slotsBeginEv","__ZNK2js8CallArgs3endEv","__ZN2js12StackSegment8pushRegsERNS_9FrameRegsE","__ZN2js12StackSegment7popRegsEPNS_9FrameRegsE","__ZN2js12StackSegment8pushCallERNS_12CallArgsListE","__ZN2js12StackSegment11pointAtCallERNS_12CallArgsListE","__ZN2js12StackSegment7popCallEv","__ZN2js10StackSpaceC2Ev","__ZNK2js10StackFrame5slotsEv","__ZN2js12ContextStack11threadResetEv","__ZN2js12ImplicitCastINS_8CallArgsENS_15InvokeArgsGuardEEERT_RT0_","__ZN2js15InvokeArgsGuard9setPushedERNS_12ContextStackE","__ZN2js10FrameGuard9setPushedERNS_12ContextStackE","__ZN2jsL7PodCopyIN2JS5ValueEEEvPT_PKS3_j","__ZNK2js10StackFrame7callObjEv","__ZN2js15ArgumentsObject13setStackFrameEPNS_10StackFrameE","__ZN2js10StackFrame11pcQuadraticERKNS_12ContextStackEPS0_PPNS_13JSInlinedSiteE","__ZNK2js10StackSpace17containingSegmentEPKNS_10StackFrameE","__ZNK2js12StackSegment16computeNextFrameEPKNS_10StackFrameE","__ZNK2js12StackSegment8containsEPKNS_10StackFrameE","__ZNK2js12StackSegment7maybefpEv","__ZNK2js12StackSegment8containsEPKNS_12CallArgsListE","__ZNK2js12StackSegment3endEv","__ZN2js10StackSpace4initEv","__ZN2js10StackSpaceD2Ev","__ZN2js10StackSpace4markEP8JSTracer","__ZNK2js10StackSpace11firstUnusedEv","__ZNK2js10StackSpace15ensureSpaceSlowEP9JSContextNS_16MaybeReportErrorEPN2JS5ValueEiP13JSCompartment","__ZNK2js10StackSpace11ensureSpaceEP9JSContextNS_16MaybeReportErrorEPN2JS5ValueEiP13JSCompartment","__ZN2js12ContextStackC2EP9JSContext","__ZNK2js12ContextStack5onTopEv","__ZN2js12ContextStack11ensureOnTopEP9JSContextNS_16MaybeReportErrorEjNS0_11MaybeExtendEPbP13JSCompartment","__ZN2js12StackSegmentC1EPS0_S1_PNS_9FrameRegsEPNS_12CallArgsListE","__ZN2js12ContextStack10popSegmentEv","__ZN9JSContext27maybeMigrateVersionOverrideEv","__ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE","__ZN2js12ContextStack13popInvokeArgsERKNS_15InvokeArgsGuardE","__ZN2js12ContextStack15pushInvokeFrameEP9JSContextRKNS_8CallArgsENS_17InitialFrameFlagsEPNS_16InvokeFrameGuardE","__ZNK2js12ContextStack12getCallFrameEP9JSContextNS_16MaybeReportErrorERKNS_8CallArgsEP10JSFunctionP8JSScriptPNS_10StackFrame5FlagsE","__ZN2js10StackFrame13initCallFrameEP9JSContextR8JSObjectP10JSFunctionP8JSScriptjNS0_5FlagsE","__ZN2js9FrameRegs12prepareToRunERNS_10StackFrameEP8JSScript","__ZNK2js9StackIter2fpEv","__ZN11JSGenerator13floatingFrameEv","__ZNK2js12CallArgsList4prevEv","__ZNK2js9StackIter8isScriptEv","__ZNK2js10StackFrame22isFramePushedByExecuteEv","__ZNK2js12CallArgsList6activeEv","__ZNK2js9StackIter4doneEv","__ZN9JSContext14setCompartmentEP13JSCompartment","__ZN2js10StackFrame22unsetFloatingGeneratorEv","__ZN2js10StackFrame20setFloatingGeneratorEv","__ZN2js9StackIter10poisonRegsEv","__ZNK2js12CallReceiver4baseEv","__ZNK2js12CallReceiver7calleevEv","__ZN2js12ContextStack16pushExecuteFrameEP9JSContextP8JSScriptRKN2JS5ValueER8JSObjectNS_11ExecuteTypeEPNS_10StackFrameEPNS_17ExecuteFrameGuardE","__ZN2js9StackIterppEv","__ZNK2js12ContextStack7maybefpEv","__ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueEj","__ZN2js12ContextStack14pushDummyFrameEP9JSContextP13JSCompartmentR8JSObjectPNS_15DummyFrameGuardE","__ZN2js9FrameRegs14initDummyFrameERNS_10StackFrameE","__ZN2js12ContextStack8popFrameERKNS_10FrameGuardE","__ZN2js10StackFrame16functionEpilogueEv","__ZN2js12ContextStack18pushGeneratorFrameEP9JSContextP11JSGeneratorPNS_19GeneratorFrameGuardE","__ZNK2js10StackFrame8numSlotsEv","__ZN2js10StackFrame18resetGeneratorPrevEP9JSContext","__ZN2js9FrameRegs12rebaseFromToERKS0_RNS_10StackFrameE","__ZN2js12ContextStack17popGeneratorFrameERKNS_19GeneratorFrameGuardE","__ZN2js12ContextStack14saveFrameChainEv","__ZN2js12ContextStack17restoreFrameChainEv","__ZN2js9StackIter8popFrameEv","__ZNK2js10StackFrame13actualArgsEndEv","__ZN2js9StackIter7popCallEv","__ZN2js9StackIter18settleOnNewSegmentEv","__ZN2js9StackIter14startOnSegmentEPNS_12StackSegmentE","__ZN2js9StackIter16settleOnNewStateEv","__ZL12js_GetOpcodeP9JSContextP8JSScriptPh161","__ZNK2js10StackFrame4baseEv","__ZL18CrashIfInvalidSlotPN2js10StackFrameEPN2JS5ValueE","__ZN2jsL16IsNativeFunctionERKN2JS5ValueE","__ZN2js9StackIterC2EP9JSContextNS0_11SavedOptionE","__ZNK8JSScript7nestingEv","__ZNK17JSDependentString4baseEv","__ZNK7mozilla9RangedPtrIKtEdeEv","__ZNK9JSContext19isVersionOverriddenEv","__ZNK8JSObject6isCallEv","__ZNK8JSString12isExtensibleEv","__ZNK8JSString6isRopeEv","__ZN8JSString19buildLengthAndFlagsEjj","__ZN13JSShortString10lengthFitsEj","__ZNK7mozilla9RangedPtrIKtEeqIS1_EEbRKNS0_IT_EE","__ZNK8JSString12asExtensibleEv","__ZN8JSString7asFixedEv","__ZNK8JSString6asAtomEv","__ZNK2js9StackIter10nativeArgsEv","__ZN9JSContext20clearVersionOverrideEv","__ZN2js12StackSegmentC2EPS0_S1_PNS_9FrameRegsEPNS_12CallArgsListE","__ZNK18JSExtensibleString8capacityEv","__ZNK6JSRope9leftChildEv","__ZN2js13StaticStrings15fitsInSmallCharEt","__ZN7mozilla9RangedPtrIKtEaSIS1_EERS2_RKNS0_IT_EE","__ZN7mozilla9RangedPtrIKtEC2EPS1_S3_j","__ZN7mozilla9RangedPtrIKtEC2EPS1_j","__ZN2js19PreserveCompartmentD2Ev","__ZN2js13AllFramesIterC2ERNS_10StackSpaceE","__ZN2js13AllFramesIterppEv","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP10JSFunction","__ZNK10JSFunction8isNativeEv","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject","__ZNK2js10StackFrame20maintainNestingStateEv","__ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueES2_","__ZNK9JSContext9maybeRegsEv","__ZNK2js12ContextStack9maybeRegsEv","__ZNK2js2gc4Cell12getAllocKindEv","__ZN14JSLinearString4markEP8JSTracer","__ZNK2js2gc4Cell14markIfUnmarkedEj","__ZN6JSRope7flattenEP9JSContext","__ZL10AllocCharsP9JSContextjPPtPj","__ZN2jsL7PodCopyItEEvPT_PKS1_j","__Z16js_ConcatStringsP9JSContextP8JSStringS2_","__Z19js_NewGCShortStringP9JSContext","__ZN8JSString8getCharsEP9JSContext","__ZN14JSInlineString4initEj","__ZN6JSRope4new_EP9JSContextP8JSStringS3_j","__ZN17JSDependentString8undependEP9JSContext","__ZNK12JSFlatString6charsZEv","__ZN7mozilla9RangedPtrIKtEC1EPS1_j","__ZN7mozilla9RangedPtrIKtEC1EPS1_S3_j","__ZN7mozilla9RangedPtrIKtEppEi","__ZN2js13StaticStrings4initEP9JSContext","__ZN2js19SwitchToCompartmentC1EP9JSContextP13JSCompartment","__ZN13JSFixedString27morphAtomizedStringIntoAtomEv","__ZN2js19SwitchToCompartmentD1Ev","__ZN2js13StaticStrings5traceEP8JSTracer","__ZN7mozilla9RangedPtrIKtEppEv","__ZN7mozilla9RangedPtrIKtEpLEj","__ZN7mozilla9RangedPtrIKtEplEj","__ZNK7mozilla9RangedPtrIKtE6createEPS1_","__ZN2js19SwitchToCompartmentD2Ev","__ZNK2v88internal5DiyFp1fEv","__ZNK2v88internal5DiyFp1eEv","__ZNK2js2gc4Cell5chunkEv","__ZNK2v88internal13StringBuilder12is_finalizedEv","__ZN2v88internalL15BiggestPowerTenEjiPjPi","__ZN2js19PreserveCompartmentC2EP9JSContext","__ZNK2js2gc11ArenaHeader12getAllocKindEv","__ZN2v88internal6VectorIcEC2EPci","__ZNK2v88internal6VectorIcEixEi","__ZN2v88internal5DiyFp8MultiplyERKS1_","__ZN2v88internal5DiyFp5set_fEy","__ZN2v88internal5DiyFp5set_eEi","__ZN2v88internal5DiyFp9NormalizeEv","__ZN2js19SwitchToCompartmentC2EP9JSContextP13JSCompartment","_js_malloc181","__Z14js_NewGCStringP9JSContext","__ZN6JSRope4initEP8JSStringS1_j","__Z10NewGCThingI8JSStringEPT_P9JSContextN2js2gc9AllocKindEj","__Z10NewGCThingI13JSShortStringEPT_P9JSContextN2js2gc9AllocKindEj","__ZN2js11OffTheBooks7malloc_Ej","__ZN2js2gc11ChunkBitmap14markIfUnmarkedEPKNS0_4CellEj","__ZN2js2gc11ChunkBitmap18getMarkWordAndMaskEPKNS0_4CellEjPPjS5_","__ZN2v88internal15DoubleToCStringEdPci","__ZN2v88internal13StringBuilderC1EPci","__ZN2v88internal13StringBuilder12AddCharacterEc","__ZN2v88internal6VectorIcEC1EPci","__ZN2v88internal13StringBuilderD1Ev","__ZN2v88internal13StringBuilderD2Ev","__ZN2v88internal13StringBuilderC2EPci","__ZN2v88internal9RoundWeedENS0_6VectorIcEEiyyyyy","__ZN2v88internal8DigitGenENS0_5DiyFpES1_S1_NS0_6VectorIcEEPiS4_","__ZN2v88internal5DiyFpC1Eyi","__ZN2v88internal5DiyFp5MinusERKS1_S3_","__ZN2v88internal6grisu3EdNS0_6VectorIcEEPiS3_","__ZN2v88internal6DoubleC1Ed","__ZNK2v88internal6Double17AsNormalizedDiyFpEv","__ZN2v88internal5DiyFpC1Ev","__ZNK2v88internal6Double20NormalizedBoundariesEPNS0_5DiyFpES3_","__ZN2v88internalL14GetCachedPowerEiiiPiPNS0_5DiyFpE","__ZN2v88internal5DiyFp5TimesERKS1_S3_","__ZN2v88internal8FastDtoaEdNS0_6VectorIcEEPiS3_","__ZNK2v88internal6Double7AsDiyFpEv","__ZN2v88internal5DiyFp9NormalizeERKS1_","__ZNK2v88internal6Double11SignificandEv","__ZNK2v88internal6Double8AsUint64Ev","__ZN2js7analyzeL7ArgSlotEj","__ZN2v88internal5DiyFpC2Ev","__ZN2v88internal7BitCastIydEET_RKT0_","__ZN2v88internal5DiyFp8SubtractERKS1_","__ZN2v88internal5DiyFpC2Eyi","__ZN8JSScript7getAtomEj","__ZNK2v88internal6Double8ExponentEv","__ZNK2v88internal6Double10IsDenormalEv","__ZN2v88internal6DoubleC2Ed","__ZN2v88internalL16double_to_uint64Ed","__ZN2js15TempAllocPolicy13onOutOfMemoryEPvj","__ZNK2js15TempAllocPolicy19reportAllocOverflowEv","__ZN2js7analyze8Bytecode12mergeDefinesEP9JSContextPNS0_14ScriptAnalysisEbjPjj","__ZN2js10ArenaArrayIjEEPT_R11JSArenaPoolj","__ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext","__ZN2js7analyze14ScriptAnalysis16checkAliasedNameEP9JSContextPh","__ZN8JSScript11getFunctionEj","__ZN2js7analyzeL9LocalSlotEP8JSScriptj","__ZN2js7analyze14ScriptAnalysis15analyzeBytecodeEP9JSContext","__ZNK8JSScript8functionEv","__ZN2js7analyzeL21BytecodeNoFallThroughE4JSOp","__ZNK10JSFunction13isHeavyweightEv","__ZN2js5types10TypeScript9typeArrayEv","__ZN8JSScript12getClosedArgEj","__ZN2js7analyze14ScriptAnalysis8setLocalEjj","__ZN8JSScript12getClosedVarEj","__ZN2js7analyze14ScriptAnalysis9maybeCodeEj","__ZN2js7analyzeL13GetJumpOffsetEPhS1_","__ZN2js7analyze14ScriptAnalysis7getCodeEj","__ZN8JSScript8trynotesEv","__ZN2js7analyzeL10TotalSlotsEP8JSScript","__ZN2js10ArenaArrayIPNS_7analyze8BytecodeEEEPT_R11JSArenaPoolj","__ZN2js10ArenaArrayIhEEPT_R11JSArenaPoolj","__ZN2jsL7PodZeroIPNS_7analyze8BytecodeEEEvPT_j","__ZN2jsL7PodZeroIhEEvPT_j","__ZN2js8ArenaNewINS_7analyze8BytecodeEEEPT_R11JSArenaPool","__ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh","__ZN2js7analyzeL17GetBytecodeLengthEPh","__ZN2js7analyzeL11GetUseCountEP8JSScriptj","__ZN2js7analyzeL11GetDefCountEP8JSScriptj","__ZN2js7analyze14ScriptAnalysis7addJumpEP9JSContextjPjS4_jS4_j","__ZN2js7analyze14ScriptAnalysis10jumpTargetEPKh","__ZN2js7analyze14ScriptAnalysis12localDefinedEjj","__ZN2js7analyze12UntrapOpcodeD1Ev","__ZN2js7analyze14ScriptAnalysis11ranBytecodeEv","__ZN2js7analyze14ScriptAnalysis6failedEv","__ZN2js7analyze14ScriptAnalysis14ensureVariableERNS0_16LifetimeVariableEj","__ZN2js7analyze14ScriptAnalysis11slotEscapesEj","__ZN2js7analyze14ScriptAnalysis16analyzeLifetimesEP9JSContext","__ZN2js10ArenaArrayINS_7analyze16LifetimeVariableEEEPT_R11JSArenaPoolj","__ZN2jsL7PodZeroINS_7analyze16LifetimeVariableEEEvPT_j","__ZN2js7analyze14ScriptAnalysis14extendVariableEP9JSContextRNS0_16LifetimeVariableEjj","__ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh","__ZN2js7analyze14ScriptAnalysis11addVariableEP9JSContextRNS0_16LifetimeVariableEjRPPS4_Rj","__ZNK2js7analyze16LifetimeVariable4liveEj","__ZN2js7analyze14ScriptAnalysis12killVariableEP9JSContextRNS0_16LifetimeVariableEjRPPS4_Rj","__ZN2js8ArenaNewINS_7analyze8LifetimeEjjPS2_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_","__ZN2js7analyzeL12FollowBranchEP9JSContextP8JSScriptj","__ZN2js8ArenaNewINS_7analyze12LoopAnalysisEEEPT_R11JSArenaPool","__ZN2jsL7PodZeroINS_7analyze12LoopAnalysisEEEvPT_","__ZN2js7analyze14ScriptAnalysis12ranLifetimesEv","__ZN2js7analyze14ScriptAnalysis10analyzeSSAEP9JSContext","__ZN2js7analyze14ScriptAnalysis9trackSlotEj","__ZN2js7analyze8SSAValue11initInitialEj","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEC1ES1_","__ZN2js7analyze14ScriptAnalysis9maybeCodeEPKh","__ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6lengthEv","__ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE6lengthEv","__ZN2js7analyzeL11ExtendedDefEPh","__ZNK2js7analyze8SSAValue4kindEv","__ZNK2js7analyze8SSAValue9phiOffsetEv","__ZN2js7analyze14ScriptAnalysis8livenessEj","__ZNK2js7analyze8SSAValue7phiNodeEv","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE7popBackEv","__ZN2jsL7PodZeroINS_7analyze8SSAValueEEEvPT_j","__ZN2js7analyze14ScriptAnalysis18removeBranchTargetERNS_6VectorIjLj0ENS_15TempAllocPolicyEEEj","__ZN9JSContext4new_IN2js6VectorINS1_7analyze9SlotValueELj0ENS1_15TempAllocPolicyEEEPS_EEPT_T0_","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEixEj","__ZNK2js7analyze16LifetimeVariable10firstWriteEPNS0_12LoopAnalysisE","__ZN2js7analyze14ScriptAnalysis7makePhiEP9JSContextjjPNS0_8SSAValueE","__ZN2js7analyze14ScriptAnalysis9insertPhiEP9JSContextRNS0_8SSAValueERKS4_","__ZN2js7analyze14ScriptAnalysis10mergeValueEP9JSContextjRKNS0_8SSAValueEPNS0_9SlotValueE","__ZN2js7analyze14ScriptAnalysis17mergeBranchTargetEP9JSContextRKNS0_8SSAValueEjRKNS_6VectorIjLj0ENS_15TempAllocPolicyEEE","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_","__ZN2js7analyze9SlotValueC1EjRKNS0_8SSAValueE","__ZN2js7analyze14ScriptAnalysis15freezeNewValuesEP9JSContextj","__ZN2js7analyzeL11ExtendedUseEPh","__ZN2js10ArenaArrayINS_7analyze8SSAValueEEEPT_R11JSArenaPoolj","__ZN2js7analyze8SSAValue5clearEv","__ZN2js10ArenaArrayINS_7analyze11SSAUseChainEEEPT_R11JSArenaPoolj","__ZN2jsL7PodZeroINS_7analyze11SSAUseChainEEEvPT_j","__ZN2js7analyze14ScriptAnalysis13trackUseChainERKNS0_8SSAValueE","__ZN2js7analyze14ScriptAnalysis8useChainERKNS0_8SSAValueE","__ZN2js7analyze8SSAValue10initPushedEjj","__ZN2js10ArenaArrayIPNS_7analyze11SSAUseChainEEEPT_R11JSArenaPoolj","__ZN2jsL7PodZeroIPNS_7analyze11SSAUseChainEEEvPT_j","__ZN2js7analyze8SSAValue11initWrittenEjj","__ZN2js7analyze14ScriptAnalysis17checkBranchTargetEP9JSContextjRNS_6VectorIjLj0ENS_15TempAllocPolicyEEEPNS0_8SSAValueEj","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEED1Ev","__ZN2js8ArenaNewINS_7analyze10SSAPhiNodeEEEPT_R11JSArenaPool","__ZN2js7analyzeL15PhiNodeCapacityEj","__ZN2js7analyze8SSAValue7initPhiEjPNS0_10SSAPhiNodeE","__ZNK2js7analyze8SSAValue6equalsERKS1_","__ZN2js8ArenaNewINS_7analyze11SSAUseChainEEEPT_R11JSArenaPool","__ZN2jsL7PodCopyINS_7analyze8SSAValueEEEvPT_PKS3_j","__ZN2js7analyze14ScriptAnalysis17checkPendingValueEP9JSContextRKNS0_8SSAValueEjPNS_6VectorINS0_9SlotValueELj0ENS_15TempAllocPolicyEEE","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE6appendIjEEbT_","__ZN2js7analyzeL9StackSlotEP8JSScriptj","__ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEEixEj","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE4backEv","__ZN9JSContext7delete_IN2js6VectorINS1_7analyze9SlotValueELj0ENS1_15TempAllocPolicyEEEEEvPT_","__ZN8JSScript8analysisEv","__ZNK2js7analyze8SSAValue11pushedIndexEv","__ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js7MoveRefINS_7analyze9SlotValueEEcvRS2_Ev","__ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE5beginEv","__ZNK2js7analyze8SSAValue9varOffsetEv","__ZNK2js7analyze8SSAValue10varInitialEv","__ZNK2js7analyze8SSAValue7varSlotEv","__ZNK2js7analyze8SSAValue12pushedOffsetEv","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE3endEv","__ZN2js5types7TypeSetC2Ev","__ZN2js7MoveRefINS_7analyze9SlotValueEEC2ERS2_","__ZN2js7analyze8LifetimeC2EjjPS1_","__ZN2jsL7PodZeroINS_7analyze8SSAValueEEEvPT_","__ZN2js7analyze9SlotValueC2EjRKNS0_8SSAValueE","__ZNK2js7analyze16LifetimeVariable10firstWriteEjj","__ZZN2js7analyze14ScriptAnalysis10analyzeSSAEP9JSContextEN13FreeSSAValuesC2ES3_PNS0_8SSAValueE","__ZN2js7analyze12UntrapOpcode6retrapEv","__ZN2js7analyze8Bytecode9isDefinedEj","__ZN2js7analyze14ScriptAnalysis10jumpTargetEj","__ZL13IMPL_TO_JSVAL12jsval_layout","_BUILD_JSVAL225","__ZN2js10ArenaArrayINS_7analyze9SlotValueEEEPT_R11JSArenaPoolj","__ZN2js7analyze14ScriptAnalysis11poppedValueEPKhj","__ZN2js7analyze14ScriptAnalysis13getValueTypesERKNS0_8SSAValueE","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEED2Ev","__ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE14internalAppendIjEEvT_","__ZN2js7analyze11SSAUseChainC1Ev","__ZN2js7analyze11SSAUseChainC2Ev","__ZN2jsL7PodZeroINS_7analyze11SSAUseChainEEEvPT_","__ZN2js7analyze10SSAPhiNodeC1Ev","__ZN2js7analyze10SSAPhiNodeC2Ev","__ZN2js5types7TypeSetC1Ev","__ZN2jsL7PodZeroINS_7analyze10SSAPhiNodeEEEvPT_","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj0ES3_EEj","__ZN2js4MoveINS_7analyze9SlotValueEEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefINS_7analyze9SlotValueEEC1ERS2_","__ZN2js10VectorImplINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js4MoveINS_7analyze9SlotValueEEENS_7MoveRefIT_EERKS4_","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEC1ES3_","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEC2ES3_","__ZN2js7analyze8LifetimeC1EjjPS1_","__ZN2js7analyze8BytecodeC1Ev","__ZN2js7analyze8BytecodeC2Ev","__ZN2jsL7PodZeroINS_7analyze8BytecodeEEEvPT_","__ZN2js7analyze14ScriptAnalysis11pushedTypesEjj","__ZN2js5types10TypeScript9SlotTypesEP8JSScriptj","__ZN2js7analyze14ScriptAnalysis11poppedValueEjj","__ZZN2js7analyze14ScriptAnalysis10analyzeSSAEP9JSContextEN13FreeSSAValuesD2Ev","__ZN2js8ArenaNewINS_7analyze8LifetimeEjiPS2_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_","__ZN2js7analyze12UntrapOpcodeD2Ev","__ZN2js7analyze14ScriptAnalysis20localHasUseBeforeDefEj","__Z28js_GetVariableBytecodeLengthPh","__ZN2js7analyze12UntrapOpcodeC2EP9JSContextP8JSScriptPh","__ZN8JSScript9getObjectEj","___cxx_global_var_init","___cxx_global_var_init1","___cxx_global_var_init2","___cxx_global_var_init3","___cxx_global_var_init4","___cxx_global_var_init5","_JS_Now","_JS_GetEmptyStringValue","_STRING_TO_JSVAL","_JS_ConvertArguments","__ZNK2js15AutoValueRooter5valueEv","_JS_GetTypeName","_JS_ConvertArgumentsVA","__ZN12JSValueArrayC1EPN2JS5ValueEj","__ZN16JSAutoByteStringC1Ev","__ZN2js20GetFunctionNameBytesEP9JSContextP10JSFunctionP16JSAutoByteString","_JS_ReportErrorNumber","__ZN16JSAutoByteStringD1Ev","_JS_ValueToUint16","_JS_ValueToECMAInt32","_JS_ValueToECMAUint32","_JS_ValueToInt32","_JS_ValueToNumber","__ZL18js_DoubleToIntegerd","__ZN8JSString11ensureFixedEP9JSContext","_OBJECT_TO_JSVAL","__ZL20TryArgumentFormatterP9JSContextPPKciPPN2JS5ValueEPPc","_JS_ConvertValue","_DOUBLE_TO_JSVAL","_BOOLEAN_TO_JSVAL","_JS_ValueToObject","_JS_ValueToFunction","_JS_ValueToString","_JS_ValueToSource","__ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE","__ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd","__ZN2js15AutoValueRooterD1Ev","__ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi","__ZN2js17ValueToECMAUint32EP9JSContextRKN2JS5ValueEPj","__ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi","__ZN2js13ValueToUint16EP9JSContextRKN2JS5ValueEPt","_JS_ValueToBoolean","_JS_TypeOfValue","_JS_SameValue","__ZN9JSRuntimeC2Ev","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEEC1ES3_","__ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEEC1ES5_","__ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC1ES5_","__ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEEC1ES3_","__ZN11JSAtomStateC1Ev","__ZN2js13StaticStringsC1Ev","__ZN9JSRuntime4initEj","__ZN9JSRuntime4new_I13JSCompartmentPS_EEPT_T0_","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6appendIS2_EEbT_","__ZN2js10Foreground7delete_I13JSCompartmentEEvPT_","__ZN9JSRuntimeD2Ev","__ZN11JSAtomStateD1Ev","__ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEED1Ev","_JS_GetContextPrivate","_JS_GetRuntime","_JS_PropertyStub","_JS_StrictPropertyStub","_JS_EnumerateStub","_JS_ResolveStub","_JS_GetGlobalObject","_JS_FinalizeStub","__ZN2jsL13VersionNumberE9JSVersion","_JSID_TO_STRING243","_JS_CANONICALIZE_NAN","__ZN2js8ValueifyEP12JSStackFrame","__ZN2jsL8ValueifyEP7JSClass","_JS_SetContextPrivate","__ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv","_JS_SetNativeStackQuota","__ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED1Ev","__ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEED1Ev","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEED1Ev","_JS_Init","__ZN2js11OffTheBooks7calloc_Ej","_JS_Finish","__ZN2js10Foreground7delete_I9JSRuntimeEEvPT_","_JS_NewContext","_JS_DestroyContext","_JS_DestroyContextNoGC","_JS_GetVersion","_JS_SetVersion","__ZN2jsL16VersionCopyFlagsEP9JSVersionS0_","__ZN9JSContext20maybeOverrideVersionE9JSVersion","_JS_GetOptions","__ZNK9JSContext10allOptionsEv","_JS_SetOptions","__ZL16SetOptionsCommonP9JSContextj","_JS_ToggleOptions","_JS_EnterCrossCompartmentCall","__ZN9JSContext4new_IN2js15AutoCompartmentEPS_P8JSObjectEEPT_T0_T1_","__ZN2js10Foreground7delete_INS_15AutoCompartmentEEEvPT_","_JS_ConvertStub","_JS_NewGlobalObject","_JS_LeaveCrossCompartmentCall","__ZN22JSAutoEnterCompartment5enterEP9JSContextP8JSObject","__ZNK8JSObject14getCompartmentEv","_JS_WrapObject","__ZN2JSL11ObjectValueER8JSObject239","__ZNK2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE6lookupERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv","__ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj","__ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_","__ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3putERKS2_S7_","_JS_SetGlobalObject","_JS_InitStandardClasses","_JS_ResolveStandardClass","__ZL12JSID_IS_ATOMi242","__ZL12ATOM_TO_JSIDP6JSAtom244","__ZN2JSL14UndefinedValueEv245","__ZL13StdNameToAtomP9JSContextP9JSStdName","_JS_EnumerateStandardClasses","__ZN8JSObject14nativeContainsEP9JSContexti","_JS_GetGlobalForScopeChain","__ZN2jsL22GetGlobalForScopeChainEP9JSContext","_JS_ComputeThis","__ZN2js18CallReceiverFromVpEPN2JS5ValueE","_JS_malloc","_JS_realloc","__ZN9JSContext8realloc_EPvj","_JS_free","_JS_strdup","_JS_NewNumberValue","_JS_AddValueRoot","_JS_AddNamedStringRoot","_JS_RemoveValueRoot","_JS_RemoveStringRoot","_JS_ReportOutOfMemory","_JS_TraceRuntime","_JS_CallTracer","_JS_CompartmentGC","_JS_MaybeGC","_JS_SetGCParameter","__ZN9JSRuntime19setGCMaxMallocBytesEj","_JS_GetGCParameter","__ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE5countEv","_JS_DestroyIdArray","_JS_InitClass","_JS_GetClass","__ZNK8JSObject10getJSClassEv","__ZNK8JSObject8slotSpanEv","__ZNK8JSObject9isNewbornEv","_INT_TO_JSID250","_JS_InstanceOf","_JS_HasInstance","_JS_GetPrivate","_JS_SetPrivate","_JS_GetInstancePrivate","_JS_GetParent","_JS_GetConstructor","__ZN18JSAutoResolveFlagsC1EP9JSContextj","__ZN18JSAutoResolveFlagsD1Ev","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject246","_JS_NewCompartmentAndGlobalObject","__ZN19AutoHoldCompartmentC1EP13JSCompartment","__ZN19AutoHoldCompartmentD1Ev","_JS_NewObject","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_","__ZN2js5types31MarkTypeObjectUnknownPropertiesEP9JSContextPNS0_10TypeObjectEb","_JS_NewObjectWithGivenProto","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_247","_JS_NewObjectForConstructor","_JSVAL_TO_OBJECT","_JS_FreezeObject","__ZNK2JS5Value11isPrimitiveEv","__ZL18LookupPropertyByIdP9JSContextP8JSObjectijPS2_PP10JSProperty","__ZN2js9IndexToIdEP9JSContextjPi","__ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty","_JS_HasPropertyById","_JS_DefinePropertyById","__ZL18DefinePropertyByIdP9JSContextP8JSObjectiRKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ejji","_JS_DefineElement","_JS_DefineProperty","__ZL14DefinePropertyP9JSContextP8JSObjectPKcRKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ejji","_JS_DefineObject","__ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_","_JS_DefineConstDoubles","__ZN2JSL11DoubleValueEd","_JS_DefineProperties","_JS_GetPropertyDescriptorById","__ZL25GetPropertyDescriptorByIdP9JSContextP8JSObjectijiP20JSPropertyDescriptor","_JS_GetPropertyById","_JS_GetProperty","_JS_SetPropertyById","__ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi","_JS_SetElement","_JS_SetProperty","_JS_DeletePropertyById2","_JS_ClearScope","__ZNK8JSObject8isGlobalEv","_JS_Enumerate","__ZL18prop_iter_finalizeP9JSContextP8JSObject","__ZL15prop_iter_traceP8JSTracerP8JSObject","_JS_GetRuntimeSecurityCallbacks","__ZNK2js5Shape5Range5frontEv","__ZNK16JSAutoByteString3ptrEv","__ZNK2js5Shape10enumerableEv","__ZNK2js11UpvarCookie5levelEv","__ZN2js11TokenStream15isUnexpectedEOFEv","_JS_SetRuntimeSecurityCallbacks","_JS_GetSecurityCallbacks","__ZN9JSRuntime20setTrustedPrincipalsEP12JSPrincipals","__ZN8JSScript6upvarsEv","__ZN2js5Shape5Range8popFrontEv","_JS_GetFunctionObject","_JS_GetFunctionId","_JS_SetErrorReporter","_JS_SetOperationCallback","_JS_NewPropertyIterator","__ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject","__ZN2js16AutoObjectRooterD1Ev","__ZN2JSL10Int32ValueEi251","_JS_NextProperty","_JS_GetReservedSlot","_JS_SetReservedSlot","_JS_NewArrayObject","_JS_IsArrayObject","__ZNK8JSObject7isArrayEv","_JS_SetTrustedPrincipals","_JS_NewFunction","_JS_CloneFunctionObject","__Z19CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectb","__ZNK10JSFunction13isFlatClosureEv","__ZN2js5Shape5RangeC1EPKS0_","__ZNK8JSObject20getFlatClosureUpvarsEv","_JS_DefineFunctions","__ZL35js_generic_native_method_dispatcherP9JSContextjPN2JS5ValueE","__ZN2JSL12PrivateValueEPv257","_JS_DefineFunction","__ZL34CompileUCScriptForPrincipalsCommonP9JSContextP8JSObjectP12JSPrincipalsPKtjPKcj9JSVersion","_JS_CompileUCScriptForPrincipals","_JS_CompileUCScript","_JS_BufferIsCompilableUnit","_JS_SaveExceptionState","_JS_RestoreExceptionState","_JS_CompileFile","__ZN18AutoLastFrameCheckC1EP9JSContext","__ZL17CompileFileHelperP9JSContextP8JSObjectP12JSPrincipalsPKcP7__sFILE","__ZN18AutoLastFrameCheckD1Ev","_JS_CompileFileHandleForPrincipals","_JS_CompileFileHandle","_JS_DecompileFunction","_JS_ExecuteScript","__Z35EvaluateUCScriptForPrincipalsCommonP9JSContextP8JSObjectP12JSPrincipalsPKtjPKcjPN2JS5ValueE9JSVersion","_JS_EvaluateUCScriptForPrincipals","_JS_EvaluateUCScript","_JS_EvaluateScriptForPrincipals","_JS_EvaluateScript","__ZN2js15InvokeArgsGuardC1Ev","__ZN2js17InvokeConstructorEP9JSContextRNS_15InvokeArgsGuardE","__ZN2js15InvokeArgsGuardD1Ev","_JS_TriggerAllOperationCallbacks","_JS_SetCStringsAreUTF8","__ZNK2js6RegExp9getSourceEv","__ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5countEv","__ZNK8JSString6isAtomEv","_JS_CStringsAreUTF8","__ZNK8JSObject6isDateEv","__ZNK8JSObject8isRegExpEv","__ZN2jsL16GetClassProtoKeyEPNS_5ClassE","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10overloadedEv","__ZNK2js6RegExp8getFlagsEv","__ZN2js2gcL15GetGCObjectKindEjb264","__ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrdeEv","_JS_IsRunning","__ZNK9JSContext7maybefpEv","_JS_SaveFrameChain","_JS_RestoreFrameChain","_JS_NewStringCopyN","_JS_NewStringCopyZ","_JS_InternString","_JS_NewUCString","_JS_NewUCStringCopyN","_JS_InternUCStringN","_JS_GetStringLength","_JS_GetStringCharsZ","_JS_GetStringCharsAndLength","_JS_FlattenString","_JS_StringEqualsAscii","_JS_FlatStringEqualsAscii","_JS_FileEscapedString","__ZN2js17FileEscapedStringEP7__sFILEP14JSLinearStringj","_JS_EncodeCharacters","_JS_DecodeBytes","_JS_DecodeUTF8","_JS_EncodeString","__ZN2js12StringBufferC1EP9JSContext","__ZNK2js12StringBuffer5emptyEv","__ZN2js12StringBuffer5beginEv","__ZNK2js12StringBuffer6lengthEv","__ZN2js12StringBufferD1Ev","__ZN2JSL9NullValueEv259","_JS_ReadStructuredClone","_JS_WriteStructuredClone","_JS_ReportError","_JS_ReportWarning","_JS_ReportErrorFlagsAndNumber","_JS_ReportErrorFlagsAndNumberUC","__ZN2js6RegExp12createObjectEP9JSContextPNS_13RegExpStaticsEPKtjjPNS_11TokenStreamE","__ZN2js6RegExp11extractFromEP8JSObject","__ZN2js6RegExp7executeEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE","__ZN2js6RegExp21createObjectNoStaticsEP9JSContextPKtjjPNS_11TokenStreamE","_JS_IsExceptionPending","_JS_GetPendingException","_JS_SetPendingException","_JS_ClearPendingException","_JS_ReportPendingException","_JSVAL_IS_GCTHING","_JS_DropExceptionState","__ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE","__ZN2js6detailL9NewObjectILb0ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE","__ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE","__ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE267","__ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE271","__ZNK2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE12lookupForAddERKS2_","__ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S2_EENS5_13MapHashPolicyES4_E6AddPtrERKS2_SF_","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrEPPS5_","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE10getKeyHashEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEptEv","__ZNK2js7MoveRefINS_12HashMapEntryIN2JS5ValueES3_EEEptEv","__ZNK2JS5Value9asRawBitsEv","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr7nonNullEv","__ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE12beginNoCheckEv","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isFreeEv","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE10isLiveHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE9matchHashEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE12hasCollisionEv","_JSVAL_IS_GCTHING_IMPL","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE7setLiveEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE14unsetCollisionEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEC2ERS7_","__ZN2js7MoveRefINS_12HashMapEntryIN2JS5ValueES3_EEEC2ERS4_","__ZN2js12HashMapEntryIN2JS5ValueES2_EC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE12setCollisionEj","__ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S2_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11underloadedEv","__ZN2js12HashMapEntryIN2JS5ValueES2_EaSERKS3_","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE10endNoCheckEv","__ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_EC2ES7_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_","__ZL13JSVAL_TO_IMPLN2JS5ValueE","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isLiveEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEEaSENS_7MoveRefIS6_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEENS_7MoveRefIT_EERS9_","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj","_js_free272","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEC1ERS7_","__ZN2js12HashMapEntryIN2JS5ValueES2_EaSENS_7MoveRefIS3_EE","__ZN2js4MoveINS_12HashMapEntryIN2JS5ValueES3_EEEENS_7MoveRefIT_EERS6_","__ZN2js7MoveRefINS_12HashMapEntryIN2JS5ValueES3_EEEC1ERS4_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEEC2Ev","__ZN2js12HashMapEntryIN2JS5ValueES2_EC1Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKS4_","__ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS5_EERKS4_","__ZN2js13WrapperHasher5matchERKN2JS5ValueES4_","__ZN2js13WrapperHasher4hashEN2JS5ValueE","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10isLiveHashEj","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE16infallibleAppendERKS2_","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE7reserveEj","__ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr5foundEv","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6removeERNS0_14HashTableEntryIS5_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16checkUnderloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE7setFreeEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC1ERNS0_14HashTableEntryIS5_EE","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE13growStorageByEj","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_","__ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj","_js_realloc274","__ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEED2Ev","__ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEEC2ES3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_EC1ES7_","__ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_","__ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEEC2ES3_","__ZN2js6RegExp15executeInternalEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE","__ZN2js6RegExp9initArenaEP9JSContext","__ZN2js18AutoArenaAllocatorC1EP11JSArenaPool","__ZNK2js15AlreadyIncRefedINS_6RegExpEE3getEv","__ZNK2js15AlreadyIncRefedINS_6RegExpEEptEv","__ZNK2js6RegExp6stickyEv","__ZNK2js6RegExp6globalEv","__ZNK2js6RegExp10ignoreCaseEv","__ZNK2js6RegExp9multilineEv","__ZNK7mozilla14AlignedStorageILj80EE4addrEv","__ZNK2js15AlreadyIncRefedINS_6RegExpEEcvPPPPPS1_Ev","_STRING_TO_JSVAL_IMPL277","__ZN2js18RegExpMatchBuilderC2EP9JSContextP8JSObject","_BOOLEAN_TO_JSVAL_IMPL278","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE8shrinkByEj","__ZN2js18AutoArenaAllocatorC2EP11JSArenaPool","__ZN8JSObject15setLastPropertyEPKN2js5ShapeE","__ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10endNoCheckEv","__ZN2js18AutoArenaAllocator5allocIiEEPT_j","__ZN2js13RegExpStatics15updateFromMatchEP9JSContextP14JSLinearStringPij","__ZN2JSL12BooleanValueEb275","__ZN2js6RegExp12createResultEP9JSContextP8JSStringPij","__ZN2js18AutoArenaAllocatorD1Ev","__ZN2js18AutoArenaAllocatorD2Ev","__ZN2js18RegExpMatchBuilderC1EP9JSContextP8JSObject","__ZN2js18RegExpMatchBuilder6appendEjN2JS5ValueE","__ZN2JSL11StringValueEP8JSString276","__ZN2js18RegExpMatchBuilder8setIndexEi","__ZN2js18RegExpMatchBuilder8setInputEP8JSString","__ZN2js18RegExpMatchBuilder11setPropertyEP6JSAtomN2JS5ValueE","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE19resizeUninitializedEj","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEEixEj","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE19growByUninitializedEj","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE10growByImplILb0EEEbj","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE13growStorageByEj","__ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIiLj20ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIiLj20ES1_EEj","__ZN2js10VectorImplIiLj20ENS_17SystemAllocPolicyELb1EE13moveConstructIiEEvPiPKT_S7_","__ZN2js6RegExp6createEP9JSContextP8JSStringjPNS_11TokenStreamE","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE279","__ZN8JSObject10initRegExpEP9JSContextPN2js6RegExpE","__ZN2js6RegExp6decrefEP9JSContext","__ZN9JSContext7delete_IN2js6RegExpEEEvPT_","__ZN2js6RegExpD1Ev","__ZN2js6RegExpD2Ev","__ZN8JSObject19zeroRegExpLastIndexEv","__ZN8JSObject15setRegExpSourceEP8JSString","__ZN8JSObject15setRegExpGlobalEb","__ZN8JSObject19setRegExpIgnoreCaseEb","__ZN8JSObject18setRegExpMultilineEb","__ZN8JSObject15setRegExpStickyEb","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE280","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE281","__ZN2js15AlreadyIncRefedINS_6RegExpEEC1EPS1_","__ZN9JSContext4new_IN2js6RegExpEP14JSLinearStringjP13JSCompartmentEEPT_T0_T1_T2_","__ZN2js6RegExp7compileEP9JSContextPNS_11TokenStreamE","__ZN2js10Foreground7delete_INS_6RegExpEEEvPT_","__ZN2js6RegExp13compileHelperEP9JSContextR14JSLinearStringPNS_11TokenStreamE","__ZN2js12StringBuffer7reserveEj","__ZN2js12StringBuffer16infallibleAppendEPKtj","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16infallibleAppendItEEvPKT_j","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendItEEvPKT_j","__ZN2js12StringBuffer11checkLengthEj","__ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE12beginNoCheckEv","__ZNK2js18ContextAllocPolicy7contextEv","__ZNK2js13RegExpStatics8getFlagsEv","__ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv","__ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE5beginEv","__ZNK2js5Shape10attributesEv","__ZNK2js5Shape6getterEv","__ZNK2js5Shape6setterEv","__ZN19AutoHoldCompartmentD2Ev","__ZL14JSID_FROM_BITSj300","__ZNK9JSContext13getRunOptionsEv","__ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE5emptyEv","__ZNK2js15InvokeArgsGuard6pushedEv","__ZNK9JSContext12hasRunOptionEj","__ZNK8JSObject11isSlowArrayEv","_JSID_IS_STRING293","__ZNK2js5Shape8isMethodEv","_JSVAL_IS_PRIMITIVE_IMPL","_JSVAL_TO_OBJECT_IMPL296","__ZNK2js5Shape8hasTableEv","__ZN2jsL13VersionSetXMLEP9JSVersionb","__ZN2jsL13OptionsHasXMLEj","__ZN2jsL13VersionHasXMLE9JSVersion","__ZN2jsL19VersionExtractFlagsE9JSVersion","_JSVAL_IS_INT32_IMPL","__ZN2jsL8JsvalifyEPNS_5ClassE","__ZL18JSDOUBLE_IS_FINITEd","__ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE11allocPolicyEv","__ZN2js6RegExpC2EP14JSLinearStringjP13JSCompartment","__ZN2js15AlreadyIncRefedINS_6RegExpEEC2EPS1_","__ZN2js18ContextAllocPolicyC2EP9JSContext","__ZN2js12CallArgsList9setActiveEv","__ZN2js12CallArgsList11setInactiveEv","_OBJECT_TO_JSVAL_IMPL284","__ZN18AutoLastFrameCheckC2EP9JSContext","__ZN9JSContext17setDefaultVersionE9JSVersion","__ZN9JSContext15overrideVersionE9JSVersion","__ZN2js5Shape5RangeC2EPKS0_","__ZNK2js5Shape12methodObjectEv","__ZN19AutoHoldCompartmentC2EP13JSCompartment","__ZN18JSAutoResolveFlagsD2Ev","__ZN18JSAutoResolveFlagsC2EP9JSContextj","__ZN9JSRuntime18resetGCMallocBytesEv","__ZNK2js5Shape8getTableEv","__ZN9JSContext13setRunOptionsEj","__ZN2js13StaticStringsC2Ev","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE7reserveEj","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE13growStorageByEj","__ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE6growToERNS_6VectorItLj32ES1_EEj","__ZN2js18ContextAllocPolicy8realloc_EPvjj","__ZN9JSContext8realloc_EPvjj","__ZN9JSRuntime8realloc_EPvjjP9JSContext","__ZNK2js18ContextAllocPolicy19reportAllocOverflowEv","__ZN2js18ContextAllocPolicy7malloc_Ej","__ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13moveConstructItEEvPtPKT_S7_","__ZN2jsL17CheckStringLengthEP9JSContextj","__ZNK2js12StringBuffer7contextEv","__ZN2js6RegExpC1EP14JSLinearStringjP13JSCompartment","__ZN2js13RegExpStatics12setMultilineEb","__ZN2js12StringBufferD2Ev","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEED1Ev","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEED2Ev","__ZN2js18ContextAllocPolicy5free_EPv","__ZN2js12StringBufferC2EP9JSContext","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEEC1ES1_","__ZN2js18ContextAllocPolicyC1EP9JSContext","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEEC2ES1_","__ZN2js15InvokeArgsGuardD2Ev","__ZN2js15InvokeArgsGuardC2Ev","__ZN2js8BindingsC1EP9JSContext","__ZN2js8Bindings11addArgumentEP9JSContextP6JSAtomPt","__ZN2js8BindingsC2EP9JSContext","__ZN18AutoLastFrameCheckD2Ev","__ZL21JS_OPTIONS_TO_TCFLAGSP9JSContext","__ZNK8JSObject12getFixedSlotEj","__ZN2js16AutoObjectRooterD2Ev","__ZN2js16AutoObjectRooterC2EP9JSContextP8JSObject","__ZN8JSObject13setAttributesEP9JSContextiPj","__ZNK8JSObject12containsSlotEj","__ZNK8JSObject13nativeGetSlotEj","__ZN8JSObject13getAttributesEP9JSContextiPj","__ZN8JSObject17methodReadBarrierEP9JSContextRKN2js5ShapeEPN2JS5ValueE","__Z19CloneFunctionObjectP9JSContextP10JSFunction","__ZN8JSObject12setMethodObjERS_","__ZN8JSObject13nativeSetSlotEjRKN2JS5ValueE","__ZN9JSRuntime8realloc_EPvjP9JSContext","_js_calloc299","__ZN8JSObject12nativeLookupEP9JSContexti","__ZN8JSObject12nativeSearchEP9JSContextib","__ZN2js5Shape6searchEP9JSContextPPS0_ib","__ZN9JSContext17setCompileOptionsEj","__ZNK9JSContext17getCompileOptionsEv","__ZN2jsL20OptionFlagsToVersionEj9JSVersion","__ZN2jsL21VersionFlagsToOptionsE9JSVersion","__ZNK9JSContext20canSetDefaultVersionEv","__ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj","__ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj","__ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_ED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E12destroyTableERS7_PNS0_14HashTableEntryIS4_EEj","__ZN11JSAtomStateD2Ev","__ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEED1Ev","__ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj","__ZN11JSAtomStateC2Ev","__ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEEC1ES5_","__ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_","__ZNK2JS5Value7isInt32Ev","__ZN8JSObject21getDenseArrayElementsEv","__ZNK8JSObject9isIndexedEv","__ZL15JSDOUBLE_IS_NaNd","__ZN8JSObject11asArgumentsEv","__ZN16JSAutoByteStringC2Ev","__ZN12JSValueArrayC2EPN2JS5ValueEj","_JS_InitArenaPool","__ZN2js15AutoValueRooter4addrEv","__ZN8JSObject30getDenseArrayInitializedLengthEv","__ZN8JSObject20getDenseArrayElementEj","__ZN2js15AutoValueRooterD2Ev","__ZN2js15AutoValueRooterC2EP9JSContextRKN2JS5ValueE","__ZN16JSAutoByteStringD2Ev","__ZN16JSAutoByteString6encodeEP9JSContextP8JSString","__GLOBAL__I_a","_JS_ArenaAllocate","_JS_ArenaRealloc","__ZN2js11OffTheBooks8realloc_EPvj","_JS_ArenaGrow","_JS_ArenaRelease","__ZL13FreeArenaListP11JSArenaPoolP7JSArena","_JS_FreeArenaPool","_JS_FinishArenaPool","_js_realloc311","__Z20js_GetLengthPropertyP9JSContextP8JSObjectPj","__ZNK8JSObject14getArrayLengthEv","__ZNK8JSObject11isArgumentsEv","__ZNK2js15ArgumentsObject19hasOverriddenLengthEv","__ZN2js15AutoValueRooterC1EP9JSContext","__ZN2js18StringIsArrayIndexEP14JSLinearStringPj","__ZN8JSObject22willBeSparseDenseArrayEjj","__ZNK2JS5Value7isMagicE10JSWhyMagic","__ZN8JSObject22arrayGetOwnDataElementEP9JSContextjPN2JS5ValueE","__ZL9IndexToIdP9JSContextP8JSObjectdPiS3_i","__ZN2js11GetElementsEP9JSContextP8JSObjectjPN2JS5ValueE","__Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject","__ZN2JSL14UndefinedValueEv351","__ZN2js15ArgumentsObject11getElementsEjjPN2JS5ValueE","__ZN2jsL15GetElementsSlowEP9JSContextP8JSObjectjPN2JS5ValueE","__Z20js_SetLengthPropertyP9JSContextP8JSObjectd","__ZL12ATOM_TO_JSIDP6JSAtom354","__Z12js_IdIsIndexiPj","__ZL26array_getElementAttributesP9JSContextP8JSObjectjPj","__ZL12array_typeOfP9JSContextP8JSObject","__ZN2js20array_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ej","__ZL12JSID_IS_ATOMiP6JSAtom","__ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj","__ZN8JSObject19setDenseArrayLengthEj","__ZN8JSObject28setDenseArrayElementWithTypeEP9JSContextjRKN2JS5ValueE","__ZN8JSObject18makeDenseArraySlowEP9JSContext","__ZN2js19array_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ej","__ZN2js20array_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN2JSL10MagicValueE10JSWhyMagic","__ZN2js19array_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZL11array_traceP8JSTracerP8JSObject","__ZL20array_lookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty","__ZL19array_lookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty","__ZL19array_lookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty","__ZL19array_defineSpecialP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ej","__ZL16array_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE","__ZL17array_getPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE","__ZL16array_getElementP9JSContextP8JSObjectS2_jPN2JS5ValueE","__ZL16array_getSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE","__ZL17array_setPropertyP9JSContextP8JSObjectiPN2JS5ValueEi","__ZL16array_setElementP9JSContextP8JSObjectjPN2JS5ValueEi","__ZL16array_setSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZL19array_getAttributesP9JSContextP8JSObjectiPj","__ZL26array_getSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj","__ZL19array_setAttributesP9JSContextP8JSObjectiPj","__ZL26array_setElementAttributesP9JSContextP8JSObjectjPj","__ZL26array_setSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj","__ZL19array_deleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN2js15AutoArrayRooter12changeLengthEj","__ZL9array_fixP9JSContextP8JSObjectPbPN2js12AutoIdVectorE","__ZL21slowarray_addPropertyP9JSContextP8JSObjectiPN2JS5ValueE","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE359","__ZN8JSObject23backfillDenseArrayHolesEP9JSContext","__ZN8JSObject21getDenseArrayCapacityEv","__ZNK8JSObject24denseArrayHasInlineSlotsEv","__ZN2js14AutoValueArrayC1EP9JSContextPN2JS5ValueEj","__ZL17AddLengthPropertyP9JSContextP8JSObject","__ZN2JSL10Int32ValueEi360","__ZN2js14AutoValueArrayD1Ev","__Z12js_MergeSortPvjjPFiS_PKvS1_PiES_S_19JSMergeSortElemType","__ZL11MergeArraysP9MSortArgsPvS1_jj","__ZN2js10array_sortEP9JSContextjPN2JS5ValueE","__ZN2js15AutoArrayRooterC1EP9JSContextjPN2JS5ValueE","__ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE","__ZN2jsL15MakeRangeGCSafeEPN2JS5ValueEj","__ZN2js15AutoArrayRooter11changeArrayEPN2JS5ValueEj","__ZL20sort_compare_stringsPvPKvS1_Pi","__ZN11CompareArgsC1EP9JSContextN2JS5ValueE","__ZL12sort_comparePvPKvS1_Pi","__ZN11CompareArgsD1Ev","__ZL17InitArrayElementsP9JSContextP8JSObjectjjPN2JS5ValueEb","__ZN2js15AutoArrayRooterD1Ev","__ZL15SetArrayElementP9JSContextP8JSObjectdRKN2JS5ValueE","__ZL18DeleteArrayElementP9JSContextP8JSObjectdb","__Z19js_NewbornArrayPushP9JSContextP8JSObjectRKN2JS5ValueE","__Z20NewbornArrayPushImplP9JSContextP8JSObjectRKN2JS5ValueE","__ZN2js10array_pushEP9JSContextjPN2JS5ValueE","__ZL17array_push_slowlyP9JSContextP8JSObjectjPN2JS5ValueES5_","__ZL17array_push1_denseP9JSContextP8JSObjectRKN2JS5ValueEPS4_","__ZN2js9array_popEP9JSContextjPN2JS5ValueE","__ZL15array_pop_denseP9JSContextP8JSObjectPN2JS5ValueE","__ZL16array_pop_slowlyP9JSContextP8JSObjectPN2JS5ValueE","__ZL14array_toSourceP9JSContextjPN2JS5ValueE","__ZL14array_toStringP9JSContextjPN2JS5ValueE","__ZL20array_toLocaleStringP9JSContextjPN2JS5ValueE","__ZL10array_joinP9JSContextjPN2JS5ValueE","__ZL13array_reverseP9JSContextjPN2JS5ValueE","__ZL11array_shiftP9JSContextjPN2JS5ValueE","__ZL13array_unshiftP9JSContextjPN2JS5ValueE","__ZL12array_spliceP9JSContextjPN2JS5ValueE","__ZN2jsL16GetClassProtoKeyEPNS_5ClassE382","__ZN8JSObject30setDenseArrayInitializedLengthEj","__ZN2js2gcL15GetGCObjectKindEjb374","__ZL12array_concatP9JSContextjPN2JS5ValueE","__ZL11array_sliceP9JSContextjPN2JS5ValueE","__ZL13array_indexOfP9JSContextjPN2JS5ValueE","__ZL17array_lastIndexOfP9JSContextjPN2JS5ValueE","__ZL13array_forEachP9JSContextjPN2JS5ValueE","__ZL9array_mapP9JSContextjPN2JS5ValueE","__ZL12array_reduceP9JSContextjPN2JS5ValueE","__ZL17array_reduceRightP9JSContextjPN2JS5ValueE","__ZL12array_filterP9JSContextjPN2JS5ValueE","__ZL10array_someP9JSContextjPN2JS5ValueE","__ZL11array_everyP9JSContextjPN2JS5ValueE","__ZL13array_isArrayP9JSContextjPN2JS5ValueE","__Z8js_ArrayP9JSContextjPN2JS5ValueE","__ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey","__ZL14InitArrayTypesP9JSContextPN2js5types10TypeObjectEPKN2JS5ValueEj","__ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject","__ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject","__ZN2js24NewDenseUnallocatedArrayEP9JSContextjP8JSObject","__ZN8JSObject14setArrayLengthEP9JSContextj","__Z17js_InitArrayClassP9JSContextP8JSObject","__ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_","__ZN2jsL8NewArrayILb0EEEP8JSObjectP9JSContextjS2_","__ZN2js22NewDenseAllocatedArrayEP9JSContextjP8JSObject","__ZN2jsL8NewArrayILb1EEEP8JSObjectP9JSContextjS2_","__ZN8JSObject22copyDenseArrayElementsEjPKN2JS5ValueEj","__ZN2js17NewSlowEmptyArrayEP9JSContext","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_373","__ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE375","__ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_376","__ZN2js5types13TypeObjectKey6getKeyEPS1_","_JSID_IS_INT387","_JSID_IS_STRING388","__ZNK2js5types7TypeSet7unknownEv","__ZNK2js5types4Type9isUnknownEv","__ZNK2js5types7TypeSet9baseFlagsEv","__ZNK2js5types4Type11isPrimitiveEv","__ZN2js5types17PrimitiveTypeFlagE11JSValueType","__ZNK2js5types4Type9primitiveEv","__ZNK2js5types4Type11isAnyObjectEv","__ZNK2js5types7TypeSet15baseObjectCountEv","__ZNK2js5types4Type9objectKeyEv","__ZNK2js5types4Type10typeObjectEv","__ZNK2js5types4Type8isObjectEv","__ZN2js5types13TypeObjectKey7keyBitsEPS1_","_JSVAL_EXTRACT_NON_DOUBLE_TYPE_IMPL","__ZN2js5types7TypeSet18setBaseObjectCountEj","__ZN2js5types10TypeObject20setBasePropertyCountEj","__ZN2jsL17GuessObjectGCKindEjb","__ZN8JSObject11ensureSlotsEP9JSContextj","__ZN2JSL11ObjectValueER8JSObject383","__ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiRKN2JS5ValueE","__ZN2js5typesL15HashSetCapacityEj385","__ZN2js5typesL7HashKeyIiNS0_8PropertyEEEjT_386","__ZN2js5types4Type10DoubleTypeEv","__ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb","__ZN2js5types10TypeObject11getPropertyEP9JSContextib","__ZN2js5types12GetValueTypeEP9JSContextRKN2JS5ValueE","__ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE","__ZN2js5types22AutoEnterTypeInferenceD1Ev","__ZN2js5types22AutoEnterTypeInferenceD2Ev","__ZN2js5types7TypeSet12clearObjectsEv","__ZN2js5typesL13HashSetInsertIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_","__ZNK2js5types4Type12isTypeObjectEv","__ZN2js5types4Type13AnyObjectTypeEv","__ZN2js5types15TypeCompartment10addPendingEP9JSContextPNS0_14TypeConstraintEPNS0_7TypeSetENS0_4TypeE","__ZN2js5types15TypeCompartment14resolvePendingEP9JSContext","__ZN2js10ArenaArrayIPNS_5types13TypeObjectKeyEEEPT_R11JSArenaPoolj","__ZN2jsL7PodZeroIPNS_5types13TypeObjectKeyEEEvPT_j","__ZN2js5typesL16HashSetInsertTryIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_","__ZN2js5typesL7HashKeyIPNS0_13TypeObjectKeyES2_EEjT_","__ZN2js5types4Type10ObjectTypeEP8JSObject","__ZN2js5types4Type13PrimitiveTypeE11JSValueType","__ZNK2JS5Value20extractNonDoubleTypeEv","__ZN2js5typesL13HashSetInsertIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_","__ZN2js5types4Type11UnknownTypeEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isFreeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE9matchHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE9isRemovedEv","__ZN2js5types22AutoEnterTypeInferenceC2EP9JSContextb","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE12setCollisionEj","__ZN2js5types17AllocationSiteKey5matchERKS1_S3_","__ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS7_EE","__ZN2js5types17AllocationSiteKey4hashES1_","__ZN2jsL7PodZeroINS_5types17AllocationSiteKeyEEEvPT_","__ZN2js5types7TypeSet14setOwnPropertyEP9JSContextb","__ZN2js10ArenaArrayIPNS_5types8PropertyEEEPT_R11JSArenaPoolj","__ZN2jsL7PodZeroIPNS_5types8PropertyEEEvPT_j","__ZN2js5typesL16HashSetInsertTryIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_","__ZNK2js12ContextStack13currentScriptEPPh","__ZN2js5types10TypeScript10InitObjectEP9JSContextP8JSScriptPKh10JSProtoKey","__ZN2js5types16GetTypeNewObjectEP9JSContext10JSProtoKey","__ZNK8JSScript9hasGlobalEv","__ZN2js5types17AllocationSiteKeyC1Ev","__ZNK2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE6lookupERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isLiveEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS7_EE","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS7_EERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj","__ZN2js5types17AllocationSiteKeyC2Ev","__ZNK2js12GlobalObject9isClearedEv","__ZL11array_extraP9JSContext14ArrayExtraModejPN2JS5ValueE","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_","__ZN8JSObject18isPackedDenseArrayEv","_INT_TO_JSID398","__ZN22AutoArrayCycleDetector10foundCycleEv","__ZN2jsL3MinIjEET_S1_S1_","__ZN2js6detail14HashTableEntryIKP8JSObjectE10isLiveHashEj","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj","__ZNK2js6detail14HashTableEntryIKP8JSObjectE6isFreeEv","__ZN2js6detail14HashTableEntryIKP8JSObjectE9matchHashEj","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj","__ZNK2js6detail14HashTableEntryIKP8JSObjectE9isRemovedEv","__ZL18JSDOUBLE_IS_FINITEd396","__ZL15JSDOUBLE_IS_NaNd397","__ZN2js6detail14HashTableEntryIKP8JSObjectE12setCollisionEj","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv","__ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE","__ZL19array_indexOfHelperP9JSContextijPN2JS5ValueE","__ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd","__ZL18js_DoubleToIntegerd395","__ZL17TryReuseArrayTypeP8JSObjectS0_","__ZL15InitArrayObjectP9JSContextP8JSObjectjPKN2JS5ValueE","__ZN8JSObject22moveDenseArrayElementsEjjj","__ZL23SetOrDeleteArrayElementP9JSContextP8JSObjectdiRKN2JS5ValueE","__ZL18array_toString_subP9JSContextP8JSObjectiP8JSStringPN2JS5ValueE","__ZN22AutoArrayCycleDetectorC1EP9JSContextP8JSObject","__ZN22AutoArrayCycleDetector4initEv","__ZN2js19ValueToStringBufferEP9JSContextRKN2JS5ValueERNS_12StringBufferE","__ZN2js12StringBuffer6appendEPKtj","__ZN22AutoArrayCycleDetectorD1Ev","__ZN22AutoArrayCycleDetectorD2Ev","__ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE10generationEv","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS6_6SetOpsES5_E3PtrE","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeERKS2_","__ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6lookupERKS2_","__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv","__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv","__ZNK2js6detail14HashTableEntryIKP8JSObjectE6isLiveEv","__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS4_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE","__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_jj","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS4_EE","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv","__ZNK2js6detail14HashTableEntryIKP8JSObjectE10getKeyHashEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryIKP8JSObjectEEEptEv","__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10generationEv","__ZN2js12AutoIdRooter2idEv","__ZNK2js6detail14HashTableEntryIKP8JSObjectE12hasCollisionEv","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv","__ZNK18ArraySharpDetector14initiallySharpEv","__ZNK18ArraySharpDetector13hasSharpCharsEv","_JSID_IS_VOID","_JSVAL_IS_SPECIFIC_BOOLEAN407","__ZN2JS5Value12getDoubleRefEv","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryIKP8JSObjectE14unsetCollisionEv","__ZN2js7MoveRefINS_6detail14HashTableEntryIKP8JSObjectEEEC2ERS6_","__ZN2js6detail14HashTableEntryIKP8JSObjectE12setCollisionEv","__ZN2js6detail14HashTableEntryIKP8JSObjectEC2Ev","__ZN2js6detail14HashTableEntryIKP8JSObjectE10setRemovedEv","__ZN2js6detail14HashTableEntryIKP8JSObjectE7setFreeEv","__ZN2js6detail14HashTableEntryIKP8JSObjectE7setLiveEj","__ZN22AutoArrayCycleDetectorC2EP9JSContextP8JSObject","__ZN18ArraySharpDetector14takeSharpCharsEv","__ZN18ArraySharpDetector9makeSharpEv","__ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13copyConstructIcEEvPtPKT_S7_","__ZN18ArraySharpDetectorC2EP9JSContext","__ZN2js12AutoIdRooter4addrEv","__ZZN2js10array_sortEP9JSContextjPN2JS5ValueEEN14AutoFreeVectorC2ES1_RS4_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryIKP8JSObjectEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_6detail14HashTableEntryIKP8JSObjectEEEENS_7MoveRefIT_EERS8_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj","__ZN2js7MoveRefINS_6detail14HashTableEntryIKP8JSObjectEEEC1ERS6_","__ZN2js6detail14HashTableEntryIKP8JSObjectEC1Ev","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbPKT_j","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbPKT_S6_","__ZN2js12StringBuffer6appendEP8JSString","__ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE12lookupForAddERKS2_","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS6_6SetOpsES5_E6AddPtrERS9_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS4_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE","__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERS4_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj","__ZL13js_IsCallableRKN2JS5ValueE405","__ZN18ArraySharpDetectorC1EP9JSContext","__ZN18ArraySharpDetector4initEP8JSObject","__ZN2js12StringBuffer16replaceRawBufferEPtj","__ZN2js12StringBuffer6appendEt","__ZN2js12StringBuffer6appendILj3EEEbRAT__Kc","__ZN2JSL11StringValueEP8JSString406","__ZN18ArraySharpDetectorD1Ev","__ZN18ArraySharpDetectorD2Ev","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendIcEEbPKT_S6_","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendIcEEvPKT_j","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbT_","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendItEEvT_","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16replaceRawBufferEPtj","__ZN2js12AutoIdRooterC1EP9JSContexti","__ZNK2JS5Value6isTrueEv","__ZN2js12AutoIdRooterD1Ev","__ZN2js12AutoIdRooterD2Ev","__ZN2js12AutoIdRooterC2EP9JSContexti","__ZZN2js10array_sortEP9JSContextjPN2JS5ValueEEN14AutoFreeVectorD2Ev","__ZN2js15AutoArrayRooterD2Ev","__ZN2JSL11DoubleValueEd408","__Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi","__Z14js_ValueToAtomP9JSContextRKN2JS5ValueEPP6JSAtom","__ZN11CompareArgsD2Ev","__ZN11CompareArgsC2EP9JSContextN2JS5ValueE","__ZN2jsL7PodZeroIN2JS5ValueEEEvPT_j412","__ZN2js15ArgumentsObject10getElementEjPN2JS5ValueE","__ZNK2js15ArgumentsObject7elementEj","__ZNK2js15ArgumentsObject7onTraceEv","__ZNK2js15ArgumentsObject15maybeStackFrameEv","__ZNK2js15ArgumentsObject4dataEv","__ZN2js15AutoArrayRooterC2EP9JSContextjPN2JS5ValueE","__ZN2js14AutoValueArrayD2Ev","__ZL19array_length_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE","__ZL14JSID_FROM_BITSj423","_JSID_TO_INT420","_JSID_TO_STRING422","_JSVAL_IS_MAGIC_IMPL","__ZNK8JSObject17isStrictArgumentsEv","__ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv","__ZNK2js18TaggedPointerEntryI6JSAtomE5asPtrEv","__ZNK2js18TaggedPointerEntryI6JSAtomE8isTaggedEv","__ZNK2js10StackFrame13formalArgsEndEv","__ZN6JSAtom14asPropertyNameEv","__ZN2js6detail17CopyNonHoleArgsToC2EPNS_15ArgumentsObjectEPN2JS5ValueE","__ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv","__ZN11JSAtomState16commonAtomsStartEv","__Z20js_FinishCommonAtomsP9JSContext","__ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrptEv","__ZNK2js18TaggedPointerEntryI6JSAtomE9setTaggedEb","__ZL19array_length_setterP9JSContextP8JSObjectiiPN2JS5ValueE","__ZN8JSObject24shrinkDenseArrayElementsEP9JSContextj","__ZN2js14AutoValueArrayC2EP9JSContextPN2JS5ValueEj","__Z13js_GetElementP9JSContextP8JSObjectjPN2JS5ValueE","__Z14js_GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE","__ZL17IsDenseArrayIndexP8JSObjectj","__ZN8JSObject13lookupElementEP9JSContextjPPS_PP10JSProperty","__ZL14IsDenseArrayIdP9JSContextP8JSObjecti","__ZL12JSID_TO_ATOMi421","__ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE","__ZNK2js15ArgumentsObject8elementsEv","__ZN2js10StackFrame25forEachCanonicalActualArgINS_6detail17CopyNonHoleArgsToEEEbT_jj","__ZN2js6detail17CopyNonHoleArgsToC1EPNS_15ArgumentsObjectEPN2JS5ValueE","__ZN2js6detail17CopyNonHoleArgsToclEjPN2JS5ValueE","__ZL12BigIndexToIdP9JSContextP8JSObjectjiPi","__ZL18ReallyBigIndexToIdP9JSContextdPi","__ZN2js15AutoValueRooterC2EP9JSContext","__ZN2JSL9NullValueEv429","__Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString","__ZN2JSL11StringValueEP8JSString478","__Z16js_InitAtomStateP9JSRuntime","__ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE4initEj","__Z18js_FinishAtomStateP9JSRuntime","__ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE11initializedEv","__ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE3allEv","__ZN6JSAtom8finalizeEP9JSRuntime","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv","__Z18js_InitCommonAtomsP9JSContext","__Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE","__ZN11JSAtomState14clearLazyAtomsEv","__Z17js_TraceAtomStateP8JSTracer","__ZN2js18TaggedPointerEntryI6JSAtomEC1ERKS2_","__Z17js_SweepAtomStateP9JSContext","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC1IS9_EERT_","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4Enum11removeFrontEv","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD1Ev","__ZN2js24AutoLockAtomsCompartmentC1EP9JSContext","__ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE6lookupERKNS4_6LookupE","__ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv","__Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE","__ZL7AtomizeP9JSContextPPKtjN2js14InternBehaviorE16OwnCharsBehavior","__ZN2jsL17CheckStringLengthEP9JSContextj489","__Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE","__ZNK7mozilla9RangedPtrItE3getEv","__ZNK7mozilla9RangedPtrItEdeEv","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv","__ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS3_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv","__ZNK7mozilla9RangedPtrItEmiERKS1_","_INT_TO_JSID501","__ZNK8JSObject5isXMLEv","_OBJECT_TO_JSID502","_JSID_TO_STRING504","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE10isLiveHashEj","__ZNK2js9InlineMapIP6JSAtomjLj24EE8usingMapEv","__ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE10isLiveHashEj","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj","__ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isFreeEv","__ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE9matchHashEj","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj","__ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE9isRemovedEv","__ZNK2js9InlineMapIP6JSAtomjLj24EE5asMapEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv","__ZNK2js9InlineMapIP6JSAtomjLj24EE8asInlineEv","__ZNK2js9InlineMapIP6JSAtomjLj24EE9inlineEndEv","__ZN7mozilla9RangedPtrItEaSItEERS1_RKNS0_IT_EE","__ZN7mozilla9RangedPtrItEC2EPtS2_j","__ZN7mozilla9RangedPtrItEC2EPtS2_S2_","__ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE12setCollisionEj","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE","__ZN2js9HashCharsEPKtj","__ZL13AtomizeInlineP9JSContextPPKtjN2js14InternBehaviorE16OwnCharsBehavior","__Z24js_GetExistingStringAtomP9JSContextPKtj","__ZN2js13StaticStrings6lookupEPKtj","__ZN2js10AtomHasher6LookupC1EPKtj","__Z14js_InitAtomMapP9JSContextPN2js9InlineMapIP6JSAtomjLj24EEEPS4_","__ZNK2js9InlineMapIP6JSAtomjLj24EE5isMapEv","__ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv","__ZN2js13IndexToIdSlowEP9JSContextjPi","__ZN7mozilla9RangedPtrItEC1EPtS2_S2_","__ZN2js25BackfillIndexInCharBufferItEEN7mozilla9RangedPtrIT_EEjS4_","__ZL12ATOM_TO_JSIDP6JSAtom496","__Z22js_CheckForStringIndexi","__ZL12JSID_IS_ATOMi499","__ZL12JSID_TO_ATOMi500","__Z28js_InternNonIntElementIdSlowP9JSContextP8JSObjectRKN2JS5ValueEPi","__Z28js_InternNonIntElementIdSlowP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_","__ZN2jsL9IdToValueEi503","__ZN7mozilla9RangedPtrItEmmEv","__ZN7mozilla9RangedPtrItEmIEj","__ZN7mozilla9RangedPtrItEmiEj","__ZNK7mozilla9RangedPtrItE6createEPt","__ZN7mozilla9RangedPtrItEC1EPtS2_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isLiveEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_","__ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv","__ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isLiveEv","__ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERKNS7_6LookupE","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERKNS7_6LookupE","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS5_EE","__ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERKNS7_6LookupEjj","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS5_EERKNS7_6LookupE","__ZN2js10AtomHasher5matchERKNS_18TaggedPointerEntryI6JSAtomEERKNS0_6LookupE","__ZN2jsL8PodEqualIKtEEbPT_S3_j","__ZN2js10AtomHasher4hashERKNS0_6LookupE","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj","__ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE10getKeyHashEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEptEv","__ZNK2js7MoveRefINS_18TaggedPointerEntryI6JSAtomEEEcvRS3_Ev","__ZL14JSID_FROM_BITSj522","_JSVAL_TO_BOOLEAN_IMPL","__ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE12hasCollisionEv","__ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11initializedEv","_JSID_IS_STRING508","_JSID_IS_INT509","_JSID_TO_INT511","_JSID_IS_OBJECT512","_JSID_TO_OBJECT514","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv","__ZL15JSDOUBLE_IS_NaNd535","__ZN2js18TaggedPointerEntryI6JSAtomEC2Ev","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE14unsetCollisionEv","__ZN2js7MoveRefINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEC2ERS7_","__ZN2js7MoveRefINS_18TaggedPointerEntryI6JSAtomEEEC2ERS3_","__ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE12setCollisionEv","__ZN2js18TaggedPointerEntryI6JSAtomEC2ERKS2_","__ZN2js10AtomHasher6LookupC2EPKtj","__ZN2js13StaticStrings7getUnitEt","__ZN2js13StaticStrings10getLength2Ett","__ZN2js13StaticStrings7getUintEj","__ZN2js18TaggedPointerEntryI6JSAtomEC2EPS1_b","__ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE7setLiveEj","__ZN2js24AutoLockAtomsCompartmentC2EP9JSContext","__Z18js_BooleanToStringP9JSContexti","__ZN2js2gcL15GetGCObjectKindEjb560","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS5_EE","__ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE10setRemovedEv","__ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE7setFreeEv","__ZN2js18TaggedPointerEntryI6JSAtomEC1Ev","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD2Ev","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEaSENS_7MoveRefIS6_EE","__ZN2js4MoveINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEENS_7MoveRefIT_EERS9_","__ZN2js7MoveRefINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEC1ERS7_","__ZN2js4MoveINS_18TaggedPointerEntryI6JSAtomEEEENS_7MoveRefIT_EERS5_","__ZN2js7MoveRefINS_18TaggedPointerEntryI6JSAtomEEEC1ERS3_","__ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEC1Ev","__ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEC2Ev","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC2IS9_EERT_","__ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3allEv","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC1EPNS0_14HashTableEntryIS5_EESF_","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC2EPNS0_14HashTableEntryIS5_EESF_","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj","__ZN2JSL10Int32ValueEi510","__ZN2JSL11ObjectValueER8JSObject513","__ZN2JSL14UndefinedValueEv515","__ZN2js13StaticStrings6getIntEi","__ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE12lookupForAddERKNS4_6LookupE","__ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE13relookupOrAddERNS_6detail9HashTableIKS3_NS6_6SetOpsES5_E6AddPtrERKNS4_6LookupERS9_","__ZN2js18TaggedPointerEntryI6JSAtomEC1EPS1_b","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E13relookupOrAddERNSB_6AddPtrERKNS7_6LookupERS5_","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS5_","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE","__ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERKNS7_6LookupE","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj","__ZN12JSFlatString8finalizeEP9JSRuntime","__ZL13bool_toSourceP9JSContextjPN2JS5ValueE","__ZL13bool_toStringP9JSContextjPN2JS5ValueE","__ZL12bool_valueOfP9JSContextjPN2JS5ValueE","__Z19js_InitBooleanClassP9JSContextP8JSObject","__ZN8JSObject16setPrimitiveThisERKN2JS5ValueE","__ZN2JSL12BooleanValueEb532","__ZL7BooleanP9JSContextjPN2JS5ValueE","__ZN2js21BooleanToStringBufferEP9JSContextiRNS_12StringBufferE","__ZN2js12StringBuffer6appendILj5EEEbRAT__Kc","__ZN2js12StringBuffer6appendILj6EEEbRAT__Kc","__Z17js_ValueToBooleanRKN2JS5ValueE","__ZNK2JS5Value9toBooleanEv","__ZN2jsL14IsConstructingEPKN2JS5ValueE","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE558","__ZL9SwapBytesy","__ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE6lengthEv","_JSVAL_IS_MAGIC_IMPL571","_JSVAL_IS_BOOLEAN_IMPL","__ZL12PairToUInt64jj","_JSID_IS_INT594","_JSID_TO_INT595","_JSID_TO_STRING596","__ZL14ArrayTypeToTagj","__ZL25ReinterpretDoubleAsUInt64d","__ZN2js7SCInputC2EP9JSContextPKyj","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE561","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE562","__ZNK2JS5Value7isMagicEv","__ZN2js16GetPrimitiveThisIbEEbP9JSContextPN2JS5ValueEPT_","__ZN2js6detail17PrimitiveBehaviorIbE6isTypeERKN2JS5ValueE","__ZN2js6detail17PrimitiveBehaviorIbE7extractERKN2JS5ValueE","__ZNK8JSObject16getPrimitiveThisEv","__ZNK2JS5Value9isBooleanEv","__ZN2js20WriteStructuredCloneEP9JSContextRKN2JS5ValueEPPyPjPK26JSStructuredCloneCallbacksPv","__ZN23JSStructuredCloneWriterC1ERN2js8SCOutputEPK26JSStructuredCloneCallbacksPv","__ZN23JSStructuredCloneWriter4initEv","__ZN23JSStructuredCloneWriter5writeERKN2JS5ValueE","__ZN2js8SCOutput13extractBufferEPPyPj","__ZN23JSStructuredCloneWriterD1Ev","__ZN2js8SCOutputD1Ev","__ZN2js19ReadStructuredCloneEP9JSContextPKyjPN2JS5ValueEPK26JSStructuredCloneCallbacksPv","__ZN23JSStructuredCloneReaderC1ERN2js7SCInputEPK26JSStructuredCloneCallbacksPv","__ZN23JSStructuredCloneReader4readEPN2JS5ValueE","__ZN23JSStructuredCloneReaderD1Ev","__ZN2js7SCInput3eofEv","__ZN2js7SCInput4readEPy","__ZN2js7SCInput8readPairEPjS1_","__ZN2js7SCInput10readDoubleEPd","__ZL15CanonicalizeNand","__ZN2js7SCInput9readArrayIhEEbPT_j","__ZN2js7SCInput9readCharsEPtj","__ZN2js7SCInput9readArrayItEEbPT_j","__ZN2js8SCOutputC2EP9JSContext","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEC1ES1_","__ZN2js8SCOutput5writeEy","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE6appendIyEEbT_","__ZN2js8SCOutput9writePairEjj","__ZN2js8SCOutput11writeDoubleEd","__ZN2js8SCOutput10writeBytesEPKvj","__ZN2js8SCOutput10writeArrayIhEEbPKT_j","__ZN2js8SCOutput10writeCharsEPKtj","__ZN2js8SCOutput10writeArrayItEEbPKT_j","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE16extractRawBufferEv","__ZN23JSStructuredCloneWriter11writeStringEjP8JSString","__ZN23JSStructuredCloneWriter7contextEv","__ZN23JSStructuredCloneWriter7writeIdEi","__ZN23JSStructuredCloneWriter15writeTypedArrayEP8JSObject","__ZN2js10TypedArray7getTypeEP8JSObject","__ZN2js10TypedArray9getLengthEP8JSObject","__ZN2js10TypedArray13getDataOffsetEP8JSObject","__ZN2js8SCOutput10writeArrayIjEEbPKT_j","__ZN5Chars3getEv","__ZNK8JSObject9isBooleanEv","__ZNK8JSObject8isNumberEv","__ZNK8JSObject8isStringEv","__ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE5emptyEv","_JSID_IS_STRING598","_JSVAL_IS_DOUBLE_IMPL599","__ZL14TagToArrayTypej","__ZN8JSObject21arrayBufferByteLengthEv","__ZN8JSObject21arrayBufferDataOffsetEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrptEv","__ZN2jsL7ReverseIiEEvPT_S2_","__ZN5Chars6forgetEv","__ZN2js8SCOutput10writeArrayIyEEbPKT_j","__ZN23JSStructuredCloneWriter16writeArrayBufferEP8JSObject","__ZN23JSStructuredCloneWriter11startObjectEP8JSObject","__ZNK2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv","__ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKj","__ZNK2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv","__ZN2js16AutoVectorRooterIiE5beginEv","__ZN2js16AutoVectorRooterIiE3endEv","__ZN2JSL11ObjectValueER8JSObject597","__ZN23JSStructuredCloneWriter10startWriteERKN2JS5ValueE","__ZNK2js16AutoVectorRooterIN2JS5ValueEE4backEv","__ZNK2js16AutoVectorRooterIiE4backEv","__ZN2js16AutoVectorRooterIiE7popBackEv","__ZN2js16AutoVectorRooterIN2JS5ValueEE7popBackEv","__ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv","__ZN23JSStructuredCloneReader11checkDoubleEd","__ZN23JSStructuredCloneReader7contextEv","__ZN23JSStructuredCloneReader10readStringEj","__ZN5CharsC1Ev","__ZN5Chars8allocateEP9JSContextj","__ZN5CharsD1Ev","__ZN23JSStructuredCloneReader14readTypedArrayEjjPN2JS5ValueE","__ZN2js7SCInput9readArrayIjEEbPT_j","__ZN2js7SCInput9readArrayIyEEbPT_j","__ZN23JSStructuredCloneReader15readArrayBufferEjPN2JS5ValueE","__ZL9SwapBytesj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE10getKeyHashEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEptEv","__ZNK2js7MoveRefINS_12HashMapEntryIP8JSObjectjEEEptEv","__ZNK2js7MoveRefIjEcvRjEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5countEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv","_INT_TO_JSID603","_JSID_IS_VOID605","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10overloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE6isFreeEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE10isLiveHashEj","__ZL18JSDOUBLE_IS_FINITEd600","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE5clearEv","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE7popBackEv","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE7popBackEv","__ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE3endEv","__ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE3endEv","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE3endEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE7setLiveEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE14unsetCollisionEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEC2ERS7_","__ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectjEEEC2ERS4_","__ZN2js7MoveRefIjEC2ERj","__ZN2js12HashMapEntryIP8JSObjectjEC2Ev","__ZN23JSStructuredCloneReader9startReadEPN2JS5ValueE","__ZL18js_DoubleToIntegerd601","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE602","__ZL23ReinterpretPairAsDoublejj","__ZN23JSStructuredCloneReader6readIdEPi","__ZL12ATOM_TO_JSIDP6JSAtom604","__ZN2js16AutoVectorRooterIN2JS5ValueEE5clearEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5clearEv","__ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE4backEv","__ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE4backEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE6isLiveEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEaSENS_7MoveRefIS6_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEENS_7MoveRefIT_EERS9_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEC1ERS7_","__ZN2js12HashMapEntryIP8JSObjectjEaSENS_7MoveRefIS3_EE","__ZN2js4MoveINS_12HashMapEntryIP8JSObjectjEEEENS_7MoveRefIT_EERS6_","__ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectjEEEC1ERS4_","__ZN2js4MoveIjEENS_7MoveRefIT_EERS2_","__ZN2js7MoveRefIjEC1ERj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEC2Ev","__ZN2js12HashMapEntryIP8JSObjectjEC1Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_","__ZNK2js8SCOutput7contextEv","__ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE5beginEv","__ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZL9SwapBytest","__ZL14JSID_FROM_BITSj609","__ZNK2js7SCInput7contextEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE9matchHashEj","_JS_CANONICALIZE_NAN644","__ZL25ReinterpretUInt64AsDoubley","__ZL15JSDOUBLE_IS_NaNd628","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE12setCollisionEj","__ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_jEE","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE3endEv","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js10VectorImplIyLj0ENS_15TempAllocPolicyELb1EE13copyConstructIyEEvPyPKT_S7_","__ZN2js2gcL15GetGCObjectKindEjb613","__ZN5CharsC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC2ES9_","__ZN2js10ThreadData24triggerOperationCallbackEP9JSRuntime","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE19growByUninitializedEj","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE4backEv","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEixEj","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE10growByImplILb0EEEbj","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIyLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIyLj0ES1_EEj","__ZN2js10VectorImplIyLj0ENS_15TempAllocPolicyELb1EE13moveConstructIyEEvPyPKT_S7_","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE14internalAppendIyEEvT_","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEC2ES1_","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE614","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE615","__ZN5CharsD2Ev","__ZN23JSStructuredCloneReaderD2Ev","__ZN23JSStructuredCloneReaderC2ERN2js7SCInputEPK26JSStructuredCloneCallbacksPv","__ZN2js8SCOutputD2Ev","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEED2Ev","__ZN23JSStructuredCloneWriterD2Ev","__ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev","__ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED2Ev","__ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E4initEj","__ZN23JSStructuredCloneWriterC2ERN2js8SCOutputEPK26JSStructuredCloneCallbacksPv","__ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_","__ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC1ES9_","__ZN2js10ThreadDataC2Ev","__ZN2js8GSNCacheC1Ev","__ZN2js13PropertyCacheC1Ev","__ZN2js18GetNativeStackBaseEv","__ZN2js24ConservativeGCThreadDataC1Ev","__ZN2js10ThreadDataD2Ev","__ZN2js8GSNCacheD1Ev","__ZN2js10ThreadData4initEv","__Z14js_InitThreadsP9JSRuntime","__Z15js_PurgeThreadsP9JSContext","__ZN2js10ThreadData5purgeEP9JSContext","__Z13js_NewContextP9JSRuntimej","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE4initEj","__ZN2js10Foreground7delete_I9JSContextEEvPT_","__ZN9JSContext13fromLinkFieldEP10JSCListStr","__ZNK2js13AutoResolving18alreadyStartedSlowEv","__Z18js_GetErrorMessagePvPKcj","__Z17js_DestroyContextP9JSContext20JSDestroyContextMode","__Z18js_ContextIteratorP9JSRuntimeiPP9JSContext","__ZN7mozilla5MaybeIN2js10AutoLockGCEEC1Ev","__ZN7mozilla5MaybeIN2js10AutoLockGCEE9constructIP9JSRuntimeEEvRKT_","__Z20js_ReportOutOfMemoryP9JSContext","__ZN2jsL7PodZeroI13JSErrorReportEEvPT_","__ZL19PopulateReportBlameP9JSContextP13JSErrorReport","__ZN2js19AutoAtomicIncrementC1EPi","__ZN2js19AutoAtomicIncrementD1Ev","__Z21js_ReportOverRecursedP9JSContext","__Z27js_ReportAllocationOverflowP9JSContext","__Z16js_ReportErrorVAP9JSContextjPKcPc","__ZL16checkReportFlagsP9JSContextPj","__ZL11ReportErrorP9JSContextPKcP13JSErrorReportPFPK19JSErrorFormatStringPvS2_jES8_","__Z23js_ExpandErrorArgumentsP9JSContextPFPK19JSErrorFormatStringPvPKcjES4_jPPcP13JSErrorReportbS9_","__Z22js_ReportErrorNumberVAP9JSContextjPFPK19JSErrorFormatStringPvPKcjES4_jiPc","__Z19js_ReportErrorAgainP9JSContextPKcP13JSErrorReport","__Z21js_ReportIsNotDefinedP9JSContextPKc","__ZN9JSContext22thisDuringConstructionEv","__ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE6lengthEv","__ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE5beginEv","__ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE12beginNoCheckEv","__ZNK2js10StackFrame8imacropcEv","__ZNK2js9StackIter2pcEv","__ZNK2js14ThreadDataIter5emptyEv","__ZNK2js10StackFrame11hasImacropcEv","__ZN2js19AutoAtomicIncrementD2Ev","__ZNK7mozilla14AlignedStorageILj8EE4addrEv","__ZN7mozilla14AlignedStorageILj8EE4addrEv","__ZN7mozilla15AlignedStorage2IN2js10AutoLockGCEE4addrEv","__ZNK2js14ThreadDataIter10threadDataEv","__ZN2js14ThreadDataIter8popFrontEv","__ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE3endEv","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE10endNoCheckEv","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_","__ZN7mozilla5MaybeIN2js10AutoLockGCEEC2Ev","__ZN14DSTOffsetCache5purgeEv","__ZN2js14ThreadDataIterC2EP9JSRuntime","__ZN2js19AutoAtomicIncrementC2EPi","__ZN2js24ConservativeGCThreadDataC2Ev","__Z26js_ReportIsNullOrUndefinedP9JSContextiRKN2JS5ValueEP8JSString","__ZN2jsL23DecompileValueGeneratorEP9JSContextiRKN2JS5ValueEP8JSString","__Z19js_ReportMissingArgP9JSContextRKN2JS5ValueEj","__ZN2jsL16IsFunctionObjectERKN2JS5ValueE","__Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_","__Z16checkOutOfMemoryP9JSRuntime","__Z26js_InvokeOperationCallbackP9JSContext","__Z27js_HandleExecutionInterruptP9JSContext","__ZN2js28TriggerAllOperationCallbacksEP9JSRuntime","__ZN2js14ThreadDataIterC1EP9JSRuntime","__Z20js_GetScriptedCallerP9JSContextPN2js10StackFrameE","__ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind","__Z23js_GetCurrentBytecodePCP9JSContext","__ZNK2js10StackFrame13maybeImacropcEv","__ZN9JSContextC2EP9JSRuntime","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES5_","__ZN14DSTOffsetCacheC1Ev","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEEC1ES3_","__ZN9JSContextD2Ev","__ZN2js10Foreground7delete_INS_12ParseMapPoolEEEvPT_","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEED1Ev","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev","__ZN9JSContext16resetCompartmentEv","__Z19OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject","__ZN9JSContext20wrapPendingExceptionEv","__ZNK9JSContext12generatorForEPN2js10StackFrameE","__ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE4backEv","__ZN11JSGenerator9liveFrameEv","__ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEEixEj","__ZNK9JSContext28runningWithTrustedPrincipalsEv","__ZN9JSRuntime15onTooMuchMallocEv","__ZN9JSRuntime13onOutOfMemoryEPvjP9JSContext","__ZN9JSContext5purgeEv","__ZL13FreeOldArenasP9JSRuntimeP11JSArenaPool","__ZN2js12ParseMapPoolD1Ev","_js_free816","__ZN2js12ParseMapPoolD2Ev","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEED1Ev","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEED2Ev","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEED2Ev","__ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEEC2ES3_","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev","__ZN14DSTOffsetCacheC2Ev","__ZNK9JSContext15hasStrictOptionEv","__ZNK9JSContext15hasWErrorOptionEv","__ZN2js13FrameRegsIterC1EP9JSContextNS_9StackIter11SavedOptionE","__ZNK2js13FrameRegsIter4doneEv","__ZNK2js13FrameRegsIter2fpEv","__ZNK2js13FrameRegsIter2pcEv","__ZN2js13FrameRegsIterppEv","__ZN2js13FrameRegsIter6settleEv","__ZN2js13FrameRegsIterC2EP9JSContextNS_9StackIter11SavedOptionE","__ZN2js8GSNCacheD2Ev","__ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEED1Ev","__ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj","__ZN2js13PropertyCacheC2Ev","__ZN2jsL7PodZeroINS_13PropertyCacheEEEvPT_","__ZN2js8GSNCacheC2Ev","__ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEEC1ES4_","__ZN13JSCompartment11thisForCtorEv","__ZNK8JSObject15isStopIterationEv","_JSID_IS_INT844","__ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5emptyEv","__ZN2jsL16CastAsPropertyOpEP8JSObject846","__ZN2jsL22CastAsStrictPropertyOpEP8JSObject847","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_","__ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5frontEv","__ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEEC2ES4_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_","__ZN13JSCompartmentC2EP9JSRuntime","__ZN2js2gc10ArenaListsC1Ev","__ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEEC1ES4_","__ZN2js12PropertyTreeC1EP13JSCompartment","__ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES5_","__ZN2js15NativeIterCacheC1Ev","__ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEEC1Ev","__ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEEC1ES4_","__ZN2js9DtoaCacheC1Ev","__ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC1ES4_","__ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEEC1ES6_","__ZN2js18RuntimeAllocPolicyC1EP9JSRuntime","__ZN2jsL12PodArrayZeroIP8JSScriptLj64EEEvRAT0__T_","__ZN13JSCompartmentD2Ev","__ZN2js10Foreground7delete_INS_9MathCacheEEEvPT_","__ZN2js10Foreground7delete_INS_13WatchpointMapEEEvPT_","__ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEED1Ev","__ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED1Ev","__ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEED1Ev","__ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEED1Ev","__ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev","__ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEED1Ev","__ZN2js2gc10ArenaListsD1Ev","__ZN13JSCompartment4initEP9JSContext","__ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE4initEj","__ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE4initEj","__ZN9JSRuntime4new_IN3WTF20BumpPointerAllocatorEEEPT_v","__ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE4initEj","__ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE4initEj","__ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE","__ZNK2JS5Value10isMarkableEv","__ZL25IsCrossCompartmentWrapperP8JSObject","__ZN13JSCompartment4wrapEP9JSContextPP8JSObject","__ZN13JSCompartment4wrapEP9JSContextPP8JSString","__ZN2JSL11StringValueEP8JSString840","__ZN2JSL11ObjectValueER8JSObject841","__ZN13JSCompartment6wrapIdEP9JSContextPi","__ZN2jsL9IdToValueEi845","__ZN13JSCompartment4wrapEP9JSContextPPFiS1_P8JSObjectiPN2JS5ValueEE","__ZN2js17CastAsObjectJsvalEPFiP9JSContextP8JSObjectiPN2JS5ValueEE","__ZN13JSCompartment4wrapEP9JSContextPPFiS1_P8JSObjectiiPN2JS5ValueEE","__ZN2js17CastAsObjectJsvalEPFiP9JSContextP8JSObjectiiPN2JS5ValueEE","__ZN13JSCompartment4wrapEP9JSContextP20JSPropertyDescriptor","__ZN13JSCompartment4wrapEP9JSContextRN2js12AutoIdVectorE","__ZN13JSCompartment28markCrossCompartmentWrappersEP8JSTracer","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC1IS9_EERT_","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range8popFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD1Ev","__ZNK2js2gc12CellIterImpl4doneEv","__ZNK2js18ThreadContextRange5emptyEv","__ZNK2js2gc12CellIterImpl3getI8JSScriptEEPT_v","__ZNK2js2gc12CellIterImpl3getI8JSObjectEEPT_v","__ZNK2js2gc12CellIterImpl3getINS_5types10TypeObjectEEEPT_v","__ZN8JSScript13clearAnalysisEv","__ZN2js9DtoaCache5purgeEv","__ZN2js18ThreadContextRange8popFrontEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrptEv","__ZN13JSCompartment9markTypesEP8JSTracer","__ZN2js2gc15CellIterUnderGCC1EP13JSCompartmentNS0_9AllocKindE","__ZN2js2gc12CellIterImpl4nextEv","__ZN13JSCompartment5sweepEP9JSContextj","__ZNK2JS5Value9toGCThingEv","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4Enum11removeFrontEv","__ZN13JSCompartment16sweepBreakpointsEP9JSContext","__ZN2js13MoveArenaPoolEP11JSArenaPoolS1_","__ZN13JSCompartment5purgeEP9JSContext","__ZN2js2gc10ArenaLists5purgeEv","__ZN2js15NativeIterCache5purgeEv","__ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE20destroyIfConstructedEv","__ZN13JSCompartment14allocMathCacheEP9JSContext","__ZN9JSContext4new_IN2js9MathCacheEEEPT_v","__ZN13JSCompartment17hasScriptsOnStackEP9JSContext","__ZN13JSCompartment17setDebugModeFromCEP9JSContextb","__ZN13JSCompartment18updateForDebugModeEP9JSContext","__ZN2js18ThreadContextRangeC1EP9JSContext","__ZN13JSCompartment11addDebuggeeEP9JSContextPN2js12GlobalObjectE","__ZN13JSCompartment14removeDebuggeeEP9JSContextPN2js12GlobalObjectEPNS2_6detail9HashTableIKS4_NS2_7HashSetIS4_NS2_13DefaultHasherIS4_EENS2_17SystemAllocPolicyEE6SetOpsESB_E4EnumE","__ZN13JSCompartment17getBreakpointSiteEPh","__ZNK2js14BreakpointSite7hasTrapEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E10overloadedEv","__ZNK7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE5emptyEv","__ZNK2js2gc8FreeSpan7isEmptyEv","__ZN2js2gc8FreeSpan13encodeOffsetsEjj","__ZN7mozilla15AlignedStorage2IN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE4addrEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE7setLiveEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej","__ZN2js12HashMapEntryIPhjEC2Ev","__ZN3WTF20BumpPointerAllocatorC2Ev","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC2ES7_","__ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEEC2Ev","__ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_EC2ESA_","__ZN2js18ThreadContextRangeC2EP9JSContext","__ZN2js2gc8FreeSpan11initAsEmptyEj","__ZN13JSCompartment25getOrCreateBreakpointSiteEP9JSContextP8JSScriptPhP8JSObject","__ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS1_","__ZN9JSRuntime4new_IN2js14BreakpointSiteEP8JSScriptPhEEPT_T0_T1_","__ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S3_EENS7_13MapHashPolicyES6_E6AddPtrERKS1_RKS3_","__ZN13JSCompartment18clearBreakpointsInEP9JSContextPN2js8DebuggerEP8JSScriptP8JSObject","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumC1ISB_EERT_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumD1Ev","__ZN13JSCompartment10clearTrapsEP9JSContextP8JSScript","__ZN13JSCompartment27markTrapClosuresIterativelyEP8JSTracer","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumD2Ev","_js_free864","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumC2ISB_EERT_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrEPPS6_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrE","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E12lookupForAddERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6AddPtrC1ERNS0_14HashTableEntryIS6_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6AddPtrC2ERNS0_14HashTableEntryIS6_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEEC2Ev","__ZN2js12HashMapEntryIPhjEC1Ev","__ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE7destroyEv","__ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE3refEv","__ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev","__ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_ED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj","__ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE3asTEv","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC2IS9_EERT_","__ZNK2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3allEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC1EPNS0_14HashTableEntryIS5_EESF_","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC2EPNS0_14HashTableEntryIS5_EESF_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4initEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj","__ZN3WTF20BumpPointerAllocatorC1Ev","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4initEj","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11createTableERS7_j","__ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEC1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj","__ZN2js13WatchpointMapD1Ev","__ZN2js13WatchpointMapD2Ev","__ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED1Ev","__ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj","__ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEED2Ev","__ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC2ES4_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_","__ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEEC2ES4_","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC1ES7_","__ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_","__ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEEC2ES4_","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_","__ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEEC2ES6_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_EC1ESA_","__ZN2jsL12PodArrayZeroIP8JSObjectLj256EEEvRAT0__T_","__ZNK2js2gc8FreeSpan11arenaHeaderEv","__ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE","__ZNK2js2gc8FreeSpan15encodeAsOffsetsEv","__ZNK2js2gc8FreeSpan12arenaAddressEv","__ZNK9JSWrapper5flagsEv","__ZNK2js2gc8FreeSpan21arenaAddressUncheckedEv","_JSVAL_TO_GCTHING_IMPL","__ZNK2js2gc8FreeSpan7hasNextEv","__ZNK2js2gc8FreeSpan8nextSpanEv","__ZNK2js2gc11ArenaHeader7addressEv","_JSID_IS_STRING869","_JSID_TO_STRING870","_JSID_TO_INT872","_JSID_IS_OBJECT873","_JSID_TO_OBJECT874","_JSVAL_IS_TRACEABLE_IMPL","__ZN2js2gc5Chunk11fromAddressEj","__ZN2js2gc8FreeSpanC2Ejj","__ZN2js2gc5Arena16firstThingOffsetENS0_9AllocKindE","__ZNK2js2gc10ArenaLists13getFirstArenaENS0_9AllocKindE","__ZN2js18RuntimeAllocPolicyC2EP9JSRuntime","__ZN2js9DtoaCacheC2Ev","__ZN2js12PropertyTreeC2EP13JSCompartment","__ZN2js2gc10ArenaLists9ArenaList5clearEv","__ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv","__ZNK2js2gc11ArenaHeader12arenaAddressEv","__ZN2js2gc8FreeSpan13decodeOffsetsEjj","__ZN2js2gc8FreeSpanC1Ejj","__ZN2js2gc15CellIterUnderGCC2EP13JSCompartmentNS0_9AllocKindE","__ZN2js2gc12CellIterImpl4initEP13JSCompartmentNS0_9AllocKindE","__ZN2JSL17ObjectOrNullValueEP8JSObject866","__ZN2JSL10Int32ValueEi871","__ZN2JSL14UndefinedValueEv875","__ZN2js2gc10ArenaListsD2Ev","__ZNK2js2gc11ArenaHeader5chunkEv","__ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev","__ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev","__ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev","__ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj","__ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED1Ev","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED2Ev","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12destroyTableERS7_PNS0_14HashTableEntryIS4_EEj","__ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev","__ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_ED2Ev","__ZN2js15NativeIterCacheC2Ev","__ZN2js2gc10ArenaListsC2Ev","__ZN2js2gc10ArenaLists9ArenaListC1Ev","__ZN2js2gc10ArenaLists9ArenaListC2Ev","__ZN2js5crash5StackC2Ey","__ZN2js5crash10CrashStackC2Ey","__ZN2js5crash4RingC2Ey","__ZN2js5crash9CrashRingC2Ey","___cxx_global_var_init888","___cxx_global_var_init1889","___cxx_global_var_init2890","__ZN2js5crash11CrashHeaderC1Ey","__ZN2js5crash11CrashHeaderC2Ey","__GLOBAL__I_a891","__ZL12date_convertP9JSContextP8JSObject6JSTypePN2JS5ValueE","__ZL8date_UTCP9JSContextjPN2JS5ValueE","__ZL10date_parseP9JSContextjPN2JS5ValueE","__ZL8date_nowP9JSContextjPN2JS5ValueE","__ZL12date_getTimeP9JSContextjPN2JS5ValueE","__ZL22date_getTimezoneOffsetP9JSContextjPN2JS5ValueE","__ZL12date_getYearP9JSContextjPN2JS5ValueE","__ZL16date_getFullYearP9JSContextjPN2JS5ValueE","__ZL19date_getUTCFullYearP9JSContextjPN2JS5ValueE","__ZL13date_getMonthP9JSContextjPN2JS5ValueE","__ZL16date_getUTCMonthP9JSContextjPN2JS5ValueE","__ZL12date_getDateP9JSContextjPN2JS5ValueE","__ZL15date_getUTCDateP9JSContextjPN2JS5ValueE","__ZL11date_getDayP9JSContextjPN2JS5ValueE","__ZL14date_getUTCDayP9JSContextjPN2JS5ValueE","__ZL13date_getHoursP9JSContextjPN2JS5ValueE","__ZL16date_getUTCHoursP9JSContextjPN2JS5ValueE","__ZL15date_getMinutesP9JSContextjPN2JS5ValueE","__ZL18date_getUTCMinutesP9JSContextjPN2JS5ValueE","__ZL18JSDOUBLE_IS_FINITEd1004","__ZL18date_getUTCSecondsP9JSContextjPN2JS5ValueE","__ZL23date_getUTCMillisecondsP9JSContextjPN2JS5ValueE","__ZL12date_setTimeP9JSContextjPN2JS5ValueE","__ZL12date_setYearP9JSContextjPN2JS5ValueE","__ZL16date_setFullYearP9JSContextjPN2JS5ValueE","__ZL19date_setUTCFullYearP9JSContextjPN2JS5ValueE","__ZL13date_setMonthP9JSContextjPN2JS5ValueE","__ZL16date_setUTCMonthP9JSContextjPN2JS5ValueE","__ZL12date_setDateP9JSContextjPN2JS5ValueE","__ZL15date_setUTCDateP9JSContextjPN2JS5ValueE","__ZL13date_setHoursP9JSContextjPN2JS5ValueE","__ZL16date_setUTCHoursP9JSContextjPN2JS5ValueE","__ZL15date_setMinutesP9JSContextjPN2JS5ValueE","__ZL18date_setUTCMinutesP9JSContextjPN2JS5ValueE","__ZL15date_setSecondsP9JSContextjPN2JS5ValueE","__ZL18date_setUTCSecondsP9JSContextjPN2JS5ValueE","__ZL20date_setMillisecondsP9JSContextjPN2JS5ValueE","__ZL23date_setUTCMillisecondsP9JSContextjPN2JS5ValueE","__ZL16date_toGMTStringP9JSContextjPN2JS5ValueE","__ZL19date_toLocaleStringP9JSContextjPN2JS5ValueE","__ZL23date_toLocaleDateStringP9JSContextjPN2JS5ValueE","__ZL23date_toLocaleTimeStringP9JSContextjPN2JS5ValueE","__ZL19date_toLocaleFormatP9JSContextjPN2JS5ValueE","__ZL17date_toDateStringP9JSContextjPN2JS5ValueE","__ZL17date_toTimeStringP9JSContextjPN2JS5ValueE","__ZL16date_toISOStringP9JSContextjPN2JS5ValueE","__ZL11date_toJSONP9JSContextjPN2JS5ValueE","__ZL13date_toSourceP9JSContextjPN2JS5ValueE","__ZL13date_toStringP9JSContextjPN2JS5ValueE","__ZL12date_valueOfP9JSContextjPN2JS5ValueE","__Z7js_DateP9JSContextjPN2JS5ValueE","__ZN2jsL14IsConstructingEPKN2JS5ValueE1003","__ZL11date_formatP9JSContextd10formatspecPN2JS5ValueE","__ZL11NowAsMillisv","__ZL15JSDOUBLE_IS_NaNd1014","__ZL18js_DoubleToIntegerd1005","__ZL16date_parseStringP14JSLinearStringPdP9JSContext","__ZL17date_msecFromArgsP9JSContextjPN2JS5ValueEPd","__ZL3UTCdP9JSContext","__Z20js_NewDateObjectMsecP9JSContextd","__Z16js_InitDateClassP9JSContextP8JSObject","__ZL12SetDateToNaNP9JSContextP8JSObjectPN2JS5ValueE","__ZL12ATOM_TO_JSIDP6JSAtom1010","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE1011","__ZL10SetUTCTimeP9JSContextP8JSObjectdPN2JS5ValueE","__ZL17date_msecFromDateddddddd","__ZL10GetUTCTimeP9JSContextP8JSObjectPN2JS5ValueEPd","__Z14js_DateGetYearP9JSContextP8JSObject","__ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd","__ZL12YearFromTimed","__ZL13MonthFromTimed","__ZL14JSID_FROM_BITSj1046","__ZL10IsLeapYeari","__ZN2js2gcL15GetGCObjectKindEjb1026","__ZL12DateFromTimed","__ZL12HourFromTimed","__ZL11MinFromTimed","__ZL11SecFromTimed","__Z24js_DateGetMsecSinceEpochP9JSContextP8JSObject","__Z14js_IntervalNowv","__ZL14DaysInFebruaryi","__ZL10DaysInYeari","__ZL14FillLocalTimesP9JSContextP8JSObject","__ZNK8JSObject14getDateUTCTimeEv","__ZN2JSL11DoubleValueEd1017","__ZL9LocalTimedP9JSContext","__ZN2JSL10Int32ValueEi1018","__ZL7WeekDayd","__ZL10AdjustTimedP9JSContext","__ZL16DaylightSavingTAdP9JSContext","__ZL20EquivalentYearForDSTi","__ZL7MakeDayddd","__ZL13TimeWithinDayd","__ZN2JSL14UndefinedValueEv1024","__ZN8JSObject14setDateUTCTimeERKN2JS5ValueE","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1027","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1028","__ZN2JSL11ObjectValueER8JSObject1038","__ZNK16JSAutoByteStringntEv","__ZN2js7unicode8CharInfoEt","__ZL10fractionalPdPKtPjj","__ZL6digitsPjPKtS_j","__ZL19date_parseISOStringP14JSLinearStringPdP9JSContext","__ZL18date_regionMatchesPKciPKtiii","__ZN2js7unicode11ToLowerCaseEt","__ZL7ndigitsjPjPKtS_j","__ZL11DaysInMonthii","__ZL11new_explodedP8PRMJTimeP9JSContext","__ZL10msFromTimed","__ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd","__ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE","__ZL13js_IsCallableRKN2JS5ValueE1052","__ZN8JSObject12defaultValueEP9JSContext6JSTypePN2JS5ValueE","__ZL15date_utc_formatP9JSContextPN2JS5ValueEPFvPcjdE","__ZL16print_iso_stringPcjd","__ZN16JSAutoByteStringC1EP9JSContextP8JSString","__ZL19date_toLocaleHelperP9JSContextP8JSObjectPKcPN2JS5ValueE","__ZN16JSAutoByteStringC2EP9JSContextP8JSString","__ZL16print_gmt_stringPcjd","_JSID_IS_INT1059","__ZN2jsL8JsvalifyEPNS_10StackFrameE","_JS_SetRuntimeDebugMode","__ZN2js10StackFrame11setHookDataEPv","__ZN2js11GetGSNCacheEP9JSContext","__ZN2js15AutoValueRooter3setEN2JS5ValueE","__ZL13date_makeTimeP9JSContextjijPN2JS5ValueE","__ZL13date_makeDateP9JSContextjijPN2JS5ValueE","_JS_GetDebugMode","_JS_SetDebugMode","_JS_SetDebugModeForCompartment","__ZN2js19ScriptDebugPrologueEP9JSContextPNS_10StackFrameE","__ZN2js8Debugger12onEnterFrameEP9JSContext","__ZN2js19ScriptDebugEpilogueEP9JSContextPNS_10StackFrameEb","__ZNK2js10StackFrame13maybeHookDataEv","__ZN2js8Debugger12onLeaveFrameEP9JSContext","__ZL14CheckDebugModeP9JSContext","_js_UntrapScriptCode","_JS_SetTrap","_JS_GetTrapOpcode","_JS_ClearTrap","_JS_ClearScriptTraps","_JS_SetWatchPoint","__ZN2jsL9IdToValueEi1060","__ZN9JSRuntime4new_IN2js13WatchpointMapEEEPT_v","_JS_ClearWatchPoint","_JS_ClearAllWatchPoints","__ZNK10JSFunction6nativeEv","_JS_DHashFinalizeStub","__ZNK2js5Shape8writableEv","__ZNK2js5Shape12configurableEv","__ZNK2js5Shape5Range5emptyEv","__ZNK2js8Bindings15countLocalNamesEv","_JSID_IS_STRING1077","_JSID_TO_STRING1080","_JSID_TO_INT1082","_JSID_IS_OBJECT1083","_JSID_TO_OBJECT1085","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5emptyEv","__ZNK2js10StackFrame11hasHookDataEv","_JS_DHashVoidPtrKeyStub","_JS_SetDebuggerHandler","_JS_SetThrowHook","__ZN8JSScript7regexpsEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_","__ZN2js10StackFrame15markReturnValueEv","_JS_DHashMatchEntryStub","_JS_PCToLineNumber","_JS_LineNumberToPC","__ZNK2js8Bindings13hasLocalNamesEv","__ZNK10JSFunction11maybeScriptEv","__ZNK10JSFunction11maybeNativeEv","_JS_GetFrameScript","_JS_GetFramePC","_JS_GetScriptedCaller","_JS_GetFrameScopeChain","_JS_GetFrameCallObject","__ZNK2js10StackFrame8maybeFunEv","__ZN2js10StackFrame11returnValueEv","__ZN2js10StackFrame14setReturnValueERKN2JS5ValueE","_JS_EvaluateUCInStackFrame","_JS_GetPropertyDesc","__ZN2jsL9IdToJsvalEi1067","__ZN2JSL14UndefinedValueEv1068","__ZNK2js5Shape3allEv","_JS_GetPropertyDescArray","__ZNK8JSObject13propertyCountEv","_JS_PutPropertyDescArray","_js_RevertVersion","_JS_DumpCompartmentBytecode","__ZN2js13WatchpointMapC1Ev","__ZN2js13WatchpointMapC2Ev","__ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC1ES5_","__ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_","__ZNK8JSObject10structSizeEv","__ZNK2js5Shape10entryCountEv","__ZN2JSL11StringValueEP8JSString1079","__ZN2JSL10Int32ValueEi1081","__ZN2JSL11ObjectValueER8JSObject1084","__ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE5emptyEv","_JS_DHashAllocTable","_JS_DHashFreeTable","_JS_DHashMoveEntryStub","_JS_DHashClearEntryStub","_JS_NewDHashTable","_JS_DHashTableInit","_JS_DHashTableDestroy","_JS_DHashTableFinish","__ZL13FindFreeEntryP12JSDHashTablej","_JS_DHashTableOperate","__ZL11SearchTableP12JSDHashTablePKvj15JSDHashOperator","__ZL11ChangeTableP12JSDHashTablei","_JS_DHashTableRawRemove","_js_strtod_harder","__strtod","_js_dtostr","_dtoa","__ZL6divremP6Bigintj","__ZL7quorem2P6Biginti","_cmp","_freedtoa","_js_dtobasestr","_d2b","_lshift","_Bfree","_i2b","_multadd","_diff","_js_NewDtoaState","_newdtoa","_js_DestroyDtoaState","_destroydtoa","__Z9dtoa_freePv","__Z11dtoa_mallocj","_lo0bits","_hi0bits","_ulp","_Balloc","_nrv_alloc","_rv_alloc","_pow5mult","_mult","_quorem","_s2b","_ratio","_b2d","__ZN13JSTreeContext5traceEP8JSTracer","__ZN15JSCodeGeneratorC2EPN2js6ParserEj","__ZN13JSTreeContextC2EPN2js6ParserE","__ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEEC1EP9JSContext","__ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES7_","__ZN13JSGCConstListC1EP9JSContext","__ZN14JSCGObjectListC1Ev","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEEC1ES2_","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEEC1ES3_","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEC1ES1_","__ZN15JSCodeGenerator4initEP9JSContextN13JSTreeContext12InitBehaviorE","__ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE4initEv","__ZN13JSTreeContext4initEP9JSContextNS_12InitBehaviorE","__ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj","__ZNK2js8Bindings9countVarsEv","__ZNK13JSTreeContext10inFunctionEv","__ZL10GetSpanDepP15JSCodeGeneratorPh","__ZN13JSTreeContext11inStatementE10JSStmtType","__ZN13JSTreeContext7blockidEv","__ZN13JSTreeContext10blockChainEv","_js_PopStatement","__ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE9ensureMapEP9JSContext","__ZN15JSCodeGeneratorD2Ev","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEED1Ev","__ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEED1Ev","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEED1Ev","__ZN13JSGCConstListD1Ev","__ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev","__ZN13JSTreeContextD2Ev","_js_Emit1","__ZL9EmitCheckP9JSContextP15JSCodeGeneratori","__ZL11UpdateDepthP9JSContextP15JSCodeGeneratori","_js_Emit2","_js_Emit3","_js_Emit5","_js_EmitN","_js_SetJumpOffset","__ZL17BuildSpanDepTableP9JSContextP15JSCodeGenerator","__ZL16SetSpanDepTargetP9JSContextP15JSCodeGeneratorP9JSSpanDepi","__ZN13JSTreeContext16ensureSharpSlotsEv","__ZN2js8Bindings11addVariableEP9JSContextP6JSAtom","_js_PushStatement","_js_PushBlockScope","_js_PopStatementCG","__ZL9BackPatchP9JSContextP15JSCodeGeneratoriPhh","_js_DefineCompileTimeConstant","__ZNK11JSParseNode6isKindEN2js9TokenKindE","__ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3putERKS2_RKS4_","__ZN2JSL11NumberValueEd1149","__ZN15JSCodeGenerator7contextEv","__ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv","__ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE6lengthEv","__ZNK13JSTreeContext9callsEvalEv","__ZNK11JSParseNode6isDefnEv","__ZN2js11UpvarCookie3setEtt","_js_LexicalLookup","__ZL12ATOM_TO_JSIDP6JSAtom1150","__ZN15JSCodeGenerator20shouldNoteClosedNameEP11JSParseNode","__ZNK11JSParseNode8isClosedEv","__ZN15JSCodeGenerator12addGlobalUseEP6JSAtomjPN2js11UpvarCookieE","__ZN2js9InlineMapIP6JSAtomjLj24EE12lookupForAddERKS2_","__ZNK2js9InlineMapIP6JSAtomjLj24EE6AddPtrcvPPPPPPPS4_Ev","__ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtr5valueEv","__ZN2js11UpvarCookie8makeFreeEv","__ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE6appendIS2_EEbT_","__ZN2js9InlineMapIP6JSAtomjLj24EE3addERNS3_6AddPtrERKS2_RKj","_js_EmitFunctionScript","__ZNK13JSTreeContext19needsEagerArgumentsEv","_js_EmitTree","_INT_TO_JSID1151","_INT_FITS_IN_JSID","__ZNK2js11UpvarCookie6isFreeEv","__ZNK2js11UpvarCookie4slotEv","__ZNK11JSParseNode4lastEv","__ZNK11JSParseNode7getKindEv","__ZNK11JSParseNode5getOpEv","__ZNK13JSFunctionBox8functionEv","__ZN13JSTreeContext11setFunctionEP10JSFunction","__ZN14JSCGObjectList5indexEP11JSObjectBox","__ZN11JSParseNode16getConstantValueEP9JSContextbPN2JS5ValueE","__ZN2js5types12FixArrayTypeEP9JSContextP8JSObject","__ZN2jsL17GuessObjectGCKindEjb1152","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1153","__Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPi","__ZN2js5types13FixObjectTypeEP9JSContextP8JSObject","__ZN16EmitLevelManagerC1EP15JSCodeGenerator","_js_NewSrcNote2","_js_NewSrcNote","__ZNK11JSParseNode7isArityE16JSParseNodeArity","__ZL18EmitFunctionDefNopP9JSContextP15JSCodeGeneratorj","__ZN9JSContext4new_I15JSCodeGeneratorPN2js6ParserEjEEPT_T0_T1_","__ZN2js8Bindings8transferEP9JSContextPS0_","__ZN9JSContext7delete_I15JSCodeGeneratorEEvPT_","__ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_","__ZL14EmitBlockChainP9JSContextP15JSCodeGenerator","__ZL10BindGlobalP9JSContextP15JSCodeGeneratorP11JSParseNodeP6JSAtom","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE6appendItEEbT_","__ZL15EmitSlotIndexOpP9JSContext4JSOpjjP15JSCodeGenerator","__ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE8clearMapEv","__ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode","__ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE10releaseMapEP9JSContext","_js_SetSrcNoteOffset","__ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi","__ZL8EmitGotoP9JSContextP15JSCodeGeneratorP10JSStmtInfoPij13JSSrcNoteType","__ZL10EmitSwitchP9JSContextP15JSCodeGeneratorP11JSParseNodeP10JSStmtInfo","__ZL11EmitTraceOpP9JSContextP15JSCodeGeneratorP11JSParseNode","__ZN12TempPopScopeC1Ev","__ZNK2js11UpvarCookie9asIntegerEv","__ZN2jsL15TokenKindIsDeclENS_9TokenKindE","__ZNK11JSParseNode4exprEv","__ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp","__ZN12TempPopScope8popBlockEP9JSContextP15JSCodeGenerator","__ZN12TempPopScope11repushBlockEP9JSContextP15JSCodeGenerator","__ZL14EmitAssignmentP9JSContextP15JSCodeGeneratorP11JSParseNode4JSOpS4_","__ZNK11JSParseNode4isOpE4JSOp","__ZL24MaybeEmitGroupAssignmentP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodePS3_","__ZL10NewTryNoteP9JSContextP15JSCodeGenerator13JSTryNoteKindjjj","__ZL15EmitBackPatchOpP9JSContextP15JSCodeGenerator4JSOpPi","__ZL19EmitKnownBlockChainP9JSContextP15JSCodeGeneratorP11JSObjectBox","__ZL14EmitLeaveBlockP9JSContextP15JSCodeGenerator4JSOpP11JSObjectBox","__ZL21UpdateLineNumberNotesP9JSContextP15JSCodeGeneratorj","__ZL20EmitDestructuringOpsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode","__ZNK11JSParseNode25isDirectivePrologueMemberEv","__ZN11JSParseNode5setOpE4JSOp","__ZL13EmitVariablesP9JSContextP15JSCodeGeneratorP11JSParseNodeiPi","__ZL21EmitNonLocalJumpFixupP9JSContextP15JSCodeGeneratorP10JSStmtInfo","__ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi","__ZL17SetBackPatchDeltaP9JSContextP15JSCodeGeneratorPhi","__ZL13GetJumpOffsetP15JSCodeGeneratorPh","__ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_","__ZL11EmitXMLNameP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator","__ZL14EmitNameIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator","__ZNK11JSParseNode7isConstEv","__ZL14EmitPropIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator","__ZL14EmitElemIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator","__ZL10EmitPropOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratoriPS3_","__ZL10EmitElemOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator","__ZL10EmitNameOpP9JSContextP15JSCodeGeneratorP11JSParseNodei","__ZNK15JSCodeGenerator9hasSharpsEv","__ZNK13JSTreeContext12compileAndGoEv","__ZL19FitsWithoutBigIndexj","__ZL14EmitEnterBlockP9JSContextP11JSParseNodeP15JSCodeGenerator","__ZL15AdjustBlockSlotP9JSContextP15JSCodeGeneratori","__ZL11EmitNewInitP9JSContextP15JSCodeGenerator10JSProtoKeyP11JSParseNodei","__ZL11EmitEndInitP9JSContextP15JSCodeGeneratorj","__ZN15JSCodeGenerator21checkSingletonContextEv","__ZL24EmitSingletonInitialiserP9JSContextP15JSCodeGeneratorP11JSParseNode","__ZL12EmitNumberOpP9JSContextdP15JSCodeGenerator","__ZN2JSL14UndefinedValueEv1154","__ZNK8JSObject16inDictionaryModeEv","__ZL12EmitObjectOpP9JSContextP11JSObjectBox4JSOpP15JSCodeGenerator","_js_SrcNoteLength","_js_GetSrcNoteOffset","__ZL16OptimizeSpanDepsP9JSContextP15JSCodeGenerator","__ZN16EmitLevelManagerD1Ev","__ZL12AllocSrcNoteP9JSContextP15JSCodeGenerator","_js_NewSrcNote3","_js_AddToSrcNoteDelta","__ZL12GrowSrcNotesP9JSContextP15JSCodeGenerator","__ZL23ReportStatementTooLargeP9JSContextP15JSCodeGenerator","__ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE5beginEv","__ZN9JSContext12parseMapPoolEv","__ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js7MoveRefINS_15GlobalSlotArray5EntryEEcvRS2_Ev","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE10getKeyHashEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEptEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10overloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE6isFreeEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj","__ZN14JSCGObjectList6finishEP13JSObjectArray","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE3endEv","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js10VectorImplIjLj8ENS_15TempAllocPolicyELb1EE13copyConstructIjEEvPjPKT_S7_","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js7MoveRefINS_15GlobalSlotArray5EntryEEC2ERS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrptEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE7setLiveEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE14unsetCollisionEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEC2ERS9_","_js_FinishTakingSrcNotes","_js_FinishTakingTryNotes","__ZN13JSGCConstList6finishEP12JSConstArray","__ZN2js12ParseMapPool7releaseEPNS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEE","__ZN2js12ParseMapPool7recycleEPv","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE14internalAppendItEEvT_","__ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIjLj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIjLj8ES1_EEj","__ZN2js10VectorImplIjLj8ENS_15TempAllocPolicyELb1EE13moveConstructIjEEvPjPKT_S7_","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_","__ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj16ES3_EEj","__ZN2js4MoveINS_15GlobalSlotArray5EntryEEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefINS_15GlobalSlotArray5EntryEEC1ERS2_","__ZN2js10VectorImplINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js4MoveINS_15GlobalSlotArray5EntryEEENS_7MoveRefIT_EERKS4_","__ZNK2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv","__ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE6isLiveEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEaSENS_7MoveRefIS8_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEENS_7MoveRefIT_EERSB_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEC1ERS9_","__ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEptEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv","__ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE10getKeyHashEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEptEv","__ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomjEEEptEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE10isLiveHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE9matchHashEj","__ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE5emptyEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10overloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isFreeEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj","__ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC2ERS6_","__ZN2js12HashMapEntryIP6JSAtomN2JS5ValueEEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE12setCollisionEj","__ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE","__ZN2js9InlineMapIP6JSAtomjLj24EE5clearEv","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE7popBackEv","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_EC2ESB_","__ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE8clearMapEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE7setLiveEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE14unsetCollisionEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEC2ERS7_","__ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomjEEEC2ERS4_","__ZN2js12HashMapEntryIP6JSAtomjEC2Ev","__ZN2js12HashMapEntryIP6JSAtomN2JS5ValueEEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEENS_7MoveRefIT_EERS8_","__ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC1ERS6_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC2Ev","__ZN2js12HashMapEntryIP6JSAtomN2JS5ValueEEC1Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj","__ZN2js12ParseMapPool7acquireINS_9InlineMapIP6JSAtomjLj24EEEEEPT_v","__ZN2js12ParseMapPool8allocateEv","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE7popCopyEv","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE4backEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E4initEj","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEED2Ev","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEED2Ev","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEED2Ev","__ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEED2Ev","__ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE10releaseMapEP9JSContext","__ZN2js12ParseMapPool7releaseEPNS_9InlineMapIP6JSAtomjLj24EEE","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEC2ES1_","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEEC2ES3_","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEEC2ES2_","__ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES7_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_EC1ESB_","__ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEEC2EP9JSContext","__ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE4initEv","__ZN2js9InlineMapIP6JSAtomjLj24EE12switchAndAddERKS2_RKj","__ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEaSENS_7MoveRefIS6_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEENS_7MoveRefIT_EERS9_","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEC1ERS7_","__ZN2js12HashMapEntryIP6JSAtomjEaSENS_7MoveRefIS3_EE","__ZN2js4MoveINS_12HashMapEntryIP6JSAtomjEEEENS_7MoveRefIT_EERS6_","__ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomjEEEC1ERS4_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEC2Ev","__ZN2js12HashMapEntryIP6JSAtomjEC1Ev","__ZN2js9InlineMapIP6JSAtomjLj24EE11switchToMapEv","__ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKj","__ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5countEv","__ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE6lengthEv","__ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE9matchHashEj","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11initializedEv","__ZNK2js5Shape12inDictionaryEv","__ZNK13JSTreeContext12inStrictModeEv","__ZNK13JSTreeContext16mutatesParameterEv","_JSDOUBLE_IS_NEGZERO1166","__ZN11JSParseNode7setKindEN2js9TokenKindE","__ZN11JSParseNode8setArityE16JSParseNodeArity","__ZNK11JSParseNode8getArityEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE12setCollisionEj","__ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_jEE","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrptEv","__ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC2EPNS3_10InlineElemEb","__ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC2ERKNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E6AddPtrE","__ZL13StatementNameP15JSCodeGenerator","__ZN16EmitLevelManagerD2Ev","__ZL18FindNearestSpanDepP15JSCodeGeneratoriiP9JSSpanDep","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZL21UpdateDecomposeLengthP15JSCodeGeneratorj","__ZNK11JSParseNode4testEj","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj","__ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE11initializedEv","__ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv","__ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj","__ZN2js9InlineMapIP6JSAtomjLj24EE5countEv","__ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E4initEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5clearEv","__ZNK2js9InlineMapIP6JSAtomjLj24EE6AddPtr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv","__ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC1ERKNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E6AddPtrE","__ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC1EPNS3_10InlineElemEb","__ZL17UpdateJumpTargetsP12JSJumpTargetii","__ZL15FreeJumpTargetsP15JSCodeGeneratorP12JSJumpTarget","_JSDOUBLE_IS_INT321163","__ZN13JSGCConstList6appendEN2JS5ValueE","__ZN2JSL11DoubleValueEd1164","__ZNK13JSGCConstList6lengthEv","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_","__ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIN2JS5ValueELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj0ES3_EEj","__ZN2js10VectorImplIN2JS5ValueELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN13JSTreeContext16needStrictChecksEv","__ZNK11JSParseNode9frameSlotEv","__ZN2JSL12BooleanValueEb1168","__ZN8JSObject16setBlockOwnShapeEP9JSContext","__ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp","__ZN11JSParseNode9maybeExprEv","__ZL17EmitSpecialPropOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator","__ZL9FlushPopsP9JSContextP15JSCodeGeneratorPi","__ZL22EmitDestructuringDeclsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode","__ZL12OpToDeclType4JSOp","__ZNK2js5Shape16hasDefaultGetterEv","__ZN13JSTreeContext15asCodeGeneratorEv","__ZNK11JSParseNode6isUsedEv","__ZN12TempPopScopeC2Ev","__ZNK13JSTreeContext10scopeChainEv","__ZL16MaybeEmitVarDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodePj","__ZL21EmitDestructuringDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode","__ZL26EmitDestructuringOpsHelperP9JSContextP15JSCodeGeneratorP11JSParseNode","__ZL20EmitDestructuringLHSP9JSContextP15JSCodeGeneratorP11JSParseNode","__ZNK11JSParseNode13isInitializedEv","__ZL18EmitBigIndexPrefixP9JSContextP15JSCodeGeneratorj","__ZL19EmitGroupAssignmentP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodeS5_","__ZL25LookupCompileTimeConstantP9JSContextP15JSCodeGeneratorP6JSAtomPN2JS5ValueE","__ZL22AllocateSwitchConstantP9JSContext","__ZL17AddSwitchSpanDepsP9JSContextP15JSCodeGeneratorPh","__ZL10AddSpanDepP9JSContextP15JSCodeGeneratorPhS3_i","__ZNK2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_","__ZNK2js8Bindings10hasBindingEP9JSContextP6JSAtom","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE","__ZNK11JSParseNode13isDeoptimizedEv","__ZN12JSDefinition4kindEv","__ZNK11JSParseNode10isTopLevelEv","__ZNK12JSDefinition8isGlobalEv","__ZNK13JSTreeContext3funEv","__ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv","__ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE5beginEv","__ZNK2js7MoveRefINS_11UpvarCookieEEcvRS1_Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5countEv","__ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE5beginEv","__ZL14JSID_FROM_BITSj1189","__ZNK2js11TokenStream11getFilenameEv","__ZNK13JSTreeContext16mightAliasLocalsEv","__ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE5emptyEv","__ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE8usingMapEv","__ZNK13JSTreeContext13usesArgumentsEv","__ZN13JSTreeContext8compilerEv","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE11allocPolicyEv","__ZN2js7MoveRefINS_11UpvarCookieEEC2ERS1_","__ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC2EPNS3_10InlineElemE","__ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC2ENS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E3PtrE","__ZN16EmitLevelManagerC2EP15JSCodeGenerator","__ZN2js2gcL15GetGCObjectKindEjb1183","__ZL18BalanceJumpTargetsPP12JSJumpTarget","__ZL17TryConvertToGnameP15JSCodeGeneratorP11JSParseNodeP4JSOp","__ZN2js8Bindings8addUpvarEP9JSContextP6JSAtom","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5countEv","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE19growByUninitializedEj","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE16replaceRawBufferEPS1_j","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEEixEj","__ZN2js10VectorImplINS_11UpvarCookieELj8ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_","__ZN2js4MoveINS_11UpvarCookieEEENS_7MoveRefIT_EERKS3_","__ZN2js7MoveRefINS_11UpvarCookieEEC1ERS1_","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplINS_11UpvarCookieELj8ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj8ES2_EEj","__ZN2js4MoveINS_11UpvarCookieEEENS_7MoveRefIT_EERS3_","__ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv","__ZNK11JSParseNode5isLetEv","__ZL15BindKnownGlobalP9JSContextP15JSCodeGeneratorP11JSParseNodeS4_P6JSAtom","__ZN2js9InlineMapIP6JSAtomjLj24EE6lookupERKS2_","__ZN2js9InlineMapIP6JSAtomjLj24EE3Ptr5valueEv","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEEixEj","__ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC1ENS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E3PtrE","__ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_","__ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC1EPNS3_10InlineElemE","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS5_EE","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1177","__ZL13AddJumpTargetP17AddJumpTargetArgsPP12JSJumpTarget","_js_GetStackUses","__ZN2JSL10Int32ValueEi1190","__ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEED1Ev","__ZN2js9AtomDeclsD1Ev","__ZN2js9AtomDeclsD2Ev","__ZN2js12ParseMapPool7releaseEPNS_9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EEE","__ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEED2Ev","__ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_ED2Ev","__ZNK8JSObject7isErrorEv","__ZN14JSCGObjectListC2Ev","__ZN2js9AtomDeclsC2EP9JSContext","__ZN13JSGCConstListD2Ev","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEED2Ev","__ZN2js9AtomDecls4initEv","__ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE9ensureMapEP9JSContext","__ZN2js12ParseMapPool7acquireINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEEPT_v","__ZN2js12ParseMapPool7acquireINS_9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EEEEEPT_v","__ZN13JSGCConstListC2EP9JSContext","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEEC1ES3_","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEEC2ES3_","__ZN2js9AtomDeclsC1EP9JSContext","__ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEEC1EP9JSContext","__ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEEC2EP9JSContext","__ZL11exn_resolveP9JSContextP8JSObjectijPS2_","__ZL12exn_finalizeP9JSContextP8JSObject","__ZL9exn_traceP8JSTracerP8JSObject","__Z21js_ErrorFromExceptionP9JSContextN2JS5ValueE","_JSVAL_IS_PRIMITIVE","_JSVAL_TO_OBJECT1203","__ZL13GetExnPrivateP8JSObject","__ZL12exn_toSourceP9JSContextjPN2JS5ValueE","__ZL12exn_toStringP9JSContextjPN2JS5ValueE","__Z23js_InitExceptionClassesP9JSContextP8JSObject","__ZL14InitErrorClassP9JSContextPN2js12GlobalObjectEiR8JSObject","__Z27js_GetLocalizedErrorMessageP9JSContextPvPKcj","__ZL20GetExceptionProtoKeyi","__Z19js_ErrorToExceptionP9JSContextPKcP13JSErrorReportPFPK19JSErrorFormatStringPvS2_jES8_","__ZN2jsL12PodArrayZeroIN2JS5ValueELj4EEEvRAT0__T_","_OBJECT_TO_JSVAL1210","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_","_STRING_TO_JSVAL1211","__ZL14InitExnPrivateP9JSContextP8JSObjectP8JSStringS4_jP13JSErrorReporti","__Z26js_ReportUncaughtExceptionP9JSContext","__ZN2jsL12PodArrayZeroIN2JS5ValueELj5EEEvRAT0__T_","_JSVAL_IS_STRING","__ZN16JSAutoByteString5clearEv","__ZN2jsL7PodZeroI13JSErrorReportEEvPT_1214","_JSVAL_TO_STRING","__Z18js_CopyErrorObjectP9JSContextP8JSObjectS2_","__ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE6lengthEv","__ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE5beginEv","__ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js7MoveRefI16JSStackTraceElemEcvRS1_Ev","__ZL14JSID_FROM_BITSj1226","_JSVAL_TO_STRING_IMPL1217","_JSVAL_IS_STRING_IMPL1221","_JSVAL_TO_OBJECT_IMPL1225","__ZL13JSVAL_TO_IMPLN2JS5ValueE1218","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN9AppendArgC2ERN2js6VectorIN2JS5ValueELj0ENS0_15TempAllocPolicyEEE","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE3endEv","__ZN2js7MoveRefI16JSStackTraceElemEC2ERS1_","__ZL13IMPL_TO_JSVAL12jsval_layout1228","_STRING_TO_JSVAL_IMPL1229","__ZN2js2gcL15GetGCObjectKindEjb1230","_OBJECT_TO_JSVAL_IMPL1238","__ZL15CopyErrorReportP9JSContextP13JSErrorReport","__ZZ18js_CopyErrorObjectP9JSContextP8JSObjectS2_EN8AutoFreeD2Ev","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEEC1ES2_","__ZN19SuppressErrorsGuardC1EP9JSContext","__ZNK2js10StackFrame11compartmentEv","__ZN2JSL9NullValueEv1222","__ZL12ATOM_TO_JSIDP6JSAtom1223","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE6growByEj","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE4backEv","__ZN2js10StackFrame25forEachCanonicalActualArgI9AppendArgEEbT_jj","__ZN9AppendArgC1ERN2js6VectorIN2JS5ValueELj0ENS0_15TempAllocPolicyEEE","__ZN19SuppressErrorsGuardD1Ev","__ZN2jsL7PodCopyI16JSStackTraceElemEEvPT_PKS2_j","__ZN2jsL7PodCopyIN2JS5ValueEEEvPT_PKS3_j1224","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEED2Ev","__ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN19SuppressErrorsGuardD2Ev","__ZN9AppendArgclEjPN2JS5ValueE","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE10growByImplILb1EEEbj","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js10VectorImplI16JSStackTraceElemLj0ENS_15TempAllocPolicyELb0EE10initializeEPS1_S4_","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplI16JSStackTraceElemLj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj0ES2_EEj","__ZN2js4MoveI16JSStackTraceElemEENS_7MoveRefIT_EERS3_","__ZN2js7MoveRefI16JSStackTraceElemEC1ERS1_","__ZN2js10VectorImplI16JSStackTraceElemLj0ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_","__ZN2js4MoveI16JSStackTraceElemEENS_7MoveRefIT_EERKS3_","__ZN19SuppressErrorsGuardC2EP9JSContext","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEEC2ES2_","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1231","__ZN2JSL11StringValueEP8JSString1239","__ZN2JSL10Int32ValueEi1240","_JSID_IS_STRING1247","_JSVAL_IS_PRIMITIVE_IMPL1252","_JSID_TO_STRING1254","_JSVAL_TO_GCTHING_IMPL1256","_JSVAL_IS_TRACEABLE_IMPL1257","__ZNK2js10StackFrame17hasOverriddenArgsEv","_INT32_TO_JSVAL_IMPL1251","__ZL24GetStackTraceValueBufferP12JSExnPrivate","__ZL9ExceptionP9JSContextjPN2JS5ValueE","__ZL16FilenameToStringP9JSContextPKc","__ZL12JSID_IS_ATOMi1253","_INT_TO_JSVAL","__ZL18StackTraceToStringP9JSContextP12JSExnPrivate","__ZL18ValueToShortSourceP9JSContextRKN2JS5ValueE","_JSVAL_IS_TRACEABLE","_JSVAL_TO_GCTHING","_JSVAL_TRACE_KIND","_JSVAL_TRACE_KIND_IMPL","__ZNK8JSObject13hasSlotsArrayEv","__ZNK8JSObject15numDynamicSlotsEj","__Z15js_GetArgsValueP9JSContextPN2js10StackFrameEPN2JS5ValueE","__Z16js_GetArgsObjectP9JSContextPN2js10StackFrameE","_JSID_IS_INT1285","_JSID_TO_INT1286","__ZNK2js10StackFrame16isEvalInFunctionEv","__ZN2js10StackFrame10setArgsObjERNS_15ArgumentsObjectE","__ZN2jsL20CallObjectLambdaNameEP10JSFunction","__ZN2js10StackFrame27setScopeChainWithOwnCallObjERNS_10CallObjectE","__Z18js_GetArgsPropertyP9JSContextPN2js10StackFrameEiPN2JS5ValueE","__ZNK2js10StackFrame12maybeArgsObjEv","__ZNK2js10StackFrame14functionScriptEv","__ZL12JSID_IS_ATOMiP6JSAtom1287","__ZN2js15ArgumentsObject6createEP9JSContextjR8JSObject","__ZN2js10EmptyShape22getEmptyArgumentsShapeEP9JSContext","__ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueEj1288","__ZN2js15ArgumentsObject16setInitialLengthEj","__ZN2js15ArgumentsObject16setCalleeAndDataER8JSObjectPNS_13ArgumentsDataE","__ZN2js10StackFrame25forEachCanonicalActualArgI6PutArgEEbT_jj","__ZN6PutArgC1EPN2JS5ValueE","__Z16js_PutArgsObjectPN2js10StackFrameE","__ZL16args_delPropertyP9JSContextP8JSObjectiPN2JS5ValueE","__ZL14args_enumerateP9JSContextP8JSObject","__ZL12args_resolveP9JSContextP8JSObjectijPS2_","__ZL13args_finalizeP9JSContextP8JSObject","__ZL10args_traceP8JSTracerP8JSObject","__ZL20strictargs_enumerateP9JSContextP8JSObject","__ZL18strictargs_resolveP9JSContextP8JSObjectijPS2_","__ZN2js19CreateFunCallObjectEP9JSContextPNS_10StackFrameE","__ZL16NewDeclEnvObjectP9JSContextPN2js10StackFrameE","__ZL12ATOM_TO_JSIDP6JSAtom1293","__ZN2JSL11ObjectValueER8JSObject1294","__ZN2js10CallObject13setStackFrameEPNS_10StackFrameE","__ZN2js20CreateEvalCallObjectEP9JSContextPNS_10StackFrameE","__ZNK2js8Bindings9countArgsEv","__ZeqRK8JSObjectS1_","__ZN8JSObject16hasMethodBarrierEv","__ZNK2js5Shape7hasSlotEv","__ZN10JSFunction14compiledFunObjEv","__Z16js_PutCallObjectPN2js10StackFrameE","__ZN2js10CallObject12setArgumentsERKN2JS5ValueE","__ZNK2js10CallObject9isForEvalEv","__ZN2js10CallObject10copyValuesEjPN2JS5ValueEjS3_","__ZN2js10CallObject6setArgEjRKN2JS5ValueE","__ZN2js10CallObject6setVarEjRKN2JS5ValueE","__ZN2js10CallObject8argArrayEv","__ZN2js10CallObject8varArrayEv","__ZN2js10GetCallArgEP9JSContextP8JSObjectiPN2JS5ValueE","__ZNK2js10CallObject15maybeStackFrameEv","__ZNK2js10CallObject3argEj","__ZN2js10SetCallArgEP9JSContextP8JSObjectiiPN2JS5ValueE","__ZNK2js10CallObject17getCalleeFunctionEv","__ZN8JSScript14ensureHasTypesEP9JSContextP10JSFunction","__ZN2js5types10TypeScript11SetArgumentEP9JSContextP8JSScriptjRKN2JS5ValueE","__ZN2js12GetCallUpvarEP9JSContextP8JSObjectiPN2JS5ValueE","__ZNK2js10CallObject9getCalleeEv","__ZN8JSObject19getFlatClosureUpvarEj","__ZN2js12SetCallUpvarEP9JSContextP8JSObjectiiPN2JS5ValueE","__ZN8JSObject19setFlatClosureUpvarEjRKN2JS5ValueE","__ZN2js10GetCallVarEP9JSContextP8JSObjectiPN2JS5ValueE","__ZN2js10StackFrame7varSlotEj","__ZNK2js10CallObject3varEj","__ZN2js10SetCallVarEP9JSContextP8JSObjectiiPN2JS5ValueE","__ZN2js5types10TypeScript8SetLocalEP9JSContextP8JSScriptjRKN2JS5ValueE","__ZL12call_resolveP9JSContextP8JSObjectijPS2_","__ZL10call_traceP8JSTracerP8JSObject","__ZN2js10StackFrame20getValidCalleeObjectEP9JSContextPN2JS5ValueE","__ZNK2js10StackFrame12functionThisEv","__ZNK10JSFunction10methodAtomEv","__ZN2js10StackFrame15overwriteCalleeER8JSObject","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject1303","__ZNK8JSObject12hasMethodObjERKS_","__Z20js_XDRFunctionObjectP10JSXDRStatePP8JSObject","__ZN8JSObject11clearParentEv","__ZN8JSObject9clearTypeEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrptEv","__Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom","__ZL13fun_enumerateP9JSContextP8JSObject","__ZL11fun_resolveP9JSContextP8JSObjectijPS2_","__ZL12fun_finalizeP9JSContextP8JSObject","__ZL15fun_hasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi","__ZL9fun_traceP8JSTracerP8JSObject","__Z18fun_toStringHelperP9JSContextP8JSObjectj","__ZNK2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6lookupERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv","__ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE9constructEv","__ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE4initEj","__ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3putERKS2_RKS4_","__Z11js_fun_callP9JSContextjPN2JS5ValueE","__ZL13js_IsCallableRKN2JS5ValueE1306","__Z12js_fun_applyP9JSContextjPN2JS5ValueE","__ZN2js28CallOrConstructBoundFunctionEP9JSContextjPN2JS5ValueE","__ZN2jsL14IsConstructingEPKN2JS5ValueE1307","__ZNK8JSObject29getBoundFunctionArgumentCountEv","__ZNK8JSObject22getBoundFunctionTargetEv","__ZNK8JSObject20getBoundFunctionThisEv","__ZNK8JSObject24getBoundFunctionArgumentEj","__ZL12fun_toSourceP9JSContextjPN2JS5ValueE","__ZL12fun_toStringP9JSContextjPN2JS5ValueE","__ZNK2js8Bindings11countUpvarsEv","__ZNK2js8Bindings9hasUpvarsEv","__ZNK8JSObject10isDelegateEv","__ZN2jsL3MinIPN2JS5ValueEEET_S4_S4_","__ZNK2js11TokenStream12currentTokenEv","__ZN2JS6AnchorIP8JSStringE3setERKS2_","__ZN8JSObject13clearDelegateEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv","__ZL8fun_bindP9JSContextjPN2JS5ValueE","__ZL15fun_isGeneratorP9JSContextjPN2JS5ValueE","__ZN2js8FunctionEP9JSContextjPN2JS5ValueE","__ZN2js24CurrentScriptFileAndLineEP9JSContextPjNS_10LineOptionE","__ZN2js18AutoArenaAllocator5allocItEEPT_j","__ZN2js11TokenStream8getTokenEv","__ZL11OnBadFormalP9JSContextN2js9TokenKindE","__ZL35ResolveInterpretedFunctionPrototypeP9JSContextP8JSObject","__ZN2jsL11NewFunctionEP9JSContextP8JSObject","__Z22js_CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectS4_","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_1314","__ZN2js8Debugger11onNewScriptEP9JSContextP8JSScriptP8JSObjectNS0_13NewScriptKindE","__Z19js_AllocFlatClosureP9JSContextP10JSFunctionP8JSObject","__ZN8JSObject20setFlatClosureUpvarsEPN2JS5ValueE","__Z17js_NewFlatClosureP9JSContextP10JSFunction4JSOpj","__Z17js_DefineFunctionP9JSContextP8JSObjectiPFiS0_jPN2JS5ValueEEjj","__ZL12JSID_IS_ATOMi1319","__ZL12JSID_TO_ATOMi1320","__Z18js_ValueToFunctionP9JSContextPKN2JS5ValueEj","__Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj","__Z24js_ValueToFunctionObjectP9JSContextPN2JS5ValueEj","__Z24js_ValueToCallableObjectP9JSContextPN2JS5ValueEj","__ZNK2js13FrameRegsIter2spEv","__ZNK2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE12lookupForAddERKS2_","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE10getKeyHashEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEptEv","__ZNK2js7MoveRefINS_12HashMapEntryIP10JSFunctionP8JSStringEEEptEv","__ZNK2js7MoveRefIP10JSFunctionEcvRS2_Ev","__ZNK2js7MoveRefIP8JSStringEcvRS2_Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv","__ZNK2js9StackIter2spEv","_JSVAL_TO_PRIVATE_UINT32_IMPL","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E10overloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE6isFreeEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE10isLiveHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE9matchHashEj","__ZN2js13PointerHasherIP10JSFunctionLj2EE5matchERKS2_S5_","__ZN2js13PointerHasherIP10JSFunctionLj2EE4hashERKS2_","_JSID_TO_STRING1332","_JSID_IS_STRING1333","__ZN2jsL16GetClassProtoKeyEPNS_5ClassE1345","__ZNK8JSObject15isBoundFunctionEv","__ZNK10JSFunction19isFunctionPrototypeEv","__ZN2jsL16CastAsPropertyOpEP8JSObject1357","__ZN2jsL22CastAsStrictPropertyOpEP8JSObject1358","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE7setLiveEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE14unsetCollisionEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEC2ERS9_","__ZN2js7MoveRefINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC2ERS6_","__ZN2js7MoveRefIP8JSStringEC2ERS2_","__ZN2js7MoveRefIP10JSFunctionEC2ERS2_","__ZN2js12HashMapEntryIP10JSFunctionP8JSStringEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE12setCollisionEj","__ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_EC2ESB_","__ZN2js2gcL15GetGCObjectKindEjb1337","_PRIVATE_UINT32_TO_JSVAL_IMPL","__ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE6isLiveEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEaSENS_7MoveRefIS8_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEENS_7MoveRefIT_EERSB_","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEC1ERS9_","__ZN2js12HashMapEntryIP10JSFunctionP8JSStringEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_12HashMapEntryIP10JSFunctionP8JSStringEEEENS_7MoveRefIT_EERS8_","__ZN2js7MoveRefINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC1ERS6_","__ZN2js4MoveIP10JSFunctionEENS_7MoveRefIT_EERKS4_","__ZN2js4MoveIP8JSStringEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefIP8JSStringEC1ERS2_","__ZN2js7MoveRefIP10JSFunctionEC1ERS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC2Ev","__ZN2js12HashMapEntryIP10JSFunctionP8JSStringEC1Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E4initEj","__ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES7_","__ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES7_","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_EC1ESB_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE","__ZN6PutArgclEjPN2JS5ValueE","__ZN2JSL12PrivateValueEPv1335","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1338","__ZN2js6detailL9NewObjectILb0ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE1342","__ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_1343","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE1344","__ZN2JSL12BooleanValueEb1348","__ZN2JSL14UndefinedValueEv1350","__ZN8JSObject17initBoundFunctionEP9JSContextRKN2JS5ValueEPS4_j","__ZN2JSL18PrivateUint32ValueEj","__ZN2JS5Value16setPrivateUint32Ej","__ZNK2JS5Value15toPrivateUint32Ev","__ZN8JSObject27finalizeUpvarsIfFlatClosureEv","__ZNK8JSObject17getThrowTypeErrorEv","__ZL14JSID_FROM_BITSj1372","__ZNK10JSFunction8joinableEv","__ZNK2js10StackFrame19isFloatingGeneratorEv","__ZN2js7analyzeL7ArgSlotEj1371","_INT_TO_JSID1373","__ZNK2js2gc5Chunk18hasAvailableArenasEv","__ZN8JSObject17asStrictArgumentsEv","__ZN8JSObject17asNormalArgumentsEv","__ZN2js10StackFrame17setOverriddenArgsEv","__ZN6PutArgC2EPN2JS5ValueE","__ZN2js2gc11ArenaHeader17setAsNotAllocatedEv","__ZN2js2gc11ArenaHeader4initEP13JSCompartmentNS0_9AllocKindE","__ZN2js2gc5Chunk23removeFromAvailableListEv","__ZL15fun_getPropertyP9JSContextP8JSObjectiPN2JS5ValueE","__ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind1359","__ZNK2js12GlobalObject17getThrowTypeErrorEv","__ZN8JSObject11hasPropertyEP9JSContextiPbj","__ZL18MaybeMarkGeneratorP8JSTracerP8JSObject","__ZN2jsL16GetCallArgumentsEP9JSContextP8JSObjectiPN2JS5ValueE","__ZN2jsL16SetCallArgumentsEP9JSContextP8JSObjectiiPN2JS5ValueE","__ZNK2js10CallObject12getArgumentsEv","__ZN2js5types10TypeScript8SetLocalEP9JSContextP8JSScriptjNS0_4TypeE","__ZN2js5types10TypeScript10LocalTypesEP8JSScriptj","__ZN2js5types7TypeSet7hasTypeENS0_4TypeE","__ZN2js5typesL15HashSetCapacityEj1366","__ZN2js5typesL7HashKeyIPNS0_13TypeObjectKeyES2_EEjT_1367","__ZN2js5typesL13HashSetLookupIPNS0_13TypeObjectKeyES2_S2_EEPT0_PS5_jT_","__ZN2js7analyzeL9LocalSlotEP8JSScriptj1368","__ZN2js5types10TypeScript11SetArgumentEP9JSContextP8JSScriptjNS0_4TypeE","__ZN2js5types10TypeScript8ArgTypesEP8JSScriptj","__ZN2js10EmptyShape20getEmptyDeclEnvShapeEP9JSContext","__ZN2js10EmptyShape6ensureEP9JSContextPNS_5ClassEPPS0_","__ZL15StrictArgGetterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL15StrictArgSetterP9JSContextP8JSObjectiiPN2JS5ValueE","__ZN2js15ArgumentsObject10setElementEjRKN2JS5ValueE","__ZNK2js21NormalArgumentsObject6calleeEv","__ZL9ArgGetterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL9ArgSetterP9JSContextP8JSObjectiiPN2JS5ValueE","__ZN2JSL10MagicValueE10JSWhyMagic1374","__ZN2js15ArgumentsObject20markLengthOverriddenEv","__ZN2js21NormalArgumentsObject11clearCalleeEv","__ZN2JSL10Int32ValueEi1375","__ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueES2_1378","__ZN2js2gc5Chunk4initEv","__ZN2js2gc11ChunkBitmap5clearEv","__ZN2js2gc5Chunk13allocateArenaEP13JSCompartmentNS0_9AllocKindE","__ZNK2js2gc5Chunk6unusedEv","__ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv","__ZN2jsL3MaxIjEET_S1_S1_","__ZN2jsL3MinIfEET_S1_S1_","__ZN2js2gc11IsGCAllowedEP9JSContext","__ZNK2JS5Value11payloadWordEv","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5clearEv","__ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv","__ZN2js20TriggerCompartmentGCEP13JSCompartment","__ZN2js2gc5Chunk12releaseArenaEPNS0_11ArenaHeaderE","__ZN2js2gc5Chunk18addToAvailableListEP13JSCompartment","__ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6removeERKS3_","__Z20IsAboutToBeFinalizedP9JSContextPKv","__ZNK2js2gc4Cell8isMarkedEj","__Z9js_InitGCP9JSRuntimej","__ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE4initEj","__ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE4initEj","__ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE4initEj","__ZN9JSRuntime14setGCLastBytesEj18JSGCInvocationKind","__ZN2js28MarkStackRangeConservativelyEP8JSTracerPN2JS5ValueES4_","__ZN2jsL23MarkRangeConservativelyEP8JSTracerPKjS3_","__ZN2js26MarkConservativeStackRootsEP8JSTracer","__ZN2jsL28MarkThreadDataConservativelyEP8JSTracerPNS_10ThreadDataE","__ZN2js24ConservativeGCThreadData14recordStackTopEv","__Z11js_FinishGCP9JSRuntime","__ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE3allEv","__Z14ReleaseGCChunkP9JSRuntimePN2js2gc5ChunkE","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv","__ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE5clearEv","__ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE5clearEv","__ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE5clearEv","__Z10js_AddRootP9JSContextPN2JS5ValueEPKc","_js_AddRootRT","__Z17js_AddGCThingRootP9JSContextPPvPKc","_js_AddGCThingRootRT","__ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3putERKS1_RKS2_","__ZN2js8RootInfoC1EPKc12JSGCRootType","_js_RemoveRoot","__ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6removeERKS1_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv","__ZN13JSCompartment14setGCLastBytesEj18JSGCInvocationKind","__ZN2js2gc10ArenaLists15finalizeObjectsEP9JSContext","__ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE","__ZN2js2gc10ArenaLists13finalizeLaterEP9JSContextNS0_9AllocKindE","__ZN2js2gc10ArenaLists15finalizeStringsEP9JSContext","__ZN2js2gc10ArenaLists14finalizeShapesEP9JSContext","__ZN2js2gc10ArenaLists15finalizeScriptsEP9JSContext","__ZN2js2gc10ArenaLists14refillFreeListEP9JSContextNS0_9AllocKindE","__ZN2js2gcL14RunLastDitchGCEP9JSContext","__ZN2js2gc10ArenaLists17allocateFromArenaEP13JSCompartmentNS0_9AllocKindE","__ZN2js9TriggerGCEP9JSRuntime","__ZN2js2gc19GetGCThingTraceKindEPKv","__ZN2js8GCMarkerC2EP9JSContext","__ZN2js9MarkStackIP8JSObjectEC1EPPvj","__ZN2js9MarkStackIP6JSRopeEC1EPPvj","__ZN2js9MarkStackIPNS_5types10TypeObjectEEC1EPPvj","__ZN2js9MarkStackIP5JSXMLEC1EPPvj","__ZN2js9MarkStackINS_13LargeMarkItemEEC1EPPvj","__ZN2js8GCMarker20delayMarkingChildrenEPKv","__ZN2js2gc11ArenaHeader21setNextDelayedMarkingEPNS0_5ArenaE","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5Range5emptyEv","__ZNK2js2gc18GCCompartmentsIter4doneEv","__ZNK2js2gc11ArenaHeader21getNextDelayedMarkingEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5Range5frontEv","__ZN2js2gc18GCCompartmentsIter4nextEv","__ZN13AutoGCSessionC2EP9JSContext","__ZN13AutoGCSessionD2Ev","__ZN2js2gcL19MapAllocToTraceKindENS0_9AllocKindE","__ZN2js2gc11ArenaHeader8getArenaEv","__ZN2js8GCMarker19markDelayedChildrenEv","__ZN2jsL19MarkDelayedChildrenEPNS_8GCMarkerEPNS_2gc5ArenaE","__Z18js_TraceStackFrameP8JSTracerPN2js10StackFrameE","__ZN2js19AutoEnumStateRooter5traceEP8JSTracer","__ZN2js11MarkContextEP8JSTracerP9JSContext","__ZN2js12AutoGCRooter5traceEP8JSTracer","__ZN2js11MarkRuntimeEP8JSTracer","__ZNK2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3allEv","__ZL17gc_root_traversalP8JSTracerRKN2js12HashMapEntryIPvNS1_8RootInfoEEE","__ZNK2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE3allEv","__ZL17gc_lock_traversalRKN2js12HashMapEntryIPvjEEP8JSTracer","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5Range8popFrontEv","__ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime","__ZNK2js2gc18GCCompartmentsIterptEv","__ZN2js10ThreadData4markEP8JSTracer","__ZN2js7MaybeGCEP9JSContext","__Z5js_GCP9JSContextP13JSCompartment18JSGCInvocationKind","__ZN2jsL25RecordNativeStackTopForGCEP9JSContext","__ZL7GCCycleP9JSContextP13JSCompartment18JSGCInvocationKindRN2js7GCTimerE","__ZN2js12TraceRuntimeEP8JSTracer","__ZN2js24AutoCopyFreeListToArenasC1EP9JSRuntime","__ZN2js24AutoCopyFreeListToArenasD1Ev","__ZN2js12AutoUnlockGCC1EP9JSRuntime","__ZNK2js7MoveRefIPvEcvRS1_Ev","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE10getKeyHashEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEptEv","__ZNK2js7MoveRefINS_12HashMapEntryIPvNS_8RootInfoEEEEptEv","__ZNK2js7MoveRefINS_8RootInfoEEcvRS1_Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE10isLiveHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE10isLiveHashEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE12hasCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isFreeEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE9matchHashEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE9isRemovedEv","__ZN2js13PointerHasherIPvLj2EE5matchERKS1_S4_","__ZN2js13PointerHasherIPvLj2EE4hashERKS1_","__ZN2js9MarkStackINS_13LargeMarkItemEEC2EPPvj","__ZN2js9MarkStackIP5JSXMLEC2EPPvj","__ZN2js9MarkStackIPNS_5types10TypeObjectEEC2EPPvj","__ZN2js9MarkStackIP6JSRopeEC2EPPvj","__ZN2js9MarkStackIP8JSObjectEC2EPPvj","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E16setTableSizeLog2Ej","__ZN2js7MoveRefIPvEC2ERS1_","__ZN2js12HashMapEntryIPvjEC2Ev","__ZN2js12HashMapEntryIPvNS_8RootInfoEEaSERKS3_","__ZN2js12HashMapEntryIPvNS_8RootInfoEEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE14unsetCollisionEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEC2ERS7_","__ZN2js7MoveRefINS_12HashMapEntryIPvNS_8RootInfoEEEEC2ERS4_","__ZN2js7MoveRefINS_8RootInfoEEC2ERS1_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE12setCollisionEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE12setCollisionEj","__ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S2_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrdeEv","__ZN2js12IterateCellsEP9JSContextP13JSCompartmentNS_2gc9AllocKindEPvPFvS1_S6_S6_13JSGCTraceKindjE","__ZN2js2gc14NewCompartmentEP9JSContextP12JSPrincipals","__ZN9JSContext4new_I13JSCompartmentP9JSRuntimeEEPT_T0_","__Z11js_NewGCXMLP9JSContext","__Z10NewGCThingI5JSXMLEPT_P9JSContextN2js2gc9AllocKindEj","__ZN2js2gc5Arena11thingsStartENS0_9AllocKindE","__ZNK2js2gc5Arena7addressEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE6isLiveEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5RangeC1EPNS0_14HashTableEntryIS4_EESE_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5RangeC2EPNS0_14HashTableEntryIS4_EESE_","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isLiveEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E11createTableERS7_j","__ZN2js4MoveIPvEENS_7MoveRefIT_EERKS3_","__ZN2js7MoveRefIPvEC1ERS1_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEEC2Ev","__ZN2js12HashMapEntryIPvjEC1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS5_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE7setFreeEv","__ZN2js12HashMapEntryIPvNS_8RootInfoEEC1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEaSENS_7MoveRefIS6_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEENS_7MoveRefIT_EERS9_","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEC1ERS7_","__ZN2js12HashMapEntryIPvNS_8RootInfoEEaSENS_7MoveRefIS3_EE","__ZN2js4MoveINS_12HashMapEntryIPvNS_8RootInfoEEEEENS_7MoveRefIT_EERS6_","__ZN2js7MoveRefINS_12HashMapEntryIPvNS_8RootInfoEEEEC1ERS4_","__ZN2js4MoveINS_8RootInfoEEENS_7MoveRefIT_EERS3_","__ZN2js7MoveRefINS_8RootInfoEEC1ERS1_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEC2Ev","__ZNK2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6lookupERKS1_","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv","__ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E3PtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeENSC_3PtrE","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS5_EE","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj","__ZNK2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE12lookupForAddERKS1_","__ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E6AddPtrERKS1_RKS2_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_","__ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEptEv","__ZNK2js7MoveRefIPNS_2gc5ChunkEEcvRS3_Ev","__ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE10getKeyHashEv","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv","__ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv","__ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE10isLiveHashEj","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj","__ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isFreeEv","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj","__ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE12hasCollisionEv","__ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE9matchHashEj","__ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE9isRemovedEv","__ZN2js13GCChunkHasher5matchEPNS_2gc5ChunkES3_","__ZN2js13GCChunkHasher4hashEPNS_2gc5ChunkE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE7setLiveEj","__ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEEC2Ev","__ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEC2ERS7_","__ZN2js7MoveRefIPNS_2gc5ChunkEEC2ERS3_","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv","__ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE14unsetCollisionEv","__ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE12setCollisionEv","__ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE10setRemovedEv","__ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE7setFreeEv","__ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE12setCollisionEj","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE","__ZN2js12AutoUnlockGCC2EP9JSRuntime","__ZN2js2gc11ArenaHeader14setAsFullyUsedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5clearEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5clearEv","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEENS_7MoveRefIT_EERKS9_","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5clearEv","__ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEEaSENS_7MoveRefIS6_EE","__ZN2js4MoveINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEENS_7MoveRefIT_EERKS9_","__ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEEC1Ev","__ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEC1ERS7_","__ZN2js4MoveIPNS_2gc5ChunkEEENS_7MoveRefIT_EERS5_","__ZN2js7MoveRefIPNS_2gc5ChunkEEC1ERS3_","__ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isLiveEv","__ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3allEv","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC1EPNS0_14HashTableEntryIS5_EESF_","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC2EPNS0_14HashTableEntryIS5_EESF_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E4initEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j","__ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6lookupERKS3_","__ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv","__ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS3_NS6_6SetOpsES5_E3PtrE","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS5_EE","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj","__ZN2js4MoveINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEENS_7MoveRefIT_EERS9_","__ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv","__ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS5_","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS5_","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS5_EE","__ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS5_jj","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS5_EERS5_","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj","__ZN2js24AutoCopyFreeListToArenasD2Ev","__ZN2js2gc10ArenaLists22clearFreeListsInArenasEv","__ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE","__ZN2js24AutoCopyFreeListToArenasC2EP9JSRuntime","__ZN2js2gc10ArenaLists21copyFreeListsToArenasEv","__ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE","__ZL12MarkAndSweepP9JSContext18JSGCInvocationKindRN2js7GCTimerE","__ZNK2js2gc18GCCompartmentsIter3getEv","__ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE6lengthEv","__ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE6lengthEv","__ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE5beginEv","__ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE6lengthEv","__ZNK2js14AutoValueArray6lengthEv","__ZNK2js14AutoValueArray5startEv","__ZNK2js10AutoLockGC6lockedEv","__ZNK2js2gc10ArenaLists18arenaListsAreEmptyEv","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE8shrinkByEj","__ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE10initializeEPS2_S5_","__ZZ5js_GCP9JSContextP13JSCompartment18JSGCInvocationKindEN11AutoGCProbeC2ES2_","__ZN2js2gc8FreeSpan18infallibleAllocateEj","__ZN2js10AutoLockGC4lockEP9JSRuntime","__ZN2js2gc8FreeSpan20allocateFromNewArenaEjjj","__Z21GetAvailableChunkListP13JSCompartment","__ZL14BeginMarkPhaseP9JSContextPN2js8GCMarkerE18JSGCInvocationKindRNS1_7GCTimerE","__ZL12EndMarkPhaseP9JSContextPN2js8GCMarkerE18JSGCInvocationKindRNS1_7GCTimerE","__ZL10SweepPhaseP9JSContextPN2js8GCMarkerE18JSGCInvocationKindRNS1_7GCTimerE","__ZNK2js2gc18GCCompartmentsItercvP13JSCompartmentEv","__ZL25ComputeJitReleaseIntervalP9JSContext","__ZL17SweepCompartmentsP9JSContext18JSGCInvocationKind","__ZL14ExpireGCChunksP9JSRuntime18JSGCInvocationKind","__ZN9JSContext7delete_I13JSCompartmentEEvPT_","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6resizeEj","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6growByEj","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE10growByImplILb1EEEbj","__ZN2js2gc18GCCompartmentsIterC2EP9JSRuntime","__ZN2js2gc5Arena9thingsEndEv","__ZL9PickChunkP13JSCompartment","__Z15AllocateGCChunkP9JSRuntime","__ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE12lookupForAddERKS3_","__ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS3_NS6_6SetOpsES5_E6AddPtrERS9_","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS5_","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv","__ZNK2js2gc11ArenaHeader13hasFreeThingsEv","__ZNK2js2gc8FreeSpan17nextSpanUncheckedEj","__ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE7setLiveEj","__ZN2js13AutoKeepAtomsD2Ev","__ZN2js13AutoKeepAtomsC2EP9JSRuntime","__ZNK16JSExternalString12externalTypeEv","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE","__ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERS5_","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj","__ZN2js13AutoKeepAtomsC1EP9JSRuntime","__ZN2js13AutoKeepAtomsD1Ev","__ZN2js2gcL14FinalizeArenasEP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE","__ZN2js2gc19FinalizeTypedArenasI8JSObjectEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE","__ZN2js2gc19FinalizeTypedArenasI8JSScriptEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE","__ZN2js2gc19FinalizeTypedArenasINS_5ShapeEEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE","__ZN2js2gc19FinalizeTypedArenasINS_5types10TypeObjectEEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE","__ZN2js2gc19FinalizeTypedArenasI5JSXMLEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE","__ZN2js2gc19FinalizeTypedArenasI8JSStringEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE","__ZN2js2gc19FinalizeTypedArenasI13JSShortStringEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE","__ZN2js2gc19FinalizeTypedArenasI16JSExternalStringEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE","__ZN2js2gc5Arena8finalizeI16JSExternalStringEEbP9JSContextNS0_9AllocKindEj","__ZN16JSExternalString8finalizeEP9JSContext","__ZN2js2gc5Arena8finalizeI13JSShortStringEEbP9JSContextNS0_9AllocKindEj","__ZN2js2gc5Arena8finalizeI8JSStringEEbP9JSContextNS0_9AllocKindEj","__ZN8JSString8finalizeEP9JSContext","__ZN2js2gc5Chunk17withinArenasRangeEj","__ZN2js2gc5Chunk10arenaIndexEj","__ZN2js14FindChunkStartEPv","__ZN2js8RootInfoC2EPKc12JSGCRootType","__ZNK2js2gc11ArenaHeader9allocatedEv","__ZN2js2gc5Arena8finalizeI5JSXMLEEbP9JSContextNS0_9AllocKindEj","__ZN5JSXML8finalizeEP9JSContext","__ZN2js2gc5Arena8finalizeINS_5types10TypeObjectEEEbP9JSContextNS0_9AllocKindEj","__ZN2js2gc5Arena8finalizeINS_5ShapeEEEbP9JSContextNS0_9AllocKindEj","__ZN2js2gc5Arena8finalizeI8JSScriptEEbP9JSContextNS0_9AllocKindEj","__ZN2js2gc5Arena8finalizeI8JSObjectEEbP9JSContextNS0_9AllocKindEj","__ZN8JSObject8finalizeEP9JSContext","__ZN8JSObject6finishEP9JSContext","__ZN2jsL22MarkWordConservativelyEP8JSTracerj","__ZN2js17MarkIfGCThingWordEP8JSTracerj","__ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE3hasERKS3_","__ZN2js10InFreeListEPNS_2gc11ArenaHeaderEj","__ZN2js2gc11ChunkBitmap8isMarkedEPKNS0_4CellEj","__ZN2jsL12PodArrayZeroIjLj4032EEEvRAT0__T_","__ZN2js12AllocGCChunkEv","__ZL8MapPagesPvj","__ZL10UnmapPagesPvj","__ZN2js11FreeGCChunkEPv","__ZN2js2gc10MarkStringEP8JSTracerP8JSString","__ZN2js2gc4MarkI8JSStringEEvP8JSTracerPT_","__ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc","__ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc","__ZN2js2gc4MarkI8JSObjectEEvP8JSTracerPT_","__ZN2js2gc26MarkCrossCompartmentObjectEP8JSTracerR8JSObjectPKc","__ZN2js2gc21MarkObjectWithPrinterEP8JSTracerR8JSObjectPFvS2_PcjEPKvj","__ZN2js2gc10MarkScriptEP8JSTracerP8JSScriptPKc","__ZN2js2gc4MarkI8JSScriptEEvP8JSTracerPT_","__ZN2js2gc9MarkShapeEP8JSTracerPKNS_5ShapeEPKc","__ZN2js2gc4MarkIKNS_5ShapeEEEvP8JSTracerPT_","__ZN2js2gc14MarkTypeObjectEP8JSTracerPNS_5types10TypeObjectEPKc","__ZNK8JSObject10typeFromGCEv","_JSID_IS_STRING1510","_JSID_TO_STRING1511","_JSID_IS_OBJECT1512","_JSID_TO_OBJECT1513","__ZNK2js5Shape14hasGetterValueEv","__ZNK2js5Shape14hasSetterValueEv","__ZNK6JSRope10rightChildEv","__ZN8JSScript6constsEv","__ZNK2js5Shape12getterObjectEv","__ZNK2js5Shape12setterObjectEv","__ZN2js2gc4MarkINS_5types10TypeObjectEEEvP8JSTracerPT_","__ZN2js2gc4MarkI5JSXMLEEvP8JSTracerPT_","__ZN2js2gc15MarkObjectRangeEP8JSTracerjPP8JSObjectPKc","__ZN2js2gc12MarkXMLRangeEP8JSTracerjPP5JSXMLPKc","__ZN2js2gc6MarkIdEP8JSTraceri","__ZN2js2gc6MarkIdEP8JSTraceriPKc","__ZN2js2gc11MarkIdRangeEP8JSTracerPiS3_PKc","__ZN2js2gc11MarkIdRangeEP8JSTracerjPiPKc","__ZN2js2gc8MarkKindEP8JSTracerPv13JSGCTraceKind","__ZN2js2gc4MarkINS_5ShapeEEEvP8JSTracerPT_","__ZN2js2gc12MarkValueRawEP8JSTracerRKN2JS5ValueE","__ZNK2JS5Value6gcKindEv","__ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc","__ZN2js2gc25MarkCrossCompartmentValueEP8JSTracerRKN2JS5ValueEPKc","__ZN2js2gc14MarkValueRangeEP8JSTracerPKN2JS5ValueES6_PKc","__ZN2js2gc14MarkValueRangeEP8JSTracerjPKN2JS5ValueEPKc","__ZN2js2gc14MarkShapeRangeEP8JSTracerPPKNS_5ShapeES6_PKc","__ZN2js2gc14MarkShapeRangeEP8JSTracerjPPKNS_5ShapeEPKc","__ZN2js2gc11MarkGCThingEP8JSTracerPv","__ZN2js2gc11MarkGCThingEP8JSTracerPvPKc","__ZN2js2gc11MarkGCThingEP8JSTracerPvPKcj","__ZN2js2gc12MarkChildrenEP8JSTracerP8JSObject","__ZN2js2gc12MarkChildrenEP8JSTracerP8JSString","__ZN2js2gc12MarkChildrenEP8JSTracerP8JSScript","__ZN2js2gcL13MarkAtomRangeEP8JSTracerjPP6JSAtomPKc","__ZN2js5types10TypeScript5traceEP8JSTracer","__ZN2js2gc12MarkChildrenEP8JSTracerPKNS_5ShapeE","__ZN2js2gc12MarkChildrenEP8JSTracerPNS_5types10TypeObjectE","__ZN2js5types10TypeObject16getPropertyCountEv","__ZN2js5types10TypeObject11getPropertyEj","__ZN2js2gc12MarkChildrenEP8JSTracerP5JSXML","__ZNK2js8GCMarker12getMarkColorEv","__ZN2js9MarkStackIP6JSRopeE7isEmptyEv","__ZN2js9MarkStackIP8JSObjectE7isEmptyEv","__ZN2js9MarkStackIPNS_5types10TypeObjectEE7isEmptyEv","__ZN2js9MarkStackIP5JSXMLE7isEmptyEv","__ZN2js9MarkStackINS_13LargeMarkItemEE7isEmptyEv","__ZN2js9MarkStackIP6JSRopeE3popEv","__ZN2js9MarkStackIP8JSObjectE3popEv","__ZN2js9MarkStackIPNS_5types10TypeObjectEE3popEv","__ZN2js9MarkStackIP5JSXMLE3popEv","__ZN2js9MarkStackINS_13LargeMarkItemEE4peekEv","__ZN2js9MarkStackINS_13LargeMarkItemEE3popEv","__ZL23js_RegenerateShapeForGCP9JSRuntime","__ZN2js9MarkStackIP8JSObjectE4pushES2_","__ZN2js8GCMarker14drainMarkStackEv","__ZN2js8GCMarker16isMarkStackEmptyEv","__ZN2js2gcL8ScanRopeEPNS_8GCMarkerEP6JSRope","__ZN2js2gcL10ScanObjectEPNS_8GCMarkerEP8JSObject","__ZN2js2gcL14ScanTypeObjectEPNS_8GCMarkerEPNS_5types10TypeObjectE","__ZN2js2gcL15ScanLargeObjectEPNS_8GCMarkerERNS_13LargeMarkItemE","_JS_TraceChildren","__ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE","__ZN2js2gcL9ScanShapeEPNS_8GCMarkerEPKNS_5ShapeE","__ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSString","__ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSObject","__ZN2js8GCMarker10pushObjectEP8JSObject","__ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP5JSXML","__ZNK8JSObject11hasOwnShapeEv","__ZN2js5types10TypeScript8hasScopeEv","_JSVAL_IS_STRING_IMPL1546","__ZN9JSRuntime6GCData14isTimerEnabledEv","_JS_CompareValues","__ZN2js9MarkStackIP5JSXMLE4pushES2_","__ZN2js9MarkStackIPNS_5types10TypeObjectEE4pushES3_","__ZN2js9MarkStackINS_13LargeMarkItemEE4pushES1_","__ZN2js13LargeMarkItemC2EP8JSObject","__ZN2js9MarkStackIP6JSRopeE4pushES2_","__ZN9JSRuntime6GCData13setFirstEnterEy","_JS_HashString","__ZN2js8GCMarker7pushXMLEP5JSXML","__ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPNS_5types10TypeObjectE","__ZN2js8GCMarker8pushTypeEPNS_5types10TypeObjectE","__ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSScript","__ZN2js2gcL9ScanValueEPNS_8GCMarkerERKN2JS5ValueE","__ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP10JSFunction","__ZN2js13LargeMarkItemC1EP8JSObject","__ZN8JSObject9scanSlotsEPN2js8GCMarkerE","__ZN2js8GCMarker8pushRopeEP6JSRope","__ZN2js5typesL15HashSetCapacityEj1539","__ZN2js2gc4MarkI6JSAtomEEvP8JSTracerPT_","_JSVAL_TRACE_KIND_IMPL1545","__ZN2js7GCTimerC2EP9JSRuntimeP13JSCompartment","__ZN2js7GCTimer15clearTimestampsEv","__ZN2js7GCTimer13getFirstEnterEv","__ZN2js7GCTimer6finishEb","_JS_NewHashTable","_JS_HashTableDestroy","_JS_HashTableRawLookup","_JS_HashTableRawAdd","__ZL6ResizeP11JSHashTablej","_JS_HashTableEnumerateEntries","__ZL17DefaultAllocTablePvj","__ZL16DefaultFreeTablePvS_j","__ZL17DefaultAllocEntryPvPKv","__ZL16DefaultFreeEntryPvP11JSHashEntryj","__ZNK2js5types7TypeSet18isDefinitePropertyEv","__ZNK2js5types7TypeSet12definiteSlotEv","__ZN2js5types11TypeFailureEP9JSContextPKcz","__ZN2js5types15TypeCompartment5printEP9JSContextb","__ZN2js5types7TypeSet4makeEP9JSContextPKc","__ZN2js8ArenaNewINS_5types7TypeSetEEEPT_R11JSArenaPool","__ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext","__ZN2js5types7TypeSet14getObjectCountEv","__ZN2js5types7TypeSet9getObjectEj","__ZN2js5types4Type10ObjectTypeEPNS0_13TypeObjectKeyE","__ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_","__ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb","__ZN2js8ArenaNewI20TypeConstraintSubsetPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_","__ZN2js5types7TypeSet14addGetPropertyEP9JSContextP8JSScriptPhPS1_i","__ZN2js8ArenaNewI18TypeConstraintPropP8JSScriptPhPNS_5types7TypeSetEibEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_RKT4_","__ZN2js5types7TypeSet14addSetPropertyEP9JSContextP8JSScriptPhPS1_i","__ZN2js5types7TypeSet15addCallPropertyEP9JSContextP8JSScriptPhi","__ZN2js7analyze14ScriptAnalysis9getCallPCEPh","__ZN2js8ArenaNewI22TypeConstraintCallPropP8JSScriptPhiEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_","__ZN2js5types7TypeSet13addSetElementEP9JSContextP8JSScriptPhPS1_S7_","__ZN2js8ArenaNewI24TypeConstraintSetElementP8JSScriptPhPNS_5types7TypeSetES7_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_","__ZN2js5types7TypeSet7addCallEP9JSContextPNS0_12TypeCallsiteE","__ZN2js8ArenaNewI18TypeConstraintCallPNS_5types12TypeCallsiteEEEPT_R11JSArenaPoolRKT0_","__ZN2js5types7TypeSet8addArithEP9JSContextPS1_S4_","__ZN2js8ArenaNewI19TypeConstraintArithPNS_5types7TypeSetES4_EEPT_R11JSArenaPoolRKT0_RKT1_","__ZN2js5types7TypeSet16addTransformThisEP9JSContextP8JSScriptPS1_","__ZN2js8ArenaNewI27TypeConstraintTransformThisP8JSScriptPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_RKT1_","__ZN2js5types7TypeSet16addPropagateThisEP9JSContextP8JSScriptPhNS0_4TypeEPS1_","__ZN2js8ArenaNewI27TypeConstraintPropagateThisP8JSScriptPhNS_5types4TypeEPNS5_7TypeSetEEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_","__ZN2js5types7TypeSet19addFilterPrimitivesEP9JSContextPS1_NS1_10FilterKindE","__ZN2js8ArenaNewI29TypeConstraintFilterPrimitivePNS_5types7TypeSetENS3_10FilterKindEEEPT_R11JSArenaPoolRKT0_RKT1_","__ZNK2js5types4Type11isPrimitiveE11JSValueType","__ZN2js5types7TypeSet21hasPropagatedPropertyEv","__ZN2js7analyze14ScriptAnalysis17pruneTypeBarriersEP9JSContextj","__ZL17GetSingletonShapeP9JSContextP8JSObjecti","__ZN2js7analyze14ScriptAnalysis17breakTypeBarriersEP9JSContextjb","__ZN2js7analyze14ScriptAnalysis20breakTypeBarriersSSAEP9JSContextRKNS0_8SSAValueE","__ZN2js5types7TypeSet16addSubsetBarrierEP9JSContextP8JSScriptPhPS1_","__ZN2js8ArenaNewI27TypeConstraintSubsetBarrierP8JSScriptPhPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_","__ZN2js5types7TypeSet16addLazyArgumentsEP9JSContextPS1_","__ZN2js8ArenaNewI27TypeConstraintLazyArgumentsPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_","__ZN18TypeConstraintProp7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZL21UnknownPropertyAccessP8JSScriptN2js5types4TypeE","__ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb","__ZL25MarkPropertyAccessUnknownP9JSContextP8JSScriptPhPN2js5types7TypeSetE","__ZL9id_lengthP9JSContext","__ZN2js5types4Type9Int32TypeEv","__ZL17GetPropertyObjectP9JSContextP8JSScriptN2js5types4TypeE","__ZL14PropertyAccessP9JSContextP8JSScriptPhPN2js5types10TypeObjectEbPNS5_7TypeSetEi","__ZN22TypeConstraintCallProp7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN2js5types10TypeObject17getFromPrototypesEP9JSContextiPNS0_7TypeSetEb","__ZN24TypeConstraintSetElement7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZNK2js5types4Type12singleObjectEv","__ZN2js5types10TypeObject11hasAnyFlagsEj","__ZN18TypeConstraintCall7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZNK2js5types4Type14isSingleObjectEv","__ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE","__ZN2js5types10TypeScript9ThisTypesEP8JSScript","__ZN2js5types10TypeScript11ReturnTypesEP8JSScript","__ZN27TypeConstraintPropagateThis7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN19TypeConstraintArith7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZNK2js5types7TypeSet10hasAnyFlagEj","__ZN2js5types4Type10StringTypeEv","__ZN27TypeConstraintTransformThis7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN2js5types10TypeScript12StandardTypeEP9JSContextP8JSScript10JSProtoKey","__ZN2js5types7TypeSet15getSingleObjectEj","__ZN2js5types20MarkArgumentsCreatedEP9JSContextP8JSScript","__ZN8JSScript17ensureRanAnalysisEP9JSContextP10JSFunctionP8JSObject","__ZN2js7analyze14ScriptAnalysis7getCodeEPKh","__ZNK2JS5Value12isMagicCheckE10JSWhyMagic","__ZNK8JSScript6globalEv","__ZNK2js5types7TypeSet13isOwnPropertyEb","__ZN2jsL3MaxIjEET_S1_S1_1674","__ZL24CheckNewScriptPropertiesP9JSContextPN2js5types10TypeObjectEP10JSFunction","__ZN2js5types7TypeSet12getSingletonEP9JSContextb","__ZN2js5types10TypeObjectC1EP8JSObjectbb","__ZN2js5types15TypeCompartment4initEP9JSContext","__ZN2jsL7PodZeroINS_5types15TypeCompartmentEEEvPT_","__ZN2js5types15TypeCompartment13newTypeObjectEP9JSContextP8JSScript10JSProtoKeyP8JSObjectb","__Z10NewGCThingIN2js5types10TypeObjectEEPT_P9JSContextNS0_2gc9AllocKindEj","__ZN2js5types10TypeObject15setFlagsFromKeyEP9JSContext10JSProtoKey","__ZN2js5types15TypeCompartment27newAllocationSiteTypeObjectEP9JSContextRKNS0_17AllocationSiteKeyE","__ZN9JSContext4new_IN2js7HashMapINS1_5types17AllocationSiteKeyEPNS3_10TypeObjectES4_NS1_17SystemAllocPolicyEEEEEPT_v","__ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE4initEj","__ZNK2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE12lookupForAddERKS2_","__ZN2js5types10TypeObject21addDefinitePropertiesEP9JSContextP8JSObject","__ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKS4_","__ZN2js5types10UseNewTypeEP9JSContextP8JSScriptPh","__ZL9GetAtomIdP9JSContextP8JSScriptPKhj","__ZL12id_prototypeP9JSContext","__ZN2js5types15TypeCompartment16growPendingArrayEP9JSContext","__ZN2js5types15TypeCompartment24processPendingRecompilesEP9JSContext","__ZN9JSContext7delete_IN2js6VectorIP8JSScriptLj0ENS1_15TempAllocPolicyEEEEEvPT_","__ZN2js5types15TypeCompartment9nukeTypesEP9JSContext","__ZL17ObjectStateChangeP9JSContextPN2js5types10TypeObjectEbb","__ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE6lengthEv","__ZN2js7analyze14ScriptAnalysis12ranInferenceEv","__ZN2js7analyzeL11ExtendedDefEPh1682","__ZNK2js5types4TypeeqES1_","__ZN8JSScript11hasAnalysisEv","__ZN2js5types15TypeCompartment11compartmentEv","__ZN2js5types15TypeCompartment15markSetsUnknownEP9JSContextPNS0_10TypeObjectE","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEEC1ES4_","__ZN2js2gc8CellIterC1EP9JSContextP13JSCompartmentNS0_9AllocKindE","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_","__ZN2js2gc8CellIterD1Ev","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEEixEj","__ZN2js5types10TypeScript11NumTypeSetsEP8JSScript","__ZN2js7analyzeL11GetDefCountEP8JSScriptj1681","__ZN2js7analyze14ScriptAnalysis11pushedTypesEPKhj","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEED1Ev","__ZN2js7analyze14ScriptAnalysis14addTypeBarrierEP9JSContextPKhPNS_5types7TypeSetENS6_4TypeE","__ZN2js8ArenaNewINS_5types11TypeBarrierEPNS1_7TypeSetENS1_4TypeEP8JSObjectiEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_","__ZN2js7analyze14ScriptAnalysis23addSingletonTypeBarrierEP9JSContextPKhPNS_5types7TypeSetEP8JSObjecti","__ZL15InferSpewActiveN2js5types11SpewChannelE","__ZN2js7analyze14ScriptAnalysis10printTypesEP9JSContext","__ZN2js5types15TypeCompartment12fixArrayTypeEP9JSContextP8JSObject","__ZNK2js5types4TypeneES1_","_JSID_IS_EMPTY","_JSID_IS_VOID1691","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv","__ZN2js5types7TypeSet21setPropagatedPropertyEv","__ZN2js5types7TypeSet11setDefiniteEj","__ZN9JSContext4new_IN2js7HashMapINS1_5types13ArrayTableKeyEPNS3_10TypeObjectES4_NS1_17SystemAllocPolicyEEEEEPT_v","__ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE4initEj","__ZL20GetValueTypeForTableP9JSContextRKN2JS5ValueE","__ZL11NumberTypesN2js5types4TypeES1_","__ZN2js5types13ArrayTableKeyC1Ev","__ZNK2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE12lookupForAddERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv","__ZN2js5types10TypeObject15addPropertyTypeEP9JSContextiNS0_4TypeE","__ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13relookupOrAddERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKS4_","__ZN2js5types15TypeCompartment13fixObjectTypeEP9JSContextP8JSObject","__ZN9JSContext4new_IN2js7HashMapINS1_5types14ObjectTableKeyENS3_16ObjectTableEntryES4_NS1_17SystemAllocPolicyEEEEEPT_v","__ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE4initEj","__ZNK2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE12lookupForAddERKP8JSObject","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv","__ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS5_13MapHashPolicyES4_E6AddPtrERKS2_RKS3_","__ZN2js5types10TypeObject11addPropertyEP9JSContextiPPNS0_8PropertyE","__ZN2js8ArenaNewINS_5types8PropertyEiEEPT_R11JSArenaPoolRKT0_","__ZL18UpdatePropertyTypeP9JSContextPN2js5types7TypeSetEP8JSObjectPKNS1_5ShapeEb","__ZN8JSObject11isFixedSlotEj","__ZN2js5types10TypeObject23matchDefinitePropertiesEP8JSObject","__Z21InlineAddTypePropertyP9JSContextPN2js5types10TypeObjectEiNS2_4TypeE","__ZN2js5types10TypeObject15addPropertyTypeEP9JSContextiRKN2JS5ValueE","__ZN2js5types10TypeObject15addPropertyTypeEP9JSContextPKcNS0_4TypeE","__ZL12ATOM_TO_JSIDP6JSAtom1694","__ZN2js5types10TypeObject15addPropertyTypeEP9JSContextPKcRKN2JS5ValueE","__ZN2js5types10TypeObject22markPropertyConfiguredEP9JSContexti","__ZN2js5types10TypeObject15markStateChangeEP9JSContext","__ZN2js5types10TypeObject8setFlagsEP9JSContextj","__ZN2js5types10TypeObject11markUnknownEP9JSContext","__ZN2js7analyze14ScriptAnalysis16addsScopeObjectsEv","__ZN2js7analyzeL7ArgSlotEj1706","__ZN2jsL20CallObjectLambdaNameEP10JSFunction1708","__ZN2js5types10TypeObject14clearNewScriptEP9JSContext","__ZN2js7analyze14ScriptAnalysis17resolveNameAccessEP9JSContextib","__ZN2jsL7PodZeroINS_7analyze14ScriptAnalysis10NameAccessEEEvPT_","__ZL12JSID_IS_ATOMi1703","__ZL12JSID_TO_ATOMi1704","__ZN8JSScript18ensureRanInferenceEP9JSContext","__ZL12js_GetOpcodeP9JSContextP8JSScriptPh1705","__ZN2js7analyzeL9LocalSlotEP8JSScriptj1707","__ZN2js7analyze14ScriptAnalysis20analyzeTypesBytecodeEP9JSContextjRNS1_18TypeInferenceStateE","__ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE6lengthEv","__ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE6lengthEv","__ZN2js7analyze14ScriptAnalysis3OOMEv","__ZN2js7analyze14ScriptAnalysis6ranSSAEv","__ZNK2js7analyze14ScriptAnalysis14usesScopeChainEv","__ZN2js7analyze14ScriptAnalysis12extendsScopeEv","__ZN2js7analyze14ScriptAnalysis16localsAliasStackEv","__ZN2js10ArenaArrayINS_5types7TypeSetEEEPT_R11JSArenaPoolj","__ZN2jsL7PodZeroINS_5types7TypeSetEEEvPT_j","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_","__ZN2js5types4Type11BooleanTypeEv","__ZN2js5types4Type8NullTypeEv","__ZL15GetScriptObjectP9JSContextP8JSScriptPKhj","__ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj","__ZN2js7analyze14ScriptAnalysis13bytecodeTypesEPKh","__ZL13CheckNextTestPh","__ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh1709","__ZN2js7analyzeL10TotalSlotsEP8JSScript1710","__ZN2js5types4Type12LazyArgsTypeEv","__ZN2js7analyzeL11GetUseCountEP8JSScriptj1711","__ZN2js8ArenaNewINS_5types12TypeCallsiteEP9JSContextP8JSScriptPhbjEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_RKT4_","__ZL18GetInitializerTypeP9JSContextP8JSScriptPh","__ZL12id___proto__P9JSContext","__ZN2js12GlobalObject29getOrCreateGeneratorPrototypeEP9JSContext","__ZN2js7analyze14ScriptAnalysis12analyzeTypesEP9JSContext","__ZNK8JSScript16hasClearedGlobalEv","__ZL19DetachNestingParentP8JSScript","__ZN2js7analyze14ScriptAnalysis18TypeInferenceStateC1EP9JSContext","__ZN2js7analyzeL17GetBytecodeLengthEPh1712","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEEixEj","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEEC1ES3_","__ZN2js7analyze14ScriptAnalysis23followEscapingArgumentsEP9JSContextRKNS0_8SSAValueEPNS_6VectorIS4_Lj0ENS_15TempAllocPolicyEEE","__ZN2js7analyze8SSAValue11PushedValueEjj","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEED1Ev","__ZN2js7analyze14ScriptAnalysis18TypeInferenceStateD1Ev","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEEixEj","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_","__ZN2js7analyze14ScriptAnalysis23followEscapingArgumentsEP9JSContextPNS0_11SSAUseChainEPNS_6VectorINS0_8SSAValueELj0ENS_15TempAllocPolicyEEE","__ZN2js7analyze8SSAValue8PhiValueEjPNS0_10SSAPhiNodeE","__ZN2js7analyze8SSAValue10WrittenVarEjj","__ZN2js7analyze17AutoEnterAnalysisC1EP9JSContext","__ZN2js7analyze17AutoEnterAnalysisD1Ev","__ZN2js5types23MarkIteratorUnknownSlowEP9JSContext","__ZN9JSContext4new_IN2js5types10TypeResultEjNS2_4TypeEEEPT_T0_T1_","__ZN2js5types19TypeMonitorCallSlowEP9JSContextP8JSObjectRKNS_8CallArgsEb","__ZN2js5types10TypeScript7SetThisEP9JSContextP8JSScriptRKN2JS5ValueE","__ZN2JSL14UndefinedValueEv1713","__ZN2js5types17TypeDynamicResultEP9JSContextP8JSScriptPhNS0_4TypeE","__ZN9JSContext4new_IN2js5types10TypeResultEiNS2_4TypeEEEPT_T0_T1_","__ZN2js5types17TypeMonitorResultEP9JSContextP8JSScriptPhRKN2JS5ValueE","__ZN2js5types10TypeScript8SetScopeEP9JSContextP8JSScriptP8JSObject","__ZNK10JSFunction13isNullClosureEv","__ZN9JSContext4new_IN2js5types17TypeScriptNestingEEEPT_v","__ZN2js5types17TypeScriptNestingD2Ev","__ZNK8JSObject18hasSpecialEqualityEv","__ZN2js5types18ClearActiveNestingEP8JSScript","__ZN2js5types15NestingPrologueEP9JSContextPNS_10StackFrameE","__ZN2js5typesL18CheckNestingParentEP9JSContextP8JSObjectP8JSScript","__ZN2js5types15NestingEpilogueEPNS_10StackFrameE","__ZN8JSScript9makeTypesEP9JSContextP10JSFunction","__ZN2js5types10TypeScriptC1EP10JSFunction","__ZN8JSScript12makeAnalysisEP9JSContext","__ZN2js8ArenaNewINS_7analyze14ScriptAnalysisEP8JSScriptEEPT_R11JSArenaPoolRKT0_","__ZN8JSScript15typeSetFunctionEP9JSContextP10JSFunctionb","__ZN8JSObject21shouldSplicePrototypeEP9JSContext","__ZN8JSObject15splicePrototypeEP9JSContextPS_","__ZN8JSObject12makeLazyTypeEP9JSContext","__ZN8JSObject11makeNewTypeEP9JSContextP10JSFunctionb","__Z16SweepTypeObjectsP9JSContextP13JSCompartment","__ZN17SweepTypeObjectOpC1EP9JSContext","__ZN2js2gc19ForEachArenaAndCellIPFvPNS0_5ArenaEE17SweepTypeObjectOpEEvP13JSCompartmentNS0_9AllocKindET_T0_","__ZN2js5types14TypeConstraint16newPropertyStateEP9JSContextPNS0_7TypeSetE","__ZN2js5types14TypeConstraint14newObjectStateEP9JSContextPNS0_10TypeObjectEb","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5emptyEv","_JSID_IS_STRING1730","_JSID_TO_STRING1731","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE12hasCollisionEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5frontEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv","__ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEaSERKS5_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv","__ZN2js5types15TypeCompartment5sweepEP9JSContext","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC1ISA_EERT_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC1IS9_EERT_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4Enum11removeFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range8popFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC1ISA_EERT_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev","__ZN2js5types15TypeCompartmentD2Ev","__ZN2js10Foreground7delete_INS_7HashMapINS_5types13ArrayTableKeyEPNS3_10TypeObjectES4_NS_17SystemAllocPolicyEEEEEvPT_","__ZN2js10Foreground7delete_INS_7HashMapINS_5types14ObjectTableKeyENS3_16ObjectTableEntryES4_NS_17SystemAllocPolicyEEEEEvPT_","__ZN2js10Foreground7delete_INS_7HashMapINS_5types17AllocationSiteKeyEPNS3_10TypeObjectES4_NS_17SystemAllocPolicyEEEEEvPT_","__ZN2js5types10TypeScript5SweepEP9JSContextP8JSScript","__ZN2js5types7TypeSet5sweepEP9JSContextP13JSCompartment","__ZN2js5typesL20IsAboutToBeFinalizedEP9JSContextPNS0_13TypeObjectKeyE","__ZN9JSContext7delete_IN2js5types10TypeResultEEEvPT_","__ZN2js5types10TypeScript7destroyEv","__ZN2js10Foreground7delete_INS_5types10TypeResultEEEvPT_","__ZN2js10Foreground7delete_INS_5types17TypeScriptNestingEEEvPT_","_js_free1736","__ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED1Ev","__ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS7_EEj","__ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEED1Ev","__ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS6_EEj","__ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED1Ev","__ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS7_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE7setFreeEv","__ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEC1Ev","__ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE10getKeyHashEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEptEv","__ZNK2js7MoveRefINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEptEv","__ZNK2js7MoveRefINS_5types17AllocationSiteKeyEEcvRS2_Ev","__ZNK2js7MoveRefIPNS_5types10TypeObjectEEcvRS3_Ev","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE10getKeyHashEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEptEv","__ZNK2js7MoveRefINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEptEv","__ZNK2js7MoveRefINS_5types14ObjectTableKeyEEcvRS2_Ev","__ZNK2js7MoveRefINS_5types16ObjectTableEntryEEcvRS2_Ev","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE12hasCollisionEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isFreeEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE12hasCollisionEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE14unsetCollisionEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEC2ERS9_","__ZN2js7MoveRefINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEC2ERS6_","__ZN2js7MoveRefIPNS_5types10TypeObjectEEC2ERS3_","__ZN2js7MoveRefINS_5types17AllocationSiteKeyEEC2ERS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E11underloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE14unsetCollisionEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEC2ERS8_","__ZN2js7MoveRefINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEC2ERS5_","__ZN2js7MoveRefINS_5types16ObjectTableEntryEEC2ERS2_","__ZN2js7MoveRefINS_5types14ObjectTableKeyEEC2ERS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE12setCollisionEv","__ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEaSERKS5_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE14unsetCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEEaSENS_7MoveRefIS8_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEENS_7MoveRefIT_EERSB_","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEC1ERS9_","__ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEENS_7MoveRefIT_EERS8_","__ZN2js7MoveRefINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEC1ERS6_","__ZN2js4MoveINS_5types17AllocationSiteKeyEEENS_7MoveRefIT_EERKS4_","__ZN2js4MoveIPNS_5types10TypeObjectEEENS_7MoveRefIT_EERS5_","__ZN2js7MoveRefIPNS_5types10TypeObjectEEC1ERS3_","__ZN2js7MoveRefINS_5types17AllocationSiteKeyEEC1ERS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC2ISA_EERT_","__ZNK2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE3allEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS7_EESG_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS7_EESG_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6removeERNS0_14HashTableEntryIS6_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE7setFreeEv","__ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEaSERKS4_","__ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEC1Ev","__ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEC2Ev","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isLiveEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E16checkUnderloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEEaSENS_7MoveRefIS7_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEENS_7MoveRefIT_EERSA_","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEC1ERS8_","__ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEaSENS_7MoveRefIS4_EE","__ZN2js4MoveINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEENS_7MoveRefIT_EERS7_","__ZN2js7MoveRefINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEC1ERS5_","__ZN2js4MoveINS_5types14ObjectTableKeyEEENS_7MoveRefIT_EERKS4_","__ZN2js4MoveINS_5types16ObjectTableEntryEEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefINS_5types16ObjectTableEntryEEC1ERS2_","__ZN2js7MoveRefINS_5types14ObjectTableKeyEEC1ERS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC2IS9_EERT_","__ZNK2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE3allEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC1EPNS0_14HashTableEntryIS6_EESF_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC2EPNS0_14HashTableEntryIS6_EESF_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS7_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE7setFreeEv","__ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC1Ev","__ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC2Ev","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isLiveEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE10getKeyHashEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEptEv","__ZNK2js7MoveRefINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEptEv","__ZNK2js7MoveRefINS_5types13ArrayTableKeyEEcvRS2_Ev","__ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js7MoveRefINS_7analyze8SSAValueEEcvRS2_Ev","__ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE5beginEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isFreeEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEC2ERS9_","__ZN2js7MoveRefINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEC2ERS6_","__ZN2js7MoveRefINS_5types13ArrayTableKeyEEC2ERS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE12setCollisionEv","__ZN8JSObject14revertLazyTypeEv","__ZN2js5types10TypeResultC2EjNS0_4TypeE","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js7MoveRefINS_7analyze8SSAValueEEC2ERS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEEaSENS_7MoveRefIS8_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEENS_7MoveRefIT_EERSB_","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEC1ERS9_","__ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEENS_7MoveRefIT_EERS8_","__ZN2js7MoveRefINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEC1ERS6_","__ZN2js4MoveINS_5types13ArrayTableKeyEEENS_7MoveRefIT_EERKS4_","__ZN2js7MoveRefINS_5types13ArrayTableKeyEEC1ERS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC2ISA_EERT_","__ZNK2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE3allEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS7_EESG_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS7_EESG_","__ZN17SweepTypeObjectOpclEPN2js2gc4CellE","__ZN2js5types10TypeObject5sweepEP9JSContext","__ZN2js5types10TypeObject15clearPropertiesEv","__ZN2js5typesL15HashSetCapacityEj1739","__ZN2js8ArenaNewINS_5types8PropertyES2_EEPT_R11JSArenaPoolRKT0_","__ZN2js5typesL13HashSetInsertIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_1740","__ZN2jsL7PodZeroIPNS_5types8PropertyEEEvPT_j1741","__ZN2js5typesL16HashSetInsertTryIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_1742","__ZN2js5typesL7HashKeyIiNS0_8PropertyEEEjT_1743","__ZN2js5types8PropertyC1ERKS1_","__ZN2js5types8PropertyC2ERKS1_","__ZN2js7analyze14ScriptAnalysisC1EP8JSScript","__ZN2js7analyze14ScriptAnalysisC2EP8JSScript","__ZN2jsL7PodZeroINS_7analyze14ScriptAnalysisEEEvPT_","__ZN2js5types17TypeScriptNestingC1Ev","__ZN2js5types17TypeScriptNestingC2Ev","__ZN2jsL7PodZeroINS_5types17TypeScriptNestingEEEvPT_","__ZN2js5types10TypeResultC1EjNS0_4TypeE","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_","__ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj0ES3_EEj","__ZN2js4MoveINS_7analyze8SSAValueEEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefINS_7analyze8SSAValueEEC1ERS2_","__ZN2js10VectorImplINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js4MoveINS_7analyze8SSAValueEEENS_7MoveRefIT_EERKS4_","__ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE5beginEv","__ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr7nonNullEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv","__ZNK2js5types4Type3rawEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E10overloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE9matchHashEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE9matchHashEj","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js10VectorImplIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyELb1EE13copyConstructIS3_EEvPS3_PKT_SA_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE7setLiveEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS6_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE12setCollisionEj","__ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S3_EE","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_","__ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC2ERKS2_RKS4_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE7setLiveEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE12setCollisionEj","__ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS7_EE","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEED2Ev","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEEC2ES3_","__ZN2js5types12TypeCallsiteC1EP9JSContextP8JSScriptPhbj","__ZN2js5types12TypeCallsiteC2EP9JSContextP8JSScriptPhbj","__ZN2js10ArenaArrayIPNS_5types7TypeSetEEEPT_R11JSArenaPoolj","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_","__ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS3_Lj0ES4_EEj","__ZN2js10VectorImplIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyELb1EE13moveConstructIS3_EEvPS3_PKT_SA_","__ZN2js5types8PropertyC1Ei","__ZN2js5types8PropertyC2Ei","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrEPPS6_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrE","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E12lookupForAddERKP8JSObject","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKP8JSObject","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKP8JSObjectjj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC1ERNS0_14HashTableEntryIS6_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC2ERNS0_14HashTableEntryIS6_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS6_EERKP8JSObject","__ZN2js5types14ObjectTableKey5matchERKS1_P8JSObject","__ZN2js5types14ObjectTableKey4hashEP8JSObject","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj","__ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEEC1ES4_","__ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEEC2ES4_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13relookupOrAddERNSC_6AddPtrERKS4_RKS7_","__ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC1ERKS2_RKS4_","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrERKS7_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS7_EERKS4_","__ZN2js5types13ArrayTableKey5matchERKS1_S3_","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj","__ZN2js5types13ArrayTableKey4hashERKS1_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj","__ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC1ES5_","__ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_","__ZN2js5types11TypeBarrierC1EPNS0_7TypeSetENS0_4TypeEP8JSObjecti","__ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE5beginEv","__ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN27TypeConstraintLazyArguments7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv","__ZN2js5types11TypeBarrierC2EPNS0_7TypeSetENS0_4TypeEP8JSObjecti","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js10VectorImplIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyELb1EE13copyConstructIS3_EEvPS3_PKT_SA_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE7setLiveEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_","__ZN2js5types14TypeConstraintC2EPKc","__ZN17SweepTypeObjectOpC2EP9JSContext","__ZN2js5types10TypeScriptC2EP10JSFunction","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_","__ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS3_Lj0ES4_EEj","__ZN2js10VectorImplIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyELb1EE13moveConstructIS3_EEvPS3_PKT_SA_","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEED2Ev","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEEC2ES4_","__ZN2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEED2Ev","__ZNK2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS7_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj","__ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC1ES5_","__ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_","__ZN27TypeConstraintLazyArgumentsC1EPN2js5types7TypeSetE","__ZN27TypeConstraintLazyArgumentsC2EPN2js5types7TypeSetE","__ZN27TypeConstraintLazyArguments14newObjectStateEP9JSContextPN2js5types10TypeObjectEb","__ZN27TypeConstraintSubsetBarrierC1EP8JSScriptPhPN2js5types7TypeSetE","__ZN27TypeConstraintSubsetBarrierC2EP8JSScriptPhPN2js5types7TypeSetE","__ZN27TypeConstraintSubsetBarrier7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN29TypeConstraintFilterPrimitiveC1EPN2js5types7TypeSetENS2_10FilterKindE","__ZN29TypeConstraintFilterPrimitiveC2EPN2js5types7TypeSetENS2_10FilterKindE","__ZN29TypeConstraintFilterPrimitive7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN27TypeConstraintPropagateThisC1EP8JSScriptPhN2js5types4TypeEPNS4_7TypeSetE","__ZN27TypeConstraintPropagateThisC2EP8JSScriptPhN2js5types4TypeEPNS4_7TypeSetE","__ZN27TypeConstraintTransformThisC1EP8JSScriptPN2js5types7TypeSetE","__ZN27TypeConstraintTransformThisC2EP8JSScriptPN2js5types7TypeSetE","__ZN19TypeConstraintArithC1EPN2js5types7TypeSetES3_","__ZN19TypeConstraintArithC2EPN2js5types7TypeSetES3_","__ZN18TypeConstraintCallC1EPN2js5types12TypeCallsiteE","__ZN18TypeConstraintCallC2EPN2js5types12TypeCallsiteE","__ZN24TypeConstraintSetElementC1EP8JSScriptPhPN2js5types7TypeSetES6_","__ZN24TypeConstraintSetElementC2EP8JSScriptPhPN2js5types7TypeSetES6_","__ZN22TypeConstraintCallPropC1EP8JSScriptPhi","__ZN22TypeConstraintCallPropC2EP8JSScriptPhi","__ZN18TypeConstraintPropC1EP8JSScriptPhPN2js5types7TypeSetEib","__ZN18TypeConstraintPropC2EP8JSScriptPhPN2js5types7TypeSetEib","__ZN20TypeConstraintSubsetC1EPN2js5types7TypeSetE","__ZN20TypeConstraintSubsetC2EPN2js5types7TypeSetE","__ZN20TypeConstraintSubset7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN2js5typesL13HashSetInsertIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_1745","__ZN2jsL7PodZeroIPNS_5types13TypeObjectKeyEEEvPT_j1746","__ZN2js5typesL16HashSetInsertTryIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_1747","__ZN2js5typesL7HashKeyIPNS0_13TypeObjectKeyES2_EEjT_1748","__ZN2js5types10TypeScript7SetThisEP9JSContextP8JSScriptNS0_4TypeE","__ZN2js7analyze17AutoEnterAnalysisD2Ev","__ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE6lengthEv","__ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE5beginEv","__ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js7MoveRefINS_5types13TypeNewScript11InitializerEEcvRS3_Ev","__ZN2js7analyze17AutoEnterAnalysis5leaveEv","__ZN2js7analyze17AutoEnterAnalysisC2EP9JSContext","__ZN2js2gcL15GetGCObjectKindEjb1752","__ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js7MoveRefINS_5types13TypeNewScript11InitializerEEC2ERS3_","__ZN2js5types13TypeNewScript11InitializerC2ENS2_4KindEj","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1751","__ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEEC1ES4_","__ZL26AnalyzeNewScriptPropertiesP9JSContextPN2js5types10TypeObjectEP10JSFunctionPP8JSObjectPNS1_6VectorINS2_13TypeNewScript11InitializerELj0ENS1_15TempAllocPolicyEEE","__ZN2js5types13TypeNewScript11InitializerC1ENS2_4KindEj","__ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_","__ZN2jsL7PodCopyINS_5types13TypeNewScript11InitializerEEEvPT_PKS4_j","__ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEED2Ev","__ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_","__ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS3_Lj0ES4_EEj","__ZN2js4MoveINS_5types13TypeNewScript11InitializerEEENS_7MoveRefIT_EERS5_","__ZN2js7MoveRefINS_5types13TypeNewScript11InitializerEEC1ERS3_","__ZN2js10VectorImplINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS3_EEvPS3_PKT_SA_","__ZN2js4MoveINS_5types13TypeNewScript11InitializerEEENS_7MoveRefIT_EERKS5_","__ZL14JSID_FROM_BITSj1765","__ZN2jsL12PodArrayZeroIbLj2EEEvRAT0__T_","__ZN2js5types17TypeFlagPrimitiveEj","__ZL22UsePropertyTypeBarrierPh","__ZL14id_constructorP9JSContext","__ZN2js8ArenaNewI33TypeConstraintClearDefiniteSetterPNS_5types10TypeObjectEEEPT_R11JSArenaPoolRKT0_","__ZN2js8ArenaNewI33TypeConstraintClearDefiniteSinglePNS_5types10TypeObjectEEEPT_R11JSArenaPoolRKT0_","__ZN33TypeConstraintClearDefiniteSingleC1EPN2js5types10TypeObjectE","__ZN33TypeConstraintClearDefiniteSingleC2EPN2js5types10TypeObjectE","__ZN33TypeConstraintClearDefiniteSingle7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN33TypeConstraintClearDefiniteSetterC1EPN2js5types10TypeObjectE","__ZN33TypeConstraintClearDefiniteSetterC2EPN2js5types10TypeObjectE","__ZN33TypeConstraintClearDefiniteSetter7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEEC2ES4_","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1753","__ZN2js7analyze14ScriptAnalysis18TypeInferenceStateD2Ev","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEED2Ev","__ZN2js7analyze14ScriptAnalysis18TypeInferenceStateC2EP9JSContext","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEEC1ES4_","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEEC2ES4_","__ZN8JSScript12clearNestingEv","__ZNK2js5Shape26hasDefaultGetterOrIsMethodEv","__ZN2js5types13ArrayTableKeyC2Ev","__ZN2js2gc8CellIterD2Ev","__ZN2js2gc8CellIterC2EP9JSContextP13JSCompartmentNS0_9AllocKindE","__ZN2js2gc10ArenaLists22isSynchronizedFreeListENS0_9AllocKindE","__ZN2js5types10TypeObjectC2EP8JSObjectbb","__ZN2jsL7PodZeroINS_5types10TypeObjectEEEvPT_","__ZN2js13GetScopeChainEP9JSContext","__ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind1790","__ZN2js13GetScopeChainEP9JSContextPNS_10StackFrameE","__ZN2js13GetBlockChainEP9JSContextPNS_10StackFrameE","__ZL12js_GetOpcodeP9JSContextP8JSScriptPh1793","__ZN2js17GetBlockChainFastEP9JSContextPNS_10StackFrameE4JSOpj","__ZL17GetScopeChainFullP9JSContextPN2js10StackFrameEP8JSObject","__ZN2js17GetScopeChainFastEP9JSContextPNS_10StackFrameE4JSOpj","__ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE","__ZN2js16BoxNonStrictThisEP9JSContextRKNS_12CallReceiverE","__ZN8JSObject10thisObjectEP9JSContext","__ZL20no_such_method_traceP8JSTracerP8JSObject","__ZN2js15OnUnknownMethodEP9JSContextPN2JS5ValueE","__ZL12ATOM_TO_JSIDP6JSAtom1798","__ZN2js5types10TypeScript14MonitorUnknownEP9JSContextP8JSScriptPh","__ZN2jsL9IdToValueEi1799","__ZN2js9RunScriptEP9JSContextP8JSScriptPNS_10StackFrameE","__ZN2js9InterpretEP9JSContextPNS_10StackFrameENS_10InterpModeE","__ZN2jsL13ToReportFlagsENS_17InitialFrameFlagsE","__ZNK8JSScript7isEmptyEv","__ZN2js12InvokeKernelEP9JSContextRKNS_8CallArgsENS_14MaybeConstructE","__ZL12NoSuchMethodP9JSContextjPN2JS5ValueE","__ZN2js12CallJSNativeEP9JSContextPFiS1_jPN2JS5ValueEERKNS_8CallArgsE","__ZN2js5types15TypeMonitorCallEP9JSContextRKNS_8CallArgsEb","__ZN2js16InvokeFrameGuardC1Ev","__ZNK2js10FrameGuard2fpEv","__ZN2js10StackFrame16functionPrologueEP9JSContext","__ZN2js23AutoPreserveEnumeratorsC1EP9JSContext","__ZN2js23AutoPreserveEnumeratorsD1Ev","__ZN2js16InvokeFrameGuardD1Ev","__ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_","__ZN2js17InvokeConstructorEP9JSContextRKN2JS5ValueEjPS3_S6_","__ZN2js20InvokeGetterOrSetterEP9JSContextP8JSObjectRKN2JS5ValueEjPS5_S8_","__ZN2JSL11ObjectValueER8JSObject1804","__ZN2js13ExecuteKernelEP9JSContextP8JSScriptR8JSObjectRKN2JS5ValueENS_11ExecuteTypeEPNS_10StackFrameEPS7_","__ZN2js17ExecuteFrameGuardC1Ev","__ZNK2js10StackFrame17isStrictEvalFrameEv","__ZL14InitSharpSlotsP9JSContextPN2js10StackFrameE","__ZN2js17ExecuteFrameGuardD1Ev","__ZN2js7ExecuteEP9JSContextP8JSScriptR8JSObjectPN2JS5ValueE","__ZN2js18CheckRedeclarationEP9JSContextP8JSObjectij","__ZN2jsL16IsFunctionObjectERKN2JS5ValueE1809","__ZN2js11HasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPi","__ZeqRK8JSObjectS1_1816","__ZNK10JSFunction13isConstructorEv","_INT_FITS_IN_JSID1825","_INT_TO_JSID1826","__ZNK8JSObject7isXMLIdEv","_OBJECT_TO_JSID1827","__ZNK8JSObject6isWithEv","__ZNK8JSObject7isBlockEv","__ZN8JSScript15stepModeEnabledEv","__ZN12JSPCCounters3getEi","__ZNK2JS5Value18payloadAsRawUint32Ev","__ZNK23GenericInterruptEnablerIiE16enableInterruptsEv","__ZN2js12LooselyEqualEP9JSContextRKN2JS5ValueES5_Pi","__ZN2JS8SameTypeERKNS_5ValueES2_","__ZN2jsL11ToPrimitiveEP9JSContextPN2JS5ValueE","__ZN2js13StrictlyEqualEP9JSContextRKN2JS5ValueES5_Pi","__ZN2js9SameValueEP9JSContextRKN2JS5ValueES5_Pi","__ZL14IsNegativeZeroRKN2JS5ValueE","__ZL5IsNaNRKN2JS5ValueE","__ZN2js11TypeOfValueEP9JSContextRKN2JS5ValueE","__ZN8JSObject6typeOfEP9JSContext","__ZN2js23InvokeConstructorKernelEP9JSContextRKNS_8CallArgsE","__ZN2JS5Value31setMagicWithObjectOrNullPayloadEP8JSObject","__ZN2js23CallJSNativeConstructorEP9JSContextPFiS1_jPN2JS5ValueEERKNS_8CallArgsE","__ZNK10JSFunction24isInterpretedConstructorEv","__ZN2js30InvokeConstructorWithGivenThisEP9JSContextP8JSObjectRKN2JS5ValueEjPS5_S8_","__ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi","__ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi","__ZN2js19IsActiveWithOrBlockEP9JSContextR8JSObjecti","__Z27js_FloatingFrameIfGeneratorP9JSContextPN2js10StackFrameE","__ZN2js11UnwindScopeEP9JSContextii","__ZL9LeaveWithP9JSContext","__ZN2js8GetUpvarEP9JSContextjNS_11UpvarCookieE","__ZN2js14FindUpvarFrameEP9JSContextj","__ZNK2js10StackFrame8numFixedEv","__ZN23GenericInterruptEnablerIiEC1EPii","__ZN2js17PreserveRegsGuardC1EP9JSContextRNS_9FrameRegsE","__ZN2js17InterpreterFramesC1EP9JSContextPNS_9FrameRegsERKNS0_20InterruptEnablerBaseE","__ZNK2js10StackFrame15maybeFormalArgsEv","__ZN2js31ScriptPrologueOrGeneratorResumeEP9JSContextPNS_10StackFrameEb","__ZN2js5types17UseNewTypeAtEntryEP9JSContextPNS_10StackFrameE","__ZNK8JSObject5shapeEv","__ZNK2js10StackFrame18loweredCallOrApplyEv","_JSID_IS_VOID1831","__ZNK2js5PCVal6isSlotEv","__ZNK2js5PCVal6toSlotEv","__ZL24CanIncDecWithoutOverflowi","__ZNK2js5PCVal8isFunObjEv","__ZNK2js5PCVal8toFunObjEv","__ZNK2js5PCVal7toShapeEv","__ZNK2js18PropertyCacheEntry7vcapTagEv","__ZNK2js18PropertyCacheEntry6vshapeEv","__ZNK2js5Shape16hasDefaultSetterEv","__ZN8JSObject25brandedOrHasMethodBarrierEv","_JSID_IS_STRING1834","_JSID_IS_INT1835","_JSID_TO_INT1836","__ZN2JS5Value11getInt32RefEv","__ZN2JS5Value4swapERS0_","__ZN2jsL18GetDecomposeLengthEPhj","__ZNK2js12CallReceiver11spAfterCallEv","__ZL9EnterWithP9JSContexti4JSOpj","__ZN2js14ScriptEpilogueEP9JSContextPNS_10StackFrameEb","__ZN2js12ContextStack14popInlineFrameERNS_9FrameRegsE","__ZN2jsL13FrameAtomBaseEP9JSContextPNS_10StackFrameE","__ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE","__Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_","__ZL12IteratorMoreP9JSContextP8JSObjectPbPN2JS5ValueE","__ZL12IteratorNextP9JSContextP8JSObjectPN2JS5ValueE","__ZN2js10StackFrame6varObjEv","__ZN2js13PropertyCache4testEP9JSContextPhRP8JSObjectS6_RPNS_18PropertyCacheEntryERP6JSAtom","__ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE1830","__ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh","__ZL5IsXMLRKN2JS5ValueE","__ZN2js5types10TypeScript13MonitorStringEP9JSContextP8JSScriptPh","__ZN2js9NumberDivEdd","__ZL7js_fmoddd","__ZN2js8ToNumberEP9JSContextPN2JS5ValueE","__ZN2JSL10Int32ValueEi1832","__ZL8DoIncDecP9JSContextPK10JSCodeSpecPN2JS5ValueES6_","__ZN2JSL11NumberValueEd1833","__Z23js_GetProtoIfDenseArrayP8JSObject","__ZN2js13PropertyCache10testForSetEP9JSContextPhP8JSObjectPPNS_18PropertyCacheEntryEPS5_PP6JSAtom","__ZNK2js18PropertyCacheEntry6addingEv","__ZN8JSObject21nativeSetSlotWithTypeEP9JSContextPKN2js5ShapeERKN2JS5ValueE","__ZN8JSObject6extendEP9JSContextPKN2js5ShapeEb","__Z18js_PurgeScopeChainP9JSContextP8JSObjecti","__ZN2js13StaticStrings23getUnitStringForElementEP9JSContextP8JSStringj","__ZN2js19ValuePropertyBearerEP9JSContextRKN2JS5ValueEi","__ZN2js5types10TypeScript13MonitorAssignEP9JSContextP8JSScriptPhP8JSObjectiRKN2JS5ValueE","__ZN2js14CallArgsFromSpEjPN2JS5ValueE","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction1837","__ZN2js12ContextStack15pushInlineFrameEP9JSContextRNS_9FrameRegsERKNS_8CallArgsER8JSObjectP10JSFunctionP8JSScriptNS_17InitialFrameFlagsE","__ZN2js14ScriptPrologueEP9JSContextPNS_10StackFrameEb","__ZN2js19ComputeImplicitThisEP9JSContextP8JSObjectRKN2JS5ValueEPS5_","__Z19js_UnwrapWithObjectP9JSContextP8JSObject","__ZN8JSScript8getConstEj","__ZN2jsL12ToFrameFlagsENS_17InitialFrameFlagsE1859","__ZNK2js14NativeIterator7currentEv","__ZL14JSID_FROM_BITSj1904","__ZL17iterator_iteratorP9JSContextP8JSObjecti","__ZNK2js14NativeIterator5beginEv","__ZNK2js14NativeIterator3endEv","__ZNK2js5Shape20isAccessorDescriptorEv","__ZN2js10StackFrame10isYieldingEv","_JSVAL_TO_OBJECT_IMPL1849","_JSVAL_IS_OBJECT_OR_NULL_IMPL","__ZN2js13PropertyCache4hashEPhj","__ZNK8JSObject9isDeclEnvEv","_JSID_TO_STRING1867","__ZNK8JSObject8isVarObjEv","__ZNK8JSObject10isIteratorEv","__ZNK2js14NativeIterator9isKeyIterEv","_JSVAL_SAME_TYPE_IMPL","__ZNK2js10FrameGuard6pushedEv","_JSID_IS_OBJECT1900","_JSID_TO_OBJECT1901","__ZN2jsL16CastAsPropertyOpEP8JSObject1842","__ZN2jsL22CastAsStrictPropertyOpEP8JSObject1843","__ZL15JSDOUBLE_IS_NaNd1870","__ZL15JSDOUBLE_IS_NEGd","_JSDOUBLE_IS_NEGZERO1872","__ZN2js23AdvanceOverBlockchainOpEPh","__ZN2js10StackFrame11setYieldingEv","__ZN8JSScript4mainEv","__ZN2js10StackFrame24setFinishedInInterpreterEv","__ZN2js17InterpreterFrames20InterruptEnablerBaseC2Ev","__ZN2js12StackSegment11repointRegsEPNS_9FrameRegsE","__ZN2js17InterpreterFramesD2Ev","__ZL13JSVAL_TO_IMPLN2JS5ValueE1850","__ZN2js2gcL25GetGCObjectFixedSlotsKindEj","__ZN8JSObject10setIndexedEv","__ZN8JSObject16setMethodBarrierEv","__ZN2js14NativeIterator9incCursorEv","__ZN2js17InterpreterFramesC2EP9JSContextPNS_9FrameRegsERKNS0_20InterruptEnablerBaseE","_MAGIC_OBJ_TO_JSVAL_IMPL","__ZN2js10FrameGuardC2Ev","__ZN2js23AutoPreserveEnumeratorsD2Ev","__ZN2js23AutoPreserveEnumeratorsC2EP9JSContext","__ZN8JSScript9getRegExpEj","__ZN2JSL10MagicValueE10JSWhyMagic1838","__ZN2JSL14UndefinedValueEv1839","__ZN10JSFunction13setMethodAtomEP6JSAtom","__ZNK8JSObject20canHaveMethodBarrierEv","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject1840","__ZL13js_IsCallableRKN2JS5ValueE1841","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1845","__ZN2jsL21CopyInitializerObjectEP9JSContextP8JSObjectPNS_5types10TypeObjectE","__ZN2js13PropertyCache11testForInitEP9JSRuntimePhP8JSObjectPPKNS_5ShapeEPPNS_18PropertyCacheEntryE","__ZNK2JS5Value14isObjectOrNullEv","__ZN2js8Debugger19onDebuggerStatementEP9JSContextPN2JS5ValueE","__ZN2JSL11StringValueEP8JSString1846","_JSVAL_TO_OBJECT1847","__ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueES2_1848","__ZN2js8Debugger17onExceptionUnwindEP9JSContextPN2JS5ValueE","__ZN2js10StackFrame16clearReturnValueEv","__ZN2js30ScriptEpilogueOrGeneratorYieldEP9JSContextPNS_10StackFrameEb","__ZN2js17InterpreterFramesD1Ev","__ZN2js17PreserveRegsGuardD1Ev","__ZN23GenericInterruptEnablerIiEC2EPii","__ZN2js17PreserveRegsGuardD2Ev","__ZN2js12ContextStack11repointRegsEPNS_9FrameRegsE","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1852","__ZNK8JSObject11isPrimitiveEv","__ZN2jsL25IsCacheableNonGlobalScopeEP8JSObject","__ZN8JSObject11updateFlagsEPKN2js5ShapeEb","__ZN8JSObject11updateShapeEP9JSContext","_JSDOUBLE_IS_INT321871","__ZN2js13PropertyCache10matchShapeEP9JSContextP8JSObjectj","__ZNK8JSObject17getNativeIteratorEv","__ZL12JSID_IS_ATOMi1876","__ZN2js9FrameRegs8popFrameEPN2JS5ValueE","__ZNK2js10StackFrame15constructorThisEv","__ZN2js17PreserveRegsGuardC2EP9JSContextRNS_9FrameRegsE","__ZN2js17ExecuteFrameGuardD2Ev","__ZN2js10FrameGuardD2Ev","__ZN2js17ExecuteFrameGuardC2Ev","__ZN2js16InvokeFrameGuardD2Ev","__ZN2js16InvokeFrameGuardC2Ev","__ZL17iterator_finalizeP9JSContextP8JSObject","__ZL14iterator_traceP8JSTracerP8JSObject","__ZN2js14NativeIterator4markEP8JSTracer","__ZN2js15VectorToIdArrayEP9JSContextRNS_12AutoIdVectorEPP9JSIdArray","__ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE","__ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE6lengthEv","__ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE5beginEv","__ZN2js14NativeIterator4initEP8JSObjectjjj","__ZL18RegisterEnumeratorP9JSContextP8JSObjectPN2js14NativeIteratorE","__ZN2jsL20UpdateNativeIteratorEPNS_14NativeIteratorEP8JSObject","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE5clearEv","__ZL7CompareIjEbPT_S1_j","__ZL8SnapshotP9JSContextP8JSObjectjPN2js12AutoIdVectorE","__ZN2js14NativeIterator16allocateIteratorEP9JSContextjRKNS_12AutoIdVectorE","__ZNK2js16AutoVectorRooterIiE5beginEv","__ZN2js19VectorToKeyIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE","__ZL19VectorToKeyIteratorP9JSContextP8JSObjectjRN2js12AutoIdVectorEjjPN2JS5ValueE","__ZN2js21VectorToValueIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE","__ZL17NewIteratorObjectP9JSContextj","__ZN8JSObject17setNativeIteratorEPN2js14NativeIteratorE","__ZN2js28EnumeratedIdVectorToIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE","__ZN2js11GetIteratorEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN2js5types19MarkIteratorUnknownEP9JSContext","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE6appendIjEEbT_","__ZNK2js15NativeIterCache3getEj","__ZNK8JSObject11isGeneratorEv","__ZN2js13StaticStrings6hasIntEi","__ZL17GetCustomIteratorP9JSContextP8JSObjectjPN2JS5ValueE","__ZN2js15NativeIterCache3setEjP8JSObject","__Z21js_ThrowStopIterationP9JSContext","__ZL13iterator_nextP9JSContextjPN2JS5ValueE","__Z18js_ValueToIteratorP9JSContextjPN2JS5ValueE","__Z16js_CloseIteratorP9JSContextP8JSObject","__ZL14CloseGeneratorP9JSContextP8JSObject","__Z26js_SuppressDeletedPropertyP9JSContextP8JSObjecti","__ZL29SuppressDeletedPropertyHelperI17SingleIdPredicateEbP9JSContextP8JSObjectT_","__ZN17SingleIdPredicateC1Ei","__Z25js_SuppressDeletedElementP9JSContextP8JSObjectj","__Z33js_SuppressDeletedIndexPropertiesP9JSContextP8JSObjectii","__ZL29SuppressDeletedPropertyHelperI19IndexRangePredicateEbP9JSContextP8JSObjectT_","__ZN19IndexRangePredicateC1Eii","__Z15js_IteratorMoreP9JSContextP8JSObjectPN2JS5ValueE","__ZL12ATOM_TO_JSIDP6JSAtom1935","__ZN2JSL11ObjectValueER8JSObject1936","__ZN2jsL15IsStopIterationERKN2JS5ValueE","__ZL15NewKeyValuePairP9JSContextiRKN2JS5ValueEPS2_","__Z15js_IteratorNextP9JSContextP8JSObjectPN2JS5ValueE","__ZN2jsL9IdToValueEi1939","__ZNK2js16AutoObjectRooter6objectEv","_JSID_IS_INT1957","_JSID_TO_INT1958","__ZN17SingleIdPredicateclEi","_JSID_IS_STRING1965","__ZN2js10StackFrame21initFloatingGeneratorEv","__ZN2js2gcL15GetGCObjectKindEjb1947","__ZN2js16AutoObjectRooter4addrEv","__ZN2js10StackFrame13clearYieldingEv","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE7popBackEv","__ZL20stopiter_hasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi","__ZL18generator_finalizeP9JSContextP8JSObject","__ZL15generator_traceP8JSTracerP8JSObject","__Z15js_NewGeneratorP9JSContext","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_1942","__Z27js_FloatingFrameToGeneratorPN2js10StackFrameE","__ZL14generator_nextP9JSContextjPN2JS5ValueE","__ZL14generator_sendP9JSContextjPN2JS5ValueE","__ZL15generator_throwP9JSContextjPN2JS5ValueE","__ZL15generator_closeP9JSContextjPN2JS5ValueE","__ZN2js12GlobalObject18initGeneratorClassEP9JSContext","__Z22js_InitIteratorClassesP9JSContextP8JSObject","__ZL17InitIteratorClassP9JSContextPN2js12GlobalObjectE","__ZL22InitStopIterationClassP9JSContextPN2js12GlobalObjectE","__ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE1948","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE1951","__ZN19IndexRangePredicateclEi","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE14internalAppendIjEEvT_","__ZN2JSL14UndefinedValueEv1961","__ZL8IteratorP9JSContextjPN2JS5ValueE","__ZL12generator_opP9JSContext13JSGeneratorOpPN2JS5ValueEj","__ZL15SendToGeneratorP9JSContext13JSGeneratorOpP8JSObjectP11JSGeneratorRKN2JS5ValueE","__ZN2JSL17ObjectOrNullValueEP8JSObject1967","__ZN9JSContext25ensureGeneratorStackSpaceEv","__ZN2JSL10MagicValueE10JSWhyMagic1968","__ZN2js19GeneratorFrameGuardC1Ev","__ZN9JSContext14enterGeneratorEP11JSGenerator","__ZN9JSContext14leaveGeneratorEP11JSGenerator","__ZN2js19GeneratorFrameGuardD1Ev","__ZN2js19GeneratorFrameGuardD2Ev","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE6appendIS2_EEbT_","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE13growStorageByEj","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE20convertToHeapStorageEj","__ZL14JSID_FROM_BITSj1979","__ZNK2js6detail14HashTableEntryIKiE10getKeyHashEv","_JSID_TO_STRING1974","_JSID_IS_OBJECT1976","_JSID_TO_OBJECT1977","_INT_TO_JSID1982","__ZN2js15NativeIterCache8getIndexEj","__ZNK2js6detail14HashTableEntryIKiE9isRemovedEv","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E10overloadedEv","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5hash1Ejj","__ZNK2js6detail14HashTableEntryIKiE6isFreeEv","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5hash2Ejjj","__ZN2js10VectorImplIP11JSGeneratorLj2ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_","__ZN19IndexRangePredicateC2Eii","__ZN17SingleIdPredicateC2Ei","__ZN2js10VectorImplIiLj8ENS_15TempAllocPolicyELb1EE13copyConstructIiEEvPiPKT_S7_","__ZN2js6detail14HashTableEntryIKiE7setLiveEj","__ZN2js6detail14HashTableEntryIKiE12setCollisionEv","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryIKiE14unsetCollisionEv","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIP11JSGeneratorLj2ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj2ES3_EEj","__ZN2js10VectorImplIP11JSGeneratorLj2ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js19GeneratorFrameGuardC2Ev","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE7reserveEj","__ZN2JSL11StringValueEP8JSString1973","__ZN2JSL10Int32ValueEi1975","__ZN2JSL12BooleanValueEb1988","__ZN2js10EmptyShape23getEmptyEnumeratorShapeEP9JSContext","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE1991","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1992","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1993","__ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEEC1ES2_","__ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE4initEj","__ZL25EnumerateNativePropertiesP9JSContextP8JSObjectS2_jRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE","__ZL29EnumerateDenseArrayPropertiesP9JSContextP8JSObjectS2_jRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE","__ZL9EnumerateP9JSContextP8JSObjectS2_ibjRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE","__ZN8JSObject9enumerateEP9JSContext11JSIterateOpPN2JS5ValueEPi","__ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEED1Ev","__ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEED2Ev","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_ED1Ev","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_ED2Ev","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E12destroyTableERS5_PNS0_14HashTableEntryIS2_EEj","__ZNK2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE12lookupForAddERKi","__ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3PtrcvMS9_FvvEEv","__ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE3addERNS_6detail9HashTableIKiNS3_6SetOpsES2_E6AddPtrERS6_","__ZN2js16AutoVectorRooterIiE6appendERKi","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE6appendIiEEbT_","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE14internalAppendIiEEvT_","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIiLj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIiLj8ES1_EEj","__ZN2js10VectorImplIiLj8ENS_15TempAllocPolicyELb1EE13moveConstructIiEEvPiPKT_S7_","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3addERNS8_6AddPtrERS2_","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3addERNS8_6AddPtrE","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E15changeTableSizeEi","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E13findFreeEntryEj","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E11createTableERS5_j","__ZNK2js6detail14HashTableEntryIKiE6isLiveEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryIKiEEEptEv","__ZNK2js7MoveRefIiEcvRiEv","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3Ptr7nonNullEv","__ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOps6getKeyERKi","__ZN12IdHashPolicy4hashEi","__ZN2js6detail14HashTableEntryIKiE10isLiveHashEj","__ZN2js6detail14HashTableEntryIKiE9matchHashEj","__ZN12IdHashPolicy5matchEii","_JSID_IS_DEFAULT_XML_NAMESPACE","__ZL15JSDOUBLE_IS_NaNd2026","__ZL18JSDOUBLE_IS_FINITEd2027","__ZN2js7MoveRefINS_6detail14HashTableEntryIKiEEEC2ERS4_","__ZN2js7MoveRefIiEC2ERi","__ZN2js6detail14HashTableEntryIKiEC2Ev","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3PtrC2ERNS0_14HashTableEntryIS2_EE","__ZN2js6detail14HashTableEntryIKiE12setCollisionEj","__ZN2jsL7ReverseIiEEvPT_S2_1995","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_EC2ES5_","__ZL14random_setSeedP9JSContextx","__ZN2js6detail14HashTableEntryIKiEaSENS_7MoveRefIS3_EE","__ZN2js4MoveINS_6detail14HashTableEntryIKiEEEENS_7MoveRefIT_EERS6_","__ZN2js7MoveRefINS_6detail14HashTableEntryIKiEEEC1ERS4_","__ZN2js4MoveIiEENS_7MoveRefIT_EERS2_","__ZN2js7MoveRefIiEC1ERi","__ZN2js6detail14HashTableEntryIKiEC1Ev","__ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3Ptr5foundEv","__ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E12lookupForAddERS2_","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E11prepareHashERS2_","__ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E6lookupERS2_jj","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E6AddPtrC1ERNS0_14HashTableEntryIS2_EEj","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E6AddPtrC2ERNS0_14HashTableEntryIS2_EEj","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5matchERNS0_14HashTableEntryIS2_EERS2_","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E10isLiveHashEj","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E4initEj","__ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEEC2ES2_","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_EC1ES5_","_JS_CeilingLog2","__ZN2js9MathCacheC2Ev","__Z11js_math_absP9JSContextjPN2JS5ValueE","__Z17js_math_ceil_impld","__Z12js_math_ceilP9JSContextjPN2JS5ValueE","__Z18js_math_floor_impld","__Z13js_math_floorP9JSContextjPN2JS5ValueE","__Z11js_math_maxP9JSContextjPN2JS5ValueE","__Z11js_math_minP9JSContextjPN2JS5ValueE","__Z11js_math_powP9JSContextjPN2JS5ValueE","__ZL4powidi","__Z13js_InitRandomP9JSContext","__Z13js_math_roundP9JSContextjPN2JS5ValueE","__Z12js_math_sqrtP9JSContextjPN2JS5ValueE","__ZN2jsL12GetMathCacheEP9JSContext","__ZN2js9MathCache6lookupEPFddEd","__ZL13math_toSourceP9JSContextjPN2JS5ValueE","__ZL9math_acosP9JSContextjPN2JS5ValueE","__ZL9math_asinP9JSContextjPN2JS5ValueE","__ZL9math_atanP9JSContextjPN2JS5ValueE","__ZL10math_atan2P9JSContextjPN2JS5ValueE","__ZL8math_cosP9JSContextjPN2JS5ValueE","__ZN2jsL16GetClassProtoKeyEPNS_5ClassE2046","__ZN2js9MathCache4hashEd","__ZL20JSDOUBLE_IS_INFINITEd","__ZN2js2gcL15GetGCObjectKindEjb2034","__ZL13IMPL_TO_JSVAL12jsval_layout2047","_OBJECT_TO_JSVAL_IMPL2048","__ZL11random_nextP9JSContexti","__ZN2js12ToCStringBufC2Ev","__ZL8math_expP9JSContextjPN2JS5ValueE","__ZL8math_logP9JSContextjPN2JS5ValueE","__ZL11math_randomP9JSContextjPN2JS5ValueE","__ZL8math_sinP9JSContextjPN2JS5ValueE","__ZL8math_tanP9JSContextjPN2JS5ValueE","__Z16js_InitMathClassP9JSContextP8JSObject","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2032","_OBJECT_TO_JSVAL2033","__ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2035","__ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_2036","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2039","__ZL17random_nextDoubleP9JSContext","__ZL13math_exp_bodyd","__ZL17math_atan2_kerneldd","__ZN13JSCompartment12getMathCacheEP9JSContext","__ZN2js22GetNativeStackBaseImplEv","__ZN2js16GetPrefixIntegerEP9JSContextPKtS3_iPS3_Pd","__ZL29ComputeAccurateDecimalIntegerP9JSContextPKtS2_Pd","__ZL32ComputeAccurateBinaryBaseIntegerP9JSContextPKtS2_i","__ZL9num_isNaNP9JSContextjPN2JS5ValueE","__ZL12num_isFiniteP9JSContextjPN2JS5ValueE","__ZL14num_parseFloatP9JSContextjPN2JS5ValueE","__ZL12num_parseIntP9JSContextjPN2JS5ValueE","__ZN2js12ToCStringBufD2Ev","__Z14js_IntToStringP9JSContexti","__ZN2js13StaticStrings7hasUintEj","__ZN8JSObject8asNumberEv","__ZN2js9DtoaCache6lookupEid","__ZN13JSShortString23inlineStorageBeforeInitEv","__ZN2js9DtoaCache5cacheEidP13JSFixedString","__ZN13JSShortString20initAtOffsetInBufferEPKtj","__Z14js_num_valueOfP9JSContextjPN2JS5ValueE","__ZN2js16GetPrimitiveThisIdEEbP9JSContextPN2JS5ValueEPT_","__ZL12num_toSourceP9JSContextjPN2JS5ValueE","__ZL12num_toStringP9JSContextjPN2JS5ValueE","__ZL18num_toLocaleStringP9JSContextjPN2JS5ValueE","__ZL11num_toFixedP9JSContextjPN2JS5ValueE","__ZL17num_toExponentialP9JSContextjPN2JS5ValueE","__ZL15num_toPrecisionP9JSContextjPN2JS5ValueE","__ZN2js22InitRuntimeNumberStateEP9JSRuntime","__ZN2js24FinishRuntimeNumberStateEP9JSRuntime","__Z18js_InitNumberClassP9JSContextP8JSObject","__ZN2js12NumberObject17setPrimitiveValueEd","__ZL6NumberP9JSContextjPN2JS5ValueE","__ZL12ATOM_TO_JSIDP6JSAtom2097","__ZN2js15NumberToCStringEP9JSContextPNS_12ToCStringBufEdi","_JSDOUBLE_IS_INT322100","__ZL12IntToCStringPN2js12ToCStringBufEii","__ZN2jsL19FracNumberToCStringEP9JSContextPNS_12ToCStringBufEdi","__Z17js_NumberToStringP9JSContextd","__ZL25js_NumberToStringWithBaseP9JSContextdi","__ZN2js14NumberToStringEP9JSContextd","__ZN2js13IndexToStringEP9JSContextj","__ZN2js12NumberTraitsIdE10toSelfTypeEd","__ZNK7mozilla9RangedPtrIcEdeEv","__ZNK7mozilla9RangedPtrIcE3getEv","__ZL14JSID_FROM_BITSj2143","__ZN2js12NumberTraitsIdE3NaNEv","__ZNK2js7unicode13CharacterInfo7isSpaceEv","__ZL18JSDOUBLE_IS_FINITEd2111","__ZL15JSDOUBLE_IS_NaNd2114","_JSDOUBLE_IS_NEGZERO2132","__ZN7mozilla9RangedPtrIcEaSERKS1_","__ZN7mozilla9RangedPtrIcEaSIcEERS1_RKNS0_IT_EE","__ZN7mozilla9RangedPtrIcEC2EPcS2_j","__ZN2js2gcL15GetGCObjectKindEjb2146","__ZN2js25NumberValueToStringBufferEP9JSContextRKN2JS5ValueERNS_12StringBufferE","__ZN2js12StringBuffer14appendInflatedEPKcj","__ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd","__ZN2jsL18StringToNumberTypeIdEEbP9JSContextP8JSStringPT_","__ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE2103","__ZN2js20ValueToECMAInt32SlowEP9JSContextRKN2JS5ValueEPi","__ZL20js_DoubleToECMAInt32d2106","__ZN2js21ValueToECMAUint32SlowEP9JSContextRKN2JS5ValueEPj","__Z21js_DoubleToECMAUint32d","__ZN2js16ValueToInt32SlowEP9JSContextRKN2JS5ValueEPi","__ZN2js17ValueToUint16SlowEP9JSContextRKN2JS5ValueEPt","__Z9js_strtodP9JSContextPKtS2_PS2_Pd","__ZN2jsL9SkipSpaceEPKtS1_","__ZN2js7unicode7IsSpaceEt","__ZN2js6detail17PrimitiveBehaviorIdE6isTypeERKN2JS5ValueE","__ZN2js6detail17PrimitiveBehaviorIdE7extractERKN2JS5ValueE","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE19growByUninitializedEj","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10growByImplILb0EEEbj","__ZN7mozilla9RangedPtrIcEC1EPcS2_j","__ZN2js25BackfillIndexInCharBufferIcEEN7mozilla9RangedPtrIT_EEjS4_","__ZN7mozilla9RangedPtrIcEmmEv","__ZN7mozilla9RangedPtrIcEmIEj","__ZN7mozilla9RangedPtrIcEmiEj","__ZNK7mozilla9RangedPtrIcE6createEPc","__ZN2jsL14IsConstructingEPKN2JS5ValueE2144","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2145","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2147","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2148","__ZN2JSL11NumberValueEd2157","__ZL14js_hash_objectPKv","__ZN17BinaryDigitReader9nextDigitEv","__ZN17BinaryDigitReaderC2EiPKtS1_","__ZL6num_toP9JSContext12JSDToStrModeS1_iiijPN2JS5ValueE","__ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd2159","__ZL18js_DoubleToIntegerd2161","__ZL20ParseIntDoubleHelperd","__ZL20ParseIntStringHelperP9JSContextPKtS2_ibPd","__ZN17BinaryDigitReaderC1EiPKtS1_","__Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject","__ZL12obj_getProtoP9JSContextP8JSObjectiPN2JS5ValueE","__ZL12obj_setProtoP9JSContextP8JSObjectiiPN2JS5ValueE","__Z19js_EnterSharpObjectP9JSContextP8JSObjectPP9JSIdArrayPPt","__ZL16MarkSharpObjectsP9JSContextP8JSObjectPP9JSIdArray","__Z19js_LeaveSharpObjectP9JSContextPP9JSIdArray","__Z16js_TraceSharpMapP8JSTracerP16JSSharpObjectMap","__ZL27gc_sharp_table_entry_markerP11JSHashEntryiPv","__ZN2jsL16CastAsPropertyOpEP8JSObject2286","__ZN2js18obj_toStringHelperEP9JSContextP8JSObject","__ZN2js13NonNullObjectEP9JSContextRKN2JS5ValueE","__ZN2js21InformalValueTypeNameERKN2JS5ValueE","__ZN2js4evalEP9JSContextjPN2JS5ValueE","__ZL17WarnOnTooManyArgsP9JSContextRKN2js8CallArgsE","__ZL10EvalKernelP9JSContextRKN2js8CallArgsE8EvalTypePNS1_10StackFrameER8JSObject","__ZNK8JSObject9getGlobalEv","__ZN2js10DirectEvalEP9JSContextRKNS_8CallArgsE","__ZN2js21AutoFunctionCallProbeC1EP9JSContextP10JSFunctionP8JSScript","__ZN2js21IsBuiltinEvalForScopeEP8JSObjectRKN2JS5ValueE","__ZNK2js12GlobalObject15getOriginalEvalEv","__ZN2js25PrincipalsForCompiledCodeERKNS_8CallArgsEP9JSContext","__Z23js_HasOwnPropertyHelperP9JSContextPFiS0_P8JSObjectiPS2_PP10JSPropertyEjPN2JS5ValueE","__ZN2JSL14UndefinedValueEv2280","__Z17js_HasOwnPropertyP9JSContextPFiS0_P8JSObjectiPS2_PP10JSPropertyES2_iS3_S6_","__Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty","__Z23js_PropertyIsEnumerableP9JSContextP8JSObjectiPN2JS5ValueE","__Z19js_obj_defineGetterP9JSContextjPN2JS5ValueE","__ZL13js_IsCallableRKN2JS5ValueE2285","__ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj","__ZN2jsL22CastAsStrictPropertyOpEP8JSObject2289","__Z19js_obj_defineSetterP9JSContextjPN2JS5ValueE","__Z18obj_getPrototypeOfP9JSContextjPN2JS5ValueE","__ZN2jsL23DecompileValueGeneratorEP9JSContextiRKN2JS5ValueEP8JSString2290","__ZL12ATOM_TO_JSIDP6JSAtom2291","__ZN2js27NewPropertyDescriptorObjectEP9JSContextPK20JSPropertyDescriptorPN2JS5ValueE","__ZN2js8PropDesc26initFromPropertyDescriptorERK20JSPropertyDescriptor","__ZN2js8PropDesc10makeObjectEP9JSContext","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2296","__ZN2JSL12BooleanValueEb2297","__ZN2js24GetOwnPropertyDescriptorEP9JSContextP8JSObjectiP20JSPropertyDescriptor","__ZN2js24GetOwnPropertyDescriptorEP9JSContextP8JSObjectiPN2JS5ValueE","__ZN2js8PropDescC2Ev","__ZN2js8PropDesc10initializeEP9JSContextRKN2JS5ValueEb","__ZL11HasPropertyP9JSContextP8JSObjectiPN2JS5ValueEPb","__ZN2js14DefinePropertyEP9JSContextP8JSObjectRKiRKNS_8PropDescEbPb","__ZL21DefinePropertyOnArrayP9JSContextP8JSObjectRKiRKN2js8PropDescEbPb","__ZL6RejectP9JSContextP8JSObjectjbPb","__ZL22DefinePropertyOnObjectP9JSContextP8JSObjectRKiRKN2js8PropDescEbPb","__Z20js_DefineOwnPropertyP9JSContextP8JSObjectiRKN2JS5ValueEPi","__ZN2js23ReadPropertyDescriptorsEP9JSContextP8JSObjectbPNS_12AutoIdVectorEPNS_23AutoPropDescArrayRooterE","__Z17js_PopulateObjectP9JSContextP8JSObjectS2_","__ZL16DefinePropertiesP9JSContextP8JSObjectS2_","__ZN8JSObject12sealOrFreezeEP9JSContextNS_16ImmutabilityTypeE","__ZN8JSObject16isSealedOrFrozenEP9JSContextNS_16ImmutabilityTypeEPb","__ZL12obj_toSourceP9JSContextjPN2JS5ValueE","__ZL12obj_toStringP9JSContextjPN2JS5ValueE","__ZL18obj_toLocaleStringP9JSContextjPN2JS5ValueE","__ZL11obj_valueOfP9JSContextjPN2JS5ValueE","__ZL9obj_watchP9JSContextjPN2JS5ValueE","__ZL11obj_unwatchP9JSContextjPN2JS5ValueE","__ZL18obj_hasOwnPropertyP9JSContextjPN2JS5ValueE","__ZL17obj_isPrototypeOfP9JSContextjPN2JS5ValueE","__ZL24obj_propertyIsEnumerableP9JSContextjPN2JS5ValueE","__ZN2jsL15NewObjectGCKindEP9JSContextPNS_5ClassE","__ZL16obj_lookupGetterP9JSContextjPN2JS5ValueE","__ZL16obj_lookupSetterP9JSContextjPN2JS5ValueE","__ZL28obj_getOwnPropertyDescriptorP9JSContextjPN2JS5ValueE","__ZL8obj_keysP9JSContextjPN2JS5ValueE","__ZL18obj_definePropertyP9JSContextjPN2JS5ValueE","__ZL20obj_definePropertiesP9JSContextjPN2JS5ValueE","__ZL10obj_createP9JSContextjPN2JS5ValueE","__ZL23obj_getOwnPropertyNamesP9JSContextjPN2JS5ValueE","__ZL16obj_isExtensibleP9JSContextjPN2JS5ValueE","__ZL21obj_preventExtensionsP9JSContextjPN2JS5ValueE","__ZL10obj_freezeP9JSContextjPN2JS5ValueE","__ZL12obj_isFrozenP9JSContextjPN2JS5ValueE","__ZL8obj_sealP9JSContextjPN2JS5ValueE","__ZL12obj_isSealedP9JSContextjPN2JS5ValueE","__Z9js_ObjectP9JSContextjPN2JS5ValueE","__Z22js_ValueToObjectOrNullP9JSContextRKN2JS5ValueEPP8JSObject","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2318","__ZN2js17NewReshapedObjectEP9JSContextPNS_5types10TypeObjectEP8JSObjectNS_2gc9AllocKindEPKNS_5ShapeE","_JSID_IS_EMPTY2321","__ZN2jsL17NewObjectWithTypeEP9JSContextPNS_5types10TypeObjectEP8JSObjectNS_2gc9AllocKindE","__ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij","__Z13js_CreateThisP9JSContextP8JSObject","__ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE2326","__Z33js_CreateThisForFunctionWithProtoP9JSContextP8JSObjectS2_","__ZL29CreateThisForFunctionWithTypeP9JSContextPN2js5types10TypeObjectEP8JSObject","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE","__Z24js_CreateThisForFunctionP9JSContextP8JSObjectb","__Z9DetectingP9JSContextPh","__ZL12js_GetOpcodeP9JSContextP8JSScriptPh2329","__Z13js_InferFlagsP9JSContextj","__ZL19with_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty","__ZL18with_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty","__ZL18with_LookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty","__ZL15with_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE","__ZL16with_GetPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE","__ZL15with_GetElementP9JSContextP8JSObjectS2_jPN2JS5ValueE","__ZL15with_GetSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE","__ZL16with_SetPropertyP9JSContextP8JSObjectiPN2JS5ValueEi","__ZL15with_SetElementP9JSContextP8JSObjectjPN2JS5ValueEi","__ZL15with_SetSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZL18with_GetAttributesP9JSContextP8JSObjectiPj","__ZL25with_GetElementAttributesP9JSContextP8JSObjectjPj","__ZL25with_GetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj","__ZL18with_SetAttributesP9JSContextP8JSObjectiPj","__ZL25with_SetElementAttributesP9JSContextP8JSObjectjPj","__ZL25with_SetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj","__ZL11with_TypeOfP9JSContextP8JSObject","__ZNK8JSObject7watchedEv","__ZN2js2gcL15GetGCObjectKindEjb2335","__ZL19with_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi","__ZL18with_DeleteElementP9JSContextP8JSObjectjPN2JS5ValueEi","__ZL18with_DeleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZL14with_EnumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__ZL15with_ThisObjectP9JSContextP8JSObject","__Z16js_NewWithObjectP9JSContextP8JSObjectS2_i","__ZN2js10EmptyShape17getEmptyWithShapeEP9JSContext","__ZN2JSL10Int32ValueEi2332","__ZN8JSObject11setWithThisEPS_","__Z17js_NewBlockObjectP9JSContext","__ZN2js10EmptyShape18getEmptyBlockShapeEP9JSContext","__Z19js_CloneBlockObjectP9JSContextP8JSObjectPN2js10StackFrameE","__ZN8JSObject15initClonedBlockEP9JSContextPN2js5types10TypeObjectEPNS2_10StackFrameE","__ZN8JSObject27ensureInstanceReservedSlotsEP9JSContextj","__Z17js_PutBlockObjectP9JSContexti","__ZN8JSObject13copySlotRangeEjPKN2JS5ValueEj","__ZN8JSObject19defineBlockVariableEP9JSContextii","__ZL17block_getPropertyP9JSContextP8JSObjectiPN2JS5ValueE","__ZL17block_setPropertyP9JSContextP8JSObjectiiPN2JS5ValueE","__ZN8JSObject9growSlotsEP9JSContextj","__ZN8JSObject20nonNativeSetPropertyEP9JSContextiPN2JS5ValueEi","__ZN8JSObject18copyPropertiesFromEP9JSContextPS_","__ZN2js15AutoShapeVectorC1EP9JSContext","__ZN2js16AutoVectorRooterIPKNS_5ShapeEE6appendERKS3_","__ZNK2js16AutoVectorRooterIPKNS_5ShapeEE6lengthEv","__ZN2js16AutoVectorRooterIPKNS_5ShapeEEixEj","__ZN2js15AutoShapeVectorD1Ev","__ZN8JSObject5cloneEP9JSContextPS_S2_","__ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE2346","__ZL9CopySlotsP9JSContextP8JSObjectS2_","__ZN2jsL3MaxIjEET_S1_S1_2347","__ZN8JSObject16updateFixedSlotsEj","__Z15FindObjectIndexP13JSObjectArrayP8JSObject","__ZN8JSObject19ReserveForTradeGutsEP9JSContextPS_S2_RNS_17TradeGutsReservedE","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE7reserveEj","__ZN8JSObject9TradeGutsEP9JSContextPS_S2_RNS_17TradeGutsReservedE","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE16infallibleAppendERKS2_","__ZN8JSObject14clearSlotRangeEjj","__ZN8JSObject4swapEP9JSContextPS_","__ZN8JSObject17TradeGutsReservedC1EP9JSContext","__ZN8JSObject17TradeGutsReservedD1Ev","__Z17js_XDRBlockObjectP10JSXDRStatePP8JSObject","__ZN2js16AutoVectorRooterIPKNS_5ShapeEE6growByEj","__ZL12JSID_TO_ATOMi2352","__ZN2js2gcL14GetGCKindSlotsENS0_9AllocKindE2367","__ZNK2JS5ValueneERKS0_","__ZN2js2gcL21TryIncrementAllocKindEPNS0_9AllocKindE","__ZN2js29DefineConstructorAndPrototypeEP9JSContextP8JSObject10JSProtoKeyP6JSAtomS3_PNS_5ClassEPFiS1_jPN2JS5ValueEEjP14JSPropertySpecP14JSFunctionSpecSF_SH_PS3_","__ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2353","__ZL18DefineStandardSlotP9JSContextP8JSObject10JSProtoKeyP6JSAtomRKN2JS5ValueEjRb","__ZN2JSL11ObjectValueER8JSObject2354","__ZN2jsL14SetClassObjectEP9JSContextP8JSObject10JSProtoKeyS3_S3_","__ZN2JSL17ObjectOrNullValueEP8JSObject2355","__ZN2jsL16ClearClassObjectEP9JSContextP8JSObject10JSProtoKey","__ZN2js23IsStandardClassResolvedEP8JSObjectPNS_5ClassE","__ZN2js35MarkStandardClassInitializedNoProtoEP8JSObjectPNS_5ClassE","__Z12js_InitClassP9JSContextP8JSObjectS2_PN2js5ClassEPFiS0_jPN2JS5ValueEEjP14JSPropertySpecP14JSFunctionSpecSC_SE_PS2_","__Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE","__ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2364","__ZN8JSObject10allocSlotsEP9JSContextj","__ZN2js5types21MarkObjectStateChangeEP9JSContextP8JSObject","__ZN8JSObject11shrinkSlotsEP9JSContextj","__ZN2js8SetProtoEP9JSContextP8JSObjectS3_b","__ZN2jsL16GetClassProtoKeyEPNS_5ClassE2381","__Z17js_GetClassObjectP9JSContextP8JSObject10JSProtoKeyPS2_","__ZN2js13AutoResolvingC1EP9JSContextP8JSObjectiNS0_4KindE","__ZNK2js13AutoResolving14alreadyStartedEv","__ZN2js13AutoResolvingD1Ev","__Z18js_FindClassObjectP9JSContextP8JSObject10JSProtoKeyPN2JS5ValueEPN2js5ClassE","__ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty","__Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE","__ZN8JSObject9allocSlotEP9JSContextPj","__ZN8JSObject8freeSlotEP9JSContextj","__ZN2JSL18PrivateUint32ValueEj2384","__Z24js_PurgeScopeChainHelperP9JSContextP8JSObjecti","__ZL15PurgeProtoChainP9JSContextP8JSObjecti","__Z20js_AddNativePropertyP9JSContextP8JSObjectiPFiS0_S2_iPN2JS5ValueEEPFiS0_S2_iiS5_Ejjji","__Z28js_ChangeNativePropertyAttrsP9JSContextP8JSObjectPKN2js5ShapeEjjPFiS0_S2_iPN2JS5ValueEEPFiS0_S2_iiS9_E","__Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej","__Z16js_DefineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej","__ZN8JSObject18methodWriteBarrierEP9JSContextRKN2js5ShapeERKN2JS5ValueE","__ZL19CallAddPropertyHookP9JSContextPN2js5ClassEP8JSObjectPKNS1_5ShapeEPN2JS5ValueE","__ZL29LookupPropertyWithFlagsInlineP9JSContextP8JSObjectijPS2_PP10JSProperty","__Z16js_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty","__Z21js_FindPropertyHelperP9JSContextibbPP8JSObjectS3_PP10JSProperty","__ZNK2js12ContextStack25currentScriptedScopeChainEv","__ZN2jsL25IsCacheableNonGlobalScopeEP8JSObject2396","__Z15js_FindPropertyP9JSContextibPP8JSObjectS3_PP10JSProperty","__Z21js_FindIdentifierBaseP9JSContextP8JSObjecti","__Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE","__ZL18js_NativeGetInlineP9JSContextP8JSObjectS2_S2_PKN2js5ShapeEjPN2JS5ValueE","__Z12js_NativeSetP9JSContextP8JSObjectPKN2js5ShapeEbbPN2JS5ValueE","__ZN8JSObject18methodWriteBarrierEP9JSContextjRKN2JS5ValueE","__Z29js_ReportGetterOnlyAssignmentP9JSContext","__ZNK2js5Shape3setEP9JSContextP8JSObjectbPN2JS5ValueE","__ZN8JSObject14nativeContainsEP9JSContextRKN2js5ShapeE","__Z20js_GetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueE","__ZL26js_GetPropertyHelperInlineP9JSContextP8JSObjectS2_ijPN2JS5ValueE","__Z14js_GetPropertyP9JSContextP8JSObjectS2_iPN2JS5ValueE","__Z13js_GetElementP9JSContextP8JSObjectS2_jPN2JS5ValueE","__ZN2js18GetPropertyDefaultEP9JSContextP8JSObjectiRKN2JS5ValueEPS5_","__Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE","__Z31js_CheckUndeclaredVarAssignmentP9JSContextP8JSString","__ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind2415","__ZN8JSObject14reportReadOnlyEP9JSContextij","__ZN2jsL9IdToValueEi2416","__ZN8JSObject21reportNotConfigurableEP9JSContextij","__ZN8JSObject19reportNotExtensibleEP9JSContextj","__ZN8JSObject10callMethodEP9JSContextijPN2JS5ValueES4_","_JSID_TO_STRING2421","__ZNK2js5Shape10hasShortIDEv","__ZeqRK8JSObjectS1_2422","_INT_TO_JSID2431","__ZN2js2gcL6GCPokeEP9JSContextN2JS5ValueE","__Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi","__ZN2js10CallSetterEP9JSContextP8JSObjectiPFiS1_S3_iiPN2JS5ValueEEjjiS6_","__ZNK2js5Shape10shadowableEv","__ZL25CloneFunctionForSetMethodP9JSContextPN2JS5ValueE","__Z19js_SetElementHelperP9JSContextP8JSObjectjjPN2JS5ValueEi","__Z16js_GetAttributesP9JSContextP8JSObjectiPj","__Z23js_GetElementAttributesP9JSContextP8JSObjectjPj","__ZN8JSObject20getElementAttributesEP9JSContextjPj","__Z22js_SetNativeAttributesP9JSContextP8JSObjectPN2js5ShapeEj","__Z16js_SetAttributesP9JSContextP8JSObjectiPj","__Z23js_SetElementAttributesP9JSContextP8JSObjectjPj","__ZN8JSObject20setElementAttributesEP9JSContextjPj","__Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN2js16CallJSPropertyOpEP9JSContextPFiS1_P8JSObjectiPN2JS5ValueEES3_iS6_","__ZN2jsL8JsvalifyEPNS_5ClassE2452","__ZN2jsL8ValueifyEP7JSClass2453","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE3endEv","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject2432","__Z16js_DeleteElementP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN2js15HasDataPropertyEP9JSContextP8JSObjectiPN2JS5ValueE","__ZN2js12DefaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE","__ZN2jsL19ClassMethodIsNativeEP9JSContextP8JSObjectPNS_5ClassEiPFiS1_jPN2JS5ValueEE","__ZN2jsL15MaybeCallMethodEP9JSContextP8JSObjectiPN2JS5ValueE","__Z12js_EnumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__Z9js_TypeOfP9JSContextP8JSObject","__Z13js_IsDelegateP9JSContextP8JSObjectRKN2JS5ValueE","__ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE","__ZN2jsL16IsFunctionObjectERKN2JS5ValueE2445","__Z17PrimitiveToObjectP9JSContextRKN2JS5ValueE","__ZN2js12StringObject6createEP9JSContextP8JSString","__ZN2js12NumberObject6createEP9JSContextd","__Z20js_PrimitiveToObjectP9JSContextPN2JS5ValueE","__ZN2js12ToObjectSlowEP9JSContextPN2JS5ValueE","__Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE","__Z12js_XDRObjectP10JSXDRStatePP8JSObject","__Z14js_ClearNativeP9JSContextP8JSObject","__ZL21LastConfigurableShapeP8JSObject","__Z18js_GetReservedSlotP9JSContextP8JSObjectjPN2JS5ValueE","__Z18js_SetReservedSlotP9JSContextP8JSObjectjRKN2JS5ValueE","__ZN2JSL9NullValueEv2460","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE19growByUninitializedEj","__ZN2jsL15MakeRangeGCSafeEPPKNS_5ShapeES3_","__ZN2jsL7PodZeroIPKNS_5ShapeEEEvPT_j","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE13growStorageByEj","__ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js5Shape8setterOpEv","__ZNK2js5Shape8getterOpEv","__ZL16js_InitNullClassP9JSContextP8JSObject","_JSID_IS_STRING2486","_JSID_IS_INT2487","_JSID_TO_INT2488","_JSID_IS_OBJECT2489","_JSID_TO_OBJECT2490","__ZN8JSObject8asStringEv","__ZN2js10VectorImplIPKNS_5ShapeELj8ENS_15TempAllocPolicyELb1EE13copyConstructIS3_EEvPS3_PKT_SA_","__ZN2js13AutoResolvingD2Ev","__ZN2js13AutoResolvingC2EP9JSContextP8JSObjectiNS0_4KindE","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIPKNS_5ShapeELj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS3_Lj8ES4_EEj","__ZN2js10VectorImplIPKNS_5ShapeELj8ENS_15TempAllocPolicyELb1EE13moveConstructIS3_EEvPS3_PKT_SA_","__ZN2js6detailL9NewObjectILb1ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2464","__ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2465","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2468","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEEixEj","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE6appendIS3_EEbT_","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_","__ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2469","__ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_2470","__ZN2js6detailL9NewObjectILb0ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2471","__ZN2js12StringObject4initEP9JSContextP8JSString","__ZN2js12StringObject13setStringThisEP8JSString","__ZN2JSL11StringValueEP8JSString2480","__ZN2jsL16IsNativeFunctionERKN2JS5ValueEPFiP9JSContextjPS1_E","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP10JSFunction2483","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction2484","__ZN2js22CallJSPropertyOpSetterEP9JSContextPFiS1_P8JSObjectiiPN2JS5ValueEES3_iiS6_","__ZL12JSID_IS_ATOMiP6JSAtom2491","__ZNK2js5Shape11setterValueEv","__ZL18ChangesMethodValueRKN2JS5ValueES2_","__ZNK2js5Shape3getEP9JSContextP8JSObjectS4_S4_PN2JS5ValueE","__ZNK2js5Shape11getterValueEv","__ZL13CallResolveOpP9JSContextP8JSObjectS2_ijPS2_PP10JSPropertyPb","__ZN8JSObject17TradeGutsReservedD2Ev","__ZN8JSObject17TradeGutsReservedC2EP9JSContext","__ZN2js15AutoShapeVectorD2Ev","__ZN2js16AutoVectorRooterIPKNS_5ShapeEED2Ev","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEED1Ev","__ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE2500","__ZL14JSID_FROM_BITSj2517","__ZNK15EvalScriptGuard6scriptEv","__ZNK2js8PropDesc16isDataDescriptorEv","__ZNK2js8PropDesc20isAccessorDescriptorEv","__ZNK2js8PropDesc8writableEv","__ZNK2js8PropDesc12configurableEv","__ZNK2js8PropDesc10enumerableEv","__ZN15EvalScriptGuard11foundScriptEv","__ZNK2js8PropDesc11getterValueEv","__ZNK2js8PropDesc11setterValueEv","__ZN2js21AutoFunctionCallProbeC2EP9JSContextP10JSFunctionP8JSScript","__ZN15EvalScriptGuard12setNewScriptEP8JSScript","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEED2Ev","__ZN2js15AutoShapeVectorC2EP9JSContext","__ZN2js16AutoVectorRooterIPKNS_5ShapeEEC2EP9JSContexti","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEEC1ES4_","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEEC2ES4_","__Z23js_LiveFrameIfGeneratorPN2js10StackFrameE","__ZN8JSObject15getFixedSlotRefEj","__ZNK8JSObject11getWithThisEv","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2510","__ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject","__ZL12JSID_IS_ATOMi2511","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2514","__ZL17obj_watch_handlerP9JSContextP8JSObjectiN2JS5ValueEPS4_Pv","__ZN2jsL12PodArrayZeroIN2JS5ValueELj4EEEvRAT0__T_2515","__ZNK2js8PropDesc19isGenericDescriptorEv","__ZNK2js8PropDesc6getterEv","__ZNK2js8PropDesc6setterEv","__ZNK2js5Shape17getterOrUndefinedEv","__ZNK2js5Shape17setterOrUndefinedEv","__ZL6RejectP9JSContextjbiPb","__ZNK2js8PropDesc12setterObjectEv","__ZNK2js8PropDesc12getterObjectEv","__ZN10JSONParserC1EP9JSContextPKtjNS_11ParsingModeENS_13ErrorHandlingE","__ZN15EvalScriptGuardC1EP9JSContextP14JSLinearString","__ZN15EvalScriptGuard17lookupInEvalCacheEPN2js10StackFrameEjP12JSPrincipalsR8JSObject","__ZN15EvalScriptGuardD1Ev","__ZN15EvalScriptGuardD2Ev","__ZL15EvalCacheLookupP9JSContextP14JSLinearStringPN2js10StackFrameEjP12JSPrincipalsR8JSObjectPP8JSScript","__ZN8JSScript17getCallerFunctionEv","__ZN15EvalScriptGuardC2EP9JSContextP14JSLinearString","__ZL13EvalCacheHashP9JSContextP14JSLinearString","__ZN10JSONParserC2EP9JSContextPKtjNS_11ParsingModeENS_13ErrorHandlingE","__Z13js_json_parseP9JSContextjPN2JS5ValueE","__ZN2JSL14UndefinedValueEv2537","__ZN2js20ParseJSONWithReviverEP9JSContextPKtjRKN2JS5ValueEPS5_12DecodingMode","__Z17js_json_stringifyP9JSContextjPN2JS5ValueE","_INT_FITS_IN_JSID2543","_INT_TO_JSID2544","__ZN2js2gcL15GetGCObjectKindEjb2555","__Z12js_StringifyP9JSContextPN2JS5ValueEP8JSObjectS2_RN2js12StringBufferE","__ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEEC1ES3_","__ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE4initEj","__ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi2542","__ZNK2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE12lookupForAddERKi","__ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3PtrcvMSA_FvvEEv","__ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE3addERNS_6detail9HashTableIKiNS4_6SetOpsES3_E6AddPtrERS7_","__ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED1Ev","__ZN2JSL11NumberValueEd2545","__ZN2JSL11StringValueEP8JSString2546","__ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd2547","__ZN2js12StringBuffer7appendNEtj","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2548","__ZL12ATOM_TO_JSIDP6JSAtom2549","__ZN16StringifyContextC1EP9JSContextRN2js12StringBufferERKS3_P8JSObjectRKNS2_12AutoIdVectorE","__ZN16StringifyContext4initEv","__ZL15PreprocessValueIiEbP9JSContextP8JSObjectT_PN2JS5ValueEP16StringifyContext","__ZL15IsFilteredValueRKN2JS5ValueE","__ZL3StrP9JSContextRKN2JS5ValueEP16StringifyContext","__ZN16StringifyContextD1Ev","__ZL13js_IsCallableRKN2JS5ValueE2550","__ZL6ReviveP9JSContextRKN2JS5ValueEPS2_","__ZL13json_toSourceP9JSContextjPN2JS5ValueE","__Z16js_InitJSONClassP9JSContextP8JSObject","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2553","_OBJECT_TO_JSVAL2554","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3Ptr7nonNullEv","__ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOps6getKeyERKi","__ZN2js13DefaultHasherIiE4hashERKi","__ZN2jsL16GetClassProtoKeyEPNS_5ClassE2566","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E10overloadedEv","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5hash1Ejj","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5hash2Ejjj","__ZN2js13DefaultHasherIiE5matchERKiS3_","_JSID_IS_STRING2575","_JSID_TO_STRING2576","_JSID_IS_INT2577","_JSID_TO_INT2578","_JSID_IS_OBJECT2581","_JSID_TO_OBJECT2582","_JSDOUBLE_IS_NEGZERO2573","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E16setTableSizeLog2Ej","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3PtrC2ERNS0_14HashTableEntryIS2_EE","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_EC2ES6_","_OBJECT_TO_JSVAL_IMPL2574","__ZL13IMPL_TO_JSVAL12jsval_layout2583","__ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2556","__ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_2557","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2560","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3addERNS9_6AddPtrERS2_","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3addERNS9_6AddPtrE","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E15changeTableSizeEi","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E13findFreeEntryEj","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E11createTableERS6_j","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E12destroyTableERS6_PNS0_14HashTableEntryIS2_EEj","__ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3Ptr5foundEv","__ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E12lookupForAddERS2_","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E11prepareHashERS2_","__ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E6lookupERS2_jj","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E6AddPtrC1ERNS0_14HashTableEntryIS2_EEj","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E6AddPtrC2ERNS0_14HashTableEntryIS2_EEj","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5matchERNS0_14HashTableEntryIS2_EERS2_","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E10isLiveHashEj","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E4initEj","__ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEEC2ES3_","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_EC1ES6_","__ZN14KeyStringifierIiE8toStringEP9JSContexti","__ZN2JSL11ObjectValueER8JSObject2569","_JSDOUBLE_IS_INT322570","__ZN2jsL10IdToStringEP9JSContexti","__ZN2jsL9IdToValueEi2579","__ZN2JSL10Int32ValueEi2580","__ZL4WalkP9JSContextP8JSObjectiRKN2JS5ValueEPS4_","__ZN16StringifyContextD2Ev","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_ED1Ev","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6SetOps6getKeyERKS2_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5hash1Ejj","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5hash2Ejjj","__ZL18JSDOUBLE_IS_FINITEd2585","__ZN7mozilla15AlignedStorage2IN2js12AutoIdVectorEE4addrEv","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E11underloadedEv","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE","__ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE3endEv","__ZN7mozilla5MaybeIN2js12AutoIdVectorEEC2Ev","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_ED2Ev","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj","__ZL5QuoteP9JSContextRN2js12StringBufferEP8JSString","__ZL2JAP9JSContextP8JSObjectP16StringifyContext","__ZL2JOP9JSContextP8JSObjectP16StringifyContext","__ZN13CycleDetectorC1EP16StringifyContextP8JSObject","__ZN13CycleDetector4initEP9JSContext","__ZN7mozilla5MaybeIN2js12AutoIdVectorEEC1Ev","__ZN7mozilla5MaybeIN2js12AutoIdVectorEE9constructIP9JSContextEEvRKT_","__ZN7mozilla5MaybeIN2js12AutoIdVectorEE4addrEv","__ZNK2js16AutoVectorRooterIiEixEj","__ZL11WriteIndentP9JSContextP16StringifyContextj","__ZN7mozilla5MaybeIN2js12AutoIdVectorEED1Ev","__ZN13CycleDetectorD1Ev","__ZN13CycleDetectorD2Ev","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeERKS2_","__ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_","__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS6_6SetOpsES5_E3PtrE","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS4_EE","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E15changeTableSizeEi","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E11createTableERS8_j","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E13findFreeEntryEj","__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3Ptr5foundEv","__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6lookupERS4_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E11prepareHashERS4_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE","__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6lookupERS4_jj","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E10isLiveHashEj","__ZN7mozilla5MaybeIN2js12AutoIdVectorEED2Ev","__ZN7mozilla5MaybeIN2js12AutoIdVectorEE3asTEv","__ZN2js12StringBuffer6appendEPKtS2_","__ZNK2js12StringBuffer5beginEv","__ZNK2js12StringBuffer3endEv","__ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEEixEj","__ZL14JSID_FROM_BITSj2592","__ZN10JSONParser5tokenENS_5TokenE","__ZNK7mozilla9RangedPtrIKtE3getEv","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E10overloadedEv","__ZL23IsQuoteSpecialCharactert","__ZN10JSONParser11errorReturnEv","__ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE","__ZL15JSDOUBLE_IS_NaNd2597","__ZN13CycleDetectorC2EP16StringifyContextP8JSObject","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_EC2ES8_","__ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE14copyConstructNEPtjRKt","__ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS6_6SetOpsES5_E6AddPtrERS9_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS4_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE","__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E12lookupForAddERS4_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj","__ZL15PreprocessValueIjEbP9JSContextP8JSObjectT_PN2JS5ValueEP16StringifyContext","__ZN14KeyStringifierIjE8toStringEP9JSContextj","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E4initEj","__ZN16StringifyContextC2EP9JSContextRN2js12StringBufferERKS3_P8JSObjectRKNS2_12AutoIdVectorE","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_EC1ES8_","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2593","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2594","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE7appendNERKtj","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE15internalAppendNERKtj","__ZL18js_DoubleToIntegerd2596","__ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED2Ev","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_ED1Ev","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_ED2Ev","__ZN10JSONParser5errorEPKc","__ZN10JSONParser10readNumberEv","__ZN10JSONParser11numberTokenEd","__ZL16IsJSONWhitespacet","__ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE","__ZNK7mozilla9RangedPtrIKtEmiERKS2_","__ZN10JSONParser7advanceEv","__ZN10JSONParser10readStringILNS_10StringTypeE1EEENS_5TokenEv","__ZNK7mozilla9RangedPtrIKtEixEi","__ZN10JSONParser22advanceAfterObjectOpenEv","__ZN10JSONParser10readStringILNS_10StringTypeE0EEENS_5TokenEv","__ZN10JSONParser24advanceAfterArrayElementEv","__ZN10JSONParser19advancePropertyNameEv","__ZN10JSONParser20advancePropertyColonEv","__ZN10JSONParser20advanceAfterPropertyEv","__ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js7MoveRefI11ParserStateEcvRS1_Ev","__ZL14JSID_FROM_BITSj2665","__ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE5emptyEv","__ZNK10JSONParser11stringValueEv","__ZNK10JSONParser11numberValueEv","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE7popBackEv","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE3endEv","__ZN2js7MoveRefI11ParserStateEC2ERS1_","__ZN7mozilla9RangedPtrIKtEaSERKS2_","__ZN2js2gcL15GetGCObjectKindEjb2650","__ZN10JSONParser5parseEPN2JS5ValueE","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEEC1ES2_","__ZN2JSL14UndefinedValueEv2637","__ZN2js16AutoVectorRooterIN2JS5ValueEE7popCopyEv","__ZL12ATOM_TO_JSIDP6JSAtom2638","__ZNK10JSONParser9atomValueEv","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE6appendIS1_EEbT_","__ZN2JSL12BooleanValueEb2639","__ZN2JSL9NullValueEv2640","__ZN2JSL11ObjectValueER8JSObject2641","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2642","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE4backEv","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE7popCopyEv","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE14internalAppendIS1_EEvT_","__ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplI11ParserStateLj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj0ES2_EEj","__ZN2js4MoveI11ParserStateEENS_7MoveRefIT_EERS3_","__ZN2js7MoveRefI11ParserStateEC1ERS1_","__ZN2js10VectorImplI11ParserStateLj0ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_","__ZN2js4MoveI11ParserStateEENS_7MoveRefIT_EERKS3_","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE7popCopyEv","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE4backEv","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEED2Ev","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEEC2ES2_","__ZN10JSONParser11stringTokenEP8JSString","__ZN2JSL11StringValueEP8JSString2648","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2651","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2652","__ZN2JSL11NumberValueEd2666","_js_GetIndexFromBytecode","__ZL12js_GetOpcodeP9JSContextP8JSScriptPh2825","__Z28js_GetVariableBytecodeLength4JSOpPh","_js_GetVariableStackUses","_js_GetEnterBlockStackDefs","__ZL18SprintEnsureBufferPN2js8SprinterEj","__ZN2js9SprintPutEPNS_8SprinterEPKcj","__ZN2js13SprintCStringEPNS_8SprinterEPKc","__ZN2js12SprintStringEPNS_8SprinterEP8JSString","__ZN2js6SprintEPNS_8SprinterEPKcz","_js_QuoteString","__ZL11QuoteStringPN2js8SprinterEP8JSStringj","_js_NewPrinter","__ZN9JSContext4new_IN2js6VectorIP6JSAtomLj0ENS1_15TempAllocPolicyEEEPS_EEPT_T0_","_js_DestroyPrinter","__ZN2js10Foreground7delete_INS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEEEEvPT_","_js_GetPrinterOutput","_js_printf","_js_puts","__ZL10StackDepthP8JSScript","__Z8GetLocalP11SprintStacki","__ZL6GetStrP11SprintStackj","__ZL12JSID_IS_ATOMi2840","__ZL12JSID_TO_ATOMi2841","__ZL13DecompileBodyP9JSPrinterP8JSScriptPh","_js_DecompileToString","_js_DecompileFunction","__ZN19AutoScriptUntrapperC1EP9JSContextP8JSScriptPPh","__ZL15GetArgOrVarAtomP9JSPrinterj","__ZL15InitSprintStackP9JSContextP11SprintStackP9JSPrinterj","__ZN2js10StackFrame13clearImacropcEv","__ZN2js10StackFrame11setImacropcEPh","__ZL13GetJumpOffsetPhS_","__ZL22DecompileDestructuringP11SprintStackPhS1_","__ZL6PopStrP11SprintStack4JSOp","__ZN19AutoScriptUntrapperD1Ev","_js_DecompileValueGenerator","__ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind2852","__ZL18ReconstructPCStackP9JSContextP8JSScriptPhPS3_","__ZL19DecompileExpressionP9JSContextP8JSScriptP10JSFunctionPh","_js_ReconstructStackDepth","__ZN2js17GetBytecodeLengthEP9JSContextP8JSScriptPh","__ZN2js21IsValidBytecodeOffsetEP9JSContextP8JSScriptj","__ZN2js13BytecodeRangeC1EP9JSContextP8JSScript","_js_free2859","__ZL10SimulateOpP9JSContextP8JSScript4JSOpPK10JSCodeSpecPhPS7_Rj","_js_GetStackUses2860","_js_GetStackDefs","__ZL13DecompileCodeP9JSPrinterP8JSScriptPhjj","__ZL9DecompileP11SprintStackPhi4JSOp","_JSVAL_TO_INT32_IMPL2866","__ZL15IsInitializerOph","_JSVAL_IS_STRING_IMPL2869","_JSVAL_IS_DOUBLE_IMPL2870","_JSVAL_TO_STRING_IMPL2873","_JSDOUBLE_IS_NEGZERO2875","__ZL18JSDOUBLE_IS_FINITEd2876","__ZL15JSDOUBLE_IS_NaNd2877","__ZL9IsVarSlotP9JSPrinterPhPi","__ZN2jsL18GetDecomposeLengthEPhj2861","__ZL14CompareOffsetsPvPKvS1_Pi","__ZL13JSVAL_TO_IMPLN2JS5ValueE2867","__ZL13IMPL_TO_JSVAL12jsval_layout2871","_INT32_TO_JSVAL_IMPL2872","__ZL6PopOffP11SprintStack4JSOp","__ZL10PopOffPrecP11SprintStackh","__ZL6GetOffP11SprintStackj","__ZL10PopStrPrecP11SprintStackh","__ZL24DecompileGroupAssignmentP11SprintStackPhS1_S1_Pi","__ZL7PushOffP11SprintStacki4JSOp","__ZL9VarPrefixPh","__ZL12AddParenSlopP11SprintStack","_DOUBLE_TO_JSVAL2862","__ZL17SprintDoubleValuePN2js8SprinterEN2JS5ValueEP4JSOp","__ZN2JSL11ObjectValueER8JSObject2863","_JSVAL_TO_STRING2864","_INT_TO_JSVAL2865","__ZL15DecompileSwitchP11SprintStackP10TableEntryjPhiii","_JSVAL_TO_INT","_JSVAL_IS_DOUBLE","_JSVAL_IS_STRING2868","_JSVAL_TO_DOUBLE","_JSID_TO_STRING2878","_JSID_IS_STRING2879","__ZNK13JSFunctionBox17scopeIsExtensibleEv","__ZN2js6Parser13setPrincipalsEP12JSPrincipals","__ZNK13JSFunctionBox17inAnyDynamicScopeEv","__ZNK13JSFunctionBox13shouldUnbrandEjj","__ZL25DecompileDestructuringLHSP11SprintStackPhS1_Pi","__ZN19AutoScriptUntrapperD2Ev","__ZN19AutoScriptUntrapperC2EP9JSContextP8JSScriptPPh","__ZN11JSParseNode6becomeEPS_","__ZN11JSParseNode5clearEv","__ZN2js6ParserC2EP9JSContextP12JSPrincipalsPNS_10StackFrameEb","__ZN2jsL12PodArrayZeroIPvLj6EEEvRAT0__T_","__ZN2js6Parser4initEPKtjPKcj9JSVersion","__ZN9JSContext18ensureParseMapPoolEv","__ZN2js6ParserD2Ev","__ZN2js6Parser12newObjectBoxEP8JSObject","__ZN2js6Parser14newFunctionBoxEP8JSObjectP11JSParseNodeP13JSTreeContext","__ZNK13JSFunctionBox8joinableEv","__ZN2js6Parser5traceEP8JSTracer","__ZN2js6Parser17cleanFunctionListEPP13JSFunctionBox","__ZN11JSParseNode8initListEPS_","__ZN11JSParseNode6appendEPS_","__ZN13JSTreeContext13setScopeChainEP8JSObject","__ZL17AddNodeToFreeListP11JSParseNodePN2js6ParserE","__ZN11JSParseNode6createE16JSParseNodeArityP13JSTreeContext","__ZN11JSParseNode6createE16JSParseNodeArityN2js9TokenKindE4JSOpRKNS1_8TokenPosEP13JSTreeContext","__ZL17NewOrRecycledNodeP13JSTreeContext","__ZN11JSParseNode4initEN2js9TokenKindE4JSOp16JSParseNodeArity","__ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext","__ZL11RecycleTreeP11JSParseNodeP13JSTreeContext","__ZN2js8NameNode6createEP6JSAtomP13JSTreeContext","__ZN2js8NameNode10initCommonEP13JSTreeContext","__ZN2js6Parser5parseEP8JSObject","__ZN13JSTreeContextC1EPN2js6ParserE","__ZL15GenerateBlockIdP13JSTreeContextRj","__ZN2js6Parser10statementsEv","__ZN2js11TokenStream10matchTokenENS_9TokenKindE","__ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz","_js_FoldConstants","__ZN13JSTreeContextD1Ev","__ZN2js8CompilerC2EP9JSContextP12JSPrincipalsPNS_10StackFrameE","__ZNK2js11TokenStream9getLinenoEv","__ZN2js8Compiler13compileScriptEP9JSContextP8JSObjectPNS_10StackFrameEP12JSPrincipalsjPKtjPKcj9JSVersionP8JSStringj","__ZN2js8Compiler4initEPKtjPKcj9JSVersion","__ZN2js11GlobalScopeC1EP9JSContextP8JSObjectP15JSCodeGenerator","__ZL14SetStaticLevelP13JSTreeContextj","__ZN2js11TokenStream13setStrictModeEb","__ZN2js11TokenStream23setOctalCharacterEscapeEb","__ZN2js11TokenStream9peekTokenEj","__ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE6lengthEv","__ZN2jsL13TreeTypeIsXMLENS_9TokenKindE","__ZN2js6Parser9statementEv","__ZN2js6Parser26recognizeDirectivePrologueEP11JSParseNodePb","__ZN2js6Parser16analyzeFunctionsEP13JSTreeContext","__ZNK15JSCodeGenerator10sharpSlotsEv","__ZN2js8Compiler13defineGlobalsEP9JSContextRNS_11GlobalScopeEP8JSScript","__ZN2js11GlobalScopeD1Ev","__ZN2js8CompilerD1Ev","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEEixEj","__ZNK2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE6lengthEv","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE7popBackEv","__ZN8JSScript7globalsEv","__ZN10JSFunction11setArgCountEt","__ZN2js11TokenStream17mungeCurrentTokenENS_9TokenKindE","__ZL12ATOM_TO_JSIDP6JSAtom2903","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEEC1ES3_","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE6appendIS2_EEbT_","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE4backEv","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEED1Ev","__Z21CheckStrictAssignmentP9JSContextP13JSTreeContextP11JSParseNode","__Z18CheckStrictBindingP9JSContextP13JSTreeContextP6JSAtomP11JSParseNode","__ZN2js6Parser12functionBodyEv","__ZN2js9UnaryNode6createEP13JSTreeContext","__ZN2js6Parser10assignExprEv","__ZL15ReportBadReturnP9JSContextP13JSTreeContextP11JSParseNodejjj","__ZL16CheckFinalReturnP9JSContextP13JSTreeContextP11JSParseNode","__ZN2js8Compiler19compileFunctionBodyEP9JSContextP10JSFunctionP12JSPrincipalsPNS_8BindingsEPKtjPKcj9JSVersion","__ZN2js12FunctionNode6createEP13JSTreeContext","__ZL9DefineArgP11JSParseNodeP6JSAtomjP13JSTreeContext","__ZL21CheckStrictParametersP9JSContextP13JSTreeContext","__ZN2js6Parser11newFunctionEP13JSTreeContextP6JSAtomNS_18FunctionSyntaxKindE","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Entry5valueEv","__ZN18JSFunctionBoxQueue4pullEv","__ZN11JSParseNode9setFunArgEv","__ZN18JSFunctionBoxQueue4pushEP13JSFunctionBox","__ZN10JSFunction7setKindEt","__ZN2js6Parser11markFunArgsEP13JSFunctionBox","__ZN2js6Parser30markExtensibleScopeDescendantsEP13JSFunctionBoxb","__ZN2js6Parser16setFunctionKindsEP13JSFunctionBoxPj","__ZN18JSFunctionBoxQueueC1Ev","__ZN18JSFunctionBoxQueue4initEj","__ZL11FindFunArgsP13JSFunctionBoxiP18JSFunctionBoxQueue","__ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3allEv","__ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5frontEv","__ZN12JSDefinition7resolveEv","__ZNK12JSDefinition9isFreeVarEv","__ZNK11JSParseNode8isFunArgEv","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range8popFrontEv","__ZN18JSFunctionBoxQueueD1Ev","__ZL18ConsiderUnbrandingP13JSFunctionBox","__ZL15CanFlattenUpvarP12JSDefinitionP13JSFunctionBoxj","__ZN2js8Bindings20setExtensibleParentsEv","__ZN12JSDefinition10kindStringENS_4KindE","__ZN11JSParseNode9makeEmptyEv","__ZN13JSTreeContext11atBodyLevelEv","__ZL16FlagHeavyweightsP12JSDefinitionP13JSFunctionBoxPj","__ZN10JSFunction11setJoinableEv","__ZN2js6Parser17functionArgumentsER13JSTreeContextP13JSFunctionBoxPP11JSParseNode","__ZN8BindDataC1Ev","__ZL20BindDestructuringArgP9JSContextP8BindDataP6JSAtomP13JSTreeContext","__ZN2js6Parser17destructuringExprEP8BindDataNS_9TokenKindE","__ZN2js8Bindings16addDestructuringEP9JSContextPt","__ZN2js8ListNode6createEP13JSTreeContext","__ZN2js9AtomDecls11lookupFirstEP6JSAtom","__ZN2js6Parser11functionDefEP6JSAtomNS0_12FunctionTypeENS_18FunctionSyntaxKindE","__ZN2js11TokenStream17mungeCurrentTokenENS_9TokenKindE4JSOp","__ZNK13JSTreeContext9compilingEv","__ZN11JSParseNode7setDefnEb","__ZN2js11TokenStream10ungetTokenEv","__ZN13JSTreeContext13noteCallsEvalEv","__ZN13JSTreeContext20noteMightAliasLocalsEv","__ZN2js9AtomDecls11updateFirstEP6JSAtomP12JSDefinition","__ZL14MakeDefIntoUseP12JSDefinitionP11JSParseNodeP6JSAtomP13JSTreeContext","__ZN2js14AtomDefnMapPtr10lookupDefnEP6JSAtom","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6removeERKS2_","__ZL6DefineP11JSParseNodeP6JSAtomP13JSTreeContextb","__ZL13EnterFunctionP11JSParseNodeP13JSTreeContextP6JSAtomN2js18FunctionSyntaxKindE","__ZN2js13AtomDeclsIterC1EPNS_9AtomDeclsE","__ZN2js13AtomDeclsIterclEv","__ZL17BindLocalVariableP9JSContextP13JSTreeContextP11JSParseNodeN2js11BindingKindE","__ZN2js11TokenStream8getTokenEj","__ZL22MatchOrInsertSemicolonP9JSContextPN2js11TokenStreamE","__ZL12DefineGlobalP11JSParseNodeP15JSCodeGeneratorP6JSAtom","__ZNK2js11TokenStream23hasOctalCharacterEscapeEv","__ZNK2js11TokenStream5isEOFEv","__ZNK11JSParseNode10isInParensEv","__ZN13JSTreeContext22noteHasExtensibleScopeEv","__ZL13LeaveFunctionP11JSParseNodeP13JSTreeContextP6JSAtomN2js18FunctionSyntaxKindE","__ZN2js6Parser12functionStmtEv","__ZN2js6Parser12functionExprEv","__ZNK11JSParseNode21isStringExprStatementEv","__ZNK11JSParseNode25isEscapeFreeStringLiteralEv","__ZN2js11TokenStream16setUnexpectedEOFEb","__ZN2js6Parser9conditionEv","__ZN2js6Parser9parenExprEPi","__ZN2js6Parser11primaryExprENS_9TokenKindEi","__ZL18CheckDestructuringP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext","__ZN2js6Parser13returnOrYieldEb","__ZN2js11TokenStream17peekTokenSameLineEj","__ZN2js6Parser4exprEv","__ZN2js6Parser8letBlockEi","__ZN2js10BinaryNode6createEP13JSTreeContext","__ZL16PushLexicalScopeP9JSContextPN2js11TokenStreamEP13JSTreeContextP10JSStmtInfo","__ZN2js6Parser9variablesEb","__ZN2js11TokenStream10matchTokenENS_9TokenKindEj","__ZL12PopStatementP13JSTreeContext","__ZN2js6Parser15switchStatementEv","__ZL26GenerateBlockIdForStmtNodeP11JSParseNodeP13JSTreeContext","__ZN2jsL15TokenKindIsDeclENS_9TokenKindE2906","__ZN2js6Parser12forStatementEv","__ZN2js11TokenStream9peekTokenEv","__ZN2js11TernaryNode6createEP13JSTreeContext","__ZNK2js6Parser13versionNumberEv","__ZL17CloneLeftHandSideP11JSParseNodeP13JSTreeContext","__ZN2js6Parser19setAssignmentLhsOpsEP11JSParseNode4JSOp","__ZL10NoteLValueP9JSContextP11JSParseNodeP13JSTreeContextj","__ZN2js6Parser12tryStatementEv","__ZL22PushBlocklikeStatementP10JSStmtInfo10JSStmtTypeP13JSTreeContext","__ZL7BindLetP9JSContextP8BindDataP6JSAtomP13JSTreeContext","__ZL14NewBindingNodeP6JSAtomP13JSTreeContextb","__ZN2js6Parser13withStatementEv","__ZL20DeoptimizeUsesWithinP12JSDefinitionRKN2js8TokenPosE","__ZN2js6Parser12letStatementEv","__ZN2js16LexicalScopeNode6createEP13JSTreeContext","__ZN2js6Parser19expressionStatementEv","__ZL9ForgetUseP11JSParseNode","__ZN2js11NullaryNode6createEP13JSTreeContext","__ZL10MatchLabelP9JSContextPN2js11TokenStreamEP11JSParseNode","__ZL14BindVarOrConstP9JSContextP8BindDataP6JSAtomP13JSTreeContext","__ZL22UndominateInitializersP11JSParseNodeRKN2js8TokenPtrEP13JSTreeContext","__ZL14MakeAssignmentP11JSParseNodeS0_P13JSTreeContext","__ZN13JSTreeContext16noteArgumentsUseEP11JSParseNode","__ZN2js6Parser9mulExpr1nEv","__ZN2js6Parser9mulExpr1iEv","__ZN2js6Parser9addExpr1nEv","__ZN2js6Parser9addExpr1iEv","__ZN2js6Parser11shiftExpr1nEv","__ZN2js6Parser11shiftExpr1iEv","__ZN2js6Parser9relExpr1nEv","__ZN2js6Parser9relExpr1iEv","__ZN2js6Parser8eqExpr1nEv","__ZN2js6Parser8eqExpr1iEv","__ZN2js6Parser12bitAndExpr1nEv","__ZN2js6Parser12bitAndExpr1iEv","__ZN2js6Parser12bitXorExpr1nEv","__ZN2js6Parser12bitXorExpr1iEv","__ZN2js6Parser11bitOrExpr1nEv","__ZN2js6Parser11bitOrExpr1iEv","__ZN2js6Parser9andExpr1nEv","__ZN2js6Parser9andExpr1iEv","__ZL11MakeSetCallP9JSContextP11JSParseNodeP13JSTreeContextj","__ZN2js6Parser9condExpr1Ev","__ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE","__ZNK11JSParseNode10isAssignedEv","__ZN2js6Parser9unaryExprEv","__ZN2js6Parser10memberExprEi","__ZNK2js11TokenStream13onCurrentLineERKNS_8TokenPosE","__ZN13JSTreeContext17countArgumentsUseEP11JSParseNode","__ZN11GenexpGuard7endBodyEv","__ZL13AdjustBlockIdP11JSParseNodejP13JSTreeContext","__ZL11SetIncOpKidP9JSContextPN2js11TokenStreamEP13JSTreeContextP11JSParseNodeS7_NS1_9TokenKindEi","__ZN11GenexpGuard14checkValidBodyEP11JSParseNode","__ZN11GenexpGuard18maybeNoteGeneratorEP11JSParseNode","__ZN20CompExprTransplanter10transplantEP11JSParseNode","__ZN2js8TokenPosgeERKS0_","__ZL15BumpStaticLevelP11JSParseNodeP13JSTreeContext","__ZNK11JSParseNode13isPlaceholderEv","__ZN2js8TokenPosltERKS0_","__ZL15MakePlaceholderP11JSParseNodeP13JSTreeContext","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3putERKS2_RKS4_","__ZN2jsL14TokenKindIsXMLENS_9TokenKindE","__ZN11JSParseNode11setInParensEb","__ZN2js6Parser17comprehensionTailEP11JSParseNodejbNS_9TokenKindE4JSOp","__ZN20CompExprTransplanterC1EP11JSParseNodeP13JSTreeContextbj","__ZN11GenexpGuardC1EP13JSTreeContext","__ZN2js11TernaryNode6createENS_9TokenKindE4JSOpP11JSParseNodeS4_S4_P13JSTreeContext","__ZN2js6Parser13generatorExprEP11JSParseNode","__ZN2js6Parser12argumentListEP11JSParseNode","__ZL32CheckForImmediatelyAppliedLambdaP11JSParseNode","__ZN2js6Parser13bracketedExprEv","__ZN2js6Parser16endBracketedExprEv","__ZN2js6Parser16propertySelectorEv","__ZN2js6Parser15qualifiedSuffixEP11JSParseNode","__ZN2js6Parser19qualifiedIdentifierEv","__ZN2js6Parser19attributeIdentifierEv","__ZN2js14MultiDeclRange5frontEv","__ZN2js11TokenStream12isXMLTagModeEv","__ZNK2js14MultiDeclRange5emptyEv","__ZN2js11TokenStream6setXMLEb","__ZN2js6Parser7xmlExprEi","__ZN2js11TokenStream13setXMLTagModeEb","__ZN2js6Parser11xmlAtomNodeEv","__ZN2js6Parser11xmlNameExprEv","__ZN2js6Parser13xmlTagContentENS_9TokenKindEPP6JSAtom","__ZN2js6Parser17xmlElementContentEP11JSParseNode","__ZN2js6Parser16xmlElementOrListEi","__ZN2js6Parser20xmlElementOrListRootEi","__ZNK2js11TokenStream6hasXMLEv","__ZN2js6Parser12parseXMLTextEP8JSObjectb","__ZN2js11TokenStream14setXMLOnlyModeEb","__ZN11JSParseNode10isConstantEv","__ZN2JSL11DoubleValueEd2907","__ZN2js9AtomDecls11lookupMultiEP6JSAtom","__ZL14BlockIdInScopejP13JSTreeContext","__ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5beginEv","__ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv","__ZL15JSDOUBLE_IS_NaNd2908","__ZN2js14MultiDeclRange8popFrontEv","__ZNK2js11TokenStream11getTokenbufEv","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE12lookupForAddERKS2_","__ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrcvPPPPPPPS6_Ev","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtr5valueEv","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3addERNS5_6AddPtrERKS2_RKS4_","__ZL12LinkUseToDefP11JSParseNodeP12JSDefinitionP13JSTreeContext","__ZN9JSContext13regExpStaticsEv","__ZL12ContainsStmtP11JSParseNodeN2js9TokenKindE","__ZL7BoolishP11JSParseNode","__ZL8FoldTypeP9JSContextP11JSParseNodeN2js9TokenKindE","__ZL17FoldBinaryNumericP9JSContext4JSOpP11JSParseNodeS3_S3_P13JSTreeContext","__ZL20js_DoubleToECMAInt32d2909","__ZL16FoldXMLConstantsP9JSContextP11JSParseNodeP13JSTreeContext","__ZN2JSL11StringValueEP8JSString2910","__ZL22PrepareNodeForMutationP11JSParseNodeP13JSTreeContext","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE12switchAndAddERKS2_RKS4_","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE10getKeyHashEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEptEv","__ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEptEv","__ZNK2js7MoveRefIP12JSDefinitionEcvRS2_Ev","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10overloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isFreeEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE10isLiveHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE9matchHashEj","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11initializedEv","__ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range13isInlineRangeEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE7setLiveEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE14unsetCollisionEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEC2ERS9_","__ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC2ERS6_","__ZN2js7MoveRefIP12JSDefinitionEC2ERS2_","__ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE12setCollisionEj","__ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrptEv","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC2EPNS5_10InlineElemEb","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC2ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E6AddPtrE","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5EntryC2ERKS2_RKS4_","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range16advancePastNullsEPNS5_10InlineElemE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC2Ev","__ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isLiveEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEaSENS_7MoveRefIS8_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEENS_7MoveRefIT_EERSB_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEC1ERS9_","__ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEENS_7MoveRefIT_EERS8_","__ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC1ERS6_","__ZN2js4MoveIP12JSDefinitionEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefIP12JSDefinitionEC1ERS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC2Ev","__ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEC1Ev","_js_malloc2912","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE11switchToMapEv","__ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKS4_","__ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj","__ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE11initializedEv","__ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv","__ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E4initEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5clearEv","__ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC1ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E6AddPtrE","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC1EPNS5_10InlineElemEb","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5EntryC1ERKS2_RKS4_","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range10bumpCurPtrEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E5RangeE","__ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3allEv","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC1EPKNS5_10InlineElemES9_","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC2EPKNS5_10InlineElemES9_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC1Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E5RangeE","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6lookupERKS2_","__ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrcvPPPPPPPS6_Ev","__ZNK2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE5beginEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE12hasCollisionEv","__ZN2js9NodeStack5emptyEv","__ZN2jsL13VersionNumberE9JSVersion2944","__ZN2jsL13VersionHasXMLE9JSVersion2945","_JSID_IS_STRING2948","_JSID_TO_STRING2950","__ZL18JSDOUBLE_IS_FINITEd2916","__ZL15JSDOUBLE_IS_NEGd2917","__ZN11JSParseNode7setUsedEb","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11underloadedEv","__ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEaSERKS5_","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC2EPNS5_10InlineElemE","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E3PtrE","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE3endEv","__ZN2js10VectorImplIP8JSScriptLj16ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_","__ZN2js9NodeStack3popEv","__ZN2js9NodeStack8pushListEP11JSParseNode","__ZN2js9NodeStack4pushEP11JSParseNode","__ZN2js9NodeStackC2Ev","__ZN2js14MultiDeclRangeC2EPNS_12AtomDeclNodeE","__ZN2js14MultiDeclRangeC2EP12JSDefinition","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC2EPNS4_10InlineElemE","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E3PtrE","__ZN2js11TokenStream7setFlagEbNS_16TokenStreamFlagsE","__ZN11GenexpGuardC2EP13JSTreeContext","__ZN20CompExprTransplanterC2EP11JSParseNodeP13JSTreeContextbj","__ZN2js8TokenPtrltERKS0_","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6removeENS5_3PtrE","__ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE7setFreeEv","__ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3Ptr5foundEv","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E3PtrE","__ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC1EPNS5_10InlineElemE","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_","__ZNK2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIP8JSScriptLj16ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj16ES3_EEj","__ZN2js10VectorImplIP8JSScriptLj16ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEED2Ev","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEEC2ES3_","__ZN2js9NodeStackC1Ev","__ZL16PushNodeChildrenP11JSParseNodePN2js9NodeStackE","__ZL17AddNodeToFreeListP11JSParseNodeP13JSTreeContext","__ZN2js9NodeStack14pushUnlessNullEP11JSParseNode","__ZN2js16AutoStringRooterC1EP9JSContextP8JSString","__ZN2js16AutoStringRooterD1Ev","__ZN2js16AutoStringRooterD2Ev","__ZN2js16AutoStringRooterC2EP9JSContextP8JSString","__ZL7js_fmoddd2918","__ZN2JSL14UndefinedValueEv2937","__ZN2jsL22GetGlobalForScopeChainEP9JSContext2940","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6lookupERKS2_","__ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrcvPPPPPPPS5_Ev","__ZN2js14MultiDeclRangeC1EP12JSDefinition","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3Ptr5valueEv","__ZN2js14MultiDeclRangeC1EPNS_12AtomDeclNodeE","__ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3Ptr5foundEv","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E3PtrE","__ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC1EPNS4_10InlineElemE","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6lookupERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3PtrC1ERNS0_14HashTableEntryIS6_EE","__ZN2jsL21VersionShouldParseXMLE9JSVersion","__ZNK2js11TokenStream13versionNumberEv","__ZL12JSID_TO_ATOMi2949","__ZL10SetLvalKidP9JSContextPN2js11TokenStreamEP13JSTreeContextP11JSParseNodeS7_PKc","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE12hasCollisionEv","__ZNK15JSCodeGenerator16compilingForEvalEv","__ZNK11JSParseNode6lexdefEv","__ZN2js8TokenPtrleERKS0_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11underloadedEv","__ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEaSERKS4_","__ZN2js11TokenStream7FlaggerD2Ev","__ZN2js11TokenStream7FlaggerC2EPS0_j","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js6Parser7orExpr1Ev","__ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindES1_","__ZL8OuterLetP13JSTreeContextP10JSStmtInfoP6JSAtom","__ZL17BindFunctionLocalP9JSContextP8BindDataRN2js14MultiDeclRangeEP13JSTreeContext","__ZL15BindTopLevelVarP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext","__ZN2js8TokenPtrgeERKS0_","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3Ptr5valueEv","__ZN2JSL12PrivateValueEPv2951","__ZNK11JSParseNode12isBlockChildEv","__ZNK11JSParseNode10frameLevelEv","__ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext","__ZN2js10BinaryNode6createENS_9TokenKindE4JSOpRKNS_8TokenPosEP11JSParseNodeS7_P13JSTreeContext","__ZN2js9AtomDecls6removeEP6JSAtom","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6removeENS4_3PtrE","__ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E3PtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6removeENSD_3PtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6removeERNS0_14HashTableEntryIS6_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E16checkUnderloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE7setFreeEv","__ZN2js11TokenStream7FlaggerC1EPS0_j","__ZN2js11TokenStream7FlaggerD1Ev","__ZL20BindDestructuringVarP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext","__ZL20BindDestructuringLHSP9JSContextP11JSParseNodeP13JSTreeContext","__ZN2js11GlobalScope9GlobalDefC1Ej","__ZN2js11GlobalScope9GlobalDefC1EP6JSAtomP13JSFunctionBox","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE6appendIS2_EEbT_","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_","__ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js7MoveRefINS_11GlobalScope9GlobalDefEEcvRS2_Ev","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Entry3keyEv","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Entry5valueEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE10getKeyHashEv","__ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range13isInlineRangeEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv","__ZN18JSFunctionBoxQueue6lengthEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10overloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE6isFreeEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj","__ZNK7mozilla14AlignedStorageILj192EE4addrEv","__ZN2js7MoveRefINS_11GlobalScope9GlobalDefEEC2ERS2_","__ZN2js11GlobalScope9GlobalDefC2EP6JSAtomP13JSFunctionBox","__ZN2js11GlobalScope9GlobalDefC2Ej","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range16advancePastNullsEPNS4_10InlineElemE","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5Range5frontEv","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5EntryC2ERKS2_RKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC2Ev","__ZN2js12DefnOrHeaderC2EP12JSDefinition","__ZN2js11TokenStream17mungeCurrentTokenE4JSOp","__ZN8BindDataC2Ev","__ZN18JSFunctionBoxQueueC2Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrptEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE7setLiveEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE14unsetCollisionEv","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj16ES3_EEj","__ZN2js4MoveINS_11GlobalScope9GlobalDefEEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefINS_11GlobalScope9GlobalDefEEC1ERS2_","__ZN2js10VectorImplINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js4MoveINS_11GlobalScope9GlobalDefEEENS_7MoveRefIT_EERKS4_","__ZN2js11NameSetNode6createEP13JSTreeContext","__ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range5emptyEv","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range5frontEv","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range8popFrontEv","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range10bumpCurPtrEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5Range8popFrontEv","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5EntryC1ERKS2_RKS3_","__ZN2js13AtomDeclsIterC2EPNS_9AtomDeclsE","__ZN2js9AtomDecls3allEv","__ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3allEv","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E5RangeE","__ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3allEv","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC1EPKNS4_10InlineElemES8_","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC2EPKNS4_10InlineElemES8_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC1Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC1EPNS0_14HashTableEntryIS6_EESH_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC2EPNS0_14HashTableEntryIS6_EESH_","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E5RangeE","__ZN2js9AtomDecls9addUniqueEP6JSAtomP12JSDefinition","__ZN2js12DefnOrHeaderC1EP12JSDefinition","__ZN12JSDefinition13isBindingFormEv","__ZN2JSL9NullValueEv2953","__ZL10MinBlockIdP11JSParseNodej","__ZN18JSFunctionBoxQueueD2Ev","__ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_","__ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj","__ZL12JSID_IS_ATOMi2955","__ZL18ReportBadParameterP9JSContextP13JSTreeContextP6JSAtomj","__ZNK2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv","__ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_bEENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKb","__ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev","__ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE6isLiveEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEaSENS_7MoveRefIS6_EE","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEptEv","__ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtombEEEptEv","__ZNK2js7MoveRefIbEcvRbEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv","__ZL14JSID_FROM_BITSj2961","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE10isLiveHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE9matchHashEj","__ZN2js11UpvarCookie15isLevelReservedEt","__ZNK2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE6hasMapEv","_JSVAL_TO_OBJECT_IMPL3001","_JSVAL_IS_PRIMITIVE_IMPL3003","__ZN7mozilla14AlignedStorageILj192EE4addrEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEC2ERS7_","__ZN2js7MoveRefINS_12HashMapEntryIP6JSAtombEEEC2ERS4_","__ZN2js7MoveRefIbEC2ERb","__ZN2js12HashMapEntryIP6JSAtombEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE12setCollisionEj","__ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_bEE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC2ES9_","__ZL13JSVAL_TO_IMPLN2JS5ValueE3002","__ZL13IMPL_TO_JSVAL12jsval_layout3004","_INT32_TO_JSVAL_IMPL3005","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEENS_7MoveRefIT_EERS9_","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEC1ERS7_","__ZN2js12HashMapEntryIP6JSAtombEaSENS_7MoveRefIS3_EE","__ZN2js4MoveINS_12HashMapEntryIP6JSAtombEEEENS_7MoveRefIT_EERS6_","__ZN2js7MoveRefINS_12HashMapEntryIP6JSAtombEEEC1ERS4_","__ZN2js4MoveIbEENS_7MoveRefIT_EERS2_","__ZN2js7MoveRefIbEC1ERb","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEC2Ev","__ZN2js12HashMapEntryIP6JSAtombEC1Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E4initEj","__ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC1ES9_","__ZL14HasFinalReturnP11JSParseNode","__ZN2js8CompilerD2Ev","__ZN2js11GlobalScopeD2Ev","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEED2Ev","__ZN2js11GlobalScopeC2EP9JSContextP8JSObjectP15JSCodeGenerator","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEEC1ES3_","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEEC2ES3_","__ZN2js11OffTheBooks4new_INS_12ParseMapPoolEP9JSContextEEPT_T0_","__ZN2js12ParseMapPoolC1EP9JSContext","__ZN2js12ParseMapPoolC2EP9JSContext","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEEC1ES2_","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEEC2ES2_","__ZL8pm_startP9JSContextjPN2JS5ValueE","__ZL7pm_stopP9JSContextjPN2JS5ValueE","__ZL8pm_resetP9JSContextjPN2JS5ValueE","__ZL22pm_canMeasureSomethingP9JSContextjPN2JS5ValueE","__ZL11pm_finalizeP9JSContextP8JSObject","__ZN2JS23RegisterPerfMeasurementEP9JSContextP8JSObject","__ZL12pm_constructP9JSContextjPN2JS5ValueE","_INT_TO_JSVAL2997","_JSVAL_IS_PRIMITIVE2998","_JSVAL_TO_OBJECT2999","__ZL17pm_get_cpu_cyclesP9JSContextP8JSObjectiPN2JS5ValueE","__ZL19pm_get_instructionsP9JSContextP8JSObjectiPN2JS5ValueE","__ZL23pm_get_cache_referencesP9JSContextP8JSObjectiPN2JS5ValueE","__ZL19pm_get_cache_missesP9JSContextP8JSObjectiPN2JS5ValueE","__ZL26pm_get_branch_instructionsP9JSContextP8JSObjectiPN2JS5ValueE","_OBJECT_TO_JSVAL_IMPL3007","_BOOLEAN_TO_JSVAL_IMPL3011","__ZL20pm_get_branch_missesP9JSContextP8JSObjectiPN2JS5ValueE","__ZL17pm_get_bus_cyclesP9JSContextP8JSObjectiPN2JS5ValueE","__ZL18pm_get_page_faultsP9JSContextP8JSObjectiPN2JS5ValueE","__ZL24pm_get_major_page_faultsP9JSContextP8JSObjectiPN2JS5ValueE","__ZL23pm_get_context_switchesP9JSContextP8JSObjectiPN2JS5ValueE","__ZL21pm_get_cpu_migrationsP9JSContextP8JSObjectiPN2JS5ValueE","__ZL21pm_get_eventsMeasuredP9JSContextP8JSObjectiPN2JS5ValueE","__ZL5GetPMP9JSContextP8JSObjectPKc","__ZN9JSContext4new_IN2JS15PerfMeasurementENS2_9EventMaskEEEPT_T0_","_OBJECT_TO_JSVAL3006","__ZN9JSContext7delete_IN2JS15PerfMeasurementEEEvPT_","__ZL13GetPMFromThisP9JSContextPN2JS5ValueE","_BOOLEAN_TO_JSVAL3010","_JS_THIS","__ZL9dosprintfP15SprintfStateStrPKcPc","_JS_smprintf","_JS_vsmprintf","__ZL9GrowStuffP15SprintfStateStrPKcj","_JS_snprintf","__ZL10LimitStuffP15SprintfStateStrPKcj","_JS_vsnprintf","_JS_sprintf_append","_JS_vsprintf_append","__ZL13BuildArgArrayPKcPcPiP11NumArgState","__ZL5cvt_lP15SprintfStateStrliiiiiPKc","__ZL6cvt_llP15SprintfStateStrxiiiiiPKc","__ZL5cvt_fP15SprintfStateStrdPKcS2_","__ZL6cvt_wsP15SprintfStateStrPKtiii","__ZL5cvt_sP15SprintfStateStrPKciii","__ZL5fill2P15SprintfStateStrPKciii","__ZL6fill_nP15SprintfStateStrPKciiiii","__ZN8JSObject7genericEv","__ZNK2js11KidsPointer6isNullEv","__ZNK2js11KidsPointer7toShapeEv","__ZNK2js11KidsPointer6toHashEv","__ZNK2js11KidsPointer6isHashEv","__ZL26js_IsPropertyCacheDisabledP9JSContext3032","__ZN2js5PCVal9setFunObjER8JSObject","__ZN2js5PCVal7setSlotEj","__ZN2js5PCVal8setShapeEPKNS_5ShapeE","__ZN2js18PropertyCacheEntry6assignEPhjjjjNS_5PCValE","__ZN2js5Shape9setParentEPS0_","__ZN2js11KidsPointer8setShapeEPNS_5ShapeE","__ZN2js11KidsPointer7setHashEPNS_7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEE","__ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrdeEv","__ZN2js13PropertyCache4fillEP9JSContextP8JSObjectjS4_PKNS_5ShapeEi","__ZL12js_GetOpcodeP9JSContextP8JSScriptPh3033","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject3034","__ZN2js13PropertyCache8fullTestEP9JSContextPhPP8JSObjectS6_PNS_18PropertyCacheEntryE","__ZL19GetAtomFromBytecodeP9JSContextPh4JSOpRK10JSCodeSpec","__ZN2js13PropertyCache5purgeEP9JSContext","__ZN2jsL12PodArrayZeroINS_18PropertyCacheEntryELj4096EEEvRAT0__T_","__ZN2js12PropertyTree8newShapeEP9JSContext","__Z13js_NewGCShapeP9JSContext","__ZN2js12PropertyTree11insertChildEP9JSContextPNS_5ShapeES4_","__ZNK2js11KidsPointer7isShapeEv","__ZL12HashChildrenPN2js5ShapeES1_","__ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6putNewERKS2_","__ZN2js5Shape11removeChildEPS0_","__ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6removeERKPKS1_","__ZN2js12PropertyTree8getChildEP9JSContextPNS_5ShapeERKS3_","__ZNK2js5Shape7matchesEPKS0_","__ZNK2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6lookupERKPKS1_","__ZN2js5ShapeC1EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj","__ZN2js5Shape8finalizeEP9JSContext","__ZN9JSContext7delete_IN2js7HashSetIPNS1_5ShapeENS1_11ShapeHasherENS1_17SystemAllocPolicyEEEEEvPT_","__ZN2js5Shape9freeTableEP9JSContext","__ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEED1Ev","_js_free3045","__ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED1Ev","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED2Ev","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12destroyTableERS7_PNS0_14HashTableEntryIS4_EEj","__ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6lookupERKPKS2_","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11prepareHashERKPKS2_","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrC1ERNS0_14HashTableEntryIS4_EE","__ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_","__ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE10getKeyHashEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_5ShapeEEEEptEv","__ZNK2js7MoveRefIPNS_5ShapeEEcvRS2_Ev","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr7nonNullEv","__ZN2js14JSProxyHandlerD2Ev","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash1Ejj","__ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE6isFreeEv","__ZN2js6detail14HashTableEntryIKPNS_5ShapeEE9matchHashEj","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash2Ejjj","__ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE9isRemovedEv","__ZN2js6detail14HashTableEntryIKPNS_5ShapeEE10isLiveHashEj","__ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE12hasCollisionEv","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10overloadedEv","_INT_TO_JSID3072","__ZN2js6detail14HashTableEntryIKPNS_5ShapeEE12setCollisionEj","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrC2ERNS0_14HashTableEntryIS4_EE","__ZNK2js5Shape4hashEv","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11underloadedEv","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryIKPNS_5ShapeEE14unsetCollisionEv","__ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_5ShapeEEEEC2ERS6_","__ZN2js7MoveRefIPNS_5ShapeEEC2ERS2_","__ZN2js6detail14HashTableEntryIKPNS_5ShapeEE12setCollisionEv","__ZN2js6detail14HashTableEntryIKPNS_5ShapeEEC2Ev","__ZN2js6detail14HashTableEntryIKPNS_5ShapeEE10setRemovedEv","__ZN2js6detail14HashTableEntryIKPNS_5ShapeEE7setFreeEv","__ZN2js6detail14HashTableEntryIKPNS_5ShapeEE7setLiveEj","__ZNK2js5Shape8setTableEPNS_13PropertyTableE","__ZNK2js5Shape20matchesParamsAfterIdEPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjji","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC2ES7_","__ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6lookupERKPKS2_jj","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5matchERNS0_14HashTableEntryIS4_EERKPKS2_","__ZN2js11ShapeHasher5matchEPNS_5ShapeEPKS1_","__ZN2js11ShapeHasher4hashEPKNS_5ShapeE","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10isLiveHashEj","__ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrcvMSB_FvvEEv","__ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS5_6SetOpsES4_E3PtrE","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6removeENSA_3PtrE","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6removeERNS0_14HashTableEntryIS4_EE","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16checkUnderloadedEv","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E15changeTableSizeEi","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11createTableERS7_j","__ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE6isLiveEv","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryIKPNS_5ShapeEEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_6detail14HashTableEntryIKPNS_5ShapeEEEEENS_7MoveRefIT_EERS8_","__ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_5ShapeEEEEC1ERS6_","__ZN2js4MoveIPNS_5ShapeEEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefIPNS_5ShapeEEC1ERS2_","__ZN2js6detail14HashTableEntryIKPNS_5ShapeEEC1Ev","_js_malloc3046","__ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr5foundEv","__ZNK2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE12lookupForAddERKPKS1_","__ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS5_6SetOpsES4_E6AddPtrERS8_","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrERS4_","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrE","__ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12lookupForAddERKPKS2_","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj","__ZN9JSContext7delete_IN2js13PropertyTableEEEvPT_","__ZN2js13PropertyTableD1Ev","__ZN2js13PropertyTableD2Ev","__ZN2js5ShapeC2EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj","__ZN2js11OffTheBooks4new_INS_7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEEEEPT_v","__ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE4initEj","__ZN2js10Foreground7delete_INS_7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEEEEvPT_","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4initEj","__ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEC1ES4_","__ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEC2ES4_","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC1ES7_","__Z10NewGCThingIN2js5ShapeEEPT_P9JSContextNS0_2gc9AllocKindEj","__ZN2js14JSProxyHandler3hasEP9JSContextP8JSObjectiPb","__ZN2js14JSProxyHandler6hasOwnEP9JSContextP8JSObjectiPb","__ZN2js14JSProxyHandler3getEP9JSContextP8JSObjectS4_iPN2JS5ValueE","__ZN2js14JSProxyHandler8finalizeEP9JSContextP8JSObject","__ZN2js14JSProxyHandler5traceEP8JSTracerP8JSObject","__ZL24IndicatePropertyNotFoundP9JSContextP20JSPropertyDescriptor","__ZN2js14JSProxyHandler3setEP9JSContextP8JSObjectS4_ibPN2JS5ValueE","__ZNK8JSObject15getProxyHandlerEv","__ZN2js14JSProxyHandler4keysEP9JSContextP8JSObjectRNS_12AutoIdVectorE","__ZN2js16AutoVectorRooterIiE6resizeEj","__ZN2js14JSProxyHandler7iterateEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN2js14JSProxyHandler12obj_toStringEP9JSContextP8JSObject","__ZN2js14JSProxyHandler12fun_toStringEP9JSContextP8JSObjectj","__ZL7GetCallP8JSObject","__ZN2js14JSProxyHandler12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE","__ZN2js14JSProxyHandler4callEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN2js14JSProxyHandler9constructEP9JSContextP8JSObjectjPN2JS5ValueES7_","__ZL12GetConstructP8JSObject","__ZN2JSL14UndefinedValueEv3073","__ZN2js14JSProxyHandler11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb","__ZN2JSL11ObjectValueER8JSObject3074","__ZN2js14JSProxyHandler6typeOfEP9JSContextP8JSObject","__ZN22JSScriptedProxyHandlerD0Ev","__ZN22JSScriptedProxyHandler21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor","__ZL21GetProxyHandlerObjectP9JSContextP8JSObject","__ZL18GetFundamentalTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE","__ZL5Trap1P9JSContextP8JSObjectN2JS5ValueEiPS4_","__ZL31ReturnedValueMustNotBePrimitiveP9JSContextP8JSObjectP6JSAtomRKN2JS5ValueE","__ZL29ParsePropertyDescriptorObjectP9JSContextP8JSObjectiRKN2JS5ValueEP20JSPropertyDescriptor","__ZN22JSScriptedProxyHandler24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor","__ZN22JSScriptedProxyHandler14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor","__ZL5Trap2P9JSContextP8JSObjectN2JS5ValueEiS4_PS4_","__ZN22JSScriptedProxyHandler19getOwnPropertyNamesEP9JSContextP8JSObjectRN2js12AutoIdVectorE","__ZL4TrapP9JSContextP8JSObjectN2JS5ValueEjPS4_S5_","__ZL15ArrayToIdVectorP9JSContextRKN2JS5ValueERN2js12AutoIdVectorE","__ZN22JSScriptedProxyHandler7delete_EP9JSContextP8JSObjectiPb","__ZL11ValueToBoolP9JSContextRKN2JS5ValueEPb","__ZN22JSScriptedProxyHandler9enumerateEP9JSContextP8JSObjectRN2js12AutoIdVectorE","__ZN22JSScriptedProxyHandler3fixEP9JSContextP8JSObjectPN2JS5ValueE","__ZN22JSScriptedProxyHandler3hasEP9JSContextP8JSObjectiPb","__ZL14GetDerivedTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE","__ZL13js_IsCallableRKN2JS5ValueE3075","__ZN22JSScriptedProxyHandler6hasOwnEP9JSContextP8JSObjectiPb","__ZN22JSScriptedProxyHandler3getEP9JSContextP8JSObjectS3_iPN2JS5ValueE","__ZN2jsL9IdToValueEi3076","__ZN2JSL11StringValueEP8JSString3077","__ZN2JSL17ObjectOrNullValueEP8JSObject3078","__ZN22JSScriptedProxyHandler3setEP9JSContextP8JSObjectS3_ibPN2JS5ValueE","__ZN22JSScriptedProxyHandler4keysEP9JSContextP8JSObjectRN2js12AutoIdVectorE","__ZN22JSScriptedProxyHandler7iterateEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN2js7JSProxy21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor","__ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject","__ZN25AutoPendingProxyOperationD1Ev","__ZN2js7JSProxy24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor","__ZN2js7JSProxy14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor","__ZN2js7JSProxy14definePropertyEP9JSContextP8JSObjectiRKN2JS5ValueE","__ZN2js7JSProxy19getOwnPropertyNamesEP9JSContextP8JSObjectRNS_12AutoIdVectorE","__ZN2js7JSProxy7delete_EP9JSContextP8JSObjectiPb","__ZN2js7JSProxy9enumerateEP9JSContextP8JSObjectRNS_12AutoIdVectorE","__ZN2js7JSProxy3fixEP9JSContextP8JSObjectPN2JS5ValueE","__ZN2js7JSProxy3hasEP9JSContextP8JSObjectiPb","__ZN2js7JSProxy6hasOwnEP9JSContextP8JSObjectiPb","__ZN2js7JSProxy3getEP9JSContextP8JSObjectS4_iPN2JS5ValueE","__ZN2js7JSProxy3setEP9JSContextP8JSObjectS4_ibPN2JS5ValueE","__ZN2js7JSProxy4keysEP9JSContextP8JSObjectRNS_12AutoIdVectorE","__ZN2js7JSProxy7iterateEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN2js7JSProxy4callEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN2js7JSProxy9constructEP9JSContextP8JSObjectjPN2JS5ValueES7_","__ZN2js7JSProxy11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb","__ZN2js7JSProxy6typeOfEP9JSContextP8JSObject","__ZN2js7JSProxy12obj_toStringEP9JSContextP8JSObject","__ZN2js7JSProxy12fun_toStringEP9JSContextP8JSObjectj","__ZN2js7JSProxy12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE","__ZL13proxy_ConvertP9JSContextP8JSObject6JSTypePN2JS5ValueE","__ZL14proxy_FinalizeP9JSContextP8JSObject","__ZL17proxy_HasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi","__ZL17proxy_TraceObjectP8JSTracerP8JSObject","__ZL20proxy_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty","__ZL19proxy_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty","__ZL19proxy_LookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty","__ZL20proxy_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej","__ZL19proxy_DefineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej","__ZL19proxy_DefineSpecialP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ej","__ZL16proxy_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE","__ZL17proxy_GetPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE","__ZL16proxy_GetElementP9JSContextP8JSObjectS2_jPN2JS5ValueE","__ZL16proxy_GetSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE","__ZL17proxy_SetPropertyP9JSContextP8JSObjectiPN2JS5ValueEi","__ZL16proxy_SetElementP9JSContextP8JSObjectjPN2JS5ValueEi","__ZL16proxy_SetSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZL19proxy_GetAttributesP9JSContextP8JSObjectiPj","__ZL26proxy_GetElementAttributesP9JSContextP8JSObjectjPj","__ZL26proxy_GetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj","__ZL19proxy_SetAttributesP9JSContextP8JSObjectiPj","__ZL26proxy_SetElementAttributesP9JSContextP8JSObjectjPj","__ZL26proxy_SetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj","__ZL20proxy_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi","__ZL19proxy_DeleteElementP9JSContextP8JSObjectjPN2JS5ValueEi","__ZL19proxy_DeleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZL12proxy_TypeOfP9JSContextP8JSObject","__ZL9proxy_FixP9JSContextP8JSObjectPbPN2js12AutoIdVectorE","__ZL17proxy_innerObjectP9JSContextP8JSObject","__ZL10proxy_CallP9JSContextjPN2JS5ValueE","__ZL15proxy_ConstructP9JSContextjPN2JS5ValueE","__ZL19proxy_TraceFunctionP8JSTracerP8JSObject","__ZN2js14NewProxyObjectEP9JSContextPNS_14JSProxyHandlerERKN2JS5ValueEP8JSObjectS9_S9_S9_","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3103","__ZN2JSL12PrivateValueEPv3104","__ZL12proxy_createP9JSContextjPN2JS5ValueE","__ZL20proxy_createFunctionP9JSContextjPN2JS5ValueE","__Z18callable_ConstructP9JSContextjPN2JS5ValueE","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_3105","__ZL13callable_CallP9JSContextjPN2JS5ValueE","__ZN2js8FixProxyEP9JSContextP8JSObjectPi","__ZN2js14JSProxyHandler13isOuterWindowEv","__ZL14JSID_FROM_BITSj3130","__ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3133","__ZN2jsL16GetClassProtoKeyEPNS_5ClassE3121","_JSID_IS_STRING3137","_JSID_TO_STRING3138","_JSID_IS_INT3139","_JSID_TO_INT3141","_JSID_IS_OBJECT3142","_JSID_TO_OBJECT3143","_INT_TO_JSID3398","__ZL19OperationInProgressP9JSContextP8JSObject","__ZN2js2gcL15GetGCObjectKindEjb3110","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE8shrinkByEj","__ZL13IMPL_TO_JSVAL12jsval_layout3125","_OBJECT_TO_JSVAL_IMPL3126","__ZN25AutoPendingProxyOperationD2Ev","__ZN25AutoPendingProxyOperationC2EP9JSContextP8JSObject","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE","_js_InitProxyClass","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3108","_OBJECT_TO_JSVAL3109","__ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3111","__ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_3112","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE3115","__ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3122","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE19growByUninitializedEj","__ZN2jsL15MakeRangeGCSafeEPiS0_","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE3127","__ZL12ATOM_TO_JSIDP6JSAtom3129","__ZNK8JSObject13getProxyExtraEv","__ZN2JSL10Int32ValueEi3140","__ZL7GetTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE","__ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPP8JSObject","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3397","__ZN2js11NodeBuilder10setNodeLocEP8JSObjectPNS_8TokenPosE","__ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE","__ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE","__ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE","__ZN2js11NodeBuilder10newNodeLocEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder9newObjectEPP8JSObject","__ZN2JSL11ObjectValueER8JSObject3399","__ZN2JSL9NullValueEv3400","__ZN2js11NodeBuilder7programERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder14blockStatementERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder19expressionStatementEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_","__ZN2js11NodeBuilder14emptyStatementEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder8callbackEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder11ifStatementEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder3optEN2JS5ValueE","__ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_","__ZN2js11NodeBuilder14breakStatementEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder17continueStatementEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder16labeledStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_","__ZN2js11NodeBuilder14throwStatementEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder15returnStatementEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder12forStatementEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_S2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_S5_S7_PS7_","__ZN2js11NodeBuilder14forInStatementEN2JS5ValueES2_S2_bPNS_8TokenPosEPS2_","__ZN2JSL12BooleanValueEb3401","__ZN2js11NodeBuilder13withStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder14whileStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder16doWhileStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder15switchStatementEN2JS5ValueERNS_15AutoValueVectorEbPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder12tryStatementEN2JS5ValueERNS_15AutoValueVectorES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder17debuggerStatementEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder16binaryExpressionENS_14BinaryOperatorEN2JS5ValueES3_PNS_8TokenPosEPS3_","__ZN2js11NodeBuilder15unaryExpressionENS_13UnaryOperatorEN2JS5ValueEPNS_8TokenPosEPS3_","__ZN2js11NodeBuilder20assignmentExpressionENS_18AssignmentOperatorEN2JS5ValueES3_PNS_8TokenPosEPS3_","__ZN2js11NodeBuilder16updateExpressionEN2JS5ValueEbbPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder17logicalExpressionEbN2JS5ValueES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder21conditionalExpressionEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder18sequenceExpressionERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder14callExpressionEN2JS5ValueERNS_15AutoValueVectorEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder13newExpressionEN2JS5ValueERNS_15AutoValueVectorEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder16memberExpressionEbN2JS5ValueES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder15arrayExpressionERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder15propertyPatternEN2JS5ValueES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder19propertyInitializerEN2JS5ValueES2_NS_8PropKindEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder16objectExpressionERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder14thisExpressionEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder15yieldExpressionEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder18comprehensionBlockEN2JS5ValueES2_bPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder23comprehensionExpressionEN2JS5ValueERNS_15AutoValueVectorES2_PNS_8TokenPosEPS2_","__ZN2js13ASTSerializer3aopE4JSOp","__ZN2js13ASTSerializer4unopENS_9TokenKindE4JSOp","__ZN2js13ASTSerializer5binopENS_9TokenKindE4JSOp","__ZN2js11NodeBuilder19generatorExpressionEN2JS5ValueERNS_15AutoValueVectorES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder15graphExpressionEiN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2JSL11NumberValueEd3402","__ZN2js11NodeBuilder20graphIndexExpressionEiPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder13letExpressionERNS_15AutoValueVectorEN2JS5ValueEPNS_8TokenPosEPS4_","__ZN2js11NodeBuilder12letStatementERNS_15AutoValueVectorEN2JS5ValueEPNS_8TokenPosEPS4_","__ZN2js11NodeBuilder19variableDeclarationERNS_15AutoValueVectorENS_11VarDeclKindEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder18variableDeclaratorEN2JS5ValueES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder10switchCaseEN2JS5ValueERNS_15AutoValueVectorEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder11catchClauseEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder7literalEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder10identifierEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder13objectPatternERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder12arrayPatternERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder8functionENS_7ASTTypeEPNS_8TokenPosEN2JS5ValueERNS_15AutoValueVectorES5_bbPS5_","__ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_S2_S2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_S5_S7_S5_S7_PS7_","__ZN2js11NodeBuilder10xmlAnyNameEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder19xmlEscapeExpressionEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder19xmlFilterExpressionEN2JS5ValueES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder19xmlDefaultNamespaceEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder20xmlAttributeSelectorEN2JS5ValueEbPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder30xmlFunctionQualifiedIdentifierEN2JS5ValueEbPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder22xmlQualifiedIdentifierEN2JS5ValueES2_bPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder10xmlElementERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder7xmlTextEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder7xmlListERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder11xmlStartTagERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder9xmlEndTagERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder11xmlPointTagERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder7xmlNameEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder7xmlNameERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder12xmlAttributeEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder8xmlCdataEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder10xmlCommentEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder5xmlPIEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder5xmlPIEN2JS5ValueES2_PNS_8TokenPosEPS2_","__ZN2js13ASTSerializer10statementsEP11JSParseNodeRNS_15AutoValueVectorE","__ZN2js13ASTSerializer13sourceElementEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer11expressionsEP11JSParseNodeRNS_15AutoValueVectorE","__ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer4xmlsEP11JSParseNodeRNS_15AutoValueVectorE","__ZN2js13ASTSerializer3xmlEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer14blockStatementEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer7programEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer11declarationEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer8functionEP11JSParseNodeNS_7ASTTypeEPN2JS5ValueE","__ZN2js13ASTSerializer19variableDeclarationEP11JSParseNodebPN2JS5ValueE","__ZN2js13ASTSerializer7patternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE","__ZN2js13ASTSerializer18variableDeclaratorEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE","__ZN2js13ASTSerializer13optExpressionEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer7letHeadEP11JSParseNodeRNS_15AutoValueVectorE","__ZN2js13ASTSerializer10switchCaseEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer15switchStatementEP11JSParseNodePN2JS5ValueE","__ZN2JSL14UndefinedValueEv3403","__ZN2js13ASTSerializer11catchClauseEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer12tryStatementEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer12optStatementEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer7forInitEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer13optIdentifierEP6JSAtomPNS_8TokenPosEPN2JS5ValueE","__ZN2js13ASTSerializer10identifierEP6JSAtomPNS_8TokenPosEPN2JS5ValueE","__ZN2js13ASTSerializer13leftAssociateEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer18comprehensionBlockEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer13comprehensionEP11JSParseNodePN2JS5ValueE","__ZN2JSL10MagicValueE10JSWhyMagic3404","__ZN2js13ASTSerializer19generatorExpressionEP11JSParseNodePN2JS5ValueE","__ZNK11JSParseNode15isGeneratorExprEv","__ZNK11JSParseNode13generatorExprEv","__ZN2js13ASTSerializer8propertyEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer10identifierEP11JSParseNodePN2JS5ValueE","__ZN2jsL16GetClassProtoKeyEPNS_5ClassE3418","__ZN2js2gcL15GetGCObjectKindEjb3408","__ZL13IMPL_TO_JSVAL12jsval_layout3419","__ZN2js13ASTSerializer7literalEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer12atomContentsEP6JSAtom","__ZN2js13ASTSerializer12propertyNameEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer12arrayPatternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE","__ZN2js13ASTSerializer13objectPatternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE","__ZN2js13ASTSerializer19functionArgsAndBodyEP11JSParseNodeRNS_15AutoValueVectorEPN2JS5ValueE","__ZN2js13ASTSerializer12functionArgsEP11JSParseNodeS2_S2_S2_RNS_15AutoValueVectorE","__ZN2js13ASTSerializer12functionBodyEP11JSParseNodePNS_8TokenPosEPN2JS5ValueE","__ZL13reflect_parseP9JSContextjPN2JS5ValueE","_JS_InitReflect","_OBJECT_TO_JSVAL3405","__ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3409","__ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_3410","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE3413","__ZL14JSID_FROM_BITSj3426","_OBJECT_TO_JSVAL_IMPL3420","__ZN2js11NodeBuilderC2EP9JSContextbPKc","__ZN2js22AutoReleaseNullablePtrC2EP9JSContextPv","__ZN2js6RegExp6increfEP9JSContext","__ZN2js22AutoReleaseNullablePtrC1EP9JSContextPv","__ZL12ATOM_TO_JSIDP6JSAtom3421","__ZN2js22AutoReleaseNullablePtr5resetEPv","__ZN2JSL10Int32ValueEi3422","__ZN2js13ASTSerializerC1EP9JSContextbPKcj","__ZN2js13ASTSerializer4initEP8JSObject","__ZN2js22AutoReleaseNullablePtrD1Ev","__ZN2js22AutoReleaseNullablePtrD2Ev","__ZN2js11NodeBuilder4initEP8JSObject","__ZN2js13ASTSerializerC2EP9JSContextbPKcj","__ZN2js11NodeBuilderC1EP9JSContextbPKc","__ZN2JSL11StringValueEP8JSString3435","__ZN2js11NodeBuilder9setResultEP8JSObjectPN2JS5ValueE","__ZL13resc_finalizeP9JSContextP8JSObject","__ZL10resc_traceP8JSTracerP8JSObject","__Z20js_CloneRegExpObjectP9JSContextP8JSObjectS2_","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_3476","__ZN2js6RegExp15reportPCREErrorEP9JSContexti","__ZN2js6RegExp10parseFlagsEP9JSContextP8JSStringPj","__ZN2js6RegExp13createFlaggedEP9JSContextP8JSStringS4_PNS_11TokenStreamE","__ZN8JSObject24assignInitialRegExpShapeEP9JSContext","__ZL12ATOM_TO_JSIDP6JSAtom3481","__ZL19static_input_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL19static_input_setterP9JSContextP8JSObjectiiPN2JS5ValueE","__ZL23static_multiline_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL23static_multiline_setterP9JSContextP8JSObjectiiPN2JS5ValueE","__ZL23static_lastMatch_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL23static_lastParen_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL25static_leftContext_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL26static_rightContext_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL20static_paren1_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL20static_paren2_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL20static_paren3_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL20static_paren4_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL20static_paren5_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL20static_paren6_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL20static_paren7_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL20static_paren8_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL20static_paren9_getterP9JSContextP8JSObjectiPN2JS5ValueE","__Z18js_XDRRegExpObjectP10JSXDRStatePP8JSObject","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3482","__ZL15regexp_finalizeP9JSContextP8JSObject","__ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE6lengthEv","__ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE5emptyEv","__ZNK7mozilla14AlignedStorageILj256EE4addrEv","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE10endNoCheckEv","__Z18js_regexp_toStringP9JSContextP8JSObjectPN2JS5ValueE","__ZN2JSL11StringValueEP8JSString3485","__ZN2js12StringBuffer16infallibleAppendEt","__ZN2js12StringBuffer6appendILj7EEEbRAT__Kc","__Z14js_regexp_execP9JSContextjPN2JS5ValueE","__ZL13ExecuteRegExpP9JSContext8ExecTypejPN2JS5ValueE","__Z14js_regexp_testP9JSContextjPN2JS5ValueE","__ZL15regexp_toStringP9JSContextjPN2JS5ValueE","__ZL14regexp_compileP9JSContextjPN2JS5ValueE","__Z18js_InitRegExpClassP9JSContextP8JSObject","__ZL16regexp_constructP9JSContextjPN2JS5ValueE","__ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcNS0_4TypeE","__ZN2JSL11ObjectValueER8JSObject3490","__ZN2JSL14UndefinedValueEv3491","__ZN2jsL14IsConstructingEPKN2JS5ValueE3500","__ZL20CompileRegExpAndSwapP9JSContextP8JSObjectjPN2JS5ValueES5_","__ZL19SwapRegExpInternalsP9JSContextP8JSObjectPN2JS5ValueEP8JSStringj","__ZL16SwapObjectRegExpP9JSContextP8JSObjectN2js15AlreadyIncRefedINS3_6RegExpEEE","__ZL25EscapeNakedForwardSlashesP9JSContextP8JSString","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEEC1ES1_","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE7reserveEj","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE16infallibleAppendItEEvPKT_j","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE6appendIcEEbT_","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE6appendItEEbT_","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE16extractRawBufferEv","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEED2Ev","__ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZNK2js11NeedsIncRefINS_6RegExpEE3getEv","_JSVAL_TO_BOOLEAN_IMPL3536","__ZL14JSID_FROM_BITSj3545","_JSVAL_IS_BOOLEAN_IMPL3538","__ZNK2js13RegExpStatics9multilineEv","_JSVAL_TO_STRING_IMPL3543","_JSVAL_IS_STRING_IMPL3544","__ZN7mozilla14AlignedStorageILj256EE4addrEv","__ZL18JSDOUBLE_IS_FINITEd3520","__ZL15JSDOUBLE_IS_NaNd3521","__ZN2js10VectorImplItLj128ENS_15TempAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_","_BOOLEAN_TO_JSVAL_IMPL3507","__ZN2js11NeedsIncRefINS_6RegExpEEC2EPS1_","__ZN2js2gcL15GetGCObjectKindEjb3527","__ZL13JSVAL_TO_IMPLN2JS5ValueE3537","__ZL13IMPL_TO_JSVAL12jsval_layout3540","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE14internalAppendItEEvT_","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplItLj128ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorItLj128ES1_EEj","__ZN2js10VectorImplItLj128ENS_15TempAllocPolicyELb1EE13moveConstructItEEvPtPKT_S7_","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE14internalAppendIcEEvT_","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE14internalAppendItEEvPKT_j","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEEC2ES1_","__ZN2js12AutoRefCountINS_6RegExpEEC1EP9JSContextNS_11NeedsIncRefIS1_EE","__ZN2js11NeedsIncRefINS_6RegExpEEC1EPS1_","__ZNK8JSObject18getRegExpLastIndexEv","__ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd3509","__ZN2JSL9NullValueEv3510","__ZN8JSObject18setRegExpLastIndexEd","__ZN2js12AutoRefCountINS_6RegExpEED1Ev","__ZN2js12AutoRefCountINS_6RegExpEED2Ev","__ZN2JSL11NumberValueEd3511","__ZL18js_DoubleToIntegerd3519","__ZN2js12AutoRefCountINS_6RegExpEEC2EP9JSContextNS_11NeedsIncRefIS1_EE","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16infallibleAppendERKt","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE3528","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE3529","__ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE","__ZNK2js13RegExpStatics9pairCountEv","__ZNK2js13RegExpStatics9makeMatchEP9JSContextjjPN2JS5ValueE","__ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEEixEj","__ZNK2js13RegExpStatics15createDependentEP9JSContextjjPN2JS5ValueE","__ZNK2js13RegExpStatics3getEjb","__ZNK2js13RegExpStatics18createRightContextEP9JSContextPN2JS5ValueE","__ZNK2js13RegExpStatics17createLeftContextEP9JSContextPN2JS5ValueE","__ZNK2js13RegExpStatics15createLastParenEP9JSContextPN2JS5ValueE","__ZNK2js13RegExpStatics15createLastMatchEP9JSContextPN2JS5ValueE","_JSVAL_IS_BOOLEAN","_JSVAL_TO_BOOLEAN","_BOOLEAN_TO_JSVAL3539","_JSVAL_IS_STRING3541","__ZN2js13RegExpStatics15setPendingInputEP8JSString","_JSVAL_TO_STRING3542","__ZNK2js13RegExpStatics18createPendingInputEP9JSContextPN2JS5ValueE","__ZNK2js13RegExpStatics4markEP8JSTracer","__ZN9JSContext7delete_IN2js13RegExpStaticsEEEvPT_","__ZN2js13RegExpStaticsD1Ev","__ZN2js13RegExpStaticsD2Ev","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEED1Ev","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEED2Ev","__ZN2jsL13VersionHasXMLE9JSVersion3598","__ZNK2js11TokenStream8TokenBuf11hasRawCharsEv","__ZN2js11FindKeywordEPKtj","__ZN2js11TokenStream8TokenBuf4initEPKtj","__ZN2js11TokenStream8TokenBuf10getRawCharEv","__Z15js_IsIdentifierP14JSLinearString","__ZN2js7unicode17IsIdentifierStartEt","__ZN2js7unicode16IsIdentifierPartEt","__ZN2js11TokenStreamC2EP9JSContext","__ZN2js11TokenStream8TokenBufC1Ev","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEEC1ES1_","__ZN2js11TokenStream4initEPKtjPKcj9JSVersion","__ZN2js11TokenStreamD2Ev","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEED1Ev","__Z8js_fgetsPciP7__sFILE","__ZN2js11TokenStream7getCharEv","__ZN2js11TokenStream8TokenBuf12isRawEOLCharEi","__ZNK2js11TokenStream8TokenBuf7atStartEv","__ZN2js11TokenStream12isStrictModeEv","__ZN2js11TokenStream8TokenBuf12matchRawCharEt","__ZN2js11TokenStream8TokenBuf12ungetRawCharEv","__ZN2js11TokenStream8TokenBuf21matchRawCharBackwardsEt","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE8shrinkByEj","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE3endEv","__ZN2js11TokenStream20updateLineInfoForEOLEv","__ZN2js11TokenStream16getCharIgnoreEOLEv","__ZN2js11TokenStream9ungetCharEi","__ZN2js11TokenStream18ungetCharIgnoreEOLEi","__ZN2js11TokenStream9peekCharsEiPt","__ZN2js11TokenStream8TokenBuf7findEOLEv","__ZN2js11TokenStream26reportCompileErrorNumberVAEP11JSParseNodejjPc","__ZN2jsL7PodZeroI13JSErrorReportEEvPT_3601","__ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz","__ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz","__ZN2js11TokenStream12getXMLEntityEv","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIcEEbT_","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_","__ZN2js7unicode10IsXMLSpaceEt","__ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5emptyEv","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE5clearEv","__ZN2js11TokenStream15getXMLTextOrTagEPNS_9TokenKindEPPNS_5TokenE","__ZN2js11TokenStream8newTokenEi","__ZN2js11TokenStream7atomizeEP9JSContextRNS_6VectorItLj32ENS_15TempAllocPolicyEEE","__ZN2js7unicode19IsXMLNamespaceStartEt","__ZN2js7unicode13IsXMLNamePartEt","__ZN2js11TokenStream8peekCharEv","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIcEEbPKT_j","__ZN2js11TokenStream9matchCharEi","__ZN2js11TokenStream12getXMLMarkupEPNS_9TokenKindEPPNS_5TokenE","__ZN2js11TokenStream9skipCharsEi","__ZN2js7unicode18IsXMLNamespacePartEt","__ZN2js11TokenStream17peekUnicodeEscapeEPi","__ZN2js11TokenStream25matchUnicodeEscapeIdStartEPi","__ZN2js11TokenStream23matchUnicodeEscapeIdentEPi","__ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv","__ZL10CharsMatchPKtPKc","__ZN2js11TokenStream8TokenBuf23setAddressOfNextRawCharEPKt","__ZN2js11TokenStream9getAtLineEv","__ZN2js7unicode13IsSpaceOrBOM2Et","__ZN2js11TokenStream21getAtSourceMappingURLEv","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendItEEbT_","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEEixEj","__ZN2js11TokenStream18putIdentInTokenbufEPKt","__ZN2js11TokenStream16getTokenInternalEv","__ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js7unicode13CharacterInfo8isLetterEv","__ZNK2js7unicode13CharacterInfo15isEnclosingMarkEv","__ZNK2js7unicode13CharacterInfo22isCombiningSpacingMarkEv","__ZNK2js7unicode13CharacterInfo16isIdentifierPartEv","__ZN2js13PropertyTable13sizeOfEntriesEj","__ZN2jsL6HashIdEi","__ZNK2js13PropertyTable8capacityEv","__ZN2js11TokenStream17updateFlagsForEOLEv","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_","__ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE13copyConstructIcEEvPtPKT_S7_","__ZN2js11TokenStream8TokenBufC2Ev","__ZN2js7unicode8IsLetterEt","__ZNK9JSContext15hasAtLineOptionEv","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendItEEvT_","__ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorItLj32ES1_EEj","__ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE13moveConstructItEEvPtPKT_S7_","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIcEEbPKT_S6_","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendIcEEvPKT_j","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendIiEEvT_","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendIcEEvT_","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEED2Ev","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEEC2ES1_","__Z16js_GenerateShapeP9JSRuntime","__Z16js_GenerateShapeP9JSContext","__ZN8JSObject38ensureClassReservedSlotsForEmptyObjectEP9JSContext","__ZN2js13PropertyTable4initEP9JSRuntimePNS_5ShapeE","__ZN2js13PropertyTable6searchEib","__ZN2js5Shape7hashifyEP9JSContext","__ZN9JSRuntime4new_IN2js13PropertyTableEjEEPT_T0_","__ZN2js13PropertyTable6changeEiP9JSContext","__ZN2js13PropertyTable4growEP9JSContext","__ZN2js5Shape8getChildEP9JSContextRKS0_PPS0_","__ZNK2js13PropertyTable11needsToGrowEv","__ZN2js5Shape18newDictionaryShapeEP9JSContextRKS0_PPS0_","__ZN2js5Shape17newDictionaryListEP9JSContextPPS0_","__ZNK2js5Shape6frozenEv","__ZL24NormalizeGetterAndSetterP9JSContextP8JSObjectijjRPFiS0_S2_iPN2JS5ValueEERPFiS0_S2_iiS5_E","__ZN8JSObject13clearOwnShapeEv","__ZN8JSObject18removeLastPropertyEv","__ZN8JSObject16getChildPropertyEP9JSContextPN2js5ShapeERS3_","__ZN2js5Shape20insertIntoDictionaryEPPS0_","__ZN8JSObject16toDictionaryModeEP9JSContext","__ZN8JSObject11addPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji","__ZN8JSObject19addPropertyInternalEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_EjjjiPPN2js5ShapeE","__ZN8JSObject11putPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji","__Z19CheckCanChangeAttrsP9JSContextP8JSObjectPKN2js5ShapeEPj","__ZN2JSL14UndefinedValueEv3631","__ZN8JSObject14changePropertyEP9JSContextPKN2js5ShapeEjjPFiS1_PS_iPN2JS5ValueEEPFiS1_S6_iiS9_E","__ZN8JSObject14removePropertyEP9JSContexti","__ZNK2js8Bindings9lastUpvarEv","__ZNK2js5Shape8getFlagsEv","__ZNK8JSObject20getMethodThrashCountEv","_INT_TO_JSID3676","__ZNK2js5Shape20removeFromDictionaryEP8JSObject","__ZN8JSObject20setMethodThrashCountEj","__ZN2js13PropertyTableC2Ej","__ZN2js5Shape9setFrozenEv","__ZN2JSL18PrivateUint32ValueEj3636","__ZN8JSObject5clearEP9JSContext","__ZN8JSObject18rollbackPropertiesEP9JSContextj","__ZN8JSObject16generateOwnShapeEP9JSContext","__ZN8JSObject17methodShapeChangeEP9JSContextRKN2js5ShapeE","__ZN8JSObject17methodShapeChangeEP9JSContextj","__ZN8JSObject16protoShapeChangeEP9JSContext","__ZN8JSObject20shadowingShapeChangeEP9JSContextRKN2js5ShapeE","__ZN2js13PropertyTableC1Ej","__ZNK2js8Bindings6lookupEP9JSContextP6JSAtomPj","__ZL12ATOM_TO_JSIDP6JSAtom3673","__ZN2js8Bindings3addEP9JSContextP6JSAtomNS_11BindingKindE","__ZN2js8Bindings11ensureShapeEP9JSContext","__ZN2js8Bindings17getLocalNameArrayEP9JSContextPNS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEE","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE19growByUninitializedEj","__ZL12JSID_IS_ATOMi3679","__ZL12JSID_TO_ATOMi3680","__ZNK2js8Bindings12lastVariableEv","__ZN2js8Bindings13sharpSlotBaseEP9JSContext","__ZN2js8Bindings13makeImmutableEv","__ZN2js8Bindings5traceEP8JSTracer","__Z12js_XDRScriptP10JSXDRStatePP8JSScript","__ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5Range5emptyEv","__Z21js_MarkScriptFilenamePKc","__ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5Range5frontEv","__ZN2jsL7PodZeroIjEEvPT_j","__ZN8JSScript8numNotesEv","__ZN8JSScript9NewScriptEP9JSContextjjjjjjjjjttj9JSVersion","__ZL18SaveScriptFilenameP9JSContextPKc","__ZN12JSPCCounters4initEP9JSContextj","__ZN12JSPCCounters7destroyEP9JSContext","__ZL12script_traceP8JSTracerP8JSObject","__Z23js_SweepScriptFilenamesP13JSCompartment","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumC1IS8_EERT_","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4Enum11removeFrontEv","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5Range8popFrontEv","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumD1Ev","__Z14js_NewGCScriptP9JSContext","__ZN2jsL7PodZeroI8JSScriptEEvPT_","__ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE6getMapEv","__ZNK2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE6hasMapEv","__ZN2js11TokenStream16releaseSourceMapEv","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE5clearEv","__ZN8JSScript15NewScriptFromCGEP9JSContextP15JSCodeGenerator","__ZNK15JSCodeGenerator7versionEv","__ZNK15JSCodeGenerator15hasUpvarIndicesEv","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEixEj","__Z18js_NewScriptObjectP9JSContextP8JSScript","__Z20js_CallNewScriptHookP9JSContextP8JSScriptP10JSFunction","__Z24js_CallDestroyScriptHookP9JSContextP8JSScript","__ZN2js8Debugger15onDestroyScriptEP8JSScript","__ZN8JSScript8finalizeEP9JSContext","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3707","__ZN2js8GSNCache5purgeEv","__ZNK2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE11initializedEv","__ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE6finishEv","__ZNK14AutoJSXDRStatecvP10JSXDRStateEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10overloadedEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv","__Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh","__ZNK2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE6lookupERKS1_","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv","__ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE4initEj","__ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE3putERKS1_S7_","__Z22js_FramePCToLineNumberP9JSContextPN2js10StackFrameEPh","__Z17js_PCToLineNumberP9JSContextP8JSScriptPh","__ZL12js_GetOpcodeP9JSContextP8JSScriptPh3716","__Z17js_LineNumberToPCP8JSScriptj","__Z22js_GetScriptLineExtentP8JSScript","__ZN2js28CurrentScriptFileAndLineSlowEP9JSContextPj","__Z14js_CloneScriptP9JSContextP8JSScript","__ZN14AutoJSXDRStateC1EP10JSXDRState","__ZN28DisablePrincipalsTranscodingC1EP9JSContext","__ZN14AutoJSXDRStateD1Ev","__ZN28DisablePrincipalsTranscodingD1Ev","__ZN8JSScript14tryNewStepModeEP9JSContextj","__ZN2js17InterpreterFrames25enableInterruptsIfRunningEP8JSScript","__ZN8JSScript19changeStepModeCountEP9JSContexti","__ZNK2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE12lookupForAddERKS1_","__ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S1_EENS5_13MapHashPolicyES4_E6AddPtrERKS1_SF_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrEPPS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrE","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE10getKeyHashEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEptEv","__ZNK2js7MoveRefINS_12HashMapEntryIPhS2_EEEptEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr7nonNullEv","__ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE10getKeyHashEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEptEv","__ZNK2js7MoveRefIPNS_19ScriptFilenameEntryEEcvRS2_Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE6isFreeEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE10isLiveHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE9matchHashEj","__ZN2js13PointerHasherIPhLj0EE5matchERKS1_S4_","__ZN2js13PointerHasherIPhLj0EE4hashERKS1_","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11initializedEv","__ZN2jsL16GetClassProtoKeyEPNS_5ClassE3741","__ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE12hasCollisionEv","__ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE10isLiveHashEj","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash1Ejj","__ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isFreeEv","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE7setLiveEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE14unsetCollisionEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEC2ERS6_","__ZN2js7MoveRefINS_12HashMapEntryIPhS2_EEEC2ERS3_","__ZN2js12HashMapEntryIPhS1_EC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE12setCollisionEj","__ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S1_EE","__ZN2js2gcL15GetGCObjectKindEjb3731","__ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE10setRemovedEv","__ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE7setFreeEv","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11underloadedEv","__ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE14unsetCollisionEv","__ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEC2ERS6_","__ZN2js7MoveRefIPNS_19ScriptFilenameEntryEEC2ERS2_","__ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE6isLiveEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEENS_7MoveRefIT_EERS8_","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEC1ERS6_","__ZN2js12HashMapEntryIPhS1_EaSENS_7MoveRefIS2_EE","__ZN2js4MoveINS_12HashMapEntryIPhS2_EEEENS_7MoveRefIT_EERS5_","__ZN2js7MoveRefINS_12HashMapEntryIPhS2_EEEC1ERS3_","__ZN2js4MoveIPhEENS_7MoveRefIT_EERS3_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEEC2Ev","__ZN2js12HashMapEntryIPhS1_EC1Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12lookupForAddERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKS3_","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS3_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS4_EERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6finishEv","__ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3732","__ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_3733","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE3736","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6removeERNS0_14HashTableEntryIS4_EE","__ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isLiveEv","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumD2Ev","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16checkUnderloadedEv","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E15changeTableSizeEi","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEENS_7MoveRefIT_EERS8_","__ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEC1ERS6_","__ZN2js4MoveIPNS_19ScriptFilenameEntryEEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefIPNS_19ScriptFilenameEntryEEC1ERS2_","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumC2IS8_EERT_","__ZNK2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE3allEv","__ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3allEv","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5RangeC1EPNS0_14HashTableEntryIS4_EESE_","__ZNK2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv","__ZNK2js11TokenStream16versionWithFlagsEv","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr7nonNullEv","__ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_","__ZL14JSID_FROM_BITSj3746","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5emptyEv","__ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE9isRemovedEv","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10overloadedEv","__ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE9matchHashEj","_JSID_TO_STRING3744","_JSID_IS_STRING3745","__ZN2js10VectorImplIP6JSAtomLj0ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_","__ZN28DisablePrincipalsTranscodingD2Ev","__ZN14AutoJSXDRStateC2EP10JSXDRState","__ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrdeEv","__ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE7setLiveEj","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrC2ERNS0_14HashTableEntryIS4_EE","__ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE12setCollisionEj","__ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkC2EP11JSArenaPool","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5RangeC2EPNS0_14HashTableEntryIS4_EESE_","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE10growByImplILb0EEEbj","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIP6JSAtomLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj","__ZN2js10VectorImplIP6JSAtomLj0ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN14AutoJSXDRStateD2Ev","__ZN28DisablePrincipalsTranscodingC2EP9JSContext","__ZNK2js9InlineMapIP6JSAtomjLj24EE5emptyEv","__ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5emptyEv","__ZNK2js6Parser16versionWithFlagsEv","__Z10NewGCThingI8JSScriptEPT_P9JSContextN2js2gc9AllocKindEj","__ZNK2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE12lookupForAddERKPKc","__ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrcvMSB_FvvEEv","__ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS5_6SetOpsES4_E6AddPtrERS8_","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrERS4_","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrE","__ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr5foundEv","__ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12lookupForAddERKPKc","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11prepareHashERKPKc","__ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6lookupERKPKcjj","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5matchERNS0_14HashTableEntryIS4_EERKPKc","__ZN2js20ScriptFilenameHasher5matchEPKNS_19ScriptFilenameEntryEPKc","__ZN2js20ScriptFilenameHasher4hashEPKc","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10isLiveHashEj","__ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkD2Ev","__ZN2js10EmptyShape17getEmptyCallShapeEP9JSContext","__ZL10str_escapeP9JSContextjPN2JS5ValueE","__ZL12str_unescapeP9JSContextjPN2JS5ValueE","__ZL10str_unevalP9JSContextjPN2JS5ValueE","__ZL13str_decodeURIP9JSContextjPN2JS5ValueE","__ZL13str_encodeURIP9JSContextjPN2JS5ValueE","__ZL23str_decodeURI_ComponentP9JSContextjPN2JS5ValueE","__ZL23str_encodeURI_ComponentP9JSContextjPN2JS5ValueE","__ZL13str_enumerateP9JSContextP8JSObject","__ZL11str_resolveP9JSContextP8JSObjectijPS2_","__Z15js_str_toStringP9JSContextjPN2JS5ValueE","__ZN2js16GetPrimitiveThisIP8JSStringEEbP9JSContextPN2JS5ValueEPT_","__Z14js_toLowerCaseP9JSContextP8JSString","__Z12js_NewStringP9JSContextPtj","__Z14js_toUpperCaseP9JSContextP8JSString","__ZN2js7unicode11ToUpperCaseEt","__Z13js_str_charAtP9JSContextjPN2JS5ValueE","__ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE","__ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd3824","__Z17js_str_charCodeAtP9JSContextjPN2JS5ValueE","__Z21js_BoyerMooreHorspoolPKtjS0_j","__ZNK9FlatMatch5matchEv","__Z15js_strchr_limitPKttS0_","__ZN2js11str_replaceEP9JSContextjPN2JS5ValueE","__ZN11ReplaceDataC1EP9JSContext","__ZN11RegExpGuard4initEjPN2JS5ValueEb","__ZL13js_IsCallableRKN2JS5ValueE3827","__ZN2JSL14UndefinedValueEv3828","__ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj","__ZN11RegExpGuard12tryFlatMatchEP9JSContextP8JSStringjjb","__ZL18str_replace_regexpP9JSContextjPN2JS5ValueER11ReplaceData","__ZL23str_replace_flat_lambdaP9JSContextjPN2JS5ValueER11ReplaceDataRK9FlatMatch","__ZL22BuildDollarReplacementP9JSContextP8JSStringP14JSLinearStringPKtRK9FlatMatchPN2JS5ValueE","__ZL20BuildFlatReplacementP9JSContextP8JSStringS2_RK9FlatMatchPN2JS5ValueE","__ZN11ReplaceDataD1Ev","__ZL9str_quoteP9JSContextjPN2JS5ValueE","__ZL12str_toSourceP9JSContextjPN2JS5ValueE","__ZL13str_substringP9JSContextjPN2JS5ValueE","__ZL15str_toLowerCaseP9JSContextjPN2JS5ValueE","__ZL15str_toUpperCaseP9JSContextjPN2JS5ValueE","__ZL11str_indexOfP9JSContextjPN2JS5ValueE","__ZL15str_lastIndexOfP9JSContextjPN2JS5ValueE","__ZL8str_trimP9JSContextjPN2JS5ValueE","__ZL12str_trimLeftP9JSContextjPN2JS5ValueE","__ZL13str_trimRightP9JSContextjPN2JS5ValueE","__ZL21str_toLocaleLowerCaseP9JSContextjPN2JS5ValueE","__ZL21str_toLocaleUpperCaseP9JSContextjPN2JS5ValueE","__ZL17str_localeCompareP9JSContextjPN2JS5ValueE","__ZL9str_matchP9JSContextjPN2JS5ValueE","__ZL10str_searchP9JSContextjPN2JS5ValueE","__ZL9str_splitP9JSContextjPN2JS5ValueE","__ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE8capacityEv","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE5clearEv","__ZL10str_substrP9JSContextjPN2JS5ValueE","__ZL10str_concatP9JSContextjPN2JS5ValueE","__ZL9str_sliceP9JSContextjPN2JS5ValueE","__ZL8str_boldP9JSContextjPN2JS5ValueE","__ZL11str_italicsP9JSContextjPN2JS5ValueE","__ZL9str_fixedP9JSContextjPN2JS5ValueE","__ZL12str_fontsizeP9JSContextjPN2JS5ValueE","__ZL13str_fontcolorP9JSContextjPN2JS5ValueE","__ZL8str_linkP9JSContextjPN2JS5ValueE","__ZL10str_anchorP9JSContextjPN2JS5ValueE","__ZL10str_strikeP9JSContextjPN2JS5ValueE","__ZL9str_smallP9JSContextjPN2JS5ValueE","__ZL7str_bigP9JSContextjPN2JS5ValueE","__ZL9str_blinkP9JSContextjPN2JS5ValueE","__ZL7str_supP9JSContextjPN2JS5ValueE","__ZL7str_subP9JSContextjPN2JS5ValueE","__Z9js_StringP9JSContextjPN2JS5ValueE","__Z16js_ValueToStringP9JSContextRKN2JS5ValueE","__ZN2jsL14IsConstructingEPKN2JS5ValueE3833","__ZL16str_fromCharCodeP9JSContextjPN2JS5ValueE","__ZN2js12StringObject18assignInitialShapeEP9JSContext","__ZL12ATOM_TO_JSIDP6JSAtom3836","__Z18js_InitStringClassP9JSContextP8JSObject","__ZN2jsL17CheckStringLengthEP9JSContextj3839","__ZN13JSFixedString4new_EP9JSContextPKtj","__ZN2js12StringBuffer16extractWellSizedEv","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16extractRawBufferEv","__ZN2js12StringBuffer12finishStringEv","__ZL14NewShortStringP9JSContextPKtj","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendIcEEbT_","__ZN2js12StringBuffer10finishAtomEv","__Z21js_NewDependentStringP9JSContextP8JSStringjj","_JSDOUBLE_IS_NEGZERO3865","__Z9js_strlenPKt","__Z9js_strchrPKtt","__ZN17JSDependentString4new_EP9JSContextP14JSLinearStringPKtj","__Z17js_NewStringCopyNP9JSContextPKtj","__Z17js_NewStringCopyNP9JSContextPKcj","__ZL14NewShortStringP9JSContextPKcj","__ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE","__Z17js_NewStringCopyZP9JSContextPKc","__Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb","__Z16js_ValueToSourceP9JSContextRKN2JS5ValueE","__ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE3862","__ZN2js23ValueToStringBufferSlowEP9JSContextRKN2JS5ValueERNS_12StringBufferE","__ZN2js12StringBuffer6appendEP6JSAtom","__ZN2JSL9NullValueEv3866","__ZN2js12EqualStringsEP9JSContextP8JSStringS3_Pi","__ZN2jsL8PodEqualIKtEEbPT_S3_j3869","__ZN2js12EqualStringsEP14JSLinearStringS1_","__ZN2js14CompareStringsEP9JSContextP8JSStringS3_Pi","__ZN2jsL18CompareStringsImplEP9JSContextP8JSStringS3_Pi","__ZN2js17StringEqualsAsciiEP14JSLinearStringPKc","__ZN2js25InflateUTF8StringToBufferEP9JSContextPKcjPtPjNS_13FlationCodingE","__ZN2js13DeflateStringEP9JSContextPKtj","__Z20js_OneUcs4ToUtf8CharPhj","__ZL17Utf8ToOneUcs4CharPKhi","__ZN2js23GetDeflatedStringLengthEP9JSContextPKtj","__ZN2js21DeflateStringToBufferEP9JSContextPKtjPcPj","__ZN2js27GetDeflatedUTF8StringLengthEP9JSContextPKtjNS_13FlationCodingE","__ZN2js25DeflateStringToUTF8BufferEP9JSContextPKtjPcPjNS_13FlationCodingE","__ZN2js21InflateStringToBufferEP9JSContextPKcjPtPj","__ZN2js20PutEscapedStringImplEPcjP7__sFILEP14JSLinearStringj","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendIcEEvT_","__ZN2js6detail17PrimitiveBehaviorIP8JSStringE6isTypeERKN2JS5ValueE","__ZN2js6detail17PrimitiveBehaviorIP8JSStringE7extractERKN2JS5ValueE","__ZL6EncodeP9JSContextP8JSStringPKtS4_PN2JS5ValueE","__ZL22TransferBufferToStringP9JSContextRN2js12StringBufferEPN2JS5ValueE","__ZL14JSID_FROM_BITSj3911","__ZNK16SplitMatchResult6lengthEv","__ZN14JSInlineString10lengthFitsEj","_JSID_IS_INT3906","__ZN2js13StaticStrings7hasUnitEt","__ZNK16SplitMatchResult9isFailureEv","__ZL6DecodeP9JSContextP8JSStringPKtPN2JS5ValueE","__ZN14JSInlineString4new_EP9JSContext","__ZN13JSShortString4new_EP9JSContext","__ZN14JSInlineString11resetLengthEj","__ZN17JSDependentString4initEP14JSLinearStringPKtj","__ZN2jsL7PodCopyItEEvPT_PKS1_j3900","__ZN13JSFixedString4initEPKtj","__ZN2JSL11ObjectValueER8JSObject3902","__ZN2JSL11StringValueEP8JSString3909","__ZN2JSL10Int32ValueEi3910","__ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE","__ZL12tagify_valueP9JSContextjPN2JS5ValueEPKcS5_","__Z19ValueToIntegerRangeP9JSContextRKN2JS5ValueEPi","__ZL15VALUE_IS_REGEXPP9JSContextN2JS5ValueE","__ZL11SplitHelperI18SplitRegExpMatcherEP8JSObjectP9JSContextP14JSLinearStringjT_PN2js5types10TypeObjectE","__ZN18SplitRegExpMatcherC1EPN2js6RegExpEPNS0_13RegExpStaticsE","__ZL11SplitHelperI18SplitStringMatcherEP8JSObjectP9JSContextP14JSLinearStringjT_PN2js5types10TypeObjectE","__ZN18SplitStringMatcherC1EP14JSLinearString","__ZN18SplitStringMatcherC2EP14JSLinearString","__ZN18SplitStringMatcherclEP9JSContextP14JSLinearStringjP16SplitMatchResult","__ZNK16SplitMatchResult8endIndexEv","__ZNK2js12AutoRefCountINS_6RegExpEEdeEv","__ZNK10RegExpPair5reobjEv","__ZNK9FlatMatch13patternLengthEv","__ZNK2js18StringSegmentRange5frontEv","__ZN2js6RegExp10isMetaCharEt","__ZNK2js12AutoRefCountINS_6RegExpEE4nullEv","__ZNK2js18StringSegmentRange5emptyEv","__ZL15JSDOUBLE_IS_NaNd3930","__ZL18JSDOUBLE_IS_FINITEd3932","__ZN16SplitMatchResult10setFailureEv","__ZN16SplitMatchResult9setResultEjj","__ZN9ManualCmp13computeExtentEPKtj","__ZN9ManualCmp5matchEPKtS1_S1_","__ZN18SplitRegExpMatcherC2EPN2js6RegExpEPNS0_13RegExpStaticsE","__ZN9FlatMatchC2Ev","__ZN2js12AutoRefCountINS_6RegExpEEC2EP9JSContext","__ZNK9FlatMatch7patternEv","__ZL11StringMatchPKtjS0_j","__ZL13UnrolledMatchI9ManualCmpEiPKtjS2_j","__ZN18SplitRegExpMatcherclEP9JSContextP14JSLinearStringjP16SplitMatchResult","__ZNK2js13RegExpStatics10parenCountEv","__ZNK2js13RegExpStatics13pairIsPresentEj","__ZNK2js13RegExpStatics8getParenEjP11JSSubString","__ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcRKN2JS5ValueE","__ZNK2js13RegExpStatics14getParenLengthEj","__ZNK2js13RegExpStatics12getLastMatchEP11JSSubString","__ZN11RegExpGuardC1EP9JSContext","__ZN11RegExpGuard15normalizeRegExpEbjjPN2JS5ValueE","__ZNK10RegExpPair2reEv","__ZNK2js13RegExpStatics10matchStartEv","__ZN11RegExpGuardD1Ev","__ZN11RegExpGuardD2Ev","__ZN10RegExpPairD1Ev","__ZN10RegExpPairD2Ev","__ZNK10RegExpPair9hasRegExpEv","__ZN11RegExpGuard14flattenPatternEP9JSContextP14JSLinearString","__ZN10RegExpPair5resetEN2js15AlreadyIncRefedINS0_6RegExpEEE","__ZN2js12AutoRefCountINS_6RegExpEE5resetENS_15AlreadyIncRefedIS1_EE","__ZN11RegExpGuardC2EP9JSContext","__ZN10RegExpPairC1EP9JSContext","__ZN9FlatMatchC1Ev","__ZN10RegExpPairC2EP9JSContext","__ZN2js12AutoRefCountINS_6RegExpEEC1EP9JSContext","__ZL19BuildFlatMatchArrayP9JSContextP8JSStringRK9FlatMatchPN2JS5ValueE","__ZL7DoMatchP9JSContextPN2js13RegExpStaticsEP8JSStringRK10RegExpPairPFbS0_S3_jPvES9_17MatchControlFlagsPN2JS5ValueE","__ZL13MatchCallbackP9JSContextPN2js13RegExpStaticsEjPv","__ZN8JSObject13defineElementEP9JSContextjRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej","__ZL7MatchedbRKN2JS5ValueE","__ZNK2js13RegExpStatics7matchedEv","__ZL13js_TrimStringP9JSContextPN2JS5ValueEii","__ZL18js_DoubleToIntegerd3931","__ZN11ReplaceDataD2Ev","__ZN2js11RopeBuilderC1EP9JSContext","__ZN2js18StringSegmentRangeC1EP9JSContext","__ZN2js18StringSegmentRange4initEP8JSString","__ZN2js11RopeBuilder6resultEv","__ZNK2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE5emptyEv","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE7popBackEv","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE3endEv","__ZN2js10VectorImplIP8JSStringLj32ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_","__ZN2js11RopeBuilderC2EP9JSContext","__ZN2js11RopeBuilder6appendEP8JSString","__ZN2js18StringSegmentRange8popFrontEv","__ZN2js18StringSegmentRangeD1Ev","__ZN2js18StringSegmentRangeD2Ev","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEED2Ev","__ZNK2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js18StringSegmentRange6settleEP8JSString","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE7popCopyEv","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE4backEv","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE6appendIS2_EEbT_","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIP8JSStringLj32ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj32ES3_EEj","__ZN2js10VectorImplIP8JSStringLj32ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js18StringSegmentRangeC2EP9JSContext","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEEC1ES3_","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEEC2ES3_","__ZN2js12StringBuffer16infallibleAppendEPKtS2_","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16infallibleAppendItEEvPKT_S6_","__ZL21ReplaceRegExpCallbackP9JSContextPN2js13RegExpStaticsEjPv","__ZNK2js13RegExpStatics15getRightContextEP11JSSubString","__ZNK2js13RegExpStatics10matchLimitEv","__ZL17FindReplaceLengthP9JSContextPN2js13RegExpStaticsER11ReplaceDataPj","__ZL9DoReplaceP9JSContextPN2js13RegExpStaticsER11ReplaceData","__ZL15InterpretDollarP9JSContextPN2js13RegExpStaticsEPKtS5_R11ReplaceDataP11JSSubStringPj","__ZNK2js13RegExpStatics12getLastParenEP11JSSubString","__ZNK2js13RegExpStatics14getLeftContextEP11JSSubString","__ZN2js21PreserveRegExpStaticsC1EPNS_13RegExpStaticsE","__ZN2js21PreserveRegExpStatics4initEP9JSContext","__ZN2jsL33ValueToString_TestForStringInlineEP9JSContextRKN2JS5ValueE","__ZN2js21PreserveRegExpStaticsD1Ev","__ZN2js21PreserveRegExpStaticsD2Ev","__ZN2js13RegExpStatics7restoreEv","__ZNK2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE5beginEv","__ZNK2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE12beginNoCheckEv","__ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983","_JSID_TO_INT3948","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE3endEv","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE10endNoCheckEv","__ZN2js10VectorImplIP14JSLinearStringLj16ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_","__ZN8JSObject8setClassEPN2js5ClassE","__ZN2js13RegExpStatics4saveEP9JSContextPS0_","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE7reserveEj","__ZN2js21PreserveRegExpStaticsC2EPNS_13RegExpStaticsE","__ZN2js13RegExpStaticsC1ENS0_10InitBufferE","__ZN2js13RegExpStaticsC2ENS0_10InitBufferE","__ZN2js6RegExp12hasMetaCharsEPKtj","__ZL9RopeMatchP9JSContextP8JSStringPKtjPi","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEEC1ES3_","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE6appendIS2_EEbT_","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEED1Ev","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEED2Ev","__ZNK2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE13growStorageByEj","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIP14JSLinearStringLj16ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj16ES3_EEj","__ZN2js10VectorImplIP14JSLinearStringLj16ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEEC2ES3_","__ZN10RegExpPair5resetER8JSObject","__ZN2js12AutoRefCountINS_6RegExpEE5resetENS_11NeedsIncRefIS1_EE","__ZN11ReplaceDataC2EP9JSContext","__ZN2jsL19ClassMethodIsNativeEP9JSContextP8JSObjectPNS_5ClassEiPFiS1_jPN2JS5ValueEE3938","__ZN2jsL16IsNativeFunctionERKN2JS5ValueEPFiP9JSContextjPS1_E3939","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP10JSFunction3940","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction3941","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject3942","__ZN2js11ArrayBuffer14getArrayBufferEP8JSObject","__Z16js_IsArrayBufferP8JSObject","__ZN2js11ArrayBuffer18prop_getByteLengthEP9JSContextP8JSObjectiPN2JS5ValueE","__ZN2js11ArrayBuffer17class_constructorEP9JSContextjPN2JS5ValueE","__ZN2js11ArrayBuffer6createEP9JSContexti","__ZN8JSObject24allocateArrayBufferSlotsEP9JSContextj","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981","__ZN2js11ArrayBuffer9obj_traceEP8JSTracerP8JSObject","__ZN2js11ArrayBuffer18obj_lookupPropertyEP9JSContextP8JSObjectiPS4_PP10JSProperty","__ZL12JSID_IS_ATOMiP6JSAtom3982","__ZL14DelegateObjectP9JSContextP8JSObject","__ZN2js11ArrayBuffer17obj_lookupElementEP9JSContextP8JSObjectjPS4_PP10JSProperty","__ZN2js11ArrayBuffer17obj_lookupSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPS4_PP10JSProperty","__ZN2js11ArrayBuffer10obj_typeOfEP9JSContextP8JSObject","__ZN2js10TypedArray24obj_getElementAttributesEP9JSContextP8JSObjectjPj","__Z32js_TypedArray_uint8_clamp_doubled","__ZL15JSDOUBLE_IS_NaNd3989","__ZN2js11ArrayBuffer18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN2js11ArrayBuffer17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN2js11ArrayBuffer17obj_defineSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS7_EPFiS2_S4_iiSA_Ej","__ZN2js11ArrayBuffer14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE","__ZN2js11ArrayBuffer15obj_getPropertyEP9JSContextP8JSObjectS4_PNS_12PropertyNameEPN2JS5ValueE","__ZL12ATOM_TO_JSIDP6JSAtom3984","__ZN2js11ArrayBuffer14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE","__ZN2js11ArrayBuffer14obj_getSpecialEP9JSContextP8JSObjectS4_NS_9SpecialIdEPN2JS5ValueE","__ZN2js11ArrayBuffer15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN2js11ArrayBuffer14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN2js11ArrayBuffer14obj_setSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPN2JS5ValueEi","__ZN2js11ArrayBuffer17obj_getAttributesEP9JSContextP8JSObjectiPj","__ZN2js11ArrayBuffer24obj_getElementAttributesEP9JSContextP8JSObjectjPj","__ZN2js11ArrayBuffer24obj_getSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj","__ZN2js11ArrayBuffer17obj_setAttributesEP9JSContextP8JSObjectiPj","__ZN2js11ArrayBuffer24obj_setElementAttributesEP9JSContextP8JSObjectjPj","__ZN2js11ArrayBuffer24obj_setSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj","__ZN2js11ArrayBuffer18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN2js11ArrayBuffer17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN2js11ArrayBuffer17obj_deleteSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPN2JS5ValueEi","__ZN2js11ArrayBuffer13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__ZN2js10TypedArray13getTypedArrayEP8JSObject","__Z15js_IsTypedArrayP8JSObject","__ZN2js10TypedArray14prop_getBufferEP9JSContextP8JSObjectiPN2JS5ValueE","__ZN16TypedArrayGetterIXadL_Z14getBufferValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE","__ZN2js10TypedArray18prop_getByteOffsetEP9JSContextP8JSObjectiPN2JS5ValueE","__ZN16TypedArrayGetterIXadL_Z18getByteOffsetValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE","__ZN2js10TypedArray18prop_getByteLengthEP9JSContextP8JSObjectiPN2JS5ValueE","__ZN16TypedArrayGetterIXadL_Z18getByteLengthValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE","__ZN2js10TypedArray14prop_getLengthEP9JSContextP8JSObjectiPN2JS5ValueE","__ZN16TypedArrayGetterIXadL_Z14getLengthValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE","__ZN2js10TypedArray18obj_lookupPropertyEP9JSContextP8JSObjectiPS4_PP10JSProperty","__ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj","__ZN2js10TypedArray17obj_lookupElementEP9JSContextP8JSObjectjPS4_PP10JSProperty","__ZN2js10TypedArray17obj_lookupSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPS4_PP10JSProperty","__ZN2js10TypedArray17obj_getAttributesEP9JSContextP8JSObjectiPj","__ZN2js10TypedArray24obj_getSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj","__ZN2js10TypedArray17obj_setAttributesEP9JSContextP8JSObjectiPj","__ZN2js10TypedArray24obj_setElementAttributesEP9JSContextP8JSObjectjPj","__ZN2js10TypedArray24obj_setSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj","__ZN18TypedArrayTemplateIiE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN18TypedArrayTemplateIiE8getIndexEP8JSObjectj","__ZN18TypedArrayTemplateIjE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN18TypedArrayTemplateIjE8getIndexEP8JSObjectj","__ZN18TypedArrayTemplateIfE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN18TypedArrayTemplateIfE8getIndexEP8JSObjectj","__ZN18TypedArrayTemplateIdE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN18TypedArrayTemplateIdE8getIndexEP8JSObjectj","__ZN18TypedArrayTemplateIaE12fun_subarrayEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIaE7fun_setEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIhE12fun_subarrayEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIhE7fun_setEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIsE12fun_subarrayEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIsE7fun_setEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateItE12fun_subarrayEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateItE7fun_setEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIiE12fun_subarrayEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIiE7fun_setEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIjE12fun_subarrayEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIjE7fun_setEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIfE12fun_subarrayEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIfE7fun_setEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIdE12fun_subarrayEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIdE7fun_setEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateI13uint8_clampedE12fun_subarrayEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIaE10obj_typeOfEP9JSContextP8JSObject","__ZN18TypedArrayTemplateIhE10obj_typeOfEP9JSContextP8JSObject","__ZN18TypedArrayTemplateI13uint8_clampedE7fun_setEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIaE9obj_traceEP8JSTracerP8JSObject","__ZN18TypedArrayTemplateIaE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIaE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIaE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej","__ZN18TypedArrayTemplateIaE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE","__ZN18TypedArrayTemplateIaE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE","__ZN18TypedArrayTemplateIaE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE","__ZN18TypedArrayTemplateIaE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE","__ZN18TypedArrayTemplateIaE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIaE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIaE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIaE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIaE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIaE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIaE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__ZN18TypedArrayTemplateIhE9obj_traceEP8JSTracerP8JSObject","__ZN18TypedArrayTemplateIhE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIhE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIhE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej","__ZN18TypedArrayTemplateIhE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE","__ZN18TypedArrayTemplateIhE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE","__ZN18TypedArrayTemplateIhE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE","__ZN18TypedArrayTemplateIhE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE","__ZN18TypedArrayTemplateIhE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIhE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIhE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIhE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIhE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIhE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIhE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__ZN18TypedArrayTemplateIsE9obj_traceEP8JSTracerP8JSObject","__ZN18TypedArrayTemplateIsE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIsE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIsE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej","__ZN18TypedArrayTemplateIsE10obj_typeOfEP9JSContextP8JSObject","__ZN18TypedArrayTemplateItE10obj_typeOfEP9JSContextP8JSObject","__ZN18TypedArrayTemplateIsE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE","__ZN18TypedArrayTemplateIsE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE","__ZN18TypedArrayTemplateIsE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE","__ZN18TypedArrayTemplateIsE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE","__ZN18TypedArrayTemplateIsE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIsE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIsE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIsE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIsE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIsE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIsE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__ZN18TypedArrayTemplateItE9obj_traceEP8JSTracerP8JSObject","__ZN18TypedArrayTemplateItE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateItE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateItE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej","__ZN18TypedArrayTemplateItE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE","__ZN18TypedArrayTemplateItE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE","__ZN18TypedArrayTemplateItE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE","__ZN18TypedArrayTemplateItE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE","__ZN18TypedArrayTemplateItE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateItE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateItE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateItE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateItE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateItE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateItE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__ZN18TypedArrayTemplateIiE9obj_traceEP8JSTracerP8JSObject","__ZN18TypedArrayTemplateIiE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIiE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIiE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej","__ZN18TypedArrayTemplateIiE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE","__ZN18TypedArrayTemplateIiE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE","__ZN18TypedArrayTemplateIiE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE","__ZN18TypedArrayTemplateIiE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE","__ZN18TypedArrayTemplateIiE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIiE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIiE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIiE10obj_typeOfEP9JSContextP8JSObject","__ZN18TypedArrayTemplateIjE10obj_typeOfEP9JSContextP8JSObject","__ZN18TypedArrayTemplateIfE10obj_typeOfEP9JSContextP8JSObject","__ZN18TypedArrayTemplateIiE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIiE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIiE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIiE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__ZN18TypedArrayTemplateIjE9obj_traceEP8JSTracerP8JSObject","__ZN18TypedArrayTemplateIjE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIjE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIjE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej","__ZN18TypedArrayTemplateIjE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE","__ZN18TypedArrayTemplateIjE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE","__ZN18TypedArrayTemplateIjE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE","__ZN18TypedArrayTemplateIjE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE","__ZN18TypedArrayTemplateIjE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIjE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIjE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIjE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIjE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIjE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIjE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__ZN18TypedArrayTemplateIfE9obj_traceEP8JSTracerP8JSObject","__ZN18TypedArrayTemplateIfE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIfE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIfE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej","__ZN18TypedArrayTemplateIfE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE","__ZN18TypedArrayTemplateIfE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE","__ZN18TypedArrayTemplateIfE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE","__ZN18TypedArrayTemplateIfE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE","__ZN18TypedArrayTemplateIfE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIfE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIfE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIfE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIfE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIfE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIfE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__ZN18TypedArrayTemplateIdE9obj_traceEP8JSTracerP8JSObject","__ZN18TypedArrayTemplateIdE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIdE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIdE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej","__ZN18TypedArrayTemplateIdE10obj_typeOfEP9JSContextP8JSObject","__ZN18TypedArrayTemplateI13uint8_clampedE10obj_typeOfEP9JSContextP8JSObject","__ZN18TypedArrayTemplateIdE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE","__ZN18TypedArrayTemplateIdE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE","__ZN18TypedArrayTemplateIdE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE","__ZN18TypedArrayTemplateIdE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE","__ZN18TypedArrayTemplateIdE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIdE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIdE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIdE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIdE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIdE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIdE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__ZN18TypedArrayTemplateI13uint8_clampedE9obj_traceEP8JSTracerP8JSObject","__ZN18TypedArrayTemplateI13uint8_clampedE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS3_S5_iPS7_EPFiS3_S5_iiSA_Ej","__ZN18TypedArrayTemplateI13uint8_clampedE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS3_S5_iPS7_EPFiS3_S5_iiSA_Ej","__ZN18TypedArrayTemplateI13uint8_clampedE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS3_S5_iPS9_EPFiS3_S5_iiSC_Ej","__ZN18TypedArrayTemplateI13uint8_clampedE14obj_getGenericEP9JSContextP8JSObjectS5_iPN2JS5ValueE","__ZN18TypedArrayTemplateI13uint8_clampedE15obj_getPropertyEP9JSContextP8JSObjectS5_PN2js12PropertyNameEPN2JS5ValueE","__ZN18TypedArrayTemplateI13uint8_clampedE14obj_getElementEP9JSContextP8JSObjectS5_jPN2JS5ValueE","__ZN18TypedArrayTemplateI13uint8_clampedE14obj_getSpecialEP9JSContextP8JSObjectS5_N2js9SpecialIdEPN2JS5ValueE","__ZN18TypedArrayTemplateI13uint8_clampedE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateI13uint8_clampedE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateI13uint8_clampedE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateI13uint8_clampedE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateI13uint8_clampedE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateI13uint8_clampedE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateI13uint8_clampedE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__Z24js_InitTypedArrayClassesP9JSContextP8JSObject","__ZL19InitTypedArrayClassI9Int8ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE","__ZL19InitTypedArrayClassI10Uint8ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE","__ZL19InitTypedArrayClassI10Int16ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE","__ZNK8JSObject13isArrayBufferEv","__ZN2js21IsFastTypedArrayClassEPKNS_5ClassE","__ZL19InitTypedArrayClassI11Uint16ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE","__ZL19InitTypedArrayClassI10Int32ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE","__ZL19InitTypedArrayClassI11Uint32ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE","__ZL19InitTypedArrayClassI12Float32ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE","__ZL19InitTypedArrayClassI12Float64ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE","__ZL19InitTypedArrayClassI17Uint8ClampedArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE","__ZL20InitArrayBufferClassP9JSContextPN2js12GlobalObjectE","__Z20js_CreateArrayBufferP9JSContextj","__Z19js_CreateTypedArrayP9JSContextij","__ZN2JSL10Int32ValueEi3996","__ZL19TypedArrayConstructP9JSContextijPN2JS5ValueE","__ZN2JSL11ObjectValueER8JSObject3997","__ZN18TypedArrayTemplateI13uint8_clampedE17class_constructorEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateI13uint8_clampedE6createEP9JSContextjPN2JS5ValueE","__ZL13ValueIsLengthP9JSContextRKN2JS5ValueEPj","__ZN18TypedArrayTemplateI13uint8_clampedE28createBufferWithSizeAndCountEP9JSContextj","__ZN18TypedArrayTemplateI13uint8_clampedE16createTypedArrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateI13uint8_clampedE18copyFromTypedArrayEP9JSContextP8JSObjectS5_j","_INT_TO_JSID4006","__ZL18JSDOUBLE_IS_FINITEd4011","__ZN13uint8_clampedaSERKS_","__ZN13uint8_clampedaSEj","__ZN13uint8_clampedaSEi","__ZN13uint8_clampedaSEt","__ZN13uint8_clampedaSEs","__ZN13uint8_clampedaSEh","__ZN13uint8_clampedaSEa","__ZN18TypedArrayTemplateI13uint8_clampedE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii","__ZN18TypedArrayTemplateI13uint8_clampedE13copyFromArrayEP9JSContextP8JSObjectS5_jj","__ZN18TypedArrayTemplateI13uint8_clampedE15nativeFromValueEP9JSContextRKN2JS5ValueE","__ZN13uint8_clampedC1Ei","__ZN13uint8_clampedC1Ed","__ZN13uint8_clampedC1Ej","__ZL20js_DoubleToECMAInt32d4007","__ZN13uint8_clampedC2Ej","__ZN13uint8_clampedC2Ed","__ZN13uint8_clampedaSEd","__ZN13uint8_clampedC2Ei","__ZN2js10TypedArray9getBufferEP8JSObject","__ZN18TypedArrayTemplateI13uint8_clampedE19copyFromWithOverlapEP9JSContextP8JSObjectS5_j","__ZN2js10TypedArray13getByteLengthEP8JSObject","__ZN13uint8_clampedC1Ea","__ZN13uint8_clampedC1Eh","__ZN13uint8_clampedC1Es","__ZN13uint8_clampedC1Et","__ZN13uint8_clampedC2Et","__ZN13uint8_clampedC2Es","__ZN13uint8_clampedC2Eh","__ZN13uint8_clampedC2Ea","__ZN18TypedArrayTemplateIdE17class_constructorEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIdE6createEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIdE28createBufferWithSizeAndCountEP9JSContextj","__ZN18TypedArrayTemplateIdE16createTypedArrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIdE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIdE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii","__ZN18TypedArrayTemplateIdE13copyFromArrayEP9JSContextP8JSObjectS4_jj","__ZN18TypedArrayTemplateIdE15nativeFromValueEP9JSContextRKN2JS5ValueE","__ZN18TypedArrayTemplateIdE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIfE17class_constructorEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIfE6createEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIfE28createBufferWithSizeAndCountEP9JSContextj","__ZN18TypedArrayTemplateIfE16createTypedArrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIfE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIfE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii","__ZN18TypedArrayTemplateIfE13copyFromArrayEP9JSContextP8JSObjectS4_jj","__ZN18TypedArrayTemplateIfE15nativeFromValueEP9JSContextRKN2JS5ValueE","__ZN18TypedArrayTemplateIfE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIjE17class_constructorEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIjE6createEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIjE28createBufferWithSizeAndCountEP9JSContextj","__ZN18TypedArrayTemplateIjE16createTypedArrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIjE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIjE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii","__ZN18TypedArrayTemplateIjE13copyFromArrayEP9JSContextP8JSObjectS4_jj","__ZN18TypedArrayTemplateIjE15nativeFromValueEP9JSContextRKN2JS5ValueE","__ZN18TypedArrayTemplateIjE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIiE17class_constructorEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIiE6createEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIiE28createBufferWithSizeAndCountEP9JSContextj","__ZN18TypedArrayTemplateIiE16createTypedArrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIiE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIiE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii","__ZN18TypedArrayTemplateIiE13copyFromArrayEP9JSContextP8JSObjectS4_jj","__ZN18TypedArrayTemplateIiE15nativeFromValueEP9JSContextRKN2JS5ValueE","__ZN18TypedArrayTemplateIiE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateItE17class_constructorEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateItE6createEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateItE28createBufferWithSizeAndCountEP9JSContextj","__ZN18TypedArrayTemplateItE16createTypedArrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateItE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateItE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii","__ZN18TypedArrayTemplateItE13copyFromArrayEP9JSContextP8JSObjectS4_jj","__ZN18TypedArrayTemplateItE15nativeFromValueEP9JSContextRKN2JS5ValueE","__ZN18TypedArrayTemplateItE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIsE17class_constructorEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIsE6createEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIsE28createBufferWithSizeAndCountEP9JSContextj","__ZN18TypedArrayTemplateIsE16createTypedArrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIsE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIsE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii","__ZN18TypedArrayTemplateIsE13copyFromArrayEP9JSContextP8JSObjectS4_jj","__ZN18TypedArrayTemplateIsE15nativeFromValueEP9JSContextRKN2JS5ValueE","__ZN18TypedArrayTemplateIsE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIhE17class_constructorEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIhE6createEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIhE28createBufferWithSizeAndCountEP9JSContextj","__ZN18TypedArrayTemplateIhE16createTypedArrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIhE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIhE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii","__ZN18TypedArrayTemplateIhE13copyFromArrayEP9JSContextP8JSObjectS4_jj","__ZN18TypedArrayTemplateIhE15nativeFromValueEP9JSContextRKN2JS5ValueE","__ZN18TypedArrayTemplateIhE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIaE17class_constructorEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIaE6createEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIaE28createBufferWithSizeAndCountEP9JSContextj","__ZN18TypedArrayTemplateIaE16createTypedArrayEP9JSContextP8JSObjectjj","__ZNK13uint8_clampedcvhEv","__ZN13uint8_clampedC2ERKS_","__ZN18TypedArrayTemplateIaE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIaE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii","__ZN18TypedArrayTemplateIaE13copyFromArrayEP9JSContextP8JSObjectS4_jj","__ZN18TypedArrayTemplateIaE15nativeFromValueEP9JSContextRKN2JS5ValueE","__ZN18TypedArrayTemplateIaE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateI13uint8_clampedE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateI13uint8_clampedE8setIndexEP8JSObjectjS0_","__ZN18TypedArrayTemplateI13uint8_clampedE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN18TypedArrayTemplateI13uint8_clampedE8getIndexEP8JSObjectj","__ZN13uint8_clampedC1ERKS_","__ZN18TypedArrayTemplateIdE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIdE8setIndexEP8JSObjectjd","__ZN18TypedArrayTemplateIfE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIfE8setIndexEP8JSObjectjf","__ZN18TypedArrayTemplateIjE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZL14JSID_FROM_BITSj4031","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv","__ZN2js2gcL15GetGCObjectKindEjb4033","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv","__ZN18TypedArrayTemplateIjE8setIndexEP8JSObjectjj","__ZN18TypedArrayTemplateIiE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIiE8setIndexEP8JSObjectji","__ZN18TypedArrayTemplateItE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateItE8setIndexEP8JSObjectjt","__ZN18TypedArrayTemplateItE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN18TypedArrayTemplateItE8getIndexEP8JSObjectj","__ZN18TypedArrayTemplateIsE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIsE8setIndexEP8JSObjectjs","__ZN18TypedArrayTemplateIsE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN18TypedArrayTemplateIsE8getIndexEP8JSObjectj","__ZN18TypedArrayTemplateIhE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIhE8setIndexEP8JSObjectjh","__ZN18TypedArrayTemplateIhE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN18TypedArrayTemplateIhE8getIndexEP8JSObjectj","__ZN18TypedArrayTemplateIaE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIaE8setIndexEP8JSObjectja","__ZN18TypedArrayTemplateIaE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN18TypedArrayTemplateIaE8getIndexEP8JSObjectj","__ZN18TypedArrayTemplateI13uint8_clampedE14createSubarrayEP9JSContextP8JSObjectjj","__ZN2js10TypedArray13getByteOffsetEP8JSObject","__ZN18TypedArrayTemplateIdE14createSubarrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIfE14createSubarrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIjE14createSubarrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIiE14createSubarrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateItE14createSubarrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIsE14createSubarrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIhE14createSubarrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIaE14createSubarrayEP9JSContextP8JSObjectjj","__Z14getLengthValueP8JSObject","__Z18getByteLengthValueP8JSObject","__Z18getByteOffsetValueP8JSObject","__Z14getBufferValueP8JSObject","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_4032","__ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE4034","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE4037","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE4041","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE4042","_JS_Assert","__ZL9CrashInJSv","__ZN2js13WatchpointMap4initEv","__ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE4initEj","__ZN2js13WatchpointMap5watchEP9JSContextP8JSObjectiPFiS2_S4_iN2JS5ValueEPS6_PvES4_","__ZN8JSObject10setWatchedEP9JSContext","__ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3putERKS1_RKS2_","__ZN2js8WatchKeyC1EP8JSObjecti","__ZN2js13WatchpointMap7unwatchEP8JSObjectiPPFiP9JSContextS2_iN2JS5ValueEPS6_PvEPS2_","__ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6lookupERKS1_","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv","__ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E3PtrE","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC1ISA_EERT_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev","__ZN2js13WatchpointMap5clearEv","__ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE5clearEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEptEv","__ZNK2js7MoveRefINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEptEv","__ZNK2js7MoveRefINS_8WatchKeyEEcvRS1_Ev","__ZNK2js7MoveRefINS_10WatchpointEEcvRS1_Ev","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE10getKeyHashEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE10isLiveHashEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE12hasCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isFreeEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEC2ERS7_","__ZN2js7MoveRefINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC2ERS4_","__ZN2js7MoveRefINS_10WatchpointEEC2ERS1_","__ZN2js7MoveRefINS_8WatchKeyEEC2ERS1_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE14unsetCollisionEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE12setCollisionEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrdeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE7setLiveEj","__ZN2js13WatchpointMap17triggerWatchpointEP9JSContextP8JSObjectiPN2JS5ValueE","__ZN15AutoEntryHolderC1ERN2js7HashMapINS0_8WatchKeyENS0_10WatchpointENS0_13DefaultHasherIS2_EENS0_17SystemAllocPolicyEEENS0_6detail9HashTableINS0_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E3PtrE","__ZN2JSL11ObjectValueER8JSObject4064","__ZN15AutoEntryHolderD1Ev","__ZN2js13WatchpointMap18markAllIterativelyEP8JSTracer","__ZN2js13WatchpointMap15markIterativelyEP8JSTracer","__ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3allEv","__ZN2js13WatchpointMap8sweepAllEP9JSContext","__ZN2js13WatchpointMap5sweepEP9JSContext","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isLiveEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5clearEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEaSENS_7MoveRefIS6_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEENS_7MoveRefIT_EERKS9_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC2Ev","__ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEC1Ev","__ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEC2Ev","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEC1ERS7_","__ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEaSENS_7MoveRefIS3_EE","__ZN2js4MoveINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEENS_7MoveRefIT_EERS6_","__ZN2js7MoveRefINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC1ERS4_","__ZN2js4MoveINS_8WatchKeyEEENS_7MoveRefIT_EERKS3_","__ZN2js4MoveINS_10WatchpointEEENS_7MoveRefIT_EERS3_","__ZN2js7MoveRefINS_10WatchpointEEC1ERS1_","__ZN2js7MoveRefINS_8WatchKeyEEC1ERS1_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS5_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE7setFreeEv","__ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEaSERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEENS_7MoveRefIT_EERS9_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC2ISA_EERT_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeENSC_3PtrE","__ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE12lookupForAddERKS1_","__ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E6AddPtrERKS1_RKS2_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10generationEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE9matchHashEj","__ZN2jsL6HashIdEi4071","__ZNK8JSObject9isWeakMapEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE12setCollisionEj","__ZN2js13DefaultHasherINS_8WatchKeyEE5matchERKS1_S4_","__ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S2_EE","__ZN2js8WatchKeyC2EP8JSObjecti","__ZN2js2gcL15GetGCObjectKindEjb4109","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS3_","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_jj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS3_","__ZN2js13DefaultHasherINS_8WatchKeyEE4hashERKS1_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS5_EE","__ZN15AutoEntryHolderD2Ev","__ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE10generationEv","__ZN15AutoEntryHolderC2ERN2js7HashMapINS0_8WatchKeyENS0_10WatchpointENS0_13DefaultHasherIS2_EENS0_17SystemAllocPolicyEEENS0_6detail9HashTableINS0_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E3PtrE","__ZN2js11WeakMapBase18markAllIterativelyEP8JSTracer","__ZN2js11WeakMapBase8sweepAllEP8JSTracer","__ZL16WeakMap_finalizeP9JSContextP8JSObject","__ZL12WeakMap_markP8JSTracerP8JSObject","__ZL11WeakMap_hasP9JSContextjPN2JS5ValueE","__ZL11WeakMap_getP9JSContextjPN2JS5ValueE","__ZL14WeakMap_deleteP9JSContextjPN2JS5ValueE","__ZL11WeakMap_setP9JSContextjPN2JS5ValueE","__Z19js_InitWeakMapClassP9JSContextP8JSObject","__ZL17WeakMap_constructP9JSContextjPN2JS5ValueE","__ZN2JSL14UndefinedValueEv4098","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE4108","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE4110","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE4111","__ZL13NonNullObjectP9JSContextPN2JS5ValueE","__ZL12GetObjectMapP8JSObject","__ZN9JSContext4new_IN2js7WeakMapIP8JSObjectN2JS5ValueENS1_13DefaultHasherIS4_EENS1_17DefaultMarkPolicyIS4_S6_EEEEPS_EEPT_T0_","__ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj","__ZN9JSContext7delete_IN2js7WeakMapIP8JSObjectN2JS5ValueENS1_13DefaultHasherIS4_EENS1_17DefaultMarkPolicyIS4_S6_EEEEEEvPT_","__ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3putERKS2_RKS4_","__ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE10getKeyHashEv","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEptEv","__ZNK2js7MoveRefINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEptEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10overloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isFreeEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE10isLiveHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE9matchHashEj","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE12hasCollisionEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE7setLiveEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE14unsetCollisionEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEC2ERS9_","__ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC2ERS6_","__ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE12setCollisionEj","__ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11underloadedEv","__ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEaSERKS5_","__ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEEC2EP8JSTracer","__ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isLiveEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEaSENS_7MoveRefIS8_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEENS_7MoveRefIT_EERSB_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEC1ERS9_","__ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEENS_7MoveRefIT_EERS8_","__ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC1ERS6_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC2Ev","__ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEC1Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj","__ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEED1Ev","__ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEED2Ev","__ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4initEj","__ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEEC1EP9JSContext","__ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEEC2EP9JSContext","__ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES7_","__ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEE15nonMarkingTraceEP8JSTracer","__ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEE15markIterativelyEP8JSTracer","__ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEE5sweepEP8JSTracer","__ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEEC1EP8JSTracer","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC1INS_7WeakMapIS4_S6_SA_NS_17DefaultMarkPolicyIS4_S6_EEEEEERT_","__ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE9keyMarkedES2_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4Enum11removeFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE7setFreeEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC2INS_7WeakMapIS4_S6_SA_NS_17DefaultMarkPolicyIS4_S6_EEEEEERT_","__ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_","__ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE15markEntryIfLiveES2_RKS4_","__ZN2js14JSProxyHandler6familyEv","__ZN9JSWrapperD2Ev","__ZN9JSWrapper5enterEP9JSContextP8JSObjectiNS_6ActionEPb","__ZN9JSWrapper5leaveEP9JSContextP8JSObject","__ZL4CondiPb","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC2ESB_","__ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE17markUnmarkedValueERKS4_","__ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE18overrideKeyMarkingES2_","__ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE11valueMarkedERKS4_","__ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE9markEntryERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC1ESB_","__ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_","__ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE","__ZN2JSL12BooleanValueEb4125","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE","__ZNK8JSObject9isWrapperEv","__ZNK8JSObject25isCrossCompartmentWrapperEv","__ZNK8JSObject17getWrapperHandlerEv","__ZN8JSObject6unwrapEPj","__ZN9JSWrapperD0Ev","__ZN9JSWrapper21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor","__ZN9JSWrapper13wrappedObjectEPK8JSObject","__ZN9JSWrapper24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor","__ZL24GetOwnPropertyDescriptorP9JSContextP8JSObjectijP20JSPropertyDescriptor","__ZN9JSWrapper14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor","__ZN9JSWrapper19getOwnPropertyNamesEP9JSContextP8JSObjectRN2js12AutoIdVectorE","__ZN9JSWrapper7delete_EP9JSContextP8JSObjectiPb","__ZL14ValueToBooleanPN2JS5ValueEPb","__ZN9JSWrapper9enumerateEP9JSContextP8JSObjectRN2js12AutoIdVectorE","__ZN9JSWrapper3fixEP9JSContextP8JSObjectPN2JS5ValueE","__ZN9JSWrapper3hasEP9JSContextP8JSObjectiPb","__ZN9JSWrapper6hasOwnEP9JSContextP8JSObjectiPb","__ZN9JSWrapper3getEP9JSContextP8JSObjectS3_iPN2JS5ValueE","__ZN9JSWrapper3setEP9JSContextP8JSObjectS3_ibPN2JS5ValueE","__ZN9JSWrapper4keysEP9JSContextP8JSObjectRN2js12AutoIdVectorE","__ZN9JSWrapper7iterateEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN9JSWrapper4callEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN9JSWrapper9constructEP9JSContextP8JSObjectjPN2JS5ValueES6_","__ZN9JSWrapper11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb","__ZN9JSWrapper6typeOfEP9JSContextP8JSObject","__ZN2JSL11ObjectValueER8JSObject4137","__ZN9JSWrapper12obj_toStringEP9JSContextP8JSObject","__ZN9JSWrapper12fun_toStringEP9JSContextP8JSObjectj","__ZN9JSWrapper12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE","__ZN2jsL11ToPrimitiveEP9JSContextPN2JS5ValueE4138","__ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE4139","__ZN9JSWrapper5traceEP8JSTracerP8JSObject","__ZN9JSWrapper14wrapperHandlerEPK8JSObject","__ZN9JSWrapper3NewEP9JSContextP8JSObjectS3_S3_PS_","_TransparentObjectWrapper","__ZN2js15AutoCompartmentC2EP9JSContextP8JSObject","__ZN7mozilla5MaybeIN2js15DummyFrameGuardEEC1Ev","__ZN7mozilla15AlignedStorage2IN2js15DummyFrameGuardEE4addrEv","__ZN7mozilla5MaybeIN2js15DummyFrameGuardEEC2Ev","__ZN2js15AutoCompartmentD2Ev","__ZN2js15AutoCompartment5leaveEv","__ZN7mozilla5MaybeIN2js15DummyFrameGuardEED1Ev","__ZN2js15AutoCompartment5enterEv","__ZN7mozilla5MaybeIN2js15DummyFrameGuardEE9constructEv","__ZN7mozilla5MaybeIN2js15DummyFrameGuardEE3refEv","__ZN7mozilla5MaybeIN2js15DummyFrameGuardEE7destroyEv","__ZN2js11ErrorCopierD2Ev","__ZN25JSCrossCompartmentWrapperD0Ev","__ZN25JSCrossCompartmentWrapper21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor","__ZN25JSCrossCompartmentWrapper24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor","__ZN25JSCrossCompartmentWrapper14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor","__ZN2js28AutoPropertyDescriptorRooterC1EP9JSContextP20JSPropertyDescriptor","__ZN25JSCrossCompartmentWrapper19getOwnPropertyNamesEP9JSContextP8JSObjectRN2js12AutoIdVectorE","__ZN25JSCrossCompartmentWrapper7delete_EP9JSContextP8JSObjectiPb","__ZN25JSCrossCompartmentWrapper9enumerateEP9JSContextP8JSObjectRN2js12AutoIdVectorE","__ZN25JSCrossCompartmentWrapper3hasEP9JSContextP8JSObjectiPb","__ZN25JSCrossCompartmentWrapper6hasOwnEP9JSContextP8JSObjectiPb","__ZN25JSCrossCompartmentWrapper3getEP9JSContextP8JSObjectS3_iPN2JS5ValueE","__ZN25JSCrossCompartmentWrapper3setEP9JSContextP8JSObjectS3_ibPN2JS5ValueE","__ZN25JSCrossCompartmentWrapper4keysEP9JSContextP8JSObjectRN2js12AutoIdVectorE","__ZN25JSCrossCompartmentWrapper7iterateEP9JSContextP8JSObjectjPN2JS5ValueE","__ZL8CanReifyPN2JS5ValueE","__ZL5ReifyP9JSContextP13JSCompartmentPN2JS5ValueE","__ZN25JSCrossCompartmentWrapper4callEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN25JSCrossCompartmentWrapper9constructEP9JSContextP8JSObjectjPN2JS5ValueES6_","__ZN25JSCrossCompartmentWrapper11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb","__ZN25JSCrossCompartmentWrapper12obj_toStringEP9JSContextP8JSObject","__ZN25JSCrossCompartmentWrapper12fun_toStringEP9JSContextP8JSObjectj","__ZN25JSCrossCompartmentWrapper12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE","__ZN25JSCrossCompartmentWrapper5traceEP8JSTracerP8JSObject","__ZN2js15DummyFrameGuardD1Ev","__ZN2js15DummyFrameGuardD2Ev","__ZN7mozilla5MaybeIN2js15DummyFrameGuardEE3asTEv","__ZN2js15DummyFrameGuardC1Ev","__ZN2js15DummyFrameGuardC2Ev","__ZN7mozilla5MaybeIN2js15DummyFrameGuardEED2Ev","__ZN17AutoCloseIteratorC1EP9JSContextP8JSObject","__ZN17AutoCloseIterator5clearEv","__ZN17AutoCloseIteratorC2EP9JSContextP8JSObject","_JS_XDRInitBase","_JS_XDRMemGetData","_JS_XDRMemSetData","__ZN2js14XDRScriptStateC2EP10JSXDRState","__ZNK2js14NativeIterator7numKeysEv","__ZN17AutoCloseIteratorD1Ev","__ZN17AutoCloseIteratorD2Ev","__ZN2js28AutoPropertyDescriptorRooterC2EP9JSContextP20JSPropertyDescriptor","_JS_XDRNewMem","_JS_XDRDestroy","_JS_XDRUint32","_JS_XDRBytes","_JS_XDRString","__ZL8XDRCharsP10JSXDRStatePtj","_JS_XDRDouble","__ZL14XDRDoubleValueP10JSXDRStatePd","_JS_XDRValue","__ZL9GetXDRTagN2JS5ValueE","__ZL12XDRValueBodyP10JSXDRStatejPN2JS5ValueE","_js_XDRAtom","__ZN2js14XDRScriptStateD2Ev","_JS_XDRRegisterClass","_JSVAL_TO_INT32_IMPL4206","_JSVAL_TO_BOOLEAN_IMPL4209","_JSVAL_TO_OBJECT_IMPL4211","_JSVAL_TO_STRING_IMPL4213","_JSVAL_IS_STRING_IMPL4216","_JSVAL_IS_DOUBLE_IMPL4217","_JSVAL_IS_INT32_IMPL4218","_JSVAL_IS_OBJECT_OR_NULL_IMPL4219","_JSVAL_IS_UNDEFINED_IMPL4220","_JSVAL_IS_NULL_IMPL4221","_JS_XDRFindClassById","__ZL13IMPL_TO_JSVAL12jsval_layout4204","_INT32_TO_JSVAL_IMPL4205","__ZL13JSVAL_TO_IMPLN2JS5ValueE4207","_BOOLEAN_TO_JSVAL_IMPL4208","_OBJECT_TO_JSVAL_IMPL4210","_STRING_TO_JSVAL_IMPL4212","__ZL8mem_tellP10JSXDRState","_JS_XDRFindClassIdByName","_JSVAL_TO_STRING4194","_STRING_TO_JSVAL4195","_JSVAL_TO_DOUBLE4196","_DOUBLE_TO_JSVAL4197","_JSVAL_TO_OBJECT4198","_OBJECT_TO_JSVAL4199","_JSVAL_TO_BOOLEAN4200","_BOOLEAN_TO_JSVAL4201","_JSVAL_TO_INT4202","_INT_TO_JSVAL4203","_JSVAL_IS_NULL","_JSVAL_IS_VOID","_JSVAL_IS_OBJECT","_JSVAL_IS_INT","_JSVAL_IS_DOUBLE4214","_JSVAL_IS_STRING4215","__ZL9mem_get32P10JSXDRStatePj","__ZL9mem_set32P10JSXDRStatePj","__ZL12mem_getbytesP10JSXDRStatePcj","__ZL12mem_setbytesP10JSXDRStatePcj","__ZL7mem_rawP10JSXDRStatej","__ZL8mem_seekP10JSXDRStatei11JSXDRWhence","__ZL12mem_finalizeP10JSXDRState","__ZL18namespace_equalityP9JSContextP8JSObjectPKN2JS5ValueEPi","__ZL18namespace_toStringP9JSContextjPN2JS5ValueE","__ZNK8JSObject7isQNameEv","_JSID_IS_OBJECT4314","_JSID_TO_OBJECT4315","__ZN16JSXMLArrayCursor10disconnectEv","__ZL14qname_equalityP9JSContextP8JSObjectPKN2JS5ValueEPi","__ZL14qname_toStringP9JSContextjPN2JS5ValueE","__Z26js_ConstructXMLQNameObjectP9JSContextRKN2JS5ValueES4_","__Z12js_IsXMLNameP9JSContextN2JS5ValueE","_JSVAL_IS_PRIMITIVE4303","_JSVAL_TO_OBJECT4304","__ZNK8JSObject17getQNameLocalNameEv","__ZL9IsXMLNamePKtj","__ZN16JSXMLArrayCursor5traceEP8JSTracer","__ZN10JSXMLArray11setCapacityEP9JSContextj","__ZN10JSXMLArray4trimEv","__ZN10JSXMLArray6finishEP9JSContext","__Z32js_GetLocalNameFromFunctionQNameP8JSObjectPiP9JSContext","__ZL29GetLocalNameFromFunctionQNameP8JSObjectPiP9JSContext","__Z11xml_convertP9JSContextP8JSObject6JSTypePN2JS5ValueE","__ZN2JS6AnchorIP8JSObjectEC1ES2_","__ZL19xml_toString_helperP9JSContextP5JSXML","__ZN2JSL11StringValueEP8JSString4311","__Z15js_GetXMLMethodP9JSContextP8JSObjectiPN2JS5ValueE","__ZL14GetXMLFunctionP9JSContextP8JSObjectiPN2JS5ValueE","__Z18js_TestXMLEqualityP9JSContextRKN2JS5ValueES4_Pi","__ZL6EqualsP9JSContextP5JSXMLN2JS5ValueEPi","_OBJECT_TO_JSVAL4318","__ZL15xml_hasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi","__ZL16HasSimpleContentP5JSXML","__ZN2JSL11ObjectValueER8JSObject4319","__ZL9XMLEqualsP9JSContextP5JSXMLS2_Pi","_JSVAL_IS_STRING4320","_JSVAL_IS_NUMBER","_JSVAL_TO_STRING4321","_STRING_TO_JSVAL4322","_JSVAL_IS_INT4323","_JSVAL_TO_INT4324","_JSVAL_TO_DOUBLE4325","__Z17js_ConcatenateXMLP9JSContextP8JSObjectS2_PN2JS5ValueE","__Z15js_NewXMLObjectP9JSContext10JSXMLClass","__ZL6AppendP9JSContextP5JSXMLS2_","__ZL12xml_finalizeP9JSContextP8JSObject","__ZL9xml_traceP8JSTracerP8JSObject","__ZL18xml_lookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty","__ZL17xml_lookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty","__ZL17xml_lookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty","__ZL18xml_definePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej","__ZL17xml_defineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej","__ZL17xml_defineSpecialP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ej","__ZL14xml_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE","__ZL15xml_getPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE","__ZL14xml_getElementP9JSContextP8JSObjectS2_jPN2JS5ValueE","__ZL14xml_getSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE","__ZL15xml_setPropertyP9JSContextP8JSObjectiPN2JS5ValueEi","__ZL14xml_setElementP9JSContextP8JSObjectjPN2JS5ValueEi","__ZL14xml_setSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZL17xml_getAttributesP9JSContextP8JSObjectiPj","__ZL24xml_getElementAttributesP9JSContextP8JSObjectjPj","__ZL24xml_getSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj","__ZL17xml_setAttributesP9JSContextP8JSObjectiPj","__ZL24xml_setElementAttributesP9JSContextP8JSObjectjPj","__ZL24xml_setSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj","__ZL10xml_typeOfP9JSContextP8JSObject","__ZL7xml_fixP9JSContextP8JSObjectPbPN2js12AutoIdVectorE","__ZL9xml_clearP9JSContextP8JSObject","__ZL18xml_deletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi","__ZL17xml_deleteElementP9JSContextP8JSObjectjPN2JS5ValueEi","__ZL17xml_deleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZL13xml_enumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__ZL16xml_addNamespaceP9JSContextjPN2JS5ValueE","__ZL15xml_appendChildP9JSContextjPN2JS5ValueE","__ZL13xml_attributeP9JSContextjPN2JS5ValueE","__ZL14xml_attributesP9JSContextjPN2JS5ValueE","__ZL9xml_childP9JSContextjPN2JS5ValueE","__ZL14xml_childIndexP9JSContextjPN2JS5ValueE","__ZL12xml_childrenP9JSContextjPN2JS5ValueE","__ZL12xml_commentsP9JSContextjPN2JS5ValueE","__ZL12xml_containsP9JSContextjPN2JS5ValueE","__ZL8xml_copyP9JSContextjPN2JS5ValueE","__ZL15xml_descendantsP9JSContextjPN2JS5ValueE","__ZL12xml_elementsP9JSContextjPN2JS5ValueE","__ZL18xml_hasOwnPropertyP9JSContextjPN2JS5ValueE","__ZL21xml_hasComplexContentP9JSContextjPN2JS5ValueE","__ZL20xml_hasSimpleContentP9JSContextjPN2JS5ValueE","__ZL21xml_inScopeNamespacesP9JSContextjPN2JS5ValueE","__ZL20xml_insertChildAfterP9JSContextjPN2JS5ValueE","__ZL21xml_insertChildBeforeP9JSContextjPN2JS5ValueE","__ZL10xml_lengthP9JSContextjPN2JS5ValueE","__ZL13xml_localNameP9JSContextjPN2JS5ValueE","__ZL8xml_nameP9JSContextjPN2JS5ValueE","__ZL13xml_namespaceP9JSContextjPN2JS5ValueE","__ZL25xml_namespaceDeclarationsP9JSContextjPN2JS5ValueE","__ZL12xml_nodeKindP9JSContextjPN2JS5ValueE","__ZL13xml_normalizeP9JSContextjPN2JS5ValueE","__ZL10xml_parentP9JSContextjPN2JS5ValueE","__ZL26xml_processingInstructionsP9JSContextjPN2JS5ValueE","__ZL16xml_prependChildP9JSContextjPN2JS5ValueE","__ZL24xml_propertyIsEnumerableP9JSContextjPN2JS5ValueE","__ZL19xml_removeNamespaceP9JSContextjPN2JS5ValueE","__ZL11xml_replaceP9JSContextjPN2JS5ValueE","__ZL15xml_setChildrenP9JSContextjPN2JS5ValueE","__ZL16xml_setLocalNameP9JSContextjPN2JS5ValueE","__ZL11xml_setNameP9JSContextjPN2JS5ValueE","__ZN10JSXMLArray4initEv","__ZL16xml_setNamespaceP9JSContextjPN2JS5ValueE","__ZL8xml_textP9JSContextjPN2JS5ValueE","__ZL12xml_toSourceP9JSContextjPN2JS5ValueE","__ZL12xml_toStringP9JSContextjPN2JS5ValueE","__ZL15xml_toXMLStringP9JSContextjPN2JS5ValueE","__ZL11xml_valueOfP9JSContextjPN2JS5ValueE","__ZL12xml_settingsP9JSContextjPN2JS5ValueE","__ZL15xml_setSettingsP9JSContextjPN2JS5ValueE","__ZL19xml_defaultSettingsP9JSContextjPN2JS5ValueE","__Z9js_NewXMLP9JSContext10JSXMLClass","_js_TraceXML","__ZL16xml_trace_vectorP8JSTracerPP5JSXMLj","__ZL19XMLArrayCursorTraceP8JSTracerP16JSXMLArrayCursor","__ZN2js13AutoXMLRooterC1EP9JSContextP5JSXML","__Z15js_GetXMLObjectP9JSContextP5JSXML","__ZN2js13AutoXMLRooterD1Ev","__ZL12NewXMLObjectP9JSContextP5JSXML","__Z21js_InitNamespaceClassP9JSContextP8JSObject","__ZN8JSObject13setNamePrefixEP14JSLinearString","__ZN8JSObject10setNameURIEP14JSLinearString","__ZL9NamespaceP9JSContextjPN2JS5ValueE","__Z17js_InitQNameClassP9JSContextP8JSObject","__ZL12InitXMLQNameP9JSContextP8JSObjectP14JSLinearStringS4_P6JSAtom","__ZL5QNameP9JSContextjPN2JS5ValueE","__Z15js_InitXMLClassP9JSContextP8JSObject","__ZL3XMLP9JSContextjPN2JS5ValueE","_OBJECT_TO_JSID4356","__ZL21SetDefaultXMLSettingsP9JSContextP8JSObject","__ZL7XMLListP9JSContextjPN2JS5ValueE","__ZL12ATOM_TO_JSIDP6JSAtom4336","__ZL13xml_isXMLNameP9JSContextjPN2JS5ValueE","__Z17js_InitXMLClassesP9JSContextP8JSObject","__ZN2js12GlobalObject20getFunctionNamespaceEP9JSContextPN2JS5ValueE","__ZL15NewXMLNamespaceP9JSContextP14JSLinearStringS2_i","__Z25js_GetDefaultXMLNamespaceP9JSContextPN2JS5ValueE","__ZN8JSObject10getSpecialEP9JSContextN2js9SpecialIdEPN2JS5ValueE","__ZN2js9SpecialId19defaultXMLNamespaceEv","__Z25js_SetDefaultXMLNamespaceP9JSContextRKN2JS5ValueE","__Z18js_ToAttributeNameP9JSContextPN2JS5ValueE","__ZL15ToAttributeNameP9JSContextN2JS5ValueE","__Z23js_EscapeAttributeValueP9JSContextP8JSStringi","__ZL20EscapeAttributeValueP9JSContextRN2js12StringBufferEP8JSStringi","__Z19js_AddAttributePartP9JSContextiP8JSStringS2_","__Z21js_EscapeElementValueP9JSContextP8JSString","__ZL18EscapeElementValueP9JSContextRN2js12StringBufferEP8JSStringj","__Z19js_ValueToXMLStringP9JSContextRKN2JS5ValueE","__ZL11ToXMLStringP9JSContextN2JS5ValueEj","__Z13js_GetAnyNameP9JSContextPi","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_4355","_JSID_IS_VOID4359","__ZN16JSXMLArrayCursor7getNextEv","__Z18js_FindXMLPropertyP9JSContextRKN2JS5ValueEPP8JSObjectPi","__ZL16HasNamedPropertyP5JSXMLP8JSObject","__ZL19HasFunctionPropertyP9JSContextP8JSObjectiPi","__ZL20ConvertQNameToStringP9JSContextP8JSObject","__Z20js_GetXMLDescendantsP9JSContextP8JSObjectN2JS5ValueEPS4_","__ZL10GetPrivateP9JSContextP8JSObjectPKc","__ZL11DescendantsP9JSContextP5JSXMLN2JS5ValueE","__Z24js_DeleteXMLListElementsP9JSContextP8JSObject","__ZL17DeleteListElementP9JSContextP5JSXMLj","__ZL18xmlfilter_finalizeP9JSContextP8JSObject","__ZL15xmlfilter_traceP8JSTracerP8JSObject","__Z20js_StepXMLListFilterP9JSContexti","__ZN2jsL22GetGlobalForScopeChainEP9JSContext4366","__ZN9JSContext4new_I11JSXMLFilterP5JSXMLP10JSXMLArrayEEPT_T0_T1_","__Z19js_ValueToXMLObjectP9JSContextRKN2JS5ValueE","__ZNK8JSString5emptyEv","__ZN16JSXMLArrayCursorC2EP10JSXMLArray","__ZN2JS6AnchorIP8JSObjectEC2ES2_","__ZN2js2gcL15GetGCObjectKindEjb4379","__ZL5ToXMLP9JSContextN2JS5ValueE","__Z23js_ValueToXMLListObjectP9JSContextRKN2JS5ValueE","__ZL9ToXMLListP9JSContextN2JS5ValueE","__Z22js_NewXMLSpecialObjectP9JSContext10JSXMLClassP8JSStringS3_","__ZL18GetXMLSettingFlagsP9JSContextPj","__ZL11NewXMLQNameP9JSContextP14JSLinearStringS2_P6JSAtom","__Z21js_MakeXMLCDATAStringP9JSContextP8JSString","__ZL18MakeXMLCDATAStringP9JSContextRN2js12StringBufferEP8JSString","__Z23js_MakeXMLCommentStringP9JSContextP8JSString","__ZL20MakeXMLCommentStringP9JSContextRN2js12StringBufferEP8JSString","__Z18js_MakeXMLPIStringP9JSContextP8JSStringS2_","__ZL15MakeXMLPIStringP9JSContextRN2js12StringBufferEP8JSStringS5_","__ZN11JSXMLFilterC1EP5JSXMLP10JSXMLArray","__ZN11JSXMLFilterC2EP5JSXMLP10JSXMLArray","__ZN16JSXMLArrayCursorC1EP10JSXMLArray","__ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE4380","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE4383","__ZL20MakeXMLSpecialStringP9JSContextRN2js12StringBufferEP8JSStringS5_PKtjS7_j","__ZL26NewBuiltinClassInstanceXMLP9JSContextPN2js5ClassE","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE4392","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE4393","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE4394","__ZL20GetBooleanXMLSettingP9JSContextPKcPi","__ZL13GetXMLSettingP9JSContextPKcPN2JS5ValueE","_JSVAL_IS_NULL4395","_JSVAL_IS_VOID4396","__ZL14ParseXMLSourceP9JSContextP8JSString","__ZL14OrphanXMLChildP9JSContextP5JSXMLj","__ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv","__ZN8JSObject20setNamespaceDeclaredEN2JS5ValueE","__ZNK8JSObject10getNameURIEv","__ZN2js18AutoNamespaceArrayC1EP9JSContext","__ZL12IS_XML_CHARSPKt","__ZL16HAS_NS_AFTER_XMLPKt","__ZL14ParseNodeToXMLPN2js6ParserEP11JSParseNodeP10JSXMLArrayj","__ZN2js18AutoNamespaceArrayD1Ev","__ZN2js18AutoNamespaceArrayD2Ev","__ZL18ChompXMLWhitespaceP9JSContextP8JSString","__ZL16XMLArrayTruncateP9JSContextP10JSXMLArrayj","__ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E","__ZL18namespace_identityPKvS0_","_JSVAL_TO_STRING_IMPL4397","_JSVAL_IS_UNDEFINED_IMPL4398","_JSVAL_IS_NULL_IMPL4400","_JSID_IS_INT4401","_JSID_TO_INT4402","_JSID_IS_STRING4403","_JSID_TO_STRING4405","_JS_ASSERT_STRING_IS_FLAT","__ZL13JSVAL_TO_IMPLN2JS5ValueE4399","__ZL14XMLArrayDeleteP9JSContextP10JSXMLArrayji","__ZN2js16AutoObjectRooter9setObjectEP8JSObject","__ZL16ParseNodeToQNamePN2js6ParserEP11JSParseNodeP10JSXMLArrayi","__ZNK8JSObject13getNamePrefixEv","__ZN2js18AutoNamespaceArrayC2EP9JSContext","__ZN9JSContext7delete_I11JSXMLFilterEEvPT_","__ZN11JSXMLFilterD1Ev","__ZN11JSXMLFilterD2Ev","__ZN16JSXMLArrayCursorD1Ev","__ZN16JSXMLArrayCursorD2Ev","__ZL19DeleteNamedPropertyP9JSContextP5JSXMLP8JSObjecti","__ZL13DeleteByIndexP9JSContextP5JSXMLj","__ZL13MatchAttrNameP8JSObjectP5JSXML","__ZL13MatchElemNameP8JSObjectP5JSXML","__ZL9ToXMLNameP9JSContextN2JS5ValueEPi","__ZL17DescendantsHelperP9JSContextP5JSXMLP8JSObjectS2_","__ZL16ReportBadXMLNameP9JSContextRKN2JS5ValueE","__ZN2JSL14UndefinedValueEv4406","_JSVAL_IS_BOOLEAN4407","__ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE4408","__ZNK2js18AutoNamespaceArray6lengthEv","__ZL14XMLToXMLStringP9JSContextP5JSXMLPK10JSXMLArrayj","__ZL10IsDeclaredPK8JSObject","__ZL12GetNamespaceP9JSContextP8JSObjectPK10JSXMLArray","__ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE4414","__ZL14JSID_FROM_BITSj4418","_JSVAL_IS_PRIMITIVE_IMPL4409","_JSVAL_IS_BOOLEAN_IMPL4410","_JSVAL_IS_STRING_IMPL4412","_MAGIC_JSVAL_TO_OBJECT_OR_NULL_IMPL","_STRING_TO_JSVAL_IMPL4413","__ZN2js9SpecialIdC2Ej","__ZL13IMPL_TO_JSVAL12jsval_layout4416","_BOOLEAN_TO_JSVAL_IMPL4417","_INT32_TO_JSVAL_IMPL4422","__ZL14GeneratePrefixP9JSContextP14JSLinearStringP10JSXMLArray","__ZL15namespace_matchPKvS0_","__ZL20AppendAttributeValueP9JSContextRN2js12StringBufferEP8JSString","__ZL19GetUint32XMLSettingP9JSContextPKcPj","__ZNK8JSObject20getNamespaceDeclaredEv","__ZL19NewXMLAttributeNameP9JSContextP14JSLinearStringS2_P6JSAtom","__ZN2js9SpecialIdC1Ej","_BOOLEAN_TO_JSVAL4415","__ZN2jsL14IsConstructingEPKN2JS5ValueE4419","_INT_TO_JSVAL4421","__ZL8DeepCopyP9JSContextP5JSXMLP8JSObjectj","__ZL13DeepCopyInLRSP9JSContextP5JSXMLj","__ZL16DeepCopySetInLRSP9JSContextP10JSXMLArrayS2_P5JSXMLj","__ZN2jsL42IsConstructing_PossiblyWithGivenThisObjectEPKN2JS5ValueEPP8JSObject","__ZL11QNameHelperP9JSContextP8JSObjectiPN2JS5ValueES5_","__ZNK8JSObject20getQNameLocalNameValEv","__ZNK2JS5Value27getMagicObjectOrNullPayloadEv","__ZN2jsL16GetClassProtoKeyEPNS_5ClassE4430","__ZN8JSObject17setQNameLocalNameEP6JSAtom","__ZL19QNameNameURI_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL21QNameLocalName_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZNK8JSObject13getNameURIValEv","__ZL17NamePrefix_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL14NameURI_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZNK8JSObject16getNamePrefixValEv","__ZL15NamespaceHelperP9JSContextP8JSObjectiPN2JS5ValueES5_","__ZN8JSObject15clearNamePrefixEv","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_4427","__ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE4428","__ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_4429","__ZN2js13AutoXMLRooterD2Ev","__ZN2js13AutoXMLRooterC2EP9JSContextP5JSXML","__ZL15CopyXMLSettingsP9JSContextP8JSObjectS2_","__ZL15xml_text_helperP9JSContextP8JSObjectP5JSXMLPN2JS5ValueE","__ZL15xml_list_helperP9JSContextP5JSXMLPN2JS5ValueE","__ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject","__ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject","__ZL19AddInScopeNamespaceP9JSContextP5JSXMLP8JSObject","__ZL11PutPropertyP9JSContextP8JSObjectiiPN2JS5ValueE","__ZN16JSXMLArrayCursor10getCurrentEv","__ZN2jsL9IdToJsvalEi4431","__ZN2jsL9IdToValueEi4432","__ZL12ResolveValueP9JSContextP5JSXMLPS2_","__ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE","__ZL6InsertP9JSContextP5JSXMLjN2JS5ValueE","__ZL7ReplaceP9JSContextP5JSXMLjN2JS5ValueE","__ZL14XMLArrayInsertP9JSContextP10JSXMLArrayjj","__ZL11KidToStringP9JSContextP5JSXMLj","__ZL10CheckCycleP9JSContextP5JSXMLS2_","__ZL16GetNamedPropertyP9JSContextP5JSXMLP8JSObjectS2_","__ZL21SyncInScopeNamespacesP9JSContextP5JSXML","__ZN2JSL10Int32ValueEi4433","_INT_TO_JSID4434","__ZL18HasIndexedPropertyP5JSXMLj","__ZL12IdValIsIndexP9JSContextN2JS5ValueEPjPb","__ZL26xml_removeNamespace_helperP9JSContextP5JSXMLP8JSObject","__ZL20namespace_full_matchPKvS0_","__ZL33xml_processingInstructions_helperP9JSContextP8JSObjectP5JSXMLS2_PN2JS5ValueE","__ZL20xml_normalize_helperP9JSContextP8JSObjectP5JSXML","__ZL17NormalizingDeleteP9JSContextP5JSXMLj","__ZL19NamespacesToJSArrayP9JSContextP10JSXMLArrayPN2JS5ValueE","__ZL21FindInScopeNamespacesP9JSContextP5JSXMLP10JSXMLArray","_DOUBLE_TO_JSVAL4435","__ZL11HasPropertyP9JSContextP8JSObjectN2JS5ValueEPi","__ZL19xml_elements_helperP9JSContextP8JSObjectP5JSXMLS2_PN2JS5ValueE","_JSVAL_TO_INT32_IMPL4444","_INT_FITS_IN_JSID4436","_JSVAL_IS_SPECIFIC_INT32_IMPL","_JSID_IS_DEFAULT_XML_NAMESPACE4441","_JSVAL_IS_INT32_IMPL4445","_JSVAL_IS_NUMBER_IMPL4446","_JSVAL_TO_OBJECT_IMPL4449","__ZNK8JSObject11isNamespaceEv","_OBJECT_TO_JSVAL_IMPL4443","__ZL19xml_comments_helperP9JSContextP8JSObjectP5JSXMLPN2JS5ValueE","__ZL16xml_child_helperP9JSContextP8JSObjectP5JSXMLN2JS5ValueEPS6_","__ZL9ValueToIdP9JSContextN2JS5ValueEPN2js12AutoIdRooterE","__ZN9JSContext4new_I16JSXMLArrayCursorP10JSXMLArrayEEPT_T0_","__ZNK2JS5Value7isInt32Ei","__ZN9JSContext7delete_I16JSXMLArrayCursorEEvPT_","__ZN2JSL11DoubleValueEd4439","__ZL14xml_setGenericP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN2jsL16IsFunctionObjectERKN2JS5ValueE4442","__ZL13attr_identityPKvS0_","__ZL14qname_identityP8JSObjectS0_","__Z15jsRegExpCompilePKti24JSRegExpIgnoreCaseOption23JSRegExpMultilineOptionPjPi","__ZN11CompileDataC1Ev","__ZL11returnError9ErrorCodePi","__ZL30calculateCompiledPatternLengthPKti24JSRegExpIgnoreCaseOptionR11CompileDataR9ErrorCode","__ZN2js11OffTheBooks9array_newIcEEPT_j","__ZL13compileBranchiPiPPhPPKtS3_P9ErrorCodeS_S_R11CompileData","__ZL13get2ByteValuePKh","__ZL13get3ByteValuePKh","__ZL13put2ByteValuePhi","__ZL8flipCaseh","__ZL22firstSignificantOpcodePKh","__ZL13put3ByteValuePhi","__ZL18classBitmapForCharh","__ZL10encodeUTF8iPh","__ZL14compileBracketiPiPPhPPKtS3_P9ErrorCodeiS_S_R11CompileData","__ZN2js10Foreground12array_deleteIcEEvPT_","__ZL17bracketIsAnchoredPKh","__ZL16branchIsAnchoredPKh","__ZL33bracketFindFirstAssertedCharacterPKhb","__ZL32branchFindFirstAssertedCharacterPKhb","__ZL21bracketNeedsLineStartPKhjj","__ZL20branchNeedsLineStartPKhjj","__Z12jsRegExpFreeP8JSRegExp","_js_free4455","_js_malloc4456","__ZL12getLinkValuePKh","__ZL21getLinkValueAllowZeroPKh","__ZL40firstSignificantOpcodeSkippingAssertionsPKh","__ZL21advanceToEndOfBracketRPKh","__ZL21putLinkValueAllowZeroPhi","__ZL12putLinkValuePhi","__ZL15isCountedRepeatPKtS0_","__ZL11checkEscapePPKtS0_P9ErrorCodeib","__ZL17getOthercaseRangePiiS_S_","__ZN3WTF12isASCIIDigitEt","__ZN3WTF15isASCIIHexDigitEt","__ZN3WTF12isASCIIAlphaEi","__ZN3WTF19isASCIIAlphanumericEi","__ZN3WTF12toASCIIUpperEi","__ZL25multiplyWithOverflowCheckii","__ZL19safelyCheckNextCharPKtS0_t","__ZN11CompileDataC2Ev","__ZL11toLowerCaseh","__ZL8flipCaseh4460","__ZL27tryRequiredByteOptimizationRPKtS0_iibbS1_","__ZL16readRepeatCountsPKtPiS1_P9ErrorCode","__ZL23put2ByteValueAndAdvanceRPhi","__ZL31putLinkValueAllowZeroAndAdvanceRPhi","__ZL22putLinkValueAndAdvanceRPhi","__Z15jsRegExpExecuteP9JSContextPK8JSRegExpPKtiiPii","__ZL24tryFirstByteOptimizationRPKtS0_ibbS0_","__ZL5matchP11JSArenaPoolPKtPKhiR9MatchData","__ZL9isNewlinet","__ZL13get2ByteValuePKh4462","__ZN3WTF12isASCIIDigitEi","__ZL13get3ByteValuePKh4465","__ZN10MatchStack29canUseStackBufferForNextFrameEv","__ZN10MatchFrame13startNewGroupEb","__ZN10LinearFlag12readAndClearEv","__ZN9MatchData13setOffsetPairEjii","__ZN10LinearFlag3setEv","__ZN10MatchFrame14restoreOffsetsEiiPii","__ZN10MatchFrame14clobberOffsetsEiiPii","__ZL38repeatInformationFromInstructionOffsetsRbRiS0_","__ZL29getUTF8CharAndIncrementLengthRiPKhS_","__ZL15charTypeForCharh","__ZN10MatchFrame4initEP11JSArenaPool","__ZN10MatchFrameC2Ev","__ZN10LinearFlagC2Ev","__Z22jsc_pcre_ucp_othercasej","__ZL28getUTF8CharAndAdvancePointerRiRPKh","__ZN10MatchStackC1EP11JSArenaPool","__ZN10LinearFlagC1Ev","__ZL10matchErroriR10MatchStack","__ZN10MatchFrame15extractBracketsEPKh","__ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei","__ZN10MatchStack15popCurrentFrameEv","__ZL12getLinkValuePKh4461","__ZL21advanceToEndOfBracketRPKh4463","__ZN10MatchFrame11saveOffsetsEiiPii","__ZL10isWordChart","__ZL11isSpaceChart","__ZL8matchRefiPKtiRK9MatchData","__ZN10MatchStackD1Ev","__ZN10MatchStackD2Ev","__ZL21getLinkValueAllowZeroPKh4464","__ZN2js10Foreground7delete_I10MatchFrameEEvPT_","_js_free4466","__ZN10MatchStack17allocateNextFrameEv","__ZN2js11OffTheBooks4new_I10MatchFrameEEPT_v","_js_malloc4467","__ZN10MatchFrameC1Ev","__ZN10MatchStack12popAllFramesEv","__ZN10MatchStackC2EP11JSArenaPool","__Z15jsc_pcre_xclassiPKh","__ZN2v88internal7ceilingEd","__ZN2JS15PerfMeasurementC2ENS0_9EventMaskE","__ZN2JS15PerfMeasurement5resetEv","_PRMJ_LocalGMTDifference","__ZL16ComputeLocalTimelP2tm","_PRMJ_Now","__ZNK2v88internal6VectorIcE5startEv","__ZL18my_GetErrorMessagePvPKcj","_PRMJ_FormatTime","__ZN14DSTOffsetCache28computeDSTOffsetMillisecondsEx","__ZN14DSTOffsetCache24getDSTOffsetMillisecondsExP9JSContext","__ZN2v88internal13StringBuilder9AddStringEPKc","__ZN2v88internal13StringBuilder12AddSubstringEPKci","__ZN2v88internal9StrLengthEPKc","__ZN2v88internal13StringBuilder10AddIntegerEi","__ZN2v88internal13StringBuilder10AddPaddingEci","__ZN2v88internal13StringBuilder8FinalizeEv","__ZN2v88internal13DoubleToAsciiEdNS0_8DtoaModeEiNS0_6VectorIcEEPiS4_S4_","__ZNK2v88internal6Double4SignEv","__Z9DumpStackP9JSContextjPN2JS5ValueE","__ZN2JSL11StringValueEP8JSString587","__ZN2JSL11ObjectValueER8JSObject588","__ZL17sandbox_enumerateP9JSContextP8JSObject","__ZL15sandbox_resolveP9JSContextP8JSObjectijPS2_","__ZL18resolver_enumerateP9JSContextP8JSObject","__ZL16resolver_resolveP9JSContextP8JSObjectijPS2_","__Z4WrapP9JSContextjPN2JS5ValueE","_JSVAL_IS_PRIMITIVE589","_JSVAL_TO_OBJECT590","_OBJECT_TO_JSVAL591","__Z9SerializeP9JSContextjPN2JS5ValueE","__Z11DeserializeP9JSContextjPN2JS5ValueE","__Z11StringStatsP9JSContextjPN2JS5ValueE","_INT_TO_JSVAL592","__Z9NewGlobalP9JSContextjPN2JS5ValueE","_JSVAL_IS_STRING593","_JSVAL_TO_STRING594","__ZL15NewGlobalObjectP9JSContext15CompartmentKind","__ZL7VersionP9JSContextjPN2JS5ValueE","__ZL13RevertVersionP9JSContextjPN2JS5ValueE","__ZL7OptionsP9JSContextjPN2JS5ValueE","__ZL4LoadP9JSContextjPN2JS5ValueE","__ZL8EvaluateP9JSContextjPN2JS5ValueE","__ZL3RunP9JSContextjPN2JS5ValueE","__ZL8ReadLineP9JSContextjPN2JS5ValueE","__ZL5PrintP9JSContextjPN2JS5ValueE","__ZL6PutStrP9JSContextjPN2JS5ValueE","__ZL3NowP9JSContextjPN2JS5ValueE","__ZL4HelpP9JSContextjPN2JS5ValueE","__ZL4QuitP9JSContextjPN2JS5ValueE","__ZL9AssertJitP9JSContextjPN2JS5ValueE","__ZL8AssertEqP9JSContextjPN2JS5ValueE","__ZL2GCP9JSContextjPN2JS5ValueE","__ZL11GCParameterP9JSContextjPN2JS5ValueE","__ZL9CountHeapP9JSContextjPN2JS5ValueE","__ZL20MakeFinalizeObserverP9JSContextjPN2JS5ValueE","__ZL13FinalizeCountP9JSContextjPN2JS5ValueE","__ZL13InternalConstP9JSContextjPN2JS5ValueE","__ZL8SetDebugP9JSContextjPN2JS5ValueE","__ZL18SetDebuggerHandlerP9JSContextjPN2JS5ValueE","__ZL12SetThrowHookP9JSContextjPN2JS5ValueE","__ZL4TrapP9JSContextjPN2JS5ValueE","__ZL6UntrapP9JSContextjPN2JS5ValueE","__ZL8LineToPCP9JSContextjPN2JS5ValueE","__ZL8PCToLineP9JSContextjPN2JS5ValueE","__ZL14StringsAreUTF8P9JSContextjPN2JS5ValueE","__ZL8TestUTF8P9JSContextjPN2JS5ValueE","__ZL10ThrowErrorP9JSContextjPN2JS5ValueE","__ZL9BuildDateP9JSContextjPN2JS5ValueE","__ZL5ClearP9JSContextjPN2JS5ValueE","__ZL6InternP9JSContextjPN2JS5ValueE","__ZL5CloneP9JSContextjPN2JS5ValueE","__ZL6GetPDAP9JSContextjPN2JS5ValueE","__ZL6GetSLXP9JSContextjPN2JS5ValueE","__ZL7ToInt32P9JSContextjPN2JS5ValueE","__ZL13EvalInContextP9JSContextjPN2JS5ValueE","__ZL11EvalInFrameP9JSContextjPN2JS5ValueE","__ZL7ShapeOfP9JSContextjPN2JS5ValueE","__ZL8ResolverP9JSContextjPN2JS5ValueE","__ZL5SnarfP9JSContextjPN2JS5ValueE","__ZL7CompileP9JSContextjPN2JS5ValueE","__ZL5ParseP9JSContextjPN2JS5ValueE","__ZL7TimeoutP9JSContextjPN2JS5ValueE","__ZL7ElapsedP9JSContextjPN2JS5ValueE","__Z22ShellPrincipalsSubsumeP12JSPrincipalsS0_","__Z17CheckObjectAccessP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueE","__ZL6ParentP9JSContextjPN2JS5ValueE","__ZL15ParseLegacyJSONP9JSContextjPN2JS5ValueE","__ZL27EnableStackWalkingAssertionP9JSContextjPN2JS5ValueE","__ZL10GetMaxArgsP9JSContextjPN2JS5ValueE","__ZL10its_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL10its_setterP9JSContextP8JSObjectiiPN2JS5ValueE","__ZL15its_addPropertyP9JSContextP8JSObjectiPN2JS5ValueE","__ZL15its_delPropertyP9JSContextP8JSObjectiPN2JS5ValueE","__ZL15its_getPropertyP9JSContextP8JSObjectiPN2JS5ValueE","__ZL15its_setPropertyP9JSContextP8JSObjectiiPN2JS5ValueE","__ZL13its_enumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__ZL11its_resolveP9JSContextP8JSObjectijPS2_","__ZL11its_convertP9JSContextP8JSObject6JSTypePN2JS5ValueE","__ZL12its_finalizeP9JSContextP8JSObject","__ZL16global_enumerateP9JSContextP8JSObject","__ZL14global_resolveP9JSContextP8JSObjectijPS2_","__ZL15env_setPropertyP9JSContextP8JSObjectiiPN2JS5ValueE","__ZL13env_enumerateP9JSContextP8JSObject","__ZL11env_resolveP9JSContextP8JSObjectijPS2_","__Z5ShellP9JSContextPN2js3cli12OptionParserEPPc","__ZN13JSAutoRequestC1EP9JSContext","__ZN22JSAutoEnterCompartmentC1Ev","__ZL11ProcessArgsP9JSContextP8JSObjectPN2js3cli12OptionParserE","__ZN22JSAutoEnterCompartmentD1Ev","__ZL12InitWatchdogP9JSRuntime","__ZN2js3cli6detail10BoolOptionD1Ev","__ZNK2js3cli6detail6Option8isValuedEv","__ZNK2js3cli6detail6Option10isVariadicEv","__ZNK2js3cli16MultiStringRange5argnoEv","__ZNK2js3cli16MultiStringRange5frontEv","__ZNK2js3cli16MultiStringRange5emptyEv","__ZN2js3cli12OptionParser14setDescriptionEPKc","__ZN2js3cli12OptionParser19setDescriptionWidthEj","__ZN2js3cli12OptionParser12setHelpWidthEj","__ZN2js3cli12OptionParser10setVersionEPKc","__ZN2js3cli6detail6OptionC2ENS1_10OptionKindEcPKcS5_","_main","__ZL27MaybeOverrideOutFileFromEnvPKcP7__sFILEPS2_","__ZN2js3cli12OptionParserC1EPKc","__ZL10NewContextP9JSRuntime","__ZL14DestroyContextP9JSContextb","__ZL12KillWatchdogv","__ZL16ScheduleWatchdogP9JSRuntimed","__ZL12AlarmHandleri","__ZL15CancelExecutionP9JSRuntime","__ZL14GetContextDataP9JSContext","__ZL14NewContextDatav","__ZL16my_ErrorReporterP9JSContextPKcP13JSErrorReport","__ZL17SetContextOptionsP9JSContext","__ZL22ShellOperationCallbackP9JSContext","__ZN2js3cli12OptionParserC2EPKc","__ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEEC1ES5_","__ZN2js3cli6detail10BoolOptionC1EcPKcS4_","__ZN2js3cli6detail10BoolOptionC2EcPKcS4_","__ZN2js3cli6detail10BoolOptionD0Ev","__ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEEC2ES5_","__ZN22JSAutoEnterCompartmentD2Ev","__ZL14BindScriptArgsP9JSContextP8JSObjectPN2js3cli12OptionParserE","__ZL7ProcessP9JSContextP8JSObjectPKcb","_JSVAL_TO_BOOLEAN_IMPL626","_JSVAL_TO_INT32_IMPL627","_JSVAL_IS_UNDEFINED_IMPL597","__ZN8ToString5threwEv","_JSID_IS_STRING604","_JSID_TO_STRING605","_JSID_IS_INT606","_JSID_TO_INT608","_JSID_IS_OBJECT609","_JSID_TO_OBJECT610","_JSID_IS_VOID615","_JSVAL_IS_BOOLEAN_IMPL618","_JSVAL_IS_OBJECT_OR_NULL_IMPL621","_JSVAL_IS_INT32_IMPL628","__ZN2jsL8JsvalifyEPNS_10StackFrameE625","__ZN2jsL8JsvalifyEPNS_5ClassE631","__ZN2js3cli16MultiStringRange8popFrontEv","__ZL13JSVAL_TO_IMPLN2JS5ValueE598","__ZN20JSAutoSuspendRequest6resumeEv","__ZN20JSAutoSuspendRequestC2EP9JSContext","__ZL13IMPL_TO_JSVAL12jsval_layout600","_STRING_TO_JSVAL_IMPL601","__ZN22JSAutoEnterCompartmentC2Ev","__ZN13JSAutoRequestC2EP9JSContext","_INT32_TO_JSVAL_IMPL613","__ZN12FreeOnReturn4initEPKc","__ZN12FreeOnReturnC2EP9JSContextPKc","__ZN2js15AutoValueRooter10jsval_addrEv","__ZL11SkipUTF8BOMP7__sFILE","__ZN20JSAutoSuspendRequestC1EP9JSContext","__ZL7GetLineP7__sFILEPKc","__ZN20JSAutoSuspendRequestD1Ev","_JSVAL_IS_VOID595","__ZN20JSAutoSuspendRequestD2Ev","_STRING_TO_JSVAL599","__ZN13IdStringifierC1EP9JSContextii","__ZN8ToString8getBytesEv","__ZN13IdStringifierD1Ev","__ZN13IdStringifierD2Ev","__ZN8ToStringD2Ev","__ZN13IdStringifierC2EP9JSContextii","__ZN8ToStringC2EP9JSContextN2JS5ValueEi","__ZN2jsL9IdToJsvalEi602","__ZN2jsL9IdToValueEi603","__ZN2JSL10Int32ValueEi607","__ZN2JSL14UndefinedValueEv611","__ZL15ReportExceptionP9JSContext","__ZN8ToStringC1EP9JSContextN2JS5ValueEi","__ZN8ToString8getJSValEv","__ZN8ToStringD1Ev","__ZL12JSID_IS_ATOMi616","_JSVAL_IS_BOOLEAN617","__ZN2JSL9NullValueEv619","__ZL15SetTimeoutValueP9JSContextd","__ZN12FreeOnReturnC1EP9JSContextPKc","__ZL20MakeAbsolutePathnameP9JSContextPKcS2_","__ZL16FileAsTypedArrayP9JSContextPKc","__ZL12FileAsStringP9JSContextPKc","__ZN12FreeOnReturnD1Ev","__ZN12FreeOnReturnD2Ev","_JSVAL_IS_OBJECT620","_JSVAL_IS_INT622","_JSVAL_TO_INT623","_JSVAL_TO_BOOLEAN624","__ZL10NewSandboxP9JSContextb","__ZN2JSL12BooleanValueEb629","__ZL13ValueToScriptP9JSContextN2JS5ValueEPP10JSFunction","__ZNK2js11AutoIdArray6lengthEv","__ZL25finalize_counter_finalizeP9JSContextP8JSObject","_JSVAL_IS_NULL_IMPL636","_JSVAL_IS_STRING_IMPL638","_JSVAL_TO_GCTHING_IMPL640","_JSVAL_IS_TRACEABLE_IMPL641","_JSVAL_TO_OBJECT_IMPL642","_JSVAL_IS_DOUBLE_IMPL647","_JSVAL_TO_STRING_IMPL648","_JSVAL_IS_PRIMITIVE_IMPL650","__ZN2js11AutoIdArrayntEv","__ZN2js3cli6detail6Option8asValuedEv","__ZN2js3cli6detail6Option12asBoolOptionEv","__ZN2js3cli6detail6Option14asStringOptionEv","__ZN2js3cli6detail6Option11asIntOptionEv","__ZN2js3cli6detail6Option19asMultiStringOptionEv","_OBJECT_TO_JSVAL_IMPL649","__ZNK2js11AutoIdArrayixEj","__ZN2js3cli6detail6Option20setTerminatesOptionsEb","__ZL11GetTrapArgsP9JSContextjPN2JS5ValueEPP8JSScriptPi","__ZL11TrapHandlerP9JSContextP8JSScriptPhPN2JS5ValueES5_","__ZL23DebuggerAndThrowHandlerP9JSContextP8JSScriptPhPN2JS5ValueEPv","_UINT_TO_JSVAL","_DOUBLE_TO_JSVAL632","_JSVAL_IS_TRACEABLE633","_JSVAL_TO_TRACEABLE","_JSVAL_TRACE_KIND634","_JSVAL_IS_NULL635","__ZL15CountHeapNotifyP8JSTracerPv13JSGCTraceKind","_JSVAL_TRACE_KIND_IMPL637","_JSVAL_TO_GCTHING639","__ZL8ToSourceP9JSContextPN2JS5ValueEP16JSAutoByteString","_JS_THIS644","__ZL26MapContextOptionNameToFlagP9JSContextPKc","_JSVAL_IS_DOUBLE645","_JSVAL_TO_DOUBLE646","__ZL12CopyPropertyP9JSContextP8JSObjectS2_ijPS2_","__ZN2js11AutoIdArrayC1EP9JSContextP9JSIdArray","__ZN2js11AutoIdArrayD1Ev","__ZN2js11AutoIdArrayD2Ev","__ZN2js11AutoIdArrayC2EP9JSContextP9JSIdArray","__ZNK2js3cli6detail6Option12asBoolOptionEv","__ZNK2js3cli6detail6Option14asStringOptionEv","__ZNK2js3cli6detail6Option19asMultiStringOptionEv","__ZN2js3cli12OptionParser23setArgTerminatesOptionsEPKcb","__ZN2js3cli12OptionParser12findArgumentEPKc","__ZN2js3cli12OptionParser5errorEPKcz","__ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE5beginEv","__ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE6lengthEv","__ZNK2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE5beginEv","__ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE5emptyEv","__ZNK2js3cli6detail6Option20getTerminatesOptionsEv","__ZNK2js3cli12OptionParser13getHelpOptionEv","__ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE3endEv","__ZL23OptionFlagsToFormatInfocbPj","__ZNK2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE3endEv","__ZN2js3cli12OptionParser9printHelpEPKc","__ZL14PrintParagraphPKcjjb","__ZN2js3cli12OptionParser12extractValueEjPPcPjS3_","__ZN2js3cli12OptionParser12handleOptionEPNS0_6detail6OptionEjPPcPjPb","__ZN2js3cli6detail9StringArgC1EPcj","__ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE6appendIS3_EEbT_","__ZN2js3cli12OptionParser9handleArgEjPPcPjPb","__ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEEixEj","__ZN2js3cli12OptionParser9parseArgsEiPPc","__ZN2js3cli12OptionParser10findOptionEPKc","__ZN2js3cli12OptionParser10findOptionEc","__ZNK2js3cli12OptionParser13getBoolOptionEc","__ZNK2js3cli12OptionParser10findOptionEc","__ZNK2js3cli12OptionParser20getMultiStringOptionEc","__ZN2js3cli16MultiStringRangeC1EPKNS0_6detail9StringArgES5_","__ZN2js3cli12OptionParserD2Ev","__ZN2js10Foreground7delete_INS_3cli6detail6OptionEEEvPT_","__ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEED1Ev","__ZNK2js3cli12OptionParser12findArgumentEPKc","__ZNK2js3cli12OptionParser12getStringArgEPKc","__ZNK2js3cli12OptionParser17getMultiStringArgEPKc","__ZNK2js3cli6detail12ValuedOption8isValuedEv","__ZNK2js3cli6detail17MultiStringOption10isVariadicEv","__ZNK2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE12beginNoCheckEv","__ZN2js3cli6detail12StringOptionD1Ev","__ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE12beginNoCheckEv","__ZNK2js7MoveRefINS_3cli6detail9StringArgEEcvRS3_Ev","__ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE10endNoCheckEv","__ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE10endNoCheckEv","__ZN2js10VectorImplIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyELb1EE13copyConstructIS4_EEvPS4_PKT_SB_","__ZN2js7MoveRefINS_3cli6detail9StringArgEEC2ERS3_","__ZN2js3cli16MultiStringRangeC2EPKNS0_6detail9StringArgES5_","__ZN2js3cli6detail9StringArgC2EPcj","__ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE7reserveEj","__ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE16infallibleAppendERKS4_","__ZN2js3cli12OptionParser13addBoolOptionEcPKcS3_","__ZN2js11OffTheBooks4new_INS_3cli6detail10BoolOptionEcPKcS6_EEPT_T0_T1_T2_","__ZN2js3cli12OptionParser20addMultiStringOptionEcPKcS3_S3_","__ZN2js11OffTheBooks4new_INS_3cli6detail17MultiStringOptionEcPKcS6_S6_EEPT_T0_T1_T2_T3_","__ZN2js3cli12OptionParser20addOptionalStringArgEPKcS3_","__ZN2js11OffTheBooks4new_INS_3cli6detail12StringOptionEiPKcS6_S6_EEPT_T0_T1_T2_T3_","__ZN2js3cli12OptionParser25addOptionalMultiStringArgEPKcS3_","__ZN2js11OffTheBooks4new_INS_3cli6detail17MultiStringOptionEiPKcS6_S6_EEPT_T0_T1_T2_T3_","_js_malloc696","__ZN2js3cli6detail17MultiStringOptionC1EcPKcS4_S4_","__ZN2js3cli6detail17MultiStringOptionC2EcPKcS4_S4_","__ZN2js3cli6detail12ValuedOptionC2ENS1_10OptionKindEcPKcS5_S5_","__ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEEC1ES4_","__ZN2js3cli6detail17MultiStringOptionD1Ev","__ZN2js3cli6detail17MultiStringOptionD0Ev","__ZN2js3cli6detail17MultiStringOptionD2Ev","__ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEED1Ev","__ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEED2Ev","__ZNK2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv","_js_free697","__ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEEC2ES4_","__ZN2js3cli6detail12StringOptionC1EcPKcS4_S4_","__ZN2js3cli6detail12StringOptionC2EcPKcS4_S4_","__ZN2js3cli6detail12StringOptionD0Ev","__ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE14internalAppendIS4_EEvT_","__ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE13growStorageByEj","__ZNK2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS4_Lj0ES5_EEj","__ZN2js10VectorImplIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyELb1EE13moveConstructIS4_EEvPS4_PKT_SB_","__ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE13growStorageByEj","__ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE14internalAppendIS3_EEvT_","__ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyELb0EE6growToERNS_6VectorIS3_Lj0ES4_EEj","__ZN2js4MoveINS_3cli6detail9StringArgEEENS_7MoveRefIT_EERS5_","__ZN2js7MoveRefINS_3cli6detail9StringArgEEC1ERS3_","__ZN2js10VectorImplINS_3cli6detail9StringArgELj0ENS_17SystemAllocPolicyELb0EE13moveConstructIS3_EEvPS3_PKT_SA_","__ZN2js4MoveINS_3cli6detail9StringArgEEENS_7MoveRefIT_EERKS5_","__ZN2js6VectorIPNS_3cli6detail6OptionELj0ENS_17SystemAllocPolicyEED2Ev","_malloc","_tmalloc_small","_sys_alloc","_tmalloc_large","_release_unused_segments","_sys_trim","_free","_mmap_resize","_segment_holding","_init_top","_init_bins","_calloc","_realloc","_internal_realloc","_init_mparams","_prepend_alloc","__ZNKSt9bad_alloc4whatEv","__ZSt15get_new_handlerv","__ZNSt9bad_allocC2Ev","__ZdlPv","__ZNSt9bad_allocD0Ev","__ZNSt9bad_allocD2Ev","_add_segment","__Znwj"]

